diff -pruN 1.2.1+git2.18.0-1/cgit.c 1.2.3+git2.25.1-1/cgit.c
--- 1.2.1+git2.18.0-1/cgit.c	2018-08-03 15:04:03.000000000 +0000
+++ 1.2.3+git2.25.1-1/cgit.c	2020-03-13 23:49:52.000000000 +0000
@@ -19,6 +19,16 @@
 
 const char *cgit_version = CGIT_VERSION;
 
+__attribute__((constructor))
+static void constructor_environment()
+{
+	/* Do not look in /etc/ for gitconfig and gitattributes. */
+	setenv("GIT_CONFIG_NOSYSTEM", "1", 1);
+	setenv("GIT_ATTR_NOSYSTEM", "1", 1);
+	unsetenv("HOME");
+	unsetenv("XDG_CONFIG_HOME");
+}
+
 static void add_mimetype(const char *name, const char *value)
 {
 	struct string_list_item *item;
@@ -50,6 +60,8 @@ static void repo_config(struct cgit_repo
 		repo->extra_head_content = xstrdup(value);
 	else if (!strcmp(name, "snapshots"))
 		repo->snapshots = ctx.cfg.snapshots & cgit_parse_snapshots_mask(value);
+	else if (!strcmp(name, "enable-blame"))
+		repo->enable_blame = atoi(value);
 	else if (!strcmp(name, "enable-commit-graph"))
 		repo->enable_commit_graph = atoi(value);
 	else if (!strcmp(name, "enable-log-filecount"))
@@ -563,18 +575,13 @@ static void prepare_repo_env(int *nongit
 	/* The path to the git repository. */
 	setenv("GIT_DIR", ctx.repo->path, 1);
 
-	/* Do not look in /etc/ for gitconfig and gitattributes. */
-	setenv("GIT_CONFIG_NOSYSTEM", "1", 1);
-	setenv("GIT_ATTR_NOSYSTEM", "1", 1);
-	unsetenv("HOME");
-	unsetenv("XDG_CONFIG_HOME");
-
 	/* Setup the git directory and initialize the notes system. Both of these
 	 * load local configuration from the git repository, so we do them both while
 	 * the HOME variables are unset. */
 	setup_git_directory_gently(nongit);
-	init_display_notes(NULL);
+	load_display_notes(NULL);
 }
+
 static int prepare_repo_cmd(int nongit)
 {
 	struct object_id oid;
@@ -645,7 +652,7 @@ static inline void open_auth_filter(cons
 		ctx.env.https ? ctx.env.https : "",
 		ctx.qry.repo ? ctx.qry.repo : "",
 		ctx.qry.page ? ctx.qry.page : "",
-		ctx.qry.url ? ctx.qry.url : "",
+		cgit_currentfullurl(),
 		cgit_loginurl());
 }
 
@@ -809,6 +816,8 @@ static void print_repo(FILE *f, struct c
 		fprintf(f, "repo.homepage=%s\n", repo->homepage);
 	if (repo->clone_url)
 		fprintf(f, "repo.clone-url=%s\n", repo->clone_url);
+	fprintf(f, "repo.enable-blame=%d\n",
+	        repo->enable_blame);
 	fprintf(f, "repo.enable-commit-graph=%d\n",
 	        repo->enable_commit_graph);
 	fprintf(f, "repo.enable-log-filecount=%d\n",
diff -pruN 1.2.1+git2.18.0-1/cgit.h 1.2.3+git2.25.1-1/cgit.h
--- 1.2.1+git2.18.0-1/cgit.h	2018-08-03 15:04:03.000000000 +0000
+++ 1.2.3+git2.25.1-1/cgit.h	2020-03-13 23:49:52.000000000 +0000
@@ -8,6 +8,7 @@
 #include <cache.h>
 #include <grep.h>
 #include <object.h>
+#include <object-store.h>
 #include <tree.h>
 #include <commit.h>
 #include <tag.h>
@@ -93,6 +94,7 @@ struct cgit_repo {
 	char *logo_link;
 	char *snapshot_prefix;
 	int snapshots;
+	int enable_blame;
 	int enable_commit_graph;
 	int enable_log_filecount;
 	int enable_log_linecount;
diff -pruN 1.2.1+git2.18.0-1/cgitrc.5.txt 1.2.3+git2.25.1-1/cgitrc.5.txt
--- 1.2.1+git2.18.0-1/cgitrc.5.txt	2018-08-03 15:04:03.000000000 +0000
+++ 1.2.3+git2.25.1-1/cgitrc.5.txt	2020-03-13 23:49:52.000000000 +0000
@@ -407,9 +407,12 @@ side-by-side-diffs::
 snapshots::
 	Text which specifies the default set of snapshot formats that cgit
 	generates links for. The value is a space-separated list of zero or
-	more of the values "tar", "tar.gz", "tar.bz2", "tar.xz" and "zip".
-	The special value "all" enables all snapshot formats.
-	Default value: none.
+	more of the values "tar", "tar.gz", "tar.bz2", "tar.lz", "tar.xz",
+	"tar.zst" and "zip". The special value "all" enables all snapshot
+	formats. Default value: none.
+	All compressors use default settings. Some settings can be influenced
+	with environment variables, for example set ZSTD_CLEVEL=10 in web
+	server environment for higher (but slower) zstd compression.
 
 source-filter::
 	Specifies a command which will be invoked to format plaintext blobs
@@ -485,6 +488,10 @@ repo.email-filter::
 	Override the default email-filter. Default value: none. See also:
 	"enable-filter-overrides". See also: "FILTER API".
 
+repo.enable-blame::
+	A flag which can be used to disable the global setting
+	`enable-blame'. Default value: none.
+
 repo.enable-commit-graph::
 	A flag which can be used to disable the global setting
 	`enable-commit-graph'. Default value: none.
diff -pruN 1.2.1+git2.18.0-1/cmd.c 1.2.3+git2.25.1-1/cmd.c
--- 1.2.1+git2.18.0-1/cmd.c	2018-08-03 15:04:03.000000000 +0000
+++ 1.2.3+git2.25.1-1/cmd.c	2020-03-13 23:49:52.000000000 +0000
@@ -66,7 +66,7 @@ static void about_fn(void)
 
 static void blame_fn(void)
 {
-	if (ctx.cfg.enable_blame)
+	if (ctx.repo->enable_blame)
 		cgit_print_blame();
 	else
 		cgit_print_error_page(403, "Forbidden", "Blame is disabled");
diff -pruN 1.2.1+git2.18.0-1/debian/changelog 1.2.3+git2.25.1-1/debian/changelog
--- 1.2.1+git2.18.0-1/debian/changelog	2018-12-08 17:38:21.000000000 +0000
+++ 1.2.3+git2.25.1-1/debian/changelog	2020-03-30 03:24:26.000000000 +0000
@@ -1,3 +1,18 @@
+cgit (1.2.3+git2.25.1-1) unstable; urgency=medium
+
+  [ Peter Colberg ]
+  * Use https for copyright-format URL
+  * New upstream release (Closes: #954745)
+  * Run wrap-and-sort -ast
+  * Add Build-Depends on lzip and zstd for tests
+  * Bump debhelper compat level to 12
+  * Bump Standards-Version to 4.5.0
+
+  [ Helmut Grohne ]
+  * Fix FTCBFS: Also pass cross flags to make install. (Closes: #953265)
+
+ -- Peter Colberg <peter@colberg.org>  Sun, 29 Mar 2020 23:24:26 -0400
+
 cgit (1.2.1+git2.18.0-1) unstable; urgency=medium
 
   * New upstream release (Closes: #915659)
diff -pruN 1.2.1+git2.18.0-1/debian/compat 1.2.3+git2.25.1-1/debian/compat
--- 1.2.1+git2.18.0-1/debian/compat	2018-12-08 17:38:21.000000000 +0000
+++ 1.2.3+git2.25.1-1/debian/compat	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-11
diff -pruN 1.2.1+git2.18.0-1/debian/control 1.2.3+git2.25.1-1/debian/control
--- 1.2.1+git2.18.0-1/debian/control	2018-12-08 17:38:21.000000000 +0000
+++ 1.2.3+git2.25.1-1/debian/control	2020-03-30 03:17:30.000000000 +0000
@@ -2,22 +2,26 @@ Source: cgit
 Section: net
 Priority: optional
 Maintainer: Debian cgit Maintainers <team+cgit@tracker.debian.org>
-Uploaders: Alexander Wirt <formorer@debian.org>,
-           Peter Colberg <peter@colberg.org>
-Build-Depends: asciidoc-base | asciidoc,
-               debhelper (>= 11~),
-               dh-apache2,
-               docbook-xsl,
-               liblua5.1-0-dev,
-               libssl-dev,
-               libxml2-utils,
-               pkg-config,
-               strace [linux-any],
-               tidy,
-               unzip,
-               xmlto,
-               zlib1g-dev
-Standards-Version: 4.2.1
+Uploaders:
+ Alexander Wirt <formorer@debian.org>,
+ Peter Colberg <peter@colberg.org>,
+Build-Depends:
+ asciidoc-base | asciidoc,
+ debhelper-compat (= 12),
+ dh-apache2,
+ docbook-xsl,
+ liblua5.1-0-dev,
+ libssl-dev,
+ libxml2-utils,
+ lzip,
+ pkg-config,
+ strace [linux-any],
+ tidy,
+ unzip,
+ xmlto,
+ zlib1g-dev,
+ zstd,
+Standards-Version: 4.5.0
 Homepage: https://git.zx2c4.com/cgit/
 Vcs-Git: https://salsa.debian.org/debian/cgit.git
 Vcs-Browser: https://salsa.debian.org/debian/cgit
@@ -26,12 +30,16 @@ Rules-Requires-Root: binary-targets
 Package: cgit
 Architecture: any
 Multi-Arch: foreign
-Depends: ${misc:Depends}, ${shlibs:Depends}
-Recommends: ${misc:Recommends}
-Suggests: python3,
-          python3-docutils,
-          python3-markdown,
-          python3-pygments | highlight
+Depends:
+ ${misc:Depends},
+ ${shlibs:Depends},
+Recommends:
+ ${misc:Recommends},
+Suggests:
+ python3,
+ python3-docutils,
+ python3-markdown,
+ python3-pygments | highlight,
 Description: hyperfast web frontend for git repositories written in C
  This is an attempt to create a fast web interface for the Git SCM, using a
  built-in cache to decrease server I/O pressure.
diff -pruN 1.2.1+git2.18.0-1/debian/copyright 1.2.3+git2.25.1-1/debian/copyright
--- 1.2.1+git2.18.0-1/debian/copyright	2018-12-08 17:38:21.000000000 +0000
+++ 1.2.3+git2.25.1-1/debian/copyright	2020-03-30 03:17:24.000000000 +0000
@@ -1,6 +1,6 @@
-Format: http://www.debian.org/doc/packaging-manuals/copyright-format/1.0/
+Format: https://www.debian.org/doc/packaging-manuals/copyright-format/1.0/
 Upstream-Name: cgit
-Source: <http://git.zx2c4.com/cgit/about/>
+Source: https://git.zx2c4.com/cgit/about/
 
 Files: *
 Copyright: © 2006-2018 cgit Development Team <cgit@lists.zx2c4.com>
diff -pruN 1.2.1+git2.18.0-1/debian/rules 1.2.3+git2.25.1-1/debian/rules
--- 1.2.1+git2.18.0-1/debian/rules	2018-12-08 17:38:21.000000000 +0000
+++ 1.2.3+git2.25.1-1/debian/rules	2020-03-30 03:17:30.000000000 +0000
@@ -12,6 +12,8 @@ export DEB_CFLAGS_MAINT_APPEND  = -Wall
 # package maintainers to append LDFLAGS
 export DEB_LDFLAGS_MAINT_APPEND = -Wl,--as-needed
 
+-include /usr/share/dpkg/buildtools.mk
+
 %:
 	dh $@ --with apache2
 
@@ -22,7 +24,12 @@ override_dh_auto_build:
 	dh_auto_build -- V=1
 
 override_dh_auto_install:
+# Pass cross build flags to avoid rebuild (see #953265)
+ifneq ($(DEB_BUILD_GNU_TYPE),$(DEB_HOST_GNU_TYPE))
+	dh_auto_install -- install-man CC=$(CC) PKG_CONFIG=$(PKG_CONFIG)
+else
 	dh_auto_install -- install-man
+endif
 	mv debian/cgit/usr/share/cgit/cgit.cgi debian/cgit/usr/lib/cgit
 
 override_dh_auto_test:
diff -pruN 1.2.1+git2.18.0-1/filters/email-gravatar.lua 1.2.3+git2.25.1-1/filters/email-gravatar.lua
--- 1.2.1+git2.18.0-1/filters/email-gravatar.lua	2018-08-03 15:04:03.000000000 +0000
+++ 1.2.3+git2.25.1-1/filters/email-gravatar.lua	2020-03-13 23:49:52.000000000 +0000
@@ -3,15 +3,24 @@
 -- prefix in filters. It is much faster than the corresponding python script.
 --
 -- Requirements:
--- 	luacrypto >= 0.3
--- 	<http://mkottman.github.io/luacrypto/>
+-- 	luaossl
+-- 	<http://25thandclement.com/~william/projects/luaossl.html>
 --
 
-local crypto = require("crypto")
+local digest = require("openssl.digest")
+
+function md5_hex(input)
+	local b = digest.new("md5"):final(input)
+	local x = ""
+	for i = 1, #b do
+		x = x .. string.format("%.2x", string.byte(b, i))
+	end
+	return x
+end
 
 function filter_open(email, page)
 	buffer = ""
-	md5 = crypto.digest("md5", email:sub(2, -2):lower())
+	md5 = md5_hex(email:sub(2, -2):lower())
 end
 
 function filter_close()
diff -pruN 1.2.1+git2.18.0-1/filters/email-libravatar.lua 1.2.3+git2.25.1-1/filters/email-libravatar.lua
--- 1.2.1+git2.18.0-1/filters/email-libravatar.lua	2018-08-03 15:04:03.000000000 +0000
+++ 1.2.3+git2.25.1-1/filters/email-libravatar.lua	2020-03-13 23:49:52.000000000 +0000
@@ -3,15 +3,24 @@
 -- prefix in filters.
 --
 -- Requirements:
--- 	luacrypto >= 0.3
--- 	<http://mkottman.github.io/luacrypto/>
+-- 	luaossl
+-- 	<http://25thandclement.com/~william/projects/luaossl.html>
 --
 
-local crypto = require("crypto")
+local digest = require("openssl.digest")
+
+function md5_hex(input)
+	local b = digest.new("md5"):final(input)
+	local x = ""
+	for i = 1, #b do
+		x = x .. string.format("%.2x", string.byte(b, i))
+	end
+	return x
+end
 
 function filter_open(email, page)
 	buffer = ""
-	md5 = crypto.digest("md5", email:sub(2, -2):lower())
+	md5 = md5_hex(email:sub(2, -2):lower())
 end
 
 function filter_close()
diff -pruN 1.2.1+git2.18.0-1/filters/file-authentication.lua 1.2.3+git2.25.1-1/filters/file-authentication.lua
--- 1.2.1+git2.18.0-1/filters/file-authentication.lua	2018-08-03 15:04:03.000000000 +0000
+++ 1.2.3+git2.25.1-1/filters/file-authentication.lua	2020-03-13 23:49:52.000000000 +0000
@@ -1,15 +1,15 @@
 -- This script may be used with the auth-filter.
 --
 -- Requirements:
--- 	luacrypto >= 0.3
--- 	<http://mkottman.github.io/luacrypto/>
+-- 	luaossl
+-- 	<http://25thandclement.com/~william/projects/luaossl.html>
 -- 	luaposix
 -- 	<https://github.com/luaposix/luaposix>
 --
 local sysstat = require("posix.sys.stat")
 local unistd = require("posix.unistd")
-local crypto = require("crypto")
-
+local rand = require("openssl.rand")
+local hmac = require("openssl.hmac")
 
 -- This file should contain a series of lines in the form of:
 --	username1:hash1
@@ -225,6 +225,13 @@ function get_cookie(cookies, name)
 	return url_decode(string.match(cookies, ";" .. name .. "=(.-);"))
 end
 
+function tohex(b)
+	local x = ""
+	for i = 1, #b do
+		x = x .. string.format("%.2x", string.byte(b, i))
+	end
+	return x
+end
 
 --
 --
@@ -242,12 +249,12 @@ function get_secret()
 	local secret_file = io.open(secret_filename, "r")
 	if secret_file == nil then
 		local old_umask = sysstat.umask(63)
-		local temporary_filename = secret_filename .. ".tmp." .. crypto.hex(crypto.rand.bytes(16))
+		local temporary_filename = secret_filename .. ".tmp." .. tohex(rand.bytes(16))
 		local temporary_file = io.open(temporary_filename, "w")
 		if temporary_file == nil then
 			os.exit(177)
 		end
-		temporary_file:write(crypto.hex(crypto.rand.bytes(32)))
+		temporary_file:write(tohex(rand.bytes(32)))
 		temporary_file:close()
 		unistd.link(temporary_filename, secret_filename) -- Intentionally fails in the case that another process is doing the same.
 		unistd.unlink(temporary_filename)
@@ -272,7 +279,7 @@ function validate_value(expected_field,
 	local field = ""
 	local expiration = 0
 	local salt = ""
-	local hmac = ""
+	local chmac = ""
 
 	if cookie == nil or cookie:len() < 3 or cookie:sub(1, 1) == "|" then
 		return nil
@@ -291,19 +298,19 @@ function validate_value(expected_field,
 		elseif i == 3 then
 			salt = component
 		elseif i == 4 then
-			hmac = component
+			chmac = component
 		else
 			break
 		end
 		i = i + 1
 	end
 
-	if hmac == nil or hmac:len() == 0 then
+	if chmac == nil or chmac:len() == 0 then
 		return nil
 	end
 
 	-- Lua hashes strings, so these comparisons are time invariant.
-	if hmac ~= crypto.hmac.digest("sha256", field .. "|" .. value .. "|" .. tostring(expiration) .. "|" .. salt, get_secret()) then
+	if chmac ~= tohex(hmac.new(get_secret(), "sha256"):final(field .. "|" .. value .. "|" .. tostring(expiration) .. "|" .. salt)) then
 		return nil
 	end
 
@@ -324,11 +331,11 @@ function secure_value(field, value, expi
 	end
 
 	local authstr = ""
-	local salt = crypto.hex(crypto.rand.bytes(16))
+	local salt = tohex(rand.bytes(16))
 	value = url_encode(value)
 	field = url_encode(field)
 	authstr = field .. "|" .. value .. "|" .. tostring(expiration) .. "|" .. salt
-	authstr = authstr .. "|" .. crypto.hmac.digest("sha256", authstr, get_secret())
+	authstr = authstr .. "|" .. tohex(hmac.new(get_secret(), "sha256"):final(authstr))
 	return authstr
 end
 
diff -pruN 1.2.1+git2.18.0-1/filters/gentoo-ldap-authentication.lua 1.2.3+git2.25.1-1/filters/gentoo-ldap-authentication.lua
--- 1.2.1+git2.18.0-1/filters/gentoo-ldap-authentication.lua	2018-08-03 15:04:03.000000000 +0000
+++ 1.2.3+git2.25.1-1/filters/gentoo-ldap-authentication.lua	2020-03-13 23:49:52.000000000 +0000
@@ -1,8 +1,8 @@
 -- This script may be used with the auth-filter. Be sure to configure it as you wish.
 --
 -- Requirements:
--- 	luacrypto >= 0.3
--- 	<http://mkottman.github.io/luacrypto/>
+-- 	luaossl
+-- 	<http://25thandclement.com/~william/projects/luaossl.html>
 -- 	lualdap >= 1.2
 -- 	<https://git.zx2c4.com/lualdap/about/>
 -- 	luaposix
@@ -10,9 +10,9 @@
 --
 local sysstat = require("posix.sys.stat")
 local unistd = require("posix.unistd")
-local crypto = require("crypto")
 local lualdap = require("lualdap")
-
+local rand = require("openssl.rand")
+local hmac = require("openssl.hmac")
 
 --
 --
@@ -226,6 +226,13 @@ function get_cookie(cookies, name)
 	return string.match(cookies, ";" .. name .. "=(.-);")
 end
 
+function tohex(b)
+	local x = ""
+	for i = 1, #b do
+		x = x .. string.format("%.2x", string.byte(b, i))
+	end
+	return x
+end
 
 --
 --
@@ -243,12 +250,12 @@ function get_secret()
 	local secret_file = io.open(secret_filename, "r")
 	if secret_file == nil then
 		local old_umask = sysstat.umask(63)
-		local temporary_filename = secret_filename .. ".tmp." .. crypto.hex(crypto.rand.bytes(16))
+		local temporary_filename = secret_filename .. ".tmp." .. tohex(rand.bytes(16))
 		local temporary_file = io.open(temporary_filename, "w")
 		if temporary_file == nil then
 			os.exit(177)
 		end
-		temporary_file:write(crypto.hex(crypto.rand.bytes(32)))
+		temporary_file:write(tohex(rand.bytes(32)))
 		temporary_file:close()
 		unistd.link(temporary_filename, secret_filename) -- Intentionally fails in the case that another process is doing the same.
 		unistd.unlink(temporary_filename)
@@ -273,7 +280,7 @@ function validate_value(expected_field,
 	local field = ""
 	local expiration = 0
 	local salt = ""
-	local hmac = ""
+	local chmac = ""
 
 	if cookie == nil or cookie:len() < 3 or cookie:sub(1, 1) == "|" then
 		return nil
@@ -292,19 +299,19 @@ function validate_value(expected_field,
 		elseif i == 3 then
 			salt = component
 		elseif i == 4 then
-			hmac = component
+			chmac = component
 		else
 			break
 		end
 		i = i + 1
 	end
 
-	if hmac == nil or hmac:len() == 0 then
+	if chmac == nil or chmac:len() == 0 then
 		return nil
 	end
 
 	-- Lua hashes strings, so these comparisons are time invariant.
-	if hmac ~= crypto.hmac.digest("sha256", field .. "|" .. value .. "|" .. tostring(expiration) .. "|" .. salt, get_secret()) then
+	if chmac ~= tohex(hmac.new(get_secret(), "sha256"):final(field .. "|" .. value .. "|" .. tostring(expiration) .. "|" .. salt)) then
 		return nil
 	end
 
@@ -325,11 +332,11 @@ function secure_value(field, value, expi
 	end
 
 	local authstr = ""
-	local salt = crypto.hex(crypto.rand.bytes(16))
+	local salt = tohex(rand.bytes(16))
 	value = url_encode(value)
 	field = url_encode(field)
 	authstr = field .. "|" .. value .. "|" .. tostring(expiration) .. "|" .. salt
-	authstr = authstr .. "|" .. crypto.hmac.digest("sha256", authstr, get_secret())
+	authstr = authstr .. "|" .. tohex(hmac.new(get_secret(), "sha256"):final(authstr))
 	return authstr
 end
 
diff -pruN 1.2.1+git2.18.0-1/filters/html-converters/md2html 1.2.3+git2.25.1-1/filters/html-converters/md2html
--- 1.2.1+git2.18.0-1/filters/html-converters/md2html	2018-08-03 15:04:03.000000000 +0000
+++ 1.2.3+git2.25.1-1/filters/html-converters/md2html	2020-03-13 23:49:52.000000000 +0000
@@ -3,6 +3,7 @@ import markdown
 import sys
 import io
 from pygments.formatters import HtmlFormatter
+from markdown.extensions.toc import TocExtension
 sys.stdin = io.TextIOWrapper(sys.stdin.buffer, encoding='utf-8')
 sys.stdout = io.TextIOWrapper(sys.stdout.buffer, encoding='utf-8')
 sys.stdout.write('''
@@ -48,10 +49,14 @@ sys.stdout.write('''
     line-height: 1;
     padding-left: 0;
     margin-left: -22px;
-    top: 15%}
+    top: 15%;
+}
 .markdown-body h1:hover a.anchor .mini-icon-link, .markdown-body h2:hover a.anchor .mini-icon-link, .markdown-body h3:hover a.anchor .mini-icon-link, .markdown-body h4:hover a.anchor .mini-icon-link, .markdown-body h5:hover a.anchor .mini-icon-link, .markdown-body h6:hover a.anchor .mini-icon-link {
     display: inline-block;
 }
+div#cgit .markdown-body h1 a.toclink, div#cgit .markdown-body h2 a.toclink, div#cgit .markdown-body h3 a.toclink, div#cgit .markdown-body h4 a.toclink, div#cgit .markdown-body h5 a.toclink, div#cgit .markdown-body h6 a.toclink {
+    color: black;
+}
 .markdown-body h1 tt, .markdown-body h1 code, .markdown-body h2 tt, .markdown-body h2 code, .markdown-body h3 tt, .markdown-body h3 code, .markdown-body h4 tt, .markdown-body h4 code, .markdown-body h5 tt, .markdown-body h5 code, .markdown-body h6 tt, .markdown-body h6 code {
     font-size: inherit;
 }
@@ -290,5 +295,13 @@ sys.stdout.write('''
 sys.stdout.write("<div class='markdown-body'>")
 sys.stdout.flush()
 # Note: you may want to run this through bleach for sanitization
-markdown.markdownFromFile(output_format="html5", extensions=["markdown.extensions.fenced_code", "markdown.extensions.codehilite", "markdown.extensions.tables"], extension_configs={"markdown.extensions.codehilite":{"css_class":"highlight"}})
+markdown.markdownFromFile(
+	output_format="html5",
+	extensions=[
+		"markdown.extensions.fenced_code",
+		"markdown.extensions.codehilite",
+		"markdown.extensions.tables",
+		TocExtension(anchorlink=True)],
+	extension_configs={
+		"markdown.extensions.codehilite":{"css_class":"highlight"}})
 sys.stdout.write("</div>")
diff -pruN 1.2.1+git2.18.0-1/filters/simple-authentication.lua 1.2.3+git2.25.1-1/filters/simple-authentication.lua
--- 1.2.1+git2.18.0-1/filters/simple-authentication.lua	2018-08-03 15:04:03.000000000 +0000
+++ 1.2.3+git2.25.1-1/filters/simple-authentication.lua	2020-03-13 23:49:52.000000000 +0000
@@ -1,15 +1,15 @@
 -- This script may be used with the auth-filter. Be sure to configure it as you wish.
 --
 -- Requirements:
--- 	luacrypto >= 0.3
--- 	<http://mkottman.github.io/luacrypto/>
+-- 	luaossl
+-- 	<http://25thandclement.com/~william/projects/luaossl.html>
 -- 	luaposix
 -- 	<https://github.com/luaposix/luaposix>
 --
 local sysstat = require("posix.sys.stat")
 local unistd = require("posix.unistd")
-local crypto = require("crypto")
-
+local rand = require("openssl.rand")
+local hmac = require("openssl.hmac")
 
 --
 --
@@ -180,6 +180,13 @@ function get_cookie(cookies, name)
 	return url_decode(string.match(cookies, ";" .. name .. "=(.-);"))
 end
 
+function tohex(b)
+	local x = ""
+	for i = 1, #b do
+		x = x .. string.format("%.2x", string.byte(b, i))
+	end
+	return x
+end
 
 --
 --
@@ -197,12 +204,12 @@ function get_secret()
 	local secret_file = io.open(secret_filename, "r")
 	if secret_file == nil then
 		local old_umask = sysstat.umask(63)
-		local temporary_filename = secret_filename .. ".tmp." .. crypto.hex(crypto.rand.bytes(16))
+		local temporary_filename = secret_filename .. ".tmp." .. tohex(rand.bytes(16))
 		local temporary_file = io.open(temporary_filename, "w")
 		if temporary_file == nil then
 			os.exit(177)
 		end
-		temporary_file:write(crypto.hex(crypto.rand.bytes(32)))
+		temporary_file:write(tohex(rand.bytes(32)))
 		temporary_file:close()
 		unistd.link(temporary_filename, secret_filename) -- Intentionally fails in the case that another process is doing the same.
 		unistd.unlink(temporary_filename)
@@ -227,7 +234,7 @@ function validate_value(expected_field,
 	local field = ""
 	local expiration = 0
 	local salt = ""
-	local hmac = ""
+	local chmac = ""
 
 	if cookie == nil or cookie:len() < 3 or cookie:sub(1, 1) == "|" then
 		return nil
@@ -246,19 +253,19 @@ function validate_value(expected_field,
 		elseif i == 3 then
 			salt = component
 		elseif i == 4 then
-			hmac = component
+			chmac = component
 		else
 			break
 		end
 		i = i + 1
 	end
 
-	if hmac == nil or hmac:len() == 0 then
+	if chmac == nil or chmac:len() == 0 then
 		return nil
 	end
 
 	-- Lua hashes strings, so these comparisons are time invariant.
-	if hmac ~= crypto.hmac.digest("sha256", field .. "|" .. value .. "|" .. tostring(expiration) .. "|" .. salt, get_secret()) then
+	if chmac ~= tohex(hmac.new(get_secret(), "sha256"):final(field .. "|" .. value .. "|" .. tostring(expiration) .. "|" .. salt)) then
 		return nil
 	end
 
@@ -279,11 +286,11 @@ function secure_value(field, value, expi
 	end
 
 	local authstr = ""
-	local salt = crypto.hex(crypto.rand.bytes(16))
+	local salt = tohex(rand.bytes(16))
 	value = url_encode(value)
 	field = url_encode(field)
 	authstr = field .. "|" .. value .. "|" .. tostring(expiration) .. "|" .. salt
-	authstr = authstr .. "|" .. crypto.hmac.digest("sha256", authstr, get_secret())
+	authstr = authstr .. "|" .. tohex(hmac.new(get_secret(), "sha256"):final(authstr))
 	return authstr
 end
 
diff -pruN 1.2.1+git2.18.0-1/git/add-interactive.c 1.2.3+git2.25.1-1/git/add-interactive.c
--- 1.2.1+git2.18.0-1/git/add-interactive.c	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/add-interactive.c	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,1154 @@
+#include "cache.h"
+#include "add-interactive.h"
+#include "color.h"
+#include "config.h"
+#include "diffcore.h"
+#include "revision.h"
+#include "refs.h"
+#include "string-list.h"
+#include "lockfile.h"
+#include "dir.h"
+#include "run-command.h"
+
+static void init_color(struct repository *r, struct add_i_state *s,
+		       const char *slot_name, char *dst,
+		       const char *default_color)
+{
+	char *key = xstrfmt("color.interactive.%s", slot_name);
+	const char *value;
+
+	if (!s->use_color)
+		dst[0] = '\0';
+	else if (repo_config_get_value(r, key, &value) ||
+		 color_parse(value, dst))
+		strlcpy(dst, default_color, COLOR_MAXLEN);
+
+	free(key);
+}
+
+void init_add_i_state(struct add_i_state *s, struct repository *r)
+{
+	const char *value;
+
+	s->r = r;
+
+	if (repo_config_get_value(r, "color.interactive", &value))
+		s->use_color = -1;
+	else
+		s->use_color =
+			git_config_colorbool("color.interactive", value);
+	s->use_color = want_color(s->use_color);
+
+	init_color(r, s, "header", s->header_color, GIT_COLOR_BOLD);
+	init_color(r, s, "help", s->help_color, GIT_COLOR_BOLD_RED);
+	init_color(r, s, "prompt", s->prompt_color, GIT_COLOR_BOLD_BLUE);
+	init_color(r, s, "error", s->error_color, GIT_COLOR_BOLD_RED);
+	init_color(r, s, "reset", s->reset_color, GIT_COLOR_RESET);
+	init_color(r, s, "fraginfo", s->fraginfo_color,
+		   diff_get_color(s->use_color, DIFF_FRAGINFO));
+	init_color(r, s, "context", s->context_color,
+		diff_get_color(s->use_color, DIFF_CONTEXT));
+	init_color(r, s, "old", s->file_old_color,
+		diff_get_color(s->use_color, DIFF_FILE_OLD));
+	init_color(r, s, "new", s->file_new_color,
+		diff_get_color(s->use_color, DIFF_FILE_NEW));
+}
+
+/*
+ * A "prefix item list" is a list of items that are identified by a string, and
+ * a unique prefix (if any) is determined for each item.
+ *
+ * It is implemented in the form of a pair of `string_list`s, the first one
+ * duplicating the strings, with the `util` field pointing at a structure whose
+ * first field must be `size_t prefix_length`.
+ *
+ * That `prefix_length` field will be computed by `find_unique_prefixes()`; It
+ * will be set to zero if no valid, unique prefix could be found.
+ *
+ * The second `string_list` is called `sorted` and does _not_ duplicate the
+ * strings but simply reuses the first one's, with the `util` field pointing at
+ * the `string_item_list` of the first `string_list`. It  will be populated and
+ * sorted by `find_unique_prefixes()`.
+ */
+struct prefix_item_list {
+	struct string_list items;
+	struct string_list sorted;
+	int *selected; /* for multi-selections */
+	size_t min_length, max_length;
+};
+#define PREFIX_ITEM_LIST_INIT \
+	{ STRING_LIST_INIT_DUP, STRING_LIST_INIT_NODUP, NULL, 1, 4 }
+
+static void prefix_item_list_clear(struct prefix_item_list *list)
+{
+	string_list_clear(&list->items, 1);
+	string_list_clear(&list->sorted, 0);
+	FREE_AND_NULL(list->selected);
+}
+
+static void extend_prefix_length(struct string_list_item *p,
+				 const char *other_string, size_t max_length)
+{
+	size_t *len = p->util;
+
+	if (!*len || memcmp(p->string, other_string, *len))
+		return;
+
+	for (;;) {
+		char c = p->string[*len];
+
+		/*
+		 * Is `p` a strict prefix of `other`? Or have we exhausted the
+		 * maximal length of the prefix? Or is the current character a
+		 * multi-byte UTF-8 one? If so, there is no valid, unique
+		 * prefix.
+		 */
+		if (!c || ++*len > max_length || !isascii(c)) {
+			*len = 0;
+			break;
+		}
+
+		if (c != other_string[*len - 1])
+			break;
+	}
+}
+
+static void find_unique_prefixes(struct prefix_item_list *list)
+{
+	size_t i;
+
+	if (list->sorted.nr == list->items.nr)
+		return;
+
+	string_list_clear(&list->sorted, 0);
+	/* Avoid reallocating incrementally */
+	list->sorted.items = xmalloc(st_mult(sizeof(*list->sorted.items),
+					     list->items.nr));
+	list->sorted.nr = list->sorted.alloc = list->items.nr;
+
+	for (i = 0; i < list->items.nr; i++) {
+		list->sorted.items[i].string = list->items.items[i].string;
+		list->sorted.items[i].util = list->items.items + i;
+	}
+
+	string_list_sort(&list->sorted);
+
+	for (i = 0; i < list->sorted.nr; i++) {
+		struct string_list_item *sorted_item = list->sorted.items + i;
+		struct string_list_item *item = sorted_item->util;
+		size_t *len = item->util;
+
+		*len = 0;
+		while (*len < list->min_length) {
+			char c = item->string[(*len)++];
+
+			if (!c || !isascii(c)) {
+				*len = 0;
+				break;
+			}
+		}
+
+		if (i > 0)
+			extend_prefix_length(item, sorted_item[-1].string,
+					     list->max_length);
+		if (i + 1 < list->sorted.nr)
+			extend_prefix_length(item, sorted_item[1].string,
+					     list->max_length);
+	}
+}
+
+static ssize_t find_unique(const char *string, struct prefix_item_list *list)
+{
+	int index = string_list_find_insert_index(&list->sorted, string, 1);
+	struct string_list_item *item;
+
+	if (list->items.nr != list->sorted.nr)
+		BUG("prefix_item_list in inconsistent state (%"PRIuMAX
+		    " vs %"PRIuMAX")",
+		    (uintmax_t)list->items.nr, (uintmax_t)list->sorted.nr);
+
+	if (index < 0)
+		item = list->sorted.items[-1 - index].util;
+	else if (index > 0 &&
+		 starts_with(list->sorted.items[index - 1].string, string))
+		return -1;
+	else if (index + 1 < list->sorted.nr &&
+		 starts_with(list->sorted.items[index + 1].string, string))
+		return -1;
+	else if (index < list->sorted.nr)
+		item = list->sorted.items[index].util;
+	else
+		return -1;
+	return item - list->items.items;
+}
+
+struct list_options {
+	int columns;
+	const char *header;
+	void (*print_item)(int i, int selected, struct string_list_item *item,
+			   void *print_item_data);
+	void *print_item_data;
+};
+
+static void list(struct add_i_state *s, struct string_list *list, int *selected,
+		 struct list_options *opts)
+{
+	int i, last_lf = 0;
+
+	if (!list->nr)
+		return;
+
+	if (opts->header)
+		color_fprintf_ln(stdout, s->header_color,
+				 "%s", opts->header);
+
+	for (i = 0; i < list->nr; i++) {
+		opts->print_item(i, selected ? selected[i] : 0, list->items + i,
+				 opts->print_item_data);
+
+		if ((opts->columns) && ((i + 1) % (opts->columns))) {
+			putchar('\t');
+			last_lf = 0;
+		}
+		else {
+			putchar('\n');
+			last_lf = 1;
+		}
+	}
+
+	if (!last_lf)
+		putchar('\n');
+}
+struct list_and_choose_options {
+	struct list_options list_opts;
+
+	const char *prompt;
+	enum {
+		SINGLETON = (1<<0),
+		IMMEDIATE = (1<<1),
+	} flags;
+	void (*print_help)(struct add_i_state *s);
+};
+
+#define LIST_AND_CHOOSE_ERROR (-1)
+#define LIST_AND_CHOOSE_QUIT  (-2)
+
+/*
+ * Returns the selected index in singleton mode, the number of selected items
+ * otherwise.
+ *
+ * If an error occurred, returns `LIST_AND_CHOOSE_ERROR`. Upon EOF,
+ * `LIST_AND_CHOOSE_QUIT` is returned.
+ */
+static ssize_t list_and_choose(struct add_i_state *s,
+			       struct prefix_item_list *items,
+			       struct list_and_choose_options *opts)
+{
+	int singleton = opts->flags & SINGLETON;
+	int immediate = opts->flags & IMMEDIATE;
+
+	struct strbuf input = STRBUF_INIT;
+	ssize_t res = singleton ? LIST_AND_CHOOSE_ERROR : 0;
+
+	if (!singleton) {
+		free(items->selected);
+		CALLOC_ARRAY(items->selected, items->items.nr);
+	}
+
+	if (singleton && !immediate)
+		BUG("singleton requires immediate");
+
+	find_unique_prefixes(items);
+
+	for (;;) {
+		char *p;
+
+		strbuf_reset(&input);
+
+		list(s, &items->items, items->selected, &opts->list_opts);
+
+		color_fprintf(stdout, s->prompt_color, "%s", opts->prompt);
+		fputs(singleton ? "> " : ">> ", stdout);
+		fflush(stdout);
+
+		if (strbuf_getline(&input, stdin) == EOF) {
+			putchar('\n');
+			if (immediate)
+				res = LIST_AND_CHOOSE_QUIT;
+			break;
+		}
+		strbuf_trim(&input);
+
+		if (!input.len)
+			break;
+
+		if (!strcmp(input.buf, "?")) {
+			opts->print_help(s);
+			continue;
+		}
+
+		p = input.buf;
+		for (;;) {
+			size_t sep = strcspn(p, " \t\r\n,");
+			int choose = 1;
+			/* `from` is inclusive, `to` is exclusive */
+			ssize_t from = -1, to = -1;
+
+			if (!sep) {
+				if (!*p)
+					break;
+				p++;
+				continue;
+			}
+
+			/* Input that begins with '-'; de-select */
+			if (*p == '-') {
+				choose = 0;
+				p++;
+				sep--;
+			}
+
+			if (sep == 1 && *p == '*') {
+				from = 0;
+				to = items->items.nr;
+			} else if (isdigit(*p)) {
+				char *endp;
+				/*
+				 * A range can be specified like 5-7 or 5-.
+				 *
+				 * Note: `from` is 0-based while the user input
+				 * is 1-based, hence we have to decrement by
+				 * one. We do not have to decrement `to` even
+				 * if it is 0-based because it is an exclusive
+				 * boundary.
+				 */
+				from = strtoul(p, &endp, 10) - 1;
+				if (endp == p + sep)
+					to = from + 1;
+				else if (*endp == '-') {
+					to = strtoul(++endp, &endp, 10);
+					/* extra characters after the range? */
+					if (endp != p + sep)
+						from = -1;
+				}
+			}
+
+			if (p[sep])
+				p[sep++] = '\0';
+			if (from < 0) {
+				from = find_unique(p, items);
+				if (from >= 0)
+					to = from + 1;
+			}
+
+			if (from < 0 || from >= items->items.nr ||
+			    (singleton && from + 1 != to)) {
+				color_fprintf_ln(stdout, s->error_color,
+						 _("Huh (%s)?"), p);
+				break;
+			} else if (singleton) {
+				res = from;
+				break;
+			}
+
+			if (to > items->items.nr)
+				to = items->items.nr;
+
+			for (; from < to; from++)
+				if (items->selected[from] != choose) {
+					items->selected[from] = choose;
+					res += choose ? +1 : -1;
+				}
+
+			p += sep;
+		}
+
+		if ((immediate && res != LIST_AND_CHOOSE_ERROR) ||
+		    !strcmp(input.buf, "*"))
+			break;
+	}
+
+	strbuf_release(&input);
+	return res;
+}
+
+struct adddel {
+	uintmax_t add, del;
+	unsigned seen:1, unmerged:1, binary:1;
+};
+
+struct file_item {
+	size_t prefix_length;
+	struct adddel index, worktree;
+};
+
+static void add_file_item(struct string_list *files, const char *name)
+{
+	struct file_item *item = xcalloc(sizeof(*item), 1);
+
+	string_list_append(files, name)->util = item;
+}
+
+struct pathname_entry {
+	struct hashmap_entry ent;
+	const char *name;
+	struct file_item *item;
+};
+
+static int pathname_entry_cmp(const void *unused_cmp_data,
+			      const struct hashmap_entry *he1,
+			      const struct hashmap_entry *he2,
+			      const void *name)
+{
+	const struct pathname_entry *e1 =
+		container_of(he1, const struct pathname_entry, ent);
+	const struct pathname_entry *e2 =
+		container_of(he2, const struct pathname_entry, ent);
+
+	return strcmp(e1->name, name ? (const char *)name : e2->name);
+}
+
+struct collection_status {
+	enum { FROM_WORKTREE = 0, FROM_INDEX = 1 } mode;
+
+	const char *reference;
+
+	unsigned skip_unseen:1;
+	size_t unmerged_count, binary_count;
+	struct string_list *files;
+	struct hashmap file_map;
+};
+
+static void collect_changes_cb(struct diff_queue_struct *q,
+			       struct diff_options *options,
+			       void *data)
+{
+	struct collection_status *s = data;
+	struct diffstat_t stat = { 0 };
+	int i;
+
+	if (!q->nr)
+		return;
+
+	compute_diffstat(options, &stat, q);
+
+	for (i = 0; i < stat.nr; i++) {
+		const char *name = stat.files[i]->name;
+		int hash = strhash(name);
+		struct pathname_entry *entry;
+		struct file_item *file_item;
+		struct adddel *adddel, *other_adddel;
+
+		entry = hashmap_get_entry_from_hash(&s->file_map, hash, name,
+						    struct pathname_entry, ent);
+		if (!entry) {
+			if (s->skip_unseen)
+				continue;
+
+			add_file_item(s->files, name);
+
+			entry = xcalloc(sizeof(*entry), 1);
+			hashmap_entry_init(&entry->ent, hash);
+			entry->name = s->files->items[s->files->nr - 1].string;
+			entry->item = s->files->items[s->files->nr - 1].util;
+			hashmap_add(&s->file_map, &entry->ent);
+		}
+
+		file_item = entry->item;
+		adddel = s->mode == FROM_INDEX ?
+			&file_item->index : &file_item->worktree;
+		other_adddel = s->mode == FROM_INDEX ?
+			&file_item->worktree : &file_item->index;
+		adddel->seen = 1;
+		adddel->add = stat.files[i]->added;
+		adddel->del = stat.files[i]->deleted;
+		if (stat.files[i]->is_binary) {
+			if (!other_adddel->binary)
+				s->binary_count++;
+			adddel->binary = 1;
+		}
+		if (stat.files[i]->is_unmerged) {
+			if (!other_adddel->unmerged)
+				s->unmerged_count++;
+			adddel->unmerged = 1;
+		}
+	}
+	free_diffstat_info(&stat);
+}
+
+enum modified_files_filter {
+	NO_FILTER = 0,
+	WORKTREE_ONLY = 1,
+	INDEX_ONLY = 2,
+};
+
+static int get_modified_files(struct repository *r,
+			      enum modified_files_filter filter,
+			      struct prefix_item_list *files,
+			      const struct pathspec *ps,
+			      size_t *unmerged_count,
+			      size_t *binary_count)
+{
+	struct object_id head_oid;
+	int is_initial = !resolve_ref_unsafe("HEAD", RESOLVE_REF_READING,
+					     &head_oid, NULL);
+	struct collection_status s = { 0 };
+	int i;
+
+	if (discard_index(r->index) < 0 ||
+	    repo_read_index_preload(r, ps, 0) < 0)
+		return error(_("could not read index"));
+
+	prefix_item_list_clear(files);
+	s.files = &files->items;
+	hashmap_init(&s.file_map, pathname_entry_cmp, NULL, 0);
+
+	for (i = 0; i < 2; i++) {
+		struct rev_info rev;
+		struct setup_revision_opt opt = { 0 };
+
+		if (filter == INDEX_ONLY)
+			s.mode = (i == 0) ? FROM_INDEX : FROM_WORKTREE;
+		else
+			s.mode = (i == 0) ? FROM_WORKTREE : FROM_INDEX;
+		s.skip_unseen = filter && i;
+
+		opt.def = is_initial ?
+			empty_tree_oid_hex() : oid_to_hex(&head_oid);
+
+		init_revisions(&rev, NULL);
+		setup_revisions(0, NULL, &rev, &opt);
+
+		rev.diffopt.output_format = DIFF_FORMAT_CALLBACK;
+		rev.diffopt.format_callback = collect_changes_cb;
+		rev.diffopt.format_callback_data = &s;
+
+		if (ps)
+			copy_pathspec(&rev.prune_data, ps);
+
+		if (s.mode == FROM_INDEX)
+			run_diff_index(&rev, 1);
+		else {
+			rev.diffopt.flags.ignore_dirty_submodules = 1;
+			run_diff_files(&rev, 0);
+		}
+
+		if (ps)
+			clear_pathspec(&rev.prune_data);
+	}
+	hashmap_free_entries(&s.file_map, struct pathname_entry, ent);
+	if (unmerged_count)
+		*unmerged_count = s.unmerged_count;
+	if (binary_count)
+		*binary_count = s.binary_count;
+
+	/* While the diffs are ordered already, we ran *two* diffs... */
+	string_list_sort(&files->items);
+
+	return 0;
+}
+
+static void render_adddel(struct strbuf *buf,
+				struct adddel *ad, const char *no_changes)
+{
+	if (ad->binary)
+		strbuf_addstr(buf, _("binary"));
+	else if (ad->seen)
+		strbuf_addf(buf, "+%"PRIuMAX"/-%"PRIuMAX,
+			    (uintmax_t)ad->add, (uintmax_t)ad->del);
+	else
+		strbuf_addstr(buf, no_changes);
+}
+
+/* filters out prefixes which have special meaning to list_and_choose() */
+static int is_valid_prefix(const char *prefix, size_t prefix_len)
+{
+	return prefix_len && prefix &&
+		/*
+		 * We expect `prefix` to be NUL terminated, therefore this
+		 * `strcspn()` call is okay, even if it might do much more
+		 * work than strictly necessary.
+		 */
+		strcspn(prefix, " \t\r\n,") >= prefix_len &&	/* separators */
+		*prefix != '-' &&				/* deselection */
+		!isdigit(*prefix) &&				/* selection */
+		(prefix_len != 1 ||
+		 (*prefix != '*' &&				/* "all" wildcard */
+		  *prefix != '?'));				/* prompt help */
+}
+
+struct print_file_item_data {
+	const char *modified_fmt, *color, *reset;
+	struct strbuf buf, name, index, worktree;
+	unsigned only_names:1;
+};
+
+static void print_file_item(int i, int selected, struct string_list_item *item,
+			    void *print_file_item_data)
+{
+	struct file_item *c = item->util;
+	struct print_file_item_data *d = print_file_item_data;
+	const char *highlighted = NULL;
+
+	strbuf_reset(&d->index);
+	strbuf_reset(&d->worktree);
+	strbuf_reset(&d->buf);
+
+	/* Format the item with the prefix highlighted. */
+	if (c->prefix_length > 0 &&
+	    is_valid_prefix(item->string, c->prefix_length)) {
+		strbuf_reset(&d->name);
+		strbuf_addf(&d->name, "%s%.*s%s%s", d->color,
+			    (int)c->prefix_length, item->string, d->reset,
+			    item->string + c->prefix_length);
+		highlighted = d->name.buf;
+	}
+
+	if (d->only_names) {
+		printf("%c%2d: %s", selected ? '*' : ' ', i + 1,
+		       highlighted ? highlighted : item->string);
+		return;
+	}
+
+	render_adddel(&d->worktree, &c->worktree, _("nothing"));
+	render_adddel(&d->index, &c->index, _("unchanged"));
+
+	strbuf_addf(&d->buf, d->modified_fmt, d->index.buf, d->worktree.buf,
+		    highlighted ? highlighted : item->string);
+
+	printf("%c%2d: %s", selected ? '*' : ' ', i + 1, d->buf.buf);
+}
+
+static int run_status(struct add_i_state *s, const struct pathspec *ps,
+		      struct prefix_item_list *files,
+		      struct list_and_choose_options *opts)
+{
+	if (get_modified_files(s->r, NO_FILTER, files, ps, NULL, NULL) < 0)
+		return -1;
+
+	list(s, &files->items, NULL, &opts->list_opts);
+	putchar('\n');
+
+	return 0;
+}
+
+static int run_update(struct add_i_state *s, const struct pathspec *ps,
+		      struct prefix_item_list *files,
+		      struct list_and_choose_options *opts)
+{
+	int res = 0, fd;
+	size_t count, i;
+	struct lock_file index_lock;
+
+	if (get_modified_files(s->r, WORKTREE_ONLY, files, ps, NULL, NULL) < 0)
+		return -1;
+
+	if (!files->items.nr) {
+		putchar('\n');
+		return 0;
+	}
+
+	opts->prompt = N_("Update");
+	count = list_and_choose(s, files, opts);
+	if (count <= 0) {
+		putchar('\n');
+		return 0;
+	}
+
+	fd = repo_hold_locked_index(s->r, &index_lock, LOCK_REPORT_ON_ERROR);
+	if (fd < 0) {
+		putchar('\n');
+		return -1;
+	}
+
+	for (i = 0; i < files->items.nr; i++) {
+		const char *name = files->items.items[i].string;
+		if (files->selected[i] &&
+		    add_file_to_index(s->r->index, name, 0) < 0) {
+			res = error(_("could not stage '%s'"), name);
+			break;
+		}
+	}
+
+	if (!res && write_locked_index(s->r->index, &index_lock, COMMIT_LOCK) < 0)
+		res = error(_("could not write index"));
+
+	if (!res)
+		printf(Q_("updated %d path\n",
+			  "updated %d paths\n", count), (int)count);
+
+	putchar('\n');
+	return res;
+}
+
+static void revert_from_diff(struct diff_queue_struct *q,
+			     struct diff_options *opt, void *data)
+{
+	int i, add_flags = ADD_CACHE_OK_TO_ADD | ADD_CACHE_OK_TO_REPLACE;
+
+	for (i = 0; i < q->nr; i++) {
+		struct diff_filespec *one = q->queue[i]->one;
+		struct cache_entry *ce;
+
+		if (!(one->mode && !is_null_oid(&one->oid))) {
+			remove_file_from_index(opt->repo->index, one->path);
+			printf(_("note: %s is untracked now.\n"), one->path);
+		} else {
+			ce = make_cache_entry(opt->repo->index, one->mode,
+					      &one->oid, one->path, 0, 0);
+			if (!ce)
+				die(_("make_cache_entry failed for path '%s'"),
+				    one->path);
+			add_index_entry(opt->repo->index, ce, add_flags);
+		}
+	}
+}
+
+static int run_revert(struct add_i_state *s, const struct pathspec *ps,
+		      struct prefix_item_list *files,
+		      struct list_and_choose_options *opts)
+{
+	int res = 0, fd;
+	size_t count, i, j;
+
+	struct object_id oid;
+	int is_initial = !resolve_ref_unsafe("HEAD", RESOLVE_REF_READING, &oid,
+					     NULL);
+	struct lock_file index_lock;
+	const char **paths;
+	struct tree *tree;
+	struct diff_options diffopt = { NULL };
+
+	if (get_modified_files(s->r, INDEX_ONLY, files, ps, NULL, NULL) < 0)
+		return -1;
+
+	if (!files->items.nr) {
+		putchar('\n');
+		return 0;
+	}
+
+	opts->prompt = N_("Revert");
+	count = list_and_choose(s, files, opts);
+	if (count <= 0)
+		goto finish_revert;
+
+	fd = repo_hold_locked_index(s->r, &index_lock, LOCK_REPORT_ON_ERROR);
+	if (fd < 0) {
+		res = -1;
+		goto finish_revert;
+	}
+
+	if (is_initial)
+		oidcpy(&oid, s->r->hash_algo->empty_tree);
+	else {
+		tree = parse_tree_indirect(&oid);
+		if (!tree) {
+			res = error(_("Could not parse HEAD^{tree}"));
+			goto finish_revert;
+		}
+		oidcpy(&oid, &tree->object.oid);
+	}
+
+	ALLOC_ARRAY(paths, count + 1);
+	for (i = j = 0; i < files->items.nr; i++)
+		if (files->selected[i])
+			paths[j++] = files->items.items[i].string;
+	paths[j] = NULL;
+
+	parse_pathspec(&diffopt.pathspec, 0,
+		       PATHSPEC_PREFER_FULL | PATHSPEC_LITERAL_PATH,
+		       NULL, paths);
+
+	diffopt.output_format = DIFF_FORMAT_CALLBACK;
+	diffopt.format_callback = revert_from_diff;
+	diffopt.flags.override_submodule_config = 1;
+	diffopt.repo = s->r;
+
+	if (do_diff_cache(&oid, &diffopt))
+		res = -1;
+	else {
+		diffcore_std(&diffopt);
+		diff_flush(&diffopt);
+	}
+	free(paths);
+	clear_pathspec(&diffopt.pathspec);
+
+	if (!res && write_locked_index(s->r->index, &index_lock,
+				       COMMIT_LOCK) < 0)
+		res = -1;
+	else
+		res = repo_refresh_and_write_index(s->r, REFRESH_QUIET, 0, 1,
+						   NULL, NULL, NULL);
+
+	if (!res)
+		printf(Q_("reverted %d path\n",
+			  "reverted %d paths\n", count), (int)count);
+
+finish_revert:
+	putchar('\n');
+	return res;
+}
+
+static int get_untracked_files(struct repository *r,
+			       struct prefix_item_list *files,
+			       const struct pathspec *ps)
+{
+	struct dir_struct dir = { 0 };
+	size_t i;
+	struct strbuf buf = STRBUF_INIT;
+
+	if (repo_read_index(r) < 0)
+		return error(_("could not read index"));
+
+	prefix_item_list_clear(files);
+	setup_standard_excludes(&dir);
+	add_pattern_list(&dir, EXC_CMDL, "--exclude option");
+	fill_directory(&dir, r->index, ps);
+
+	for (i = 0; i < dir.nr; i++) {
+		struct dir_entry *ent = dir.entries[i];
+
+		if (index_name_is_other(r->index, ent->name, ent->len)) {
+			strbuf_reset(&buf);
+			strbuf_add(&buf, ent->name, ent->len);
+			add_file_item(&files->items, buf.buf);
+		}
+	}
+
+	strbuf_release(&buf);
+	return 0;
+}
+
+static int run_add_untracked(struct add_i_state *s, const struct pathspec *ps,
+		      struct prefix_item_list *files,
+		      struct list_and_choose_options *opts)
+{
+	struct print_file_item_data *d = opts->list_opts.print_item_data;
+	int res = 0, fd;
+	size_t count, i;
+	struct lock_file index_lock;
+
+	if (get_untracked_files(s->r, files, ps) < 0)
+		return -1;
+
+	if (!files->items.nr) {
+		printf(_("No untracked files.\n"));
+		goto finish_add_untracked;
+	}
+
+	opts->prompt = N_("Add untracked");
+	d->only_names = 1;
+	count = list_and_choose(s, files, opts);
+	d->only_names = 0;
+	if (count <= 0)
+		goto finish_add_untracked;
+
+	fd = repo_hold_locked_index(s->r, &index_lock, LOCK_REPORT_ON_ERROR);
+	if (fd < 0) {
+		res = -1;
+		goto finish_add_untracked;
+	}
+
+	for (i = 0; i < files->items.nr; i++) {
+		const char *name = files->items.items[i].string;
+		if (files->selected[i] &&
+		    add_file_to_index(s->r->index, name, 0) < 0) {
+			res = error(_("could not stage '%s'"), name);
+			break;
+		}
+	}
+
+	if (!res &&
+	    write_locked_index(s->r->index, &index_lock, COMMIT_LOCK) < 0)
+		res = error(_("could not write index"));
+
+	if (!res)
+		printf(Q_("added %d path\n",
+			  "added %d paths\n", count), (int)count);
+
+finish_add_untracked:
+	putchar('\n');
+	return res;
+}
+
+static int run_patch(struct add_i_state *s, const struct pathspec *ps,
+		     struct prefix_item_list *files,
+		     struct list_and_choose_options *opts)
+{
+	int res = 0;
+	ssize_t count, i, j;
+	size_t unmerged_count = 0, binary_count = 0;
+
+	if (get_modified_files(s->r, WORKTREE_ONLY, files, ps,
+			       &unmerged_count, &binary_count) < 0)
+		return -1;
+
+	if (unmerged_count || binary_count) {
+		for (i = j = 0; i < files->items.nr; i++) {
+			struct file_item *item = files->items.items[i].util;
+
+			if (item->index.binary || item->worktree.binary) {
+				free(item);
+				free(files->items.items[i].string);
+			} else if (item->index.unmerged ||
+				 item->worktree.unmerged) {
+				color_fprintf_ln(stderr, s->error_color,
+						 _("ignoring unmerged: %s"),
+						 files->items.items[i].string);
+				free(item);
+				free(files->items.items[i].string);
+			} else
+				files->items.items[j++] = files->items.items[i];
+		}
+		files->items.nr = j;
+	}
+
+	if (!files->items.nr) {
+		if (binary_count)
+			fprintf(stderr, _("Only binary files changed.\n"));
+		else
+			fprintf(stderr, _("No changes.\n"));
+		return 0;
+	}
+
+	opts->prompt = N_("Patch update");
+	count = list_and_choose(s, files, opts);
+	if (count >= 0) {
+		struct argv_array args = ARGV_ARRAY_INIT;
+		struct pathspec ps_selected = { 0 };
+
+		for (i = 0; i < files->items.nr; i++)
+			if (files->selected[i])
+				argv_array_push(&args,
+						files->items.items[i].string);
+		parse_pathspec(&ps_selected,
+			       PATHSPEC_ALL_MAGIC & ~PATHSPEC_LITERAL,
+			       PATHSPEC_LITERAL_PATH, "", args.argv);
+		res = run_add_p(s->r, &ps_selected);
+		argv_array_clear(&args);
+		clear_pathspec(&ps_selected);
+	}
+
+	return res;
+}
+
+static int run_diff(struct add_i_state *s, const struct pathspec *ps,
+		    struct prefix_item_list *files,
+		    struct list_and_choose_options *opts)
+{
+	int res = 0;
+	ssize_t count, i;
+
+	struct object_id oid;
+	int is_initial = !resolve_ref_unsafe("HEAD", RESOLVE_REF_READING, &oid,
+					     NULL);
+	if (get_modified_files(s->r, INDEX_ONLY, files, ps, NULL, NULL) < 0)
+		return -1;
+
+	if (!files->items.nr) {
+		putchar('\n');
+		return 0;
+	}
+
+	opts->prompt = N_("Review diff");
+	opts->flags = IMMEDIATE;
+	count = list_and_choose(s, files, opts);
+	opts->flags = 0;
+	if (count >= 0) {
+		struct argv_array args = ARGV_ARRAY_INIT;
+
+		argv_array_pushl(&args, "git", "diff", "-p", "--cached",
+				 oid_to_hex(!is_initial ? &oid :
+					    s->r->hash_algo->empty_tree),
+				 "--", NULL);
+		for (i = 0; i < files->items.nr; i++)
+			if (files->selected[i])
+				argv_array_push(&args,
+						files->items.items[i].string);
+		res = run_command_v_opt(args.argv, 0);
+		argv_array_clear(&args);
+	}
+
+	putchar('\n');
+	return res;
+}
+
+static int run_help(struct add_i_state *s, const struct pathspec *unused_ps,
+		    struct prefix_item_list *unused_files,
+		    struct list_and_choose_options *unused_opts)
+{
+	color_fprintf_ln(stdout, s->help_color, "status        - %s",
+			 _("show paths with changes"));
+	color_fprintf_ln(stdout, s->help_color, "update        - %s",
+			 _("add working tree state to the staged set of changes"));
+	color_fprintf_ln(stdout, s->help_color, "revert        - %s",
+			 _("revert staged set of changes back to the HEAD version"));
+	color_fprintf_ln(stdout, s->help_color, "patch         - %s",
+			 _("pick hunks and update selectively"));
+	color_fprintf_ln(stdout, s->help_color, "diff          - %s",
+			 _("view diff between HEAD and index"));
+	color_fprintf_ln(stdout, s->help_color, "add untracked - %s",
+			 _("add contents of untracked files to the staged set of changes"));
+
+	return 0;
+}
+
+static void choose_prompt_help(struct add_i_state *s)
+{
+	color_fprintf_ln(stdout, s->help_color, "%s",
+			 _("Prompt help:"));
+	color_fprintf_ln(stdout, s->help_color, "1          - %s",
+			 _("select a single item"));
+	color_fprintf_ln(stdout, s->help_color, "3-5        - %s",
+			 _("select a range of items"));
+	color_fprintf_ln(stdout, s->help_color, "2-3,6-9    - %s",
+			 _("select multiple ranges"));
+	color_fprintf_ln(stdout, s->help_color, "foo        - %s",
+			 _("select item based on unique prefix"));
+	color_fprintf_ln(stdout, s->help_color, "-...       - %s",
+			 _("unselect specified items"));
+	color_fprintf_ln(stdout, s->help_color, "*          - %s",
+			 _("choose all items"));
+	color_fprintf_ln(stdout, s->help_color, "           - %s",
+			 _("(empty) finish selecting"));
+}
+
+typedef int (*command_t)(struct add_i_state *s, const struct pathspec *ps,
+			 struct prefix_item_list *files,
+			 struct list_and_choose_options *opts);
+
+struct command_item {
+	size_t prefix_length;
+	command_t command;
+};
+
+struct print_command_item_data {
+	const char *color, *reset;
+};
+
+static void print_command_item(int i, int selected,
+			       struct string_list_item *item,
+			       void *print_command_item_data)
+{
+	struct print_command_item_data *d = print_command_item_data;
+	struct command_item *util = item->util;
+
+	if (!util->prefix_length ||
+	    !is_valid_prefix(item->string, util->prefix_length))
+		printf(" %2d: %s", i + 1, item->string);
+	else
+		printf(" %2d: %s%.*s%s%s", i + 1,
+		       d->color, (int)util->prefix_length, item->string,
+		       d->reset, item->string + util->prefix_length);
+}
+
+static void command_prompt_help(struct add_i_state *s)
+{
+	const char *help_color = s->help_color;
+	color_fprintf_ln(stdout, help_color, "%s", _("Prompt help:"));
+	color_fprintf_ln(stdout, help_color, "1          - %s",
+			 _("select a numbered item"));
+	color_fprintf_ln(stdout, help_color, "foo        - %s",
+			 _("select item based on unique prefix"));
+	color_fprintf_ln(stdout, help_color, "           - %s",
+			 _("(empty) select nothing"));
+}
+
+int run_add_i(struct repository *r, const struct pathspec *ps)
+{
+	struct add_i_state s = { NULL };
+	struct print_command_item_data data = { "[", "]" };
+	struct list_and_choose_options main_loop_opts = {
+		{ 4, N_("*** Commands ***"), print_command_item, &data },
+		N_("What now"), SINGLETON | IMMEDIATE, command_prompt_help
+	};
+	struct {
+		const char *string;
+		command_t command;
+	} command_list[] = {
+		{ "status", run_status },
+		{ "update", run_update },
+		{ "revert", run_revert },
+		{ "add untracked", run_add_untracked },
+		{ "patch", run_patch },
+		{ "diff", run_diff },
+		{ "quit", NULL },
+		{ "help", run_help },
+	};
+	struct prefix_item_list commands = PREFIX_ITEM_LIST_INIT;
+
+	struct print_file_item_data print_file_item_data = {
+		"%12s %12s %s", NULL, NULL,
+		STRBUF_INIT, STRBUF_INIT, STRBUF_INIT, STRBUF_INIT
+	};
+	struct list_and_choose_options opts = {
+		{ 0, NULL, print_file_item, &print_file_item_data },
+		NULL, 0, choose_prompt_help
+	};
+	struct strbuf header = STRBUF_INIT;
+	struct prefix_item_list files = PREFIX_ITEM_LIST_INIT;
+	ssize_t i;
+	int res = 0;
+
+	for (i = 0; i < ARRAY_SIZE(command_list); i++) {
+		struct command_item *util = xcalloc(sizeof(*util), 1);
+		util->command = command_list[i].command;
+		string_list_append(&commands.items, command_list[i].string)
+			->util = util;
+	}
+
+	init_add_i_state(&s, r);
+
+	/*
+	 * When color was asked for, use the prompt color for
+	 * highlighting, otherwise use square brackets.
+	 */
+	if (s.use_color) {
+		data.color = s.prompt_color;
+		data.reset = s.reset_color;
+	}
+	print_file_item_data.color = data.color;
+	print_file_item_data.reset = data.reset;
+
+	strbuf_addstr(&header, "      ");
+	strbuf_addf(&header, print_file_item_data.modified_fmt,
+		    _("staged"), _("unstaged"), _("path"));
+	opts.list_opts.header = header.buf;
+
+	if (discard_index(r->index) < 0 ||
+	    repo_read_index(r) < 0 ||
+	    repo_refresh_and_write_index(r, REFRESH_QUIET, 0, 1,
+					 NULL, NULL, NULL) < 0)
+		warning(_("could not refresh index"));
+
+	res = run_status(&s, ps, &files, &opts);
+
+	for (;;) {
+		struct command_item *util;
+
+		i = list_and_choose(&s, &commands, &main_loop_opts);
+		if (i < 0 || i >= commands.items.nr)
+			util = NULL;
+		else
+			util = commands.items.items[i].util;
+
+		if (i == LIST_AND_CHOOSE_QUIT || (util && !util->command)) {
+			printf(_("Bye.\n"));
+			res = 0;
+			break;
+		}
+
+		if (util)
+			res = util->command(&s, ps, &files, &opts);
+	}
+
+	prefix_item_list_clear(&files);
+	strbuf_release(&print_file_item_data.buf);
+	strbuf_release(&print_file_item_data.name);
+	strbuf_release(&print_file_item_data.index);
+	strbuf_release(&print_file_item_data.worktree);
+	strbuf_release(&header);
+	prefix_item_list_clear(&commands);
+
+	return res;
+}
diff -pruN 1.2.1+git2.18.0-1/git/add-interactive.h 1.2.3+git2.25.1-1/git/add-interactive.h
--- 1.2.1+git2.18.0-1/git/add-interactive.h	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/add-interactive.h	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,27 @@
+#ifndef ADD_INTERACTIVE_H
+#define ADD_INTERACTIVE_H
+
+#include "color.h"
+
+struct add_i_state {
+	struct repository *r;
+	int use_color;
+	char header_color[COLOR_MAXLEN];
+	char help_color[COLOR_MAXLEN];
+	char prompt_color[COLOR_MAXLEN];
+	char error_color[COLOR_MAXLEN];
+	char reset_color[COLOR_MAXLEN];
+	char fraginfo_color[COLOR_MAXLEN];
+	char context_color[COLOR_MAXLEN];
+	char file_old_color[COLOR_MAXLEN];
+	char file_new_color[COLOR_MAXLEN];
+};
+
+void init_add_i_state(struct add_i_state *s, struct repository *r);
+
+struct repository;
+struct pathspec;
+int run_add_i(struct repository *r, const struct pathspec *ps);
+int run_add_p(struct repository *r, const struct pathspec *ps);
+
+#endif
diff -pruN 1.2.1+git2.18.0-1/git/add-patch.c 1.2.3+git2.25.1-1/git/add-patch.c
--- 1.2.1+git2.18.0-1/git/add-patch.c	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/add-patch.c	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,1338 @@
+#include "cache.h"
+#include "add-interactive.h"
+#include "strbuf.h"
+#include "run-command.h"
+#include "argv-array.h"
+#include "pathspec.h"
+#include "color.h"
+#include "diff.h"
+
+enum prompt_mode_type {
+	PROMPT_MODE_CHANGE = 0, PROMPT_DELETION, PROMPT_HUNK
+};
+
+static const char *prompt_mode[] = {
+	N_("Stage mode change [y,n,a,q,d%s,?]? "),
+	N_("Stage deletion [y,n,a,q,d%s,?]? "),
+	N_("Stage this hunk [y,n,a,q,d%s,?]? ")
+};
+
+struct hunk_header {
+	unsigned long old_offset, old_count, new_offset, new_count;
+	/*
+	 * Start/end offsets to the extra text after the second `@@` in the
+	 * hunk header, e.g. the function signature. This is expected to
+	 * include the newline.
+	 */
+	size_t extra_start, extra_end, colored_extra_start, colored_extra_end;
+};
+
+struct hunk {
+	size_t start, end, colored_start, colored_end, splittable_into;
+	ssize_t delta;
+	enum { UNDECIDED_HUNK = 0, SKIP_HUNK, USE_HUNK } use;
+	struct hunk_header header;
+};
+
+struct add_p_state {
+	struct add_i_state s;
+	struct strbuf answer, buf;
+
+	/* parsed diff */
+	struct strbuf plain, colored;
+	struct file_diff {
+		struct hunk head;
+		struct hunk *hunk;
+		size_t hunk_nr, hunk_alloc;
+		unsigned deleted:1, mode_change:1,binary:1;
+	} *file_diff;
+	size_t file_diff_nr;
+};
+
+static void err(struct add_p_state *s, const char *fmt, ...)
+{
+	va_list args;
+
+	va_start(args, fmt);
+	fputs(s->s.error_color, stderr);
+	vfprintf(stderr, fmt, args);
+	fputs(s->s.reset_color, stderr);
+	fputc('\n', stderr);
+	va_end(args);
+}
+
+static void setup_child_process(struct add_p_state *s,
+				struct child_process *cp, ...)
+{
+	va_list ap;
+	const char *arg;
+
+	va_start(ap, cp);
+	while ((arg = va_arg(ap, const char *)))
+		argv_array_push(&cp->args, arg);
+	va_end(ap);
+
+	cp->git_cmd = 1;
+	argv_array_pushf(&cp->env_array,
+			 INDEX_ENVIRONMENT "=%s", s->s.r->index_file);
+}
+
+static int parse_range(const char **p,
+		       unsigned long *offset, unsigned long *count)
+{
+	char *pend;
+
+	*offset = strtoul(*p, &pend, 10);
+	if (pend == *p)
+		return -1;
+	if (*pend != ',') {
+		*count = 1;
+		*p = pend;
+		return 0;
+	}
+	*count = strtoul(pend + 1, (char **)p, 10);
+	return *p == pend + 1 ? -1 : 0;
+}
+
+static int parse_hunk_header(struct add_p_state *s, struct hunk *hunk)
+{
+	struct hunk_header *header = &hunk->header;
+	const char *line = s->plain.buf + hunk->start, *p = line;
+	char *eol = memchr(p, '\n', s->plain.len - hunk->start);
+
+	if (!eol)
+		eol = s->plain.buf + s->plain.len;
+
+	if (!skip_prefix(p, "@@ -", &p) ||
+	    parse_range(&p, &header->old_offset, &header->old_count) < 0 ||
+	    !skip_prefix(p, " +", &p) ||
+	    parse_range(&p, &header->new_offset, &header->new_count) < 0 ||
+	    !skip_prefix(p, " @@", &p))
+		return error(_("could not parse hunk header '%.*s'"),
+			     (int)(eol - line), line);
+
+	hunk->start = eol - s->plain.buf + (*eol == '\n');
+	header->extra_start = p - s->plain.buf;
+	header->extra_end = hunk->start;
+
+	if (!s->colored.len) {
+		header->colored_extra_start = header->colored_extra_end = 0;
+		return 0;
+	}
+
+	/* Now find the extra text in the colored diff */
+	line = s->colored.buf + hunk->colored_start;
+	eol = memchr(line, '\n', s->colored.len - hunk->colored_start);
+	if (!eol)
+		eol = s->colored.buf + s->colored.len;
+	p = memmem(line, eol - line, "@@ -", 4);
+	if (!p)
+		return error(_("could not parse colored hunk header '%.*s'"),
+			     (int)(eol - line), line);
+	p = memmem(p + 4, eol - p - 4, " @@", 3);
+	if (!p)
+		return error(_("could not parse colored hunk header '%.*s'"),
+			     (int)(eol - line), line);
+	hunk->colored_start = eol - s->colored.buf + (*eol == '\n');
+	header->colored_extra_start = p + 3 - s->colored.buf;
+	header->colored_extra_end = hunk->colored_start;
+
+	return 0;
+}
+
+static int is_octal(const char *p, size_t len)
+{
+	if (!len)
+		return 0;
+
+	while (len--)
+		if (*p < '0' || *(p++) > '7')
+			return 0;
+	return 1;
+}
+
+static int parse_diff(struct add_p_state *s, const struct pathspec *ps)
+{
+	struct argv_array args = ARGV_ARRAY_INIT;
+	struct strbuf *plain = &s->plain, *colored = NULL;
+	struct child_process cp = CHILD_PROCESS_INIT;
+	char *p, *pend, *colored_p = NULL, *colored_pend = NULL, marker = '\0';
+	size_t file_diff_alloc = 0, i, color_arg_index;
+	struct file_diff *file_diff = NULL;
+	struct hunk *hunk = NULL;
+	int res;
+
+	/* Use `--no-color` explicitly, just in case `diff.color = always`. */
+	argv_array_pushl(&args, "diff-files", "-p", "--no-color", "--", NULL);
+	color_arg_index = args.argc - 2;
+	for (i = 0; i < ps->nr; i++)
+		argv_array_push(&args, ps->items[i].original);
+
+	setup_child_process(s, &cp, NULL);
+	cp.argv = args.argv;
+	res = capture_command(&cp, plain, 0);
+	if (res) {
+		argv_array_clear(&args);
+		return error(_("could not parse diff"));
+	}
+	if (!plain->len) {
+		argv_array_clear(&args);
+		return 0;
+	}
+	strbuf_complete_line(plain);
+
+	if (want_color_fd(1, -1)) {
+		struct child_process colored_cp = CHILD_PROCESS_INIT;
+
+		setup_child_process(s, &colored_cp, NULL);
+		xsnprintf((char *)args.argv[color_arg_index], 8, "--color");
+		colored_cp.argv = args.argv;
+		colored = &s->colored;
+		res = capture_command(&colored_cp, colored, 0);
+		argv_array_clear(&args);
+		if (res)
+			return error(_("could not parse colored diff"));
+		strbuf_complete_line(colored);
+		colored_p = colored->buf;
+		colored_pend = colored_p + colored->len;
+	}
+	argv_array_clear(&args);
+
+	/* parse files and hunks */
+	p = plain->buf;
+	pend = p + plain->len;
+	while (p != pend) {
+		char *eol = memchr(p, '\n', pend - p);
+		const char *deleted = NULL, *mode_change = NULL;
+
+		if (!eol)
+			eol = pend;
+
+		if (starts_with(p, "diff ")) {
+			s->file_diff_nr++;
+			ALLOC_GROW(s->file_diff, s->file_diff_nr,
+				   file_diff_alloc);
+			file_diff = s->file_diff + s->file_diff_nr - 1;
+			memset(file_diff, 0, sizeof(*file_diff));
+			hunk = &file_diff->head;
+			hunk->start = p - plain->buf;
+			if (colored_p)
+				hunk->colored_start = colored_p - colored->buf;
+			marker = '\0';
+		} else if (p == plain->buf)
+			BUG("diff starts with unexpected line:\n"
+			    "%.*s\n", (int)(eol - p), p);
+		else if (file_diff->deleted)
+			; /* keep the rest of the file in a single "hunk" */
+		else if (starts_with(p, "@@ ") ||
+			 (hunk == &file_diff->head &&
+			  skip_prefix(p, "deleted file", &deleted))) {
+			if (marker == '-' || marker == '+')
+				/*
+				 * Should not happen; previous hunk did not end
+				 * in a context line? Handle it anyway.
+				 */
+				hunk->splittable_into++;
+
+			file_diff->hunk_nr++;
+			ALLOC_GROW(file_diff->hunk, file_diff->hunk_nr,
+				   file_diff->hunk_alloc);
+			hunk = file_diff->hunk + file_diff->hunk_nr - 1;
+			memset(hunk, 0, sizeof(*hunk));
+
+			hunk->start = p - plain->buf;
+			if (colored)
+				hunk->colored_start = colored_p - colored->buf;
+
+			if (deleted)
+				file_diff->deleted = 1;
+			else if (parse_hunk_header(s, hunk) < 0)
+				return -1;
+
+			/*
+			 * Start counting into how many hunks this one can be
+			 * split
+			 */
+			marker = *p;
+		} else if (hunk == &file_diff->head &&
+			   skip_prefix(p, "old mode ", &mode_change) &&
+			   is_octal(mode_change, eol - mode_change)) {
+			if (file_diff->mode_change)
+				BUG("double mode change?\n\n%.*s",
+				    (int)(eol - plain->buf), plain->buf);
+			if (file_diff->hunk_nr++)
+				BUG("mode change in the middle?\n\n%.*s",
+				    (int)(eol - plain->buf), plain->buf);
+
+			/*
+			 * Do *not* change `hunk`: the mode change pseudo-hunk
+			 * is _part of_ the header "hunk".
+			 */
+			file_diff->mode_change = 1;
+			ALLOC_GROW(file_diff->hunk, file_diff->hunk_nr,
+				   file_diff->hunk_alloc);
+			memset(file_diff->hunk, 0, sizeof(struct hunk));
+			file_diff->hunk->start = p - plain->buf;
+			if (colored_p)
+				file_diff->hunk->colored_start =
+					colored_p - colored->buf;
+		} else if (hunk == &file_diff->head &&
+			   skip_prefix(p, "new mode ", &mode_change) &&
+			   is_octal(mode_change, eol - mode_change)) {
+
+			/*
+			 * Extend the "mode change" pseudo-hunk to include also
+			 * the "new mode" line.
+			 */
+			if (!file_diff->mode_change)
+				BUG("'new mode' without 'old mode'?\n\n%.*s",
+				    (int)(eol - plain->buf), plain->buf);
+			if (file_diff->hunk_nr != 1)
+				BUG("mode change in the middle?\n\n%.*s",
+				    (int)(eol - plain->buf), plain->buf);
+			if (p - plain->buf != file_diff->hunk->end)
+				BUG("'new mode' does not immediately follow "
+				    "'old mode'?\n\n%.*s",
+				    (int)(eol - plain->buf), plain->buf);
+		} else if (hunk == &file_diff->head &&
+			   starts_with(p, "Binary files "))
+			file_diff->binary = 1;
+
+		if (file_diff->deleted && file_diff->mode_change)
+			BUG("diff contains delete *and* a mode change?!?\n%.*s",
+			    (int)(eol - (plain->buf + file_diff->head.start)),
+			    plain->buf + file_diff->head.start);
+
+		if ((marker == '-' || marker == '+') && *p == ' ')
+			hunk->splittable_into++;
+		if (marker && *p != '\\')
+			marker = *p;
+
+		p = eol == pend ? pend : eol + 1;
+		hunk->end = p - plain->buf;
+
+		if (colored) {
+			char *colored_eol = memchr(colored_p, '\n',
+						   colored_pend - colored_p);
+			if (colored_eol)
+				colored_p = colored_eol + 1;
+			else
+				colored_p = colored_pend;
+
+			hunk->colored_end = colored_p - colored->buf;
+		}
+
+		if (mode_change) {
+			if (file_diff->hunk_nr != 1)
+				BUG("mode change in hunk #%d???",
+				    (int)file_diff->hunk_nr);
+			/* Adjust the end of the "mode change" pseudo-hunk */
+			file_diff->hunk->end = hunk->end;
+			if (colored)
+				file_diff->hunk->colored_end = hunk->colored_end;
+		}
+	}
+
+	if (marker == '-' || marker == '+')
+		/*
+		 * Last hunk ended in non-context line (i.e. it appended lines
+		 * to the file, so there are no trailing context lines).
+		 */
+		hunk->splittable_into++;
+
+	return 0;
+}
+
+static size_t find_next_line(struct strbuf *sb, size_t offset)
+{
+	char *eol;
+
+	if (offset >= sb->len)
+		BUG("looking for next line beyond buffer (%d >= %d)\n%s",
+		    (int)offset, (int)sb->len, sb->buf);
+
+	eol = memchr(sb->buf + offset, '\n', sb->len - offset);
+	if (!eol)
+		return sb->len;
+	return eol - sb->buf + 1;
+}
+
+static void render_hunk(struct add_p_state *s, struct hunk *hunk,
+			ssize_t delta, int colored, struct strbuf *out)
+{
+	struct hunk_header *header = &hunk->header;
+
+	if (hunk->header.old_offset != 0 || hunk->header.new_offset != 0) {
+		/*
+		 * Generate the hunk header dynamically, except for special
+		 * hunks (such as the diff header).
+		 */
+		const char *p;
+		size_t len;
+		unsigned long old_offset = header->old_offset;
+		unsigned long new_offset = header->new_offset;
+
+		if (!colored) {
+			p = s->plain.buf + header->extra_start;
+			len = header->extra_end - header->extra_start;
+		} else {
+			strbuf_addstr(out, s->s.fraginfo_color);
+			p = s->colored.buf + header->colored_extra_start;
+			len = header->colored_extra_end
+				- header->colored_extra_start;
+		}
+
+		new_offset += delta;
+
+		strbuf_addf(out, "@@ -%lu,%lu +%lu,%lu @@",
+			    old_offset, header->old_count,
+			    new_offset, header->new_count);
+		if (len)
+			strbuf_add(out, p, len);
+		else if (colored)
+			strbuf_addf(out, "%s\n", GIT_COLOR_RESET);
+		else
+			strbuf_addch(out, '\n');
+	}
+
+	if (colored)
+		strbuf_add(out, s->colored.buf + hunk->colored_start,
+			   hunk->colored_end - hunk->colored_start);
+	else
+		strbuf_add(out, s->plain.buf + hunk->start,
+			   hunk->end - hunk->start);
+}
+
+static void render_diff_header(struct add_p_state *s,
+			       struct file_diff *file_diff, int colored,
+			       struct strbuf *out)
+{
+	/*
+	 * If there was a mode change, the first hunk is a pseudo hunk that
+	 * corresponds to the mode line in the header. If the user did not want
+	 * to stage that "hunk", we actually have to cut it out from the header.
+	 */
+	int skip_mode_change =
+		file_diff->mode_change && file_diff->hunk->use != USE_HUNK;
+	struct hunk *head = &file_diff->head, *first = file_diff->hunk;
+
+	if (!skip_mode_change) {
+		render_hunk(s, head, 0, colored, out);
+		return;
+	}
+
+	if (colored) {
+		const char *p = s->colored.buf;
+
+		strbuf_add(out, p + head->colored_start,
+			    first->colored_start - head->colored_start);
+		strbuf_add(out, p + first->colored_end,
+			    head->colored_end - first->colored_end);
+	} else {
+		const char *p = s->plain.buf;
+
+		strbuf_add(out, p + head->start, first->start - head->start);
+		strbuf_add(out, p + first->end, head->end - first->end);
+	}
+}
+
+/* Coalesce hunks again that were split */
+static int merge_hunks(struct add_p_state *s, struct file_diff *file_diff,
+		       size_t *hunk_index, int use_all, struct hunk *merged)
+{
+	size_t i = *hunk_index, delta;
+	struct hunk *hunk = file_diff->hunk + i;
+	/* `header` corresponds to the merged hunk */
+	struct hunk_header *header = &merged->header, *next;
+
+	if (!use_all && hunk->use != USE_HUNK)
+		return 0;
+
+	*merged = *hunk;
+	/* We simply skip the colored part (if any) when merging hunks */
+	merged->colored_start = merged->colored_end = 0;
+
+	for (; i + 1 < file_diff->hunk_nr; i++) {
+		hunk++;
+		next = &hunk->header;
+
+		/*
+		 * Stop merging hunks when:
+		 *
+		 * - the hunk is not selected for use, or
+		 * - the hunk does not overlap with the already-merged hunk(s)
+		 */
+		if ((!use_all && hunk->use != USE_HUNK) ||
+		    header->new_offset >= next->new_offset + merged->delta ||
+		    header->new_offset + header->new_count
+		    < next->new_offset + merged->delta)
+			break;
+
+		/*
+		 * If the hunks were not edited, and overlap, we can simply
+		 * extend the line range.
+		 */
+		if (merged->start < hunk->start && merged->end > hunk->start) {
+			merged->end = hunk->end;
+			merged->colored_end = hunk->colored_end;
+			delta = 0;
+		} else {
+			const char *plain = s->plain.buf;
+			size_t  overlapping_line_count = header->new_offset
+				+ header->new_count - merged->delta
+				- next->new_offset;
+			size_t overlap_end = hunk->start;
+			size_t overlap_start = overlap_end;
+			size_t overlap_next, len, j;
+
+			/*
+			 * One of the hunks was edited: the modified hunk was
+			 * appended to the strbuf `s->plain`.
+			 *
+			 * Let's ensure that at least the last context line of
+			 * the first hunk overlaps with the corresponding line
+			 * of the second hunk, and then merge.
+			 */
+			for (j = 0; j < overlapping_line_count; j++) {
+				overlap_next = find_next_line(&s->plain,
+							      overlap_end);
+
+				if (overlap_next > hunk->end)
+					BUG("failed to find %d context lines "
+					    "in:\n%.*s",
+					    (int)overlapping_line_count,
+					    (int)(hunk->end - hunk->start),
+					    plain + hunk->start);
+
+				if (plain[overlap_end] != ' ')
+					return error(_("expected context line "
+						       "#%d in\n%.*s"),
+						     (int)(j + 1),
+						     (int)(hunk->end
+							   - hunk->start),
+						     plain + hunk->start);
+
+				overlap_start = overlap_end;
+				overlap_end = overlap_next;
+			}
+			len = overlap_end - overlap_start;
+
+			if (len > merged->end - merged->start ||
+			    memcmp(plain + merged->end - len,
+				   plain + overlap_start, len))
+				return error(_("hunks do not overlap:\n%.*s\n"
+					       "\tdoes not end with:\n%.*s"),
+					     (int)(merged->end - merged->start),
+					     plain + merged->start,
+					     (int)len, plain + overlap_start);
+
+			/*
+			 * Since the start-end ranges are not adjacent, we
+			 * cannot simply take the union of the ranges. To
+			 * address that, we temporarily append the union of the
+			 * lines to the `plain` strbuf.
+			 */
+			if (merged->end != s->plain.len) {
+				size_t start = s->plain.len;
+
+				strbuf_add(&s->plain, plain + merged->start,
+					   merged->end - merged->start);
+				plain = s->plain.buf;
+				merged->start = start;
+				merged->end = s->plain.len;
+			}
+
+			strbuf_add(&s->plain,
+				   plain + overlap_end,
+				   hunk->end - overlap_end);
+			merged->end = s->plain.len;
+			merged->splittable_into += hunk->splittable_into;
+			delta = merged->delta;
+			merged->delta += hunk->delta;
+		}
+
+		header->old_count = next->old_offset + next->old_count
+			- header->old_offset;
+		header->new_count = next->new_offset + delta
+			+ next->new_count - header->new_offset;
+	}
+
+	if (i == *hunk_index)
+		return 0;
+
+	*hunk_index = i;
+	return 1;
+}
+
+static void reassemble_patch(struct add_p_state *s,
+			     struct file_diff *file_diff, int use_all,
+			     struct strbuf *out)
+{
+	struct hunk *hunk;
+	size_t save_len = s->plain.len, i;
+	ssize_t delta = 0;
+
+	render_diff_header(s, file_diff, 0, out);
+
+	for (i = file_diff->mode_change; i < file_diff->hunk_nr; i++) {
+		struct hunk merged = { 0 };
+
+		hunk = file_diff->hunk + i;
+		if (!use_all && hunk->use != USE_HUNK)
+			delta += hunk->header.old_count
+				- hunk->header.new_count;
+		else {
+			/* merge overlapping hunks into a temporary hunk */
+			if (merge_hunks(s, file_diff, &i, use_all, &merged))
+				hunk = &merged;
+
+			render_hunk(s, hunk, delta, 0, out);
+
+			/*
+			 * In case `merge_hunks()` used `plain` as a scratch
+			 * pad (this happens when an edited hunk had to be
+			 * coalesced with another hunk).
+			 */
+			strbuf_setlen(&s->plain, save_len);
+
+			delta += hunk->delta;
+		}
+	}
+}
+
+static int split_hunk(struct add_p_state *s, struct file_diff *file_diff,
+		       size_t hunk_index)
+{
+	int colored = !!s->colored.len, first = 1;
+	struct hunk *hunk = file_diff->hunk + hunk_index;
+	size_t splittable_into;
+	size_t end, colored_end, current, colored_current = 0, context_line_count;
+	struct hunk_header remaining, *header;
+	char marker, ch;
+
+	if (hunk_index >= file_diff->hunk_nr)
+		BUG("invalid hunk index: %d (must be >= 0 and < %d)",
+		    (int)hunk_index, (int)file_diff->hunk_nr);
+
+	if (hunk->splittable_into < 2)
+		return 0;
+	splittable_into = hunk->splittable_into;
+
+	end = hunk->end;
+	colored_end = hunk->colored_end;
+
+	remaining = hunk->header;
+
+	file_diff->hunk_nr += splittable_into - 1;
+	ALLOC_GROW(file_diff->hunk, file_diff->hunk_nr, file_diff->hunk_alloc);
+	if (hunk_index + splittable_into < file_diff->hunk_nr)
+		memmove(file_diff->hunk + hunk_index + splittable_into,
+			file_diff->hunk + hunk_index + 1,
+			(file_diff->hunk_nr - hunk_index - splittable_into)
+			* sizeof(*hunk));
+	hunk = file_diff->hunk + hunk_index;
+	hunk->splittable_into = 1;
+	memset(hunk + 1, 0, (splittable_into - 1) * sizeof(*hunk));
+
+	header = &hunk->header;
+	header->old_count = header->new_count = 0;
+
+	current = hunk->start;
+	if (colored)
+		colored_current = hunk->colored_start;
+	marker = '\0';
+	context_line_count = 0;
+
+	while (splittable_into > 1) {
+		ch = s->plain.buf[current];
+
+		if (!ch)
+			BUG("buffer overrun while splitting hunks");
+
+		/*
+		 * Is this the first context line after a chain of +/- lines?
+		 * Then record the start of the next split hunk.
+		 */
+		if ((marker == '-' || marker == '+') && ch == ' ') {
+			first = 0;
+			hunk[1].start = current;
+			if (colored)
+				hunk[1].colored_start = colored_current;
+			context_line_count = 0;
+		}
+
+		/*
+		 * Was the previous line a +/- one? Alternatively, is this the
+		 * first line (and not a +/- one)?
+		 *
+		 * Then just increment the appropriate counter and continue
+		 * with the next line.
+		 */
+		if (marker != ' ' || (ch != '-' && ch != '+')) {
+next_hunk_line:
+			/* Comment lines are attached to the previous line */
+			if (ch == '\\')
+				ch = marker ? marker : ' ';
+
+			/* current hunk not done yet */
+			if (ch == ' ')
+				context_line_count++;
+			else if (ch == '-')
+				header->old_count++;
+			else if (ch == '+')
+				header->new_count++;
+			else
+				BUG("unhandled diff marker: '%c'", ch);
+			marker = ch;
+			current = find_next_line(&s->plain, current);
+			if (colored)
+				colored_current =
+					find_next_line(&s->colored,
+						       colored_current);
+			continue;
+		}
+
+		/*
+		 * We got us the start of a new hunk!
+		 *
+		 * This is a context line, so it is shared with the previous
+		 * hunk, if any.
+		 */
+
+		if (first) {
+			if (header->old_count || header->new_count)
+				BUG("counts are off: %d/%d",
+				    (int)header->old_count,
+				    (int)header->new_count);
+
+			header->old_count = context_line_count;
+			header->new_count = context_line_count;
+			context_line_count = 0;
+			first = 0;
+			goto next_hunk_line;
+		}
+
+		remaining.old_offset += header->old_count;
+		remaining.old_count -= header->old_count;
+		remaining.new_offset += header->new_count;
+		remaining.new_count -= header->new_count;
+
+		/* initialize next hunk header's offsets */
+		hunk[1].header.old_offset =
+			header->old_offset + header->old_count;
+		hunk[1].header.new_offset =
+			header->new_offset + header->new_count;
+
+		/* add one split hunk */
+		header->old_count += context_line_count;
+		header->new_count += context_line_count;
+
+		hunk->end = current;
+		if (colored)
+			hunk->colored_end = colored_current;
+
+		hunk++;
+		hunk->splittable_into = 1;
+		hunk->use = hunk[-1].use;
+		header = &hunk->header;
+
+		header->old_count = header->new_count = context_line_count;
+		context_line_count = 0;
+
+		splittable_into--;
+		marker = ch;
+	}
+
+	/* last hunk simply gets the rest */
+	if (header->old_offset != remaining.old_offset)
+		BUG("miscounted old_offset: %lu != %lu",
+		    header->old_offset, remaining.old_offset);
+	if (header->new_offset != remaining.new_offset)
+		BUG("miscounted new_offset: %lu != %lu",
+		    header->new_offset, remaining.new_offset);
+	header->old_count = remaining.old_count;
+	header->new_count = remaining.new_count;
+	hunk->end = end;
+	if (colored)
+		hunk->colored_end = colored_end;
+
+	return 0;
+}
+
+static void recolor_hunk(struct add_p_state *s, struct hunk *hunk)
+{
+	const char *plain = s->plain.buf;
+	size_t current, eol, next;
+
+	if (!s->colored.len)
+		return;
+
+	hunk->colored_start = s->colored.len;
+	for (current = hunk->start; current < hunk->end; ) {
+		for (eol = current; eol < hunk->end; eol++)
+			if (plain[eol] == '\n')
+				break;
+		next = eol + (eol < hunk->end);
+		if (eol > current && plain[eol - 1] == '\r')
+			eol--;
+
+		strbuf_addstr(&s->colored,
+			      plain[current] == '-' ?
+			      s->s.file_old_color :
+			      plain[current] == '+' ?
+			      s->s.file_new_color :
+			      s->s.context_color);
+		strbuf_add(&s->colored, plain + current, eol - current);
+		strbuf_addstr(&s->colored, GIT_COLOR_RESET);
+		if (next > eol)
+			strbuf_add(&s->colored, plain + eol, next - eol);
+		current = next;
+	}
+	hunk->colored_end = s->colored.len;
+}
+
+static int edit_hunk_manually(struct add_p_state *s, struct hunk *hunk)
+{
+	size_t i;
+
+	strbuf_reset(&s->buf);
+	strbuf_commented_addf(&s->buf, _("Manual hunk edit mode -- see bottom for "
+				      "a quick guide.\n"));
+	render_hunk(s, hunk, 0, 0, &s->buf);
+	strbuf_commented_addf(&s->buf,
+			      _("---\n"
+				"To remove '%c' lines, make them ' ' lines "
+				"(context).\n"
+				"To remove '%c' lines, delete them.\n"
+				"Lines starting with %c will be removed.\n"),
+			      '-', '+', comment_line_char);
+	strbuf_commented_addf(&s->buf,
+			      _("If the patch applies cleanly, the edited hunk "
+				"will immediately be\n"
+				"marked for staging.\n"));
+	/*
+	 * TRANSLATORS: 'it' refers to the patch mentioned in the previous
+	 * messages.
+	 */
+	strbuf_commented_addf(&s->buf,
+			      _("If it does not apply cleanly, you will be "
+				"given an opportunity to\n"
+				"edit again.  If all lines of the hunk are "
+				"removed, then the edit is\n"
+				"aborted and the hunk is left unchanged.\n"));
+
+	if (strbuf_edit_interactively(&s->buf, "addp-hunk-edit.diff", NULL) < 0)
+		return -1;
+
+	/* strip out commented lines */
+	hunk->start = s->plain.len;
+	for (i = 0; i < s->buf.len; ) {
+		size_t next = find_next_line(&s->buf, i);
+
+		if (s->buf.buf[i] != comment_line_char)
+			strbuf_add(&s->plain, s->buf.buf + i, next - i);
+		i = next;
+	}
+
+	hunk->end = s->plain.len;
+	if (hunk->end == hunk->start)
+		/* The user aborted editing by deleting everything */
+		return 0;
+
+	recolor_hunk(s, hunk);
+
+	/*
+	 * If the hunk header is intact, parse it, otherwise simply use the
+	 * hunk header prior to editing (which will adjust `hunk->start` to
+	 * skip the hunk header).
+	 */
+	if (s->plain.buf[hunk->start] == '@' &&
+	    parse_hunk_header(s, hunk) < 0)
+		return error(_("could not parse hunk header"));
+
+	return 1;
+}
+
+static ssize_t recount_edited_hunk(struct add_p_state *s, struct hunk *hunk,
+				   size_t orig_old_count, size_t orig_new_count)
+{
+	struct hunk_header *header = &hunk->header;
+	size_t i;
+
+	header->old_count = header->new_count = 0;
+	for (i = hunk->start; i < hunk->end; ) {
+		switch (s->plain.buf[i]) {
+		case '-':
+			header->old_count++;
+			break;
+		case '+':
+			header->new_count++;
+			break;
+		case ' ': case '\r': case '\n':
+			header->old_count++;
+			header->new_count++;
+			break;
+		}
+
+		i = find_next_line(&s->plain, i);
+	}
+
+	return orig_old_count - orig_new_count
+		- header->old_count + header->new_count;
+}
+
+static int run_apply_check(struct add_p_state *s,
+			   struct file_diff *file_diff)
+{
+	struct child_process cp = CHILD_PROCESS_INIT;
+
+	strbuf_reset(&s->buf);
+	reassemble_patch(s, file_diff, 1, &s->buf);
+
+	setup_child_process(s, &cp,
+			    "apply", "--cached", "--check", NULL);
+	if (pipe_command(&cp, s->buf.buf, s->buf.len, NULL, 0, NULL, 0))
+		return error(_("'git apply --cached' failed"));
+
+	return 0;
+}
+
+static int prompt_yesno(struct add_p_state *s, const char *prompt)
+{
+	for (;;) {
+		color_fprintf(stdout, s->s.prompt_color, "%s", _(prompt));
+		fflush(stdout);
+		if (strbuf_getline(&s->answer, stdin) == EOF)
+			return -1;
+		strbuf_trim_trailing_newline(&s->answer);
+		switch (tolower(s->answer.buf[0])) {
+		case 'n': return 0;
+		case 'y': return 1;
+		}
+	}
+}
+
+static int edit_hunk_loop(struct add_p_state *s,
+			  struct file_diff *file_diff, struct hunk *hunk)
+{
+	size_t plain_len = s->plain.len, colored_len = s->colored.len;
+	struct hunk backup;
+
+	backup = *hunk;
+
+	for (;;) {
+		int res = edit_hunk_manually(s, hunk);
+		if (res == 0) {
+			/* abandonded */
+			*hunk = backup;
+			return -1;
+		}
+
+		if (res > 0) {
+			hunk->delta +=
+				recount_edited_hunk(s, hunk,
+						    backup.header.old_count,
+						    backup.header.new_count);
+			if (!run_apply_check(s, file_diff))
+				return 0;
+		}
+
+		/* Drop edits (they were appended to s->plain) */
+		strbuf_setlen(&s->plain, plain_len);
+		strbuf_setlen(&s->colored, colored_len);
+		*hunk = backup;
+
+		/*
+		 * TRANSLATORS: do not translate [y/n]
+		 * The program will only accept that input at this point.
+		 * Consider translating (saying "no" discards!) as
+		 * (saying "n" for "no" discards!) if the translation
+		 * of the word "no" does not start with n.
+		 */
+		res = prompt_yesno(s, _("Your edited hunk does not apply. "
+					"Edit again (saying \"no\" discards!) "
+					"[y/n]? "));
+		if (res < 1)
+			return -1;
+	}
+}
+
+#define SUMMARY_HEADER_WIDTH 20
+#define SUMMARY_LINE_WIDTH 80
+static void summarize_hunk(struct add_p_state *s, struct hunk *hunk,
+			   struct strbuf *out)
+{
+	struct hunk_header *header = &hunk->header;
+	struct strbuf *plain = &s->plain;
+	size_t len = out->len, i;
+
+	strbuf_addf(out, " -%lu,%lu +%lu,%lu ",
+		    header->old_offset, header->old_count,
+		    header->new_offset, header->new_count);
+	if (out->len - len < SUMMARY_HEADER_WIDTH)
+		strbuf_addchars(out, ' ',
+				SUMMARY_HEADER_WIDTH + len - out->len);
+	for (i = hunk->start; i < hunk->end; i = find_next_line(plain, i))
+		if (plain->buf[i] != ' ')
+			break;
+	if (i < hunk->end)
+		strbuf_add(out, plain->buf + i, find_next_line(plain, i) - i);
+	if (out->len - len > SUMMARY_LINE_WIDTH)
+		strbuf_setlen(out, len + SUMMARY_LINE_WIDTH);
+	strbuf_complete_line(out);
+}
+
+#define DISPLAY_HUNKS_LINES 20
+static size_t display_hunks(struct add_p_state *s,
+			    struct file_diff *file_diff, size_t start_index)
+{
+	size_t end_index = start_index + DISPLAY_HUNKS_LINES;
+
+	if (end_index > file_diff->hunk_nr)
+		end_index = file_diff->hunk_nr;
+
+	while (start_index < end_index) {
+		struct hunk *hunk = file_diff->hunk + start_index++;
+
+		strbuf_reset(&s->buf);
+		strbuf_addf(&s->buf, "%c%2d: ", hunk->use == USE_HUNK ? '+'
+			    : hunk->use == SKIP_HUNK ? '-' : ' ',
+			    (int)start_index);
+		summarize_hunk(s, hunk, &s->buf);
+		fputs(s->buf.buf, stdout);
+	}
+
+	return end_index;
+}
+
+static const char help_patch_text[] =
+N_("y - stage this hunk\n"
+   "n - do not stage this hunk\n"
+   "q - quit; do not stage this hunk or any of the remaining ones\n"
+   "a - stage this and all the remaining hunks\n"
+   "d - do not stage this hunk nor any of the remaining hunks\n");
+
+static const char help_patch_remainder[] =
+N_("j - leave this hunk undecided, see next undecided hunk\n"
+   "J - leave this hunk undecided, see next hunk\n"
+   "k - leave this hunk undecided, see previous undecided hunk\n"
+   "K - leave this hunk undecided, see previous hunk\n"
+   "g - select a hunk to go to\n"
+   "/ - search for a hunk matching the given regex\n"
+   "s - split the current hunk into smaller hunks\n"
+   "e - manually edit the current hunk\n"
+   "? - print help\n");
+
+static int patch_update_file(struct add_p_state *s,
+			     struct file_diff *file_diff)
+{
+	size_t hunk_index = 0;
+	ssize_t i, undecided_previous, undecided_next;
+	struct hunk *hunk;
+	char ch;
+	struct child_process cp = CHILD_PROCESS_INIT;
+	int colored = !!s->colored.len, quit = 0;
+	enum prompt_mode_type prompt_mode_type;
+
+	if (!file_diff->hunk_nr)
+		return 0;
+
+	strbuf_reset(&s->buf);
+	render_diff_header(s, file_diff, colored, &s->buf);
+	fputs(s->buf.buf, stdout);
+	for (;;) {
+		if (hunk_index >= file_diff->hunk_nr)
+			hunk_index = 0;
+		hunk = file_diff->hunk + hunk_index;
+
+		undecided_previous = -1;
+		for (i = hunk_index - 1; i >= 0; i--)
+			if (file_diff->hunk[i].use == UNDECIDED_HUNK) {
+				undecided_previous = i;
+				break;
+			}
+
+		undecided_next = -1;
+		for (i = hunk_index + 1; i < file_diff->hunk_nr; i++)
+			if (file_diff->hunk[i].use == UNDECIDED_HUNK) {
+				undecided_next = i;
+				break;
+			}
+
+		/* Everything decided? */
+		if (undecided_previous < 0 && undecided_next < 0 &&
+		    hunk->use != UNDECIDED_HUNK)
+			break;
+
+		strbuf_reset(&s->buf);
+		render_hunk(s, hunk, 0, colored, &s->buf);
+		fputs(s->buf.buf, stdout);
+
+		strbuf_reset(&s->buf);
+		if (undecided_previous >= 0)
+			strbuf_addstr(&s->buf, ",k");
+		if (hunk_index)
+			strbuf_addstr(&s->buf, ",K");
+		if (undecided_next >= 0)
+			strbuf_addstr(&s->buf, ",j");
+		if (hunk_index + 1 < file_diff->hunk_nr)
+			strbuf_addstr(&s->buf, ",J");
+		if (file_diff->hunk_nr > 1)
+			strbuf_addstr(&s->buf, ",g,/");
+		if (hunk->splittable_into > 1)
+			strbuf_addstr(&s->buf, ",s");
+		if (hunk_index + 1 > file_diff->mode_change &&
+		    !file_diff->deleted)
+			strbuf_addstr(&s->buf, ",e");
+
+		if (file_diff->deleted)
+			prompt_mode_type = PROMPT_DELETION;
+		else if (file_diff->mode_change && !hunk_index)
+			prompt_mode_type = PROMPT_MODE_CHANGE;
+		else
+			prompt_mode_type = PROMPT_HUNK;
+
+		color_fprintf(stdout, s->s.prompt_color,
+			      "(%"PRIuMAX"/%"PRIuMAX") ",
+			      (uintmax_t)hunk_index + 1,
+			      (uintmax_t)file_diff->hunk_nr);
+		color_fprintf(stdout, s->s.prompt_color,
+			      _(prompt_mode[prompt_mode_type]), s->buf.buf);
+		fflush(stdout);
+		if (strbuf_getline(&s->answer, stdin) == EOF)
+			break;
+		strbuf_trim_trailing_newline(&s->answer);
+
+		if (!s->answer.len)
+			continue;
+		ch = tolower(s->answer.buf[0]);
+		if (ch == 'y') {
+			hunk->use = USE_HUNK;
+soft_increment:
+			hunk_index = undecided_next < 0 ?
+				file_diff->hunk_nr : undecided_next;
+		} else if (ch == 'n') {
+			hunk->use = SKIP_HUNK;
+			goto soft_increment;
+		} else if (ch == 'a') {
+			for (; hunk_index < file_diff->hunk_nr; hunk_index++) {
+				hunk = file_diff->hunk + hunk_index;
+				if (hunk->use == UNDECIDED_HUNK)
+					hunk->use = USE_HUNK;
+			}
+		} else if (ch == 'd' || ch == 'q') {
+			for (; hunk_index < file_diff->hunk_nr; hunk_index++) {
+				hunk = file_diff->hunk + hunk_index;
+				if (hunk->use == UNDECIDED_HUNK)
+					hunk->use = SKIP_HUNK;
+			}
+			if (ch == 'q') {
+				quit = 1;
+				break;
+			}
+		} else if (s->answer.buf[0] == 'K') {
+			if (hunk_index)
+				hunk_index--;
+			else
+				err(s, _("No previous hunk"));
+		} else if (s->answer.buf[0] == 'J') {
+			if (hunk_index + 1 < file_diff->hunk_nr)
+				hunk_index++;
+			else
+				err(s, _("No next hunk"));
+		} else if (s->answer.buf[0] == 'k') {
+			if (undecided_previous >= 0)
+				hunk_index = undecided_previous;
+			else
+				err(s, _("No previous hunk"));
+		} else if (s->answer.buf[0] == 'j') {
+			if (undecided_next >= 0)
+				hunk_index = undecided_next;
+			else
+				err(s, _("No next hunk"));
+		} else if (s->answer.buf[0] == 'g') {
+			char *pend;
+			unsigned long response;
+
+			if (file_diff->hunk_nr < 2) {
+				err(s, _("No other hunks to goto"));
+				continue;
+			}
+			strbuf_remove(&s->answer, 0, 1);
+			strbuf_trim(&s->answer);
+			i = hunk_index - DISPLAY_HUNKS_LINES / 2;
+			if (i < file_diff->mode_change)
+				i = file_diff->mode_change;
+			while (s->answer.len == 0) {
+				i = display_hunks(s, file_diff, i);
+				printf("%s", i < file_diff->hunk_nr ?
+				       _("go to which hunk (<ret> to see "
+					 "more)? ") : _("go to which hunk? "));
+				fflush(stdout);
+				if (strbuf_getline(&s->answer,
+						   stdin) == EOF)
+					break;
+				strbuf_trim_trailing_newline(&s->answer);
+			}
+
+			strbuf_trim(&s->answer);
+			response = strtoul(s->answer.buf, &pend, 10);
+			if (*pend || pend == s->answer.buf)
+				err(s, _("Invalid number: '%s'"),
+				    s->answer.buf);
+			else if (0 < response && response <= file_diff->hunk_nr)
+				hunk_index = response - 1;
+			else
+				err(s, Q_("Sorry, only %d hunk available.",
+					  "Sorry, only %d hunks available.",
+					  file_diff->hunk_nr),
+				    (int)file_diff->hunk_nr);
+		} else if (s->answer.buf[0] == '/') {
+			regex_t regex;
+			int ret;
+
+			if (file_diff->hunk_nr < 2) {
+				err(s, _("No other hunks to search"));
+				continue;
+			}
+			strbuf_remove(&s->answer, 0, 1);
+			strbuf_trim_trailing_newline(&s->answer);
+			if (s->answer.len == 0) {
+				printf("%s", _("search for regex? "));
+				fflush(stdout);
+				if (strbuf_getline(&s->answer,
+						   stdin) == EOF)
+					break;
+				strbuf_trim_trailing_newline(&s->answer);
+				if (s->answer.len == 0)
+					continue;
+			}
+			ret = regcomp(&regex, s->answer.buf,
+				      REG_EXTENDED | REG_NOSUB | REG_NEWLINE);
+			if (ret) {
+				char errbuf[1024];
+
+				regerror(ret, &regex, errbuf, sizeof(errbuf));
+				err(s, _("Malformed search regexp %s: %s"),
+				    s->answer.buf, errbuf);
+				continue;
+			}
+			i = hunk_index;
+			for (;;) {
+				/* render the hunk into a scratch buffer */
+				render_hunk(s, file_diff->hunk + i, 0, 0,
+					    &s->buf);
+				if (regexec(&regex, s->buf.buf, 0, NULL, 0)
+				    != REG_NOMATCH)
+					break;
+				i++;
+				if (i == file_diff->hunk_nr)
+					i = 0;
+				if (i != hunk_index)
+					continue;
+				err(s, _("No hunk matches the given pattern"));
+				break;
+			}
+			hunk_index = i;
+		} else if (s->answer.buf[0] == 's') {
+			size_t splittable_into = hunk->splittable_into;
+			if (splittable_into < 2)
+				err(s, _("Sorry, cannot split this hunk"));
+			else if (!split_hunk(s, file_diff,
+					     hunk - file_diff->hunk))
+				color_fprintf_ln(stdout, s->s.header_color,
+						 _("Split into %d hunks."),
+						 (int)splittable_into);
+		} else if (s->answer.buf[0] == 'e') {
+			if (hunk_index + 1 == file_diff->mode_change)
+				err(s, _("Sorry, cannot edit this hunk"));
+			else if (edit_hunk_loop(s, file_diff, hunk) >= 0) {
+				hunk->use = USE_HUNK;
+				goto soft_increment;
+			}
+		} else {
+			const char *p = _(help_patch_remainder), *eol = p;
+
+			color_fprintf(stdout, s->s.help_color, "%s",
+				      _(help_patch_text));
+
+			/*
+			 * Show only those lines of the remainder that are
+			 * actually applicable with the current hunk.
+			 */
+			for (; *p; p = eol + (*eol == '\n')) {
+				eol = strchrnul(p, '\n');
+
+				/*
+				 * `s->buf` still contains the part of the
+				 * commands shown in the prompt that are not
+				 * always available.
+				 */
+				if (*p != '?' && !strchr(s->buf.buf, *p))
+					continue;
+
+				color_fprintf_ln(stdout, s->s.help_color,
+						 "%.*s", (int)(eol - p), p);
+			}
+		}
+	}
+
+	/* Any hunk to be used? */
+	for (i = 0; i < file_diff->hunk_nr; i++)
+		if (file_diff->hunk[i].use == USE_HUNK)
+			break;
+
+	if (i < file_diff->hunk_nr) {
+		/* At least one hunk selected: apply */
+		strbuf_reset(&s->buf);
+		reassemble_patch(s, file_diff, 0, &s->buf);
+
+		discard_index(s->s.r->index);
+		setup_child_process(s, &cp, "apply", "--cached", NULL);
+		if (pipe_command(&cp, s->buf.buf, s->buf.len,
+				 NULL, 0, NULL, 0))
+			error(_("'git apply --cached' failed"));
+		if (!repo_read_index(s->s.r))
+			repo_refresh_and_write_index(s->s.r, REFRESH_QUIET, 0,
+						     1, NULL, NULL, NULL);
+	}
+
+	putchar('\n');
+	return quit;
+}
+
+int run_add_p(struct repository *r, const struct pathspec *ps)
+{
+	struct add_p_state s = {
+		{ r }, STRBUF_INIT, STRBUF_INIT, STRBUF_INIT, STRBUF_INIT
+	};
+	size_t i, binary_count = 0;
+
+	init_add_i_state(&s.s, r);
+
+	if (discard_index(r->index) < 0 || repo_read_index(r) < 0 ||
+	    repo_refresh_and_write_index(r, REFRESH_QUIET, 0, 1,
+					 NULL, NULL, NULL) < 0 ||
+	    parse_diff(&s, ps) < 0) {
+		strbuf_release(&s.plain);
+		strbuf_release(&s.colored);
+		return -1;
+	}
+
+	for (i = 0; i < s.file_diff_nr; i++)
+		if (s.file_diff[i].binary && !s.file_diff[i].hunk_nr)
+			binary_count++;
+		else if (patch_update_file(&s, s.file_diff + i))
+			break;
+
+	if (s.file_diff_nr == 0)
+		fprintf(stderr, _("No changes.\n"));
+	else if (binary_count == s.file_diff_nr)
+		fprintf(stderr, _("Only binary files changed.\n"));
+
+	strbuf_release(&s.answer);
+	strbuf_release(&s.buf);
+	strbuf_release(&s.plain);
+	strbuf_release(&s.colored);
+	return 0;
+}
diff -pruN 1.2.1+git2.18.0-1/git/advice.c 1.2.3+git2.25.1-1/git/advice.c
--- 1.2.1+git2.18.0-1/git/advice.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/advice.c	2020-02-17 04:47:35.000000000 +0000
@@ -1,26 +1,36 @@
 #include "cache.h"
 #include "config.h"
 #include "color.h"
+#include "help.h"
 
+int advice_fetch_show_forced_updates = 1;
 int advice_push_update_rejected = 1;
 int advice_push_non_ff_current = 1;
 int advice_push_non_ff_matching = 1;
 int advice_push_already_exists = 1;
 int advice_push_fetch_first = 1;
 int advice_push_needs_force = 1;
+int advice_push_unqualified_ref_name = 1;
 int advice_status_hints = 1;
 int advice_status_u_option = 1;
+int advice_status_ahead_behind_warning = 1;
 int advice_commit_before_merge = 1;
+int advice_reset_quiet_warning = 1;
 int advice_resolve_conflict = 1;
+int advice_sequencer_in_use = 1;
 int advice_implicit_identity = 1;
 int advice_detached_head = 1;
 int advice_set_upstream_failure = 1;
 int advice_object_name_warning = 1;
+int advice_amworkdir = 1;
 int advice_rm_hints = 1;
 int advice_add_embedded_repo = 1;
 int advice_ignored_hook = 1;
 int advice_waiting_for_editor = 1;
 int advice_graft_file_deprecated = 1;
+int advice_checkout_ambiguous_remote_branch_name = 1;
+int advice_nested_tag = 1;
+int advice_submodule_alternate_error_strategy_die = 1;
 
 static int advice_use_color = -1;
 static char advice_colors[][COLOR_MAXLEN] = {
@@ -53,28 +63,37 @@ static struct {
 	const char *name;
 	int *preference;
 } advice_config[] = {
-	{ "pushupdaterejected", &advice_push_update_rejected },
-	{ "pushnonffcurrent", &advice_push_non_ff_current },
-	{ "pushnonffmatching", &advice_push_non_ff_matching },
-	{ "pushalreadyexists", &advice_push_already_exists },
-	{ "pushfetchfirst", &advice_push_fetch_first },
-	{ "pushneedsforce", &advice_push_needs_force },
-	{ "statushints", &advice_status_hints },
-	{ "statusuoption", &advice_status_u_option },
-	{ "commitbeforemerge", &advice_commit_before_merge },
-	{ "resolveconflict", &advice_resolve_conflict },
-	{ "implicitidentity", &advice_implicit_identity },
-	{ "detachedhead", &advice_detached_head },
-	{ "setupstreamfailure", &advice_set_upstream_failure },
-	{ "objectnamewarning", &advice_object_name_warning },
-	{ "rmhints", &advice_rm_hints },
-	{ "addembeddedrepo", &advice_add_embedded_repo },
-	{ "ignoredhook", &advice_ignored_hook },
-	{ "waitingforeditor", &advice_waiting_for_editor },
-	{ "graftfiledeprecated", &advice_graft_file_deprecated },
+	{ "fetchShowForcedUpdates", &advice_fetch_show_forced_updates },
+	{ "pushUpdateRejected", &advice_push_update_rejected },
+	{ "pushNonFFCurrent", &advice_push_non_ff_current },
+	{ "pushNonFFMatching", &advice_push_non_ff_matching },
+	{ "pushAlreadyExists", &advice_push_already_exists },
+	{ "pushFetchFirst", &advice_push_fetch_first },
+	{ "pushNeedsForce", &advice_push_needs_force },
+	{ "pushUnqualifiedRefName", &advice_push_unqualified_ref_name },
+	{ "statusHints", &advice_status_hints },
+	{ "statusUoption", &advice_status_u_option },
+	{ "statusAheadBehindWarning", &advice_status_ahead_behind_warning },
+	{ "commitBeforeMerge", &advice_commit_before_merge },
+	{ "resetQuiet", &advice_reset_quiet_warning },
+	{ "resolveConflict", &advice_resolve_conflict },
+	{ "sequencerInUse", &advice_sequencer_in_use },
+	{ "implicitIdentity", &advice_implicit_identity },
+	{ "detachedHead", &advice_detached_head },
+	{ "setupStreamFailure", &advice_set_upstream_failure },
+	{ "objectNameWarning", &advice_object_name_warning },
+	{ "amWorkDir", &advice_amworkdir },
+	{ "rmHints", &advice_rm_hints },
+	{ "addEmbeddedRepo", &advice_add_embedded_repo },
+	{ "ignoredHook", &advice_ignored_hook },
+	{ "waitingForEditor", &advice_waiting_for_editor },
+	{ "graftFileDeprecated", &advice_graft_file_deprecated },
+	{ "checkoutAmbiguousRemoteBranchName", &advice_checkout_ambiguous_remote_branch_name },
+	{ "nestedTag", &advice_nested_tag },
+	{ "submoduleAlternateErrorStrategyDie", &advice_submodule_alternate_error_strategy_die },
 
 	/* make this an alias for backward compatibility */
-	{ "pushnonfastforward", &advice_push_update_rejected }
+	{ "pushNonFastForward", &advice_push_update_rejected }
 };
 
 void advise(const char *advice, ...)
@@ -122,7 +141,7 @@ int git_default_advice_config(const char
 		return 0;
 
 	for (i = 0; i < ARRAY_SIZE(advice_config); i++) {
-		if (strcmp(k, advice_config[i].name))
+		if (strcasecmp(k, advice_config[i].name))
 			continue;
 		*advice_config[i].preference = git_config_bool(var, value);
 		return 0;
@@ -131,6 +150,14 @@ int git_default_advice_config(const char
 	return 0;
 }
 
+void list_config_advices(struct string_list *list, const char *prefix)
+{
+	int i;
+
+	for (i = 0; i < ARRAY_SIZE(advice_config); i++)
+		list_config_item(list, prefix, advice_config[i].name);
+}
+
 int error_resolve_conflict(const char *me)
 {
 	if (!strcmp(me, "cherry-pick"))
@@ -174,13 +201,22 @@ void NORETURN die_conclude_merge(void)
 void detach_advice(const char *new_name)
 {
 	const char *fmt =
-	_("Note: checking out '%s'.\n\n"
+	_("Note: switching to '%s'.\n"
+	"\n"
 	"You are in 'detached HEAD' state. You can look around, make experimental\n"
 	"changes and commit them, and you can discard any commits you make in this\n"
-	"state without impacting any branches by performing another checkout.\n\n"
+	"state without impacting any branches by switching back to a branch.\n"
+	"\n"
 	"If you want to create a new branch to retain commits you create, you may\n"
-	"do so (now or later) by using -b with the checkout command again. Example:\n\n"
-	"  git checkout -b <new-branch-name>\n\n");
+	"do so (now or later) by using -c with the switch command. Example:\n"
+	"\n"
+	"  git switch -c <new-branch-name>\n"
+	"\n"
+	"Or undo this operation with:\n"
+	"\n"
+	"  git switch -\n"
+	"\n"
+	"Turn off this advice by setting config variable advice.detachedHead to false\n\n");
 
 	fprintf(stderr, fmt, new_name);
 }
diff -pruN 1.2.1+git2.18.0-1/git/advice.h 1.2.3+git2.25.1-1/git/advice.h
--- 1.2.1+git2.18.0-1/git/advice.h	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/advice.h	2020-02-17 04:47:35.000000000 +0000
@@ -3,31 +3,40 @@
 
 #include "git-compat-util.h"
 
+extern int advice_fetch_show_forced_updates;
 extern int advice_push_update_rejected;
 extern int advice_push_non_ff_current;
 extern int advice_push_non_ff_matching;
 extern int advice_push_already_exists;
 extern int advice_push_fetch_first;
 extern int advice_push_needs_force;
+extern int advice_push_unqualified_ref_name;
 extern int advice_status_hints;
 extern int advice_status_u_option;
+extern int advice_status_ahead_behind_warning;
 extern int advice_commit_before_merge;
+extern int advice_reset_quiet_warning;
 extern int advice_resolve_conflict;
+extern int advice_sequencer_in_use;
 extern int advice_implicit_identity;
 extern int advice_detached_head;
 extern int advice_set_upstream_failure;
 extern int advice_object_name_warning;
+extern int advice_amworkdir;
 extern int advice_rm_hints;
 extern int advice_add_embedded_repo;
 extern int advice_ignored_hook;
 extern int advice_waiting_for_editor;
 extern int advice_graft_file_deprecated;
+extern int advice_checkout_ambiguous_remote_branch_name;
+extern int advice_nested_tag;
+extern int advice_submodule_alternate_error_strategy_die;
 
 int git_default_advice_config(const char *var, const char *value);
 __attribute__((format (printf, 1, 2)))
 void advise(const char *advice, ...);
 int error_resolve_conflict(const char *me);
-extern void NORETURN die_resolve_conflict(const char *me);
+void NORETURN die_resolve_conflict(const char *me);
 void NORETURN die_conclude_merge(void);
 void detach_advice(const char *new_name);
 
diff -pruN 1.2.1+git2.18.0-1/git/alias.c 1.2.3+git2.25.1-1/git/alias.c
--- 1.2.1+git2.18.0-1/git/alias.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/alias.c	2020-02-17 04:47:35.000000000 +0000
@@ -47,8 +47,8 @@ void list_aliases(struct string_list *li
 #define SPLIT_CMDLINE_BAD_ENDING 1
 #define SPLIT_CMDLINE_UNCLOSED_QUOTE 2
 static const char *split_cmdline_errors[] = {
-	"cmdline ends with \\",
-	"unclosed quote"
+	N_("cmdline ends with \\"),
+	N_("unclosed quote")
 };
 
 int split_cmdline(char *cmdline, const char ***argv)
diff -pruN 1.2.1+git2.18.0-1/git/alias.h 1.2.3+git2.25.1-1/git/alias.h
--- 1.2.1+git2.18.0-1/git/alias.h	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/alias.h	2020-02-17 04:47:35.000000000 +0000
@@ -1,5 +1,5 @@
-#ifndef __ALIAS_H__
-#define __ALIAS_H__
+#ifndef ALIAS_H
+#define ALIAS_H
 
 struct string_list;
 
diff -pruN 1.2.1+git2.18.0-1/git/alloc.c 1.2.3+git2.25.1-1/git/alloc.c
--- 1.2.1+git2.18.0-1/git/alloc.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/alloc.c	2020-02-17 04:47:35.000000000 +0000
@@ -4,8 +4,7 @@
  * Copyright (C) 2006 Linus Torvalds
  *
  * The standard malloc/free wastes too much space for objects, partly because
- * it maintains all the allocation infrastructure (which isn't needed, since
- * we never free an object descriptor anyway), but even more because it ends
+ * it maintains all the allocation infrastructure, but even more because it ends
  * up with maximal alignment because it doesn't know what the object alignment
  * for the new allocation is.
  */
@@ -15,6 +14,7 @@
 #include "tree.h"
 #include "commit.h"
 #include "tag.h"
+#include "alloc.h"
 
 #define BLOCKING 1024
 
@@ -30,8 +30,27 @@ struct alloc_state {
 	int count; /* total number of nodes allocated */
 	int nr;    /* number of nodes left in current allocation */
 	void *p;   /* first free node in current allocation */
+
+	/* bookkeeping of allocations */
+	void **slabs;
+	int slab_nr, slab_alloc;
 };
 
+struct alloc_state *allocate_alloc_state(void)
+{
+	return xcalloc(1, sizeof(struct alloc_state));
+}
+
+void clear_alloc_state(struct alloc_state *s)
+{
+	while (s->slab_nr > 0) {
+		s->slab_nr--;
+		free(s->slabs[s->slab_nr]);
+	}
+
+	FREE_AND_NULL(s->slabs);
+}
+
 static inline void *alloc_node(struct alloc_state *s, size_t node_size)
 {
 	void *ret;
@@ -39,61 +58,64 @@ static inline void *alloc_node(struct al
 	if (!s->nr) {
 		s->nr = BLOCKING;
 		s->p = xmalloc(BLOCKING * node_size);
+
+		ALLOC_GROW(s->slabs, s->slab_nr + 1, s->slab_alloc);
+		s->slabs[s->slab_nr++] = s->p;
 	}
 	s->nr--;
 	s->count++;
 	ret = s->p;
 	s->p = (char *)s->p + node_size;
 	memset(ret, 0, node_size);
+
 	return ret;
 }
 
-static struct alloc_state blob_state;
-void *alloc_blob_node(void)
+void *alloc_blob_node(struct repository *r)
 {
-	struct blob *b = alloc_node(&blob_state, sizeof(struct blob));
+	struct blob *b = alloc_node(r->parsed_objects->blob_state, sizeof(struct blob));
 	b->object.type = OBJ_BLOB;
 	return b;
 }
 
-static struct alloc_state tree_state;
-void *alloc_tree_node(void)
+void *alloc_tree_node(struct repository *r)
 {
-	struct tree *t = alloc_node(&tree_state, sizeof(struct tree));
+	struct tree *t = alloc_node(r->parsed_objects->tree_state, sizeof(struct tree));
 	t->object.type = OBJ_TREE;
 	return t;
 }
 
-static struct alloc_state tag_state;
-void *alloc_tag_node(void)
+void *alloc_tag_node(struct repository *r)
 {
-	struct tag *t = alloc_node(&tag_state, sizeof(struct tag));
+	struct tag *t = alloc_node(r->parsed_objects->tag_state, sizeof(struct tag));
 	t->object.type = OBJ_TAG;
 	return t;
 }
 
-static struct alloc_state object_state;
-void *alloc_object_node(void)
+void *alloc_object_node(struct repository *r)
 {
-	struct object *obj = alloc_node(&object_state, sizeof(union any_object));
+	struct object *obj = alloc_node(r->parsed_objects->object_state, sizeof(union any_object));
 	obj->type = OBJ_NONE;
 	return obj;
 }
 
-static struct alloc_state commit_state;
-
-unsigned int alloc_commit_index(void)
+static unsigned int alloc_commit_index(struct repository *r)
 {
-	static unsigned int count;
-	return count++;
+	return r->parsed_objects->commit_count++;
 }
 
-void *alloc_commit_node(void)
+void init_commit_node(struct repository *r, struct commit *c)
 {
-	struct commit *c = alloc_node(&commit_state, sizeof(struct commit));
 	c->object.type = OBJ_COMMIT;
-	c->index = alloc_commit_index();
+	c->index = alloc_commit_index(r);
 	c->graph_pos = COMMIT_NOT_FROM_GRAPH;
+	c->generation = GENERATION_NUMBER_INFINITY;
+}
+
+void *alloc_commit_node(struct repository *r)
+{
+	struct commit *c = alloc_node(r->parsed_objects->commit_state, sizeof(struct commit));
+	init_commit_node(r, c);
 	return c;
 }
 
@@ -104,9 +126,10 @@ static void report(const char *name, uns
 }
 
 #define REPORT(name, type)	\
-    report(#name, name##_state.count, name##_state.count * sizeof(type) >> 10)
+    report(#name, r->parsed_objects->name##_state->count, \
+		  r->parsed_objects->name##_state->count * sizeof(type) >> 10)
 
-void alloc_report(void)
+void alloc_report(struct repository *r)
 {
 	REPORT(blob, struct blob);
 	REPORT(tree, struct tree);
diff -pruN 1.2.1+git2.18.0-1/git/alloc.h 1.2.3+git2.25.1-1/git/alloc.h
--- 1.2.1+git2.18.0-1/git/alloc.h	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/alloc.h	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,21 @@
+#ifndef ALLOC_H
+#define ALLOC_H
+
+struct alloc_state;
+struct tree;
+struct commit;
+struct tag;
+struct repository;
+
+void *alloc_blob_node(struct repository *r);
+void *alloc_tree_node(struct repository *r);
+void init_commit_node(struct repository *r, struct commit *c);
+void *alloc_commit_node(struct repository *r);
+void *alloc_tag_node(struct repository *r);
+void *alloc_object_node(struct repository *r);
+void alloc_report(struct repository *r);
+
+struct alloc_state *allocate_alloc_state(void);
+void clear_alloc_state(struct alloc_state *s);
+
+#endif
diff -pruN 1.2.1+git2.18.0-1/git/apply.c 1.2.3+git2.25.1-1/git/apply.c
--- 1.2.1+git2.18.0-1/git/apply.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/apply.c	2020-02-17 04:47:35.000000000 +0000
@@ -9,6 +9,7 @@
 
 #include "cache.h"
 #include "config.h"
+#include "object-store.h"
 #include "blob.h"
 #include "delta.h"
 #include "diff.h"
@@ -21,11 +22,17 @@
 #include "rerere.h"
 #include "apply.h"
 
+struct gitdiff_data {
+	struct strbuf *root;
+	int linenr;
+	int p_value;
+};
+
 static void git_apply_config(void)
 {
 	git_config_get_string_const("apply.whitespace", &apply_default_whitespace);
 	git_config_get_string_const("apply.ignorewhitespace", &apply_default_ignorewhitespace);
-	git_config(git_default_config, NULL);
+	git_config(git_xmerge_config, NULL);
 }
 
 static int parse_whitespace_option(struct apply_state *state, const char *option)
@@ -55,6 +62,10 @@ static int parse_whitespace_option(struc
 		state->ws_error_action = correct_ws_error;
 		return 0;
 	}
+	/*
+	 * Please update $__git_whitespacelist in git-completion.bash
+	 * when you add new options.
+	 */
 	return error(_("unrecognized whitespace option '%s'"), option);
 }
 
@@ -75,10 +86,12 @@ static int parse_ignorewhitespace_option
 }
 
 int init_apply_state(struct apply_state *state,
+		     struct repository *repo,
 		     const char *prefix)
 {
 	memset(state, 0, sizeof(*state));
 	state->prefix = prefix;
+	state->repo = repo;
 	state->apply = 1;
 	state->line_termination = '\n';
 	state->p_value = 1;
@@ -141,6 +154,8 @@ int check_apply_state(struct apply_state
 			return error(_("--cached outside a repository"));
 		state->check_index = 1;
 	}
+	if (state->ita_only && (state->check_index || is_not_gitdir))
+		state->ita_only = 0;
 	if (state->check_index)
 		state->unsafe_paths = 0;
 
@@ -192,40 +207,6 @@ struct fragment {
 #define BINARY_DELTA_DEFLATED	1
 #define BINARY_LITERAL_DEFLATED 2
 
-/*
- * This represents a "patch" to a file, both metainfo changes
- * such as creation/deletion, filemode and content changes represented
- * as a series of fragments.
- */
-struct patch {
-	char *new_name, *old_name, *def_name;
-	unsigned int old_mode, new_mode;
-	int is_new, is_delete;	/* -1 = unknown, 0 = false, 1 = true */
-	int rejected;
-	unsigned ws_rule;
-	int lines_added, lines_deleted;
-	int score;
-	int extension_linenr; /* first line specifying delete/new/rename/copy */
-	unsigned int is_toplevel_relative:1;
-	unsigned int inaccurate_eof:1;
-	unsigned int is_binary:1;
-	unsigned int is_copy:1;
-	unsigned int is_rename:1;
-	unsigned int recount:1;
-	unsigned int conflicted_threeway:1;
-	unsigned int direct_to_threeway:1;
-	unsigned int crlf_in_old:1;
-	struct fragment *fragments;
-	char *result;
-	size_t resultsize;
-	char old_sha1_prefix[41];
-	char new_sha1_prefix[41];
-	struct patch *next;
-
-	/* three-way fallback result */
-	struct object_id threeway_stage[3];
-};
-
 static void free_fragment_list(struct fragment *list)
 {
 	while (list) {
@@ -460,9 +441,8 @@ static char *squash_slash(char *name)
 	return name;
 }
 
-static char *find_name_gnu(struct apply_state *state,
+static char *find_name_gnu(struct strbuf *root,
 			   const char *line,
-			   const char *def,
 			   int p_value)
 {
 	struct strbuf name = STRBUF_INIT;
@@ -470,7 +450,7 @@ static char *find_name_gnu(struct apply_
 
 	/*
 	 * Proposed "new-style" GNU patch/diff format; see
-	 * http://marc.info/?l=git&m=112927316408690&w=2
+	 * https://lore.kernel.org/git/7vll0wvb2a.fsf@assigned-by-dhcp.cox.net/
 	 */
 	if (unquote_c_style(&name, line, NULL)) {
 		strbuf_release(&name);
@@ -487,8 +467,8 @@ static char *find_name_gnu(struct apply_
 	}
 
 	strbuf_remove(&name, 0, cp - name.buf);
-	if (state->root.len)
-		strbuf_insert(&name, 0, state->root.buf, state->root.len);
+	if (root->len)
+		strbuf_insert(&name, 0, root->buf, root->len);
 	return squash_slash(strbuf_detach(&name, NULL));
 }
 
@@ -651,7 +631,7 @@ static size_t diff_timestamp_len(const c
 	return line + len - end;
 }
 
-static char *find_name_common(struct apply_state *state,
+static char *find_name_common(struct strbuf *root,
 			      const char *line,
 			      const char *def,
 			      int p_value,
@@ -694,30 +674,30 @@ static char *find_name_common(struct app
 			return squash_slash(xstrdup(def));
 	}
 
-	if (state->root.len) {
-		char *ret = xstrfmt("%s%.*s", state->root.buf, len, start);
+	if (root->len) {
+		char *ret = xstrfmt("%s%.*s", root->buf, len, start);
 		return squash_slash(ret);
 	}
 
 	return squash_slash(xmemdupz(start, len));
 }
 
-static char *find_name(struct apply_state *state,
+static char *find_name(struct strbuf *root,
 		       const char *line,
 		       char *def,
 		       int p_value,
 		       int terminate)
 {
 	if (*line == '"') {
-		char *name = find_name_gnu(state, line, def, p_value);
+		char *name = find_name_gnu(root, line, p_value);
 		if (name)
 			return name;
 	}
 
-	return find_name_common(state, line, def, p_value, NULL, terminate);
+	return find_name_common(root, line, def, p_value, NULL, terminate);
 }
 
-static char *find_name_traditional(struct apply_state *state,
+static char *find_name_traditional(struct strbuf *root,
 				   const char *line,
 				   char *def,
 				   int p_value)
@@ -726,7 +706,7 @@ static char *find_name_traditional(struc
 	size_t date_len;
 
 	if (*line == '"') {
-		char *name = find_name_gnu(state, line, def, p_value);
+		char *name = find_name_gnu(root, line, p_value);
 		if (name)
 			return name;
 	}
@@ -734,10 +714,10 @@ static char *find_name_traditional(struc
 	len = strchrnul(line, '\n') - line;
 	date_len = diff_timestamp_len(line, len);
 	if (!date_len)
-		return find_name_common(state, line, def, p_value, NULL, TERM_TAB);
+		return find_name_common(root, line, def, p_value, NULL, TERM_TAB);
 	len -= date_len;
 
-	return find_name_common(state, line, def, p_value, line + len, 0);
+	return find_name_common(root, line, def, p_value, line + len, 0);
 }
 
 /*
@@ -751,7 +731,7 @@ static int guess_p_value(struct apply_st
 
 	if (is_dev_null(nameline))
 		return -1;
-	name = find_name_traditional(state, nameline, NULL, 0);
+	name = find_name_traditional(&state->root, nameline, NULL, 0);
 	if (!name)
 		return -1;
 	cp = strchr(name, '/');
@@ -875,17 +855,17 @@ static int parse_traditional_patch(struc
 	if (is_dev_null(first)) {
 		patch->is_new = 1;
 		patch->is_delete = 0;
-		name = find_name_traditional(state, second, NULL, state->p_value);
+		name = find_name_traditional(&state->root, second, NULL, state->p_value);
 		patch->new_name = name;
 	} else if (is_dev_null(second)) {
 		patch->is_new = 0;
 		patch->is_delete = 1;
-		name = find_name_traditional(state, first, NULL, state->p_value);
+		name = find_name_traditional(&state->root, first, NULL, state->p_value);
 		patch->old_name = name;
 	} else {
 		char *first_name;
-		first_name = find_name_traditional(state, first, NULL, state->p_value);
-		name = find_name_traditional(state, second, first_name, state->p_value);
+		first_name = find_name_traditional(&state->root, first, NULL, state->p_value);
+		name = find_name_traditional(&state->root, second, first_name, state->p_value);
 		free(first_name);
 		if (has_epoch_timestamp(first)) {
 			patch->is_new = 1;
@@ -906,7 +886,7 @@ static int parse_traditional_patch(struc
 	return 0;
 }
 
-static int gitdiff_hdrend(struct apply_state *state,
+static int gitdiff_hdrend(struct gitdiff_data *state,
 			  const char *line,
 			  struct patch *patch)
 {
@@ -925,14 +905,14 @@ static int gitdiff_hdrend(struct apply_s
 #define DIFF_OLD_NAME 0
 #define DIFF_NEW_NAME 1
 
-static int gitdiff_verify_name(struct apply_state *state,
+static int gitdiff_verify_name(struct gitdiff_data *state,
 			       const char *line,
 			       int isnull,
 			       char **name,
 			       int side)
 {
 	if (!*name && !isnull) {
-		*name = find_name(state, line, NULL, state->p_value, TERM_TAB);
+		*name = find_name(state->root, line, NULL, state->p_value, TERM_TAB);
 		return 0;
 	}
 
@@ -941,7 +921,7 @@ static int gitdiff_verify_name(struct ap
 		if (isnull)
 			return error(_("git apply: bad git-diff - expected /dev/null, got %s on line %d"),
 				     *name, state->linenr);
-		another = find_name(state, line, NULL, state->p_value, TERM_TAB);
+		another = find_name(state->root, line, NULL, state->p_value, TERM_TAB);
 		if (!another || strcmp(another, *name)) {
 			free(another);
 			return error((side == DIFF_NEW_NAME) ?
@@ -957,7 +937,7 @@ static int gitdiff_verify_name(struct ap
 	return 0;
 }
 
-static int gitdiff_oldname(struct apply_state *state,
+static int gitdiff_oldname(struct gitdiff_data *state,
 			   const char *line,
 			   struct patch *patch)
 {
@@ -966,7 +946,7 @@ static int gitdiff_oldname(struct apply_
 				   DIFF_OLD_NAME);
 }
 
-static int gitdiff_newname(struct apply_state *state,
+static int gitdiff_newname(struct gitdiff_data *state,
 			   const char *line,
 			   struct patch *patch)
 {
@@ -984,21 +964,21 @@ static int parse_mode_line(const char *l
 	return 0;
 }
 
-static int gitdiff_oldmode(struct apply_state *state,
+static int gitdiff_oldmode(struct gitdiff_data *state,
 			   const char *line,
 			   struct patch *patch)
 {
 	return parse_mode_line(line, state->linenr, &patch->old_mode);
 }
 
-static int gitdiff_newmode(struct apply_state *state,
+static int gitdiff_newmode(struct gitdiff_data *state,
 			   const char *line,
 			   struct patch *patch)
 {
 	return parse_mode_line(line, state->linenr, &patch->new_mode);
 }
 
-static int gitdiff_delete(struct apply_state *state,
+static int gitdiff_delete(struct gitdiff_data *state,
 			  const char *line,
 			  struct patch *patch)
 {
@@ -1008,7 +988,7 @@ static int gitdiff_delete(struct apply_s
 	return gitdiff_oldmode(state, line, patch);
 }
 
-static int gitdiff_newfile(struct apply_state *state,
+static int gitdiff_newfile(struct gitdiff_data *state,
 			   const char *line,
 			   struct patch *patch)
 {
@@ -1018,47 +998,47 @@ static int gitdiff_newfile(struct apply_
 	return gitdiff_newmode(state, line, patch);
 }
 
-static int gitdiff_copysrc(struct apply_state *state,
+static int gitdiff_copysrc(struct gitdiff_data *state,
 			   const char *line,
 			   struct patch *patch)
 {
 	patch->is_copy = 1;
 	free(patch->old_name);
-	patch->old_name = find_name(state, line, NULL, state->p_value ? state->p_value - 1 : 0, 0);
+	patch->old_name = find_name(state->root, line, NULL, state->p_value ? state->p_value - 1 : 0, 0);
 	return 0;
 }
 
-static int gitdiff_copydst(struct apply_state *state,
+static int gitdiff_copydst(struct gitdiff_data *state,
 			   const char *line,
 			   struct patch *patch)
 {
 	patch->is_copy = 1;
 	free(patch->new_name);
-	patch->new_name = find_name(state, line, NULL, state->p_value ? state->p_value - 1 : 0, 0);
+	patch->new_name = find_name(state->root, line, NULL, state->p_value ? state->p_value - 1 : 0, 0);
 	return 0;
 }
 
-static int gitdiff_renamesrc(struct apply_state *state,
+static int gitdiff_renamesrc(struct gitdiff_data *state,
 			     const char *line,
 			     struct patch *patch)
 {
 	patch->is_rename = 1;
 	free(patch->old_name);
-	patch->old_name = find_name(state, line, NULL, state->p_value ? state->p_value - 1 : 0, 0);
+	patch->old_name = find_name(state->root, line, NULL, state->p_value ? state->p_value - 1 : 0, 0);
 	return 0;
 }
 
-static int gitdiff_renamedst(struct apply_state *state,
+static int gitdiff_renamedst(struct gitdiff_data *state,
 			     const char *line,
 			     struct patch *patch)
 {
 	patch->is_rename = 1;
 	free(patch->new_name);
-	patch->new_name = find_name(state, line, NULL, state->p_value ? state->p_value - 1 : 0, 0);
+	patch->new_name = find_name(state->root, line, NULL, state->p_value ? state->p_value - 1 : 0, 0);
 	return 0;
 }
 
-static int gitdiff_similarity(struct apply_state *state,
+static int gitdiff_similarity(struct gitdiff_data *state,
 			      const char *line,
 			      struct patch *patch)
 {
@@ -1068,7 +1048,7 @@ static int gitdiff_similarity(struct app
 	return 0;
 }
 
-static int gitdiff_dissimilarity(struct apply_state *state,
+static int gitdiff_dissimilarity(struct gitdiff_data *state,
 				 const char *line,
 				 struct patch *patch)
 {
@@ -1078,7 +1058,7 @@ static int gitdiff_dissimilarity(struct
 	return 0;
 }
 
-static int gitdiff_index(struct apply_state *state,
+static int gitdiff_index(struct gitdiff_data *state,
 			 const char *line,
 			 struct patch *patch)
 {
@@ -1088,13 +1068,14 @@ static int gitdiff_index(struct apply_st
 	 */
 	const char *ptr, *eol;
 	int len;
+	const unsigned hexsz = the_hash_algo->hexsz;
 
 	ptr = strchr(line, '.');
-	if (!ptr || ptr[1] != '.' || 40 < ptr - line)
+	if (!ptr || ptr[1] != '.' || hexsz < ptr - line)
 		return 0;
 	len = ptr - line;
-	memcpy(patch->old_sha1_prefix, line, len);
-	patch->old_sha1_prefix[len] = 0;
+	memcpy(patch->old_oid_prefix, line, len);
+	patch->old_oid_prefix[len] = 0;
 
 	line = ptr + 2;
 	ptr = strchr(line, ' ');
@@ -1104,10 +1085,10 @@ static int gitdiff_index(struct apply_st
 		ptr = eol;
 	len = ptr - line;
 
-	if (40 < len)
+	if (hexsz < len)
 		return 0;
-	memcpy(patch->new_sha1_prefix, line, len);
-	patch->new_sha1_prefix[len] = 0;
+	memcpy(patch->new_oid_prefix, line, len);
+	patch->new_oid_prefix[len] = 0;
 	if (*ptr == ' ')
 		return gitdiff_oldmode(state, ptr + 1, patch);
 	return 0;
@@ -1117,7 +1098,7 @@ static int gitdiff_index(struct apply_st
  * This is normal for a diff that doesn't change anything: we'll fall through
  * into the next diff. Tell the parser to break out.
  */
-static int gitdiff_unrecognized(struct apply_state *state,
+static int gitdiff_unrecognized(struct gitdiff_data *state,
 				const char *line,
 				struct patch *patch)
 {
@@ -1128,17 +1109,17 @@ static int gitdiff_unrecognized(struct a
  * Skip p_value leading components from "line"; as we do not accept
  * absolute paths, return NULL in that case.
  */
-static const char *skip_tree_prefix(struct apply_state *state,
+static const char *skip_tree_prefix(int p_value,
 				    const char *line,
 				    int llen)
 {
 	int nslash;
 	int i;
 
-	if (!state->p_value)
+	if (!p_value)
 		return (llen && line[0] == '/') ? NULL : line;
 
-	nslash = state->p_value;
+	nslash = p_value;
 	for (i = 0; i < llen; i++) {
 		int ch = line[i];
 		if (ch == '/' && --nslash <= 0)
@@ -1155,7 +1136,7 @@ static const char *skip_tree_prefix(stru
  * creation or deletion of an empty file.  In any of these cases,
  * both sides are the same name under a/ and b/ respectively.
  */
-static char *git_header_name(struct apply_state *state,
+static char *git_header_name(int p_value,
 			     const char *line,
 			     int llen)
 {
@@ -1175,7 +1156,7 @@ static char *git_header_name(struct appl
 			goto free_and_fail1;
 
 		/* strip the a/b prefix including trailing slash */
-		cp = skip_tree_prefix(state, first.buf, first.len);
+		cp = skip_tree_prefix(p_value, first.buf, first.len);
 		if (!cp)
 			goto free_and_fail1;
 		strbuf_remove(&first, 0, cp - first.buf);
@@ -1192,7 +1173,7 @@ static char *git_header_name(struct appl
 		if (*second == '"') {
 			if (unquote_c_style(&sp, second, NULL))
 				goto free_and_fail1;
-			cp = skip_tree_prefix(state, sp.buf, sp.len);
+			cp = skip_tree_prefix(p_value, sp.buf, sp.len);
 			if (!cp)
 				goto free_and_fail1;
 			/* They must match, otherwise ignore */
@@ -1203,7 +1184,7 @@ static char *git_header_name(struct appl
 		}
 
 		/* unquoted second */
-		cp = skip_tree_prefix(state, second, line + llen - second);
+		cp = skip_tree_prefix(p_value, second, line + llen - second);
 		if (!cp)
 			goto free_and_fail1;
 		if (line + llen - cp != first.len ||
@@ -1218,7 +1199,7 @@ static char *git_header_name(struct appl
 	}
 
 	/* unquoted first name */
-	name = skip_tree_prefix(state, line, llen);
+	name = skip_tree_prefix(p_value, line, llen);
 	if (!name)
 		return NULL;
 
@@ -1234,7 +1215,7 @@ static char *git_header_name(struct appl
 			if (unquote_c_style(&sp, second, NULL))
 				goto free_and_fail2;
 
-			np = skip_tree_prefix(state, sp.buf, sp.len);
+			np = skip_tree_prefix(p_value, sp.buf, sp.len);
 			if (!np)
 				goto free_and_fail2;
 
@@ -1278,7 +1259,7 @@ static char *git_header_name(struct appl
 			 */
 			if (!name[len + 1])
 				return NULL; /* no postimage name */
-			second = skip_tree_prefix(state, name + len + 1,
+			second = skip_tree_prefix(p_value, name + len + 1,
 						  line_len - (len + 1));
 			if (!second)
 				return NULL;
@@ -1293,26 +1274,28 @@ static char *git_header_name(struct appl
 	}
 }
 
-static int check_header_line(struct apply_state *state, struct patch *patch)
+static int check_header_line(int linenr, struct patch *patch)
 {
 	int extensions = (patch->is_delete == 1) + (patch->is_new == 1) +
 			 (patch->is_rename == 1) + (patch->is_copy == 1);
 	if (extensions > 1)
 		return error(_("inconsistent header lines %d and %d"),
-			     patch->extension_linenr, state->linenr);
+			     patch->extension_linenr, linenr);
 	if (extensions && !patch->extension_linenr)
-		patch->extension_linenr = state->linenr;
+		patch->extension_linenr = linenr;
 	return 0;
 }
 
-/* Verify that we recognize the lines following a git header */
-static int parse_git_header(struct apply_state *state,
-			    const char *line,
-			    int len,
-			    unsigned int size,
-			    struct patch *patch)
+int parse_git_diff_header(struct strbuf *root,
+			  int *linenr,
+			  int p_value,
+			  const char *line,
+			  int len,
+			  unsigned int size,
+			  struct patch *patch)
 {
 	unsigned long offset;
+	struct gitdiff_data parse_hdr_state;
 
 	/* A git diff has explicit new/delete information, so we don't guess */
 	patch->is_new = 0;
@@ -1324,20 +1307,24 @@ static int parse_git_header(struct apply
 	 * or removing or adding empty files), so we get
 	 * the default name from the header.
 	 */
-	patch->def_name = git_header_name(state, line, len);
-	if (patch->def_name && state->root.len) {
-		char *s = xstrfmt("%s%s", state->root.buf, patch->def_name);
+	patch->def_name = git_header_name(p_value, line, len);
+	if (patch->def_name && root->len) {
+		char *s = xstrfmt("%s%s", root->buf, patch->def_name);
 		free(patch->def_name);
 		patch->def_name = s;
 	}
 
 	line += len;
 	size -= len;
-	state->linenr++;
-	for (offset = len ; size > 0 ; offset += len, size -= len, line += len, state->linenr++) {
+	(*linenr)++;
+	parse_hdr_state.root = root;
+	parse_hdr_state.linenr = *linenr;
+	parse_hdr_state.p_value = p_value;
+
+	for (offset = len ; size > 0 ; offset += len, size -= len, line += len, (*linenr)++) {
 		static const struct opentry {
 			const char *str;
-			int (*fn)(struct apply_state *, const char *, struct patch *);
+			int (*fn)(struct gitdiff_data *, const char *, struct patch *);
 		} optable[] = {
 			{ "@@ -", gitdiff_hdrend },
 			{ "--- ", gitdiff_oldname },
@@ -1368,17 +1355,38 @@ static int parse_git_header(struct apply
 			int res;
 			if (len < oplen || memcmp(p->str, line, oplen))
 				continue;
-			res = p->fn(state, line + oplen, patch);
+			res = p->fn(&parse_hdr_state, line + oplen, patch);
 			if (res < 0)
 				return -1;
-			if (check_header_line(state, patch))
+			if (check_header_line(*linenr, patch))
 				return -1;
 			if (res > 0)
-				return offset;
+				goto done;
 			break;
 		}
 	}
 
+done:
+	if (!patch->old_name && !patch->new_name) {
+		if (!patch->def_name) {
+			error(Q_("git diff header lacks filename information when removing "
+				 "%d leading pathname component (line %d)",
+				 "git diff header lacks filename information when removing "
+				 "%d leading pathname components (line %d)",
+				 parse_hdr_state.p_value),
+			      parse_hdr_state.p_value, *linenr);
+			return -128;
+		}
+		patch->old_name = xstrdup(patch->def_name);
+		patch->new_name = xstrdup(patch->def_name);
+	}
+	if ((!patch->new_name && !patch->is_delete) ||
+	    (!patch->old_name && !patch->is_new)) {
+		error(_("git diff header lacks filename information "
+			"(line %d)"), *linenr);
+		return -128;
+	}
+	patch->is_toplevel_relative = 1;
 	return offset;
 }
 
@@ -1552,31 +1560,13 @@ static int find_header(struct apply_stat
 		 * or mode change, so we handle that specially
 		 */
 		if (!memcmp("diff --git ", line, 11)) {
-			int git_hdr_len = parse_git_header(state, line, len, size, patch);
+			int git_hdr_len = parse_git_diff_header(&state->root, &state->linenr,
+								state->p_value, line, len,
+								size, patch);
 			if (git_hdr_len < 0)
 				return -128;
 			if (git_hdr_len <= len)
 				continue;
-			if (!patch->old_name && !patch->new_name) {
-				if (!patch->def_name) {
-					error(Q_("git diff header lacks filename information when removing "
-							"%d leading pathname component (line %d)",
-							"git diff header lacks filename information when removing "
-							"%d leading pathname components (line %d)",
-							state->p_value),
-						     state->p_value, state->linenr);
-					return -128;
-				}
-				patch->old_name = xstrdup(patch->def_name);
-				patch->new_name = xstrdup(patch->def_name);
-			}
-			if ((!patch->new_name && !patch->is_delete) ||
-			    (!patch->old_name && !patch->is_new)) {
-				error(_("git diff header lacks filename information "
-					     "(line %d)"), state->linenr);
-				return -128;
-			}
-			patch->is_toplevel_relative = 1;
 			*hdrsize = git_hdr_len;
 			return offset;
 		}
@@ -1742,7 +1732,7 @@ static int parse_fragment(struct apply_s
 	}
 	if (oldlines || newlines)
 		return -1;
-	if (!deleted && !added)
+	if (!patch->recount && !deleted && !added)
 		return -1;
 
 	fragment->leading = leading;
@@ -2126,10 +2116,12 @@ static int parse_chunk(struct apply_stat
 
 	if (!use_patch(state, patch))
 		patch->ws_rule = 0;
+	else if (patch->new_name)
+		patch->ws_rule = whitespace_rule(state->repo->index,
+						 patch->new_name);
 	else
-		patch->ws_rule = whitespace_rule(patch->new_name
-						 ? patch->new_name
-						 : patch->old_name);
+		patch->ws_rule = whitespace_rule(state->repo->index,
+						 patch->old_name);
 
 	patchsize = parse_single_patch(state,
 				       buffer + offset + hdrsize,
@@ -2199,7 +2191,7 @@ static void reverse_patches(struct patch
 		SWAP(p->new_mode, p->old_mode);
 		SWAP(p->is_new, p->is_delete);
 		SWAP(p->lines_added, p->lines_deleted);
-		SWAP(p->old_sha1_prefix, p->new_sha1_prefix);
+		SWAP(p->old_oid_prefix, p->new_oid_prefix);
 
 		for (; frag; frag = frag->next) {
 			SWAP(frag->newpos, frag->oldpos);
@@ -2670,6 +2662,16 @@ static int find_pos(struct apply_state *
 	int backwards_lno, forwards_lno, current_lno;
 
 	/*
+	 * When running with --allow-overlap, it is possible that a hunk is
+	 * seen that pretends to start at the beginning (but no longer does),
+	 * and that *still* needs to match the end. So trust `match_end` more
+	 * than `match_beginning`.
+	 */
+	if (state->allow_overlap && match_beginning && match_end &&
+	    img->nr - preimage->nr != 0)
+		match_beginning = 0;
+
+	/*
 	 * If match_beginning or match_end is specified, there is no
 	 * point starting from a wrong line that will never match and
 	 * wander around and wait for a match at the specified end.
@@ -3137,15 +3139,16 @@ static int apply_binary(struct apply_sta
 {
 	const char *name = patch->old_name ? patch->old_name : patch->new_name;
 	struct object_id oid;
+	const unsigned hexsz = the_hash_algo->hexsz;
 
 	/*
 	 * For safety, we require patch index line to contain
-	 * full 40-byte textual SHA1 for old and new, at least for now.
+	 * full hex textual object ID for old and new, at least for now.
 	 */
-	if (strlen(patch->old_sha1_prefix) != 40 ||
-	    strlen(patch->new_sha1_prefix) != 40 ||
-	    get_oid_hex(patch->old_sha1_prefix, &oid) ||
-	    get_oid_hex(patch->new_sha1_prefix, &oid))
+	if (strlen(patch->old_oid_prefix) != hexsz ||
+	    strlen(patch->new_oid_prefix) != hexsz ||
+	    get_oid_hex(patch->old_oid_prefix, &oid) ||
+	    get_oid_hex(patch->new_oid_prefix, &oid))
 		return error(_("cannot apply binary patch to '%s' "
 			       "without full index line"), name);
 
@@ -3155,7 +3158,7 @@ static int apply_binary(struct apply_sta
 		 * applies to.
 		 */
 		hash_object_file(img->buf, img->len, blob_type, &oid);
-		if (strcmp(oid_to_hex(&oid), patch->old_sha1_prefix))
+		if (strcmp(oid_to_hex(&oid), patch->old_oid_prefix))
 			return error(_("the patch applies to '%s' (%s), "
 				       "which does not match the "
 				       "current contents."),
@@ -3168,13 +3171,13 @@ static int apply_binary(struct apply_sta
 				       "'%s' but it is not empty"), name);
 	}
 
-	get_oid_hex(patch->new_sha1_prefix, &oid);
+	get_oid_hex(patch->new_oid_prefix, &oid);
 	if (is_null_oid(&oid)) {
 		clear_image(img);
 		return 0; /* deletion patch */
 	}
 
-	if (has_sha1_file(oid.hash)) {
+	if (has_object_file(&oid)) {
 		/* We already have the postimage */
 		enum object_type type;
 		unsigned long size;
@@ -3184,7 +3187,7 @@ static int apply_binary(struct apply_sta
 		if (!result)
 			return error(_("the necessary postimage %s for "
 				       "'%s' cannot be read"),
-				     patch->new_sha1_prefix, name);
+				     patch->new_oid_prefix, name);
 		clear_image(img);
 		img->buf = result;
 		img->len = size;
@@ -3200,9 +3203,9 @@ static int apply_binary(struct apply_sta
 
 		/* verify that the result matches */
 		hash_object_file(img->buf, img->len, blob_type, &oid);
-		if (strcmp(oid_to_hex(&oid), patch->new_sha1_prefix))
+		if (strcmp(oid_to_hex(&oid), patch->new_oid_prefix))
 			return error(_("binary patch to '%s' creates incorrect result (expecting %s, got %s)"),
-				name, patch->new_sha1_prefix, oid_to_hex(&oid));
+				name, patch->new_oid_prefix, oid_to_hex(&oid));
 	}
 
 	return 0;
@@ -3343,7 +3346,8 @@ static int checkout_target(struct index_
 
 	costate.refresh_cache = 1;
 	costate.istate = istate;
-	if (checkout_entry(ce, &costate, NULL) || lstat(ce->name, st))
+	if (checkout_entry(ce, &costate, NULL, NULL) ||
+	    lstat(ce->name, st))
 		return error(_("cannot checkout %s"), ce->name);
 	return 0;
 }
@@ -3371,14 +3375,17 @@ static struct patch *previous_patch(stru
 	return previous;
 }
 
-static int verify_index_match(const struct cache_entry *ce, struct stat *st)
+static int verify_index_match(struct apply_state *state,
+			      const struct cache_entry *ce,
+			      struct stat *st)
 {
 	if (S_ISGITLINK(ce->ce_mode)) {
 		if (!S_ISDIR(st->st_mode))
 			return -1;
 		return 0;
 	}
-	return ce_match_stat(ce, st, CE_MATCH_IGNORE_VALID|CE_MATCH_IGNORE_SKIP_WORKTREE);
+	return ie_match_stat(state->repo->index, ce, st,
+			     CE_MATCH_IGNORE_VALID | CE_MATCH_IGNORE_SKIP_WORKTREE);
 }
 
 #define SUBMODULE_PATCH_WITHOUT_INDEX 1
@@ -3459,7 +3466,8 @@ static int load_preimage(struct apply_st
 	return 0;
 }
 
-static int three_way_merge(struct image *image,
+static int three_way_merge(struct apply_state *state,
+			   struct image *image,
 			   char *path,
 			   const struct object_id *base,
 			   const struct object_id *ours,
@@ -3475,7 +3483,9 @@ static int three_way_merge(struct image
 	status = ll_merge(&result, path,
 			  &base_file, "base",
 			  &our_file, "ours",
-			  &their_file, "theirs", NULL);
+			  &their_file, "theirs",
+			  state->repo->index,
+			  NULL);
 	free(base_file.ptr);
 	free(our_file.ptr);
 	free(their_file.ptr);
@@ -3511,17 +3521,17 @@ static int load_current(struct apply_sta
 	if (!patch->is_new)
 		BUG("patch to %s is not a creation", patch->old_name);
 
-	pos = cache_name_pos(name, strlen(name));
+	pos = index_name_pos(state->repo->index, name, strlen(name));
 	if (pos < 0)
 		return error(_("%s: does not exist in index"), name);
-	ce = active_cache[pos];
+	ce = state->repo->index->cache[pos];
 	if (lstat(name, &st)) {
 		if (errno != ENOENT)
 			return error_errno("%s", name);
-		if (checkout_target(&the_index, ce, &st))
+		if (checkout_target(state->repo->index, ce, &st))
 			return -1;
 	}
-	if (verify_index_match(ce, &st))
+	if (verify_index_match(state, ce, &st))
 		return error(_("%s: does not match index"), name);
 
 	status = load_patch_target(state, &buf, ce, &st, patch, name, mode);
@@ -3555,7 +3565,7 @@ static int try_threeway(struct apply_sta
 	/* Preimage the patch was prepared for */
 	if (patch->is_new)
 		write_object_file("", 0, blob_type, &pre_oid);
-	else if (get_oid(patch->old_sha1_prefix, &pre_oid) ||
+	else if (get_oid(patch->old_oid_prefix, &pre_oid) ||
 		 read_blob_object(&buf, &pre_oid, patch->old_mode))
 		return error(_("repository lacks the necessary blob to fall back on 3-way merge."));
 
@@ -3587,7 +3597,7 @@ static int try_threeway(struct apply_sta
 	clear_image(&tmp_image);
 
 	/* in-core three-way merge between post and our using pre as base */
-	status = three_way_merge(image, patch->new_name,
+	status = three_way_merge(state, image, patch->new_name,
 				 &pre_oid, &our_oid, &post_oid);
 	if (status < 0) {
 		if (state->apply_verbosity > verbosity_silent)
@@ -3680,18 +3690,19 @@ static int check_preimage(struct apply_s
 	}
 
 	if (state->check_index && !previous) {
-		int pos = cache_name_pos(old_name, strlen(old_name));
+		int pos = index_name_pos(state->repo->index, old_name,
+					 strlen(old_name));
 		if (pos < 0) {
 			if (patch->is_new < 0)
 				goto is_new;
 			return error(_("%s: does not exist in index"), old_name);
 		}
-		*ce = active_cache[pos];
+		*ce = state->repo->index->cache[pos];
 		if (stat_ret < 0) {
-			if (checkout_target(&the_index, *ce, st))
+			if (checkout_target(state->repo->index, *ce, st))
 				return -1;
 		}
-		if (!state->cached && verify_index_match(*ce, st))
+		if (!state->cached && verify_index_match(state, *ce, st))
 			return error(_("%s: does not match index"), old_name);
 		if (state->cached)
 			st_mode = (*ce)->ce_mode;
@@ -3735,7 +3746,7 @@ static int check_to_create(struct apply_
 	struct stat nst;
 
 	if (state->check_index &&
-	    cache_name_pos(new_name, strlen(new_name)) >= 0 &&
+	    index_name_pos(state->repo->index, new_name, strlen(new_name)) >= 0 &&
 	    !ok_if_exists)
 		return EXISTS_IN_INDEX;
 	if (state->cached)
@@ -3824,7 +3835,8 @@ static int path_is_beyond_symlink_1(stru
 		if (state->check_index) {
 			struct cache_entry *ce;
 
-			ce = cache_file_exists(name->buf, name->len, ignore_case);
+			ce = index_file_exists(state->repo->index, name->buf,
+					       name->len, ignore_case);
 			if (ce && S_ISLNK(ce->ce_mode))
 				return 1;
 		} else {
@@ -3999,9 +4011,10 @@ static int check_patch_list(struct apply
 static int read_apply_cache(struct apply_state *state)
 {
 	if (state->index_file)
-		return read_cache_from(state->index_file);
+		return read_index_from(state->repo->index, state->index_file,
+				       get_git_dir());
 	else
-		return read_cache();
+		return repo_read_index(state->repo);
 }
 
 /* This function tries to read the object name from the current index */
@@ -4012,10 +4025,10 @@ static int get_current_oid(struct apply_
 
 	if (read_apply_cache(state) < 0)
 		return -1;
-	pos = cache_name_pos(path, strlen(path));
+	pos = index_name_pos(state->repo->index, path, strlen(path));
 	if (pos < 0)
 		return -1;
-	oidcpy(oid, &active_cache[pos]->oid);
+	oidcpy(oid, &state->repo->index->cache[pos]->oid);
 	return 0;
 }
 
@@ -4044,16 +4057,16 @@ static int preimage_oid_in_gitlink_patch
 	    starts_with(++preimage, heading) &&
 	    /* does it record full SHA-1? */
 	    !get_oid_hex(preimage + sizeof(heading) - 1, oid) &&
-	    preimage[sizeof(heading) + GIT_SHA1_HEXSZ - 1] == '\n' &&
+	    preimage[sizeof(heading) + the_hash_algo->hexsz - 1] == '\n' &&
 	    /* does the abbreviated name on the index line agree with it? */
-	    starts_with(preimage + sizeof(heading) - 1, p->old_sha1_prefix))
+	    starts_with(preimage + sizeof(heading) - 1, p->old_oid_prefix))
 		return 0; /* it all looks fine */
 
 	/* we may have full object name on the index line */
-	return get_oid_hex(p->old_sha1_prefix, oid);
+	return get_oid_hex(p->old_oid_prefix, oid);
 }
 
-/* Build an index that contains the just the files needed for a 3way merge */
+/* Build an index that contains just the files needed for a 3way merge */
 static int build_fake_ancestor(struct apply_state *state, struct patch *list)
 {
 	struct patch *patch;
@@ -4079,7 +4092,7 @@ static int build_fake_ancestor(struct ap
 			else
 				return error(_("sha1 information is lacking or "
 					       "useless for submodule %s"), name);
-		} else if (!get_oid_blob(patch->old_sha1_prefix, &oid)) {
+		} else if (!get_oid_blob(patch->old_oid_prefix, &oid)) {
 			; /* ok */
 		} else if (!patch->lines_added && !patch->lines_deleted) {
 			/* mode-only change: update the current */
@@ -4090,12 +4103,12 @@ static int build_fake_ancestor(struct ap
 			return error(_("sha1 information is lacking or useless "
 				       "(%s)."), name);
 
-		ce = make_cache_entry(patch->old_mode, oid.hash, name, 0, 0);
+		ce = make_cache_entry(&result, patch->old_mode, &oid, name, 0, 0);
 		if (!ce)
 			return error(_("make_cache_entry failed for path '%s'"),
 				     name);
 		if (add_index_entry(&result, ce, ADD_CACHE_OK_TO_ADD)) {
-			free(ce);
+			discard_cache_entry(ce);
 			return error(_("could not add %s to temporary index"),
 				     name);
 		}
@@ -4180,8 +4193,8 @@ static void show_rename_copy(struct patc
 		old_name = slash_old + 1;
 		new_name = slash_new + 1;
 	}
-	/* p->old_name thru old_name is the common prefix, and old_name and new_name
-	 * through the end of names are renames
+	/* p->old_name through old_name is the common prefix, and old_name and
+	 * new_name through the end of names are renames
 	 */
 	if (old_name != p->old_name)
 		printf(" %s %.*s{%s => %s} (%d%%)\n", renamecopy,
@@ -4242,8 +4255,8 @@ static void patch_stats(struct apply_sta
 
 static int remove_file(struct apply_state *state, struct patch *patch, int rmdir_empty)
 {
-	if (state->update_index) {
-		if (remove_file_from_cache(patch->old_name) < 0)
+	if (state->update_index && !state->ita_only) {
+		if (remove_file_from_index(state->repo->index, patch->old_name) < 0)
 			return error(_("unable to remove %s from index"), patch->old_name);
 	}
 	if (!state->cached) {
@@ -4263,42 +4276,41 @@ static int add_index_file(struct apply_s
 	struct stat st;
 	struct cache_entry *ce;
 	int namelen = strlen(path);
-	unsigned ce_size = cache_entry_size(namelen);
-
-	if (!state->update_index)
-		return 0;
 
-	ce = xcalloc(1, ce_size);
+	ce = make_empty_cache_entry(state->repo->index, namelen);
 	memcpy(ce->name, path, namelen);
 	ce->ce_mode = create_ce_mode(mode);
 	ce->ce_flags = create_ce_flags(0);
 	ce->ce_namelen = namelen;
-	if (S_ISGITLINK(mode)) {
+	if (state->ita_only) {
+		ce->ce_flags |= CE_INTENT_TO_ADD;
+		set_object_name_for_intent_to_add_entry(ce);
+	} else if (S_ISGITLINK(mode)) {
 		const char *s;
 
 		if (!skip_prefix(buf, "Subproject commit ", &s) ||
 		    get_oid_hex(s, &ce->oid)) {
-			free(ce);
-		       return error(_("corrupt patch for submodule %s"), path);
+			discard_cache_entry(ce);
+			return error(_("corrupt patch for submodule %s"), path);
 		}
 	} else {
 		if (!state->cached) {
 			if (lstat(path, &st) < 0) {
-				free(ce);
+				discard_cache_entry(ce);
 				return error_errno(_("unable to stat newly "
 						     "created file '%s'"),
 						   path);
 			}
-			fill_stat_cache_info(ce, &st);
+			fill_stat_cache_info(state->repo->index, ce, &st);
 		}
 		if (write_object_file(buf, size, blob_type, &ce->oid) < 0) {
-			free(ce);
+			discard_cache_entry(ce);
 			return error(_("unable to create backing store "
 				       "for newly created file %s"), path);
 		}
 	}
-	if (add_cache_entry(ce, ADD_CACHE_OK_TO_ADD) < 0) {
-		free(ce);
+	if (add_index_entry(state->repo->index, ce, ADD_CACHE_OK_TO_ADD) < 0) {
+		discard_cache_entry(ce);
 		return error(_("unable to add cache entry for %s"), path);
 	}
 
@@ -4311,7 +4323,9 @@ static int add_index_file(struct apply_s
  *   0 if everything went well
  *   1 if a recoverable error happened
  */
-static int try_create_file(const char *path, unsigned int mode, const char *buf, unsigned long size)
+static int try_create_file(struct apply_state *state, const char *path,
+			   unsigned int mode, const char *buf,
+			   unsigned long size)
 {
 	int fd, res;
 	struct strbuf nbuf = STRBUF_INIT;
@@ -4333,7 +4347,7 @@ static int try_create_file(const char *p
 	if (fd < 0)
 		return 1;
 
-	if (convert_to_working_tree(path, buf, size, &nbuf)) {
+	if (convert_to_working_tree(state->repo->index, path, buf, size, &nbuf)) {
 		size = nbuf.len;
 		buf  = nbuf.buf;
 	}
@@ -4369,7 +4383,7 @@ static int create_one_file(struct apply_
 	if (state->cached)
 		return 0;
 
-	res = try_create_file(path, mode, buf, size);
+	res = try_create_file(state, path, mode, buf, size);
 	if (res < 0)
 		return -1;
 	if (!res)
@@ -4378,7 +4392,7 @@ static int create_one_file(struct apply_
 	if (errno == ENOENT) {
 		if (safe_create_leading_directories(path))
 			return 0;
-		res = try_create_file(path, mode, buf, size);
+		res = try_create_file(state, path, mode, buf, size);
 		if (res < 0)
 			return -1;
 		if (!res)
@@ -4400,7 +4414,7 @@ static int create_one_file(struct apply_
 		for (;;) {
 			char newpath[PATH_MAX];
 			mksnpath(newpath, sizeof(newpath), "%s~%u", path, nr);
-			res = try_create_file(newpath, mode, buf, size);
+			res = try_create_file(state, newpath, mode, buf, size);
 			if (res < 0)
 				return -1;
 			if (!res) {
@@ -4422,27 +4436,26 @@ static int add_conflicted_stages_file(st
 				       struct patch *patch)
 {
 	int stage, namelen;
-	unsigned ce_size, mode;
+	unsigned mode;
 	struct cache_entry *ce;
 
 	if (!state->update_index)
 		return 0;
 	namelen = strlen(patch->new_name);
-	ce_size = cache_entry_size(namelen);
 	mode = patch->new_mode ? patch->new_mode : (S_IFREG | 0644);
 
-	remove_file_from_cache(patch->new_name);
+	remove_file_from_index(state->repo->index, patch->new_name);
 	for (stage = 1; stage < 4; stage++) {
 		if (is_null_oid(&patch->threeway_stage[stage - 1]))
 			continue;
-		ce = xcalloc(1, ce_size);
+		ce = make_empty_cache_entry(state->repo->index, namelen);
 		memcpy(ce->name, patch->new_name, namelen);
 		ce->ce_mode = create_ce_mode(mode);
 		ce->ce_flags = create_ce_flags(stage);
 		ce->ce_namelen = namelen;
 		oidcpy(&ce->oid, &patch->threeway_stage[stage - 1]);
-		if (add_cache_entry(ce, ADD_CACHE_OK_TO_ADD) < 0) {
-			free(ce);
+		if (add_index_entry(state->repo->index, ce, ADD_CACHE_OK_TO_ADD) < 0) {
+			discard_cache_entry(ce);
 			return error(_("unable to add cache entry for %s"),
 				     patch->new_name);
 		}
@@ -4465,8 +4478,9 @@ static int create_file(struct apply_stat
 
 	if (patch->conflicted_threeway)
 		return add_conflicted_stages_file(state, patch);
-	else
+	else if (state->update_index)
 		return add_index_file(state, path, mode, buf, size);
+	return 0;
 }
 
 /* phase zero is to remove, phase one is to create */
@@ -4615,7 +4629,7 @@ static int write_out_results(struct appl
 		}
 		string_list_clear(&cpath, 0);
 
-		rerere(0);
+		repo_rerere(state->repo, 0);
 	}
 
 	return errs;
@@ -4640,6 +4654,7 @@ static int apply_patch(struct apply_stat
 	struct patch *list = NULL, **listp = &list;
 	int skipped_patch = 0;
 	int res = 0;
+	int flush_attributes = 0;
 
 	state->patch_input_file = filename;
 	if (read_patch_file(&buf, fd) < 0)
@@ -4667,6 +4682,14 @@ static int apply_patch(struct apply_stat
 			patch_stats(state, patch);
 			*listp = patch;
 			listp = &patch->next;
+
+			if ((patch->new_name &&
+			     ends_with_path_components(patch->new_name,
+						       GITATTRIBUTES_FILE)) ||
+			    (patch->old_name &&
+			     ends_with_path_components(patch->old_name,
+						       GITATTRIBUTES_FILE)))
+				flush_attributes = 1;
 		}
 		else {
 			if (state->apply_verbosity > verbosity_normal)
@@ -4686,14 +4709,15 @@ static int apply_patch(struct apply_stat
 	if (state->whitespace_error && (state->ws_error_action == die_on_ws_error))
 		state->apply = 0;
 
-	state->update_index = state->check_index && state->apply;
+	state->update_index = (state->check_index || state->ita_only) && state->apply;
 	if (state->update_index && !is_lock_file_locked(&state->lock_file)) {
 		if (state->index_file)
 			hold_lock_file_for_update(&state->lock_file,
 						  state->index_file,
 						  LOCK_DIE_ON_ERROR);
 		else
-			hold_locked_index(&state->lock_file, LOCK_DIE_ON_ERROR);
+			repo_hold_locked_index(state->repo, &state->lock_file,
+					       LOCK_DIE_ON_ERROR);
 	}
 
 	if (state->check_index && read_apply_cache(state) < 0) {
@@ -4742,6 +4766,8 @@ static int apply_patch(struct apply_stat
 	if (state->summary && state->apply_verbosity > verbosity_silent)
 		summary_patch_list(list);
 
+	if (flush_attributes)
+		reset_parsed_attributes();
 end:
 	free_patch_list(list);
 	strbuf_release(&buf);
@@ -4753,6 +4779,9 @@ static int apply_option_parse_exclude(co
 				      const char *arg, int unset)
 {
 	struct apply_state *state = opt->value;
+
+	BUG_ON_OPT_NEG(unset);
+
 	add_name_limit(state, arg, 1);
 	return 0;
 }
@@ -4761,6 +4790,9 @@ static int apply_option_parse_include(co
 				      const char *arg, int unset)
 {
 	struct apply_state *state = opt->value;
+
+	BUG_ON_OPT_NEG(unset);
+
 	add_name_limit(state, arg, 0);
 	state->has_include = 1;
 	return 0;
@@ -4771,6 +4803,9 @@ static int apply_option_parse_p(const st
 				int unset)
 {
 	struct apply_state *state = opt->value;
+
+	BUG_ON_OPT_NEG(unset);
+
 	state->p_value = atoi(arg);
 	state->p_value_known = 1;
 	return 0;
@@ -4780,6 +4815,9 @@ static int apply_option_parse_space_chan
 					   const char *arg, int unset)
 {
 	struct apply_state *state = opt->value;
+
+	BUG_ON_OPT_ARG(arg);
+
 	if (unset)
 		state->ws_ignore_action = ignore_ws_none;
 	else
@@ -4791,9 +4829,12 @@ static int apply_option_parse_whitespace
 					 const char *arg, int unset)
 {
 	struct apply_state *state = opt->value;
+
+	BUG_ON_OPT_NEG(unset);
+
 	state->whitespace_option = arg;
 	if (parse_whitespace_option(state, arg))
-		exit(1);
+		return -1;
 	return 0;
 }
 
@@ -4801,6 +4842,9 @@ static int apply_option_parse_directory(
 					const char *arg, int unset)
 {
 	struct apply_state *state = opt->value;
+
+	BUG_ON_OPT_NEG(unset);
+
 	strbuf_reset(&state->root);
 	strbuf_addstr(&state->root, arg);
 	strbuf_complete(&state->root, '/');
@@ -4889,7 +4933,7 @@ int apply_all_patches(struct apply_state
 	}
 
 	if (state->update_index) {
-		res = write_locked_index(&the_index, &state->lock_file, COMMIT_LOCK);
+		res = write_locked_index(state->repo->index, &state->lock_file, COMMIT_LOCK);
 		if (res) {
 			error(_("Unable to write new index file"));
 			res = -128;
@@ -4920,10 +4964,10 @@ int apply_parse_options(int argc, const
 	struct option builtin_apply_options[] = {
 		{ OPTION_CALLBACK, 0, "exclude", state, N_("path"),
 			N_("don't apply changes matching the given path"),
-			0, apply_option_parse_exclude },
+			PARSE_OPT_NONEG, apply_option_parse_exclude },
 		{ OPTION_CALLBACK, 0, "include", state, N_("path"),
 			N_("apply changes matching the given path"),
-			0, apply_option_parse_include },
+			PARSE_OPT_NONEG, apply_option_parse_include },
 		{ OPTION_CALLBACK, 'p', NULL, state, N_("num"),
 			N_("remove <num> leading slashes from traditional diff paths"),
 			0, apply_option_parse_p },
@@ -4941,6 +4985,8 @@ int apply_parse_options(int argc, const
 			N_("instead of applying the patch, see if the patch is applicable")),
 		OPT_BOOL(0, "index", &state->check_index,
 			N_("make sure the patch is applicable to the current index")),
+		OPT_BOOL('N', "intent-to-add", &state->ita_only,
+			N_("mark new files with `git add --intent-to-add`")),
 		OPT_BOOL(0, "cached", &state->cached,
 			N_("apply a patch without touching the working tree")),
 		OPT_BOOL_F(0, "unsafe-paths", &state->unsafe_paths,
diff -pruN 1.2.1+git2.18.0-1/git/apply.h 1.2.3+git2.25.1-1/git/apply.h
--- 1.2.1+git2.18.0-1/git/apply.h	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/apply.h	2020-02-17 04:47:35.000000000 +0000
@@ -1,6 +1,12 @@
 #ifndef APPLY_H
 #define APPLY_H
 
+#include "hash.h"
+#include "lockfile.h"
+#include "string-list.h"
+
+struct repository;
+
 enum apply_ws_error_action {
 	nowarn_ws_error,
 	warn_on_ws_error,
@@ -45,6 +51,7 @@ struct apply_state {
 	int check; /* preimage must match working tree, don't actually apply */
 	int check_index; /* preimage must match the indexed version */
 	int update_index; /* check_index && apply */
+	int ita_only;	  /* add intent-to-add entries to the index */
 
 	/* These control cosmetic aspect of the output */
 	int diffstat; /* just show a diffstat, and don't actually apply */
@@ -61,6 +68,7 @@ struct apply_state {
 	int unsafe_paths;
 
 	/* Other non boolean parameters */
+	struct repository *repo;
 	const char *index_file;
 	enum apply_verbosity apply_verbosity;
 	const char *fake_ancestor;
@@ -110,14 +118,63 @@ struct apply_state {
 	int applied_after_fixing_ws;
 };
 
-extern int apply_parse_options(int argc, const char **argv,
-			       struct apply_state *state,
-			       int *force_apply, int *options,
-			       const char * const *apply_usage);
-extern int init_apply_state(struct apply_state *state,
-			    const char *prefix);
-extern void clear_apply_state(struct apply_state *state);
-extern int check_apply_state(struct apply_state *state, int force_apply);
+/*
+ * This represents a "patch" to a file, both metainfo changes
+ * such as creation/deletion, filemode and content changes represented
+ * as a series of fragments.
+ */
+struct patch {
+	char *new_name, *old_name, *def_name;
+	unsigned int old_mode, new_mode;
+	int is_new, is_delete;	/* -1 = unknown, 0 = false, 1 = true */
+	int rejected;
+	unsigned ws_rule;
+	int lines_added, lines_deleted;
+	int score;
+	int extension_linenr; /* first line specifying delete/new/rename/copy */
+	unsigned int is_toplevel_relative:1;
+	unsigned int inaccurate_eof:1;
+	unsigned int is_binary:1;
+	unsigned int is_copy:1;
+	unsigned int is_rename:1;
+	unsigned int recount:1;
+	unsigned int conflicted_threeway:1;
+	unsigned int direct_to_threeway:1;
+	unsigned int crlf_in_old:1;
+	struct fragment *fragments;
+	char *result;
+	size_t resultsize;
+	char old_oid_prefix[GIT_MAX_HEXSZ + 1];
+	char new_oid_prefix[GIT_MAX_HEXSZ + 1];
+	struct patch *next;
+
+	/* three-way fallback result */
+	struct object_id threeway_stage[3];
+};
+
+int apply_parse_options(int argc, const char **argv,
+			struct apply_state *state,
+			int *force_apply, int *options,
+			const char * const *apply_usage);
+int init_apply_state(struct apply_state *state,
+		     struct repository *repo,
+		     const char *prefix);
+void clear_apply_state(struct apply_state *state);
+int check_apply_state(struct apply_state *state, int force_apply);
+
+/*
+ * Parse a git diff header, starting at line.  Fills the relevant
+ * metadata information in 'struct patch'.
+ *
+ * Returns -1 on failure, the length of the parsed header otherwise.
+ */
+int parse_git_diff_header(struct strbuf *root,
+			  int *linenr,
+			  int p_value,
+			  const char *line,
+			  int len,
+			  unsigned int size,
+			  struct patch *patch);
 
 /*
  * Some aspects of the apply behavior are controlled by the following
@@ -126,9 +183,8 @@ extern int check_apply_state(struct appl
 #define APPLY_OPT_INACCURATE_EOF	(1<<0) /* accept inaccurate eof */
 #define APPLY_OPT_RECOUNT		(1<<1) /* accept inaccurate line count */
 
-extern int apply_all_patches(struct apply_state *state,
-			     int argc,
-			     const char **argv,
-			     int options);
+int apply_all_patches(struct apply_state *state,
+		      int argc, const char **argv,
+		      int options);
 
 #endif
diff -pruN 1.2.1+git2.18.0-1/git/archive.c 1.2.3+git2.25.1-1/git/archive.c
--- 1.2.1+git2.18.0-1/git/archive.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/archive.c	2020-02-17 04:47:35.000000000 +0000
@@ -1,6 +1,7 @@
 #include "cache.h"
 #include "config.h"
 #include "refs.h"
+#include "object-store.h"
 #include "commit.h"
 #include "tree-walk.h"
 #include "attr.h"
@@ -28,9 +29,15 @@ void register_archiver(struct archiver *
 	archivers[nr_archivers++] = ar;
 }
 
+void init_archivers(void)
+{
+	init_tar_archiver();
+	init_zip_archiver();
+}
+
 static void format_subst(const struct commit *commit,
-                         const char *src, size_t len,
-                         struct strbuf *buf)
+			 const char *src, size_t len,
+			 struct strbuf *buf)
 {
 	char *to_free = NULL;
 	struct strbuf fmt = STRBUF_INIT;
@@ -78,7 +85,7 @@ void *object_file_to_archive(const struc
 		size_t size = 0;
 
 		strbuf_attach(&buf, buffer, *sizep, *sizep + 1);
-		convert_to_working_tree(path, buf.buf, buf.len, &buf);
+		convert_to_working_tree(args->repo->index, path, buf.buf, buf.len, &buf);
 		if (commit)
 			format_subst(commit, buf.buf, buf.len, &buf);
 		buffer = strbuf_detach(&buf, &size);
@@ -103,12 +110,14 @@ struct archiver_context {
 	struct directory *bottom;
 };
 
-static const struct attr_check *get_archive_attrs(const char *path)
+static const struct attr_check *get_archive_attrs(struct index_state *istate,
+						  const char *path)
 {
 	static struct attr_check *check;
 	if (!check)
 		check = attr_check_initl("export-ignore", "export-subst", NULL);
-	return git_check_attr(path, check) ? NULL : check;
+	git_check_attr(istate, path, check);
+	return check;
 }
 
 static int check_attr_export_ignore(const struct attr_check *check)
@@ -144,7 +153,7 @@ static int write_archive_entry(const str
 
 	if (!S_ISDIR(mode)) {
 		const struct attr_check *check;
-		check = get_archive_attrs(path_without_prefix);
+		check = get_archive_attrs(args->repo->index, path_without_prefix);
 		if (check_attr_export_ignore(check))
 			return 0;
 		args->convert = check_attr_export_subst(check);
@@ -219,7 +228,7 @@ static int queue_or_write_archive_entry(
 		/* Borrow base, but restore its original value when done. */
 		strbuf_addstr(base, filename);
 		strbuf_addch(base, '/');
-		check = get_archive_attrs(base->buf);
+		check = get_archive_attrs(c->args->repo->index, base->buf);
 		strbuf_setlen(base, baselen);
 
 		if (check_attr_export_ignore(check))
@@ -267,16 +276,17 @@ int write_archive_entries(struct archive
 		memset(&opts, 0, sizeof(opts));
 		opts.index_only = 1;
 		opts.head_idx = -1;
-		opts.src_index = &the_index;
-		opts.dst_index = &the_index;
+		opts.src_index = args->repo->index;
+		opts.dst_index = args->repo->index;
 		opts.fn = oneway_merge;
 		init_tree_desc(&t, args->tree->buffer, args->tree->size);
 		if (unpack_trees(1, &t, &opts))
 			return -1;
-		git_attr_set_direction(GIT_ATTR_INDEX, &the_index);
+		git_attr_set_direction(GIT_ATTR_INDEX);
 	}
 
-	err = read_tree_recursive(args->tree, "", 0, 0, &args->pathspec,
+	err = read_tree_recursive(args->repo, args->tree, "",
+				  0, 0, &args->pathspec,
 				  queue_or_write_archive_entry,
 				  &context);
 	if (err == READ_TREE_RECURSIVE)
@@ -303,33 +313,44 @@ static const struct archiver *lookup_arc
 	return NULL;
 }
 
+struct path_exists_context {
+	struct pathspec pathspec;
+	struct archiver_args *args;
+};
+
 static int reject_entry(const struct object_id *oid, struct strbuf *base,
 			const char *filename, unsigned mode,
 			int stage, void *context)
 {
 	int ret = -1;
+	struct path_exists_context *ctx = context;
+
 	if (S_ISDIR(mode)) {
 		struct strbuf sb = STRBUF_INIT;
 		strbuf_addbuf(&sb, base);
 		strbuf_addstr(&sb, filename);
-		if (!match_pathspec(context, sb.buf, sb.len, 0, NULL, 1))
+		if (!match_pathspec(ctx->args->repo->index,
+				    &ctx->pathspec,
+				    sb.buf, sb.len, 0, NULL, 1))
 			ret = READ_TREE_RECURSIVE;
 		strbuf_release(&sb);
 	}
 	return ret;
 }
 
-static int path_exists(struct tree *tree, const char *path)
+static int path_exists(struct archiver_args *args, const char *path)
 {
 	const char *paths[] = { path, NULL };
-	struct pathspec pathspec;
+	struct path_exists_context ctx;
 	int ret;
 
-	parse_pathspec(&pathspec, 0, 0, "", paths);
-	pathspec.recursive = 1;
-	ret = read_tree_recursive(tree, "", 0, 0, &pathspec,
-				  reject_entry, &pathspec);
-	clear_pathspec(&pathspec);
+	ctx.args = args;
+	parse_pathspec(&ctx.pathspec, 0, 0, "", paths);
+	ctx.pathspec.recursive = 1;
+	ret = read_tree_recursive(args->repo, args->tree, "",
+				  0, 0, &ctx.pathspec,
+				  reject_entry, &ctx);
+	clear_pathspec(&ctx.pathspec);
 	return ret != 0;
 }
 
@@ -347,7 +368,7 @@ static void parse_pathspec_arg(const cha
 	ar_args->pathspec.recursive = 1;
 	if (pathspec) {
 		while (*pathspec) {
-			if (**pathspec && !path_exists(ar_args->tree, *pathspec))
+			if (**pathspec && !path_exists(ar_args, *pathspec))
 				die(_("pathspec '%s' did not match any files"), *pathspec);
 			pathspec++;
 		}
@@ -359,7 +380,7 @@ static void parse_treeish_arg(const char
 		int remote)
 {
 	const char *name = argv[0];
-	const unsigned char *commit_sha1;
+	const struct object_id *commit_oid;
 	time_t archive_time;
 	struct tree *tree;
 	const struct commit *commit;
@@ -372,40 +393,42 @@ static void parse_treeish_arg(const char
 		int refnamelen = colon - name;
 
 		if (!dwim_ref(name, refnamelen, &oid, &ref))
-			die("no such ref: %.*s", refnamelen, name);
+			die(_("no such ref: %.*s"), refnamelen, name);
 		free(ref);
 	}
 
 	if (get_oid(name, &oid))
-		die("Not a valid object name");
+		die(_("not a valid object name: %s"), name);
 
-	commit = lookup_commit_reference_gently(&oid, 1);
+	commit = lookup_commit_reference_gently(ar_args->repo, &oid, 1);
 	if (commit) {
-		commit_sha1 = commit->object.oid.hash;
+		commit_oid = &commit->object.oid;
 		archive_time = commit->date;
 	} else {
-		commit_sha1 = NULL;
+		commit_oid = NULL;
 		archive_time = time(NULL);
 	}
 
 	tree = parse_tree_indirect(&oid);
 	if (tree == NULL)
-		die("not a tree object");
+		die(_("not a tree object: %s"), oid_to_hex(&oid));
 
 	if (prefix) {
 		struct object_id tree_oid;
-		unsigned int mode;
+		unsigned short mode;
 		int err;
 
-		err = get_tree_entry(&tree->object.oid, prefix, &tree_oid,
+		err = get_tree_entry(ar_args->repo,
+				     &tree->object.oid,
+				     prefix, &tree_oid,
 				     &mode);
 		if (err || !S_ISDIR(mode))
-			die("current working directory is untracked");
+			die(_("current working directory is untracked"));
 
 		tree = parse_tree_indirect(&tree_oid);
 	}
 	ar_args->tree = tree;
-	ar_args->commit_sha1 = commit_sha1;
+	ar_args->commit_oid = commit_oid;
 	ar_args->commit = commit;
 	ar_args->time = archive_time;
 }
@@ -509,6 +532,7 @@ static int parse_archive_args(int argc,
 }
 
 int write_archive(int argc, const char **argv, const char *prefix,
+		  struct repository *repo,
 		  const char *name_hint, int remote)
 {
 	const struct archiver *ar = NULL;
@@ -517,9 +541,7 @@ int write_archive(int argc, const char *
 	git_config_get_bool("uploadarchive.allowunreachable", &remote_allow_unreachable);
 	git_config(git_default_config, NULL);
 
-	init_tar_archiver();
-	init_zip_archiver();
-
+	args.repo = repo;
 	argc = parse_archive_args(argc, argv, &ar, &args, name_hint, remote);
 	if (!startup_info->have_repository) {
 		/*
diff -pruN 1.2.1+git2.18.0-1/git/archive.h 1.2.3+git2.25.1-1/git/archive.h
--- 1.2.1+git2.18.0-1/git/archive.h	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/archive.h	2020-02-17 04:47:35.000000000 +0000
@@ -1,13 +1,17 @@
 #ifndef ARCHIVE_H
 #define ARCHIVE_H
 
+#include "cache.h"
 #include "pathspec.h"
 
+struct repository;
+
 struct archiver_args {
+	struct repository *repo;
 	const char *base;
 	size_t baselen;
 	struct tree *tree;
-	const unsigned char *commit_sha1;
+	const struct object_id *commit_oid;
 	const struct commit *commit;
 	timestamp_t time;
 	struct pathspec pathspec;
@@ -17,6 +21,16 @@ struct archiver_args {
 	int compression_level;
 };
 
+/* main api */
+
+int write_archive(int argc, const char **argv, const char *prefix,
+		  struct repository *repo,
+		  const char *name_hint, int remote);
+
+const char *archive_format_from_filename(const char *filename);
+
+/* archive backend stuff */
+
 #define ARCHIVER_WANT_COMPRESSION_LEVELS 1
 #define ARCHIVER_REMOTE 2
 struct archiver {
@@ -25,23 +39,21 @@ struct archiver {
 	unsigned flags;
 	void *data;
 };
-extern void register_archiver(struct archiver *);
+void register_archiver(struct archiver *);
 
-extern void init_tar_archiver(void);
-extern void init_zip_archiver(void);
+void init_tar_archiver(void);
+void init_zip_archiver(void);
+void init_archivers(void);
 
 typedef int (*write_archive_entry_fn_t)(struct archiver_args *args,
 					const struct object_id *oid,
 					const char *path, size_t pathlen,
 					unsigned int mode);
 
-extern int write_archive_entries(struct archiver_args *args, write_archive_entry_fn_t write_entry);
-extern int write_archive(int argc, const char **argv, const char *prefix, const char *name_hint, int remote);
-
-const char *archive_format_from_filename(const char *filename);
-extern void *object_file_to_archive(const struct archiver_args *args,
-				    const char *path, const struct object_id *oid,
-				    unsigned int mode, enum object_type *type,
-				    unsigned long *sizep);
+int write_archive_entries(struct archiver_args *args, write_archive_entry_fn_t write_entry);
+void *object_file_to_archive(const struct archiver_args *args,
+			     const char *path, const struct object_id *oid,
+			     unsigned int mode, enum object_type *type,
+			     unsigned long *sizep);
 
 #endif	/* ARCHIVE_H */
diff -pruN 1.2.1+git2.18.0-1/git/archive-tar.c 1.2.3+git2.25.1-1/git/archive-tar.c
--- 1.2.1+git2.18.0-1/git/archive-tar.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/archive-tar.c	2020-02-17 04:47:35.000000000 +0000
@@ -5,6 +5,7 @@
 #include "config.h"
 #include "tar.h"
 #include "archive.h"
+#include "object-store.h"
 #include "streaming.h"
 #include "run-command.h"
 
@@ -121,7 +122,7 @@ static int stream_blocked(const struct o
 
 	st = open_istream(oid, &type, &sz, NULL);
 	if (!st)
-		return error("cannot stream blob %s", oid_to_hex(oid));
+		return error(_("cannot stream blob %s"), oid_to_hex(oid));
 	for (;;) {
 		readlen = read_istream(st, buf, sizeof(buf));
 		if (readlen <= 0)
@@ -141,19 +142,25 @@ static int stream_blocked(const struct o
  * string and appends it to a struct strbuf.
  */
 static void strbuf_append_ext_header(struct strbuf *sb, const char *keyword,
-                                     const char *value, unsigned int valuelen)
+				     const char *value, size_t valuelen)
 {
-	int len, tmp;
+	size_t orig_len = sb->len;
+	size_t len, tmp;
 
 	/* "%u %s=%s\n" */
 	len = 1 + 1 + strlen(keyword) + 1 + valuelen + 1;
-	for (tmp = len; tmp > 9; tmp /= 10)
+	for (tmp = 1; len / 10 >= tmp; tmp *= 10)
 		len++;
 
 	strbuf_grow(sb, len);
-	strbuf_addf(sb, "%u %s=", len, keyword);
+	strbuf_addf(sb, "%"PRIuMAX" %s=", (uintmax_t)len, keyword);
 	strbuf_add(sb, value, valuelen);
 	strbuf_addch(sb, '\n');
+
+	if (len != sb->len - orig_len)
+		BUG("pax extended header length miscalculated as %"PRIuMAX
+		    ", should be %"PRIuMAX,
+		    (uintmax_t)len, (uintmax_t)(sb->len - orig_len));
 }
 
 /*
@@ -201,7 +208,7 @@ static void prepare_header(struct archiv
 			   unsigned int mode, unsigned long size)
 {
 	xsnprintf(header->mode, sizeof(header->mode), "%07o", mode & 07777);
-	xsnprintf(header->size, sizeof(header->size), "%011lo", S_ISREG(mode) ? size : 0);
+	xsnprintf(header->size, sizeof(header->size), "%011"PRIoMAX , S_ISREG(mode) ? (uintmax_t)size : (uintmax_t)0);
 	xsnprintf(header->mtime, sizeof(header->mtime), "%011lo", (unsigned long) args->time);
 
 	xsnprintf(header->uid, sizeof(header->uid), "%07o", 0);
@@ -256,7 +263,7 @@ static int write_tar_entry(struct archiv
 		*header.typeflag = TYPEFLAG_REG;
 		mode = (mode | ((mode & 0100) ? 0777 : 0666)) & ~tar_umask;
 	} else {
-		return error("unsupported file mode: 0%o (SHA1: %s)",
+		return error(_("unsupported file mode: 0%o (SHA1: %s)"),
 			     mode, oid_to_hex(oid));
 	}
 	if (pathlen > sizeof(header.name)) {
@@ -276,14 +283,14 @@ static int write_tar_entry(struct archiv
 		memcpy(header.name, path, pathlen);
 
 	if (S_ISREG(mode) && !args->convert &&
-	    oid_object_info(the_repository, oid, &size) == OBJ_BLOB &&
+	    oid_object_info(args->repo, oid, &size) == OBJ_BLOB &&
 	    size > big_file_threshold)
 		buffer = NULL;
 	else if (S_ISLNK(mode) || S_ISREG(mode)) {
 		enum object_type type;
 		buffer = object_file_to_archive(args, path, oid, old_mode, &type, &size);
 		if (!buffer)
-			return error("cannot read %s", oid_to_hex(oid));
+			return error(_("cannot read %s"), oid_to_hex(oid));
 	} else {
 		buffer = NULL;
 		size = 0;
@@ -325,14 +332,15 @@ static int write_tar_entry(struct archiv
 
 static void write_global_extended_header(struct archiver_args *args)
 {
-	const unsigned char *sha1 = args->commit_sha1;
+	const struct object_id *oid = args->commit_oid;
 	struct strbuf ext_header = STRBUF_INIT;
 	struct ustar_header header;
 	unsigned int mode;
 
-	if (sha1)
+	if (oid)
 		strbuf_append_ext_header(&ext_header, "comment",
-					 sha1_to_hex(sha1), 40);
+					 oid_to_hex(oid),
+					 the_hash_algo->hexsz);
 	if (args->time > USTAR_MAX_MTIME) {
 		strbuf_append_ext_header_uint(&ext_header, "mtime",
 					      args->time);
@@ -454,17 +462,17 @@ static int write_tar_filter_archive(cons
 	filter.in = -1;
 
 	if (start_command(&filter) < 0)
-		die_errno("unable to start '%s' filter", argv[0]);
+		die_errno(_("unable to start '%s' filter"), argv[0]);
 	close(1);
 	if (dup2(filter.in, 1) < 0)
-		die_errno("unable to redirect descriptor");
+		die_errno(_("unable to redirect descriptor"));
 	close(filter.in);
 
 	r = write_tar_archive(ar, args);
 
 	close(1);
 	if (finish_command(&filter) != 0)
-		die("'%s' filter reported error", argv[0]);
+		die(_("'%s' filter reported error"), argv[0]);
 
 	strbuf_release(&cmd);
 	return r;
diff -pruN 1.2.1+git2.18.0-1/git/archive-zip.c 1.2.3+git2.25.1-1/git/archive-zip.c
--- 1.2.1+git2.18.0-1/git/archive-zip.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/archive-zip.c	2020-02-17 04:47:35.000000000 +0000
@@ -6,6 +6,7 @@
 #include "archive.h"
 #include "streaming.h"
 #include "utf8.h"
+#include "object-store.h"
 #include "userdiff.h"
 #include "xdiff-interface.h"
 
@@ -23,6 +24,11 @@ static unsigned int max_creator_version;
 #define ZIP_STREAM	(1 <<  3)
 #define ZIP_UTF8	(1 << 11)
 
+enum zip_method {
+	ZIP_METHOD_STORE = 0,
+	ZIP_METHOD_DEFLATE = 8
+};
+
 struct zip_local_header {
 	unsigned char magic[4];
 	unsigned char version[2];
@@ -263,9 +269,10 @@ static int has_only_ascii(const char *s)
 	}
 }
 
-static int entry_is_binary(const char *path, const void *buffer, size_t size)
+static int entry_is_binary(struct index_state *istate, const char *path,
+			   const void *buffer, size_t size)
 {
-	struct userdiff_driver *driver = userdiff_find_by_path(path);
+	struct userdiff_driver *driver = userdiff_find_by_path(istate, path);
 	if (!driver)
 		driver = userdiff_find_by_name("default");
 	if (driver->binary != -1)
@@ -289,7 +296,7 @@ static int write_zip_entry(struct archiv
 	unsigned long attr2;
 	unsigned long compressed_size;
 	unsigned long crc;
-	int method;
+	enum zip_method method;
 	unsigned char *out;
 	void *deflated = NULL;
 	void *buffer;
@@ -309,38 +316,38 @@ static int write_zip_entry(struct archiv
 		if (is_utf8(path))
 			flags |= ZIP_UTF8;
 		else
-			warning("Path is not valid UTF-8: %s", path);
+			warning(_("path is not valid UTF-8: %s"), path);
 	}
 
 	if (pathlen > 0xffff) {
-		return error("path too long (%d chars, SHA1: %s): %s",
+		return error(_("path too long (%d chars, SHA1: %s): %s"),
 				(int)pathlen, oid_to_hex(oid), path);
 	}
 
 	if (S_ISDIR(mode) || S_ISGITLINK(mode)) {
-		method = 0;
+		method = ZIP_METHOD_STORE;
 		attr2 = 16;
 		out = NULL;
 		size = 0;
 		compressed_size = 0;
 		buffer = NULL;
 	} else if (S_ISREG(mode) || S_ISLNK(mode)) {
-		enum object_type type = oid_object_info(the_repository, oid,
+		enum object_type type = oid_object_info(args->repo, oid,
 							&size);
 
-		method = 0;
+		method = ZIP_METHOD_STORE;
 		attr2 = S_ISLNK(mode) ? ((mode | 0777) << 16) :
 			(mode & 0111) ? ((mode) << 16) : 0;
 		if (S_ISLNK(mode) || (mode & 0111))
 			creator_version = 0x0317;
 		if (S_ISREG(mode) && args->compression_level != 0 && size > 0)
-			method = 8;
+			method = ZIP_METHOD_DEFLATE;
 
 		if (S_ISREG(mode) && type == OBJ_BLOB && !args->convert &&
 		    size > big_file_threshold) {
 			stream = open_istream(oid, &type, &size, NULL);
 			if (!stream)
-				return error("cannot stream blob %s",
+				return error(_("cannot stream blob %s"),
 					     oid_to_hex(oid));
 			flags |= ZIP_STREAM;
 			out = buffer = NULL;
@@ -348,29 +355,30 @@ static int write_zip_entry(struct archiv
 			buffer = object_file_to_archive(args, path, oid, mode,
 							&type, &size);
 			if (!buffer)
-				return error("cannot read %s",
+				return error(_("cannot read %s"),
 					     oid_to_hex(oid));
 			crc = crc32(crc, buffer, size);
-			is_binary = entry_is_binary(path_without_prefix,
+			is_binary = entry_is_binary(args->repo->index,
+						    path_without_prefix,
 						    buffer, size);
 			out = buffer;
 		}
-		compressed_size = (method == 0) ? size : 0;
+		compressed_size = (method == ZIP_METHOD_STORE) ? size : 0;
 	} else {
-		return error("unsupported file mode: 0%o (SHA1: %s)", mode,
+		return error(_("unsupported file mode: 0%o (SHA1: %s)"), mode,
 				oid_to_hex(oid));
 	}
 
 	if (creator_version > max_creator_version)
 		max_creator_version = creator_version;
 
-	if (buffer && method == 8) {
+	if (buffer && method == ZIP_METHOD_DEFLATE) {
 		out = deflated = zlib_deflate_raw(buffer, size,
 						  args->compression_level,
 						  &compressed_size);
 		if (!out || compressed_size >= size) {
 			out = buffer;
-			method = 0;
+			method = ZIP_METHOD_STORE;
 			compressed_size = size;
 		}
 	}
@@ -417,7 +425,7 @@ static int write_zip_entry(struct archiv
 		zip_offset += ZIP64_EXTRA_SIZE;
 	}
 
-	if (stream && method == 0) {
+	if (stream && method == ZIP_METHOD_STORE) {
 		unsigned char buf[STREAM_BUFFER_SIZE];
 		ssize_t readlen;
 
@@ -427,7 +435,8 @@ static int write_zip_entry(struct archiv
 				break;
 			crc = crc32(crc, buf, readlen);
 			if (is_binary == -1)
-				is_binary = entry_is_binary(path_without_prefix,
+				is_binary = entry_is_binary(args->repo->index,
+							    path_without_prefix,
 							    buf, readlen);
 			write_or_die(1, buf, readlen);
 		}
@@ -439,7 +448,7 @@ static int write_zip_entry(struct archiv
 		zip_offset += compressed_size;
 
 		write_zip_data_desc(size, compressed_size, crc);
-	} else if (stream && method == 8) {
+	} else if (stream && method == ZIP_METHOD_DEFLATE) {
 		unsigned char buf[STREAM_BUFFER_SIZE];
 		ssize_t readlen;
 		git_zstream zstream;
@@ -459,14 +468,15 @@ static int write_zip_entry(struct archiv
 				break;
 			crc = crc32(crc, buf, readlen);
 			if (is_binary == -1)
-				is_binary = entry_is_binary(path_without_prefix,
+				is_binary = entry_is_binary(args->repo->index,
+							    path_without_prefix,
 							    buf, readlen);
 
 			zstream.next_in = buf;
 			zstream.avail_in = readlen;
 			result = git_deflate(&zstream, 0);
 			if (result != Z_OK)
-				die("deflate error (%d)", result);
+				die(_("deflate error (%d)"), result);
 			out_len = zstream.next_out - compressed;
 
 			if (out_len > 0) {
@@ -572,7 +582,7 @@ static void write_zip64_trailer(void)
 	write_or_die(1, &locator64, ZIP64_DIR_TRAILER_LOCATOR_SIZE);
 }
 
-static void write_zip_trailer(const unsigned char *sha1)
+static void write_zip_trailer(const struct object_id *oid)
 {
 	struct zip_dir_trailer trailer;
 	int clamped = 0;
@@ -585,31 +595,31 @@ static void write_zip_trailer(const unsi
 	copy_le16_clamp(trailer.entries, zip_dir_entries, &clamped);
 	copy_le32(trailer.size, zip_dir.len);
 	copy_le32_clamp(trailer.offset, zip_offset, &clamped);
-	copy_le16(trailer.comment_length, sha1 ? GIT_SHA1_HEXSZ : 0);
+	copy_le16(trailer.comment_length, oid ? the_hash_algo->hexsz : 0);
 
 	write_or_die(1, zip_dir.buf, zip_dir.len);
 	if (clamped)
 		write_zip64_trailer();
 	write_or_die(1, &trailer, ZIP_DIR_TRAILER_SIZE);
-	if (sha1)
-		write_or_die(1, sha1_to_hex(sha1), GIT_SHA1_HEXSZ);
+	if (oid)
+		write_or_die(1, oid_to_hex(oid), the_hash_algo->hexsz);
 }
 
 static void dos_time(timestamp_t *timestamp, int *dos_date, int *dos_time)
 {
 	time_t time;
-	struct tm *t;
+	struct tm tm;
 
 	if (date_overflows(*timestamp))
-		die("timestamp too large for this system: %"PRItime,
+		die(_("timestamp too large for this system: %"PRItime),
 		    *timestamp);
 	time = (time_t)*timestamp;
-	t = localtime(&time);
+	localtime_r(&time, &tm);
 	*timestamp = time;
 
-	*dos_date = t->tm_mday + (t->tm_mon + 1) * 32 +
-	            (t->tm_year + 1900 - 1980) * 512;
-	*dos_time = t->tm_sec / 2 + t->tm_min * 32 + t->tm_hour * 2048;
+	*dos_date = tm.tm_mday + (tm.tm_mon + 1) * 32 +
+		    (tm.tm_year + 1900 - 1980) * 512;
+	*dos_time = tm.tm_sec / 2 + tm.tm_min * 32 + tm.tm_hour * 2048;
 }
 
 static int archive_zip_config(const char *var, const char *value, void *data)
@@ -630,7 +640,7 @@ static int write_zip_archive(const struc
 
 	err = write_archive_entries(args, write_zip_entry);
 	if (!err)
-		write_zip_trailer(args->commit_sha1);
+		write_zip_trailer(args->commit_oid);
 
 	strbuf_release(&zip_dir);
 
diff -pruN 1.2.1+git2.18.0-1/git/argv-array.c 1.2.3+git2.25.1-1/git/argv-array.c
--- 1.2.1+git2.18.0-1/git/argv-array.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/argv-array.c	2020-02-17 04:47:35.000000000 +0000
@@ -46,7 +46,7 @@ void argv_array_pushl(struct argv_array
 	const char *arg;
 
 	va_start(ap, array);
-	while((arg = va_arg(ap, const char *)))
+	while ((arg = va_arg(ap, const char *)))
 		argv_array_push(array, arg);
 	va_end(ap);
 }
diff -pruN 1.2.1+git2.18.0-1/git/argv-array.h 1.2.3+git2.25.1-1/git/argv-array.h
--- 1.2.1+git2.18.0-1/git/argv-array.h	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/argv-array.h	2020-02-17 04:47:35.000000000 +0000
@@ -1,8 +1,32 @@
 #ifndef ARGV_ARRAY_H
 #define ARGV_ARRAY_H
 
+/**
+ * The argv-array API allows one to dynamically build and store
+ * NULL-terminated lists.  An argv-array maintains the invariant that the
+ * `argv` member always points to a non-NULL array, and that the array is
+ * always NULL-terminated at the element pointed to by `argv[argc]`. This
+ * makes the result suitable for passing to functions expecting to receive
+ * argv from main().
+ *
+ * The string-list API (documented in string-list.h) is similar, but cannot be
+ * used for these purposes; instead of storing a straight string pointer,
+ * it contains an item structure with a `util` field that is not compatible
+ * with the traditional argv interface.
+ *
+ * Each `argv_array` manages its own memory. Any strings pushed into the
+ * array are duplicated, and all memory is freed by argv_array_clear().
+ */
+
 extern const char *empty_argv[];
 
+/**
+ * A single array. This should be initialized by assignment from
+ * `ARGV_ARRAY_INIT`, or by calling `argv_array_init`. The `argv`
+ * member contains the actual array; the `argc` member contains the
+ * number of elements in the array, not including the terminating
+ * NULL.
+ */
 struct argv_array {
 	const char **argv;
 	int argc;
@@ -11,17 +35,55 @@ struct argv_array {
 
 #define ARGV_ARRAY_INIT { empty_argv, 0, 0 }
 
+/**
+ * Initialize an array. This is no different than assigning from
+ * `ARGV_ARRAY_INIT`.
+ */
 void argv_array_init(struct argv_array *);
+
+/* Push a copy of a string onto the end of the array. */
 const char *argv_array_push(struct argv_array *, const char *);
+
+/**
+ * Format a string and push it onto the end of the array. This is a
+ * convenience wrapper combining `strbuf_addf` and `argv_array_push`.
+ */
 __attribute__((format (printf,2,3)))
 const char *argv_array_pushf(struct argv_array *, const char *fmt, ...);
+
+/**
+ * Push a list of strings onto the end of the array. The arguments
+ * should be a list of `const char *` strings, terminated by a NULL
+ * argument.
+ */
 LAST_ARG_MUST_BE_NULL
 void argv_array_pushl(struct argv_array *, ...);
+
+/* Push a null-terminated array of strings onto the end of the array. */
 void argv_array_pushv(struct argv_array *, const char **);
+
+/**
+ * Remove the final element from the array. If there are no
+ * elements in the array, do nothing.
+ */
 void argv_array_pop(struct argv_array *);
+
 /* Splits by whitespace; does not handle quoted arguments! */
 void argv_array_split(struct argv_array *, const char *);
+
+/**
+ * Free all memory associated with the array and return it to the
+ * initial, empty state.
+ */
 void argv_array_clear(struct argv_array *);
+
+/**
+ * Disconnect the `argv` member from the `argv_array` struct and
+ * return it. The caller is responsible for freeing the memory used
+ * by the array, and by the strings it references. After detaching,
+ * the `argv_array` is in a reinitialized state and can be pushed
+ * into again.
+ */
 const char **argv_array_detach(struct argv_array *);
 
 #endif /* ARGV_ARRAY_H */
diff -pruN 1.2.1+git2.18.0-1/git/attr.c 1.2.3+git2.25.1-1/git/attr.c
--- 1.2.1+git2.18.0-1/git/attr.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/attr.c	2020-02-17 04:47:35.000000000 +0000
@@ -1,13 +1,11 @@
 /*
  * Handle git attributes.  See gitattributes(5) for a description of
- * the file syntax, and Documentation/technical/api-gitattributes.txt
- * for a description of the API.
+ * the file syntax, and attr.h for a description of the API.
  *
  * One basic design decision here is that we are not going to support
  * an insanely large number of attributes.
  */
 
-#define NO_THE_INDEX_COMPATIBILITY_MACROS
 #include "cache.h"
 #include "config.h"
 #include "exec-cmd.h"
@@ -41,23 +39,17 @@ const char *git_attr_name(const struct g
 
 struct attr_hashmap {
 	struct hashmap map;
-#ifndef NO_PTHREADS
 	pthread_mutex_t mutex;
-#endif
 };
 
 static inline void hashmap_lock(struct attr_hashmap *map)
 {
-#ifndef NO_PTHREADS
 	pthread_mutex_lock(&map->mutex);
-#endif
 }
 
 static inline void hashmap_unlock(struct attr_hashmap *map)
 {
-#ifndef NO_PTHREADS
 	pthread_mutex_unlock(&map->mutex);
-#endif
 }
 
 /*
@@ -69,7 +61,7 @@ static struct attr_hashmap g_attr_hashma
 
 /* The container for objects stored in "struct attr_hashmap" */
 struct attr_hash_entry {
-	struct hashmap_entry ent; /* must be the first member! */
+	struct hashmap_entry ent;
 	const char *key; /* the key; memory should be owned by value */
 	size_t keylen; /* length of the key */
 	void *value; /* the stored value */
@@ -77,12 +69,14 @@ struct attr_hash_entry {
 
 /* attr_hashmap comparison function */
 static int attr_hash_entry_cmp(const void *unused_cmp_data,
-			       const void *entry,
-			       const void *entry_or_key,
+			       const struct hashmap_entry *eptr,
+			       const struct hashmap_entry *entry_or_key,
 			       const void *unused_keydata)
 {
-	const struct attr_hash_entry *a = entry;
-	const struct attr_hash_entry *b = entry_or_key;
+	const struct attr_hash_entry *a, *b;
+
+	a = container_of(eptr, const struct attr_hash_entry, ent);
+	b = container_of(entry_or_key, const struct attr_hash_entry, ent);
 	return (a->keylen != b->keylen) || strncmp(a->key, b->key, a->keylen);
 }
 
@@ -105,10 +99,10 @@ static void *attr_hashmap_get(struct att
 	if (!map->map.tablesize)
 		attr_hashmap_init(map);
 
-	hashmap_entry_init(&k, memhash(key, keylen));
+	hashmap_entry_init(&k.ent, memhash(key, keylen));
 	k.key = key;
 	k.keylen = keylen;
-	e = hashmap_get(&map->map, &k, NULL);
+	e = hashmap_get_entry(&map->map, &k, ent, NULL);
 
 	return e ? e->value : NULL;
 }
@@ -124,12 +118,12 @@ static void attr_hashmap_add(struct attr
 		attr_hashmap_init(map);
 
 	e = xmalloc(sizeof(struct attr_hash_entry));
-	hashmap_entry_init(e, memhash(key, keylen));
+	hashmap_entry_init(&e->ent, memhash(key, keylen));
 	e->key = key;
 	e->keylen = keylen;
 	e->value = value;
 
-	hashmap_add(&map->map, e);
+	hashmap_add(&map->map, &e->ent);
 }
 
 struct all_attrs_item {
@@ -168,12 +162,12 @@ static void all_attrs_init(struct attr_h
 	if (size != check->all_attrs_nr) {
 		struct attr_hash_entry *e;
 		struct hashmap_iter iter;
-		hashmap_iter_init(&map->map, &iter);
 
 		REALLOC_ARRAY(check->all_attrs, size);
 		check->all_attrs_nr = size;
 
-		while ((e = hashmap_iter_next(&iter))) {
+		hashmap_for_each_entry(&map->map, &iter, e,
+					ent /* member name */) {
 			const struct git_attr *a = e->value;
 			check->all_attrs[a->attr_nr].attr = a;
 		}
@@ -266,7 +260,7 @@ struct pattern {
 	const char *pattern;
 	int patternlen;
 	int nowildcardlen;
-	unsigned flags;		/* EXC_FLAG_* */
+	unsigned flags;		/* PATTERN_FLAG_* */
 };
 
 /*
@@ -372,8 +366,8 @@ static struct match_attr *parse_attr_lin
 	if (strlen(ATTRIBUTE_MACRO_PREFIX) < namelen &&
 	    starts_with(name, ATTRIBUTE_MACRO_PREFIX)) {
 		if (!macro_ok) {
-			fprintf(stderr, "%s not allowed: %s:%d\n",
-				name, src, lineno);
+			fprintf_ln(stderr, _("%s not allowed: %s:%d"),
+				   name, src, lineno);
 			goto fail_return;
 		}
 		is_macro = 1;
@@ -407,11 +401,11 @@ static struct match_attr *parse_attr_lin
 		char *p = (char *)&(res->state[num_attr]);
 		memcpy(p, name, namelen);
 		res->u.pat.pattern = p;
-		parse_exclude_pattern(&res->u.pat.pattern,
+		parse_path_pattern(&res->u.pat.pattern,
 				      &res->u.pat.patternlen,
 				      &res->u.pat.flags,
 				      &res->u.pat.nowildcardlen);
-		if (res->u.pat.flags & EXC_FLAG_NEGATIVE) {
+		if (res->u.pat.flags & PATTERN_FLAG_NEGATIVE) {
 			warning(_("Negative patterns are ignored in git attributes\n"
 				  "Use '\\!' for literal leading exclamation."));
 			goto fail_return;
@@ -438,14 +432,14 @@ fail_return:
  * Like info/exclude and .gitignore, the attribute information can
  * come from many places.
  *
- * (1) .gitattribute file of the same directory;
- * (2) .gitattribute file of the parent directory if (1) does not have
+ * (1) .gitattributes file of the same directory;
+ * (2) .gitattributes file of the parent directory if (1) does not have
  *      any match; this goes recursively upwards, just like .gitignore.
  * (3) $GIT_DIR/info/attributes, which overrides both of the above.
  *
  * In the same file, later entries override the earlier match, so in the
  * global list, we would have entries from info/attributes the earliest
- * (reading the file from top to bottom), .gitattribute of the root
+ * (reading the file from top to bottom), .gitattributes of the root
  * directory (again, reading the file from top to bottom) down to the
  * current directory, and then scan the list backwards to find the first match.
  * This is exactly the same as what is_excluded() does in dir.c to deal with
@@ -498,23 +492,17 @@ static struct check_vector {
 	size_t nr;
 	size_t alloc;
 	struct attr_check **checks;
-#ifndef NO_PTHREADS
 	pthread_mutex_t mutex;
-#endif
 } check_vector;
 
 static inline void vector_lock(void)
 {
-#ifndef NO_PTHREADS
 	pthread_mutex_lock(&check_vector.mutex);
-#endif
 }
 
 static inline void vector_unlock(void)
 {
-#ifndef NO_PTHREADS
 	pthread_mutex_unlock(&check_vector.mutex);
-#endif
 }
 
 static void check_vector_add(struct attr_check *c)
@@ -708,10 +696,8 @@ static struct attr_stack *read_attr_from
  * another thread could potentially be calling into the attribute system.
  */
 static enum git_attr_direction direction;
-static struct index_state *use_index;
 
-void git_attr_set_direction(enum git_attr_direction new_direction,
-			    struct index_state *istate)
+void git_attr_set_direction(enum git_attr_direction new_direction)
 {
 	if (is_bare_repository() && new_direction != GIT_ATTR_INDEX)
 		BUG("non-INDEX attr direction in a bare repo");
@@ -720,7 +706,6 @@ void git_attr_set_direction(enum git_att
 		drop_all_attr_stacks();
 
 	direction = new_direction;
-	use_index = istate;
 }
 
 static struct attr_stack *read_attr_from_file(const char *path, int macro_ok)
@@ -743,13 +728,18 @@ static struct attr_stack *read_attr_from
 	return res;
 }
 
-static struct attr_stack *read_attr_from_index(const char *path, int macro_ok)
+static struct attr_stack *read_attr_from_index(const struct index_state *istate,
+					       const char *path,
+					       int macro_ok)
 {
 	struct attr_stack *res;
 	char *buf, *sp;
 	int lineno = 0;
 
-	buf = read_blob_data_from_index(use_index ? use_index : &the_index, path, NULL);
+	if (!istate)
+		return NULL;
+
+	buf = read_blob_data_from_index(istate, path, NULL);
 	if (!buf)
 		return NULL;
 
@@ -768,15 +758,16 @@ static struct attr_stack *read_attr_from
 	return res;
 }
 
-static struct attr_stack *read_attr(const char *path, int macro_ok)
+static struct attr_stack *read_attr(const struct index_state *istate,
+				    const char *path, int macro_ok)
 {
 	struct attr_stack *res = NULL;
 
 	if (direction == GIT_ATTR_INDEX) {
-		res = read_attr_from_index(path, macro_ok);
+		res = read_attr_from_index(istate, path, macro_ok);
 	} else if (!is_bare_repository()) {
 		if (direction == GIT_ATTR_CHECKOUT) {
-			res = read_attr_from_index(path, macro_ok);
+			res = read_attr_from_index(istate, path, macro_ok);
 			if (!res)
 				res = read_attr_from_file(path, macro_ok);
 		} else if (direction == GIT_ATTR_CHECKIN) {
@@ -788,7 +779,7 @@ static struct attr_stack *read_attr(cons
 				 * We allow operation in a sparsely checked out
 				 * work tree, so read from it.
 				 */
-				res = read_attr_from_index(path, macro_ok);
+				res = read_attr_from_index(istate, path, macro_ok);
 		}
 	}
 
@@ -859,7 +850,8 @@ static void push_stack(struct attr_stack
 	}
 }
 
-static void bootstrap_attr_stack(struct attr_stack **stack)
+static void bootstrap_attr_stack(const struct index_state *istate,
+				 struct attr_stack **stack)
 {
 	struct attr_stack *e;
 
@@ -883,7 +875,7 @@ static void bootstrap_attr_stack(struct
 	}
 
 	/* root directory */
-	e = read_attr(GITATTRIBUTES_FILE, 1);
+	e = read_attr(istate, GITATTRIBUTES_FILE, 1);
 	push_stack(stack, e, xstrdup(""), 0);
 
 	/* info frame */
@@ -896,7 +888,8 @@ static void bootstrap_attr_stack(struct
 	push_stack(stack, e, NULL, 0);
 }
 
-static void prepare_attr_stack(const char *path, int dirlen,
+static void prepare_attr_stack(const struct index_state *istate,
+			       const char *path, int dirlen,
 			       struct attr_stack **stack)
 {
 	struct attr_stack *info;
@@ -907,7 +900,7 @@ static void prepare_attr_stack(const cha
 	 * set of attribute definitions, followed by the contents
 	 * of $(prefix)/etc/gitattributes and a file specified by
 	 * core.attributesfile.  Then, contents from
-	 * .gitattribute files from directories closer to the
+	 * .gitattributes files from directories closer to the
 	 * root to the ones in deeper directories are pushed
 	 * to the stack.  Finally, at the very top of the stack
 	 * we always keep the contents of $GIT_DIR/info/attributes.
@@ -917,7 +910,7 @@ static void prepare_attr_stack(const cha
 	 * .gitattributes in deeper directories to shallower ones,
 	 * and finally use the built-in set as the default.
 	 */
-	bootstrap_attr_stack(stack);
+	bootstrap_attr_stack(istate, stack);
 
 	/*
 	 * Pop the "info" one that is always at the top of the stack.
@@ -973,7 +966,7 @@ static void prepare_attr_stack(const cha
 		strbuf_add(&pathbuf, path + pathbuf.len, (len - pathbuf.len));
 		strbuf_addf(&pathbuf, "/%s", GITATTRIBUTES_FILE);
 
-		next = read_attr(pathbuf.buf, 0);
+		next = read_attr(istate, pathbuf.buf, 0);
 
 		/* reset the pathbuf to not include "/.gitattributes" */
 		strbuf_setlen(&pathbuf, len);
@@ -999,10 +992,10 @@ static int path_matches(const char *path
 	int prefix = pat->nowildcardlen;
 	int isdir = (pathlen && pathname[pathlen - 1] == '/');
 
-	if ((pat->flags & EXC_FLAG_MUSTBEDIR) && !isdir)
+	if ((pat->flags & PATTERN_FLAG_MUSTBEDIR) && !isdir)
 		return 0;
 
-	if (pat->flags & EXC_FLAG_NODIR) {
+	if (pat->flags & PATTERN_FLAG_NODIR) {
 		return match_basename(pathname + basename_offset,
 				      pathlen - basename_offset - isdir,
 				      pattern, prefix,
@@ -1095,9 +1088,11 @@ static void determine_macros(struct all_
  * If check->check_nr is non-zero, only attributes in check[] are collected.
  * Otherwise all attributes are collected.
  */
-static void collect_some_attrs(const char *path, struct attr_check *check)
+static void collect_some_attrs(const struct index_state *istate,
+			       const char *path,
+			       struct attr_check *check)
 {
-	int i, pathlen, rem, dirlen;
+	int pathlen, rem, dirlen;
 	const char *cp, *last_slash = NULL;
 	int basename_offset;
 
@@ -1114,33 +1109,21 @@ static void collect_some_attrs(const cha
 		dirlen = 0;
 	}
 
-	prepare_attr_stack(path, dirlen, &check->stack);
+	prepare_attr_stack(istate, path, dirlen, &check->stack);
 	all_attrs_init(&g_attr_hashmap, check);
 	determine_macros(check->all_attrs, check->stack);
 
-	if (check->nr) {
-		rem = 0;
-		for (i = 0; i < check->nr; i++) {
-			int n = check->items[i].attr->attr_nr;
-			struct all_attrs_item *item = &check->all_attrs[n];
-			if (item->macro) {
-				item->value = ATTR__UNSET;
-				rem++;
-			}
-		}
-		if (rem == check->nr)
-			return;
-	}
-
 	rem = check->all_attrs_nr;
 	fill(path, pathlen, basename_offset, check->stack, check->all_attrs, rem);
 }
 
-int git_check_attr(const char *path, struct attr_check *check)
+void git_check_attr(const struct index_state *istate,
+		    const char *path,
+		    struct attr_check *check)
 {
 	int i;
 
-	collect_some_attrs(path, check);
+	collect_some_attrs(istate, path, check);
 
 	for (i = 0; i < check->nr; i++) {
 		size_t n = check->items[i].attr->attr_nr;
@@ -1149,16 +1132,15 @@ int git_check_attr(const char *path, str
 			value = ATTR__UNSET;
 		check->items[i].value = value;
 	}
-
-	return 0;
 }
 
-void git_all_attrs(const char *path, struct attr_check *check)
+void git_all_attrs(const struct index_state *istate,
+		   const char *path, struct attr_check *check)
 {
 	int i;
 
 	attr_check_reset(check);
-	collect_some_attrs(path, check);
+	collect_some_attrs(istate, path, check);
 
 	for (i = 0; i < check->all_attrs_nr; i++) {
 		const char *name = check->all_attrs[i].attr->name;
@@ -1173,8 +1155,6 @@ void git_all_attrs(const char *path, str
 
 void attr_start(void)
 {
-#ifndef NO_PTHREADS
 	pthread_mutex_init(&g_attr_hashmap.mutex, NULL);
 	pthread_mutex_init(&check_vector.mutex, NULL);
-#endif
 }
diff -pruN 1.2.1+git2.18.0-1/git/attr.h 1.2.3+git2.25.1-1/git/attr.h
--- 1.2.1+git2.18.0-1/git/attr.h	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/attr.h	2020-02-17 04:47:35.000000000 +0000
@@ -1,12 +1,127 @@
 #ifndef ATTR_H
 #define ATTR_H
 
-/* An attribute is a pointer to this opaque structure */
+/**
+ * gitattributes mechanism gives a uniform way to associate various attributes
+ * to set of paths.
+ *
+ *
+ * Querying Specific Attributes
+ * ----------------------------
+ *
+ * - Prepare `struct attr_check` using attr_check_initl() function, enumerating
+ *   the names of attributes whose values you are interested in, terminated with
+ *   a NULL pointer.  Alternatively, an empty `struct attr_check` can be
+ *   prepared by calling `attr_check_alloc()` function and then attributes you
+ *   want to ask about can be added to it with `attr_check_append()` function.
+ *
+ * - Call `git_check_attr()` to check the attributes for the path.
+ *
+ * - Inspect `attr_check` structure to see how each of the attribute in the
+ *   array is defined for the path.
+ *
+ *
+ * Example
+ * -------
+ *
+ * To see how attributes "crlf" and "ident" are set for different paths.
+ *
+ * - Prepare a `struct attr_check` with two elements (because we are checking
+ *   two attributes):
+ *
+ * ------------
+ * static struct attr_check *check;
+ * static void setup_check(void)
+ * {
+ * 	if (check)
+ * 		return; // already done
+ * check = attr_check_initl("crlf", "ident", NULL);
+ * }
+ * ------------
+ *
+ * - Call `git_check_attr()` with the prepared `struct attr_check`:
+ *
+ * ------------
+ * const char *path;
+ *
+ * setup_check();
+ * git_check_attr(path, check);
+ * ------------
+ *
+ * - Act on `.value` member of the result, left in `check->items[]`:
+ *
+ * ------------
+ * const char *value = check->items[0].value;
+ *
+ * if (ATTR_TRUE(value)) {
+ * The attribute is Set, by listing only the name of the
+ * attribute in the gitattributes file for the path.
+ * } else if (ATTR_FALSE(value)) {
+ * The attribute is Unset, by listing the name of the
+ *         attribute prefixed with a dash - for the path.
+ * } else if (ATTR_UNSET(value)) {
+ * The attribute is neither set nor unset for the path.
+ * } else if (!strcmp(value, "input")) {
+ * If none of ATTR_TRUE(), ATTR_FALSE(), or ATTR_UNSET() is
+ *         true, the value is a string set in the gitattributes
+ * file for the path by saying "attr=value".
+ * } else if (... other check using value as string ...) {
+ * ...
+ * }
+ * ------------
+ *
+ * To see how attributes in argv[] are set for different paths, only
+ * the first step in the above would be different.
+ *
+ * ------------
+ * static struct attr_check *check;
+ * static void setup_check(const char **argv)
+ * {
+ *     check = attr_check_alloc();
+ *     while (*argv) {
+ *         struct git_attr *attr = git_attr(*argv);
+ *         attr_check_append(check, attr);
+ *         argv++;
+ *     }
+ * }
+ * ------------
+ *
+ *
+ * Querying All Attributes
+ * -----------------------
+ *
+ * To get the values of all attributes associated with a file:
+ *
+ * - Prepare an empty `attr_check` structure by calling `attr_check_alloc()`.
+ *
+ * - Call `git_all_attrs()`, which populates the `attr_check` with the
+ * attributes attached to the path.
+ *
+ * - Iterate over the `attr_check.items[]` array to examine the attribute
+ * names and values. The name of the attribute described by an
+ * `attr_check.items[]` object can be retrieved via
+ * `git_attr_name(check->items[i].attr)`. (Please note that no items will be
+ * returned for unset attributes, so `ATTR_UNSET()` will return false for all
+ * returned `attr_check.items[]` objects.)
+ *
+ * - Free the `attr_check` struct by calling `attr_check_free()`.
+ */
+
+struct index_state;
+
+/**
+ * An attribute is an opaque object that is identified by its name. Pass the
+ * name to `git_attr()` function to obtain the object of this type.
+ * The internal representation of this structure is of no interest to the
+ * calling programs. The name of the attribute can be retrieved by calling
+ * `git_attr_name()`.
+ */
 struct git_attr;
 
 /* opaque structures used internally for attribute collection */
 struct all_attrs_item;
 struct attr_stack;
+struct index_state;
 
 /*
  * Given a string, return the gitattribute object that
@@ -18,21 +133,36 @@ const struct git_attr *git_attr(const ch
 extern const char git_attr__true[];
 extern const char git_attr__false[];
 
-/* For public to check git_attr_check results */
+/**
+ * Attribute Values
+ * ----------------
+ *
+ * An attribute for a path can be in one of four states: Set, Unset, Unspecified
+ * or set to a string, and `.value` member of `struct attr_check_item` records
+ * it. The three macros check these, if none of them returns true, `.value`
+ * member points at a string value of the attribute for the path.
+ */
+
+/* Returns true if the attribute is Set for the path. */
 #define ATTR_TRUE(v) ((v) == git_attr__true)
+
+/* Returns true if the attribute is Unset for the path. */
 #define ATTR_FALSE(v) ((v) == git_attr__false)
+
+/* Returns true if the attribute is Unspecified for the path. */
 #define ATTR_UNSET(v) ((v) == NULL)
 
-/*
- * Send one or more git_attr_check to git_check_attrs(), and
- * each 'value' member tells what its value is.
- * Unset one is returned as NULL.
- */
+/* This structure represents one attribute and its value. */
 struct attr_check_item {
 	const struct git_attr *attr;
 	const char *value;
 };
 
+/**
+ * This structure represents a collection of `attr_check_item`. It is passed to
+ * `git_check_attr()` function, specifying the attributes to check, and
+ * receives their values.
+ */
 struct attr_check {
 	int nr;
 	int alloc;
@@ -42,40 +172,41 @@ struct attr_check {
 	struct attr_stack *stack;
 };
 
-extern struct attr_check *attr_check_alloc(void);
-extern struct attr_check *attr_check_initl(const char *, ...);
-extern struct attr_check *attr_check_dup(const struct attr_check *check);
-
-extern struct attr_check_item *attr_check_append(struct attr_check *check,
-						 const struct git_attr *attr);
-
-extern void attr_check_reset(struct attr_check *check);
-extern void attr_check_clear(struct attr_check *check);
-extern void attr_check_free(struct attr_check *check);
+struct attr_check *attr_check_alloc(void);
+struct attr_check *attr_check_initl(const char *, ...);
+struct attr_check *attr_check_dup(const struct attr_check *check);
+
+struct attr_check_item *attr_check_append(struct attr_check *check,
+					  const struct git_attr *attr);
+
+void attr_check_reset(struct attr_check *check);
+void attr_check_clear(struct attr_check *check);
+void attr_check_free(struct attr_check *check);
 
 /*
  * Return the name of the attribute represented by the argument.  The
  * return value is a pointer to a null-delimited string that is part
  * of the internal data structure; it should not be modified or freed.
  */
-extern const char *git_attr_name(const struct git_attr *);
+const char *git_attr_name(const struct git_attr *);
 
-extern int git_check_attr(const char *path, struct attr_check *check);
+void git_check_attr(const struct index_state *istate,
+		    const char *path, struct attr_check *check);
 
 /*
  * Retrieve all attributes that apply to the specified path.
  * check holds the attributes and their values.
  */
-extern void git_all_attrs(const char *path, struct attr_check *check);
+void git_all_attrs(const struct index_state *istate,
+		   const char *path, struct attr_check *check);
 
 enum git_attr_direction {
 	GIT_ATTR_CHECKIN,
 	GIT_ATTR_CHECKOUT,
 	GIT_ATTR_INDEX
 };
-void git_attr_set_direction(enum git_attr_direction new_direction,
-			    struct index_state *istate);
+void git_attr_set_direction(enum git_attr_direction new_direction);
 
-extern void attr_start(void);
+void attr_start(void);
 
 #endif /* ATTR_H */
diff -pruN 1.2.1+git2.18.0-1/git/azure-pipelines.yml 1.2.3+git2.25.1-1/git/azure-pipelines.yml
--- 1.2.1+git2.18.0-1/git/azure-pipelines.yml	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/azure-pipelines.yml	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,545 @@
+variables:
+  Agent.Source.Git.ShallowFetchDepth: 1
+
+jobs:
+- job: windows_build
+  displayName: Windows Build
+  condition: succeeded()
+  pool: Hosted
+  timeoutInMinutes: 240
+  steps:
+  - powershell: |
+      if ("$GITFILESHAREPWD" -ne "" -and "$GITFILESHAREPWD" -ne "`$`(gitfileshare.pwd)") {
+        net use s: \\gitfileshare.file.core.windows.net\test-cache "$GITFILESHAREPWD" /user:AZURE\gitfileshare /persistent:no
+        cmd /c mklink /d "$(Build.SourcesDirectory)\test-cache" S:\
+      }
+    displayName: 'Mount test-cache'
+    env:
+      GITFILESHAREPWD: $(gitfileshare.pwd)
+  - powershell: |
+      $urlbase = "https://dev.azure.com/git-for-windows/git/_apis/build/builds"
+      $id = ((Invoke-WebRequest -UseBasicParsing "${urlbase}?definitions=22&statusFilter=completed&resultFilter=succeeded&`$top=1").content | ConvertFrom-JSON).value[0].id
+      $downloadUrl = ((Invoke-WebRequest -UseBasicParsing "${urlbase}/$id/artifacts").content | ConvertFrom-JSON).value[1].resource.downloadUrl
+      (New-Object Net.WebClient).DownloadFile($downloadUrl,"git-sdk-64-minimal.zip")
+      Expand-Archive git-sdk-64-minimal.zip -DestinationPath . -Force
+      Remove-Item git-sdk-64-minimal.zip
+
+      # Let Git ignore the SDK and the test-cache
+      "/git-sdk-64-minimal/`n/test-cache/`n" | Out-File -NoNewLine -Encoding ascii -Append "$(Build.SourcesDirectory)\.git\info\exclude"
+    displayName: 'Download git-sdk-64-minimal'
+  - powershell: |
+      & git-sdk-64-minimal\usr\bin\bash.exe -lc @"
+        ci/make-test-artifacts.sh artifacts
+      "@
+      if (!$?) { exit(1) }
+    displayName: Build
+    env:
+      HOME: $(Build.SourcesDirectory)
+      MSYSTEM: MINGW64
+      DEVELOPER: 1
+      NO_PERL: 1
+  - task: PublishPipelineArtifact@0
+    displayName: 'Publish Pipeline Artifact: test artifacts'
+    inputs:
+      artifactName: 'windows-artifacts'
+      targetPath: '$(Build.SourcesDirectory)\artifacts'
+  - task: PublishPipelineArtifact@0
+    displayName: 'Publish Pipeline Artifact: git-sdk-64-minimal'
+    inputs:
+      artifactName: 'git-sdk-64-minimal'
+      targetPath: '$(Build.SourcesDirectory)\git-sdk-64-minimal'
+  - powershell: |
+      if ("$GITFILESHAREPWD" -ne "" -and "$GITFILESHAREPWD" -ne "`$`(gitfileshare.pwd)") {
+        cmd /c rmdir "$(Build.SourcesDirectory)\test-cache"
+      }
+    displayName: 'Unmount test-cache'
+    condition: true
+    env:
+      GITFILESHAREPWD: $(gitfileshare.pwd)
+
+- job: windows_test
+  displayName: Windows Test
+  dependsOn: windows_build
+  condition: succeeded()
+  pool: Hosted
+  timeoutInMinutes: 240
+  strategy:
+    parallel: 10
+  steps:
+  - powershell: |
+      if ("$GITFILESHAREPWD" -ne "" -and "$GITFILESHAREPWD" -ne "`$`(gitfileshare.pwd)") {
+        net use s: \\gitfileshare.file.core.windows.net\test-cache "$GITFILESHAREPWD" /user:AZURE\gitfileshare /persistent:no
+        cmd /c mklink /d "$(Build.SourcesDirectory)\test-cache" S:\
+      }
+    displayName: 'Mount test-cache'
+    env:
+      GITFILESHAREPWD: $(gitfileshare.pwd)
+  - task: DownloadPipelineArtifact@0
+    displayName: 'Download Pipeline Artifact: test artifacts'
+    inputs:
+      artifactName: 'windows-artifacts'
+      targetPath: '$(Build.SourcesDirectory)'
+  - task: DownloadPipelineArtifact@0
+    displayName: 'Download Pipeline Artifact: git-sdk-64-minimal'
+    inputs:
+      artifactName: 'git-sdk-64-minimal'
+      targetPath: '$(Build.SourcesDirectory)\git-sdk-64-minimal'
+  - powershell: |
+      & git-sdk-64-minimal\usr\bin\bash.exe -lc @"
+        test -f artifacts.tar.gz || {
+          echo No test artifacts found\; skipping >&2
+          exit 0
+        }
+        tar xf artifacts.tar.gz || exit 1
+
+        # Let Git ignore the SDK and the test-cache
+        printf '%s\n' /git-sdk-64-minimal/ /test-cache/ >>.git/info/exclude
+
+        ci/run-test-slice.sh `$SYSTEM_JOBPOSITIONINPHASE `$SYSTEM_TOTALJOBSINPHASE || {
+          ci/print-test-failures.sh
+          exit 1
+        }
+      "@
+      if (!$?) { exit(1) }
+    displayName: 'Test (parallel)'
+    env:
+      HOME: $(Build.SourcesDirectory)
+      MSYSTEM: MINGW64
+      NO_SVN_TESTS: 1
+      GIT_TEST_SKIP_REBASE_P: 1
+  - powershell: |
+      if ("$GITFILESHAREPWD" -ne "" -and "$GITFILESHAREPWD" -ne "`$`(gitfileshare.pwd)") {
+        cmd /c rmdir "$(Build.SourcesDirectory)\test-cache"
+      }
+    displayName: 'Unmount test-cache'
+    condition: true
+    env:
+      GITFILESHAREPWD: $(gitfileshare.pwd)
+  - task: PublishTestResults@2
+    displayName: 'Publish Test Results **/TEST-*.xml'
+    inputs:
+      mergeTestResults: true
+      testRunTitle: 'windows'
+      platform: Windows
+      publishRunAttachments: false
+    condition: succeededOrFailed()
+  - task: PublishBuildArtifacts@1
+    displayName: 'Publish trash directories of failed tests'
+    condition: failed()
+    inputs:
+      PathtoPublish: t/failed-test-artifacts
+      ArtifactName: failed-test-artifacts
+
+- job: vs_build
+  displayName: Visual Studio Build
+  condition: succeeded()
+  pool: Hosted VS2017
+  timeoutInMinutes: 240
+  steps:
+  - powershell: |
+      if ("$GITFILESHAREPWD" -ne "" -and "$GITFILESHAREPWD" -ne "`$`(gitfileshare.pwd)") {
+        net use s: \\gitfileshare.file.core.windows.net\test-cache "$GITFILESHAREPWD" /user:AZURE\gitfileshare /persistent:no
+        cmd /c mklink /d "$(Build.SourcesDirectory)\test-cache" S:\
+      }
+    displayName: 'Mount test-cache'
+    env:
+      GITFILESHAREPWD: $(gitfileshare.pwd)
+  - powershell: |
+      $urlbase = "https://dev.azure.com/git-for-windows/git/_apis/build/builds"
+      $id = ((Invoke-WebRequest -UseBasicParsing "${urlbase}?definitions=22&statusFilter=completed&resultFilter=succeeded&`$top=1").content | ConvertFrom-JSON).value[0].id
+      $downloadUrl = ((Invoke-WebRequest -UseBasicParsing "${urlbase}/$id/artifacts").content | ConvertFrom-JSON).value[1].resource.downloadUrl
+      (New-Object Net.WebClient).DownloadFile($downloadUrl,"git-sdk-64-minimal.zip")
+      Expand-Archive git-sdk-64-minimal.zip -DestinationPath . -Force
+      Remove-Item git-sdk-64-minimal.zip
+
+      # Let Git ignore the SDK and the test-cache
+      "/git-sdk-64-minimal/`n/test-cache/`n" | Out-File -NoNewLine -Encoding ascii -Append "$(Build.SourcesDirectory)\.git\info\exclude"
+    displayName: 'Download git-sdk-64-minimal'
+  - powershell: |
+      & git-sdk-64-minimal\usr\bin\bash.exe -lc @"
+        make NDEBUG=1 DEVELOPER=1 vcxproj
+      "@
+      if (!$?) { exit(1) }
+    displayName: Generate Visual Studio Solution
+    env:
+      HOME: $(Build.SourcesDirectory)
+      MSYSTEM: MINGW64
+      DEVELOPER: 1
+      NO_PERL: 1
+      GIT_CONFIG_PARAMETERS: "'user.name=CI' 'user.email=ci@git'"
+  - powershell: |
+      $urlbase = "https://dev.azure.com/git/git/_apis/build/builds"
+      $id = ((Invoke-WebRequest -UseBasicParsing "${urlbase}?definitions=9&statusFilter=completed&resultFilter=succeeded&`$top=1").content | ConvertFrom-JSON).value[0].id
+      $downloadUrl = ((Invoke-WebRequest -UseBasicParsing "${urlbase}/$id/artifacts").content | ConvertFrom-JSON).value[0].resource.downloadUrl
+      (New-Object Net.WebClient).DownloadFile($downloadUrl, "compat.zip")
+      Expand-Archive compat.zip -DestinationPath . -Force
+      Remove-Item compat.zip
+    displayName: 'Download vcpkg artifacts'
+  - task: MSBuild@1
+    inputs:
+      solution: git.sln
+      platform: x64
+      configuration: Release
+      maximumCpuCount: 4
+  - powershell: |
+      & compat\vcbuild\vcpkg_copy_dlls.bat release
+      if (!$?) { exit(1) }
+      & git-sdk-64-minimal\usr\bin\bash.exe -lc @"
+        mkdir -p artifacts &&
+        eval \"`$(make -n artifacts-tar INCLUDE_DLLS_IN_ARTIFACTS=YesPlease ARTIFACTS_DIRECTORY=artifacts | grep ^tar)\"
+      "@
+      if (!$?) { exit(1) }
+    displayName: Bundle artifact tar
+    env:
+      HOME: $(Build.SourcesDirectory)
+      MSYSTEM: MINGW64
+      DEVELOPER: 1
+      NO_PERL: 1
+      MSVC: 1
+      VCPKG_ROOT: $(Build.SourcesDirectory)\compat\vcbuild\vcpkg
+  - powershell: |
+      $tag = (Invoke-WebRequest -UseBasicParsing "https://gitforwindows.org/latest-tag.txt").content
+      $version = (Invoke-WebRequest -UseBasicParsing "https://gitforwindows.org/latest-version.txt").content
+      $url = "https://github.com/git-for-windows/git/releases/download/${tag}/PortableGit-${version}-64-bit.7z.exe"
+      (New-Object Net.WebClient).DownloadFile($url,"PortableGit.exe")
+      & .\PortableGit.exe -y -oartifacts\PortableGit
+      # Wait until it is unpacked
+      while (-not @(Remove-Item -ErrorAction SilentlyContinue PortableGit.exe; $?)) { sleep 1 }
+    displayName: Download & extract portable Git
+  - task: PublishPipelineArtifact@0
+    displayName: 'Publish Pipeline Artifact: MSVC test artifacts'
+    inputs:
+      artifactName: 'vs-artifacts'
+      targetPath: '$(Build.SourcesDirectory)\artifacts'
+  - powershell: |
+      if ("$GITFILESHAREPWD" -ne "" -and "$GITFILESHAREPWD" -ne "`$`(gitfileshare.pwd)") {
+        cmd /c rmdir "$(Build.SourcesDirectory)\test-cache"
+      }
+    displayName: 'Unmount test-cache'
+    condition: true
+    env:
+      GITFILESHAREPWD: $(gitfileshare.pwd)
+
+- job: vs_test
+  displayName: Visual Studio Test
+  dependsOn: vs_build
+  condition: succeeded()
+  pool: Hosted
+  timeoutInMinutes: 240
+  strategy:
+    parallel: 10
+  steps:
+  - powershell: |
+      if ("$GITFILESHAREPWD" -ne "" -and "$GITFILESHAREPWD" -ne "`$`(gitfileshare.pwd)") {
+        net use s: \\gitfileshare.file.core.windows.net\test-cache "$GITFILESHAREPWD" /user:AZURE\gitfileshare /persistent:no
+        cmd /c mklink /d "$(Build.SourcesDirectory)\test-cache" S:\
+      }
+    displayName: 'Mount test-cache'
+    env:
+      GITFILESHAREPWD: $(gitfileshare.pwd)
+  - task: DownloadPipelineArtifact@0
+    displayName: 'Download Pipeline Artifact: VS test artifacts'
+    inputs:
+      artifactName: 'vs-artifacts'
+      targetPath: '$(Build.SourcesDirectory)'
+  - powershell: |
+      & PortableGit\git-cmd.exe --command=usr\bin\bash.exe -lc @"
+        test -f artifacts.tar.gz || {
+          echo No test artifacts found\; skipping >&2
+          exit 0
+        }
+        tar xf artifacts.tar.gz || exit 1
+
+        # Let Git ignore the SDK and the test-cache
+        printf '%s\n' /PortableGit/ /test-cache/ >>.git/info/exclude
+
+        cd t &&
+        PATH=\"`$PWD/helper:`$PATH\" &&
+        test-tool.exe run-command testsuite --jobs=10 -V -x --write-junit-xml \
+                `$(test-tool.exe path-utils slice-tests \
+                        `$SYSTEM_JOBPOSITIONINPHASE `$SYSTEM_TOTALJOBSINPHASE t[0-9]*.sh)
+      "@
+      if (!$?) { exit(1) }
+    displayName: 'Test (parallel)'
+    env:
+      HOME: $(Build.SourcesDirectory)
+      MSYSTEM: MINGW64
+      NO_SVN_TESTS: 1
+      GIT_TEST_SKIP_REBASE_P: 1
+  - powershell: |
+      if ("$GITFILESHAREPWD" -ne "" -and "$GITFILESHAREPWD" -ne "`$`(gitfileshare.pwd)") {
+        cmd /c rmdir "$(Build.SourcesDirectory)\test-cache"
+      }
+    displayName: 'Unmount test-cache'
+    condition: true
+    env:
+      GITFILESHAREPWD: $(gitfileshare.pwd)
+  - task: PublishTestResults@2
+    displayName: 'Publish Test Results **/TEST-*.xml'
+    inputs:
+      mergeTestResults: true
+      testRunTitle: 'vs'
+      platform: Windows
+      publishRunAttachments: false
+    condition: succeededOrFailed()
+  - task: PublishBuildArtifacts@1
+    displayName: 'Publish trash directories of failed tests'
+    condition: failed()
+    inputs:
+      PathtoPublish: t/failed-test-artifacts
+      ArtifactName: failed-vs-test-artifacts
+
+- job: linux_clang
+  displayName: linux-clang
+  condition: succeeded()
+  pool: Hosted Ubuntu 1604
+  steps:
+  - bash: |
+       test "$GITFILESHAREPWD" = '$(gitfileshare.pwd)' || ci/mount-fileshare.sh //gitfileshare.file.core.windows.net/test-cache gitfileshare "$GITFILESHAREPWD" "$HOME/test-cache" || exit 1
+
+       sudo apt-get update &&
+       sudo apt-get -y install git gcc make libssl-dev libcurl4-openssl-dev libexpat-dev tcl tk gettext git-email zlib1g-dev apache2-bin &&
+
+       export CC=clang || exit 1
+
+       ci/install-dependencies.sh || exit 1
+       ci/run-build-and-tests.sh || {
+           ci/print-test-failures.sh
+           exit 1
+       }
+
+       test "$GITFILESHAREPWD" = '$(gitfileshare.pwd)' || sudo umount "$HOME/test-cache" || exit 1
+    displayName: 'ci/run-build-and-tests.sh'
+    env:
+      GITFILESHAREPWD: $(gitfileshare.pwd)
+  - task: PublishTestResults@2
+    displayName: 'Publish Test Results **/TEST-*.xml'
+    inputs:
+      mergeTestResults: true
+      testRunTitle: 'linux-clang'
+      platform: Linux
+      publishRunAttachments: false
+    condition: succeededOrFailed()
+  - task: PublishBuildArtifacts@1
+    displayName: 'Publish trash directories of failed tests'
+    condition: failed()
+    inputs:
+      PathtoPublish: t/failed-test-artifacts
+      ArtifactName: failed-test-artifacts
+
+- job: linux_gcc
+  displayName: linux-gcc
+  condition: succeeded()
+  pool: Hosted Ubuntu 1604
+  steps:
+  - bash: |
+       test "$GITFILESHAREPWD" = '$(gitfileshare.pwd)' || ci/mount-fileshare.sh //gitfileshare.file.core.windows.net/test-cache gitfileshare "$GITFILESHAREPWD" "$HOME/test-cache" || exit 1
+
+       sudo add-apt-repository ppa:ubuntu-toolchain-r/test &&
+       sudo apt-get update &&
+       sudo apt-get -y install git gcc make libssl-dev libcurl4-openssl-dev libexpat-dev tcl tk gettext git-email zlib1g-dev apache2 language-pack-is git-svn gcc-8 || exit 1
+
+       ci/install-dependencies.sh || exit 1
+       ci/run-build-and-tests.sh || {
+           ci/print-test-failures.sh
+           exit 1
+       }
+
+       test "$GITFILESHAREPWD" = '$(gitfileshare.pwd)' || sudo umount "$HOME/test-cache" || exit 1
+    displayName: 'ci/run-build-and-tests.sh'
+    env:
+      GITFILESHAREPWD: $(gitfileshare.pwd)
+  - task: PublishTestResults@2
+    displayName: 'Publish Test Results **/TEST-*.xml'
+    inputs:
+      mergeTestResults: true
+      testRunTitle: 'linux-gcc'
+      platform: Linux
+      publishRunAttachments: false
+    condition: succeededOrFailed()
+  - task: PublishBuildArtifacts@1
+    displayName: 'Publish trash directories of failed tests'
+    condition: failed()
+    inputs:
+      PathtoPublish: t/failed-test-artifacts
+      ArtifactName: failed-test-artifacts
+
+- job: osx_clang
+  displayName: osx-clang
+  condition: succeeded()
+  pool: Hosted macOS
+  steps:
+  - bash: |
+       test "$GITFILESHAREPWD" = '$(gitfileshare.pwd)' || ci/mount-fileshare.sh //gitfileshare.file.core.windows.net/test-cache gitfileshare "$GITFILESHAREPWD" "$HOME/test-cache" || exit 1
+
+       export CC=clang
+
+       ci/install-dependencies.sh || exit 1
+       ci/run-build-and-tests.sh || {
+           ci/print-test-failures.sh
+           exit 1
+       }
+
+       test "$GITFILESHAREPWD" = '$(gitfileshare.pwd)' || umount "$HOME/test-cache" || exit 1
+    displayName: 'ci/run-build-and-tests.sh'
+    env:
+      GITFILESHAREPWD: $(gitfileshare.pwd)
+  - task: PublishTestResults@2
+    displayName: 'Publish Test Results **/TEST-*.xml'
+    inputs:
+      mergeTestResults: true
+      testRunTitle: 'osx-clang'
+      platform: macOS
+      publishRunAttachments: false
+    condition: succeededOrFailed()
+  - task: PublishBuildArtifacts@1
+    displayName: 'Publish trash directories of failed tests'
+    condition: failed()
+    inputs:
+      PathtoPublish: t/failed-test-artifacts
+      ArtifactName: failed-test-artifacts
+
+- job: osx_gcc
+  displayName: osx-gcc
+  condition: succeeded()
+  pool: Hosted macOS
+  steps:
+  - bash: |
+       test "$GITFILESHAREPWD" = '$(gitfileshare.pwd)' || ci/mount-fileshare.sh //gitfileshare.file.core.windows.net/test-cache gitfileshare "$GITFILESHAREPWD" "$HOME/test-cache" || exit 1
+
+       ci/install-dependencies.sh || exit 1
+       ci/run-build-and-tests.sh || {
+           ci/print-test-failures.sh
+           exit 1
+       }
+
+       test "$GITFILESHAREPWD" = '$(gitfileshare.pwd)' || umount "$HOME/test-cache" || exit 1
+    displayName: 'ci/run-build-and-tests.sh'
+    env:
+      GITFILESHAREPWD: $(gitfileshare.pwd)
+  - task: PublishTestResults@2
+    displayName: 'Publish Test Results **/TEST-*.xml'
+    inputs:
+      mergeTestResults: true
+      testRunTitle: 'osx-gcc'
+      platform: macOS
+      publishRunAttachments: false
+    condition: succeededOrFailed()
+  - task: PublishBuildArtifacts@1
+    displayName: 'Publish trash directories of failed tests'
+    condition: failed()
+    inputs:
+      PathtoPublish: t/failed-test-artifacts
+      ArtifactName: failed-test-artifacts
+
+- job: gettext_poison
+  displayName: GETTEXT_POISON
+  condition: succeeded()
+  pool: Hosted Ubuntu 1604
+  steps:
+  - bash: |
+       test "$GITFILESHAREPWD" = '$(gitfileshare.pwd)' || ci/mount-fileshare.sh //gitfileshare.file.core.windows.net/test-cache gitfileshare "$GITFILESHAREPWD" "$HOME/test-cache" || exit 1
+
+       sudo apt-get update &&
+       sudo apt-get -y install git gcc make libssl-dev libcurl4-openssl-dev libexpat-dev tcl tk gettext git-email zlib1g-dev &&
+
+       export jobname=GETTEXT_POISON || exit 1
+
+       ci/run-build-and-tests.sh || {
+           ci/print-test-failures.sh
+           exit 1
+       }
+
+       test "$GITFILESHAREPWD" = '$(gitfileshare.pwd)' || sudo umount "$HOME/test-cache" || exit 1
+    displayName: 'ci/run-build-and-tests.sh'
+    env:
+      GITFILESHAREPWD: $(gitfileshare.pwd)
+  - task: PublishTestResults@2
+    displayName: 'Publish Test Results **/TEST-*.xml'
+    inputs:
+      mergeTestResults: true
+      testRunTitle: 'gettext-poison'
+      platform: Linux
+      publishRunAttachments: false
+    condition: succeededOrFailed()
+  - task: PublishBuildArtifacts@1
+    displayName: 'Publish trash directories of failed tests'
+    condition: failed()
+    inputs:
+      PathtoPublish: t/failed-test-artifacts
+      ArtifactName: failed-test-artifacts
+
+- job: linux32
+  displayName: Linux32
+  condition: succeeded()
+  pool: Hosted Ubuntu 1604
+  steps:
+  - bash: |
+       test "$GITFILESHAREPWD" = '$(gitfileshare.pwd)' || ci/mount-fileshare.sh //gitfileshare.file.core.windows.net/test-cache gitfileshare "$GITFILESHAREPWD" "$HOME/test-cache" || exit 1
+
+       res=0
+       sudo AGENT_OS="$AGENT_OS" BUILD_BUILDNUMBER="$BUILD_BUILDNUMBER" BUILD_REPOSITORY_URI="$BUILD_REPOSITORY_URI" BUILD_SOURCEBRANCH="$BUILD_SOURCEBRANCH" BUILD_SOURCEVERSION="$BUILD_SOURCEVERSION" SYSTEM_PHASENAME="$SYSTEM_PHASENAME" SYSTEM_TASKDEFINITIONSURI="$SYSTEM_TASKDEFINITIONSURI" SYSTEM_TEAMPROJECT="$SYSTEM_TEAMPROJECT" CC=$CC MAKEFLAGS="$MAKEFLAGS" bash -lxc ci/run-linux32-docker.sh || res=1
+
+       sudo chmod a+r t/out/TEST-*.xml
+       test ! -d t/failed-test-artifacts || sudo chmod a+r t/failed-test-artifacts
+
+       test "$GITFILESHAREPWD" = '$(gitfileshare.pwd)' || sudo umount "$HOME/test-cache" || res=1
+       exit $res
+    displayName: 'ci/run-linux32-docker.sh'
+    env:
+      GITFILESHAREPWD: $(gitfileshare.pwd)
+  - task: PublishTestResults@2
+    displayName: 'Publish Test Results **/TEST-*.xml'
+    inputs:
+      mergeTestResults: true
+      testRunTitle: 'linux32'
+      platform: Linux
+      publishRunAttachments: false
+    condition: succeededOrFailed()
+  - task: PublishBuildArtifacts@1
+    displayName: 'Publish trash directories of failed tests'
+    condition: failed()
+    inputs:
+      PathtoPublish: t/failed-test-artifacts
+      ArtifactName: failed-test-artifacts
+
+- job: static_analysis
+  displayName: StaticAnalysis
+  condition: succeeded()
+  pool: Hosted Ubuntu 1604
+  steps:
+  - bash: |
+       test "$GITFILESHAREPWD" = '$(gitfileshare.pwd)' || ci/mount-fileshare.sh //gitfileshare.file.core.windows.net/test-cache gitfileshare "$GITFILESHAREPWD" "$HOME/test-cache" || exit 1
+
+       sudo apt-get update &&
+       sudo apt-get install -y coccinelle libcurl4-openssl-dev libssl-dev libexpat-dev gettext &&
+
+       export jobname=StaticAnalysis &&
+
+       ci/run-static-analysis.sh || exit 1
+
+       test "$GITFILESHAREPWD" = '$(gitfileshare.pwd)' || sudo umount "$HOME/test-cache" || exit 1
+    displayName: 'ci/run-static-analysis.sh'
+    env:
+      GITFILESHAREPWD: $(gitfileshare.pwd)
+
+- job: documentation
+  displayName: Documentation
+  condition: succeeded()
+  pool: Hosted Ubuntu 1604
+  steps:
+  - bash: |
+       test "$GITFILESHAREPWD" = '$(gitfileshare.pwd)' || ci/mount-fileshare.sh //gitfileshare.file.core.windows.net/test-cache gitfileshare "$GITFILESHAREPWD" "$HOME/test-cache" || exit 1
+
+       sudo apt-get update &&
+       sudo apt-get install -y asciidoc xmlto asciidoctor docbook-xsl-ns &&
+
+       export ALREADY_HAVE_ASCIIDOCTOR=yes. &&
+       export jobname=Documentation &&
+
+       ci/test-documentation.sh || exit 1
+
+       test "$GITFILESHAREPWD" = '$(gitfileshare.pwd)' || sudo umount "$HOME/test-cache" || exit 1
+    displayName: 'ci/test-documentation.sh'
+    env:
+      GITFILESHAREPWD: $(gitfileshare.pwd)
diff -pruN 1.2.1+git2.18.0-1/git/banned.h 1.2.3+git2.25.1-1/git/banned.h
--- 1.2.1+git2.18.0-1/git/banned.h	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/banned.h	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,32 @@
+#ifndef BANNED_H
+#define BANNED_H
+
+/*
+ * This header lists functions that have been banned from our code base,
+ * because they're too easy to misuse (and even if used correctly,
+ * complicate audits). Including this header turns them into compile-time
+ * errors.
+ */
+
+#define BANNED(func) sorry_##func##_is_a_banned_function
+
+#undef strcpy
+#define strcpy(x,y) BANNED(strcpy)
+#undef strcat
+#define strcat(x,y) BANNED(strcat)
+#undef strncpy
+#define strncpy(x,y,n) BANNED(strncpy)
+#undef strncat
+#define strncat(x,y,n) BANNED(strncat)
+
+#undef sprintf
+#undef vsprintf
+#ifdef HAVE_VARIADIC_MACROS
+#define sprintf(...) BANNED(sprintf)
+#define vsprintf(...) BANNED(vsprintf)
+#else
+#define sprintf(buf,fmt,arg) BANNED(sprintf)
+#define vsprintf(buf,fmt,arg) BANNED(vsprintf)
+#endif
+
+#endif /* BANNED_H */
diff -pruN 1.2.1+git2.18.0-1/git/bisect.c 1.2.3+git2.25.1-1/git/bisect.c
--- 1.2.1+git2.18.0-1/git/bisect.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/bisect.c	2020-02-17 04:47:35.000000000 +0000
@@ -12,6 +12,9 @@
 #include "bisect.h"
 #include "sha1-array.h"
 #include "argv-array.h"
+#include "commit-slab.h"
+#include "commit-reach.h"
+#include "object-store.h"
 
 static struct oid_array good_revs;
 static struct oid_array skipped_revs;
@@ -70,16 +73,19 @@ static void clear_distance(struct commit
 	}
 }
 
+define_commit_slab(commit_weight, int *);
+static struct commit_weight commit_weight;
+
 #define DEBUG_BISECT 0
 
 static inline int weight(struct commit_list *elem)
 {
-	return *((int*)(elem->item->util));
+	return **commit_weight_at(&commit_weight, elem->item);
 }
 
 static inline void weight_set(struct commit_list *elem, int weight)
 {
-	*((int*)(elem->item->util)) = weight;
+	**commit_weight_at(&commit_weight, elem->item) = weight;
 }
 
 static int count_interesting_parents(struct commit *commit)
@@ -116,14 +122,14 @@ static inline int halfway(struct commit_
 	}
 }
 
-#if !DEBUG_BISECT
-#define show_list(a,b,c,d) do { ; } while (0)
-#else
 static void show_list(const char *debug, int counted, int nr,
 		      struct commit_list *list)
 {
 	struct commit_list *p;
 
+	if (!DEBUG_BISECT)
+		return;
+
 	fprintf(stderr, "%s (%d/%d)\n", debug, counted, nr);
 
 	for (p = list; p; p = p->next) {
@@ -141,7 +147,7 @@ static void show_list(const char *debug,
 			(flags & TREESAME) ? ' ' : 'T',
 			(flags & UNINTERESTING) ? 'U' : ' ',
 			(flags & COUNTED) ? 'C' : ' ');
-		if (commit->util)
+		if (*commit_weight_at(&commit_weight, p->item))
 			fprintf(stderr, "%3d", weight(p));
 		else
 			fprintf(stderr, "---");
@@ -156,7 +162,6 @@ static void show_list(const char *debug,
 		fprintf(stderr, "\n");
 	}
 }
-#endif /* DEBUG_BISECT */
 
 static struct commit_list *best_bisection(struct commit_list *list, int nr)
 {
@@ -265,7 +270,7 @@ static struct commit_list *do_find_bisec
 		struct commit *commit = p->item;
 		unsigned flags = commit->object.flags;
 
-		p->item->util = &weights[n++];
+		*commit_weight_at(&commit_weight, p->item) = &weights[n++];
 		switch (count_interesting_parents(commit)) {
 		case 0:
 			if (!(flags & TREESAME)) {
@@ -372,6 +377,7 @@ void find_bisection(struct commit_list *
 	int *weights;
 
 	show_list("bisection 2 entry", 0, 0, *commit_list);
+	init_commit_weight(&commit_weight);
 
 	/*
 	 * Count the number of total and tree-changing items on the
@@ -412,6 +418,7 @@ void find_bisection(struct commit_list *
 	}
 	free(weights);
 	*commit_list = best;
+	clear_commit_weight(&commit_weight);
 }
 
 static int register_ref(const char *refname, const struct object_id *oid,
@@ -551,7 +558,8 @@ struct commit_list *filter_skipped(struc
  * is increased by one between each call, but that should not matter
  * for this application.
  */
-static unsigned get_prn(unsigned count) {
+static unsigned get_prn(unsigned count)
+{
 	count = count * 1103515245 + 12345;
 	return (count/65536) % PRN_MODULO;
 }
@@ -589,7 +597,7 @@ static struct commit_list *skip_away(str
 
 	for (i = 0; cur; cur = cur->next, i++) {
 		if (i == index) {
-			if (oidcmp(&cur->item->object.oid, current_bad_oid))
+			if (!oideq(&cur->item->object.oid, current_bad_oid))
 				return cur;
 			if (previous)
 				return previous;
@@ -619,14 +627,15 @@ static struct commit_list *managed_skipp
 	return skip_away(list, count);
 }
 
-static void bisect_rev_setup(struct rev_info *revs, const char *prefix,
+static void bisect_rev_setup(struct repository *r, struct rev_info *revs,
+			     const char *prefix,
 			     const char *bad_format, const char *good_format,
 			     int read_paths)
 {
 	struct argv_array rev_argv = ARGV_ARRAY_INIT;
 	int i;
 
-	init_revisions(revs, prefix);
+	repo_init_revisions(r, revs, prefix);
 	revs->abbrev = 0;
 	revs->commit_format = CMIT_FMT_UNSPECIFIED;
 
@@ -649,7 +658,7 @@ static void bisect_common(struct rev_inf
 	if (prepare_revision_walk(revs))
 		die("revision walk setup failed");
 	if (revs->tree_objects)
-		mark_edges_uninteresting(revs, NULL);
+		mark_edges_uninteresting(revs, NULL, 0);
 }
 
 static void exit_if_skipped_commits(struct commit_list *tried,
@@ -698,7 +707,7 @@ static int bisect_checkout(const struct
 {
 	char bisect_rev_hex[GIT_MAX_HEXSZ + 1];
 
-	memcpy(bisect_rev_hex, oid_to_hex(bisect_rev), GIT_SHA1_HEXSZ + 1);
+	memcpy(bisect_rev_hex, oid_to_hex(bisect_rev), the_hash_algo->hexsz + 1);
 	update_ref(NULL, "BISECT_EXPECTED_REV", bisect_rev, NULL, 0, UPDATE_REFS_DIE_ON_ERR);
 
 	argv_checkout[2] = bisect_rev_hex;
@@ -716,23 +725,25 @@ static int bisect_checkout(const struct
 	return run_command_v_opt(argv_show_branch, RUN_GIT_CMD);
 }
 
-static struct commit *get_commit_reference(const struct object_id *oid)
+static struct commit *get_commit_reference(struct repository *r,
+					   const struct object_id *oid)
 {
-	struct commit *r = lookup_commit_reference(oid);
-	if (!r)
+	struct commit *c = lookup_commit_reference(r, oid);
+	if (!c)
 		die(_("Not a valid commit name %s"), oid_to_hex(oid));
-	return r;
+	return c;
 }
 
-static struct commit **get_bad_and_good_commits(int *rev_nr)
+static struct commit **get_bad_and_good_commits(struct repository *r,
+						int *rev_nr)
 {
 	struct commit **rev;
 	int i, n = 0;
 
 	ALLOC_ARRAY(rev, 1 + good_revs.nr);
-	rev[n++] = get_commit_reference(current_bad_oid);
+	rev[n++] = get_commit_reference(r, current_bad_oid);
 	for (i = 0; i < good_revs.nr; i++)
-		rev[n++] = get_commit_reference(good_revs.oid + i);
+		rev[n++] = get_commit_reference(r, good_revs.oid + i);
 	*rev_nr = n;
 
 	return rev;
@@ -801,7 +812,7 @@ static void check_merge_bases(int rev_nr
 
 	for (; result; result = result->next) {
 		const struct object_id *mb = &result->item->object.oid;
-		if (!oidcmp(mb, current_bad_oid)) {
+		if (oideq(mb, current_bad_oid)) {
 			handle_bad_merge_base();
 		} else if (0 <= oid_array_lookup(&good_revs, mb)) {
 			continue;
@@ -816,12 +827,13 @@ static void check_merge_bases(int rev_nr
 	free_commit_list(result);
 }
 
-static int check_ancestors(int rev_nr, struct commit **rev, const char *prefix)
+static int check_ancestors(struct repository *r, int rev_nr,
+			   struct commit **rev, const char *prefix)
 {
 	struct rev_info revs;
 	int res;
 
-	bisect_rev_setup(&revs, prefix, "^%s", "%s", 0);
+	bisect_rev_setup(r, &revs, prefix, "^%s", "%s", 0);
 
 	bisect_common(&revs);
 	res = (revs.commits != NULL);
@@ -840,7 +852,9 @@ static int check_ancestors(int rev_nr, s
  * If a merge base must be tested by the user, its source code will be
  * checked out to be tested by the user and we will exit.
  */
-static void check_good_are_ancestors_of_bad(const char *prefix, int no_checkout)
+static void check_good_are_ancestors_of_bad(struct repository *r,
+					    const char *prefix,
+					    int no_checkout)
 {
 	char *filename = git_pathdup("BISECT_ANCESTORS_OK");
 	struct stat st;
@@ -859,8 +873,8 @@ static void check_good_are_ancestors_of_
 		goto done;
 
 	/* Check if all good revs are ancestor of the bad rev. */
-	rev = get_bad_and_good_commits(&rev_nr);
-	if (check_ancestors(rev_nr, rev, prefix))
+	rev = get_bad_and_good_commits(r, &rev_nr);
+	if (check_ancestors(r, rev_nr, rev, prefix))
 		check_merge_bases(rev_nr, rev, no_checkout);
 	free(rev);
 
@@ -878,26 +892,19 @@ static void check_good_are_ancestors_of_
 /*
  * This does "git diff-tree --pretty COMMIT" without one fork+exec.
  */
-static void show_diff_tree(const char *prefix, struct commit *commit)
-{
+static void show_diff_tree(struct repository *r,
+			   const char *prefix,
+			   struct commit *commit)
+{
+	const char *argv[] = {
+		"diff-tree", "--pretty", "--stat", "--summary", "--cc", NULL
+	};
 	struct rev_info opt;
 
-	/* diff-tree init */
-	init_revisions(&opt, prefix);
-	git_config(git_diff_basic_config, NULL); /* no "diff" UI options */
-	opt.abbrev = 0;
-	opt.diff = 1;
-
-	/* This is what "--pretty" does */
-	opt.verbose_header = 1;
-	opt.use_terminator = 0;
-	opt.commit_format = CMIT_FMT_DEFAULT;
-
-	/* diff-tree init */
-	if (!opt.diffopt.output_format)
-		opt.diffopt.output_format = DIFF_FORMAT_RAW;
+	git_config(git_diff_ui_config, NULL);
+	repo_init_revisions(r, &opt, prefix);
 
-	setup_revisions(0, NULL, &opt, NULL);
+	setup_revisions(ARRAY_SIZE(argv) - 1, argv, &opt, NULL);
 	log_tree_commit(&opt, commit);
 }
 
@@ -938,7 +945,7 @@ void read_bisect_terms(const char **read
  * If no_checkout is non-zero, the bisection process does not
  * checkout the trial commit but instead simply updates BISECT_HEAD.
  */
-int bisect_next_all(const char *prefix, int no_checkout)
+int bisect_next_all(struct repository *r, const char *prefix, int no_checkout)
 {
 	struct rev_info revs;
 	struct commit_list *tried;
@@ -950,9 +957,9 @@ int bisect_next_all(const char *prefix,
 	if (read_bisect_refs())
 		die(_("reading bisect refs failed"));
 
-	check_good_are_ancestors_of_bad(prefix, no_checkout);
+	check_good_are_ancestors_of_bad(r, prefix, no_checkout);
 
-	bisect_rev_setup(&revs, prefix, "%s", "^%s", 1);
+	bisect_rev_setup(r, &revs, prefix, "%s", "^%s", 1);
 	revs.limited = 1;
 
 	bisect_common(&revs);
@@ -982,11 +989,11 @@ int bisect_next_all(const char *prefix,
 
 	bisect_rev = &revs.commits->item->object.oid;
 
-	if (!oidcmp(bisect_rev, current_bad_oid)) {
+	if (oideq(bisect_rev, current_bad_oid)) {
 		exit_if_skipped_commits(tried, current_bad_oid);
 		printf("%s is the first %s commit\n", oid_to_hex(bisect_rev),
 			term_bad);
-		show_diff_tree(prefix, revs.commits->item);
+		show_diff_tree(r, prefix, revs.commits->item);
 		/* This means the bisection process succeeded. */
 		exit(10);
 	}
diff -pruN 1.2.1+git2.18.0-1/git/bisect.h 1.2.3+git2.25.1-1/git/bisect.h
--- 1.2.1+git2.18.0-1/git/bisect.h	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/bisect.h	2020-02-17 04:47:35.000000000 +0000
@@ -1,6 +1,9 @@
 #ifndef BISECT_H
 #define BISECT_H
 
+struct commit_list;
+struct repository;
+
 /*
  * Find bisection. If something is found, `reaches` will be the number of
  * commits that the best commit reaches. `all` will be the count of
@@ -8,14 +11,14 @@
  * Otherwise, it will be either all non-SAMETREE commits or the single
  * best commit, as chosen by `find_all`.
  */
-extern void find_bisection(struct commit_list **list, int *reaches, int *all,
-			   int find_all);
+void find_bisection(struct commit_list **list, int *reaches, int *all,
+		    int find_all);
 
-extern struct commit_list *filter_skipped(struct commit_list *list,
-					  struct commit_list **tried,
-					  int show_all,
-					  int *count,
-					  int *skipped_first);
+struct commit_list *filter_skipped(struct commit_list *list,
+				   struct commit_list **tried,
+				   int show_all,
+				   int *count,
+				   int *skipped_first);
 
 #define BISECT_SHOW_ALL		(1<<0)
 #define REV_LIST_QUIET		(1<<1)
@@ -28,12 +31,14 @@ struct rev_list_info {
 	const char *header_prefix;
 };
 
-extern int bisect_next_all(const char *prefix, int no_checkout);
+int bisect_next_all(struct repository *r,
+		    const char *prefix,
+		    int no_checkout);
 
-extern int estimate_bisect_steps(int all);
+int estimate_bisect_steps(int all);
 
-extern void read_bisect_terms(const char **bad, const char **good);
+void read_bisect_terms(const char **bad, const char **good);
 
-extern int bisect_clean_state(void);
+int bisect_clean_state(void);
 
 #endif
diff -pruN 1.2.1+git2.18.0-1/git/blame.c 1.2.3+git2.25.1-1/git/blame.c
--- 1.2.1+git2.18.0-1/git/blame.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/blame.c	2020-02-17 04:47:35.000000000 +0000
@@ -1,11 +1,31 @@
 #include "cache.h"
 #include "refs.h"
+#include "object-store.h"
 #include "cache-tree.h"
 #include "mergesort.h"
 #include "diff.h"
 #include "diffcore.h"
 #include "tag.h"
 #include "blame.h"
+#include "alloc.h"
+#include "commit-slab.h"
+
+define_commit_slab(blame_suspects, struct blame_origin *);
+static struct blame_suspects blame_suspects;
+
+struct blame_origin *get_blame_suspects(struct commit *commit)
+{
+	struct blame_origin **result;
+
+	result = blame_suspects_peek(&blame_suspects, commit);
+
+	return result ? *result : NULL;
+}
+
+static void set_blame_suspects(struct commit *commit, struct blame_origin *origin)
+{
+	*blame_suspects_at(&blame_suspects, commit) = origin;
+}
 
 void blame_origin_decref(struct blame_origin *o)
 {
@@ -15,12 +35,12 @@ void blame_origin_decref(struct blame_or
 			blame_origin_decref(o->previous);
 		free(o->file.ptr);
 		/* Should be present exactly once in commit chain */
-		for (p = o->commit->util; p; l = p, p = p->next) {
+		for (p = get_blame_suspects(o->commit); p; l = p, p = p->next) {
 			if (p == o) {
 				if (l)
 					l->next = p->next;
 				else
-					o->commit->util = p->next;
+					set_blame_suspects(o->commit, p->next);
 				free(o);
 				return;
 			}
@@ -41,8 +61,8 @@ static struct blame_origin *make_origin(
 	FLEX_ALLOC_STR(o, path, path);
 	o->commit = commit;
 	o->refcnt = 1;
-	o->next = commit->util;
-	commit->util = o;
+	o->next = get_blame_suspects(commit);
+	set_blame_suspects(commit, o);
 	return o;
 }
 
@@ -54,13 +74,13 @@ static struct blame_origin *get_origin(s
 {
 	struct blame_origin *o, *l;
 
-	for (o = commit->util, l = NULL; o; l = o, o = o->next) {
+	for (o = get_blame_suspects(commit), l = NULL; o; l = o, o = o->next) {
 		if (!strcmp(o->path, path)) {
 			/* bump to front */
 			if (l) {
 				l->next = o->next;
-				o->next = commit->util;
-				commit->util = o;
+				o->next = get_blame_suspects(commit);
+				set_blame_suspects(commit, o);
 			}
 			return blame_origin_incref(o);
 		}
@@ -70,7 +90,8 @@ static struct blame_origin *get_origin(s
 
 
 
-static void verify_working_tree_path(struct commit *work_tree, const char *path)
+static void verify_working_tree_path(struct repository *r,
+				     struct commit *work_tree, const char *path)
 {
 	struct commit_list *parents;
 	int pos;
@@ -78,50 +99,55 @@ static void verify_working_tree_path(str
 	for (parents = work_tree->parents; parents; parents = parents->next) {
 		const struct object_id *commit_oid = &parents->item->object.oid;
 		struct object_id blob_oid;
-		unsigned mode;
+		unsigned short mode;
 
-		if (!get_tree_entry(commit_oid, path, &blob_oid, &mode) &&
-		    oid_object_info(the_repository, &blob_oid, NULL) == OBJ_BLOB)
+		if (!get_tree_entry(r, commit_oid, path, &blob_oid, &mode) &&
+		    oid_object_info(r, &blob_oid, NULL) == OBJ_BLOB)
 			return;
 	}
 
-	pos = cache_name_pos(path, strlen(path));
+	pos = index_name_pos(r->index, path, strlen(path));
 	if (pos >= 0)
 		; /* path is in the index */
-	else if (-1 - pos < active_nr &&
-		 !strcmp(active_cache[-1 - pos]->name, path))
+	else if (-1 - pos < r->index->cache_nr &&
+		 !strcmp(r->index->cache[-1 - pos]->name, path))
 		; /* path is in the index, unmerged */
 	else
 		die("no such path '%s' in HEAD", path);
 }
 
-static struct commit_list **append_parent(struct commit_list **tail, const struct object_id *oid)
+static struct commit_list **append_parent(struct repository *r,
+					  struct commit_list **tail,
+					  const struct object_id *oid)
 {
 	struct commit *parent;
 
-	parent = lookup_commit_reference(oid);
+	parent = lookup_commit_reference(r, oid);
 	if (!parent)
 		die("no such commit %s", oid_to_hex(oid));
 	return &commit_list_insert(parent, tail)->next;
 }
 
-static void append_merge_parents(struct commit_list **tail)
+static void append_merge_parents(struct repository *r,
+				 struct commit_list **tail)
 {
 	int merge_head;
 	struct strbuf line = STRBUF_INIT;
 
-	merge_head = open(git_path_merge_head(), O_RDONLY);
+	merge_head = open(git_path_merge_head(r), O_RDONLY);
 	if (merge_head < 0) {
 		if (errno == ENOENT)
 			return;
-		die("cannot open '%s' for reading", git_path_merge_head());
+		die("cannot open '%s' for reading",
+		    git_path_merge_head(r));
 	}
 
 	while (!strbuf_getwholeline_fd(&line, merge_head, '\n')) {
 		struct object_id oid;
-		if (line.len < GIT_SHA1_HEXSZ || get_oid_hex(line.buf, &oid))
-			die("unknown line in '%s': %s", git_path_merge_head(), line.buf);
-		tail = append_parent(tail, &oid);
+		if (get_oid_hex(line.buf, &oid))
+			die("unknown line in '%s': %s",
+			    git_path_merge_head(r), line.buf);
+		tail = append_parent(r, tail, &oid);
 	}
 	close(merge_head);
 	strbuf_release(&line);
@@ -132,18 +158,21 @@ static void append_merge_parents(struct
  * want to transfer ownership of the buffer to the commit (so we
  * must use detach).
  */
-static void set_commit_buffer_from_strbuf(struct commit *c, struct strbuf *sb)
+static void set_commit_buffer_from_strbuf(struct repository *r,
+					  struct commit *c,
+					  struct strbuf *sb)
 {
 	size_t len;
 	void *buf = strbuf_detach(sb, &len);
-	set_commit_buffer(c, buf, len);
+	set_commit_buffer(r, c, buf, len);
 }
 
 /*
  * Prepare a dummy commit that represents the work tree (or staged) item.
  * Note that annotating work tree item never works in the reverse.
  */
-static struct commit *fake_working_tree_commit(struct diff_options *opt,
+static struct commit *fake_working_tree_commit(struct repository *r,
+					       struct diff_options *opt,
 					       const char *path,
 					       const char *contents_from)
 {
@@ -154,14 +183,14 @@ static struct commit *fake_working_tree_
 	struct strbuf buf = STRBUF_INIT;
 	const char *ident;
 	time_t now;
-	int size, len;
+	int len;
 	struct cache_entry *ce;
 	unsigned mode;
 	struct strbuf msg = STRBUF_INIT;
 
-	read_cache();
+	repo_read_index(r);
 	time(&now);
-	commit = alloc_commit_node();
+	commit = alloc_commit_node(r);
 	commit->object.parsed = 1;
 	commit->date = now;
 	parent_tail = &commit->parents;
@@ -169,13 +198,14 @@ static struct commit *fake_working_tree_
 	if (!resolve_ref_unsafe("HEAD", RESOLVE_REF_READING, &head_oid, NULL))
 		die("no such ref: HEAD");
 
-	parent_tail = append_parent(parent_tail, &head_oid);
-	append_merge_parents(parent_tail);
-	verify_working_tree_path(commit, path);
+	parent_tail = append_parent(r, parent_tail, &head_oid);
+	append_merge_parents(r, parent_tail);
+	verify_working_tree_path(r, commit, path);
 
 	origin = make_origin(commit, path);
 
-	ident = fmt_ident("Not Committed Yet", "not.committed.yet", NULL, 0);
+	ident = fmt_ident("Not Committed Yet", "not.committed.yet",
+			WANT_BLANK_IDENT, NULL, 0);
 	strbuf_addstr(&msg, "tree 0000000000000000000000000000000000000000\n");
 	for (parent = commit->parents; parent; parent = parent->next)
 		strbuf_addf(&msg, "parent %s\n",
@@ -187,7 +217,7 @@ static struct commit *fake_working_tree_
 		    ident, ident, path,
 		    (!contents_from ? path :
 		     (!strcmp(contents_from, "-") ? "standard input" : contents_from)));
-	set_commit_buffer_from_strbuf(commit, &msg);
+	set_commit_buffer_from_strbuf(r, commit, &msg);
 
 	if (!contents_from || strcmp("-", contents_from)) {
 		struct stat st;
@@ -210,7 +240,7 @@ static struct commit *fake_working_tree_
 		switch (st.st_mode & S_IFMT) {
 		case S_IFREG:
 			if (opt->flags.allow_textconv &&
-			    textconv_object(read_from, mode, &null_oid, 0, &buf_ptr, &buf_len))
+			    textconv_object(r, read_from, mode, &null_oid, 0, &buf_ptr, &buf_len))
 				strbuf_attach(&buf, buf_ptr, buf_len, buf_len + 1);
 			else if (strbuf_read_file(&buf, read_from, st.st_size) != st.st_size)
 				die_errno("cannot open or read '%s'", read_from);
@@ -229,7 +259,7 @@ static struct commit *fake_working_tree_
 		if (strbuf_read(&buf, 0, 0) < 0)
 			die_errno("failed to read from stdin");
 	}
-	convert_to_git(&the_index, path, buf.buf, buf.len, &buf, 0);
+	convert_to_git(r->index, path, buf.buf, buf.len, &buf, 0);
 	origin->file.ptr = buf.buf;
 	origin->file.size = buf.len;
 	pretend_object_file(buf.buf, buf.len, OBJ_BLOB, &origin->blob_oid);
@@ -240,28 +270,28 @@ static struct commit *fake_working_tree_
 	 * bits; we are not going to write this index out -- we just
 	 * want to run "diff-index --cached".
 	 */
-	discard_cache();
-	read_cache();
+	discard_index(r->index);
+	repo_read_index(r);
 
 	len = strlen(path);
 	if (!mode) {
-		int pos = cache_name_pos(path, len);
+		int pos = index_name_pos(r->index, path, len);
 		if (0 <= pos)
-			mode = active_cache[pos]->ce_mode;
+			mode = r->index->cache[pos]->ce_mode;
 		else
 			/* Let's not bother reading from HEAD tree */
 			mode = S_IFREG | 0644;
 	}
-	size = cache_entry_size(len);
-	ce = xcalloc(1, size);
+	ce = make_empty_cache_entry(r->index, len);
 	oidcpy(&ce->oid, &origin->blob_oid);
 	memcpy(ce->name, path, len);
 	ce->ce_flags = create_ce_flags(0);
 	ce->ce_namelen = len;
 	ce->ce_mode = create_ce_mode(mode);
-	add_cache_entry(ce, ADD_CACHE_OK_TO_ADD|ADD_CACHE_OK_TO_REPLACE);
+	add_index_entry(r->index, ce,
+			ADD_CACHE_OK_TO_ADD | ADD_CACHE_OK_TO_REPLACE);
 
-	cache_tree_invalidate_path(&the_index, path);
+	cache_tree_invalidate_path(r->index, path);
 
 	return commit;
 }
@@ -281,12 +311,710 @@ static int diff_hunks(mmfile_t *file_a,
 	return xdi_diff(file_a, file_b, &xpp, &xecfg, &ecb);
 }
 
+static const char *get_next_line(const char *start, const char *end)
+{
+	const char *nl = memchr(start, '\n', end - start);
+
+	return nl ? nl + 1 : end;
+}
+
+static int find_line_starts(int **line_starts, const char *buf,
+			    unsigned long len)
+{
+	const char *end = buf + len;
+	const char *p;
+	int *lineno;
+	int num = 0;
+
+	for (p = buf; p < end; p = get_next_line(p, end))
+		num++;
+
+	ALLOC_ARRAY(*line_starts, num + 1);
+	lineno = *line_starts;
+
+	for (p = buf; p < end; p = get_next_line(p, end))
+		*lineno++ = p - buf;
+
+	*lineno = len;
+
+	return num;
+}
+
+struct fingerprint_entry;
+
+/* A fingerprint is intended to loosely represent a string, such that two
+ * fingerprints can be quickly compared to give an indication of the similarity
+ * of the strings that they represent.
+ *
+ * A fingerprint is represented as a multiset of the lower-cased byte pairs in
+ * the string that it represents. Whitespace is added at each end of the
+ * string. Whitespace pairs are ignored. Whitespace is converted to '\0'.
+ * For example, the string "Darth   Radar" will be converted to the following
+ * fingerprint:
+ * {"\0d", "da", "da", "ar", "ar", "rt", "th", "h\0", "\0r", "ra", "ad", "r\0"}
+ *
+ * The similarity between two fingerprints is the size of the intersection of
+ * their multisets, including repeated elements. See fingerprint_similarity for
+ * examples.
+ *
+ * For ease of implementation, the fingerprint is implemented as a map
+ * of byte pairs to the count of that byte pair in the string, instead of
+ * allowing repeated elements in a set.
+ */
+struct fingerprint {
+	struct hashmap map;
+	/* As we know the maximum number of entries in advance, it's
+	 * convenient to store the entries in a single array instead of having
+	 * the hashmap manage the memory.
+	 */
+	struct fingerprint_entry *entries;
+};
+
+/* A byte pair in a fingerprint. Stores the number of times the byte pair
+ * occurs in the string that the fingerprint represents.
+ */
+struct fingerprint_entry {
+	/* The hashmap entry - the hash represents the byte pair in its
+	 * entirety so we don't need to store the byte pair separately.
+	 */
+	struct hashmap_entry entry;
+	/* The number of times the byte pair occurs in the string that the
+	 * fingerprint represents.
+	 */
+	int count;
+};
+
+/* See `struct fingerprint` for an explanation of what a fingerprint is.
+ * \param result the fingerprint of the string is stored here. This must be
+ * 		 freed later using free_fingerprint.
+ * \param line_begin the start of the string
+ * \param line_end the end of the string
+ */
+static void get_fingerprint(struct fingerprint *result,
+			    const char *line_begin,
+			    const char *line_end)
+{
+	unsigned int hash, c0 = 0, c1;
+	const char *p;
+	int max_map_entry_count = 1 + line_end - line_begin;
+	struct fingerprint_entry *entry = xcalloc(max_map_entry_count,
+		sizeof(struct fingerprint_entry));
+	struct fingerprint_entry *found_entry;
+
+	hashmap_init(&result->map, NULL, NULL, max_map_entry_count);
+	result->entries = entry;
+	for (p = line_begin; p <= line_end; ++p, c0 = c1) {
+		/* Always terminate the string with whitespace.
+		 * Normalise whitespace to 0, and normalise letters to
+		 * lower case. This won't work for multibyte characters but at
+		 * worst will match some unrelated characters.
+		 */
+		if ((p == line_end) || isspace(*p))
+			c1 = 0;
+		else
+			c1 = tolower(*p);
+		hash = c0 | (c1 << 8);
+		/* Ignore whitespace pairs */
+		if (hash == 0)
+			continue;
+		hashmap_entry_init(&entry->entry, hash);
+
+		found_entry = hashmap_get_entry(&result->map, entry,
+						/* member name */ entry, NULL);
+		if (found_entry) {
+			found_entry->count += 1;
+		} else {
+			entry->count = 1;
+			hashmap_add(&result->map, &entry->entry);
+			++entry;
+		}
+	}
+}
+
+static void free_fingerprint(struct fingerprint *f)
+{
+	hashmap_free(&f->map);
+	free(f->entries);
+}
+
+/* Calculates the similarity between two fingerprints as the size of the
+ * intersection of their multisets, including repeated elements. See
+ * `struct fingerprint` for an explanation of the fingerprint representation.
+ * The similarity between "cat mat" and "father rather" is 2 because "at" is
+ * present twice in both strings while the similarity between "tim" and "mit"
+ * is 0.
+ */
+static int fingerprint_similarity(struct fingerprint *a, struct fingerprint *b)
+{
+	int intersection = 0;
+	struct hashmap_iter iter;
+	const struct fingerprint_entry *entry_a, *entry_b;
+
+	hashmap_for_each_entry(&b->map, &iter, entry_b,
+				entry /* member name */) {
+		entry_a = hashmap_get_entry(&a->map, entry_b, entry, NULL);
+		if (entry_a) {
+			intersection += entry_a->count < entry_b->count ?
+					entry_a->count : entry_b->count;
+		}
+	}
+	return intersection;
+}
+
+/* Subtracts byte-pair elements in B from A, modifying A in place.
+ */
+static void fingerprint_subtract(struct fingerprint *a, struct fingerprint *b)
+{
+	struct hashmap_iter iter;
+	struct fingerprint_entry *entry_a;
+	const struct fingerprint_entry *entry_b;
+
+	hashmap_iter_init(&b->map, &iter);
+
+	hashmap_for_each_entry(&b->map, &iter, entry_b,
+				entry /* member name */) {
+		entry_a = hashmap_get_entry(&a->map, entry_b, entry, NULL);
+		if (entry_a) {
+			if (entry_a->count <= entry_b->count)
+				hashmap_remove(&a->map, &entry_b->entry, NULL);
+			else
+				entry_a->count -= entry_b->count;
+		}
+	}
+}
+
+/* Calculate fingerprints for a series of lines.
+ * Puts the fingerprints in the fingerprints array, which must have been
+ * preallocated to allow storing line_count elements.
+ */
+static void get_line_fingerprints(struct fingerprint *fingerprints,
+				  const char *content, const int *line_starts,
+				  long first_line, long line_count)
+{
+	int i;
+	const char *linestart, *lineend;
+
+	line_starts += first_line;
+	for (i = 0; i < line_count; ++i) {
+		linestart = content + line_starts[i];
+		lineend = content + line_starts[i + 1];
+		get_fingerprint(fingerprints + i, linestart, lineend);
+	}
+}
+
+static void free_line_fingerprints(struct fingerprint *fingerprints,
+				   int nr_fingerprints)
+{
+	int i;
+
+	for (i = 0; i < nr_fingerprints; i++)
+		free_fingerprint(&fingerprints[i]);
+}
+
+/* This contains the data necessary to linearly map a line number in one half
+ * of a diff chunk to the line in the other half of the diff chunk that is
+ * closest in terms of its position as a fraction of the length of the chunk.
+ */
+struct line_number_mapping {
+	int destination_start, destination_length,
+		source_start, source_length;
+};
+
+/* Given a line number in one range, offset and scale it to map it onto the
+ * other range.
+ * Essentially this mapping is a simple linear equation but the calculation is
+ * more complicated to allow performing it with integer operations.
+ * Another complication is that if a line could map onto many lines in the
+ * destination range then we want to choose the line at the center of those
+ * possibilities.
+ * Example: if the chunk is 2 lines long in A and 10 lines long in B then the
+ * first 5 lines in B will map onto the first line in the A chunk, while the
+ * last 5 lines will all map onto the second line in the A chunk.
+ * Example: if the chunk is 10 lines long in A and 2 lines long in B then line
+ * 0 in B will map onto line 2 in A, and line 1 in B will map onto line 7 in A.
+ */
+static int map_line_number(int line_number,
+	const struct line_number_mapping *mapping)
+{
+	return ((line_number - mapping->source_start) * 2 + 1) *
+	       mapping->destination_length /
+	       (mapping->source_length * 2) +
+	       mapping->destination_start;
+}
+
+/* Get a pointer to the element storing the similarity between a line in A
+ * and a line in B.
+ *
+ * The similarities are stored in a 2-dimensional array. Each "row" in the
+ * array contains the similarities for a line in B. The similarities stored in
+ * a row are the similarities between the line in B and the nearby lines in A.
+ * To keep the length of each row the same, it is padded out with values of -1
+ * where the search range extends beyond the lines in A.
+ * For example, if max_search_distance_a is 2 and the two sides of a diff chunk
+ * look like this:
+ * a | m
+ * b | n
+ * c | o
+ * d | p
+ * e | q
+ * Then the similarity array will contain:
+ * [-1, -1, am, bm, cm,
+ *  -1, an, bn, cn, dn,
+ *  ao, bo, co, do, eo,
+ *  bp, cp, dp, ep, -1,
+ *  cq, dq, eq, -1, -1]
+ * Where similarities are denoted either by -1 for invalid, or the
+ * concatenation of the two lines in the diff being compared.
+ *
+ * \param similarities array of similarities between lines in A and B
+ * \param line_a the index of the line in A, in the same frame of reference as
+ *	closest_line_a.
+ * \param local_line_b the index of the line in B, relative to the first line
+ *		       in B that similarities represents.
+ * \param closest_line_a the index of the line in A that is deemed to be
+ *			 closest to local_line_b. This must be in the same
+ *			 frame of reference as line_a. This value defines
+ *			 where similarities is centered for the line in B.
+ * \param max_search_distance_a maximum distance in lines from the closest line
+ * 				in A for other lines in A for which
+ * 				similarities may be calculated.
+ */
+static int *get_similarity(int *similarities,
+			   int line_a, int local_line_b,
+			   int closest_line_a, int max_search_distance_a)
+{
+	assert(abs(line_a - closest_line_a) <=
+	       max_search_distance_a);
+	return similarities + line_a - closest_line_a +
+	       max_search_distance_a +
+	       local_line_b * (max_search_distance_a * 2 + 1);
+}
+
+#define CERTAIN_NOTHING_MATCHES -2
+#define CERTAINTY_NOT_CALCULATED -1
+
+/* Given a line in B, first calculate its similarities with nearby lines in A
+ * if not already calculated, then identify the most similar and second most
+ * similar lines. The "certainty" is calculated based on those two
+ * similarities.
+ *
+ * \param start_a the index of the first line of the chunk in A
+ * \param length_a the length in lines of the chunk in A
+ * \param local_line_b the index of the line in B, relative to the first line
+ * 		       in the chunk.
+ * \param fingerprints_a array of fingerprints for the chunk in A
+ * \param fingerprints_b array of fingerprints for the chunk in B
+ * \param similarities 2-dimensional array of similarities between lines in A
+ * 		       and B. See get_similarity() for more details.
+ * \param certainties array of values indicating how strongly a line in B is
+ * 		      matched with some line in A.
+ * \param second_best_result array of absolute indices in A for the second
+ * 			     closest match of a line in B.
+ * \param result array of absolute indices in A for the closest match of a line
+ * 		 in B.
+ * \param max_search_distance_a maximum distance in lines from the closest line
+ * 				in A for other lines in A for which
+ * 				similarities may be calculated.
+ * \param map_line_number_in_b_to_a parameter to map_line_number().
+ */
+static void find_best_line_matches(
+	int start_a,
+	int length_a,
+	int start_b,
+	int local_line_b,
+	struct fingerprint *fingerprints_a,
+	struct fingerprint *fingerprints_b,
+	int *similarities,
+	int *certainties,
+	int *second_best_result,
+	int *result,
+	const int max_search_distance_a,
+	const struct line_number_mapping *map_line_number_in_b_to_a)
+{
+
+	int i, search_start, search_end, closest_local_line_a, *similarity,
+		best_similarity = 0, second_best_similarity = 0,
+		best_similarity_index = 0, second_best_similarity_index = 0;
+
+	/* certainty has already been calculated so no need to redo the work */
+	if (certainties[local_line_b] != CERTAINTY_NOT_CALCULATED)
+		return;
+
+	closest_local_line_a = map_line_number(
+		local_line_b + start_b, map_line_number_in_b_to_a) - start_a;
+
+	search_start = closest_local_line_a - max_search_distance_a;
+	if (search_start < 0)
+		search_start = 0;
+
+	search_end = closest_local_line_a + max_search_distance_a + 1;
+	if (search_end > length_a)
+		search_end = length_a;
+
+	for (i = search_start; i < search_end; ++i) {
+		similarity = get_similarity(similarities,
+					    i, local_line_b,
+					    closest_local_line_a,
+					    max_search_distance_a);
+		if (*similarity == -1) {
+			/* This value will never exceed 10 but assert just in
+			 * case
+			 */
+			assert(abs(i - closest_local_line_a) < 1000);
+			/* scale the similarity by (1000 - distance from
+			 * closest line) to act as a tie break between lines
+			 * that otherwise are equally similar.
+			 */
+			*similarity = fingerprint_similarity(
+				fingerprints_b + local_line_b,
+				fingerprints_a + i) *
+				(1000 - abs(i - closest_local_line_a));
+		}
+		if (*similarity > best_similarity) {
+			second_best_similarity = best_similarity;
+			second_best_similarity_index = best_similarity_index;
+			best_similarity = *similarity;
+			best_similarity_index = i;
+		} else if (*similarity > second_best_similarity) {
+			second_best_similarity = *similarity;
+			second_best_similarity_index = i;
+		}
+	}
+
+	if (best_similarity == 0) {
+		/* this line definitely doesn't match with anything. Mark it
+		 * with this special value so it doesn't get invalidated and
+		 * won't be recalculated.
+		 */
+		certainties[local_line_b] = CERTAIN_NOTHING_MATCHES;
+		result[local_line_b] = -1;
+	} else {
+		/* Calculate the certainty with which this line matches.
+		 * If the line matches well with two lines then that reduces
+		 * the certainty. However we still want to prioritise matching
+		 * a line that matches very well with two lines over matching a
+		 * line that matches poorly with one line, hence doubling
+		 * best_similarity.
+		 * This means that if we have
+		 * line X that matches only one line with a score of 3,
+		 * line Y that matches two lines equally with a score of 5,
+		 * and line Z that matches only one line with a score or 2,
+		 * then the lines in order of certainty are X, Y, Z.
+		 */
+		certainties[local_line_b] = best_similarity * 2 -
+			second_best_similarity;
+
+		/* We keep both the best and second best results to allow us to
+		 * check at a later stage of the matching process whether the
+		 * result needs to be invalidated.
+		 */
+		result[local_line_b] = start_a + best_similarity_index;
+		second_best_result[local_line_b] =
+			start_a + second_best_similarity_index;
+	}
+}
+
+/*
+ * This finds the line that we can match with the most confidence, and
+ * uses it as a partition. It then calls itself on the lines on either side of
+ * that partition. In this way we avoid lines appearing out of order, and
+ * retain a sensible line ordering.
+ * \param start_a index of the first line in A with which lines in B may be
+ * 		  compared.
+ * \param start_b index of the first line in B for which matching should be
+ * 		  done.
+ * \param length_a number of lines in A with which lines in B may be compared.
+ * \param length_b number of lines in B for which matching should be done.
+ * \param fingerprints_a mutable array of fingerprints in A. The first element
+ * 			 corresponds to the line at start_a.
+ * \param fingerprints_b array of fingerprints in B. The first element
+ * 			 corresponds to the line at start_b.
+ * \param similarities 2-dimensional array of similarities between lines in A
+ * 		       and B. See get_similarity() for more details.
+ * \param certainties array of values indicating how strongly a line in B is
+ * 		      matched with some line in A.
+ * \param second_best_result array of absolute indices in A for the second
+ * 			     closest match of a line in B.
+ * \param result array of absolute indices in A for the closest match of a line
+ * 		 in B.
+ * \param max_search_distance_a maximum distance in lines from the closest line
+ * 			      in A for other lines in A for which
+ * 			      similarities may be calculated.
+ * \param max_search_distance_b an upper bound on the greatest possible
+ * 			      distance between lines in B such that they will
+ *                              both be compared with the same line in A
+ * 			      according to max_search_distance_a.
+ * \param map_line_number_in_b_to_a parameter to map_line_number().
+ */
+static void fuzzy_find_matching_lines_recurse(
+	int start_a, int start_b,
+	int length_a, int length_b,
+	struct fingerprint *fingerprints_a,
+	struct fingerprint *fingerprints_b,
+	int *similarities,
+	int *certainties,
+	int *second_best_result,
+	int *result,
+	int max_search_distance_a,
+	int max_search_distance_b,
+	const struct line_number_mapping *map_line_number_in_b_to_a)
+{
+	int i, invalidate_min, invalidate_max, offset_b,
+		second_half_start_a, second_half_start_b,
+		second_half_length_a, second_half_length_b,
+		most_certain_line_a, most_certain_local_line_b = -1,
+		most_certain_line_certainty = -1,
+		closest_local_line_a;
+
+	for (i = 0; i < length_b; ++i) {
+		find_best_line_matches(start_a,
+				       length_a,
+				       start_b,
+				       i,
+				       fingerprints_a,
+				       fingerprints_b,
+				       similarities,
+				       certainties,
+				       second_best_result,
+				       result,
+				       max_search_distance_a,
+				       map_line_number_in_b_to_a);
+
+		if (certainties[i] > most_certain_line_certainty) {
+			most_certain_line_certainty = certainties[i];
+			most_certain_local_line_b = i;
+		}
+	}
+
+	/* No matches. */
+	if (most_certain_local_line_b == -1)
+		return;
+
+	most_certain_line_a = result[most_certain_local_line_b];
+
+	/*
+	 * Subtract the most certain line's fingerprint in B from the matched
+	 * fingerprint in A. This means that other lines in B can't also match
+	 * the same parts of the line in A.
+	 */
+	fingerprint_subtract(fingerprints_a + most_certain_line_a - start_a,
+			     fingerprints_b + most_certain_local_line_b);
+
+	/* Invalidate results that may be affected by the choice of most
+	 * certain line.
+	 */
+	invalidate_min = most_certain_local_line_b - max_search_distance_b;
+	invalidate_max = most_certain_local_line_b + max_search_distance_b + 1;
+	if (invalidate_min < 0)
+		invalidate_min = 0;
+	if (invalidate_max > length_b)
+		invalidate_max = length_b;
+
+	/* As the fingerprint in A has changed, discard previously calculated
+	 * similarity values with that fingerprint.
+	 */
+	for (i = invalidate_min; i < invalidate_max; ++i) {
+		closest_local_line_a = map_line_number(
+			i + start_b, map_line_number_in_b_to_a) - start_a;
+
+		/* Check that the lines in A and B are close enough that there
+		 * is a similarity value for them.
+		 */
+		if (abs(most_certain_line_a - start_a - closest_local_line_a) >
+			max_search_distance_a) {
+			continue;
+		}
+
+		*get_similarity(similarities, most_certain_line_a - start_a,
+				i, closest_local_line_a,
+				max_search_distance_a) = -1;
+	}
+
+	/* More invalidating of results that may be affected by the choice of
+	 * most certain line.
+	 * Discard the matches for lines in B that are currently matched with a
+	 * line in A such that their ordering contradicts the ordering imposed
+	 * by the choice of most certain line.
+	 */
+	for (i = most_certain_local_line_b - 1; i >= invalidate_min; --i) {
+		/* In this loop we discard results for lines in B that are
+		 * before most-certain-line-B but are matched with a line in A
+		 * that is after most-certain-line-A.
+		 */
+		if (certainties[i] >= 0 &&
+		    (result[i] >= most_certain_line_a ||
+		     second_best_result[i] >= most_certain_line_a)) {
+			certainties[i] = CERTAINTY_NOT_CALCULATED;
+		}
+	}
+	for (i = most_certain_local_line_b + 1; i < invalidate_max; ++i) {
+		/* In this loop we discard results for lines in B that are
+		 * after most-certain-line-B but are matched with a line in A
+		 * that is before most-certain-line-A.
+		 */
+		if (certainties[i] >= 0 &&
+		    (result[i] <= most_certain_line_a ||
+		     second_best_result[i] <= most_certain_line_a)) {
+			certainties[i] = CERTAINTY_NOT_CALCULATED;
+		}
+	}
+
+	/* Repeat the matching process for lines before the most certain line.
+	 */
+	if (most_certain_local_line_b > 0) {
+		fuzzy_find_matching_lines_recurse(
+			start_a, start_b,
+			most_certain_line_a + 1 - start_a,
+			most_certain_local_line_b,
+			fingerprints_a, fingerprints_b, similarities,
+			certainties, second_best_result, result,
+			max_search_distance_a,
+			max_search_distance_b,
+			map_line_number_in_b_to_a);
+	}
+	/* Repeat the matching process for lines after the most certain line.
+	 */
+	if (most_certain_local_line_b + 1 < length_b) {
+		second_half_start_a = most_certain_line_a;
+		offset_b = most_certain_local_line_b + 1;
+		second_half_start_b = start_b + offset_b;
+		second_half_length_a =
+			length_a + start_a - second_half_start_a;
+		second_half_length_b =
+			length_b + start_b - second_half_start_b;
+		fuzzy_find_matching_lines_recurse(
+			second_half_start_a, second_half_start_b,
+			second_half_length_a, second_half_length_b,
+			fingerprints_a + second_half_start_a - start_a,
+			fingerprints_b + offset_b,
+			similarities +
+				offset_b * (max_search_distance_a * 2 + 1),
+			certainties + offset_b,
+			second_best_result + offset_b, result + offset_b,
+			max_search_distance_a,
+			max_search_distance_b,
+			map_line_number_in_b_to_a);
+	}
+}
+
+/* Find the lines in the parent line range that most closely match the lines in
+ * the target line range. This is accomplished by matching fingerprints in each
+ * blame_origin, and choosing the best matches that preserve the line ordering.
+ * See struct fingerprint for details of fingerprint matching, and
+ * fuzzy_find_matching_lines_recurse for details of preserving line ordering.
+ *
+ * The performance is believed to be O(n log n) in the typical case and O(n^2)
+ * in a pathological case, where n is the number of lines in the target range.
+ */
+static int *fuzzy_find_matching_lines(struct blame_origin *parent,
+				      struct blame_origin *target,
+				      int tlno, int parent_slno, int same,
+				      int parent_len)
+{
+	/* We use the terminology "A" for the left hand side of the diff AKA
+	 * parent, and "B" for the right hand side of the diff AKA target. */
+	int start_a = parent_slno;
+	int length_a = parent_len;
+	int start_b = tlno;
+	int length_b = same - tlno;
+
+	struct line_number_mapping map_line_number_in_b_to_a = {
+		start_a, length_a, start_b, length_b
+	};
+
+	struct fingerprint *fingerprints_a = parent->fingerprints;
+	struct fingerprint *fingerprints_b = target->fingerprints;
+
+	int i, *result, *second_best_result,
+		*certainties, *similarities, similarity_count;
+
+	/*
+	 * max_search_distance_a means that given a line in B, compare it to
+	 * the line in A that is closest to its position, and the lines in A
+	 * that are no greater than max_search_distance_a lines away from the
+	 * closest line in A.
+	 *
+	 * max_search_distance_b is an upper bound on the greatest possible
+	 * distance between lines in B such that they will both be compared
+	 * with the same line in A according to max_search_distance_a.
+	 */
+	int max_search_distance_a = 10, max_search_distance_b;
+
+	if (length_a <= 0)
+		return NULL;
+
+	if (max_search_distance_a >= length_a)
+		max_search_distance_a = length_a ? length_a - 1 : 0;
+
+	max_search_distance_b = ((2 * max_search_distance_a + 1) * length_b
+				 - 1) / length_a;
+
+	result = xcalloc(sizeof(int), length_b);
+	second_best_result = xcalloc(sizeof(int), length_b);
+	certainties = xcalloc(sizeof(int), length_b);
+
+	/* See get_similarity() for details of similarities. */
+	similarity_count = length_b * (max_search_distance_a * 2 + 1);
+	similarities = xcalloc(sizeof(int), similarity_count);
+
+	for (i = 0; i < length_b; ++i) {
+		result[i] = -1;
+		second_best_result[i] = -1;
+		certainties[i] = CERTAINTY_NOT_CALCULATED;
+	}
+
+	for (i = 0; i < similarity_count; ++i)
+		similarities[i] = -1;
+
+	fuzzy_find_matching_lines_recurse(start_a, start_b,
+					  length_a, length_b,
+					  fingerprints_a + start_a,
+					  fingerprints_b + start_b,
+					  similarities,
+					  certainties,
+					  second_best_result,
+					  result,
+					  max_search_distance_a,
+					  max_search_distance_b,
+					  &map_line_number_in_b_to_a);
+
+	free(similarities);
+	free(certainties);
+	free(second_best_result);
+
+	return result;
+}
+
+static void fill_origin_fingerprints(struct blame_origin *o)
+{
+	int *line_starts;
+
+	if (o->fingerprints)
+		return;
+	o->num_lines = find_line_starts(&line_starts, o->file.ptr,
+					o->file.size);
+	o->fingerprints = xcalloc(sizeof(struct fingerprint), o->num_lines);
+	get_line_fingerprints(o->fingerprints, o->file.ptr, line_starts,
+			      0, o->num_lines);
+	free(line_starts);
+}
+
+static void drop_origin_fingerprints(struct blame_origin *o)
+{
+	if (o->fingerprints) {
+		free_line_fingerprints(o->fingerprints, o->num_lines);
+		o->num_lines = 0;
+		FREE_AND_NULL(o->fingerprints);
+	}
+}
+
 /*
  * Given an origin, prepare mmfile_t structure to be used by the
  * diff machinery
  */
 static void fill_origin_blob(struct diff_options *opt,
-			     struct blame_origin *o, mmfile_t *file, int *num_read_blob)
+			     struct blame_origin *o, mmfile_t *file,
+			     int *num_read_blob, int fill_fingerprints)
 {
 	if (!o->file.ptr) {
 		enum object_type type;
@@ -294,7 +1022,8 @@ static void fill_origin_blob(struct diff
 
 		(*num_read_blob)++;
 		if (opt->flags.allow_textconv &&
-		    textconv_object(o->path, o->mode, &o->blob_oid, 1, &file->ptr, &file_size))
+		    textconv_object(opt->repo, o->path, o->mode,
+				    &o->blob_oid, 1, &file->ptr, &file_size))
 			;
 		else
 			file->ptr = read_object_file(&o->blob_oid, &type,
@@ -309,13 +1038,14 @@ static void fill_origin_blob(struct diff
 	}
 	else
 		*file = o->file;
+	if (fill_fingerprints)
+		fill_origin_fingerprints(o);
 }
 
 static void drop_origin_blob(struct blame_origin *o)
 {
-	if (o->file.ptr) {
-		FREE_AND_NULL(o->file.ptr);
-	}
+	FREE_AND_NULL(o->file.ptr);
+	drop_origin_fingerprints(o);
 }
 
 /*
@@ -451,7 +1181,9 @@ void blame_coalesce(struct blame_scorebo
 
 	for (ent = sb->ent; ent && (next = ent->next); ent = next) {
 		if (ent->suspect == next->suspect &&
-		    ent->s_lno + ent->num_lines == next->s_lno) {
+		    ent->s_lno + ent->num_lines == next->s_lno &&
+		    ent->ignored == next->ignored &&
+		    ent->unblamable == next->unblamable) {
 			ent->num_lines += next->num_lines;
 			ent->next = next->next;
 			blame_origin_decref(next->suspect);
@@ -478,7 +1210,7 @@ static void queue_blames(struct blame_sc
 		porigin->suspects = blame_merge(porigin->suspects, sorted);
 	else {
 		struct blame_origin *o;
-		for (o = porigin->commit->util; o; o = o->next) {
+		for (o = get_blame_suspects(porigin->commit); o; o = o->next) {
 			if (o->suspects) {
 				porigin->suspects = sorted;
 				return;
@@ -498,13 +1230,14 @@ static void queue_blames(struct blame_sc
  *
  * This also fills origin->mode for corresponding tree path.
  */
-static int fill_blob_sha1_and_mode(struct blame_origin *origin)
+static int fill_blob_sha1_and_mode(struct repository *r,
+				   struct blame_origin *origin)
 {
 	if (!is_null_oid(&origin->blob_oid))
 		return 0;
-	if (get_tree_entry(&origin->commit->object.oid, origin->path, &origin->blob_oid, &origin->mode))
+	if (get_tree_entry(r, &origin->commit->object.oid, origin->path, &origin->blob_oid, &origin->mode))
 		goto error_out;
-	if (oid_object_info(the_repository, &origin->blob_oid, NULL) != OBJ_BLOB)
+	if (oid_object_info(r, &origin->blob_oid, NULL) != OBJ_BLOB)
 		goto error_out;
 	return 0;
  error_out:
@@ -517,15 +1250,16 @@ static int fill_blob_sha1_and_mode(struc
  * We have an origin -- check if the same path exists in the
  * parent and return an origin structure to represent it.
  */
-static struct blame_origin *find_origin(struct commit *parent,
-				  struct blame_origin *origin)
+static struct blame_origin *find_origin(struct repository *r,
+					struct commit *parent,
+					struct blame_origin *origin)
 {
 	struct blame_origin *porigin;
 	struct diff_options diff_opts;
 	const char *paths[2];
 
 	/* First check any existing origins */
-	for (porigin = parent->util; porigin; porigin = porigin->next)
+	for (porigin = get_blame_suspects(parent); porigin; porigin = porigin->next)
 		if (!strcmp(porigin->path, origin->path)) {
 			/*
 			 * The same path between origin and its parent
@@ -538,7 +1272,7 @@ static struct blame_origin *find_origin(
 	 * and origin first.  Most of the time they are the
 	 * same and diff-tree is fairly efficient about this.
 	 */
-	diff_setup(&diff_opts);
+	repo_diff_setup(r, &diff_opts);
 	diff_opts.flags.recursive = 1;
 	diff_opts.detect_rename = 0;
 	diff_opts.output_format = DIFF_FORMAT_NO_OUTPUT;
@@ -605,14 +1339,15 @@ static struct blame_origin *find_origin(
  * We have an origin -- find the path that corresponds to it in its
  * parent and return an origin structure to represent it.
  */
-static struct blame_origin *find_rename(struct commit *parent,
-				  struct blame_origin *origin)
+static struct blame_origin *find_rename(struct repository *r,
+					struct commit *parent,
+					struct blame_origin *origin)
 {
 	struct blame_origin *porigin = NULL;
 	struct diff_options diff_opts;
 	int i;
 
-	diff_setup(&diff_opts);
+	repo_diff_setup(r, &diff_opts);
 	diff_opts.flags.recursive = 1;
 	diff_opts.detect_rename = DIFF_DETECT_RENAME;
 	diff_opts.output_format = DIFF_FORMAT_NO_OUTPUT;
@@ -698,8 +1433,14 @@ static void split_overlap(struct blame_e
 			  struct blame_origin *parent)
 {
 	int chunk_end_lno;
+	int i;
 	memset(split, 0, sizeof(struct blame_entry [3]));
 
+	for (i = 0; i < 3; i++) {
+		split[i].ignored = e->ignored;
+		split[i].unblamable = e->unblamable;
+	}
+
 	if (e->s_lno < tlno) {
 		/* there is a pre-chunk part not blamed on parent */
 		split[0].suspect = blame_origin_incref(e->suspect);
@@ -808,6 +1549,164 @@ static struct blame_entry *reverse_blame
 }
 
 /*
+ * Splits a blame entry into two entries at 'len' lines.  The original 'e'
+ * consists of len lines, i.e. [e->lno, e->lno + len), and the second part,
+ * which is returned, consists of the remainder: [e->lno + len, e->lno +
+ * e->num_lines).  The caller needs to sort out the reference counting for the
+ * new entry's suspect.
+ */
+static struct blame_entry *split_blame_at(struct blame_entry *e, int len,
+					  struct blame_origin *new_suspect)
+{
+	struct blame_entry *n = xcalloc(1, sizeof(struct blame_entry));
+
+	n->suspect = new_suspect;
+	n->ignored = e->ignored;
+	n->unblamable = e->unblamable;
+	n->lno = e->lno + len;
+	n->s_lno = e->s_lno + len;
+	n->num_lines = e->num_lines - len;
+	e->num_lines = len;
+	e->score = 0;
+	return n;
+}
+
+struct blame_line_tracker {
+	int is_parent;
+	int s_lno;
+};
+
+static int are_lines_adjacent(struct blame_line_tracker *first,
+			      struct blame_line_tracker *second)
+{
+	return first->is_parent == second->is_parent &&
+	       first->s_lno + 1 == second->s_lno;
+}
+
+static int scan_parent_range(struct fingerprint *p_fps,
+			     struct fingerprint *t_fps, int t_idx,
+			     int from, int nr_lines)
+{
+	int sim, p_idx;
+	#define FINGERPRINT_FILE_THRESHOLD	10
+	int best_sim_val = FINGERPRINT_FILE_THRESHOLD;
+	int best_sim_idx = -1;
+
+	for (p_idx = from; p_idx < from + nr_lines; p_idx++) {
+		sim = fingerprint_similarity(&t_fps[t_idx], &p_fps[p_idx]);
+		if (sim < best_sim_val)
+			continue;
+		/* Break ties with the closest-to-target line number */
+		if (sim == best_sim_val && best_sim_idx != -1 &&
+		    abs(best_sim_idx - t_idx) < abs(p_idx - t_idx))
+			continue;
+		best_sim_val = sim;
+		best_sim_idx = p_idx;
+	}
+	return best_sim_idx;
+}
+
+/*
+ * The first pass checks the blame entry (from the target) against the parent's
+ * diff chunk.  If that fails for a line, the second pass tries to match that
+ * line to any part of parent file.  That catches cases where a change was
+ * broken into two chunks by 'context.'
+ */
+static void guess_line_blames(struct blame_origin *parent,
+			      struct blame_origin *target,
+			      int tlno, int offset, int same, int parent_len,
+			      struct blame_line_tracker *line_blames)
+{
+	int i, best_idx, target_idx;
+	int parent_slno = tlno + offset;
+	int *fuzzy_matches;
+
+	fuzzy_matches = fuzzy_find_matching_lines(parent, target,
+						  tlno, parent_slno, same,
+						  parent_len);
+	for (i = 0; i < same - tlno; i++) {
+		target_idx = tlno + i;
+		if (fuzzy_matches && fuzzy_matches[i] >= 0) {
+			best_idx = fuzzy_matches[i];
+		} else {
+			best_idx = scan_parent_range(parent->fingerprints,
+						     target->fingerprints,
+						     target_idx, 0,
+						     parent->num_lines);
+		}
+		if (best_idx >= 0) {
+			line_blames[i].is_parent = 1;
+			line_blames[i].s_lno = best_idx;
+		} else {
+			line_blames[i].is_parent = 0;
+			line_blames[i].s_lno = target_idx;
+		}
+	}
+	free(fuzzy_matches);
+}
+
+/*
+ * This decides which parts of a blame entry go to the parent (added to the
+ * ignoredp list) and which stay with the target (added to the diffp list).  The
+ * actual decision was made in a separate heuristic function, and those answers
+ * for the lines in 'e' are in line_blames.  This consumes e, essentially
+ * putting it on a list.
+ *
+ * Note that the blame entries on the ignoredp list are not necessarily sorted
+ * with respect to the parent's line numbers yet.
+ */
+static void ignore_blame_entry(struct blame_entry *e,
+			       struct blame_origin *parent,
+			       struct blame_entry **diffp,
+			       struct blame_entry **ignoredp,
+			       struct blame_line_tracker *line_blames)
+{
+	int entry_len, nr_lines, i;
+
+	/*
+	 * We carve new entries off the front of e.  Each entry comes from a
+	 * contiguous chunk of lines: adjacent lines from the same origin
+	 * (either the parent or the target).
+	 */
+	entry_len = 1;
+	nr_lines = e->num_lines;	/* e changes in the loop */
+	for (i = 0; i < nr_lines; i++) {
+		struct blame_entry *next = NULL;
+
+		/*
+		 * We are often adjacent to the next line - only split the blame
+		 * entry when we have to.
+		 */
+		if (i + 1 < nr_lines) {
+			if (are_lines_adjacent(&line_blames[i],
+					       &line_blames[i + 1])) {
+				entry_len++;
+				continue;
+			}
+			next = split_blame_at(e, entry_len,
+					      blame_origin_incref(e->suspect));
+		}
+		if (line_blames[i].is_parent) {
+			e->ignored = 1;
+			blame_origin_decref(e->suspect);
+			e->suspect = blame_origin_incref(parent);
+			e->s_lno = line_blames[i - entry_len + 1].s_lno;
+			e->next = *ignoredp;
+			*ignoredp = e;
+		} else {
+			e->unblamable = 1;
+			/* e->s_lno is already in the target's address space. */
+			e->next = *diffp;
+			*diffp = e;
+		}
+		assert(e->num_lines == entry_len);
+		e = next;
+		entry_len = 1;
+	}
+	assert(!e);
+}
+
+/*
  * Process one hunk from the patch between the current suspect for
  * blame_entry e and its parent.  This first blames any unfinished
  * entries before the chunk (which is where target and parent start
@@ -816,13 +1715,20 @@ static struct blame_entry *reverse_blame
  * -C options may lead to overlapping/duplicate source line number
  * ranges, all we can rely on from sorting/merging is the order of the
  * first suspect line number.
+ *
+ * tlno: line number in the target where this chunk begins
+ * same: line number in the target where this chunk ends
+ * offset: add to tlno to get the chunk starting point in the parent
+ * parent_len: number of lines in the parent chunk
  */
 static void blame_chunk(struct blame_entry ***dstq, struct blame_entry ***srcq,
-			int tlno, int offset, int same,
-			struct blame_origin *parent)
+			int tlno, int offset, int same, int parent_len,
+			struct blame_origin *parent,
+			struct blame_origin *target, int ignore_diffs)
 {
 	struct blame_entry *e = **srcq;
-	struct blame_entry *samep = NULL, *diffp = NULL;
+	struct blame_entry *samep = NULL, *diffp = NULL, *ignoredp = NULL;
+	struct blame_line_tracker *line_blames = NULL;
 
 	while (e && e->s_lno < tlno) {
 		struct blame_entry *next = e->next;
@@ -833,14 +1739,9 @@ static void blame_chunk(struct blame_ent
 		 */
 		if (e->s_lno + e->num_lines > tlno) {
 			/* Move second half to a new record */
-			int len = tlno - e->s_lno;
-			struct blame_entry *n = xcalloc(1, sizeof (struct blame_entry));
-			n->suspect = e->suspect;
-			n->lno = e->lno + len;
-			n->s_lno = e->s_lno + len;
-			n->num_lines = e->num_lines - len;
-			e->num_lines = len;
-			e->score = 0;
+			struct blame_entry *n;
+
+			n = split_blame_at(e, tlno - e->s_lno, e->suspect);
 			/* Push new record to diffp */
 			n->next = diffp;
 			diffp = n;
@@ -876,6 +1777,14 @@ static void blame_chunk(struct blame_ent
 	 */
 	samep = NULL;
 	diffp = NULL;
+
+	if (ignore_diffs && same - tlno > 0) {
+		line_blames = xcalloc(sizeof(struct blame_line_tracker),
+				      same - tlno);
+		guess_line_blames(parent, target, tlno, offset, same,
+				  parent_len, line_blames);
+	}
+
 	while (e && e->s_lno < same) {
 		struct blame_entry *next = e->next;
 
@@ -887,22 +1796,37 @@ static void blame_chunk(struct blame_ent
 			 * Move second half to a new record to be
 			 * processed by later chunks
 			 */
-			int len = same - e->s_lno;
-			struct blame_entry *n = xcalloc(1, sizeof (struct blame_entry));
-			n->suspect = blame_origin_incref(e->suspect);
-			n->lno = e->lno + len;
-			n->s_lno = e->s_lno + len;
-			n->num_lines = e->num_lines - len;
-			e->num_lines = len;
-			e->score = 0;
+			struct blame_entry *n;
+
+			n = split_blame_at(e, same - e->s_lno,
+					   blame_origin_incref(e->suspect));
 			/* Push new record to samep */
 			n->next = samep;
 			samep = n;
 		}
-		e->next = diffp;
-		diffp = e;
+		if (ignore_diffs) {
+			ignore_blame_entry(e, parent, &diffp, &ignoredp,
+					   line_blames + e->s_lno - tlno);
+		} else {
+			e->next = diffp;
+			diffp = e;
+		}
 		e = next;
 	}
+	free(line_blames);
+	if (ignoredp) {
+		/*
+		 * Note ignoredp is not sorted yet, and thus neither is dstq.
+		 * That list must be sorted before we queue_blames().  We defer
+		 * sorting until after all diff hunks are processed, so that
+		 * guess_line_blames() can pick *any* line in the parent.  The
+		 * slight drawback is that we end up sorting all blame entries
+		 * passed to the parent, including those that are unrelated to
+		 * changes made by the ignored commit.
+		 */
+		**dstq = reverse_blame(ignoredp, **dstq);
+		*dstq = &ignoredp->next;
+	}
 	**srcq = reverse_blame(diffp, reverse_blame(samep, e));
 	/* Move across elements that are in the unblamable portion */
 	if (diffp)
@@ -911,7 +1835,9 @@ static void blame_chunk(struct blame_ent
 
 struct blame_chunk_cb_data {
 	struct blame_origin *parent;
+	struct blame_origin *target;
 	long offset;
+	int ignore_diffs;
 	struct blame_entry **dstq;
 	struct blame_entry **srcq;
 };
@@ -924,7 +1850,8 @@ static int blame_chunk_cb(long start_a,
 	if (start_a - start_b != d->offset)
 		die("internal error in blame::blame_chunk_cb");
 	blame_chunk(&d->dstq, &d->srcq, start_b, start_a - start_b,
-		    start_b + count_b, d->parent);
+		    start_b + count_b, count_a, d->parent, d->target,
+		    d->ignore_diffs);
 	d->offset = start_a + count_a - (start_b + count_b);
 	return 0;
 }
@@ -936,7 +1863,7 @@ static int blame_chunk_cb(long start_a,
  */
 static void pass_blame_to_parent(struct blame_scoreboard *sb,
 				 struct blame_origin *target,
-				 struct blame_origin *parent)
+				 struct blame_origin *parent, int ignore_diffs)
 {
 	mmfile_t file_p, file_o;
 	struct blame_chunk_cb_data d;
@@ -946,11 +1873,15 @@ static void pass_blame_to_parent(struct
 		return; /* nothing remains for this target */
 
 	d.parent = parent;
+	d.target = target;
 	d.offset = 0;
+	d.ignore_diffs = ignore_diffs;
 	d.dstq = &newdest; d.srcq = &target->suspects;
 
-	fill_origin_blob(&sb->revs->diffopt, parent, &file_p, &sb->num_read_blob);
-	fill_origin_blob(&sb->revs->diffopt, target, &file_o, &sb->num_read_blob);
+	fill_origin_blob(&sb->revs->diffopt, parent, &file_p,
+			 &sb->num_read_blob, ignore_diffs);
+	fill_origin_blob(&sb->revs->diffopt, target, &file_o,
+			 &sb->num_read_blob, ignore_diffs);
 	sb->num_get_patch++;
 
 	if (diff_hunks(&file_p, &file_o, blame_chunk_cb, &d, sb->xdl_opts))
@@ -958,8 +1889,13 @@ static void pass_blame_to_parent(struct
 		    oid_to_hex(&parent->commit->object.oid),
 		    oid_to_hex(&target->commit->object.oid));
 	/* The rest are the same as the parent */
-	blame_chunk(&d.dstq, &d.srcq, INT_MAX, d.offset, INT_MAX, parent);
+	blame_chunk(&d.dstq, &d.srcq, INT_MAX, d.offset, INT_MAX, 0,
+		    parent, target, 0);
 	*d.dstq = NULL;
+	if (ignore_diffs)
+		newdest = llist_mergesort(newdest, get_next_blame,
+					  set_next_blame,
+					  compare_blame_suspect);
 	queue_blames(sb, parent, newdest);
 
 	return;
@@ -1156,7 +2092,8 @@ static void find_move_in_parent(struct b
 	if (!unblamed)
 		return; /* nothing remains for this target */
 
-	fill_origin_blob(&sb->revs->diffopt, parent, &file_p, &sb->num_read_blob);
+	fill_origin_blob(&sb->revs->diffopt, parent, &file_p,
+			 &sb->num_read_blob, 0);
 	if (!file_p.ptr)
 		return;
 
@@ -1236,7 +2173,7 @@ static void find_copy_in_parent(struct b
 	if (!unblamed)
 		return; /* nothing remains for this target */
 
-	diff_setup(&diff_opts);
+	repo_diff_setup(sb->repo, &diff_opts);
 	diff_opts.flags.recursive = 1;
 	diff_opts.output_format = DIFF_FORMAT_NO_OUTPUT;
 
@@ -1285,7 +2222,8 @@ static void find_copy_in_parent(struct b
 			norigin = get_origin(parent, p->one->path);
 			oidcpy(&norigin->blob_oid, &p->one->oid);
 			norigin->mode = p->one->mode;
-			fill_origin_blob(&sb->revs->diffopt, norigin, &file_p, &sb->num_read_blob);
+			fill_origin_blob(&sb->revs->diffopt, norigin, &file_p,
+					 &sb->num_read_blob, 0);
 			if (!file_p.ptr)
 				continue;
 
@@ -1418,7 +2356,7 @@ static void pass_blame(struct blame_scor
 	 * common cases, then we look for renames in the second pass.
 	 */
 	for (pass = 0; pass < 2 - sb->no_whole_file_rename; pass++) {
-		struct blame_origin *(*find)(struct commit *, struct blame_origin *);
+		struct blame_origin *(*find)(struct repository *, struct commit *, struct blame_origin *);
 		find = pass ? find_rename : find_origin;
 
 		for (i = 0, sg = first_scapegoat(revs, commit, sb->reverse);
@@ -1431,17 +2369,17 @@ static void pass_blame(struct blame_scor
 				continue;
 			if (parse_commit(p))
 				continue;
-			porigin = find(p, origin);
+			porigin = find(sb->repo, p, origin);
 			if (!porigin)
 				continue;
-			if (!oidcmp(&porigin->blob_oid, &origin->blob_oid)) {
+			if (oideq(&porigin->blob_oid, &origin->blob_oid)) {
 				pass_whole_blame(sb, origin, porigin);
 				blame_origin_decref(porigin);
 				goto finish;
 			}
 			for (j = same = 0; j < i; j++)
 				if (sg_origin[j] &&
-				    !oidcmp(&sg_origin[j]->blob_oid, &porigin->blob_oid)) {
+				    oideq(&sg_origin[j]->blob_oid, &porigin->blob_oid)) {
 					same = 1;
 					break;
 				}
@@ -1463,12 +2401,35 @@ static void pass_blame(struct blame_scor
 			blame_origin_incref(porigin);
 			origin->previous = porigin;
 		}
-		pass_blame_to_parent(sb, origin, porigin);
+		pass_blame_to_parent(sb, origin, porigin, 0);
 		if (!origin->suspects)
 			goto finish;
 	}
 
 	/*
+	 * Pass remaining suspects for ignored commits to their parents.
+	 */
+	if (oidset_contains(&sb->ignore_list, &commit->object.oid)) {
+		for (i = 0, sg = first_scapegoat(revs, commit, sb->reverse);
+		     i < num_sg && sg;
+		     sg = sg->next, i++) {
+			struct blame_origin *porigin = sg_origin[i];
+
+			if (!porigin)
+				continue;
+			pass_blame_to_parent(sb, origin, porigin, 1);
+			/*
+			 * Preemptively drop porigin so we can refresh the
+			 * fingerprints if we use the parent again, which can
+			 * occur if you ignore back-to-back commits.
+			 */
+			drop_origin_blob(porigin);
+			if (!origin->suspects)
+				goto finish;
+		}
+	}
+
+	/*
 	 * Optionally find moves in parents' files.
 	 */
 	if (opt & PICKAXE_BLAME_MOVE) {
@@ -1530,7 +2491,8 @@ finish:
 	}
 	for (i = 0; i < num_sg; i++) {
 		if (sg_origin[i]) {
-			drop_origin_blob(sg_origin[i]);
+			if (!sg_origin[i]->suspects)
+				drop_origin_blob(sg_origin[i]);
 			blame_origin_decref(sg_origin[i]);
 		}
 	}
@@ -1550,7 +2512,7 @@ void assign_blame(struct blame_scoreboar
 
 	while (commit) {
 		struct blame_entry *ent;
-		struct blame_origin *suspect = commit->util;
+		struct blame_origin *suspect = get_blame_suspects(commit);
 
 		/* find one suspect to break down */
 		while (suspect && !suspect->suspects)
@@ -1607,37 +2569,14 @@ void assign_blame(struct blame_scoreboar
 	}
 }
 
-static const char *get_next_line(const char *start, const char *end)
-{
-	const char *nl = memchr(start, '\n', end - start);
-	return nl ? nl + 1 : end;
-}
-
 /*
  * To allow quick access to the contents of nth line in the
  * final image, prepare an index in the scoreboard.
  */
 static int prepare_lines(struct blame_scoreboard *sb)
 {
-	const char *buf = sb->final_buf;
-	unsigned long len = sb->final_buf_size;
-	const char *end = buf + len;
-	const char *p;
-	int *lineno;
-	int num = 0;
-
-	for (p = buf; p < end; p = get_next_line(p, end))
-		num++;
-
-	ALLOC_ARRAY(sb->lineno, num + 1);
-	lineno = sb->lineno;
-
-	for (p = buf; p < end; p = get_next_line(p, end))
-		*lineno++ = p - buf;
-
-	*lineno = len;
-
-	sb->num_lines = num;
+	sb->num_lines = find_line_starts(&sb->lineno, sb->final_buf,
+					 sb->final_buf_size);
 	return sb->num_lines;
 }
 
@@ -1652,7 +2591,7 @@ static struct commit *find_single_final(
 		struct object *obj = revs->pending.objects[i].item;
 		if (obj->flags & UNINTERESTING)
 			continue;
-		obj = deref_tag(obj, NULL, 0);
+		obj = deref_tag(revs->repo, obj, NULL, 0);
 		if (obj->type != OBJ_COMMIT)
 			die("Non commit %s?", revs->pending.objects[i].name);
 		if (found)
@@ -1683,14 +2622,15 @@ static struct commit *dwim_reverse_initi
 
 	/* Is that sole rev a committish? */
 	obj = revs->pending.objects[0].item;
-	obj = deref_tag(obj, NULL, 0);
+	obj = deref_tag(revs->repo, obj, NULL, 0);
 	if (obj->type != OBJ_COMMIT)
 		return NULL;
 
 	/* Do we have HEAD? */
 	if (!resolve_ref_unsafe("HEAD", RESOLVE_REF_READING, &head_oid, NULL))
 		return NULL;
-	head_commit = lookup_commit_reference_gently(&head_oid, 1);
+	head_commit = lookup_commit_reference_gently(revs->repo,
+						     &head_oid, 1);
 	if (!head_commit)
 		return NULL;
 
@@ -1718,7 +2658,7 @@ static struct commit *find_single_initia
 		struct object *obj = revs->pending.objects[i].item;
 		if (!(obj->flags & UNINTERESTING))
 			continue;
-		obj = deref_tag(obj, NULL, 0);
+		obj = deref_tag(revs->repo, obj, NULL, 0);
 		if (obj->type != OBJ_COMMIT)
 			die("Non commit %s?", revs->pending.objects[i].name);
 		if (found)
@@ -1745,16 +2685,23 @@ void init_scoreboard(struct blame_scoreb
 	sb->copy_score = BLAME_DEFAULT_COPY_SCORE;
 }
 
-void setup_scoreboard(struct blame_scoreboard *sb, const char *path, struct blame_origin **orig)
+void setup_scoreboard(struct blame_scoreboard *sb,
+		      const char *path,
+		      struct blame_origin **orig)
 {
 	const char *final_commit_name = NULL;
 	struct blame_origin *o;
 	struct commit *final_commit = NULL;
 	enum object_type type;
 
+	init_blame_suspects(&blame_suspects);
+
 	if (sb->reverse && sb->contents_from)
 		die(_("--contents and --reverse do not blend well."));
 
+	if (!sb->repo)
+		BUG("repo is NULL");
+
 	if (!sb->reverse) {
 		sb->final = find_single_final(sb->revs, &final_commit_name);
 		sb->commits.compare = compare_commits_by_commit_date;
@@ -1776,7 +2723,8 @@ void setup_scoreboard(struct blame_score
 		 * or "--contents".
 		 */
 		setup_work_tree();
-		sb->final = fake_working_tree_commit(&sb->revs->diffopt,
+		sb->final = fake_working_tree_commit(sb->repo,
+						     &sb->revs->diffopt,
 						     path, sb->contents_from);
 		add_pending_object(sb->revs, &(sb->final->object), ":");
 	}
@@ -1800,7 +2748,7 @@ void setup_scoreboard(struct blame_score
 
 		sb->revs->children.name = "children";
 		while (c->parents &&
-		       oidcmp(&c->object.oid, &sb->final->object.oid)) {
+		       !oideq(&c->object.oid, &sb->final->object.oid)) {
 			struct commit_list *l = xcalloc(1, sizeof(*l));
 
 			l->item = c;
@@ -1810,22 +2758,22 @@ void setup_scoreboard(struct blame_score
 			c = c->parents->item;
 		}
 
-		if (oidcmp(&c->object.oid, &sb->final->object.oid))
+		if (!oideq(&c->object.oid, &sb->final->object.oid))
 			die(_("--reverse --first-parent together require range along first-parent chain"));
 	}
 
 	if (is_null_oid(&sb->final->object.oid)) {
-		o = sb->final->util;
+		o = get_blame_suspects(sb->final);
 		sb->final_buf = xmemdupz(o->file.ptr, o->file.size);
 		sb->final_buf_size = o->file.size;
 	}
 	else {
 		o = get_origin(sb->final, path);
-		if (fill_blob_sha1_and_mode(o))
+		if (fill_blob_sha1_and_mode(sb->repo, o))
 			die(_("no such path %s in %s"), path, final_commit_name);
 
 		if (sb->revs->diffopt.flags.allow_textconv &&
-		    textconv_object(path, o->mode, &o->blob_oid, 1, (char **) &sb->final_buf,
+		    textconv_object(sb->repo, path, o->mode, &o->blob_oid, 1, (char **) &sb->final_buf,
 				    &sb->final_buf_size))
 			;
 		else
diff -pruN 1.2.1+git2.18.0-1/git/blame.h 1.2.3+git2.25.1-1/git/blame.h
--- 1.2.1+git2.18.0-1/git/blame.h	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/blame.h	2020-02-17 04:47:35.000000000 +0000
@@ -51,8 +51,10 @@ struct blame_origin {
 	 */
 	struct blame_entry *suspects;
 	mmfile_t file;
+	int num_lines;
+	void *fingerprints;
 	struct object_id blob_oid;
-	unsigned mode;
+	unsigned short mode;
 	/* guilty gets set when shipping any suspects to the final
 	 * blame list instead of other commits
 	 */
@@ -92,6 +94,8 @@ struct blame_entry {
 	 * scanning the lines over and over.
 	 */
 	unsigned score;
+	int ignored;
+	int unblamable;
 };
 
 /*
@@ -102,6 +106,7 @@ struct blame_scoreboard {
 	struct commit *final;
 	/* Priority queue for commits with unassigned blame records */
 	struct prio_queue commits;
+	struct repository *repo;
 	struct rev_info *revs;
 	const char *path;
 
@@ -116,6 +121,8 @@ struct blame_scoreboard {
 	/* linked list of blames */
 	struct blame_entry *ent;
 
+	struct oidset ignore_list;
+
 	/* look-up a line in the final buffer */
 	int num_lines;
 	int *lineno;
@@ -159,17 +166,23 @@ static inline struct blame_origin *blame
 		o->refcnt++;
 	return o;
 }
-extern void blame_origin_decref(struct blame_origin *o);
-
-extern void blame_coalesce(struct blame_scoreboard *sb);
-extern void blame_sort_final(struct blame_scoreboard *sb);
-extern unsigned blame_entry_score(struct blame_scoreboard *sb, struct blame_entry *e);
-extern void assign_blame(struct blame_scoreboard *sb, int opt);
-extern const char *blame_nth_line(struct blame_scoreboard *sb, long lno);
+void blame_origin_decref(struct blame_origin *o);
 
-extern void init_scoreboard(struct blame_scoreboard *sb);
-extern void setup_scoreboard(struct blame_scoreboard *sb, const char *path, struct blame_origin **orig);
+void blame_coalesce(struct blame_scoreboard *sb);
+void blame_sort_final(struct blame_scoreboard *sb);
+unsigned blame_entry_score(struct blame_scoreboard *sb, struct blame_entry *e);
+void assign_blame(struct blame_scoreboard *sb, int opt);
+const char *blame_nth_line(struct blame_scoreboard *sb, long lno);
+
+void init_scoreboard(struct blame_scoreboard *sb);
+void setup_scoreboard(struct blame_scoreboard *sb,
+		      const char *path,
+		      struct blame_origin **orig);
+
+struct blame_entry *blame_entry_prepend(struct blame_entry *head,
+					long start, long end,
+					struct blame_origin *o);
 
-extern struct blame_entry *blame_entry_prepend(struct blame_entry *head, long start, long end, struct blame_origin *o);
+struct blame_origin *get_blame_suspects(struct commit *commit);
 
 #endif /* BLAME_H */
diff -pruN 1.2.1+git2.18.0-1/git/blob.c 1.2.3+git2.25.1-1/git/blob.c
--- 1.2.1+git2.18.0-1/git/blob.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/blob.c	2020-02-17 04:47:35.000000000 +0000
@@ -1,14 +1,16 @@
 #include "cache.h"
 #include "blob.h"
+#include "repository.h"
+#include "alloc.h"
 
 const char *blob_type = "blob";
 
-struct blob *lookup_blob(const struct object_id *oid)
+struct blob *lookup_blob(struct repository *r, const struct object_id *oid)
 {
-	struct object *obj = lookup_object(oid->hash);
+	struct object *obj = lookup_object(r, oid);
 	if (!obj)
-		return create_object(oid->hash, alloc_blob_node());
-	return object_as_type(obj, OBJ_BLOB, 0);
+		return create_object(r, oid, alloc_blob_node(r));
+	return object_as_type(r, obj, OBJ_BLOB, 0);
 }
 
 int parse_blob_buffer(struct blob *item, void *buffer, unsigned long size)
diff -pruN 1.2.1+git2.18.0-1/git/blob.h 1.2.3+git2.25.1-1/git/blob.h
--- 1.2.1+git2.18.0-1/git/blob.h	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/blob.h	2020-02-17 04:47:35.000000000 +0000
@@ -9,7 +9,7 @@ struct blob {
 	struct object object;
 };
 
-struct blob *lookup_blob(const struct object_id *oid);
+struct blob *lookup_blob(struct repository *r, const struct object_id *oid);
 
 int parse_blob_buffer(struct blob *item, void *buffer, unsigned long size);
 
diff -pruN 1.2.1+git2.18.0-1/git/branch.c 1.2.3+git2.25.1-1/git/branch.c
--- 1.2.1+git2.18.0-1/git/branch.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/branch.c	2020-02-17 04:47:35.000000000 +0000
@@ -5,6 +5,7 @@
 #include "refs.h"
 #include "refspec.h"
 #include "remote.h"
+#include "sequencer.h"
 #include "commit.h"
 #include "worktree.h"
 
@@ -25,9 +26,7 @@ static int find_tracked_branch(struct re
 			tracking->remote = remote->name;
 		} else {
 			free(tracking->spec.src);
-			if (tracking->src) {
-				FREE_AND_NULL(tracking->src);
-			}
+			FREE_AND_NULL(tracking->src);
 		}
 		tracking->spec.src = NULL;
 	}
@@ -244,7 +243,8 @@ N_("\n"
 "will track its remote counterpart, you may want to use\n"
 "\"git push -u\" to set the upstream config as you push.");
 
-void create_branch(const char *name, const char *start_name,
+void create_branch(struct repository *r,
+		   const char *name, const char *start_name,
 		   int force, int clobber_head_ok, int reflog,
 		   int quiet, enum branch_track track)
 {
@@ -269,7 +269,7 @@ void create_branch(const char *name, con
 	}
 
 	real_ref = NULL;
-	if (get_oid(start_name, &oid)) {
+	if (get_oid_mb(start_name, &oid)) {
 		if (explicit_tracking) {
 			if (advice_set_upstream_failure) {
 				error(_(upstream_missing), start_name);
@@ -302,7 +302,7 @@ void create_branch(const char *name, con
 		break;
 	}
 
-	if ((commit = lookup_commit_reference(&oid)) == NULL)
+	if ((commit = lookup_commit_reference(r, &oid)) == NULL)
 		die(_("Not a valid branch point: '%s'."), start_name);
 	oidcpy(&oid, &commit->object.oid);
 
@@ -338,15 +338,19 @@ void create_branch(const char *name, con
 	free(real_ref);
 }
 
-void remove_branch_state(void)
+void remove_merge_branch_state(struct repository *r)
+{
+	unlink(git_path_merge_head(r));
+	unlink(git_path_merge_rr(r));
+	unlink(git_path_merge_msg(r));
+	unlink(git_path_merge_mode(r));
+}
+
+void remove_branch_state(struct repository *r, int verbose)
 {
-	unlink(git_path_cherry_pick_head());
-	unlink(git_path_revert_head());
-	unlink(git_path_merge_head());
-	unlink(git_path_merge_rr());
-	unlink(git_path_merge_msg());
-	unlink(git_path_merge_mode());
-	unlink(git_path_squash_msg());
+	sequencer_post_commit_cleanup(r, verbose);
+	unlink(git_path_squash_msg(r));
+	remove_merge_branch_state(r);
 }
 
 void die_if_checked_out(const char *branch, int ignore_current_worktree)
diff -pruN 1.2.1+git2.18.0-1/git/branch.h 1.2.3+git2.25.1-1/git/branch.h
--- 1.2.1+git2.18.0-1/git/branch.h	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/branch.h	2020-02-17 04:47:35.000000000 +0000
@@ -1,11 +1,27 @@
 #ifndef BRANCH_H
 #define BRANCH_H
 
+struct repository;
+struct strbuf;
+
+enum branch_track {
+	BRANCH_TRACK_UNSPECIFIED = -1,
+	BRANCH_TRACK_NEVER = 0,
+	BRANCH_TRACK_REMOTE,
+	BRANCH_TRACK_ALWAYS,
+	BRANCH_TRACK_EXPLICIT,
+	BRANCH_TRACK_OVERRIDE
+};
+
+extern enum branch_track git_branch_track;
+
 /* Functions for acting on the information about branches. */
 
 /*
  * Creates a new branch, where:
  *
+ *   - r is the repository to add a branch to
+ *
  *   - name is the new branch name
  *
  *   - start_name is the name of the existing branch that the new branch should
@@ -24,7 +40,8 @@
  *     that start_name is a tracking branch for (if any).
  *
  */
-void create_branch(const char *name, const char *start_name,
+void create_branch(struct repository *r,
+		   const char *name, const char *start_name,
 		   int force, int clobber_head_ok,
 		   int reflog, int quiet, enum branch_track track);
 
@@ -33,7 +50,7 @@ void create_branch(const char *name, con
  * Return 1 if the named branch already exists; return 0 otherwise.
  * Fill ref with the full refname for the branch.
  */
-extern int validate_branchname(const char *name, struct strbuf *ref);
+int validate_branchname(const char *name, struct strbuf *ref);
 
 /*
  * Check if a branch 'name' can be created as a new branch; die otherwise.
@@ -41,13 +58,19 @@ extern int validate_branchname(const cha
  * Return 1 if the named branch already exists; return 0 otherwise.
  * Fill ref with the full refname for the branch.
  */
-extern int validate_new_branchname(const char *name, struct strbuf *ref, int force);
+int validate_new_branchname(const char *name, struct strbuf *ref, int force);
+
+/*
+ * Remove information about the merge state on the current
+ * branch. (E.g., MERGE_HEAD)
+ */
+void remove_merge_branch_state(struct repository *r);
 
 /*
  * Remove information about the state of working on the current
  * branch. (E.g., MERGE_HEAD)
  */
-void remove_branch_state(void);
+void remove_branch_state(struct repository *r, int verbose);
 
 /*
  * Configure local branch "local" as downstream to branch "remote"
@@ -55,26 +78,26 @@ void remove_branch_state(void);
  * Returns 0 on success.
  */
 #define BRANCH_CONFIG_VERBOSE 01
-extern int install_branch_config(int flag, const char *local, const char *origin, const char *remote);
+int install_branch_config(int flag, const char *local, const char *origin, const char *remote);
 
 /*
  * Read branch description
  */
-extern int read_branch_desc(struct strbuf *, const char *branch_name);
+int read_branch_desc(struct strbuf *, const char *branch_name);
 
 /*
  * Check if a branch is checked out in the main worktree or any linked
  * worktree and die (with a message describing its checkout location) if
  * it is.
  */
-extern void die_if_checked_out(const char *branch, int ignore_current_worktree);
+void die_if_checked_out(const char *branch, int ignore_current_worktree);
 
 /*
  * Update all per-worktree HEADs pointing at the old ref to point the new ref.
  * This will be used when renaming a branch. Returns 0 if successful, non-zero
  * otherwise.
  */
-extern int replace_each_worktree_head_symref(const char *oldref, const char *newref,
-					     const char *logmsg);
+int replace_each_worktree_head_symref(const char *oldref, const char *newref,
+				      const char *logmsg);
 
 #endif
diff -pruN 1.2.1+git2.18.0-1/git/builtin/add.c 1.2.3+git2.25.1-1/git/builtin/add.c
--- 1.2.1+git2.18.0-1/git/builtin/add.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/builtin/add.c	2020-02-17 04:47:35.000000000 +0000
@@ -3,6 +3,7 @@
  *
  * Copyright (C) 2006 Linus Torvalds
  */
+#define USE_THE_INDEX_COMPATIBILITY_MACROS
 #include "cache.h"
 #include "config.h"
 #include "builtin.h"
@@ -19,6 +20,7 @@
 #include "bulk-checkin.h"
 #include "argv-array.h"
 #include "submodule.h"
+#include "add-interactive.h"
 
 static const char * const builtin_add_usage[] = {
 	N_("git add [<options>] [--] <pathspec>..."),
@@ -27,6 +29,8 @@ static const char * const builtin_add_us
 static int patch_interactive, add_interactive, edit_interactive;
 static int take_worktree_changes;
 static int add_renormalize;
+static int pathspec_file_nul;
+static const char *pathspec_from_file;
 
 struct update_callback_data {
 	int flags;
@@ -40,7 +44,7 @@ static void chmod_pathspec(struct pathsp
 	for (i = 0; i < active_nr; i++) {
 		struct cache_entry *ce = active_cache[i];
 
-		if (pathspec && !ce_path_match(ce, pathspec, NULL))
+		if (pathspec && !ce_path_match(&the_index, ce, pathspec, NULL))
 			continue;
 
 		if (chmod_cache_entry(ce, flip) < 0)
@@ -110,7 +114,7 @@ int add_files_to_cache(const char *prefi
 	memset(&data, 0, sizeof(data));
 	data.flags = flags;
 
-	init_revisions(&rev, prefix);
+	repo_init_revisions(the_repository, &rev, prefix);
 	setup_revisions(0, NULL, &rev, NULL);
 	if (pathspec)
 		copy_pathspec(&rev.prune_data, pathspec);
@@ -135,9 +139,9 @@ static int renormalize_tracked_files(con
 			continue; /* do not touch unmerged paths */
 		if (!S_ISREG(ce->ce_mode) && !S_ISLNK(ce->ce_mode))
 			continue; /* do not touch non blobs */
-		if (pathspec && !ce_path_match(ce, pathspec, NULL))
+		if (pathspec && !ce_path_match(&the_index, ce, pathspec, NULL))
 			continue;
-		retval |= add_file_to_cache(ce->name, flags | HASH_RENORMALIZE);
+		retval |= add_file_to_cache(ce->name, flags | ADD_CACHE_RENORMALIZE);
 	}
 
 	return retval;
@@ -155,7 +159,7 @@ static char *prune_directory(struct dir_
 	i = dir->nr;
 	while (--i >= 0) {
 		struct dir_entry *entry = *src++;
-		if (dir_path_match(entry, pathspec, prefix, seen))
+		if (dir_path_match(&the_index, entry, pathspec, prefix, seen))
 			*dst++ = entry;
 	}
 	dir->nr = dst - dir->entries;
@@ -176,7 +180,7 @@ static void refresh(int verbose, const s
 			die(_("pathspec '%s' did not match any files"),
 			    pathspec->items[i].match);
 	}
-        free(seen);
+	free(seen);
 }
 
 int run_add_interactive(const char *revision, const char *patch_mode,
@@ -184,6 +188,21 @@ int run_add_interactive(const char *revi
 {
 	int status, i;
 	struct argv_array argv = ARGV_ARRAY_INIT;
+	int use_builtin_add_i =
+		git_env_bool("GIT_TEST_ADD_I_USE_BUILTIN", -1);
+
+	if (use_builtin_add_i < 0)
+		git_config_get_bool("add.interactive.usebuiltin",
+				    &use_builtin_add_i);
+
+	if (use_builtin_add_i == 1) {
+		if (!patch_mode)
+			return !!run_add_i(the_repository, pathspec);
+		if (strcmp(patch_mode, "--patch"))
+			die("'%s' not yet supported in the built-in add -p",
+			    patch_mode);
+		return !!run_add_p(the_repository, pathspec);
+	}
 
 	argv_array_push(&argv, "add--interactive");
 	if (patch_mode)
@@ -232,14 +251,14 @@ static int edit_patch(int argc, const ch
 	if (read_cache() < 0)
 		die(_("Could not read the index"));
 
-	init_revisions(&rev, prefix);
+	repo_init_revisions(the_repository, &rev, prefix);
 	rev.diffopt.context = 7;
 
 	argc = setup_revisions(argc, argv, &rev, NULL);
 	rev.diffopt.output_format = DIFF_FORMAT_PATCH;
 	rev.diffopt.use_color = 0;
 	rev.diffopt.flags.ignore_dirty_submodules = 1;
-	out = open(file, O_CREAT | O_WRONLY, 0666);
+	out = open(file, O_CREAT | O_WRONLY | O_TRUNC, 0666);
 	if (out < 0)
 		die(_("Could not open '%s' for writing."), file);
 	rev.diffopt.file = xfdopen(out, "w");
@@ -304,9 +323,12 @@ static struct option builtin_add_options
 	OPT_BOOL( 0 , "refresh", &refresh_only, N_("don't add, only refresh the index")),
 	OPT_BOOL( 0 , "ignore-errors", &ignore_add_errors, N_("just skip files which cannot be added because of errors")),
 	OPT_BOOL( 0 , "ignore-missing", &ignore_missing, N_("check if - even missing - files are ignored in dry run")),
-	OPT_STRING( 0 , "chmod", &chmod_arg, N_("(+/-)x"), N_("override the executable bit of the listed files")),
+	OPT_STRING(0, "chmod", &chmod_arg, "(+|-)x",
+		   N_("override the executable bit of the listed files")),
 	OPT_HIDDEN_BOOL(0, "warn-embedded-repo", &warn_on_embedded_repo,
 			N_("warn when adding an embedded repository")),
+	OPT_PATHSPEC_FROM_FILE(&pathspec_from_file),
+	OPT_PATHSPEC_FILE_NUL(&pathspec_file_nul),
 	OPT_END(),
 };
 
@@ -317,6 +339,7 @@ static int add_config(const char *var, c
 		ignore_add_errors = git_config_bool(var, value);
 		return 0;
 	}
+
 	return git_default_config(var, value, cb);
 }
 
@@ -372,11 +395,12 @@ static int add_files(struct dir_struct *
 	}
 
 	for (i = 0; i < dir->nr; i++) {
-		check_embedded_repo(dir->entries[i]->name);
 		if (add_file_to_index(&the_index, dir->entries[i]->name, flags)) {
 			if (!ignore_add_errors)
 				die(_("adding files failed"));
 			exit_status = 1;
+		} else {
+			check_embedded_repo(dir->entries[i]->name);
 		}
 	}
 	return exit_status;
@@ -399,11 +423,17 @@ int cmd_add(int argc, const char **argv,
 			  builtin_add_usage, PARSE_OPT_KEEP_ARGV0);
 	if (patch_interactive)
 		add_interactive = 1;
-	if (add_interactive)
+	if (add_interactive) {
+		if (pathspec_from_file)
+			die(_("--pathspec-from-file is incompatible with --interactive/--patch"));
 		exit(interactive_add(argc - 1, argv + 1, prefix, patch_interactive));
+	}
 
-	if (edit_interactive)
+	if (edit_interactive) {
+		if (pathspec_from_file)
+			die(_("--pathspec-from-file is incompatible with --edit"));
 		return(edit_patch(argc, argv, prefix));
+	}
 	argc--;
 	argv++;
 
@@ -415,10 +445,6 @@ int cmd_add(int argc, const char **argv,
 	if (addremove && take_worktree_changes)
 		die(_("-A and -u are mutually incompatible"));
 
-	if (!take_worktree_changes && addremove_explicit < 0 && argc)
-		/* Turn "git add pathspec..." to "git add -A pathspec..." */
-		addremove = 1;
-
 	if (!show_only && ignore_missing)
 		die(_("Option --ignore-missing can only be used together with --dry-run"));
 
@@ -431,6 +457,37 @@ int cmd_add(int argc, const char **argv,
 
 	hold_locked_index(&lock_file, LOCK_DIE_ON_ERROR);
 
+	/*
+	 * Check the "pathspec '%s' did not match any files" block
+	 * below before enabling new magic.
+	 */
+	parse_pathspec(&pathspec, PATHSPEC_ATTR,
+		       PATHSPEC_PREFER_FULL |
+		       PATHSPEC_SYMLINK_LEADING_PATH,
+		       prefix, argv);
+
+	if (pathspec_from_file) {
+		if (pathspec.nr)
+			die(_("--pathspec-from-file is incompatible with pathspec arguments"));
+
+		parse_pathspec_file(&pathspec, PATHSPEC_ATTR,
+				    PATHSPEC_PREFER_FULL |
+				    PATHSPEC_SYMLINK_LEADING_PATH,
+				    prefix, pathspec_from_file, pathspec_file_nul);
+	} else if (pathspec_file_nul) {
+		die(_("--pathspec-file-nul requires --pathspec-from-file"));
+	}
+
+	if (require_pathspec && pathspec.nr == 0) {
+		fprintf(stderr, _("Nothing specified, nothing added.\n"));
+		fprintf(stderr, _("Maybe you wanted to say 'git add .'?\n"));
+		return 0;
+	}
+
+	if (!take_worktree_changes && addremove_explicit < 0 && pathspec.nr)
+		/* Turn "git add pathspec..." to "git add -A pathspec..." */
+		addremove = 1;
+
 	flags = ((verbose ? ADD_CACHE_VERBOSE : 0) |
 		 (show_only ? ADD_CACHE_PRETEND : 0) |
 		 (intent_to_add ? ADD_CACHE_INTENT : 0) |
@@ -438,26 +495,10 @@ int cmd_add(int argc, const char **argv,
 		 (!(addremove || take_worktree_changes)
 		  ? ADD_CACHE_IGNORE_REMOVAL : 0));
 
-	if (require_pathspec && argc == 0) {
-		fprintf(stderr, _("Nothing specified, nothing added.\n"));
-		fprintf(stderr, _("Maybe you wanted to say 'git add .'?\n"));
-		return 0;
-	}
-
-	if (read_cache() < 0)
+	if (read_cache_preload(&pathspec) < 0)
 		die(_("index file corrupt"));
 
 	die_in_unpopulated_submodule(&the_index, prefix);
-
-	/*
-	 * Check the "pathspec '%s' did not match any files" block
-	 * below before enabling new magic.
-	 */
-	parse_pathspec(&pathspec, 0,
-		       PATHSPEC_PREFER_FULL |
-		       PATHSPEC_SYMLINK_LEADING_PATH,
-		       prefix, argv);
-
 	die_path_inside_submodule(&the_index, &pathspec);
 
 	if (add_new_files) {
diff -pruN 1.2.1+git2.18.0-1/git/builtin/am.c 1.2.3+git2.25.1-1/git/builtin/am.c
--- 1.2.1+git2.18.0-1/git/builtin/am.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/builtin/am.c	2020-02-17 04:47:35.000000000 +0000
@@ -3,6 +3,7 @@
  *
  * Based on git-am.sh by Junio C Hamano.
  */
+#define USE_THE_INDEX_COMPATIBILITY_MACROS
 #include "cache.h"
 #include "config.h"
 #include "builtin.h"
@@ -23,7 +24,6 @@
 #include "sequencer.h"
 #include "revision.h"
 #include "merge-recursive.h"
-#include "revision.h"
 #include "log-tree.h"
 #include "notes-utils.h"
 #include "rerere.h"
@@ -32,22 +32,7 @@
 #include "apply.h"
 #include "string-list.h"
 #include "packfile.h"
-
-/**
- * Returns 1 if the file is empty or does not exist, 0 otherwise.
- */
-static int is_empty_file(const char *filename)
-{
-	struct stat st;
-
-	if (stat(filename, &st) < 0) {
-		if (errno == ENOENT)
-			return 1;
-		die_errno(_("could not stat %s"), filename);
-	}
-
-	return !st.st_size;
-}
+#include "repository.h"
 
 /**
  * Returns the length of the first line of msg.
@@ -260,32 +245,6 @@ static int read_state_file(struct strbuf
 }
 
 /**
- * Take a series of KEY='VALUE' lines where VALUE part is
- * sq-quoted, and append <KEY, VALUE> at the end of the string list
- */
-static int parse_key_value_squoted(char *buf, struct string_list *list)
-{
-	while (*buf) {
-		struct string_list_item *item;
-		char *np;
-		char *cp = strchr(buf, '=');
-		if (!cp)
-			return -1;
-		np = strchrnul(cp, '\n');
-		*cp++ = '\0';
-		item = string_list_append(list, buf);
-
-		buf = np + (*np == '\n');
-		*np = '\0';
-		cp = sq_dequote(cp);
-		if (!cp)
-			return -1;
-		item->util = xstrdup(cp);
-	}
-	return 0;
-}
-
-/**
  * Reads and parses the state directory's "author-script" file, and sets
  * state->author_name, state->author_email and state->author_date accordingly.
  * Returns 0 on success, -1 if the file could not be parsed.
@@ -301,42 +260,16 @@ static int parse_key_value_squoted(char
  * script, and thus if the file differs from what this function expects, it is
  * better to bail out than to do something that the user does not expect.
  */
-static int read_author_script(struct am_state *state)
+static int read_am_author_script(struct am_state *state)
 {
 	const char *filename = am_path(state, "author-script");
-	struct strbuf buf = STRBUF_INIT;
-	struct string_list kv = STRING_LIST_INIT_DUP;
-	int retval = -1; /* assume failure */
-	int fd;
 
 	assert(!state->author_name);
 	assert(!state->author_email);
 	assert(!state->author_date);
 
-	fd = open(filename, O_RDONLY);
-	if (fd < 0) {
-		if (errno == ENOENT)
-			return 0;
-		die_errno(_("could not open '%s' for reading"), filename);
-	}
-	strbuf_read(&buf, fd, 0);
-	close(fd);
-	if (parse_key_value_squoted(buf.buf, &kv))
-		goto finish;
-
-	if (kv.nr != 3 ||
-	    strcmp(kv.items[0].string, "GIT_AUTHOR_NAME") ||
-	    strcmp(kv.items[1].string, "GIT_AUTHOR_EMAIL") ||
-	    strcmp(kv.items[2].string, "GIT_AUTHOR_DATE"))
-		goto finish;
-	state->author_name = kv.items[0].util;
-	state->author_email = kv.items[1].util;
-	state->author_date = kv.items[2].util;
-	retval = 0;
-finish:
-	string_list_clear(&kv, !!retval);
-	strbuf_release(&buf);
-	return retval;
+	return read_author_script(filename, &state->author_name,
+				  &state->author_email, &state->author_date, 1);
 }
 
 /**
@@ -410,7 +343,7 @@ static void am_load(struct am_state *sta
 		BUG("state file 'last' does not exist");
 	state->last = strtol(sb.buf, NULL, 10);
 
-	if (read_author_script(state) < 0)
+	if (read_am_author_script(state) < 0)
 		die(_("could not parse author script"));
 
 	read_commit_msg(state);
@@ -519,6 +452,7 @@ static int run_post_rewrite_hook(const s
 
 	cp.in = xopen(am_path(state, "rewritten"), O_RDONLY);
 	cp.stdout_to_stderr = 1;
+	cp.trace2_hook_name = "post-rewrite";
 
 	ret = run_command(&cp);
 
@@ -551,23 +485,24 @@ static int copy_notes_for_rebase(const s
 
 	while (!strbuf_getline_lf(&sb, fp)) {
 		struct object_id from_obj, to_obj;
+		const char *p;
 
-		if (sb.len != GIT_SHA1_HEXSZ * 2 + 1) {
+		if (sb.len != the_hash_algo->hexsz * 2 + 1) {
 			ret = error(invalid_line, sb.buf);
 			goto finish;
 		}
 
-		if (get_oid_hex(sb.buf, &from_obj)) {
+		if (parse_oid_hex(sb.buf, &from_obj, &p)) {
 			ret = error(invalid_line, sb.buf);
 			goto finish;
 		}
 
-		if (sb.buf[GIT_SHA1_HEXSZ] != ' ') {
+		if (*p != ' ') {
 			ret = error(invalid_line, sb.buf);
 			goto finish;
 		}
 
-		if (get_oid_hex(sb.buf + GIT_SHA1_HEXSZ + 1, &to_obj)) {
+		if (get_oid_hex(p + 1, &to_obj)) {
 			ret = error(invalid_line, sb.buf);
 			goto finish;
 		}
@@ -578,7 +513,7 @@ static int copy_notes_for_rebase(const s
 	}
 
 finish:
-	finish_copy_notes_for_rewrite(c, msg);
+	finish_copy_notes_for_rewrite(the_repository, c, msg);
 	fclose(fp);
 	strbuf_release(&sb);
 	return ret;
@@ -1136,19 +1071,6 @@ static const char *msgnum(const struct a
 }
 
 /**
- * Refresh and write index.
- */
-static void refresh_and_write_cache(void)
-{
-	struct lock_file lock_file = LOCK_INIT;
-
-	hold_locked_index(&lock_file, LOCK_DIE_ON_ERROR);
-	refresh_cache(REFRESH_QUIET);
-	if (write_locked_index(&the_index, &lock_file, COMMIT_LOCK))
-		die(_("unable to write index file"));
-}
-
-/**
  * Dies with a user-friendly message on how to proceed after resolving the
  * problem. This message can be overridden with state->resolvemsg.
  */
@@ -1243,6 +1165,10 @@ static int parse_mail(struct am_state *s
 	fclose(mi.input);
 	fclose(mi.output);
 
+	if (mi.format_flowed)
+		warning(_("Patch sent with format=flowed; "
+			  "space at the end of lines might be lost."));
+
 	/* Extract message and author information */
 	fp = xfopen(am_path(state, "info"), "r");
 	while (!strbuf_getline_lf(&sb, fp)) {
@@ -1267,7 +1193,7 @@ static int parse_mail(struct am_state *s
 		goto finish;
 	}
 
-	if (is_empty_file(am_path(state, "patch"))) {
+	if (is_empty_or_missing_file(am_path(state, "patch"))) {
 		printf_ln(_("Patch is empty."));
 		die_user_resolve(state);
 	}
@@ -1332,7 +1258,9 @@ static void get_commit_info(struct am_st
 	buffer = logmsg_reencode(commit, NULL, get_commit_output_encoding());
 
 	ident_line = find_commit_header(buffer, "author", &ident_len);
-
+	if (!ident_line)
+		die(_("missing author line in commit %s"),
+		      oid_to_hex(&commit->object.oid));
 	if (split_ident_line(&id, ident_line, ident_len) < 0)
 		die(_("invalid ident line: %.*s"), (int)ident_len, ident_line);
 
@@ -1371,7 +1299,7 @@ static void write_commit_patch(const str
 	FILE *fp;
 
 	fp = xfopen(am_path(state, "patch"), "w");
-	init_revisions(&rev_info, NULL);
+	repo_init_revisions(the_repository, &rev_info, NULL);
 	rev_info.diff = 1;
 	rev_info.abbrev = 0;
 	rev_info.disable_stdin = 1;
@@ -1399,13 +1327,15 @@ static void write_index_patch(const stru
 	struct rev_info rev_info;
 	FILE *fp;
 
-	if (!get_oid_tree("HEAD", &head))
-		tree = lookup_tree(&head);
-	else
-		tree = lookup_tree(the_hash_algo->empty_tree);
+	if (!get_oid("HEAD", &head)) {
+		struct commit *commit = lookup_commit_or_die(&head, "HEAD");
+		tree = get_commit_tree(commit);
+	} else
+		tree = lookup_tree(the_repository,
+				   the_repository->hash_algo->empty_tree);
 
 	fp = xfopen(am_path(state, "patch"), "w");
-	init_revisions(&rev_info, NULL);
+	repo_init_revisions(the_repository, &rev_info, NULL);
 	rev_info.diff = 1;
 	rev_info.disable_stdin = 1;
 	rev_info.no_commit_id = 1;
@@ -1462,7 +1392,7 @@ static int run_apply(const struct am_sta
 	int force_apply = 0;
 	int options = 0;
 
-	if (init_apply_state(&apply_state, NULL))
+	if (init_apply_state(&apply_state, the_repository, NULL))
 		BUG("init_apply_state() failed");
 
 	argv_array_push(&apply_opts, "apply");
@@ -1561,11 +1491,11 @@ static int fall_back_threeway(const stru
 		 * review them with extra care to spot mismerges.
 		 */
 		struct rev_info rev_info;
-		const char *diff_filter_str = "--diff-filter=AM";
 
-		init_revisions(&rev_info, NULL);
+		repo_init_revisions(the_repository, &rev_info, NULL);
 		rev_info.diffopt.output_format = DIFF_FORMAT_NAME_STATUS;
-		diff_opt_parse(&rev_info.diffopt, &diff_filter_str, 1, rev_info.prefix);
+		rev_info.diffopt.filter |= diff_filter_bit('A');
+		rev_info.diffopt.filter |= diff_filter_bit('M');
 		add_pending_oid(&rev_info, "HEAD", &our_tree, 0);
 		diff_setup_done(&rev_info.diffopt);
 		run_diff_index(&rev_info, 1);
@@ -1591,17 +1521,18 @@ static int fall_back_threeway(const stru
 	 * changes.
 	 */
 
-	init_merge_options(&o);
+	init_merge_options(&o, the_repository);
 
 	o.branch1 = "HEAD";
 	their_tree_name = xstrfmt("%.*s", linelen(state->msg), state->msg);
 	o.branch2 = their_tree_name;
+	o.detect_directory_renames = MERGE_DIRECTORY_RENAMES_NONE;
 
 	if (state->quiet)
 		o.verbosity = 0;
 
 	if (merge_recursive_generic(&o, &our_tree, &their_tree, 1, bases, &result)) {
-		rerere(state->allow_rerere_autoupdate);
+		repo_rerere(the_repository, state->allow_rerere_autoupdate);
 		free(their_tree_name);
 		return error(_("Failed to merge in the changes."));
 	}
@@ -1631,13 +1562,15 @@ static void do_commit(const struct am_st
 
 	if (!get_oid_commit("HEAD", &parent)) {
 		old_oid = &parent;
-		commit_list_insert(lookup_commit(&parent), &parents);
+		commit_list_insert(lookup_commit(the_repository, &parent),
+				   &parents);
 	} else {
 		old_oid = NULL;
 		say(state, stderr, _("applying to an empty history"));
 	}
 
 	author = fmt_ident(state->author_name, state->author_email,
+		WANT_AUTHOR_IDENT,
 			state->ignore_date ? NULL : state->author_date,
 			IDENT_STRICT);
 
@@ -1699,11 +1632,8 @@ static int do_interactive(struct am_stat
 {
 	assert(state->msg);
 
-	if (!isatty(0))
-		die(_("cannot be interactive without stdin connected to a terminal."));
-
 	for (;;) {
-		const char *reply;
+		char reply[64];
 
 		puts(_("Commit Body is:"));
 		puts("--------------------------");
@@ -1715,11 +1645,11 @@ static int do_interactive(struct am_stat
 		 * in your translation. The program will only accept English
 		 * input at this point.
 		 */
-		reply = git_prompt(_("Apply? [y]es/[n]o/[e]dit/[v]iew patch/[a]ccept all: "), PROMPT_ECHO);
+		printf(_("Apply? [y]es/[n]o/[e]dit/[v]iew patch/[a]ccept all: "));
+		if (!fgets(reply, sizeof(reply), stdin))
+			die("unable to read from stdin; aborting");
 
-		if (!reply) {
-			continue;
-		} else if (*reply == 'y' || *reply == 'Y') {
+		if (*reply == 'y' || *reply == 'Y') {
 			return 0;
 		} else if (*reply == 'a' || *reply == 'A') {
 			state->interactive = 0;
@@ -1761,9 +1691,10 @@ static void am_run(struct am_state *stat
 
 	unlink(am_path(state, "dirtyindex"));
 
-	refresh_and_write_cache();
+	if (refresh_and_write_cache(REFRESH_QUIET, 0, 0) < 0)
+		die(_("unable to write index file"));
 
-	if (index_has_changes(&sb)) {
+	if (repo_index_has_changes(the_repository, NULL, &sb)) {
 		write_state_bool(state, "dirtyindex", 1);
 		die(_("Dirty index: cannot apply patches (dirty: %s)"), sb.buf);
 	}
@@ -1820,22 +1751,19 @@ static void am_run(struct am_state *stat
 			 * Applying the patch to an earlier tree and merging
 			 * the result may have produced the same tree as ours.
 			 */
-			if (!apply_status && !index_has_changes(NULL)) {
+			if (!apply_status &&
+			    !repo_index_has_changes(the_repository, NULL, NULL)) {
 				say(state, stdout, _("No changes -- Patch already applied."));
 				goto next;
 			}
 		}
 
 		if (apply_status) {
-			int advice_amworkdir = 1;
-
 			printf_ln(_("Patch failed at %s %.*s"), msgnum(state),
 				linelen(state->msg), state->msg);
 
-			git_config_get_bool("advice.amworkdir", &advice_amworkdir);
-
 			if (advice_amworkdir)
-				printf_ln(_("Use 'git am --show-current-patch' to see the failed patch"));
+				advise(_("Use 'git am --show-current-patch' to see the failed patch"));
 
 			die_user_resolve(state);
 		}
@@ -1850,7 +1778,7 @@ next:
 		resume = 0;
 	}
 
-	if (!is_empty_file(am_path(state, "rewritten"))) {
+	if (!is_empty_or_missing_file(am_path(state, "rewritten"))) {
 		assert(state->rebasing);
 		copy_notes_for_rebase(state);
 		run_post_rewrite_hook(state);
@@ -1862,7 +1790,7 @@ next:
 	 */
 	if (!state->rebasing) {
 		am_destroy(state);
-		close_all_packs(the_repository->objects);
+		close_object_store(the_repository->objects);
 		run_command_v_opt(argv_gc_auto, RUN_GIT_CMD);
 	}
 }
@@ -1878,7 +1806,7 @@ static void am_resolve(struct am_state *
 
 	say(state, stdout, _("Applying: %.*s"), linelen(state->msg), state->msg);
 
-	if (!index_has_changes(NULL)) {
+	if (!repo_index_has_changes(the_repository, NULL, NULL)) {
 		printf_ln(_("No changes - did you forget to use 'git add'?\n"
 			"If there is nothing left to stage, chances are that something else\n"
 			"already introduced the same changes; you might want to skip this patch."));
@@ -1898,7 +1826,7 @@ static void am_resolve(struct am_state *
 			goto next;
 	}
 
-	rerere(0);
+	repo_rerere(the_repository, 0);
 
 	do_commit(state);
 
@@ -2017,7 +1945,7 @@ static int clean_index(const struct obje
 	if (merge_tree(remote_tree))
 		return -1;
 
-	remove_branch_state();
+	remove_branch_state(the_repository, 0);
 
 	return 0;
 }
@@ -2028,7 +1956,7 @@ static int clean_index(const struct obje
 static void am_rerere_clear(void)
 {
 	struct string_list merge_rr = STRING_LIST_INIT_DUP;
-	rerere_clear(&merge_rr);
+	rerere_clear(the_repository, &merge_rr);
 	string_list_clear(&merge_rr, 1);
 }
 
@@ -2047,6 +1975,15 @@ static void am_skip(struct am_state *sta
 	if (clean_index(&head, &head))
 		die(_("failed to clean index"));
 
+	if (state->rebasing) {
+		FILE *fp = xfopen(am_path(state, "rewritten"), "a");
+
+		assert(!is_null_oid(&state->orig_commit));
+		fprintf(fp, "%s ", oid_to_hex(&state->orig_commit));
+		fprintf(fp, "%s\n", oid_to_hex(&head));
+		fclose(fp);
+	}
+
 	am_next(state);
 	am_load(state);
 	am_run(state, 0);
@@ -2077,7 +2014,7 @@ static int safe_to_abort(const struct am
 	if (get_oid("HEAD", &head))
 		oidclr(&head);
 
-	if (!oidcmp(&head, &abort_safety))
+	if (oideq(&head, &abort_safety))
 		return 1;
 
 	warning(_("You seem to have moved HEAD since the last 'am' failure.\n"
@@ -2160,7 +2097,9 @@ static int parse_opt_patchformat(const s
 {
 	int *opt_value = opt->value;
 
-	if (!strcmp(arg, "mbox"))
+	if (unset)
+		*opt_value = PATCH_FORMAT_UNKNOWN;
+	else if (!strcmp(arg, "mbox"))
 		*opt_value = PATCH_FORMAT_MBOX;
 	else if (!strcmp(arg, "stgit"))
 		*opt_value = PATCH_FORMAT_STGIT;
@@ -2170,6 +2109,10 @@ static int parse_opt_patchformat(const s
 		*opt_value = PATCH_FORMAT_HG;
 	else if (!strcmp(arg, "mboxrd"))
 		*opt_value = PATCH_FORMAT_MBOXRD;
+	/*
+	 * Please update $__git_patchformat in git-completion.bash
+	 * when you add new options
+	 */
 	else
 		return error(_("Invalid value for --patch-format: %s"), arg);
 	return 0;
@@ -2323,7 +2266,7 @@ int cmd_am(int argc, const char **argv,
 	/* Ensure a valid committer ident can be constructed */
 	git_committer_info(IDENT_STRICT);
 
-	if (read_index_preload(&the_index, NULL) < 0)
+	if (repo_read_index_preload(the_repository, NULL, 0) < 0)
 		die(_("failed to read the index"));
 
 	if (in_progress) {
@@ -2378,6 +2321,9 @@ int cmd_am(int argc, const char **argv,
 				argv_array_push(&paths, mkpath("%s/%s", prefix, argv[i]));
 		}
 
+		if (state.interactive && !paths.argc)
+			die(_("interactive mode requires patches on the command line"));
+
 		am_setup(&state, patch_format, paths.argv, keep_cr);
 
 		argv_array_clear(&paths);
diff -pruN 1.2.1+git2.18.0-1/git/builtin/apply.c 1.2.3+git2.25.1-1/git/builtin/apply.c
--- 1.2.1+git2.18.0-1/git/builtin/apply.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/builtin/apply.c	2020-02-17 04:47:35.000000000 +0000
@@ -16,7 +16,7 @@ int cmd_apply(int argc, const char **arg
 	int ret;
 	struct apply_state state;
 
-	if (init_apply_state(&state, prefix))
+	if (init_apply_state(&state, the_repository, prefix))
 		exit(128);
 
 	argc = apply_parse_options(argc, argv,
diff -pruN 1.2.1+git2.18.0-1/git/builtin/archive.c 1.2.3+git2.25.1-1/git/builtin/archive.c
--- 1.2.1+git2.18.0-1/git/builtin/archive.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/builtin/archive.c	2020-02-17 04:47:35.000000000 +0000
@@ -27,10 +27,10 @@ static int run_remote_archiver(int argc,
 			       const char *remote, const char *exec,
 			       const char *name_hint)
 {
-	char *buf;
 	int fd[2], i, rv;
 	struct transport *transport;
 	struct remote *_remote;
+	struct packet_reader reader;
 
 	_remote = remote_get(remote);
 	if (!_remote->url[0])
@@ -53,18 +53,19 @@ static int run_remote_archiver(int argc,
 		packet_write_fmt(fd[1], "argument %s\n", argv[i]);
 	packet_flush(fd[1]);
 
-	buf = packet_read_line(fd[0], NULL);
-	if (!buf)
+	packet_reader_init(&reader, fd[0], NULL, 0,
+			   PACKET_READ_CHOMP_NEWLINE |
+			   PACKET_READ_DIE_ON_ERR_PACKET);
+
+	if (packet_reader_read(&reader) != PACKET_READ_NORMAL)
 		die(_("git archive: expected ACK/NAK, got a flush packet"));
-	if (strcmp(buf, "ACK")) {
-		if (starts_with(buf, "NACK "))
-			die(_("git archive: NACK %s"), buf + 5);
-		if (starts_with(buf, "ERR "))
-			die(_("remote error: %s"), buf + 4);
+	if (strcmp(reader.line, "ACK")) {
+		if (starts_with(reader.line, "NACK "))
+			die(_("git archive: NACK %s"), reader.line + 5);
 		die(_("git archive: protocol error"));
 	}
 
-	if (packet_read_line(fd[0], NULL))
+	if (packet_reader_read(&reader) != PACKET_READ_FLUSH)
 		die(_("git archive: expected a flush"));
 
 	/* Now, start reading from fd[0] and spit it out to stdout */
@@ -97,6 +98,8 @@ int cmd_archive(int argc, const char **a
 	argc = parse_options(argc, argv, prefix, local_opts, NULL,
 			     PARSE_OPT_KEEP_ALL);
 
+	init_archivers();
+
 	if (output)
 		create_output_file(output);
 
@@ -105,5 +108,5 @@ int cmd_archive(int argc, const char **a
 
 	setvbuf(stderr, NULL, _IOLBF, BUFSIZ);
 
-	return write_archive(argc, argv, prefix, output, 0);
+	return write_archive(argc, argv, prefix, the_repository, output, 0);
 }
diff -pruN 1.2.1+git2.18.0-1/git/builtin/bisect--helper.c 1.2.3+git2.25.1-1/git/builtin/bisect--helper.c
--- 1.2.1+git2.18.0-1/git/builtin/bisect--helper.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/builtin/bisect--helper.c	2020-02-17 04:47:35.000000000 +0000
@@ -3,18 +3,58 @@
 #include "parse-options.h"
 #include "bisect.h"
 #include "refs.h"
+#include "dir.h"
+#include "argv-array.h"
+#include "run-command.h"
+#include "prompt.h"
+#include "quote.h"
 
 static GIT_PATH_FUNC(git_path_bisect_terms, "BISECT_TERMS")
 static GIT_PATH_FUNC(git_path_bisect_expected_rev, "BISECT_EXPECTED_REV")
 static GIT_PATH_FUNC(git_path_bisect_ancestors_ok, "BISECT_ANCESTORS_OK")
+static GIT_PATH_FUNC(git_path_bisect_start, "BISECT_START")
+static GIT_PATH_FUNC(git_path_bisect_head, "BISECT_HEAD")
+static GIT_PATH_FUNC(git_path_bisect_log, "BISECT_LOG")
+static GIT_PATH_FUNC(git_path_head_name, "head-name")
+static GIT_PATH_FUNC(git_path_bisect_names, "BISECT_NAMES")
 
 static const char * const git_bisect_helper_usage[] = {
 	N_("git bisect--helper --next-all [--no-checkout]"),
 	N_("git bisect--helper --write-terms <bad_term> <good_term>"),
 	N_("git bisect--helper --bisect-clean-state"),
+	N_("git bisect--helper --bisect-reset [<commit>]"),
+	N_("git bisect--helper --bisect-write [--no-log] <state> <revision> <good_term> <bad_term>"),
+	N_("git bisect--helper --bisect-check-and-set-terms <command> <good_term> <bad_term>"),
+	N_("git bisect--helper --bisect-next-check <good_term> <bad_term> [<term>]"),
+	N_("git bisect--helper --bisect-terms [--term-good | --term-old | --term-bad | --term-new]"),
+	N_("git bisect--helper --bisect-start [--term-{old,good}=<term> --term-{new,bad}=<term>]"
+					     "[--no-checkout] [<bad> [<good>...]] [--] [<paths>...]"),
 	NULL
 };
 
+struct bisect_terms {
+	char *term_good;
+	char *term_bad;
+};
+
+static void free_terms(struct bisect_terms *terms)
+{
+	FREE_AND_NULL(terms->term_good);
+	FREE_AND_NULL(terms->term_bad);
+}
+
+static void set_terms(struct bisect_terms *terms, const char *bad,
+		      const char *good)
+{
+	free((void *)terms->term_good);
+	terms->term_good = xstrdup(good);
+	free((void *)terms->term_bad);
+	terms->term_bad = xstrdup(bad);
+}
+
+static const char *vocab_bad = "bad|new";
+static const char *vocab_good = "good|old";
+
 /*
  * Check whether the string `term` belongs to the set of strings
  * included in the variable arguments.
@@ -106,15 +146,486 @@ static void check_expected_revs(const ch
 	}
 }
 
+static int bisect_reset(const char *commit)
+{
+	struct strbuf branch = STRBUF_INIT;
+
+	if (!commit) {
+		if (strbuf_read_file(&branch, git_path_bisect_start(), 0) < 1) {
+			printf(_("We are not bisecting.\n"));
+			return 0;
+		}
+		strbuf_rtrim(&branch);
+	} else {
+		struct object_id oid;
+
+		if (get_oid_commit(commit, &oid))
+			return error(_("'%s' is not a valid commit"), commit);
+		strbuf_addstr(&branch, commit);
+	}
+
+	if (!file_exists(git_path_bisect_head())) {
+		struct argv_array argv = ARGV_ARRAY_INIT;
+
+		argv_array_pushl(&argv, "checkout", branch.buf, "--", NULL);
+		if (run_command_v_opt(argv.argv, RUN_GIT_CMD)) {
+			error(_("could not check out original"
+				" HEAD '%s'. Try 'git bisect"
+				" reset <commit>'."), branch.buf);
+			strbuf_release(&branch);
+			argv_array_clear(&argv);
+			return -1;
+		}
+		argv_array_clear(&argv);
+	}
+
+	strbuf_release(&branch);
+	return bisect_clean_state();
+}
+
+static void log_commit(FILE *fp, char *fmt, const char *state,
+		       struct commit *commit)
+{
+	struct pretty_print_context pp = {0};
+	struct strbuf commit_msg = STRBUF_INIT;
+	char *label = xstrfmt(fmt, state);
+
+	format_commit_message(commit, "%s", &commit_msg, &pp);
+
+	fprintf(fp, "# %s: [%s] %s\n", label, oid_to_hex(&commit->object.oid),
+		commit_msg.buf);
+
+	strbuf_release(&commit_msg);
+	free(label);
+}
+
+static int bisect_write(const char *state, const char *rev,
+			const struct bisect_terms *terms, int nolog)
+{
+	struct strbuf tag = STRBUF_INIT;
+	struct object_id oid;
+	struct commit *commit;
+	FILE *fp = NULL;
+	int retval = 0;
+
+	if (!strcmp(state, terms->term_bad)) {
+		strbuf_addf(&tag, "refs/bisect/%s", state);
+	} else if (one_of(state, terms->term_good, "skip", NULL)) {
+		strbuf_addf(&tag, "refs/bisect/%s-%s", state, rev);
+	} else {
+		retval = error(_("Bad bisect_write argument: %s"), state);
+		goto finish;
+	}
+
+	if (get_oid(rev, &oid)) {
+		retval = error(_("couldn't get the oid of the rev '%s'"), rev);
+		goto finish;
+	}
+
+	if (update_ref(NULL, tag.buf, &oid, NULL, 0,
+		       UPDATE_REFS_MSG_ON_ERR)) {
+		retval = -1;
+		goto finish;
+	}
+
+	fp = fopen(git_path_bisect_log(), "a");
+	if (!fp) {
+		retval = error_errno(_("couldn't open the file '%s'"), git_path_bisect_log());
+		goto finish;
+	}
+
+	commit = lookup_commit_reference(the_repository, &oid);
+	log_commit(fp, "%s", state, commit);
+
+	if (!nolog)
+		fprintf(fp, "git bisect %s %s\n", state, rev);
+
+finish:
+	if (fp)
+		fclose(fp);
+	strbuf_release(&tag);
+	return retval;
+}
+
+static int check_and_set_terms(struct bisect_terms *terms, const char *cmd)
+{
+	int has_term_file = !is_empty_or_missing_file(git_path_bisect_terms());
+
+	if (one_of(cmd, "skip", "start", "terms", NULL))
+		return 0;
+
+	if (has_term_file && strcmp(cmd, terms->term_bad) &&
+	    strcmp(cmd, terms->term_good))
+		return error(_("Invalid command: you're currently in a "
+				"%s/%s bisect"), terms->term_bad,
+				terms->term_good);
+
+	if (!has_term_file) {
+		if (one_of(cmd, "bad", "good", NULL)) {
+			set_terms(terms, "bad", "good");
+			return write_terms(terms->term_bad, terms->term_good);
+		}
+		if (one_of(cmd, "new", "old", NULL)) {
+			set_terms(terms, "new", "old");
+			return write_terms(terms->term_bad, terms->term_good);
+		}
+	}
+
+	return 0;
+}
+
+static int mark_good(const char *refname, const struct object_id *oid,
+		     int flag, void *cb_data)
+{
+	int *m_good = (int *)cb_data;
+	*m_good = 0;
+	return 1;
+}
+
+static const char need_bad_and_good_revision_warning[] =
+	N_("You need to give me at least one %s and %s revision.\n"
+	   "You can use \"git bisect %s\" and \"git bisect %s\" for that.");
+
+static const char need_bisect_start_warning[] =
+	N_("You need to start by \"git bisect start\".\n"
+	   "You then need to give me at least one %s and %s revision.\n"
+	   "You can use \"git bisect %s\" and \"git bisect %s\" for that.");
+
+static int bisect_next_check(const struct bisect_terms *terms,
+			     const char *current_term)
+{
+	int missing_good = 1, missing_bad = 1, retval = 0;
+	const char *bad_ref = xstrfmt("refs/bisect/%s", terms->term_bad);
+	const char *good_glob = xstrfmt("%s-*", terms->term_good);
+
+	if (ref_exists(bad_ref))
+		missing_bad = 0;
+
+	for_each_glob_ref_in(mark_good, good_glob, "refs/bisect/",
+			     (void *) &missing_good);
+
+	if (!missing_good && !missing_bad)
+		goto finish;
+
+	if (!current_term) {
+		retval = -1;
+		goto finish;
+	}
+
+	if (missing_good && !missing_bad &&
+	    !strcmp(current_term, terms->term_good)) {
+		char *yesno;
+		/*
+		 * have bad (or new) but not good (or old). We could bisect
+		 * although this is less optimum.
+		 */
+		warning(_("bisecting only with a %s commit"), terms->term_bad);
+		if (!isatty(0))
+			goto finish;
+		/*
+		 * TRANSLATORS: Make sure to include [Y] and [n] in your
+		 * translation. The program will only accept English input
+		 * at this point.
+		 */
+		yesno = git_prompt(_("Are you sure [Y/n]? "), PROMPT_ECHO);
+		if (starts_with(yesno, "N") || starts_with(yesno, "n"))
+			retval = -1;
+		goto finish;
+	}
+	if (!is_empty_or_missing_file(git_path_bisect_start())) {
+		retval = error(_(need_bad_and_good_revision_warning),
+			       vocab_bad, vocab_good, vocab_bad, vocab_good);
+	} else {
+		retval = error(_(need_bisect_start_warning),
+			       vocab_good, vocab_bad, vocab_good, vocab_bad);
+	}
+
+finish:
+	free((void *) good_glob);
+	free((void *) bad_ref);
+	return retval;
+}
+
+static int get_terms(struct bisect_terms *terms)
+{
+	struct strbuf str = STRBUF_INIT;
+	FILE *fp = NULL;
+	int res = 0;
+
+	fp = fopen(git_path_bisect_terms(), "r");
+	if (!fp) {
+		res = -1;
+		goto finish;
+	}
+
+	free_terms(terms);
+	strbuf_getline_lf(&str, fp);
+	terms->term_bad = strbuf_detach(&str, NULL);
+	strbuf_getline_lf(&str, fp);
+	terms->term_good = strbuf_detach(&str, NULL);
+
+finish:
+	if (fp)
+		fclose(fp);
+	strbuf_release(&str);
+	return res;
+}
+
+static int bisect_terms(struct bisect_terms *terms, const char *option)
+{
+	if (get_terms(terms))
+		return error(_("no terms defined"));
+
+	if (option == NULL) {
+		printf(_("Your current terms are %s for the old state\n"
+			 "and %s for the new state.\n"),
+		       terms->term_good, terms->term_bad);
+		return 0;
+	}
+	if (one_of(option, "--term-good", "--term-old", NULL))
+		printf("%s\n", terms->term_good);
+	else if (one_of(option, "--term-bad", "--term-new", NULL))
+		printf("%s\n", terms->term_bad);
+	else
+		return error(_("invalid argument %s for 'git bisect terms'.\n"
+			       "Supported options are: "
+			       "--term-good|--term-old and "
+			       "--term-bad|--term-new."), option);
+
+	return 0;
+}
+
+static int bisect_append_log_quoted(const char **argv)
+{
+	int retval = 0;
+	FILE *fp = fopen(git_path_bisect_log(), "a");
+	struct strbuf orig_args = STRBUF_INIT;
+
+	if (!fp)
+		return -1;
+
+	if (fprintf(fp, "git bisect start") < 1) {
+		retval = -1;
+		goto finish;
+	}
+
+	sq_quote_argv(&orig_args, argv);
+	if (fprintf(fp, "%s\n", orig_args.buf) < 1)
+		retval = -1;
+
+finish:
+	fclose(fp);
+	strbuf_release(&orig_args);
+	return retval;
+}
+
+static int bisect_start(struct bisect_terms *terms, int no_checkout,
+			const char **argv, int argc)
+{
+	int i, has_double_dash = 0, must_write_terms = 0, bad_seen = 0;
+	int flags, pathspec_pos, retval = 0;
+	struct string_list revs = STRING_LIST_INIT_DUP;
+	struct string_list states = STRING_LIST_INIT_DUP;
+	struct strbuf start_head = STRBUF_INIT;
+	struct strbuf bisect_names = STRBUF_INIT;
+	struct object_id head_oid;
+	struct object_id oid;
+	const char *head;
+
+	if (is_bare_repository())
+		no_checkout = 1;
+
+	/*
+	 * Check for one bad and then some good revisions
+	 */
+	for (i = 0; i < argc; i++) {
+		if (!strcmp(argv[i], "--")) {
+			has_double_dash = 1;
+			break;
+		}
+	}
+
+	for (i = 0; i < argc; i++) {
+		const char *arg = argv[i];
+		if (!strcmp(argv[i], "--")) {
+			break;
+		} else if (!strcmp(arg, "--no-checkout")) {
+			no_checkout = 1;
+		} else if (!strcmp(arg, "--term-good") ||
+			 !strcmp(arg, "--term-old")) {
+			must_write_terms = 1;
+			free((void *) terms->term_good);
+			terms->term_good = xstrdup(argv[++i]);
+		} else if (skip_prefix(arg, "--term-good=", &arg) ||
+			   skip_prefix(arg, "--term-old=", &arg)) {
+			must_write_terms = 1;
+			free((void *) terms->term_good);
+			terms->term_good = xstrdup(arg);
+		} else if (!strcmp(arg, "--term-bad") ||
+			 !strcmp(arg, "--term-new")) {
+			must_write_terms = 1;
+			free((void *) terms->term_bad);
+			terms->term_bad = xstrdup(argv[++i]);
+		} else if (skip_prefix(arg, "--term-bad=", &arg) ||
+			   skip_prefix(arg, "--term-new=", &arg)) {
+			must_write_terms = 1;
+			free((void *) terms->term_bad);
+			terms->term_bad = xstrdup(arg);
+		} else if (starts_with(arg, "--") &&
+			 !one_of(arg, "--term-good", "--term-bad", NULL)) {
+			return error(_("unrecognized option: '%s'"), arg);
+		} else {
+			char *commit_id = xstrfmt("%s^{commit}", arg);
+			if (get_oid(commit_id, &oid) && has_double_dash)
+				die(_("'%s' does not appear to be a valid "
+				      "revision"), arg);
+
+			string_list_append(&revs, oid_to_hex(&oid));
+			free(commit_id);
+		}
+	}
+	pathspec_pos = i;
+
+	/*
+	 * The user ran "git bisect start <sha1> <sha1>", hence did not
+	 * explicitly specify the terms, but we are already starting to
+	 * set references named with the default terms, and won't be able
+	 * to change afterwards.
+	 */
+	if (revs.nr)
+		must_write_terms = 1;
+	for (i = 0; i < revs.nr; i++) {
+		if (bad_seen) {
+			string_list_append(&states, terms->term_good);
+		} else {
+			bad_seen = 1;
+			string_list_append(&states, terms->term_bad);
+		}
+	}
+
+	/*
+	 * Verify HEAD
+	 */
+	head = resolve_ref_unsafe("HEAD", 0, &head_oid, &flags);
+	if (!head)
+		if (get_oid("HEAD", &head_oid))
+			return error(_("bad HEAD - I need a HEAD"));
+
+	/*
+	 * Check if we are bisecting
+	 */
+	if (!is_empty_or_missing_file(git_path_bisect_start())) {
+		/* Reset to the rev from where we started */
+		strbuf_read_file(&start_head, git_path_bisect_start(), 0);
+		strbuf_trim(&start_head);
+		if (!no_checkout) {
+			struct argv_array argv = ARGV_ARRAY_INIT;
+
+			argv_array_pushl(&argv, "checkout", start_head.buf,
+					 "--", NULL);
+			if (run_command_v_opt(argv.argv, RUN_GIT_CMD)) {
+				retval = error(_("checking out '%s' failed."
+						 " Try 'git bisect start "
+						 "<valid-branch>'."),
+					       start_head.buf);
+				goto finish;
+			}
+		}
+	} else {
+		/* Get the rev from where we start. */
+		if (!get_oid(head, &head_oid) &&
+		    !starts_with(head, "refs/heads/")) {
+			strbuf_reset(&start_head);
+			strbuf_addstr(&start_head, oid_to_hex(&head_oid));
+		} else if (!get_oid(head, &head_oid) &&
+			   skip_prefix(head, "refs/heads/", &head)) {
+			/*
+			 * This error message should only be triggered by
+			 * cogito usage, and cogito users should understand
+			 * it relates to cg-seek.
+			 */
+			if (!is_empty_or_missing_file(git_path_head_name()))
+				return error(_("won't bisect on cg-seek'ed tree"));
+			strbuf_addstr(&start_head, head);
+		} else {
+			return error(_("bad HEAD - strange symbolic ref"));
+		}
+	}
+
+	/*
+	 * Get rid of any old bisect state.
+	 */
+	if (bisect_clean_state())
+		return -1;
+
+	/*
+	 * In case of mistaken revs or checkout error, or signals received,
+	 * "bisect_auto_next" below may exit or misbehave.
+	 * We have to trap this to be able to clean up using
+	 * "bisect_clean_state".
+	 */
+
+	/*
+	 * Write new start state
+	 */
+	write_file(git_path_bisect_start(), "%s\n", start_head.buf);
+
+	if (no_checkout) {
+		if (get_oid(start_head.buf, &oid) < 0) {
+			retval = error(_("invalid ref: '%s'"), start_head.buf);
+			goto finish;
+		}
+		if (update_ref(NULL, "BISECT_HEAD", &oid, NULL, 0,
+			       UPDATE_REFS_MSG_ON_ERR)) {
+			retval = -1;
+			goto finish;
+		}
+	}
+
+	if (pathspec_pos < argc - 1)
+		sq_quote_argv(&bisect_names, argv + pathspec_pos);
+	write_file(git_path_bisect_names(), "%s\n", bisect_names.buf);
+
+	for (i = 0; i < states.nr; i++)
+		if (bisect_write(states.items[i].string,
+				 revs.items[i].string, terms, 1)) {
+			retval = -1;
+			goto finish;
+		}
+
+	if (must_write_terms && write_terms(terms->term_bad,
+					    terms->term_good)) {
+		retval = -1;
+		goto finish;
+	}
+
+	retval = bisect_append_log_quoted(argv);
+	if (retval)
+		retval = -1;
+
+finish:
+	string_list_clear(&revs, 0);
+	string_list_clear(&states, 0);
+	strbuf_release(&start_head);
+	strbuf_release(&bisect_names);
+	return retval;
+}
+
 int cmd_bisect__helper(int argc, const char **argv, const char *prefix)
 {
 	enum {
 		NEXT_ALL = 1,
 		WRITE_TERMS,
 		BISECT_CLEAN_STATE,
-		CHECK_EXPECTED_REVS
+		CHECK_EXPECTED_REVS,
+		BISECT_RESET,
+		BISECT_WRITE,
+		CHECK_AND_SET_TERMS,
+		BISECT_NEXT_CHECK,
+		BISECT_TERMS,
+		BISECT_START
 	} cmdmode = 0;
-	int no_checkout = 0;
+	int no_checkout = 0, res = 0, nolog = 0;
 	struct option options[] = {
 		OPT_CMDMODE(0, "next-all", &cmdmode,
 			 N_("perform 'git bisect next'"), NEXT_ALL),
@@ -124,20 +635,36 @@ int cmd_bisect__helper(int argc, const c
 			 N_("cleanup the bisection state"), BISECT_CLEAN_STATE),
 		OPT_CMDMODE(0, "check-expected-revs", &cmdmode,
 			 N_("check for expected revs"), CHECK_EXPECTED_REVS),
+		OPT_CMDMODE(0, "bisect-reset", &cmdmode,
+			 N_("reset the bisection state"), BISECT_RESET),
+		OPT_CMDMODE(0, "bisect-write", &cmdmode,
+			 N_("write out the bisection state in BISECT_LOG"), BISECT_WRITE),
+		OPT_CMDMODE(0, "check-and-set-terms", &cmdmode,
+			 N_("check and set terms in a bisection state"), CHECK_AND_SET_TERMS),
+		OPT_CMDMODE(0, "bisect-next-check", &cmdmode,
+			 N_("check whether bad or good terms exist"), BISECT_NEXT_CHECK),
+		OPT_CMDMODE(0, "bisect-terms", &cmdmode,
+			 N_("print out the bisect terms"), BISECT_TERMS),
+		OPT_CMDMODE(0, "bisect-start", &cmdmode,
+			 N_("start the bisect session"), BISECT_START),
 		OPT_BOOL(0, "no-checkout", &no_checkout,
 			 N_("update BISECT_HEAD instead of checking out the current commit")),
+		OPT_BOOL(0, "no-log", &nolog,
+			 N_("no log for BISECT_WRITE")),
 		OPT_END()
 	};
+	struct bisect_terms terms = { .term_good = NULL, .term_bad = NULL };
 
 	argc = parse_options(argc, argv, prefix, options,
-			     git_bisect_helper_usage, 0);
+			     git_bisect_helper_usage,
+			     PARSE_OPT_KEEP_DASHDASH | PARSE_OPT_KEEP_UNKNOWN);
 
 	if (!cmdmode)
 		usage_with_options(git_bisect_helper_usage, options);
 
 	switch (cmdmode) {
 	case NEXT_ALL:
-		return bisect_next_all(prefix, no_checkout);
+		return bisect_next_all(the_repository, prefix, no_checkout);
 	case WRITE_TERMS:
 		if (argc != 2)
 			return error(_("--write-terms requires two arguments"));
@@ -149,8 +676,40 @@ int cmd_bisect__helper(int argc, const c
 	case CHECK_EXPECTED_REVS:
 		check_expected_revs(argv, argc);
 		return 0;
+	case BISECT_RESET:
+		if (argc > 1)
+			return error(_("--bisect-reset requires either no argument or a commit"));
+		return !!bisect_reset(argc ? argv[0] : NULL);
+	case BISECT_WRITE:
+		if (argc != 4 && argc != 5)
+			return error(_("--bisect-write requires either 4 or 5 arguments"));
+		set_terms(&terms, argv[3], argv[2]);
+		res = bisect_write(argv[0], argv[1], &terms, nolog);
+		break;
+	case CHECK_AND_SET_TERMS:
+		if (argc != 3)
+			return error(_("--check-and-set-terms requires 3 arguments"));
+		set_terms(&terms, argv[2], argv[1]);
+		res = check_and_set_terms(&terms, argv[0]);
+		break;
+	case BISECT_NEXT_CHECK:
+		if (argc != 2 && argc != 3)
+			return error(_("--bisect-next-check requires 2 or 3 arguments"));
+		set_terms(&terms, argv[1], argv[0]);
+		res = bisect_next_check(&terms, argc == 3 ? argv[2] : NULL);
+		break;
+	case BISECT_TERMS:
+		if (argc > 1)
+			return error(_("--bisect-terms requires 0 or 1 argument"));
+		res = bisect_terms(&terms, argc == 1 ? argv[0] : NULL);
+		break;
+	case BISECT_START:
+		set_terms(&terms, "bad", "good");
+		res = bisect_start(&terms, no_checkout, argv, argc);
+		break;
 	default:
 		return error("BUG: unknown subcommand '%d'", cmdmode);
 	}
-	return 0;
+	free_terms(&terms);
+	return !!res;
 }
diff -pruN 1.2.1+git2.18.0-1/git/builtin/blame.c 1.2.3+git2.25.1-1/git/builtin/blame.c
--- 1.2.1+git2.18.0-1/git/builtin/blame.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/builtin/blame.c	2020-02-17 04:47:35.000000000 +0000
@@ -9,6 +9,7 @@
 #include "config.h"
 #include "color.h"
 #include "builtin.h"
+#include "repository.h"
 #include "commit.h"
 #include "diff.h"
 #include "revision.h"
@@ -23,8 +24,9 @@
 #include "line-log.h"
 #include "dir.h"
 #include "progress.h"
+#include "object-store.h"
 #include "blame.h"
-#include "string-list.h"
+#include "refs.h"
 
 static char blame_usage[] = N_("git blame [<options>] [<rev-opts>] [<rev>] [--] <file>");
 
@@ -50,14 +52,17 @@ static int no_whole_file_rename;
 static int show_progress;
 static char repeated_meta_color[COLOR_MAXLEN];
 static int coloring_mode;
+static struct string_list ignore_revs_file_list = STRING_LIST_INIT_NODUP;
+static int mark_unblamable_lines;
+static int mark_ignored_lines;
 
 static struct date_mode blame_date_mode = { DATE_ISO8601 };
 static size_t blame_date_width;
 
 static struct string_list mailmap = STRING_LIST_INIT_NODUP;
 
-#ifndef DEBUG
-#define DEBUG 0
+#ifndef DEBUG_BLAME
+#define DEBUG_BLAME 0
 #endif
 
 static unsigned blame_move_score;
@@ -314,18 +319,18 @@ static const char *format_time(timestamp
 	return time_buf.buf;
 }
 
-#define OUTPUT_ANNOTATE_COMPAT	001
-#define OUTPUT_LONG_OBJECT_NAME	002
-#define OUTPUT_RAW_TIMESTAMP	004
-#define OUTPUT_PORCELAIN	010
-#define OUTPUT_SHOW_NAME	020
-#define OUTPUT_SHOW_NUMBER	040
-#define OUTPUT_SHOW_SCORE	0100
-#define OUTPUT_NO_AUTHOR	0200
-#define OUTPUT_SHOW_EMAIL	0400
-#define OUTPUT_LINE_PORCELAIN	01000
-#define OUTPUT_COLOR_LINE	02000
-#define OUTPUT_SHOW_AGE_WITH_COLOR	04000
+#define OUTPUT_ANNOTATE_COMPAT      (1U<<0)
+#define OUTPUT_LONG_OBJECT_NAME     (1U<<1)
+#define OUTPUT_RAW_TIMESTAMP        (1U<<2)
+#define OUTPUT_PORCELAIN            (1U<<3)
+#define OUTPUT_SHOW_NAME            (1U<<4)
+#define OUTPUT_SHOW_NUMBER          (1U<<5)
+#define OUTPUT_SHOW_SCORE           (1U<<6)
+#define OUTPUT_NO_AUTHOR            (1U<<7)
+#define OUTPUT_SHOW_EMAIL           (1U<<8)
+#define OUTPUT_LINE_PORCELAIN       (1U<<9)
+#define OUTPUT_COLOR_LINE           (1U<<10)
+#define OUTPUT_SHOW_AGE_WITH_COLOR  (1U<<11)
 
 static void emit_porcelain_details(struct blame_origin *suspect, int repeat)
 {
@@ -408,7 +413,7 @@ static void parse_color_fields(const cha
 	}
 
 	if (next == EXPECT_COLOR)
-		die (_("must end with a color"));
+		die(_("must end with a color"));
 
 	colorfield[colorfield_nr].hop = TIME_MAX;
 	string_list_clear(&l, 0);
@@ -454,7 +459,7 @@ static void emit_other(struct blame_scor
 
 	for (cnt = 0; cnt < ent->num_lines; cnt++) {
 		char ch;
-		int length = (opt & OUTPUT_LONG_OBJECT_NAME) ? GIT_SHA1_HEXSZ : abbrev;
+		int length = (opt & OUTPUT_LONG_OBJECT_NAME) ? the_hash_algo->hexsz : abbrev;
 
 		if (opt & OUTPUT_COLOR_LINE) {
 			if (cnt > 0) {
@@ -477,6 +482,14 @@ static void emit_other(struct blame_scor
 			}
 		}
 
+		if (mark_unblamable_lines && ent->unblamable) {
+			length--;
+			putchar('*');
+		}
+		if (mark_ignored_lines && ent->ignored) {
+			length--;
+			putchar('?');
+		}
 		printf("%.*s", length, hex);
 		if (opt & OUTPUT_ANNOTATE_COMPAT) {
 			const char *name;
@@ -543,7 +556,7 @@ static void output(struct blame_scoreboa
 			struct commit *commit = ent->suspect->commit;
 			if (commit->object.flags & MORE_THAN_ONE_PATH)
 				continue;
-			for (suspect = commit->util; suspect; suspect = suspect->next) {
+			for (suspect = get_blame_suspects(commit); suspect; suspect = suspect->next) {
 				if (suspect->guilty && count++) {
 					commit->object.flags |= MORE_THAN_ONE_PATH;
 					break;
@@ -576,7 +589,7 @@ static int read_ancestry(const char *gra
 		/* The format is just "Commit Parent1 Parent2 ...\n" */
 		struct commit_graft *graft = read_graft_line(&buf);
 		if (graft)
-			register_commit_graft(graft, 0);
+			register_commit_graft(the_repository, graft, 0);
 	}
 	fclose(fp);
 	strbuf_release(&buf);
@@ -693,6 +706,24 @@ static int git_blame_config(const char *
 		parse_date_format(value, &blame_date_mode);
 		return 0;
 	}
+	if (!strcmp(var, "blame.ignorerevsfile")) {
+		const char *str;
+		int ret;
+
+		ret = git_config_pathname(&str, var, value);
+		if (ret)
+			return ret;
+		string_list_insert(&ignore_revs_file_list, str);
+		return 0;
+	}
+	if (!strcmp(var, "blame.markunblamablelines")) {
+		mark_unblamable_lines = git_config_bool(var, value);
+		return 0;
+	}
+	if (!strcmp(var, "blame.markignoredlines")) {
+		mark_ignored_lines = git_config_bool(var, value);
+		return 0;
+	}
 	if (!strcmp(var, "color.blame.repeatedlines")) {
 		if (color_parse_mem(value, strlen(value), repeated_meta_color))
 			warning(_("invalid color '%s' in color.blame.repeatedLines"),
@@ -730,6 +761,8 @@ static int blame_copy_callback(const str
 {
 	int *opt = option->value;
 
+	BUG_ON_OPT_NEG(unset);
+
 	/*
 	 * -C enables copy from removed files;
 	 * -C -C enables copy from existing files, but only
@@ -752,6 +785,8 @@ static int blame_move_callback(const str
 {
 	int *opt = option->value;
 
+	BUG_ON_OPT_NEG(unset);
+
 	*opt |= PICKAXE_BLAME_MOVE;
 
 	if (arg)
@@ -768,6 +803,27 @@ static int is_a_rev(const char *name)
 	return OBJ_NONE < oid_object_info(the_repository, &oid, NULL);
 }
 
+static void build_ignorelist(struct blame_scoreboard *sb,
+			     struct string_list *ignore_revs_file_list,
+			     struct string_list *ignore_rev_list)
+{
+	struct string_list_item *i;
+	struct object_id oid;
+
+	oidset_init(&sb->ignore_list, 0);
+	for_each_string_list_item(i, ignore_revs_file_list) {
+		if (!strcmp(i->string, ""))
+			oidset_clear(&sb->ignore_list);
+		else
+			oidset_parse_file(&sb->ignore_list, i->string);
+	}
+	for_each_string_list_item(i, ignore_rev_list) {
+		if (get_oid_committish(i->string, &oid))
+			die(_("cannot find revision %s to ignore"), i->string);
+		oidset_insert(&sb->ignore_list, &oid);
+	}
+}
+
 int cmd_blame(int argc, const char **argv, const char *prefix)
 {
 	struct rev_info revs;
@@ -779,6 +835,7 @@ int cmd_blame(int argc, const char **arg
 	struct progress_info pi = { NULL, 0 };
 
 	struct string_list range_list = STRING_LIST_INIT_NODUP;
+	struct string_list ignore_rev_list = STRING_LIST_INIT_NODUP;
 	int output_option = 0, opt = 0;
 	int show_stats = 0;
 	const char *revs_file = NULL;
@@ -800,16 +857,10 @@ int cmd_blame(int argc, const char **arg
 		OPT_BIT('s', NULL, &output_option, N_("Suppress author name and timestamp (Default: off)"), OUTPUT_NO_AUTHOR),
 		OPT_BIT('e', "show-email", &output_option, N_("Show author email instead of name (Default: off)"), OUTPUT_SHOW_EMAIL),
 		OPT_BIT('w', NULL, &xdl_opts, N_("Ignore whitespace differences"), XDF_IGNORE_WHITESPACE),
+		OPT_STRING_LIST(0, "ignore-rev", &ignore_rev_list, N_("rev"), N_("Ignore <rev> when blaming")),
+		OPT_STRING_LIST(0, "ignore-revs-file", &ignore_revs_file_list, N_("file"), N_("Ignore revisions from <file>")),
 		OPT_BIT(0, "color-lines", &output_option, N_("color redundant metadata from previous line differently"), OUTPUT_COLOR_LINE),
 		OPT_BIT(0, "color-by-age", &output_option, N_("color lines by age"), OUTPUT_SHOW_AGE_WITH_COLOR),
-
-		/*
-		 * The following two options are parsed by parse_revision_opt()
-		 * and are only included here to get included in the "-h"
-		 * output:
-		 */
-		{ OPTION_LOWLEVEL_CALLBACK, 0, "indent-heuristic", NULL, NULL, N_("Use an experimental heuristic to improve diffs"), PARSE_OPT_NOARG, parse_opt_unknown_cb },
-
 		OPT_BIT(0, "minimal", &xdl_opts, N_("Spend extra cycles to find better match"), XDF_NEED_MINIMAL),
 		OPT_STRING('S', NULL, &revs_file, N_("file"), N_("Use revisions from <file> instead of calling git-rev-list")),
 		OPT_STRING(0, "contents", &contents_from, N_("file"), N_("Use <file>'s contents as the final image")),
@@ -825,10 +876,11 @@ int cmd_blame(int argc, const char **arg
 	struct range_set ranges;
 	unsigned int range_i;
 	long anchor;
+	const int hexsz = the_hash_algo->hexsz;
 
 	setup_default_color_by_age();
 	git_config(git_blame_config, &output_option);
-	init_revisions(&revs, NULL);
+	repo_init_revisions(the_repository, &revs, NULL);
 	revs.date_mode = blame_date_mode;
 	revs.diffopt.flags.allow_textconv = 1;
 	revs.diffopt.flags.follow_renames = 1;
@@ -844,6 +896,8 @@ int cmd_blame(int argc, const char **arg
 		case PARSE_OPT_HELP:
 		case PARSE_OPT_ERROR:
 			exit(129);
+		case PARSE_OPT_COMPLETE:
+			exit(0);
 		case PARSE_OPT_DONE:
 			if (ctx.argv[0])
 				dashdash_pos = ctx.cpidx;
@@ -869,11 +923,11 @@ parse_done:
 	} else if (show_progress < 0)
 		show_progress = isatty(2);
 
-	if (0 < abbrev && abbrev < GIT_SHA1_HEXSZ)
+	if (0 < abbrev && abbrev < hexsz)
 		/* one more abbrev length is needed for the boundary commit */
 		abbrev++;
 	else if (!abbrev)
-		abbrev = GIT_SHA1_HEXSZ;
+		abbrev = hexsz;
 
 	if (revs_file && read_ancestry(revs_file))
 		die_errno("reading graft file '%s' failed", revs_file);
@@ -917,6 +971,10 @@ parse_done:
 		 */
 		blame_date_width = utf8_strwidth(_("4 years, 11 months ago")) + 1; /* add the null */
 		break;
+	case DATE_HUMAN:
+		/* If the year is shown, no time is shown */
+		blame_date_width = sizeof("Thu Oct 19 16:00");
+		break;
 	case DATE_NORMAL:
 		blame_date_width = sizeof("Thu Oct 19 16:00:04 2006 -0700");
 		break;
@@ -981,11 +1039,27 @@ parse_done:
 
 	revs.disable_stdin = 1;
 	setup_revisions(argc, argv, &revs, NULL);
+	if (!revs.pending.nr && is_bare_repository()) {
+		struct commit *head_commit;
+		struct object_id head_oid;
+
+		if (!resolve_ref_unsafe("HEAD", RESOLVE_REF_READING,
+					&head_oid, NULL) ||
+		    !(head_commit = lookup_commit_reference_gently(revs.repo,
+							     &head_oid, 1)))
+			die("no such ref: HEAD");
+
+		add_pending_object(&revs, &head_commit->object, "HEAD");
+	}
 
 	init_scoreboard(&sb);
 	sb.revs = &revs;
 	sb.contents_from = contents_from;
 	sb.reverse = reverse;
+	sb.repo = the_repository;
+	build_ignorelist(&sb, &ignore_revs_file_list, &ignore_rev_list);
+	string_list_clear(&ignore_revs_file_list, 0);
+	string_list_clear(&ignore_rev_list, 0);
 	setup_scoreboard(&sb, path, &o);
 	lno = sb.num_lines;
 
@@ -998,15 +1072,16 @@ parse_done:
 		long bottom, top;
 		if (parse_range_arg(range_list.items[range_i].string,
 				    nth_line_cb, &sb, lno, anchor,
-				    &bottom, &top, sb.path))
+				    &bottom, &top, sb.path,
+				    the_repository->index))
 			usage(blame_usage);
-		if (lno < top || ((lno || bottom) && lno < bottom))
+		if ((!lno && (top || bottom)) || lno < bottom)
 			die(Q_("file %s has only %lu line",
 			       "file %s has only %lu lines",
 			       lno), path, lno);
 		if (bottom < 1)
 			bottom = 1;
-		if (top < 1)
+		if (top < 1 || lno < top)
 			top = lno;
 		bottom--;
 		range_set_append_unsafe(&ranges, bottom, top);
@@ -1035,7 +1110,7 @@ parse_done:
 	if (blame_copy_score)
 		sb.copy_score = blame_copy_score;
 
-	sb.debug = DEBUG;
+	sb.debug = DEBUG_BLAME;
 	sb.on_sanity_fail = &sanity_check_on_fail;
 
 	sb.show_root = show_root;
@@ -1069,7 +1144,9 @@ parse_done:
 		find_alignment(&sb, &output_option);
 		if (!*repeated_meta_color &&
 		    (output_option & OUTPUT_COLOR_LINE))
-			strcpy(repeated_meta_color, GIT_COLOR_CYAN);
+			xsnprintf(repeated_meta_color,
+				  sizeof(repeated_meta_color),
+				  "%s", GIT_COLOR_CYAN);
 	}
 	if (output_option & OUTPUT_ANNOTATE_COMPAT)
 		output_option &= ~(OUTPUT_COLOR_LINE | OUTPUT_SHOW_AGE_WITH_COLOR);
diff -pruN 1.2.1+git2.18.0-1/git/builtin/branch.c 1.2.3+git2.25.1-1/git/builtin/branch.c
--- 1.2.1+git2.18.0-1/git/builtin/branch.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/builtin/branch.c	2020-02-17 04:47:35.000000000 +0000
@@ -22,6 +22,8 @@
 #include "wt-status.h"
 #include "ref-filter.h"
 #include "worktree.h"
+#include "help.h"
+#include "commit-reach.h"
 
 static const char * const builtin_branch_usage[] = {
 	N_("git branch [<options>] [-r | -a] [--merged | --no-merged]"),
@@ -45,6 +47,7 @@ static char branch_colors[][COLOR_MAXLEN
 	GIT_COLOR_NORMAL,       /* LOCAL */
 	GIT_COLOR_GREEN,        /* CURRENT */
 	GIT_COLOR_BLUE,         /* UPSTREAM */
+	GIT_COLOR_CYAN,         /* WORKTREE */
 };
 enum color_branch {
 	BRANCH_COLOR_RESET = 0,
@@ -52,32 +55,36 @@ enum color_branch {
 	BRANCH_COLOR_REMOTE = 2,
 	BRANCH_COLOR_LOCAL = 3,
 	BRANCH_COLOR_CURRENT = 4,
-	BRANCH_COLOR_UPSTREAM = 5
+	BRANCH_COLOR_UPSTREAM = 5,
+	BRANCH_COLOR_WORKTREE = 6
+};
+
+static const char *color_branch_slots[] = {
+	[BRANCH_COLOR_RESET]	= "reset",
+	[BRANCH_COLOR_PLAIN]	= "plain",
+	[BRANCH_COLOR_REMOTE]	= "remote",
+	[BRANCH_COLOR_LOCAL]	= "local",
+	[BRANCH_COLOR_CURRENT]	= "current",
+	[BRANCH_COLOR_UPSTREAM] = "upstream",
+	[BRANCH_COLOR_WORKTREE] = "worktree",
 };
 
 static struct string_list output = STRING_LIST_INIT_DUP;
 static unsigned int colopts;
 
-static int parse_branch_color_slot(const char *slot)
-{
-	if (!strcasecmp(slot, "plain"))
-		return BRANCH_COLOR_PLAIN;
-	if (!strcasecmp(slot, "reset"))
-		return BRANCH_COLOR_RESET;
-	if (!strcasecmp(slot, "remote"))
-		return BRANCH_COLOR_REMOTE;
-	if (!strcasecmp(slot, "local"))
-		return BRANCH_COLOR_LOCAL;
-	if (!strcasecmp(slot, "current"))
-		return BRANCH_COLOR_CURRENT;
-	if (!strcasecmp(slot, "upstream"))
-		return BRANCH_COLOR_UPSTREAM;
-	return -1;
-}
+define_list_config_array(color_branch_slots);
 
 static int git_branch_config(const char *var, const char *value, void *cb)
 {
 	const char *slot_name;
+	struct ref_sorting **sorting_tail = (struct ref_sorting **)cb;
+
+	if (!strcmp(var, "branch.sort")) {
+		if (!value)
+			return config_error_nonbool(var);
+		parse_ref_sorting(sorting_tail, value);
+		return 0;
+	}
 
 	if (starts_with(var, "column."))
 		return git_column_config(var, value, "branch", &colopts);
@@ -86,7 +93,7 @@ static int git_branch_config(const char
 		return 0;
 	}
 	if (skip_prefix(var, "color.branch.", &slot_name)) {
-		int slot = parse_branch_color_slot(slot_name);
+		int slot = LOOKUP_CONFIG(color_branch_slots, slot_name);
 		if (slot < 0)
 			return 0;
 		if (!value)
@@ -126,7 +133,8 @@ static int branch_merged(int kind, const
 		    (reference_name = reference_name_to_free =
 		     resolve_refdup(upstream, RESOLVE_REF_READING,
 				    &oid, NULL)) != NULL)
-			reference_rev = lookup_commit_reference(&oid);
+			reference_rev = lookup_commit_reference(the_repository,
+								&oid);
 	}
 	if (!reference_rev)
 		reference_rev = head_rev;
@@ -159,7 +167,7 @@ static int check_branch_commit(const cha
 			       const struct object_id *oid, struct commit *head_rev,
 			       int kinds, int force)
 {
-	struct commit *rev = lookup_commit_reference(oid);
+	struct commit *rev = lookup_commit_reference(the_repository, oid);
 	if (!rev) {
 		error(_("Couldn't look up commit object for '%s'"), refname);
 		return -1;
@@ -213,7 +221,7 @@ static int delete_branches(int argc, con
 	}
 
 	if (!force) {
-		head_rev = lookup_commit_reference(&head_oid);
+		head_rev = lookup_commit_reference(the_repository, &head_oid);
 		if (!head_rev)
 			die(_("Couldn't look up commit object for HEAD"));
 	}
@@ -337,9 +345,10 @@ static char *build_format(struct ref_fil
 	struct strbuf local = STRBUF_INIT;
 	struct strbuf remote = STRBUF_INIT;
 
-	strbuf_addf(&local, "%%(if)%%(HEAD)%%(then)* %s%%(else)  %s%%(end)",
-		    branch_get_color(BRANCH_COLOR_CURRENT),
-		    branch_get_color(BRANCH_COLOR_LOCAL));
+	strbuf_addf(&local, "%%(if)%%(HEAD)%%(then)* %s%%(else)%%(if)%%(worktreepath)%%(then)+ %s%%(else)  %s%%(end)%%(end)",
+			branch_get_color(BRANCH_COLOR_CURRENT),
+			branch_get_color(BRANCH_COLOR_WORKTREE),
+			branch_get_color(BRANCH_COLOR_LOCAL));
 	strbuf_addf(&remote, "  %s",
 		    branch_get_color(BRANCH_COLOR_REMOTE));
 
@@ -358,9 +367,13 @@ static char *build_format(struct ref_fil
 		strbuf_addf(&local, " %s ", obname.buf);
 
 		if (filter->verbose > 1)
+		{
+			strbuf_addf(&local, "%%(if:notequals=*)%%(HEAD)%%(then)%%(if)%%(worktreepath)%%(then)(%s%%(worktreepath)%s) %%(end)%%(end)",
+				    branch_get_color(BRANCH_COLOR_WORKTREE), branch_get_color(BRANCH_COLOR_RESET));
 			strbuf_addf(&local, "%%(if)%%(upstream)%%(then)[%s%%(upstream:short)%s%%(if)%%(upstream:track)"
 				    "%%(then): %%(upstream:track,nobracket)%%(end)] %%(end)%%(contents:subject)",
 				    branch_get_color(BRANCH_COLOR_UPSTREAM), branch_get_color(BRANCH_COLOR_RESET));
+		}
 		else
 			strbuf_addf(&local, "%%(if)%%(upstream:track)%%(then)%%(upstream:track) %%(end)%%(contents:subject)");
 
@@ -438,6 +451,21 @@ static void print_ref_list(struct ref_fi
 	free(to_free);
 }
 
+static void print_current_branch_name(void)
+{
+	int flags;
+	const char *refname = resolve_ref_unsafe("HEAD", 0, NULL, &flags);
+	const char *shortname;
+	if (!refname)
+		die(_("could not resolve HEAD"));
+	else if (!(flags & REF_ISSYMREF))
+		return;
+	else if (skip_prefix(refname, "refs/heads/", &shortname))
+		puts(shortname);
+	else
+		die(_("HEAD (%s) points outside of refs/heads/"), refname);
+}
+
 static void reject_rebase_or_bisect_branch(const char *target)
 {
 	struct worktree **worktrees = get_worktrees(0);
@@ -576,6 +604,7 @@ static int edit_branch_description(const
 int cmd_branch(int argc, const char **argv, const char *prefix)
 {
 	int delete = 0, rename = 0, copy = 0, force = 0, list = 0;
+	int show_current = 0;
 	int reflog = 0, edit_description = 0;
 	int quiet = 0, unset_upstream = 0;
 	const char *new_upstream = NULL;
@@ -595,7 +624,7 @@ int cmd_branch(int argc, const char **ar
 		OPT_SET_INT_F(0, "set-upstream", &track, N_("do not use"),
 			BRANCH_TRACK_OVERRIDE, PARSE_OPT_HIDDEN),
 		OPT_STRING('u', "set-upstream-to", &new_upstream, N_("upstream"), N_("change the upstream info")),
-		OPT_BOOL(0, "unset-upstream", &unset_upstream, N_("Unset the upstream info")),
+		OPT_BOOL(0, "unset-upstream", &unset_upstream, N_("unset the upstream info")),
 		OPT__COLOR(&branch_use_color, N_("use colored output")),
 		OPT_SET_INT('r', "remotes",     &filter.kind, N_("act on remote-tracking branches"),
 			FILTER_REFS_REMOTES),
@@ -614,16 +643,16 @@ int cmd_branch(int argc, const char **ar
 		OPT_BIT('M', NULL, &rename, N_("move/rename a branch, even if target exists"), 2),
 		OPT_BIT('c', "copy", &copy, N_("copy a branch and its reflog"), 1),
 		OPT_BIT('C', NULL, &copy, N_("copy a branch, even if target exists"), 2),
-		OPT_BOOL(0, "list", &list, N_("list branch names")),
-		OPT_BOOL('l', "create-reflog", &reflog, N_("create the branch's reflog")),
+		OPT_BOOL('l', "list", &list, N_("list branch names")),
+		OPT_BOOL(0, "show-current", &show_current, N_("show current branch name")),
+		OPT_BOOL(0, "create-reflog", &reflog, N_("create the branch's reflog")),
 		OPT_BOOL(0, "edit-description", &edit_description,
 			 N_("edit the description for the branch")),
 		OPT__FORCE(&force, N_("force creation, move/rename, deletion"), PARSE_OPT_NOCOMPLETE),
 		OPT_MERGED(&filter, N_("print only branches that are merged")),
 		OPT_NO_MERGED(&filter, N_("print only branches that are not merged")),
 		OPT_COLUMN(0, "column", &colopts, N_("list branches in columns")),
-		OPT_CALLBACK(0 , "sort", sorting_tail, N_("key"),
-			     N_("field name to sort on"), &parse_opt_ref_sorting),
+		OPT_REF_SORT(sorting_tail),
 		{
 			OPTION_CALLBACK, 0, "points-at", &filter.points_at, N_("object"),
 			N_("print only branches of the object"), 0, parse_opt_object_name
@@ -642,7 +671,7 @@ int cmd_branch(int argc, const char **ar
 	if (argc == 2 && !strcmp(argv[1], "-h"))
 		usage_with_options(builtin_branch_usage, options);
 
-	git_config(git_branch_config, NULL);
+	git_config(git_branch_config, sorting_tail);
 
 	track = git_branch_track;
 
@@ -657,14 +686,15 @@ int cmd_branch(int argc, const char **ar
 	argc = parse_options(argc, argv, prefix, options, builtin_branch_usage,
 			     0);
 
-	if (!delete && !rename && !copy && !edit_description && !new_upstream && !unset_upstream && argc == 0)
+	if (!delete && !rename && !copy && !edit_description && !new_upstream &&
+	    !show_current && !unset_upstream && argc == 0)
 		list = 1;
 
 	if (filter.with_commit || filter.merge != REF_FILTER_MERGED_NONE || filter.points_at.nr ||
 	    filter.no_commit)
 		list = 1;
 
-	if (!!delete + !!rename + !!copy + !!new_upstream +
+	if (!!delete + !!rename + !!copy + !!new_upstream + !!show_current +
 	    list + unset_upstream > 1)
 		usage_with_options(builtin_branch_usage, options);
 
@@ -692,6 +722,9 @@ int cmd_branch(int argc, const char **ar
 		if (!argc)
 			die(_("branch name required"));
 		return delete_branches(argc, argv, delete > 1, filter.kind, quiet);
+	} else if (show_current) {
+		print_current_branch_name();
+		return 0;
 	} else if (list) {
 		/*  git branch --local also shows HEAD when it is detached */
 		if ((filter.kind & FILTER_REFS_BRANCHES) && filter.detached)
@@ -711,8 +744,7 @@ int cmd_branch(int argc, const char **ar
 		print_columns(&output, colopts, NULL);
 		string_list_clear(&output, 0);
 		return 0;
-	}
-	else if (edit_description) {
+	} else if (edit_description) {
 		const char *branch_name;
 		struct strbuf branch_ref = STRBUF_INIT;
 
@@ -779,7 +811,8 @@ int cmd_branch(int argc, const char **ar
 		 * create_branch takes care of setting up the tracking
 		 * info and making sure new_upstream is correct
 		 */
-		create_branch(branch->name, new_upstream, 0, 0, 0, quiet, BRANCH_TRACK_OVERRIDE);
+		create_branch(the_repository, branch->name, new_upstream,
+			      0, 0, 0, quiet, BRANCH_TRACK_OVERRIDE);
 	} else if (unset_upstream) {
 		struct branch *branch = branch_get(argv[0]);
 		struct strbuf buf = STRBUF_INIT;
@@ -804,18 +837,15 @@ int cmd_branch(int argc, const char **ar
 		git_config_set_multivar(buf.buf, NULL, NULL, 1);
 		strbuf_release(&buf);
 	} else if (argc > 0 && argc <= 2) {
-		struct branch *branch = branch_get(argv[0]);
-
-		if (!branch)
-			die(_("no such branch '%s'"), argv[0]);
-
 		if (filter.kind != FILTER_REFS_BRANCHES)
-			die(_("-a and -r options to 'git branch' do not make sense with a branch name"));
+			die(_("The -a, and -r, options to 'git branch' do not take a branch name.\n"
+				  "Did you mean to use: -a|-r --list <pattern>?"));
 
 		if (track == BRANCH_TRACK_OVERRIDE)
 			die(_("the '--set-upstream' option is no longer supported. Please use '--track' or '--set-upstream-to' instead."));
 
-		create_branch(argv[0], (argc == 2) ? argv[1] : head,
+		create_branch(the_repository,
+			      argv[0], (argc == 2) ? argv[1] : head,
 			      force, 0, reflog, quiet, track);
 
 	} else
diff -pruN 1.2.1+git2.18.0-1/git/builtin/bundle.c 1.2.3+git2.25.1-1/git/builtin/bundle.c
--- 1.2.1+git2.18.0-1/git/builtin/bundle.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/builtin/bundle.c	2020-02-17 04:47:35.000000000 +0000
@@ -1,4 +1,6 @@
 #include "builtin.h"
+#include "argv-array.h"
+#include "parse-options.h"
 #include "cache.h"
 #include "bundle.h"
 
@@ -9,59 +11,184 @@
  * bundle supporting "fetch", "pull", and "ls-remote".
  */
 
-static const char builtin_bundle_usage[] =
-  "git bundle create <file> <git-rev-list args>\n"
-  "   or: git bundle verify <file>\n"
-  "   or: git bundle list-heads <file> [<refname>...]\n"
-  "   or: git bundle unbundle <file> [<refname>...]";
+static const char * const builtin_bundle_usage[] = {
+  N_("git bundle create [<options>] <file> <git-rev-list args>"),
+  N_("git bundle verify [<options>] <file>"),
+  N_("git bundle list-heads <file> [<refname>...]"),
+  N_("git bundle unbundle <file> [<refname>...]"),
+  NULL
+};
+
+static const char * const builtin_bundle_create_usage[] = {
+  N_("git bundle create [<options>] <file> <git-rev-list args>"),
+  NULL
+};
+
+static const char * const builtin_bundle_verify_usage[] = {
+  N_("git bundle verify [<options>] <file>"),
+  NULL
+};
+
+static const char * const builtin_bundle_list_heads_usage[] = {
+  N_("git bundle list-heads <file> [<refname>...]"),
+  NULL
+};
+
+static const char * const builtin_bundle_unbundle_usage[] = {
+  N_("git bundle unbundle <file> [<refname>...]"),
+  NULL
+};
+
+static int verbose;
+
+static int parse_options_cmd_bundle(int argc,
+		const char **argv,
+		const char* prefix,
+		const char * const usagestr[],
+		const struct option options[],
+		const char **bundle_file) {
+	int newargc;
+	newargc = parse_options(argc, argv, NULL, options, usagestr,
+			     PARSE_OPT_STOP_AT_NON_OPTION);
+	if (argc < 1)
+		usage_with_options(usagestr, options);
+	*bundle_file = prefix_filename(prefix, argv[0]);
+	return newargc;
+}
 
-int cmd_bundle(int argc, const char **argv, const char *prefix)
-{
+static int cmd_bundle_create(int argc, const char **argv, const char *prefix) {
+	int all_progress_implied = 0;
+	int progress = isatty(STDERR_FILENO);
+	struct argv_array pack_opts;
+
+	struct option options[] = {
+		OPT_SET_INT('q', "quiet", &progress,
+			    N_("do not show progress meter"), 0),
+		OPT_SET_INT(0, "progress", &progress,
+			    N_("show progress meter"), 1),
+		OPT_SET_INT(0, "all-progress", &progress,
+			    N_("show progress meter during object writing phase"), 2),
+		OPT_BOOL(0, "all-progress-implied",
+			 &all_progress_implied,
+			 N_("similar to --all-progress when progress meter is shown")),
+		OPT_END()
+	};
+	const char* bundle_file;
+
+	argc = parse_options_cmd_bundle(argc, argv, prefix,
+			builtin_bundle_create_usage, options, &bundle_file);
+	/* bundle internals use argv[1] as further parameters */
+
+	argv_array_init(&pack_opts);
+	if (progress == 0)
+		argv_array_push(&pack_opts, "--quiet");
+	else if (progress == 1)
+		argv_array_push(&pack_opts, "--progress");
+	else if (progress == 2)
+		argv_array_push(&pack_opts, "--all-progress");
+	if (progress && all_progress_implied)
+		argv_array_push(&pack_opts, "--all-progress-implied");
+
+	if (!startup_info->have_repository)
+		die(_("Need a repository to create a bundle."));
+	return !!create_bundle(the_repository, bundle_file, argc, argv, &pack_opts);
+}
+
+static int cmd_bundle_verify(int argc, const char **argv, const char *prefix) {
 	struct bundle_header header;
-	const char *cmd, *bundle_file;
 	int bundle_fd = -1;
+	int quiet = 0;
+
+	struct option options[] = {
+		OPT_BOOL('q', "quiet", &quiet,
+			    N_("do not show bundle details")),
+		OPT_END()
+	};
+	const char* bundle_file;
+
+	argc = parse_options_cmd_bundle(argc, argv, prefix,
+			builtin_bundle_verify_usage, options, &bundle_file);
+	/* bundle internals use argv[1] as further parameters */
 
-	if (argc < 3)
-		usage(builtin_bundle_usage);
+	memset(&header, 0, sizeof(header));
+	if ((bundle_fd = read_bundle_header(bundle_file, &header)) < 0)
+		return 1;
+	close(bundle_fd);
+	if (verify_bundle(the_repository, &header, !quiet))
+		return 1;
+	fprintf(stderr, _("%s is okay\n"), bundle_file);
+	return 0;
+}
+
+static int cmd_bundle_list_heads(int argc, const char **argv, const char *prefix) {
+	struct bundle_header header;
+	int bundle_fd = -1;
 
-	cmd = argv[1];
-	bundle_file = prefix_filename(prefix, argv[2]);
-	argc -= 2;
-	argv += 2;
+	struct option options[] = {
+		OPT_END()
+	};
+	const char* bundle_file;
+
+	argc = parse_options_cmd_bundle(argc, argv, prefix,
+			builtin_bundle_list_heads_usage, options, &bundle_file);
+	/* bundle internals use argv[1] as further parameters */
 
 	memset(&header, 0, sizeof(header));
-	if (strcmp(cmd, "create") && (bundle_fd =
-				read_bundle_header(bundle_file, &header)) < 0)
+	if ((bundle_fd = read_bundle_header(bundle_file, &header)) < 0)
 		return 1;
+	close(bundle_fd);
+	return !!list_bundle_refs(&header, argc, argv);
+}
 
-	if (!strcmp(cmd, "verify")) {
-		close(bundle_fd);
-		if (argc != 1) {
-			usage(builtin_bundle_usage);
-			return 1;
-		}
-		if (verify_bundle(&header, 1))
-			return 1;
-		fprintf(stderr, _("%s is okay\n"), bundle_file);
-		return 0;
-	}
-	if (!strcmp(cmd, "list-heads")) {
-		close(bundle_fd);
-		return !!list_bundle_refs(&header, argc, argv);
+static int cmd_bundle_unbundle(int argc, const char **argv, const char *prefix) {
+	struct bundle_header header;
+	int bundle_fd = -1;
+
+	struct option options[] = {
+		OPT_END()
+	};
+	const char* bundle_file;
+
+	argc = parse_options_cmd_bundle(argc, argv, prefix,
+			builtin_bundle_unbundle_usage, options, &bundle_file);
+	/* bundle internals use argv[1] as further parameters */
+
+	memset(&header, 0, sizeof(header));
+	if ((bundle_fd = read_bundle_header(bundle_file, &header)) < 0)
+		return 1;
+	if (!startup_info->have_repository)
+		die(_("Need a repository to unbundle."));
+	return !!unbundle(the_repository, &header, bundle_fd, 0) ||
+		list_bundle_refs(&header, argc, argv);
+}
+
+int cmd_bundle(int argc, const char **argv, const char *prefix)
+{
+	struct option options[] = {
+		OPT__VERBOSE(&verbose, N_("be verbose; must be placed before a subcommand")),
+		OPT_END()
+	};
+	int result;
+
+	argc = parse_options(argc, argv, prefix, options, builtin_bundle_usage,
+		PARSE_OPT_STOP_AT_NON_OPTION);
+
+	packet_trace_identity("bundle");
+
+	if (argc < 2)
+		usage_with_options(builtin_bundle_usage, options);
+
+	else if (!strcmp(argv[0], "create"))
+		result = cmd_bundle_create(argc, argv, prefix);
+	else if (!strcmp(argv[0], "verify"))
+		result = cmd_bundle_verify(argc, argv, prefix);
+	else if (!strcmp(argv[0], "list-heads"))
+		result = cmd_bundle_list_heads(argc, argv, prefix);
+	else if (!strcmp(argv[0], "unbundle"))
+		result = cmd_bundle_unbundle(argc, argv, prefix);
+	else {
+		error(_("Unknown subcommand: %s"), argv[0]);
+		usage_with_options(builtin_bundle_usage, options);
 	}
-	if (!strcmp(cmd, "create")) {
-		if (argc < 2) {
-			usage(builtin_bundle_usage);
-			return 1;
-		}
-		if (!startup_info->have_repository)
-			die(_("Need a repository to create a bundle."));
-		return !!create_bundle(&header, bundle_file, argc, argv);
-	} else if (!strcmp(cmd, "unbundle")) {
-		if (!startup_info->have_repository)
-			die(_("Need a repository to unbundle."));
-		return !!unbundle(&header, bundle_fd, 0) ||
-			list_bundle_refs(&header, argc, argv);
-	} else
-		usage(builtin_bundle_usage);
+	return result ? 1 : 0;
 }
diff -pruN 1.2.1+git2.18.0-1/git/builtin/cat-file.c 1.2.3+git2.25.1-1/git/builtin/cat-file.c
--- 1.2.1+git2.18.0-1/git/builtin/cat-file.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/builtin/cat-file.c	2020-02-17 04:47:35.000000000 +0000
@@ -3,6 +3,7 @@
  *
  * Copyright (C) Linus Torvalds, 2005
  */
+#define USE_THE_INDEX_COMPATIBILITY_MACROS
 #include "cache.h"
 #include "config.h"
 #include "builtin.h"
@@ -13,6 +14,8 @@
 #include "tree-walk.h"
 #include "sha1-array.h"
 #include "packfile.h"
+#include "object-store.h"
+#include "promisor-remote.h"
 
 struct batch_options {
 	int enabled;
@@ -20,6 +23,7 @@ struct batch_options {
 	int print_contents;
 	int buffer_output;
 	int all_objects;
+	int unordered;
 	int cmdmode; /* may be 'w' or 'c' for --filters or --textconv */
 	const char *format;
 };
@@ -38,7 +42,7 @@ static int filter_object(const char *pat
 			     oid_to_hex(oid), path);
 	if ((type == OBJ_BLOB) && S_ISREG(mode)) {
 		struct strbuf strbuf = STRBUF_INIT;
-		if (convert_to_working_tree(path, *buf, *size, &strbuf)) {
+		if (convert_to_working_tree(&the_index, path, *buf, *size, &strbuf)) {
 			free(*buf);
 			*size = strbuf.len;
 			*buf = strbuf_detach(&strbuf, NULL);
@@ -48,6 +52,13 @@ static int filter_object(const char *pat
 	return 0;
 }
 
+static int stream_blob(const struct object_id *oid)
+{
+	if (stream_blob_to_fd(1, oid, NULL, 0))
+		die("unable to stream %s to stdout", oid_to_hex(oid));
+	return 0;
+}
+
 static int cat_one_file(int opt, const char *exp_type, const char *obj_name,
 			int unknown_type)
 {
@@ -64,7 +75,8 @@ static int cat_one_file(int opt, const c
 	if (unknown_type)
 		flags |= OBJECT_INFO_ALLOW_UNKNOWN_TYPE;
 
-	if (get_oid_with_context(obj_name, GET_OID_RECORD_PATH,
+	if (get_oid_with_context(the_repository, obj_name,
+				 GET_OID_RECORD_PATH,
 				 &oid, &obj_context))
 		die("Not a valid object name %s", obj_name);
 
@@ -90,7 +102,7 @@ static int cat_one_file(int opt, const c
 		oi.sizep = &size;
 		if (oid_object_info_extended(the_repository, &oid, &oi, flags) < 0)
 			die("git cat-file: could not get object info");
-		printf("%lu\n", size);
+		printf("%"PRIuMAX"\n", (uintmax_t)size);
 		return 0;
 
 	case 'e':
@@ -111,7 +123,8 @@ static int cat_one_file(int opt, const c
 			die("git cat-file --textconv %s: <object> must be <sha1:path>",
 			    obj_name);
 
-		if (textconv_object(path, obj_context.mode, &oid, 1, &buf, &size))
+		if (textconv_object(the_repository, path, obj_context.mode,
+				    &oid, 1, &buf, &size))
 			break;
 		/* else fallthrough */
 
@@ -129,7 +142,7 @@ static int cat_one_file(int opt, const c
 		}
 
 		if (type == OBJ_BLOB)
-			return stream_blob_to_fd(1, &oid, NULL, 0);
+			return stream_blob(&oid);
 		buf = read_object_file(&oid, &type, &size);
 		if (!buf)
 			die("Cannot read object %s", obj_name);
@@ -152,7 +165,7 @@ static int cat_one_file(int opt, const c
 				oidcpy(&blob_oid, &oid);
 
 			if (oid_object_info(the_repository, &blob_oid, NULL) == OBJ_BLOB)
-				return stream_blob_to_fd(1, &blob_oid, NULL, 0);
+				return stream_blob(&blob_oid);
 			/*
 			 * we attempted to dereference a tag to a blob
 			 * and failed; there may be new dereference
@@ -160,7 +173,8 @@ static int cat_one_file(int opt, const c
 			 * fall-back to the usual case.
 			 */
 		}
-		buf = read_object_with_reference(&oid, exp_type, &size, NULL);
+		buf = read_object_with_reference(the_repository,
+						 &oid, exp_type, &size, NULL);
 		break;
 
 	default:
@@ -199,14 +213,14 @@ struct expand_data {
 
 	/*
 	 * After a mark_query run, this object_info is set up to be
-	 * passed to sha1_object_info_extended. It will point to the data
+	 * passed to oid_object_info_extended. It will point to the data
 	 * elements above, so you can retrieve the response from there.
 	 */
 	struct object_info info;
 
 	/*
 	 * This flag will be true if the requested batch format and options
-	 * don't require us to call sha1_object_info, which can then be
+	 * don't require us to call oid_object_info, which can then be
 	 * optimized out.
 	 */
 	unsigned skip_object_info : 1;
@@ -235,7 +249,7 @@ static void expand_atom(struct strbuf *s
 		if (data->mark_query)
 			data->info.sizep = &data->size;
 		else
-			strbuf_addf(sb, "%lu", data->size);
+			strbuf_addf(sb, "%"PRIuMAX , (uintmax_t)data->size);
 	} else if (is_atom("objectsize:disk", atom, len)) {
 		if (data->mark_query)
 			data->info.disk_sizep = &data->disk_size;
@@ -303,7 +317,8 @@ static void print_object_or_die(struct b
 					    oid_to_hex(oid), data->rest);
 			} else if (opt->cmdmode == 'c') {
 				enum object_type type;
-				if (!textconv_object(data->rest, 0100644, oid,
+				if (!textconv_object(the_repository,
+						     data->rest, 0100644, oid,
 						     1, &contents, &size))
 					contents = read_object_file(oid,
 								    &type,
@@ -315,8 +330,9 @@ static void print_object_or_die(struct b
 				BUG("invalid cmdmode: %c", opt->cmdmode);
 			batch_write(opt, contents, size);
 			free(contents);
-		} else if (stream_blob_to_fd(1, oid, NULL, 0) < 0)
-			die("unable to stream %s to stdout", oid_to_hex(oid));
+		} else {
+			stream_blob(oid);
+		}
 	}
 	else {
 		enum object_type type;
@@ -336,11 +352,11 @@ static void print_object_or_die(struct b
 	}
 }
 
-static void batch_object_write(const char *obj_name, struct batch_options *opt,
+static void batch_object_write(const char *obj_name,
+			       struct strbuf *scratch,
+			       struct batch_options *opt,
 			       struct expand_data *data)
 {
-	struct strbuf buf = STRBUF_INIT;
-
 	if (!data->skip_object_info &&
 	    oid_object_info_extended(the_repository, &data->oid, &data->info,
 				     OBJECT_INFO_LOOKUP_REPLACE) < 0) {
@@ -350,10 +366,10 @@ static void batch_object_write(const cha
 		return;
 	}
 
-	strbuf_expand(&buf, opt->format, expand_format, data);
-	strbuf_addch(&buf, '\n');
-	batch_write(opt, buf.buf, buf.len);
-	strbuf_release(&buf);
+	strbuf_reset(scratch);
+	strbuf_expand(scratch, opt->format, expand_format, data);
+	strbuf_addch(scratch, '\n');
+	batch_write(opt, scratch->buf, scratch->len);
 
 	if (opt->print_contents) {
 		print_object_or_die(opt, data);
@@ -361,19 +377,25 @@ static void batch_object_write(const cha
 	}
 }
 
-static void batch_one_object(const char *obj_name, struct batch_options *opt,
+static void batch_one_object(const char *obj_name,
+			     struct strbuf *scratch,
+			     struct batch_options *opt,
 			     struct expand_data *data)
 {
 	struct object_context ctx;
 	int flags = opt->follow_symlinks ? GET_OID_FOLLOW_SYMLINKS : 0;
-	enum follow_symlinks_result result;
+	enum get_oid_result result;
 
-	result = get_oid_with_context(obj_name, flags, &data->oid, &ctx);
+	result = get_oid_with_context(the_repository, obj_name,
+				      flags, &data->oid, &ctx);
 	if (result != FOUND) {
 		switch (result) {
 		case MISSING_OBJECT:
 			printf("%s missing\n", obj_name);
 			break;
+		case SHORT_NAME_AMBIGUOUS:
+			printf("%s ambiguous\n", obj_name);
+			break;
 		case DANGLING_SYMLINK:
 			printf("dangling %"PRIuMAX"\n%s\n",
 			       (uintmax_t)strlen(obj_name), obj_name);
@@ -403,42 +425,70 @@ static void batch_one_object(const char
 		return;
 	}
 
-	batch_object_write(obj_name, opt, data);
+	batch_object_write(obj_name, scratch, opt, data);
 }
 
 struct object_cb_data {
 	struct batch_options *opt;
 	struct expand_data *expand;
+	struct oidset *seen;
+	struct strbuf *scratch;
 };
 
 static int batch_object_cb(const struct object_id *oid, void *vdata)
 {
 	struct object_cb_data *data = vdata;
 	oidcpy(&data->expand->oid, oid);
-	batch_object_write(NULL, data->opt, data->expand);
+	batch_object_write(NULL, data->scratch, data->opt, data->expand);
 	return 0;
 }
 
-static int batch_loose_object(const struct object_id *oid,
-			      const char *path,
-			      void *data)
+static int collect_loose_object(const struct object_id *oid,
+				const char *path,
+				void *data)
 {
 	oid_array_append(data, oid);
 	return 0;
 }
 
-static int batch_packed_object(const struct object_id *oid,
-			       struct packed_git *pack,
-			       uint32_t pos,
-			       void *data)
+static int collect_packed_object(const struct object_id *oid,
+				 struct packed_git *pack,
+				 uint32_t pos,
+				 void *data)
 {
 	oid_array_append(data, oid);
 	return 0;
 }
 
+static int batch_unordered_object(const struct object_id *oid, void *vdata)
+{
+	struct object_cb_data *data = vdata;
+
+	if (oidset_insert(data->seen, oid))
+		return 0;
+
+	return batch_object_cb(oid, data);
+}
+
+static int batch_unordered_loose(const struct object_id *oid,
+				 const char *path,
+				 void *data)
+{
+	return batch_unordered_object(oid, data);
+}
+
+static int batch_unordered_packed(const struct object_id *oid,
+				  struct packed_git *pack,
+				  uint32_t pos,
+				  void *data)
+{
+	return batch_unordered_object(oid, data);
+}
+
 static int batch_objects(struct batch_options *opt)
 {
-	struct strbuf buf = STRBUF_INIT;
+	struct strbuf input = STRBUF_INIT;
+	struct strbuf output = STRBUF_INIT;
 	struct expand_data data;
 	int save_warning;
 	int retval = 0;
@@ -448,13 +498,14 @@ static int batch_objects(struct batch_op
 
 	/*
 	 * Expand once with our special mark_query flag, which will prime the
-	 * object_info to be handed to sha1_object_info_extended for each
+	 * object_info to be handed to oid_object_info_extended for each
 	 * object.
 	 */
 	memset(&data, 0, sizeof(data));
 	data.mark_query = 1;
-	strbuf_expand(&buf, opt->format, expand_format, &data);
+	strbuf_expand(&output, opt->format, expand_format, &data);
 	data.mark_query = 0;
+	strbuf_release(&output);
 	if (opt->cmdmode)
 		data.split_on_whitespace = 1;
 
@@ -472,19 +523,37 @@ static int batch_objects(struct batch_op
 		data.info.typep = &data.type;
 
 	if (opt->all_objects) {
-		struct oid_array sa = OID_ARRAY_INIT;
 		struct object_cb_data cb;
 
-		for_each_loose_object(batch_loose_object, &sa, 0);
-		for_each_packed_object(batch_packed_object, &sa, 0);
-		if (repository_format_partial_clone)
-			warning("This repository has extensions.partialClone set. Some objects may not be loaded.");
+		if (has_promisor_remote())
+			warning("This repository uses promisor remotes. Some objects may not be loaded.");
 
 		cb.opt = opt;
 		cb.expand = &data;
-		oid_array_for_each_unique(&sa, batch_object_cb, &cb);
+		cb.scratch = &output;
+
+		if (opt->unordered) {
+			struct oidset seen = OIDSET_INIT;
+
+			cb.seen = &seen;
 
-		oid_array_clear(&sa);
+			for_each_loose_object(batch_unordered_loose, &cb, 0);
+			for_each_packed_object(batch_unordered_packed, &cb,
+					       FOR_EACH_OBJECT_PACK_ORDER);
+
+			oidset_clear(&seen);
+		} else {
+			struct oid_array sa = OID_ARRAY_INIT;
+
+			for_each_loose_object(collect_loose_object, &sa, 0);
+			for_each_packed_object(collect_packed_object, &sa, 0);
+
+			oid_array_for_each_unique(&sa, batch_object_cb, &cb);
+
+			oid_array_clear(&sa);
+		}
+
+		strbuf_release(&output);
 		return 0;
 	}
 
@@ -498,14 +567,14 @@ static int batch_objects(struct batch_op
 	save_warning = warn_on_object_refname_ambiguity;
 	warn_on_object_refname_ambiguity = 0;
 
-	while (strbuf_getline(&buf, stdin) != EOF) {
+	while (strbuf_getline(&input, stdin) != EOF) {
 		if (data.split_on_whitespace) {
 			/*
 			 * Split at first whitespace, tying off the beginning
 			 * of the string and saving the remainder (or NULL) in
 			 * data.rest.
 			 */
-			char *p = strpbrk(buf.buf, " \t");
+			char *p = strpbrk(input.buf, " \t");
 			if (p) {
 				while (*p && strchr(" \t", *p))
 					*p++ = '\0';
@@ -513,10 +582,11 @@ static int batch_objects(struct batch_op
 			data.rest = p;
 		}
 
-		batch_one_object(buf.buf, opt, &data);
+		batch_one_object(input.buf, &output, opt, &data);
 	}
 
-	strbuf_release(&buf);
+	strbuf_release(&input);
+	strbuf_release(&output);
 	warn_on_object_refname_ambiguity = save_warning;
 	return retval;
 }
@@ -541,8 +611,10 @@ static int batch_option_callback(const s
 {
 	struct batch_options *bo = opt->value;
 
+	BUG_ON_OPT_NEG(unset);
+
 	if (bo->enabled) {
-		return 1;
+		return error(_("only one batch option may be specified"));
 	}
 
 	bo->enabled = 1;
@@ -577,14 +649,18 @@ int cmd_cat_file(int argc, const char **
 		OPT_BOOL(0, "buffer", &batch.buffer_output, N_("buffer --batch output")),
 		{ OPTION_CALLBACK, 0, "batch", &batch, "format",
 			N_("show info and content of objects fed from the standard input"),
-			PARSE_OPT_OPTARG, batch_option_callback },
+			PARSE_OPT_OPTARG | PARSE_OPT_NONEG,
+			batch_option_callback },
 		{ OPTION_CALLBACK, 0, "batch-check", &batch, "format",
 			N_("show info about objects fed from the standard input"),
-			PARSE_OPT_OPTARG, batch_option_callback },
+			PARSE_OPT_OPTARG | PARSE_OPT_NONEG,
+			batch_option_callback },
 		OPT_BOOL(0, "follow-symlinks", &batch.follow_symlinks,
 			 N_("follow in-tree symlinks (used with --batch or --batch-check)")),
 		OPT_BOOL(0, "batch-all-objects", &batch.all_objects,
 			 N_("show all objects with --batch or --batch-check")),
+		OPT_BOOL(0, "unordered", &batch.unordered,
+			 N_("do not order --batch-all-objects output")),
 		OPT_END()
 	};
 
diff -pruN 1.2.1+git2.18.0-1/git/builtin/check-attr.c 1.2.3+git2.25.1-1/git/builtin/check-attr.c
--- 1.2.1+git2.18.0-1/git/builtin/check-attr.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/builtin/check-attr.c	2020-02-17 04:47:35.000000000 +0000
@@ -1,3 +1,4 @@
+#define USE_THE_INDEX_COMPATIBILITY_MACROS
 #include "builtin.h"
 #include "cache.h"
 #include "config.h"
@@ -63,10 +64,9 @@ static void check_attr(const char *prefi
 		prefix_path(prefix, prefix ? strlen(prefix) : 0, file);
 
 	if (collect_all) {
-		git_all_attrs(full_path, check);
+		git_all_attrs(&the_index, full_path, check);
 	} else {
-		if (git_check_attr(full_path, check))
-			die("git_check_attr died");
+		git_check_attr(&the_index, full_path, check);
 	}
 	output_attr(check, file);
 
@@ -120,7 +120,7 @@ int cmd_check_attr(int argc, const char
 	}
 
 	if (cached_attrs)
-		git_attr_set_direction(GIT_ATTR_INDEX, NULL);
+		git_attr_set_direction(GIT_ATTR_INDEX);
 
 	doubledash = -1;
 	for (i = 0; doubledash < 0 && i < argc; i++) {
diff -pruN 1.2.1+git2.18.0-1/git/builtin/check-ignore.c 1.2.3+git2.25.1-1/git/builtin/check-ignore.c
--- 1.2.1+git2.18.0-1/git/builtin/check-ignore.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/builtin/check-ignore.c	2020-02-17 04:47:35.000000000 +0000
@@ -1,3 +1,4 @@
+#define USE_THE_INDEX_COMPATIBILITY_MACROS
 #include "builtin.h"
 #include "cache.h"
 #include "config.h"
@@ -31,19 +32,19 @@ static const struct option check_ignore_
 	OPT_END()
 };
 
-static void output_exclude(const char *path, struct exclude *exclude)
+static void output_pattern(const char *path, struct path_pattern *pattern)
 {
-	char *bang  = (exclude && exclude->flags & EXC_FLAG_NEGATIVE)  ? "!" : "";
-	char *slash = (exclude && exclude->flags & EXC_FLAG_MUSTBEDIR) ? "/" : "";
+	char *bang  = (pattern && pattern->flags & PATTERN_FLAG_NEGATIVE)  ? "!" : "";
+	char *slash = (pattern && pattern->flags & PATTERN_FLAG_MUSTBEDIR) ? "/" : "";
 	if (!nul_term_line) {
 		if (!verbose) {
 			write_name_quoted(path, stdout, '\n');
 		} else {
-			if (exclude) {
-				quote_c_style(exclude->el->src, NULL, stdout, 0);
+			if (pattern) {
+				quote_c_style(pattern->pl->src, NULL, stdout, 0);
 				printf(":%d:%s%s%s\t",
-				       exclude->srcpos,
-				       bang, exclude->pattern, slash);
+				       pattern->srcpos,
+				       bang, pattern->pattern, slash);
 			}
 			else {
 				printf("::\t");
@@ -55,11 +56,11 @@ static void output_exclude(const char *p
 		if (!verbose) {
 			printf("%s%c", path, '\0');
 		} else {
-			if (exclude)
+			if (pattern)
 				printf("%s%c%d%c%s%s%s%c%s%c",
-				       exclude->el->src, '\0',
-				       exclude->srcpos, '\0',
-				       bang, exclude->pattern, slash, '\0',
+				       pattern->pl->src, '\0',
+				       pattern->srcpos, '\0',
+				       bang, pattern->pattern, slash, '\0',
 				       path, '\0');
 			else
 				printf("%c%c%c%s%c", '\0', '\0', '\0', path, '\0');
@@ -73,7 +74,7 @@ static int check_ignore(struct dir_struc
 	const char *full_path;
 	char *seen;
 	int num_ignored = 0, i;
-	struct exclude *exclude;
+	struct path_pattern *pattern;
 	struct pathspec pathspec;
 
 	if (!argc) {
@@ -102,15 +103,15 @@ static int check_ignore(struct dir_struc
 	seen = find_pathspecs_matching_against_index(&pathspec, &the_index);
 	for (i = 0; i < pathspec.nr; i++) {
 		full_path = pathspec.items[i].match;
-		exclude = NULL;
+		pattern = NULL;
 		if (!seen[i]) {
 			int dtype = DT_UNKNOWN;
-			exclude = last_exclude_matching(dir, &the_index,
+			pattern = last_matching_pattern(dir, &the_index,
 							full_path, &dtype);
 		}
-		if (!quiet && (exclude || show_non_matching))
-			output_exclude(pathspec.items[i].original, exclude);
-		if (exclude)
+		if (!quiet && (pattern || show_non_matching))
+			output_pattern(pathspec.items[i].original, pattern);
+		if (pattern)
 			num_ignored++;
 	}
 	free(seen);
diff -pruN 1.2.1+git2.18.0-1/git/builtin/checkout.c 1.2.3+git2.25.1-1/git/builtin/checkout.c
--- 1.2.1+git2.18.0-1/git/builtin/checkout.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/builtin/checkout.c	2020-02-17 04:47:35.000000000 +0000
@@ -1,27 +1,31 @@
+#define USE_THE_INDEX_COMPATIBILITY_MACROS
 #include "builtin.h"
-#include "config.h"
+#include "advice.h"
+#include "blob.h"
+#include "branch.h"
+#include "cache-tree.h"
 #include "checkout.h"
+#include "commit.h"
+#include "config.h"
+#include "diff.h"
+#include "dir.h"
+#include "ll-merge.h"
 #include "lockfile.h"
+#include "merge-recursive.h"
+#include "object-store.h"
 #include "parse-options.h"
 #include "refs.h"
-#include "commit.h"
+#include "remote.h"
+#include "resolve-undo.h"
+#include "revision.h"
+#include "run-command.h"
+#include "submodule.h"
+#include "submodule-config.h"
 #include "tree.h"
 #include "tree-walk.h"
-#include "cache-tree.h"
 #include "unpack-trees.h"
-#include "dir.h"
-#include "run-command.h"
-#include "merge-recursive.h"
-#include "branch.h"
-#include "diff.h"
-#include "revision.h"
-#include "remote.h"
-#include "blob.h"
+#include "wt-status.h"
 #include "xdiff-interface.h"
-#include "ll-merge.h"
-#include "resolve-undo.h"
-#include "submodule-config.h"
-#include "submodule.h"
 
 static const char * const checkout_usage[] = {
 	N_("git checkout [<options>] <branch>"),
@@ -29,17 +33,45 @@ static const char * const checkout_usage
 	NULL,
 };
 
+static const char * const switch_branch_usage[] = {
+	N_("git switch [<options>] [<branch>]"),
+	NULL,
+};
+
+static const char * const restore_usage[] = {
+	N_("git restore [<options>] [--source=<branch>] <file>..."),
+	NULL,
+};
+
 struct checkout_opts {
 	int patch_mode;
 	int quiet;
 	int merge;
 	int force;
 	int force_detach;
+	int implicit_detach;
 	int writeout_stage;
 	int overwrite_ignore;
 	int ignore_skipworktree;
 	int ignore_other_worktrees;
 	int show_progress;
+	int count_checkout_paths;
+	int overlay_mode;
+	int dwim_new_local_branch;
+	int discard_changes;
+	int accept_ref;
+	int accept_pathspec;
+	int switch_branch_doing_nothing_is_ok;
+	int only_merge_on_switching_branches;
+	int can_switch_when_in_progress;
+	int orphan_from_empty_tree;
+	int empty_pathspec_ok;
+	int checkout_index;
+	int checkout_worktree;
+	const char *ignore_unmerged_opt;
+	int ignore_unmerged;
+	int pathspec_file_nul;
+	const char *pathspec_from_file;
 
 	const char *new_branch;
 	const char *new_branch_force;
@@ -47,10 +79,12 @@ struct checkout_opts {
 	int new_branch_log;
 	enum branch_track track;
 	struct diff_options diff_options;
+	char *conflict_style;
 
 	int branch_exists;
 	const char *prefix;
 	struct pathspec pathspec;
+	const char *from_treeish;
 	struct tree *source_tree;
 };
 
@@ -77,7 +111,7 @@ static int update_some(const struct obje
 		return READ_TREE_RECURSIVE;
 
 	len = base->len + strlen(pathname);
-	ce = xcalloc(1, cache_entry_size(len));
+	ce = make_empty_cache_entry(&the_index, len);
 	oidcpy(&ce->oid, oid);
 	memcpy(ce->name, base->buf, base->len);
 	memcpy(ce->name + base->len, pathname, len - base->len);
@@ -94,9 +128,10 @@ static int update_some(const struct obje
 	if (pos >= 0) {
 		struct cache_entry *old = active_cache[pos];
 		if (ce->ce_mode == old->ce_mode &&
-		    !oidcmp(&ce->oid, &old->oid)) {
+		    !ce_intent_to_add(old) &&
+		    oideq(&ce->oid, &old->oid)) {
 			old->ce_flags |= CE_UPDATE;
-			free(ce);
+			discard_cache_entry(ce);
 			return 0;
 		}
 	}
@@ -107,7 +142,8 @@ static int update_some(const struct obje
 
 static int read_tree_some(struct tree *tree, const struct pathspec *pathspec)
 {
-	read_tree_recursive(tree, "", 0, 0, pathspec, update_some, NULL);
+	read_tree_recursive(the_repository, tree, "", 0, 0,
+			    pathspec, update_some, NULL);
 
 	/* update the index with the given tree's info
 	 * for all args, expanding wildcards, and exit
@@ -124,7 +160,8 @@ static int skip_same_name(const struct c
 	return pos;
 }
 
-static int check_stage(int stage, const struct cache_entry *ce, int pos)
+static int check_stage(int stage, const struct cache_entry *ce, int pos,
+		       int overlay_mode)
 {
 	while (pos < active_nr &&
 	       !strcmp(active_cache[pos]->name, ce->name)) {
@@ -132,6 +169,8 @@ static int check_stage(int stage, const
 			return 0;
 		pos++;
 	}
+	if (!overlay_mode)
+		return 0;
 	if (stage == 2)
 		return error(_("path '%s' does not have our version"), ce->name);
 	else
@@ -157,21 +196,27 @@ static int check_stages(unsigned stages,
 }
 
 static int checkout_stage(int stage, const struct cache_entry *ce, int pos,
-			  const struct checkout *state)
+			  const struct checkout *state, int *nr_checkouts,
+			  int overlay_mode)
 {
 	while (pos < active_nr &&
 	       !strcmp(active_cache[pos]->name, ce->name)) {
 		if (ce_stage(active_cache[pos]) == stage)
-			return checkout_entry(active_cache[pos], state, NULL);
+			return checkout_entry(active_cache[pos], state,
+					      NULL, nr_checkouts);
 		pos++;
 	}
+	if (!overlay_mode) {
+		unlink_entry(ce);
+		return 0;
+	}
 	if (stage == 2)
 		return error(_("path '%s' does not have our version"), ce->name);
 	else
 		return error(_("path '%s' does not have their version"), ce->name);
 }
 
-static int checkout_merged(int pos, const struct checkout *state)
+static int checkout_merged(int pos, const struct checkout *state, int *nr_checkouts)
 {
 	struct cache_entry *ce = active_cache[pos];
 	const char *path = ce->name;
@@ -206,7 +251,8 @@ static int checkout_merged(int pos, cons
 	 * merge.renormalize set, too
 	 */
 	status = ll_merge(&result_buf, path, &ancestor, "base",
-			  &ours, "ours", &theirs, "theirs", NULL);
+			  &ours, "ours", &theirs, "theirs",
+			  state->istate, NULL);
 	free(ancestor.ptr);
 	free(ours.ptr);
 	free(theirs.ptr);
@@ -230,24 +276,137 @@ static int checkout_merged(int pos, cons
 	if (write_object_file(result_buf.ptr, result_buf.size, blob_type, &oid))
 		die(_("Unable to add merge result for '%s'"), path);
 	free(result_buf.ptr);
-	ce = make_cache_entry(mode, oid.hash, path, 2, 0);
+	ce = make_transient_cache_entry(mode, &oid, path, 2);
 	if (!ce)
 		die(_("make_cache_entry failed for path '%s'"), path);
-	status = checkout_entry(ce, state, NULL);
-	free(ce);
+	status = checkout_entry(ce, state, NULL, nr_checkouts);
+	discard_cache_entry(ce);
 	return status;
 }
 
+static void mark_ce_for_checkout_overlay(struct cache_entry *ce,
+					 char *ps_matched,
+					 const struct checkout_opts *opts)
+{
+	ce->ce_flags &= ~CE_MATCHED;
+	if (!opts->ignore_skipworktree && ce_skip_worktree(ce))
+		return;
+	if (opts->source_tree && !(ce->ce_flags & CE_UPDATE))
+		/*
+		 * "git checkout tree-ish -- path", but this entry
+		 * is in the original index but is not in tree-ish
+		 * or does not match the pathspec; it will not be
+		 * checked out to the working tree.  We will not do
+		 * anything to this entry at all.
+		 */
+		return;
+	/*
+	 * Either this entry came from the tree-ish we are
+	 * checking the paths out of, or we are checking out
+	 * of the index.
+	 *
+	 * If it comes from the tree-ish, we already know it
+	 * matches the pathspec and could just stamp
+	 * CE_MATCHED to it from update_some(). But we still
+	 * need ps_matched and read_tree_recursive (and
+	 * eventually tree_entry_interesting) cannot fill
+	 * ps_matched yet. Once it can, we can avoid calling
+	 * match_pathspec() for _all_ entries when
+	 * opts->source_tree != NULL.
+	 */
+	if (ce_path_match(&the_index, ce, &opts->pathspec, ps_matched))
+		ce->ce_flags |= CE_MATCHED;
+}
+
+static void mark_ce_for_checkout_no_overlay(struct cache_entry *ce,
+					    char *ps_matched,
+					    const struct checkout_opts *opts)
+{
+	ce->ce_flags &= ~CE_MATCHED;
+	if (!opts->ignore_skipworktree && ce_skip_worktree(ce))
+		return;
+	if (ce_path_match(&the_index, ce, &opts->pathspec, ps_matched)) {
+		ce->ce_flags |= CE_MATCHED;
+		if (opts->source_tree && !(ce->ce_flags & CE_UPDATE))
+			/*
+			 * In overlay mode, but the path is not in
+			 * tree-ish, which means we should remove it
+			 * from the index and the working tree.
+			 */
+			ce->ce_flags |= CE_REMOVE | CE_WT_REMOVE;
+	}
+}
+
+static int checkout_worktree(const struct checkout_opts *opts)
+{
+	struct checkout state = CHECKOUT_INIT;
+	int nr_checkouts = 0, nr_unmerged = 0;
+	int errs = 0;
+	int pos;
+
+	state.force = 1;
+	state.refresh_cache = 1;
+	state.istate = &the_index;
+
+	enable_delayed_checkout(&state);
+	for (pos = 0; pos < active_nr; pos++) {
+		struct cache_entry *ce = active_cache[pos];
+		if (ce->ce_flags & CE_MATCHED) {
+			if (!ce_stage(ce)) {
+				errs |= checkout_entry(ce, &state,
+						       NULL, &nr_checkouts);
+				continue;
+			}
+			if (opts->writeout_stage)
+				errs |= checkout_stage(opts->writeout_stage,
+						       ce, pos,
+						       &state,
+						       &nr_checkouts, opts->overlay_mode);
+			else if (opts->merge)
+				errs |= checkout_merged(pos, &state,
+							&nr_unmerged);
+			pos = skip_same_name(ce, pos) - 1;
+		}
+	}
+	remove_marked_cache_entries(&the_index, 1);
+	remove_scheduled_dirs();
+	errs |= finish_delayed_checkout(&state, &nr_checkouts);
+
+	if (opts->count_checkout_paths) {
+		if (nr_unmerged)
+			fprintf_ln(stderr, Q_("Recreated %d merge conflict",
+					      "Recreated %d merge conflicts",
+					      nr_unmerged),
+				   nr_unmerged);
+		if (opts->source_tree)
+			fprintf_ln(stderr, Q_("Updated %d path from %s",
+					      "Updated %d paths from %s",
+					      nr_checkouts),
+				   nr_checkouts,
+				   find_unique_abbrev(&opts->source_tree->object.oid,
+						      DEFAULT_ABBREV));
+		else if (!nr_unmerged || nr_checkouts)
+			fprintf_ln(stderr, Q_("Updated %d path from the index",
+					      "Updated %d paths from the index",
+					      nr_checkouts),
+				   nr_checkouts);
+	}
+
+	return errs;
+}
+
 static int checkout_paths(const struct checkout_opts *opts,
 			  const char *revision)
 {
 	int pos;
-	struct checkout state = CHECKOUT_INIT;
 	static char *ps_matched;
 	struct object_id rev;
 	struct commit *head;
 	int errs = 0;
 	struct lock_file lock_file = LOCK_INIT;
+	int checkout_index;
+
+	trace2_cmd_mode(opts->patch_mode ? "patch" : "path");
 
 	if (opts->track != BRANCH_TRACK_UNSPECIFIED)
 		die(_("'%s' cannot be used with updating paths"), "--track");
@@ -255,8 +414,9 @@ static int checkout_paths(const struct c
 	if (opts->new_branch_log)
 		die(_("'%s' cannot be used with updating paths"), "-l");
 
-	if (opts->force && opts->patch_mode)
-		die(_("'%s' cannot be used with updating paths"), "-f");
+	if (opts->ignore_unmerged && opts->patch_mode)
+		die(_("'%s' cannot be used with updating paths"),
+		    opts->ignore_unmerged_opt);
 
 	if (opts->force_detach)
 		die(_("'%s' cannot be used with updating paths"), "--detach");
@@ -264,18 +424,48 @@ static int checkout_paths(const struct c
 	if (opts->merge && opts->patch_mode)
 		die(_("'%s' cannot be used with %s"), "--merge", "--patch");
 
-	if (opts->force && opts->merge)
-		die(_("'%s' cannot be used with %s"), "-f", "-m");
+	if (opts->ignore_unmerged && opts->merge)
+		die(_("'%s' cannot be used with %s"),
+		    opts->ignore_unmerged_opt, "-m");
 
 	if (opts->new_branch)
 		die(_("Cannot update paths and switch to branch '%s' at the same time."),
 		    opts->new_branch);
 
-	if (opts->patch_mode)
-		return run_add_interactive(revision, "--patch=checkout",
-					   &opts->pathspec);
+	if (!opts->checkout_worktree && !opts->checkout_index)
+		die(_("neither '%s' or '%s' is specified"),
+		    "--staged", "--worktree");
+
+	if (!opts->checkout_worktree && !opts->from_treeish)
+		die(_("'%s' must be used when '%s' is not specified"),
+		    "--worktree", "--source");
+
+	if (opts->checkout_index && !opts->checkout_worktree &&
+	    opts->writeout_stage)
+		die(_("'%s' or '%s' cannot be used with %s"),
+		    "--ours", "--theirs", "--staged");
+
+	if (opts->checkout_index && !opts->checkout_worktree &&
+	    opts->merge)
+		die(_("'%s' or '%s' cannot be used with %s"),
+		    "--merge", "--conflict", "--staged");
+
+	if (opts->patch_mode) {
+		const char *patch_mode;
+
+		if (opts->checkout_index && opts->checkout_worktree)
+			patch_mode = "--patch=checkout";
+		else if (opts->checkout_index && !opts->checkout_worktree)
+			patch_mode = "--patch=reset";
+		else if (!opts->checkout_index && opts->checkout_worktree)
+			patch_mode = "--patch=worktree";
+		else
+			BUG("either flag must have been set, worktree=%d, index=%d",
+			    opts->checkout_worktree, opts->checkout_index);
+		return run_add_interactive(revision, patch_mode, &opts->pathspec);
+	}
 
-	hold_locked_index(&lock_file, LOCK_DIE_ON_ERROR);
+	repo_hold_locked_index(the_repository, &lock_file, LOCK_DIE_ON_ERROR);
 	if (read_cache_preload(&opts->pathspec) < 0)
 		return error(_("index file corrupt"));
 
@@ -288,39 +478,17 @@ static int checkout_paths(const struct c
 	 * Make sure all pathspecs participated in locating the paths
 	 * to be checked out.
 	 */
-	for (pos = 0; pos < active_nr; pos++) {
-		struct cache_entry *ce = active_cache[pos];
-		ce->ce_flags &= ~CE_MATCHED;
-		if (!opts->ignore_skipworktree && ce_skip_worktree(ce))
-			continue;
-		if (opts->source_tree && !(ce->ce_flags & CE_UPDATE))
-			/*
-			 * "git checkout tree-ish -- path", but this entry
-			 * is in the original index; it will not be checked
-			 * out to the working tree and it does not matter
-			 * if pathspec matched this entry.  We will not do
-			 * anything to this entry at all.
-			 */
-			continue;
-		/*
-		 * Either this entry came from the tree-ish we are
-		 * checking the paths out of, or we are checking out
-		 * of the index.
-		 *
-		 * If it comes from the tree-ish, we already know it
-		 * matches the pathspec and could just stamp
-		 * CE_MATCHED to it from update_some(). But we still
-		 * need ps_matched and read_tree_recursive (and
-		 * eventually tree_entry_interesting) cannot fill
-		 * ps_matched yet. Once it can, we can avoid calling
-		 * match_pathspec() for _all_ entries when
-		 * opts->source_tree != NULL.
-		 */
-		if (ce_path_match(ce, &opts->pathspec, ps_matched))
-			ce->ce_flags |= CE_MATCHED;
-	}
+	for (pos = 0; pos < active_nr; pos++)
+		if (opts->overlay_mode)
+			mark_ce_for_checkout_overlay(active_cache[pos],
+						     ps_matched,
+						     opts);
+		else
+			mark_ce_for_checkout_no_overlay(active_cache[pos],
+							ps_matched,
+							opts);
 
-	if (report_path_error(ps_matched, &opts->pathspec, opts->prefix)) {
+	if (report_path_error(ps_matched, &opts->pathspec)) {
 		free(ps_matched);
 		return 1;
 	}
@@ -336,10 +504,11 @@ static int checkout_paths(const struct c
 		if (ce->ce_flags & CE_MATCHED) {
 			if (!ce_stage(ce))
 				continue;
-			if (opts->force) {
-				warning(_("path '%s' is unmerged"), ce->name);
+			if (opts->ignore_unmerged) {
+				if (!opts->quiet)
+					warning(_("path '%s' is unmerged"), ce->name);
 			} else if (opts->writeout_stage) {
-				errs |= check_stage(opts->writeout_stage, ce, pos);
+				errs |= check_stage(opts->writeout_stage, ce, pos, opts->overlay_mode);
 			} else if (opts->merge) {
 				errs |= check_stages((1<<2) | (1<<3), ce, pos);
 			} else {
@@ -353,32 +522,35 @@ static int checkout_paths(const struct c
 		return 1;
 
 	/* Now we are committed to check them out */
-	state.force = 1;
-	state.refresh_cache = 1;
-	state.istate = &the_index;
+	if (opts->checkout_worktree)
+		errs |= checkout_worktree(opts);
+	else
+		remove_marked_cache_entries(&the_index, 1);
 
-	enable_delayed_checkout(&state);
-	for (pos = 0; pos < active_nr; pos++) {
-		struct cache_entry *ce = active_cache[pos];
-		if (ce->ce_flags & CE_MATCHED) {
-			if (!ce_stage(ce)) {
-				errs |= checkout_entry(ce, &state, NULL);
-				continue;
-			}
-			if (opts->writeout_stage)
-				errs |= checkout_stage(opts->writeout_stage, ce, pos, &state);
-			else if (opts->merge)
-				errs |= checkout_merged(pos, &state);
-			pos = skip_same_name(ce, pos) - 1;
-		}
-	}
-	errs |= finish_delayed_checkout(&state);
+	/*
+	 * Allow updating the index when checking out from the index.
+	 * This is to save new stat info.
+	 */
+	if (opts->checkout_worktree && !opts->checkout_index && !opts->source_tree)
+		checkout_index = 1;
+	else
+		checkout_index = opts->checkout_index;
 
-	if (write_locked_index(&the_index, &lock_file, COMMIT_LOCK))
-		die(_("unable to write new index file"));
+	if (checkout_index) {
+		if (write_locked_index(&the_index, &lock_file, COMMIT_LOCK))
+			die(_("unable to write new index file"));
+	} else {
+		/*
+		 * NEEDSWORK: if --worktree is not specified, we
+		 * should save stat info of checked out files in the
+		 * index to avoid the next (potentially costly)
+		 * refresh. But it's a bit tricker to do...
+		 */
+		rollback_lock_file(&lock_file);
+	}
 
 	read_ref_full("HEAD", 0, &rev, NULL);
-	head = lookup_commit_reference_gently(&rev, 1);
+	head = lookup_commit_reference_gently(the_repository, &rev, 1);
 
 	errs |= post_checkout_hook(head, head, 0);
 	return errs;
@@ -389,7 +561,7 @@ static void show_local_changes(struct ob
 {
 	struct rev_info rev;
 	/* I think we want full paths, even if we're in a subdirectory. */
-	init_revisions(&rev, NULL);
+	repo_init_revisions(the_repository, &rev, NULL);
 	rev.diffopt.flags = opts->flags;
 	rev.diffopt.output_format |= DIFF_FORMAT_NAME_STATUS;
 	diff_setup_done(&rev.diffopt);
@@ -477,15 +649,21 @@ static int merge_working_tree(const stru
 {
 	int ret;
 	struct lock_file lock_file = LOCK_INIT;
+	struct tree *new_tree;
 
 	hold_locked_index(&lock_file, LOCK_DIE_ON_ERROR);
 	if (read_cache_preload(NULL) < 0)
 		return error(_("index file corrupt"));
 
 	resolve_undo_clear();
-	if (opts->force) {
-		ret = reset_tree(get_commit_tree(new_branch_info->commit),
-				 opts, 1, writeout_error);
+	if (opts->new_orphan_branch && opts->orphan_from_empty_tree) {
+		if (new_branch_info->commit)
+			BUG("'switch --orphan' should never accept a commit as starting point");
+		new_tree = parse_tree_indirect(the_hash_algo->empty_tree);
+	} else
+		new_tree = get_commit_tree(new_branch_info->commit);
+	if (opts->discard_changes) {
+		ret = reset_tree(new_tree, opts, 1, writeout_error);
 		if (ret)
 			return ret;
 	} else {
@@ -511,7 +689,7 @@ static int merge_working_tree(const stru
 		topts.initial_checkout = is_cache_unborn();
 		topts.update = 1;
 		topts.merge = 1;
-		topts.gently = opts->merge && old_branch_info->commit;
+		topts.quiet = opts->merge && old_branch_info->commit;
 		topts.verbose_update = opts->show_progress;
 		topts.fn = twoway_merge;
 		if (opts->overwrite_ignore) {
@@ -523,7 +701,8 @@ static int merge_working_tree(const stru
 					   &old_branch_info->commit->object.oid :
 					   the_hash_algo->empty_tree);
 		init_tree_desc(&trees[0], tree->buffer, tree->size);
-		tree = parse_tree_indirect(&new_branch_info->commit->object.oid);
+		parse_tree(new_tree);
+		tree = new_tree;
 		init_tree_desc(&trees[1], tree->buffer, tree->size);
 
 		ret = unpack_trees(2, trees, &topts);
@@ -534,9 +713,12 @@ static int merge_working_tree(const stru
 			 * give up or do a real merge, depending on
 			 * whether the merge flag was used.
 			 */
-			struct tree *result;
 			struct tree *work;
+			struct tree *old_tree;
 			struct merge_options o;
+			struct strbuf sb = STRBUF_INIT;
+			struct strbuf old_commit_shortname = STRBUF_INIT;
+
 			if (!opts->merge)
 				return 1;
 
@@ -546,6 +728,12 @@ static int merge_working_tree(const stru
 			 */
 			if (!old_branch_info->commit)
 				return 1;
+			old_tree = get_commit_tree(old_branch_info->commit);
+
+			if (repo_index_has_changes(the_repository, old_tree, &sb))
+				die(_("cannot continue with staged changes in "
+				      "the following files:\n%s"), sb.buf);
+			strbuf_release(&sb);
 
 			/* Do more real merge */
 
@@ -568,29 +756,35 @@ static int merge_working_tree(const stru
 			 * a pain; plumb in an option to set
 			 * o.renormalize?
 			 */
-			init_merge_options(&o);
+			init_merge_options(&o, the_repository);
 			o.verbosity = 0;
-			work = write_tree_from_memory(&o);
+			work = write_in_core_index_as_tree(the_repository);
 
-			ret = reset_tree(get_commit_tree(new_branch_info->commit),
+			ret = reset_tree(new_tree,
 					 opts, 1,
 					 writeout_error);
 			if (ret)
 				return ret;
 			o.ancestor = old_branch_info->name;
+			if (old_branch_info->name == NULL) {
+				strbuf_add_unique_abbrev(&old_commit_shortname,
+							 &old_branch_info->commit->object.oid,
+							 DEFAULT_ABBREV);
+				o.ancestor = old_commit_shortname.buf;
+			}
 			o.branch1 = new_branch_info->name;
 			o.branch2 = "local";
 			ret = merge_trees(&o,
-					  get_commit_tree(new_branch_info->commit),
+					  new_tree,
 					  work,
-					  get_commit_tree(old_branch_info->commit),
-					  &result);
+					  old_tree);
 			if (ret < 0)
 				exit(128);
-			ret = reset_tree(get_commit_tree(new_branch_info->commit),
+			ret = reset_tree(new_tree,
 					 opts, 0,
 					 writeout_error);
 			strbuf_release(&o.obuf);
+			strbuf_release(&old_commit_shortname);
 			if (ret)
 				return ret;
 		}
@@ -605,7 +799,7 @@ static int merge_working_tree(const stru
 	if (write_locked_index(&the_index, &lock_file, COMMIT_LOCK))
 		die(_("unable to write new index file"));
 
-	if (!opts->force && !opts->quiet)
+	if (!opts->discard_changes && !opts->quiet && new_branch_info->commit)
 		show_local_changes(&new_branch_info->commit->object, &opts->diff_options);
 
 	return 0;
@@ -651,7 +845,8 @@ static void update_refs_for_switch(const
 			free(refname);
 		}
 		else
-			create_branch(opts->new_branch, new_branch_info->name,
+			create_branch(the_repository,
+				      opts->new_branch, new_branch_info->name,
 				      opts->new_branch_force ? 1 : 0,
 				      opts->new_branch_force ? 1 : 0,
 				      opts->new_branch_log,
@@ -709,7 +904,7 @@ static void update_refs_for_switch(const
 				delete_reflog(old_branch_info->path);
 		}
 	}
-	remove_branch_state();
+	remove_branch_state(the_repository, !opts->quiet);
 	strbuf_release(&msg);
 	if (!opts->quiet &&
 	    (new_branch_info->path || (!opts->force_detach && !strcmp(new_branch_info->name, "HEAD"))))
@@ -798,14 +993,17 @@ static void orphaned_commit_warning(stru
 	struct rev_info revs;
 	struct object *object = &old_commit->object;
 
-	init_revisions(&revs, NULL);
+	repo_init_revisions(the_repository, &revs, NULL);
 	setup_revisions(0, NULL, &revs, NULL);
 
 	object->flags &= ~UNINTERESTING;
 	add_pending_object(&revs, object, oid_to_hex(&object->oid));
 
 	for_each_ref(add_pending_uninteresting_ref, &revs);
-	add_pending_oid(&revs, "HEAD", &new_commit->object.oid, UNINTERESTING);
+	if (new_commit)
+		add_pending_oid(&revs, "HEAD",
+				&new_commit->object.oid,
+				UNINTERESTING);
 
 	if (prepare_revision_walk(&revs))
 		die(_("internal error in revision walk"));
@@ -826,28 +1024,45 @@ static int switch_branches(const struct
 	void *path_to_free;
 	struct object_id rev;
 	int flag, writeout_error = 0;
+	int do_merge = 1;
+
+	trace2_cmd_mode("branch");
+
 	memset(&old_branch_info, 0, sizeof(old_branch_info));
 	old_branch_info.path = path_to_free = resolve_refdup("HEAD", 0, &rev, &flag);
 	if (old_branch_info.path)
-		old_branch_info.commit = lookup_commit_reference_gently(&rev, 1);
+		old_branch_info.commit = lookup_commit_reference_gently(the_repository, &rev, 1);
 	if (!(flag & REF_ISSYMREF))
 		old_branch_info.path = NULL;
 
 	if (old_branch_info.path)
 		skip_prefix(old_branch_info.path, "refs/heads/", &old_branch_info.name);
 
+	if (opts->new_orphan_branch && opts->orphan_from_empty_tree) {
+		if (new_branch_info->name)
+			BUG("'switch --orphan' should never accept a commit as starting point");
+		new_branch_info->commit = NULL;
+		new_branch_info->name = "(empty)";
+		do_merge = 1;
+	}
+
 	if (!new_branch_info->name) {
 		new_branch_info->name = "HEAD";
 		new_branch_info->commit = old_branch_info.commit;
 		if (!new_branch_info->commit)
 			die(_("You are on a branch yet to be born"));
 		parse_commit_or_die(new_branch_info->commit);
+
+		if (opts->only_merge_on_switching_branches)
+			do_merge = 0;
 	}
 
-	ret = merge_working_tree(opts, &old_branch_info, new_branch_info, &writeout_error);
-	if (ret) {
-		free(path_to_free);
-		return ret;
+	if (do_merge) {
+		ret = merge_working_tree(opts, &old_branch_info, new_branch_info, &writeout_error);
+		if (ret) {
+			free(path_to_free);
+			return ret;
+		}
 	}
 
 	if (!opts->quiet && !old_branch_info.path && old_branch_info.commit && new_branch_info->commit != old_branch_info.commit)
@@ -874,16 +1089,43 @@ static int git_checkout_config(const cha
 	return git_xmerge_config(var, value, NULL);
 }
 
+static void setup_new_branch_info_and_source_tree(
+	struct branch_info *new_branch_info,
+	struct checkout_opts *opts,
+	struct object_id *rev,
+	const char *arg)
+{
+	struct tree **source_tree = &opts->source_tree;
+	struct object_id branch_rev;
+
+	new_branch_info->name = arg;
+	setup_branch_path(new_branch_info);
+
+	if (!check_refname_format(new_branch_info->path, 0) &&
+	    !read_ref(new_branch_info->path, &branch_rev))
+		oidcpy(rev, &branch_rev);
+	else
+		new_branch_info->path = NULL; /* not an existing branch */
+
+	new_branch_info->commit = lookup_commit_reference_gently(the_repository, rev, 1);
+	if (!new_branch_info->commit) {
+		/* not a commit */
+		*source_tree = parse_tree_indirect(rev);
+	} else {
+		parse_commit_or_die(new_branch_info->commit);
+		*source_tree = get_commit_tree(new_branch_info->commit);
+	}
+}
+
 static int parse_branchname_arg(int argc, const char **argv,
 				int dwim_new_local_branch_ok,
 				struct branch_info *new_branch_info,
 				struct checkout_opts *opts,
-				struct object_id *rev)
+				struct object_id *rev,
+				int *dwim_remotes_matched)
 {
-	struct tree **source_tree = &opts->source_tree;
 	const char **new_branch = &opts->new_branch;
 	int argcount = 0;
-	struct object_id branch_rev;
 	const char *arg;
 	int dash_dash_pos;
 	int has_dash_dash = 0;
@@ -910,8 +1152,10 @@ static int parse_branchname_arg(int argc
 	 *   (b) If <something> is _not_ a commit, either "--" is present
 	 *       or <something> is not a path, no -t or -b was given, and
 	 *       and there is a tracking branch whose name is <something>
-	 *       in one and only one remote, then this is a short-hand to
-	 *       fork local <something> from that remote-tracking branch.
+	 *       in one and only one remote (or if the branch exists on the
+	 *       remote named in checkout.defaultRemote), then this is a
+	 *       short-hand to fork local <something> from that
+	 *       remote-tracking branch.
 	 *
 	 *   (c) Otherwise, if "--" is present, treat it like case (1).
 	 *
@@ -931,10 +1175,16 @@ static int parse_branchname_arg(int argc
 	if (!argc)
 		return 0;
 
+	if (!opts->accept_pathspec) {
+		if (argc > 1)
+			die(_("only one reference expected"));
+		has_dash_dash = 1; /* helps disambiguate */
+	}
+
 	arg = argv[0];
 	dash_dash_pos = -1;
 	for (i = 0; i < argc; i++) {
-		if (!strcmp(argv[i], "--")) {
+		if (opts->accept_pathspec && !strcmp(argv[i], "--")) {
 			dash_dash_pos = i;
 			break;
 		}
@@ -945,6 +1195,7 @@ static int parse_branchname_arg(int argc
 		has_dash_dash = 1; /* case (3) or (1) */
 	else if (dash_dash_pos >= 2)
 		die(_("only one reference expected, %d given."), dash_dash_pos);
+	opts->count_checkout_paths = !opts->quiet && !has_dash_dash;
 
 	if (!strcmp(arg, "-"))
 		arg = "@{-1}";
@@ -960,20 +1211,29 @@ static int parse_branchname_arg(int argc
 		 */
 		int recover_with_dwim = dwim_new_local_branch_ok;
 
-		if (!has_dash_dash &&
-		    (check_filename(opts->prefix, arg) || !no_wildcard(arg)))
+		int could_be_checkout_paths = !has_dash_dash &&
+			check_filename(opts->prefix, arg);
+
+		if (!has_dash_dash && !no_wildcard(arg))
 			recover_with_dwim = 0;
+
 		/*
-		 * Accept "git checkout foo" and "git checkout foo --"
-		 * as candidates for dwim.
+		 * Accept "git checkout foo", "git checkout foo --"
+		 * and "git switch foo" as candidates for dwim.
 		 */
 		if (!(argc == 1 && !has_dash_dash) &&
-		    !(argc == 2 && has_dash_dash))
+		    !(argc == 2 && has_dash_dash) &&
+		    opts->accept_pathspec)
 			recover_with_dwim = 0;
 
 		if (recover_with_dwim) {
-			const char *remote = unique_tracking_name(arg, rev);
+			const char *remote = unique_tracking_name(arg, rev,
+								  dwim_remotes_matched);
 			if (remote) {
+				if (could_be_checkout_paths)
+					die(_("'%s' could be both a local file and a tracking branch.\n"
+					      "Please use -- (and optionally --no-guess) to disambiguate"),
+					    arg);
 				*new_branch = arg;
 				arg = remote;
 				/* DWIMmed to create local branch, case (3).(b) */
@@ -994,26 +1254,11 @@ static int parse_branchname_arg(int argc
 	argv++;
 	argc--;
 
-	new_branch_info->name = arg;
-	setup_branch_path(new_branch_info);
+	setup_new_branch_info_and_source_tree(new_branch_info, opts, rev, arg);
 
-	if (!check_refname_format(new_branch_info->path, 0) &&
-	    !read_ref(new_branch_info->path, &branch_rev))
-		oidcpy(rev, &branch_rev);
-	else
-		new_branch_info->path = NULL; /* not an existing branch */
-
-	new_branch_info->commit = lookup_commit_reference_gently(rev, 1);
-	if (!new_branch_info->commit) {
-		/* not a commit */
-		*source_tree = parse_tree_indirect(rev);
-	} else {
-		parse_commit_or_die(new_branch_info->commit);
-		*source_tree = get_commit_tree(new_branch_info->commit);
-	}
-
-	if (!*source_tree)                   /* case (1): want a tree */
+	if (!opts->source_tree)                   /* case (1): want a tree */
 		die(_("reference is not a tree: %s"), arg);
+
 	if (!has_dash_dash) {	/* case (3).(d) -> (1) */
 		/*
 		 * Do not complain the most common case
@@ -1023,7 +1268,7 @@ static int parse_branchname_arg(int argc
 		 */
 		if (argc)
 			verify_non_filename(opts->prefix, arg);
-	} else {
+	} else if (opts->accept_pathspec) {
 		argcount++;
 		argv++;
 		argc--;
@@ -1037,6 +1282,8 @@ static int switch_unborn_to_new_branch(c
 	int status;
 	struct strbuf branch_ref = STRBUF_INIT;
 
+	trace2_cmd_mode("unborn");
+
 	if (!opts->new_branch)
 		die(_("You are on a branch yet to be born"));
 	strbuf_addf(&branch_ref, "refs/heads/%s", opts->new_branch);
@@ -1048,6 +1295,60 @@ static int switch_unborn_to_new_branch(c
 	return status;
 }
 
+static void die_expecting_a_branch(const struct branch_info *branch_info)
+{
+	struct object_id oid;
+	char *to_free;
+
+	if (dwim_ref(branch_info->name, strlen(branch_info->name), &oid, &to_free) == 1) {
+		const char *ref = to_free;
+
+		if (skip_prefix(ref, "refs/tags/", &ref))
+			die(_("a branch is expected, got tag '%s'"), ref);
+		if (skip_prefix(ref, "refs/remotes/", &ref))
+			die(_("a branch is expected, got remote branch '%s'"), ref);
+		die(_("a branch is expected, got '%s'"), ref);
+	}
+	if (branch_info->commit)
+		die(_("a branch is expected, got commit '%s'"), branch_info->name);
+	/*
+	 * This case should never happen because we already die() on
+	 * non-commit, but just in case.
+	 */
+	die(_("a branch is expected, got '%s'"), branch_info->name);
+}
+
+static void die_if_some_operation_in_progress(void)
+{
+	struct wt_status_state state;
+
+	memset(&state, 0, sizeof(state));
+	wt_status_get_state(the_repository, &state, 0);
+
+	if (state.merge_in_progress)
+		die(_("cannot switch branch while merging\n"
+		      "Consider \"git merge --quit\" "
+		      "or \"git worktree add\"."));
+	if (state.am_in_progress)
+		die(_("cannot switch branch in the middle of an am session\n"
+		      "Consider \"git am --quit\" "
+		      "or \"git worktree add\"."));
+	if (state.rebase_interactive_in_progress || state.rebase_in_progress)
+		die(_("cannot switch branch while rebasing\n"
+		      "Consider \"git rebase --quit\" "
+		      "or \"git worktree add\"."));
+	if (state.cherry_pick_in_progress)
+		die(_("cannot switch branch while cherry-picking\n"
+		      "Consider \"git cherry-pick --quit\" "
+		      "or \"git worktree add\"."));
+	if (state.revert_in_progress)
+		die(_("cannot switch branch while reverting\n"
+		      "Consider \"git revert --quit\" "
+		      "or \"git worktree add\"."));
+	if (state.bisect_in_progress)
+		warning(_("you are switching branch while bisecting"));
+}
+
 static int checkout_branch(struct checkout_opts *opts,
 			   struct branch_info *new_branch_info)
 {
@@ -1058,6 +1359,10 @@ static int checkout_branch(struct checko
 		die(_("'%s' cannot be used with switching branches"),
 		    "--patch");
 
+	if (opts->overlay_mode != -1)
+		die(_("'%s' cannot be used with switching branches"),
+		    "--[no]-overlay");
+
 	if (opts->writeout_stage)
 		die(_("'%s' cannot be used with switching branches"),
 		    "--ours/--theirs");
@@ -1065,6 +1370,9 @@ static int checkout_branch(struct checko
 	if (opts->force && opts->merge)
 		die(_("'%s' cannot be used with '%s'"), "-f", "-m");
 
+	if (opts->discard_changes && opts->merge)
+		die(_("'%s' cannot be used with '%s'"), "--discard-changes", "--merge");
+
 	if (opts->force_detach && opts->new_branch)
 		die(_("'%s' cannot be used with '%s'"),
 		    "--detach", "-b/-B/--orphan");
@@ -1072,6 +1380,8 @@ static int checkout_branch(struct checko
 	if (opts->new_orphan_branch) {
 		if (opts->track != BRANCH_TRACK_UNSPECIFIED)
 			die(_("'%s' cannot be used with '%s'"), "--orphan", "-t");
+		if (opts->orphan_from_empty_tree && new_branch_info->name)
+			die(_("'%s' cannot take <start-point>"), "--orphan");
 	} else if (opts->force_detach) {
 		if (opts->track != BRANCH_TRACK_UNSPECIFIED)
 			die(_("'%s' cannot be used with '%s'"), "--detach", "-t");
@@ -1082,6 +1392,23 @@ static int checkout_branch(struct checko
 		die(_("Cannot switch branch to a non-commit '%s'"),
 		    new_branch_info->name);
 
+	if (!opts->switch_branch_doing_nothing_is_ok &&
+	    !new_branch_info->name &&
+	    !opts->new_branch &&
+	    !opts->force_detach)
+		die(_("missing branch or commit argument"));
+
+	if (!opts->implicit_detach &&
+	    !opts->force_detach &&
+	    !opts->new_branch &&
+	    !opts->new_branch_force &&
+	    new_branch_info->name &&
+	    !new_branch_info->path)
+		die_expecting_a_branch(new_branch_info);
+
+	if (!opts->can_switch_when_in_progress)
+		die_if_some_operation_in_progress();
+
 	if (new_branch_info->path && !opts->force_detach && !opts->new_branch &&
 	    !opts->ignore_other_worktrees) {
 		int flag;
@@ -1103,99 +1430,159 @@ static int checkout_branch(struct checko
 	return switch_branches(opts, new_branch_info);
 }
 
-int cmd_checkout(int argc, const char **argv, const char *prefix)
+static struct option *add_common_options(struct checkout_opts *opts,
+					 struct option *prevopts)
 {
-	struct checkout_opts opts;
-	struct branch_info new_branch_info;
-	char *conflict_style = NULL;
-	int dwim_new_local_branch = 1;
 	struct option options[] = {
-		OPT__QUIET(&opts.quiet, N_("suppress progress reporting")),
-		OPT_STRING('b', NULL, &opts.new_branch, N_("branch"),
-			   N_("create and checkout a new branch")),
-		OPT_STRING('B', NULL, &opts.new_branch_force, N_("branch"),
-			   N_("create/reset and checkout a branch")),
-		OPT_BOOL('l', NULL, &opts.new_branch_log, N_("create reflog for new branch")),
-		OPT_BOOL(0, "detach", &opts.force_detach, N_("detach HEAD at named commit")),
-		OPT_SET_INT('t', "track",  &opts.track, N_("set upstream info for new branch"),
+		OPT__QUIET(&opts->quiet, N_("suppress progress reporting")),
+		{ OPTION_CALLBACK, 0, "recurse-submodules", NULL,
+			    "checkout", "control recursive updating of submodules",
+			    PARSE_OPT_OPTARG, option_parse_recurse_submodules_worktree_updater },
+		OPT_BOOL(0, "progress", &opts->show_progress, N_("force progress reporting")),
+		OPT_BOOL('m', "merge", &opts->merge, N_("perform a 3-way merge with the new branch")),
+		OPT_STRING(0, "conflict", &opts->conflict_style, N_("style"),
+			   N_("conflict style (merge or diff3)")),
+		OPT_END()
+	};
+	struct option *newopts = parse_options_concat(prevopts, options);
+	free(prevopts);
+	return newopts;
+}
+
+static struct option *add_common_switch_branch_options(
+	struct checkout_opts *opts, struct option *prevopts)
+{
+	struct option options[] = {
+		OPT_BOOL('d', "detach", &opts->force_detach, N_("detach HEAD at named commit")),
+		OPT_SET_INT('t', "track",  &opts->track, N_("set upstream info for new branch"),
 			BRANCH_TRACK_EXPLICIT),
-		OPT_STRING(0, "orphan", &opts.new_orphan_branch, N_("new-branch"), N_("new unparented branch")),
-		OPT_SET_INT('2', "ours", &opts.writeout_stage, N_("checkout our version for unmerged files"),
-			    2),
-		OPT_SET_INT('3', "theirs", &opts.writeout_stage, N_("checkout their version for unmerged files"),
-			    3),
-		OPT__FORCE(&opts.force, N_("force checkout (throw away local modifications)"),
+		OPT__FORCE(&opts->force, N_("force checkout (throw away local modifications)"),
 			   PARSE_OPT_NOCOMPLETE),
-		OPT_BOOL('m', "merge", &opts.merge, N_("perform a 3-way merge with the new branch")),
-		OPT_BOOL_F(0, "overwrite-ignore", &opts.overwrite_ignore,
+		OPT_STRING(0, "orphan", &opts->new_orphan_branch, N_("new-branch"), N_("new unparented branch")),
+		OPT_BOOL_F(0, "overwrite-ignore", &opts->overwrite_ignore,
 			   N_("update ignored files (default)"),
 			   PARSE_OPT_NOCOMPLETE),
-		OPT_STRING(0, "conflict", &conflict_style, N_("style"),
-			   N_("conflict style (merge or diff3)")),
-		OPT_BOOL('p', "patch", &opts.patch_mode, N_("select hunks interactively")),
-		OPT_BOOL(0, "ignore-skip-worktree-bits", &opts.ignore_skipworktree,
-			 N_("do not limit pathspecs to sparse entries only")),
-		OPT_HIDDEN_BOOL(0, "guess", &dwim_new_local_branch,
-				N_("second guess 'git checkout <no-such-branch>'")),
-		OPT_BOOL(0, "ignore-other-worktrees", &opts.ignore_other_worktrees,
+		OPT_BOOL(0, "ignore-other-worktrees", &opts->ignore_other_worktrees,
 			 N_("do not check if another worktree is holding the given ref")),
-		{ OPTION_CALLBACK, 0, "recurse-submodules", NULL,
-			    "checkout", "control recursive updating of submodules",
-			    PARSE_OPT_OPTARG, option_parse_recurse_submodules_worktree_updater },
-		OPT_BOOL(0, "progress", &opts.show_progress, N_("force progress reporting")),
-		OPT_END(),
+		OPT_END()
 	};
+	struct option *newopts = parse_options_concat(prevopts, options);
+	free(prevopts);
+	return newopts;
+}
+
+static struct option *add_checkout_path_options(struct checkout_opts *opts,
+						struct option *prevopts)
+{
+	struct option options[] = {
+		OPT_SET_INT_F('2', "ours", &opts->writeout_stage,
+			      N_("checkout our version for unmerged files"),
+			      2, PARSE_OPT_NONEG),
+		OPT_SET_INT_F('3', "theirs", &opts->writeout_stage,
+			      N_("checkout their version for unmerged files"),
+			      3, PARSE_OPT_NONEG),
+		OPT_BOOL('p', "patch", &opts->patch_mode, N_("select hunks interactively")),
+		OPT_BOOL(0, "ignore-skip-worktree-bits", &opts->ignore_skipworktree,
+			 N_("do not limit pathspecs to sparse entries only")),
+		OPT_PATHSPEC_FROM_FILE(&opts->pathspec_from_file),
+		OPT_PATHSPEC_FILE_NUL(&opts->pathspec_file_nul),
+		OPT_END()
+	};
+	struct option *newopts = parse_options_concat(prevopts, options);
+	free(prevopts);
+	return newopts;
+}
+
+static int checkout_main(int argc, const char **argv, const char *prefix,
+			 struct checkout_opts *opts, struct option *options,
+			 const char * const usagestr[])
+{
+	struct branch_info new_branch_info;
+	int dwim_remotes_matched = 0;
+	int parseopt_flags = 0;
 
-	memset(&opts, 0, sizeof(opts));
 	memset(&new_branch_info, 0, sizeof(new_branch_info));
-	opts.overwrite_ignore = 1;
-	opts.prefix = prefix;
-	opts.show_progress = -1;
+	opts->overwrite_ignore = 1;
+	opts->prefix = prefix;
+	opts->show_progress = -1;
+
+	git_config(git_checkout_config, opts);
 
-	git_config(git_checkout_config, &opts);
+	opts->track = BRANCH_TRACK_UNSPECIFIED;
 
-	opts.track = BRANCH_TRACK_UNSPECIFIED;
+	if (!opts->accept_pathspec && !opts->accept_ref)
+		BUG("make up your mind, you need to take _something_");
+	if (opts->accept_pathspec && opts->accept_ref)
+		parseopt_flags = PARSE_OPT_KEEP_DASHDASH;
 
-	argc = parse_options(argc, argv, prefix, options, checkout_usage,
-			     PARSE_OPT_KEEP_DASHDASH);
+	argc = parse_options(argc, argv, prefix, options,
+			     usagestr, parseopt_flags);
 
-	if (opts.show_progress < 0) {
-		if (opts.quiet)
-			opts.show_progress = 0;
+	if (opts->show_progress < 0) {
+		if (opts->quiet)
+			opts->show_progress = 0;
 		else
-			opts.show_progress = isatty(2);
+			opts->show_progress = isatty(2);
 	}
 
-	if (conflict_style) {
-		opts.merge = 1; /* implied */
-		git_xmerge_config("merge.conflictstyle", conflict_style, NULL);
+	if (opts->conflict_style) {
+		opts->merge = 1; /* implied */
+		git_xmerge_config("merge.conflictstyle", opts->conflict_style, NULL);
+	}
+	if (opts->force) {
+		opts->discard_changes = 1;
+		opts->ignore_unmerged_opt = "--force";
+		opts->ignore_unmerged = 1;
 	}
 
-	if ((!!opts.new_branch + !!opts.new_branch_force + !!opts.new_orphan_branch) > 1)
+	if ((!!opts->new_branch + !!opts->new_branch_force + !!opts->new_orphan_branch) > 1)
 		die(_("-b, -B and --orphan are mutually exclusive"));
 
+	if (opts->overlay_mode == 1 && opts->patch_mode)
+		die(_("-p and --overlay are mutually exclusive"));
+
+	if (opts->checkout_index >= 0 || opts->checkout_worktree >= 0) {
+		if (opts->checkout_index < 0)
+			opts->checkout_index = 0;
+		if (opts->checkout_worktree < 0)
+			opts->checkout_worktree = 0;
+	} else {
+		if (opts->checkout_index < 0)
+			opts->checkout_index = -opts->checkout_index - 1;
+		if (opts->checkout_worktree < 0)
+			opts->checkout_worktree = -opts->checkout_worktree - 1;
+	}
+	if (opts->checkout_index < 0 || opts->checkout_worktree < 0)
+		BUG("these flags should be non-negative by now");
+	/*
+	 * convenient shortcut: "git restore --staged" equals
+	 * "git restore --staged --source HEAD"
+	 */
+	if (!opts->from_treeish && opts->checkout_index && !opts->checkout_worktree)
+		opts->from_treeish = "HEAD";
+
 	/*
 	 * From here on, new_branch will contain the branch to be checked out,
 	 * and new_branch_force and new_orphan_branch will tell us which one of
 	 * -b/-B/--orphan is being used.
 	 */
-	if (opts.new_branch_force)
-		opts.new_branch = opts.new_branch_force;
+	if (opts->new_branch_force)
+		opts->new_branch = opts->new_branch_force;
 
-	if (opts.new_orphan_branch)
-		opts.new_branch = opts.new_orphan_branch;
+	if (opts->new_orphan_branch)
+		opts->new_branch = opts->new_orphan_branch;
 
 	/* --track without -b/-B/--orphan should DWIM */
-	if (opts.track != BRANCH_TRACK_UNSPECIFIED && !opts.new_branch) {
+	if (opts->track != BRANCH_TRACK_UNSPECIFIED && !opts->new_branch) {
 		const char *argv0 = argv[0];
 		if (!argc || !strcmp(argv0, "--"))
-			die (_("--track needs a branch name"));
+			die(_("--track needs a branch name"));
 		skip_prefix(argv0, "refs/", &argv0);
 		skip_prefix(argv0, "remotes/", &argv0);
 		argv0 = strchr(argv0, '/');
 		if (!argv0 || !argv0[1])
-			die (_("Missing branch name; try -b"));
-		opts.new_branch = argv0 + 1;
+			die(_("missing branch name; try -b"));
+		opts->new_branch = argv0 + 1;
 	}
 
 	/*
@@ -1211,58 +1598,238 @@ int cmd_checkout(int argc, const char **
 	 * including "last branch" syntax and DWIM-ery for names of
 	 * remote branches, erroring out for invalid or ambiguous cases.
 	 */
-	if (argc) {
+	if (argc && opts->accept_ref) {
 		struct object_id rev;
 		int dwim_ok =
-			!opts.patch_mode &&
-			dwim_new_local_branch &&
-			opts.track == BRANCH_TRACK_UNSPECIFIED &&
-			!opts.new_branch;
+			!opts->patch_mode &&
+			opts->dwim_new_local_branch &&
+			opts->track == BRANCH_TRACK_UNSPECIFIED &&
+			!opts->new_branch;
 		int n = parse_branchname_arg(argc, argv, dwim_ok,
-					     &new_branch_info, &opts, &rev);
+					     &new_branch_info, opts, &rev,
+					     &dwim_remotes_matched);
 		argv += n;
 		argc -= n;
+	} else if (!opts->accept_ref && opts->from_treeish) {
+		struct object_id rev;
+
+		if (get_oid_mb(opts->from_treeish, &rev))
+			die(_("could not resolve %s"), opts->from_treeish);
+
+		setup_new_branch_info_and_source_tree(&new_branch_info,
+						      opts, &rev,
+						      opts->from_treeish);
+
+		if (!opts->source_tree)
+			die(_("reference is not a tree: %s"), opts->from_treeish);
 	}
 
 	if (argc) {
-		parse_pathspec(&opts.pathspec, 0,
-			       opts.patch_mode ? PATHSPEC_PREFIX_ORIGIN : 0,
+		parse_pathspec(&opts->pathspec, 0,
+			       opts->patch_mode ? PATHSPEC_PREFIX_ORIGIN : 0,
 			       prefix, argv);
 
-		if (!opts.pathspec.nr)
+		if (!opts->pathspec.nr)
 			die(_("invalid path specification"));
 
 		/*
 		 * Try to give more helpful suggestion.
 		 * new_branch && argc > 1 will be caught later.
 		 */
-		if (opts.new_branch && argc == 1)
+		if (opts->new_branch && argc == 1)
 			die(_("'%s' is not a commit and a branch '%s' cannot be created from it"),
-				argv[0], opts.new_branch);
+				argv[0], opts->new_branch);
 
-		if (opts.force_detach)
+		if (opts->force_detach)
 			die(_("git checkout: --detach does not take a path argument '%s'"),
 			    argv[0]);
+	}
+
+	if (opts->pathspec_from_file) {
+		if (opts->pathspec.nr)
+			die(_("--pathspec-from-file is incompatible with pathspec arguments"));
 
-		if (1 < !!opts.writeout_stage + !!opts.force + !!opts.merge)
+		if (opts->force_detach)
+			die(_("--pathspec-from-file is incompatible with --detach"));
+
+		if (opts->patch_mode)
+			die(_("--pathspec-from-file is incompatible with --patch"));
+
+		parse_pathspec_file(&opts->pathspec, 0,
+				    0,
+				    prefix, opts->pathspec_from_file, opts->pathspec_file_nul);
+	} else if (opts->pathspec_file_nul) {
+		die(_("--pathspec-file-nul requires --pathspec-from-file"));
+	}
+
+	if (opts->pathspec.nr) {
+		if (1 < !!opts->writeout_stage + !!opts->force + !!opts->merge)
 			die(_("git checkout: --ours/--theirs, --force and --merge are incompatible when\n"
 			      "checking out of the index."));
+	} else {
+		if (opts->accept_pathspec && !opts->empty_pathspec_ok &&
+		    !opts->patch_mode)	/* patch mode is special */
+			die(_("you must specify path(s) to restore"));
 	}
 
-	if (opts.new_branch) {
+	if (opts->new_branch) {
 		struct strbuf buf = STRBUF_INIT;
 
-		if (opts.new_branch_force)
-			opts.branch_exists = validate_branchname(opts.new_branch, &buf);
+		if (opts->new_branch_force)
+			opts->branch_exists = validate_branchname(opts->new_branch, &buf);
 		else
-			opts.branch_exists =
-				validate_new_branchname(opts.new_branch, &buf, 0);
+			opts->branch_exists =
+				validate_new_branchname(opts->new_branch, &buf, 0);
 		strbuf_release(&buf);
 	}
 
 	UNLEAK(opts);
-	if (opts.patch_mode || opts.pathspec.nr)
-		return checkout_paths(&opts, new_branch_info.name);
-	else
-		return checkout_branch(&opts, &new_branch_info);
+	if (opts->patch_mode || opts->pathspec.nr) {
+		int ret = checkout_paths(opts, new_branch_info.name);
+		if (ret && dwim_remotes_matched > 1 &&
+		    advice_checkout_ambiguous_remote_branch_name)
+			advise(_("'%s' matched more than one remote tracking branch.\n"
+				 "We found %d remotes with a reference that matched. So we fell back\n"
+				 "on trying to resolve the argument as a path, but failed there too!\n"
+				 "\n"
+				 "If you meant to check out a remote tracking branch on, e.g. 'origin',\n"
+				 "you can do so by fully qualifying the name with the --track option:\n"
+				 "\n"
+				 "    git checkout --track origin/<name>\n"
+				 "\n"
+				 "If you'd like to always have checkouts of an ambiguous <name> prefer\n"
+				 "one remote, e.g. the 'origin' remote, consider setting\n"
+				 "checkout.defaultRemote=origin in your config."),
+			       argv[0],
+			       dwim_remotes_matched);
+		return ret;
+	} else {
+		return checkout_branch(opts, &new_branch_info);
+	}
+}
+
+int cmd_checkout(int argc, const char **argv, const char *prefix)
+{
+	struct checkout_opts opts;
+	struct option *options;
+	struct option checkout_options[] = {
+		OPT_STRING('b', NULL, &opts.new_branch, N_("branch"),
+			   N_("create and checkout a new branch")),
+		OPT_STRING('B', NULL, &opts.new_branch_force, N_("branch"),
+			   N_("create/reset and checkout a branch")),
+		OPT_BOOL('l', NULL, &opts.new_branch_log, N_("create reflog for new branch")),
+		OPT_BOOL(0, "guess", &opts.dwim_new_local_branch,
+			 N_("second guess 'git checkout <no-such-branch>' (default)")),
+		OPT_BOOL(0, "overlay", &opts.overlay_mode, N_("use overlay mode (default)")),
+		OPT_END()
+	};
+	int ret;
+
+	memset(&opts, 0, sizeof(opts));
+	opts.dwim_new_local_branch = 1;
+	opts.switch_branch_doing_nothing_is_ok = 1;
+	opts.only_merge_on_switching_branches = 0;
+	opts.accept_ref = 1;
+	opts.accept_pathspec = 1;
+	opts.implicit_detach = 1;
+	opts.can_switch_when_in_progress = 1;
+	opts.orphan_from_empty_tree = 0;
+	opts.empty_pathspec_ok = 1;
+	opts.overlay_mode = -1;
+	opts.checkout_index = -2;    /* default on */
+	opts.checkout_worktree = -2; /* default on */
+
+	if (argc == 3 && !strcmp(argv[1], "-b")) {
+		/*
+		 * User ran 'git checkout -b <branch>' and expects
+		 * the same behavior as 'git switch -c <branch>'.
+		 */
+		opts.switch_branch_doing_nothing_is_ok = 0;
+		opts.only_merge_on_switching_branches = 1;
+	}
+
+	options = parse_options_dup(checkout_options);
+	options = add_common_options(&opts, options);
+	options = add_common_switch_branch_options(&opts, options);
+	options = add_checkout_path_options(&opts, options);
+
+	ret = checkout_main(argc, argv, prefix, &opts,
+			    options, checkout_usage);
+	FREE_AND_NULL(options);
+	return ret;
+}
+
+int cmd_switch(int argc, const char **argv, const char *prefix)
+{
+	struct checkout_opts opts;
+	struct option *options = NULL;
+	struct option switch_options[] = {
+		OPT_STRING('c', "create", &opts.new_branch, N_("branch"),
+			   N_("create and switch to a new branch")),
+		OPT_STRING('C', "force-create", &opts.new_branch_force, N_("branch"),
+			   N_("create/reset and switch to a branch")),
+		OPT_BOOL(0, "guess", &opts.dwim_new_local_branch,
+			 N_("second guess 'git switch <no-such-branch>'")),
+		OPT_BOOL(0, "discard-changes", &opts.discard_changes,
+			 N_("throw away local modifications")),
+		OPT_END()
+	};
+	int ret;
+
+	memset(&opts, 0, sizeof(opts));
+	opts.dwim_new_local_branch = 1;
+	opts.accept_ref = 1;
+	opts.accept_pathspec = 0;
+	opts.switch_branch_doing_nothing_is_ok = 0;
+	opts.only_merge_on_switching_branches = 1;
+	opts.implicit_detach = 0;
+	opts.can_switch_when_in_progress = 0;
+	opts.orphan_from_empty_tree = 1;
+	opts.overlay_mode = -1;
+
+	options = parse_options_dup(switch_options);
+	options = add_common_options(&opts, options);
+	options = add_common_switch_branch_options(&opts, options);
+
+	ret = checkout_main(argc, argv, prefix, &opts,
+			    options, switch_branch_usage);
+	FREE_AND_NULL(options);
+	return ret;
+}
+
+int cmd_restore(int argc, const char **argv, const char *prefix)
+{
+	struct checkout_opts opts;
+	struct option *options;
+	struct option restore_options[] = {
+		OPT_STRING('s', "source", &opts.from_treeish, "<tree-ish>",
+			   N_("which tree-ish to checkout from")),
+		OPT_BOOL('S', "staged", &opts.checkout_index,
+			   N_("restore the index")),
+		OPT_BOOL('W', "worktree", &opts.checkout_worktree,
+			   N_("restore the working tree (default)")),
+		OPT_BOOL(0, "ignore-unmerged", &opts.ignore_unmerged,
+			 N_("ignore unmerged entries")),
+		OPT_BOOL(0, "overlay", &opts.overlay_mode, N_("use overlay mode")),
+		OPT_END()
+	};
+	int ret;
+
+	memset(&opts, 0, sizeof(opts));
+	opts.accept_ref = 0;
+	opts.accept_pathspec = 1;
+	opts.empty_pathspec_ok = 0;
+	opts.overlay_mode = 0;
+	opts.checkout_index = -1;    /* default off */
+	opts.checkout_worktree = -2; /* default on */
+	opts.ignore_unmerged_opt = "--ignore-unmerged";
+
+	options = parse_options_dup(restore_options);
+	options = add_common_options(&opts, options);
+	options = add_checkout_path_options(&opts, options);
+
+	ret = checkout_main(argc, argv, prefix, &opts,
+			    options, restore_usage);
+	FREE_AND_NULL(options);
+	return ret;
 }
diff -pruN 1.2.1+git2.18.0-1/git/builtin/checkout-index.c 1.2.3+git2.25.1-1/git/builtin/checkout-index.c
--- 1.2.1+git2.18.0-1/git/builtin/checkout-index.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/builtin/checkout-index.c	2020-02-17 04:47:35.000000000 +0000
@@ -4,6 +4,7 @@
  * Copyright (C) 2005 Linus Torvalds
  *
  */
+#define USE_THE_INDEX_COMPATIBILITY_MACROS
 #include "builtin.h"
 #include "config.h"
 #include "lockfile.h"
@@ -67,7 +68,8 @@ static int checkout_file(const char *nam
 			continue;
 		did_checkout = 1;
 		if (checkout_entry(ce, &state,
-		    to_tempfile ? topath[ce_stage(ce)] : NULL) < 0)
+				   to_tempfile ? topath[ce_stage(ce)] : NULL,
+				   NULL) < 0)
 			errs++;
 	}
 
@@ -111,7 +113,8 @@ static void checkout_all(const char *pre
 				write_tempfile_record(last_ce->name, prefix);
 		}
 		if (checkout_entry(ce, &state,
-		    to_tempfile ? topath[ce_stage(ce)] : NULL) < 0)
+				   to_tempfile ? topath[ce_stage(ce)] : NULL,
+				   NULL) < 0)
 			errs++;
 		last_ce = ce;
 	}
@@ -132,6 +135,8 @@ static const char * const builtin_checko
 static int option_parse_stage(const struct option *opt,
 			      const char *arg, int unset)
 {
+	BUG_ON_OPT_NEG(unset);
+
 	if (!strcmp(arg, "all")) {
 		to_tempfile = 1;
 		checkout_stage = CHECKOUT_ALL;
@@ -172,7 +177,7 @@ int cmd_checkout_index(int argc, const c
 			N_("write the content to temporary files")),
 		OPT_STRING(0, "prefix", &state.base_dir, N_("string"),
 			N_("when creating files, prepend <string>")),
-		{ OPTION_CALLBACK, 0, "stage", NULL, "1-3|all",
+		{ OPTION_CALLBACK, 0, "stage", NULL, "(1|2|3|all)",
 			N_("copy out the files from named stage"),
 			PARSE_OPT_NONEG, option_parse_stage },
 		OPT_END()
@@ -190,6 +195,7 @@ int cmd_checkout_index(int argc, const c
 
 	argc = parse_options(argc, argv, prefix, builtin_checkout_index_options,
 			builtin_checkout_index_usage, 0);
+	state.istate = &the_index;
 	state.force = force;
 	state.quiet = quiet;
 	state.not_new = not_new;
diff -pruN 1.2.1+git2.18.0-1/git/builtin/clean.c 1.2.3+git2.25.1-1/git/builtin/clean.c
--- 1.2.1+git2.18.0-1/git/builtin/clean.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/builtin/clean.c	2020-02-17 04:47:35.000000000 +0000
@@ -6,6 +6,7 @@
  * Based on git-clean.sh by Pavel Roskin
  */
 
+#define USE_THE_INDEX_COMPATIBILITY_MACROS
 #include "builtin.h"
 #include "cache.h"
 #include "config.h"
@@ -16,6 +17,7 @@
 #include "column.h"
 #include "color.h"
 #include "pathspec.h"
+#include "help.h"
 
 static int force = -1; /* unset */
 static int interactive;
@@ -32,6 +34,7 @@ static const char *msg_would_remove = N_
 static const char *msg_skip_git_dir = N_("Skipping repository %s\n");
 static const char *msg_would_skip_git_dir = N_("Would skip repository %s\n");
 static const char *msg_warn_remove_failed = N_("failed to remove %s");
+static const char *msg_warn_lstat_failed = N_("could not lstat %s\n");
 
 enum color_clean {
 	CLEAN_COLOR_RESET = 0,
@@ -42,6 +45,15 @@ enum color_clean {
 	CLEAN_COLOR_ERROR = 5
 };
 
+static const char *color_interactive_slots[] = {
+	[CLEAN_COLOR_ERROR]  = "error",
+	[CLEAN_COLOR_HEADER] = "header",
+	[CLEAN_COLOR_HELP]   = "help",
+	[CLEAN_COLOR_PLAIN]  = "plain",
+	[CLEAN_COLOR_PROMPT] = "prompt",
+	[CLEAN_COLOR_RESET]  = "reset",
+};
+
 static int clean_use_color = -1;
 static char clean_colors[][COLOR_MAXLEN] = {
 	[CLEAN_COLOR_ERROR] = GIT_COLOR_BOLD_RED,
@@ -82,22 +94,7 @@ struct menu_stuff {
 	void *stuff;
 };
 
-static int parse_clean_color_slot(const char *var)
-{
-	if (!strcasecmp(var, "reset"))
-		return CLEAN_COLOR_RESET;
-	if (!strcasecmp(var, "plain"))
-		return CLEAN_COLOR_PLAIN;
-	if (!strcasecmp(var, "prompt"))
-		return CLEAN_COLOR_PROMPT;
-	if (!strcasecmp(var, "header"))
-		return CLEAN_COLOR_HEADER;
-	if (!strcasecmp(var, "help"))
-		return CLEAN_COLOR_HELP;
-	if (!strcasecmp(var, "error"))
-		return CLEAN_COLOR_ERROR;
-	return -1;
-}
+define_list_config_array(color_interactive_slots);
 
 static int git_clean_config(const char *var, const char *value, void *cb)
 {
@@ -113,7 +110,7 @@ static int git_clean_config(const char *
 		return 0;
 	}
 	if (skip_prefix(var, "color.interactive.", &slot_name)) {
-		int slot = parse_clean_color_slot(slot_name);
+		int slot = LOOKUP_CONFIG(color_interactive_slots, slot_name);
 		if (slot < 0)
 			return 0;
 		if (!value)
@@ -145,6 +142,7 @@ static void clean_print_color(enum color
 static int exclude_cb(const struct option *opt, const char *arg, int unset)
 {
 	struct string_list *exclude_list = opt->value;
+	BUG_ON_OPT_NEG(unset);
 	string_list_append(exclude_list, arg);
 	return 0;
 }
@@ -160,7 +158,8 @@ static int remove_dirs(struct strbuf *pa
 
 	*dir_gone = 1;
 
-	if ((force_flag & REMOVE_DIR_KEEP_NESTED_GIT) && is_nonbare_repository_dir(path)) {
+	if ((force_flag & REMOVE_DIR_KEEP_NESTED_GIT) &&
+	    is_nonbare_repository_dir(path)) {
 		if (!quiet) {
 			quote_path_relative(path->buf, prefix, &quoted);
 			printf(dry_run ?  _(msg_would_skip_git_dir) : _(msg_skip_git_dir),
@@ -197,7 +196,7 @@ static int remove_dirs(struct strbuf *pa
 		strbuf_setlen(path, len);
 		strbuf_addstr(path, e->d_name);
 		if (lstat(path->buf, &st))
-			; /* fall thru */
+			warning_errno(_(msg_warn_lstat_failed), path->buf);
 		else if (S_ISDIR(st.st_mode)) {
 			if (remove_dirs(path, prefix, force_flag, dry_run, quiet, &gone))
 				ret = 1;
@@ -650,7 +649,7 @@ static int filter_by_patterns_cmd(void)
 	struct strbuf confirm = STRBUF_INIT;
 	struct strbuf **ignore_list;
 	struct string_list_item *item;
-	struct exclude_list *el;
+	struct pattern_list *pl;
 	int changed = -1, i;
 
 	for (;;) {
@@ -673,7 +672,7 @@ static int filter_by_patterns_cmd(void)
 			break;
 
 		memset(&dir, 0, sizeof(dir));
-		el = add_exclude_list(&dir, EXC_CMDL, "manual exclude");
+		pl = add_pattern_list(&dir, EXC_CMDL, "manual exclude");
 		ignore_list = strbuf_split_max(&confirm, ' ', 0);
 
 		for (i = 0; ignore_list[i]; i++) {
@@ -681,7 +680,7 @@ static int filter_by_patterns_cmd(void)
 			if (!ignore_list[i]->len)
 				continue;
 
-			add_exclude(ignore_list[i]->buf, "", 0, el, -(i+1));
+			add_pattern(ignore_list[i]->buf, "", 0, pl, -(i+1));
 		}
 
 		changed = 0;
@@ -903,7 +902,7 @@ int cmd_clean(int argc, const char **arg
 	struct pathspec pathspec;
 	struct strbuf buf = STRBUF_INIT;
 	struct string_list exclude_list = STRING_LIST_INIT_NODUP;
-	struct exclude_list *el;
+	struct pattern_list *pl;
 	struct string_list_item *item;
 	const char *qname;
 	struct option options[] = {
@@ -948,9 +947,19 @@ int cmd_clean(int argc, const char **arg
 
 	if (force > 1)
 		rm_flags = 0;
+	else
+		dir.flags |= DIR_SKIP_NESTED_GIT;
 
 	dir.flags |= DIR_SHOW_OTHER_DIRECTORIES;
 
+	if (argc) {
+		/*
+		 * Remaining args implies pathspecs specified, and we should
+		 * recurse within those.
+		 */
+		remove_directories = 1;
+	}
+
 	if (remove_directories)
 		dir.flags |= DIR_SHOW_IGNORED_TOO | DIR_KEEP_UNTRACKED_CONTENTS;
 
@@ -960,9 +969,9 @@ int cmd_clean(int argc, const char **arg
 	if (!ignored)
 		setup_standard_excludes(&dir);
 
-	el = add_exclude_list(&dir, EXC_CMDL, "--exclude option");
+	pl = add_pattern_list(&dir, EXC_CMDL, "--exclude option");
 	for (i = 0; i < exclude_list.nr; i++)
-		add_exclude(exclude_list.items[i].string, "", 0, el, -(i+1));
+		add_pattern(exclude_list.items[i].string, "", 0, pl, -(i+1));
 
 	parse_pathspec(&pathspec, 0,
 		       PATHSPEC_PREFER_CWD,
@@ -981,7 +990,7 @@ int cmd_clean(int argc, const char **arg
 			continue;
 
 		if (pathspec.nr)
-			matches = dir_path_match(ent, &pathspec, 0, NULL);
+			matches = dir_path_match(&the_index, ent, &pathspec, 0, NULL);
 
 		if (pathspec.nr && !matches)
 			continue;
@@ -1009,6 +1018,7 @@ int cmd_clean(int argc, const char **arg
 	for_each_string_list_item(item, &del_list) {
 		struct stat st;
 
+		strbuf_reset(&abs_path);
 		if (prefix)
 			strbuf_addstr(&abs_path, prefix);
 
@@ -1042,7 +1052,6 @@ int cmd_clean(int argc, const char **arg
 				printf(dry_run ? _(msg_would_remove) : _(msg_remove), qname);
 			}
 		}
-		strbuf_reset(&abs_path);
 	}
 
 	strbuf_release(&abs_path);
diff -pruN 1.2.1+git2.18.0-1/git/builtin/clone.c 1.2.3+git2.25.1-1/git/builtin/clone.c
--- 1.2.1+git2.18.0-1/git/builtin/clone.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/builtin/clone.c	2020-02-17 04:47:35.000000000 +0000
@@ -8,6 +8,7 @@
  * Clone a repository into a different directory that does not yet exist.
  */
 
+#define USE_THE_INDEX_COMPATIBILITY_MACROS
 #include "builtin.h"
 #include "config.h"
 #include "lockfile.h"
@@ -15,12 +16,15 @@
 #include "fetch-pack.h"
 #include "refs.h"
 #include "refspec.h"
+#include "object-store.h"
 #include "tree.h"
 #include "tree-walk.h"
 #include "unpack-trees.h"
 #include "transport.h"
 #include "strbuf.h"
 #include "dir.h"
+#include "dir-iterator.h"
+#include "iterator.h"
 #include "sigchain.h"
 #include "branch.h"
 #include "remote.h"
@@ -28,7 +32,6 @@
 #include "connected.h"
 #include "packfile.h"
 #include "list-objects-filter-options.h"
-#include "object-store.h"
 
 /*
  * Overall FIXMEs:
@@ -56,6 +59,7 @@ static const char *real_git_dir;
 static char *option_upload_pack = "git-upload-pack";
 static int option_verbosity;
 static int option_progress = -1;
+static int option_sparse_checkout;
 static enum transport_family family;
 static struct string_list option_config = STRING_LIST_INIT_NODUP;
 static struct string_list option_required_reference = STRING_LIST_INIT_NODUP;
@@ -64,6 +68,8 @@ static int option_dissociate;
 static int max_jobs = -1;
 static struct string_list option_recurse_submodules = STRING_LIST_INIT_NODUP;
 static struct list_objects_filter_options filter_options;
+static struct string_list server_options = STRING_LIST_INIT_NODUP;
+static int option_remote_submodules;
 
 static int recurse_submodules_cb(const struct option *opt,
 				 const char *arg, int unset)
@@ -96,10 +102,7 @@ static struct option builtin_clone_optio
 		    N_("don't use local hardlinks, always copy")),
 	OPT_BOOL('s', "shared", &option_shared,
 		    N_("setup as shared repository")),
-	{ OPTION_CALLBACK, 0, "recursive", &option_recurse_submodules,
-	  N_("pathspec"), N_("initialize submodules in the clone"),
-	  PARSE_OPT_OPTARG | PARSE_OPT_HIDDEN, recurse_submodules_cb,
-	  (intptr_t)"." },
+	OPT_ALIAS(0, "recursive", "recurse-submodules"),
 	{ OPTION_CALLBACK, 0, "recurse-submodules", &option_recurse_submodules,
 	  N_("pathspec"), N_("initialize submodules in the clone"),
 	  PARSE_OPT_OPTARG, recurse_submodules_cb, (intptr_t)"." },
@@ -135,11 +138,17 @@ static struct option builtin_clone_optio
 		   N_("separate git dir from working tree")),
 	OPT_STRING_LIST('c', "config", &option_config, N_("key=value"),
 			N_("set config inside the new repository")),
+	OPT_STRING_LIST(0, "server-option", &server_options,
+			N_("server-specific"), N_("option to transmit")),
 	OPT_SET_INT('4', "ipv4", &family, N_("use IPv4 addresses only"),
 			TRANSPORT_FAMILY_IPV4),
 	OPT_SET_INT('6', "ipv6", &family, N_("use IPv6 addresses only"),
 			TRANSPORT_FAMILY_IPV6),
 	OPT_PARSE_LIST_OBJECTS_FILTER(&filter_options),
+	OPT_BOOL(0, "remote-submodules", &option_remote_submodules,
+		    N_("any cloned submodules will use their remote-tracking branch")),
+	OPT_BOOL(0, "sparse", &option_sparse_checkout,
+		    N_("initialize sparse-checkout file to include only files at root")),
 	OPT_END()
 };
 
@@ -352,8 +361,7 @@ static void setup_reference(void)
 			     add_one_reference, &required);
 }
 
-static void copy_alternates(struct strbuf *src, struct strbuf *dst,
-			    const char *src_repo)
+static void copy_alternates(struct strbuf *src, const char *src_repo)
 {
 	/*
 	 * Read from the source objects/info/alternates file
@@ -390,58 +398,63 @@ static void copy_alternates(struct strbu
 	fclose(in);
 }
 
+static void mkdir_if_missing(const char *pathname, mode_t mode)
+{
+	struct stat st;
+
+	if (!mkdir(pathname, mode))
+		return;
+
+	if (errno != EEXIST)
+		die_errno(_("failed to create directory '%s'"), pathname);
+	else if (stat(pathname, &st))
+		die_errno(_("failed to stat '%s'"), pathname);
+	else if (!S_ISDIR(st.st_mode))
+		die(_("%s exists and is not a directory"), pathname);
+}
+
 static void copy_or_link_directory(struct strbuf *src, struct strbuf *dest,
-				   const char *src_repo, int src_baselen)
+				   const char *src_repo)
 {
-	struct dirent *de;
-	struct stat buf;
 	int src_len, dest_len;
-	DIR *dir;
+	struct dir_iterator *iter;
+	int iter_status;
+	unsigned int flags;
 
-	dir = opendir(src->buf);
-	if (!dir)
-		die_errno(_("failed to open '%s'"), src->buf);
-
-	if (mkdir(dest->buf, 0777)) {
-		if (errno != EEXIST)
-			die_errno(_("failed to create directory '%s'"), dest->buf);
-		else if (stat(dest->buf, &buf))
-			die_errno(_("failed to stat '%s'"), dest->buf);
-		else if (!S_ISDIR(buf.st_mode))
-			die(_("%s exists and is not a directory"), dest->buf);
-	}
+	mkdir_if_missing(dest->buf, 0777);
+
+	flags = DIR_ITERATOR_PEDANTIC | DIR_ITERATOR_FOLLOW_SYMLINKS;
+	iter = dir_iterator_begin(src->buf, flags);
+
+	if (!iter)
+		die_errno(_("failed to start iterator over '%s'"), src->buf);
 
 	strbuf_addch(src, '/');
 	src_len = src->len;
 	strbuf_addch(dest, '/');
 	dest_len = dest->len;
 
-	while ((de = readdir(dir)) != NULL) {
+	while ((iter_status = dir_iterator_advance(iter)) == ITER_OK) {
 		strbuf_setlen(src, src_len);
-		strbuf_addstr(src, de->d_name);
+		strbuf_addstr(src, iter->relative_path);
 		strbuf_setlen(dest, dest_len);
-		strbuf_addstr(dest, de->d_name);
-		if (stat(src->buf, &buf)) {
-			warning (_("failed to stat %s\n"), src->buf);
-			continue;
-		}
-		if (S_ISDIR(buf.st_mode)) {
-			if (de->d_name[0] != '.')
-				copy_or_link_directory(src, dest,
-						       src_repo, src_baselen);
+		strbuf_addstr(dest, iter->relative_path);
+
+		if (S_ISDIR(iter->st.st_mode)) {
+			mkdir_if_missing(dest->buf, 0777);
 			continue;
 		}
 
 		/* Files that cannot be copied bit-for-bit... */
-		if (!strcmp(src->buf + src_baselen, "/info/alternates")) {
-			copy_alternates(src, dest, src_repo);
+		if (!fspathcmp(iter->relative_path, "info/alternates")) {
+			copy_alternates(src, src_repo);
 			continue;
 		}
 
 		if (unlink(dest->buf) && errno != ENOENT)
 			die_errno(_("failed to unlink '%s'"), dest->buf);
 		if (!option_no_hardlinks) {
-			if (!link(src->buf, dest->buf))
+			if (!link(real_path(src->buf), dest->buf))
 				continue;
 			if (option_local > 0)
 				die_errno(_("failed to create link '%s'"), dest->buf);
@@ -450,7 +463,11 @@ static void copy_or_link_directory(struc
 		if (copy_file_with_time(dest->buf, src->buf, 0666))
 			die_errno(_("failed to copy file to '%s'"), dest->buf);
 	}
-	closedir(dir);
+
+	if (iter_status != ITER_DONE) {
+		strbuf_setlen(src, src_len);
+		die(_("failed to iterate over '%s'"), src->buf);
+	}
 }
 
 static void clone_local(const char *src_repo, const char *dest_repo)
@@ -468,7 +485,7 @@ static void clone_local(const char *src_
 		get_common_dir(&dest, dest_repo);
 		strbuf_addstr(&src, "/objects");
 		strbuf_addstr(&dest, "/objects");
-		copy_or_link_directory(&src, &dest, src_repo, src.len);
+		copy_or_link_directory(&src, &dest, src_repo);
 		strbuf_release(&src);
 		strbuf_release(&dest);
 	}
@@ -490,7 +507,7 @@ static enum {
 static const char junk_leave_repo_msg[] =
 N_("Clone succeeded, but checkout failed.\n"
    "You can inspect what was checked out with 'git status'\n"
-   "and retry the checkout with 'git checkout -f HEAD'\n");
+   "and retry with 'git restore --source=HEAD :/'\n");
 
 static void remove_junk(void)
 {
@@ -547,7 +564,7 @@ static struct ref *find_remote_branch(co
 }
 
 static struct ref *wanted_peer_refs(const struct ref *refs,
-		struct refspec_item *refspec)
+		struct refspec *refspec)
 {
 	struct ref *head = copy_ref(find_ref_by_name(refs, "HEAD"));
 	struct ref *local_refs = head;
@@ -568,13 +585,19 @@ static struct ref *wanted_peer_refs(cons
 			warning(_("Could not find remote branch %s to clone."),
 				option_branch);
 		else {
-			get_fetch_map(remote_head, refspec, &tail, 0);
+			int i;
+			for (i = 0; i < refspec->nr; i++)
+				get_fetch_map(remote_head, &refspec->items[i],
+					      &tail, 0);
 
 			/* if --branch=tag, pull the requested tag explicitly */
 			get_fetch_map(remote_head, tag_refspec, &tail, 0);
 		}
-	} else
-		get_fetch_map(refs, refspec, &tail, 0);
+	} else {
+		int i;
+		for (i = 0; i < refspec->nr; i++)
+			get_fetch_map(refs, &refspec->items[i], &tail, 0);
+	}
 
 	if (!option_mirror && !option_single_branch && !option_no_tags)
 		get_fetch_map(refs, tag_refspec, &tail, 0);
@@ -649,7 +672,8 @@ static void update_remote_refs(const str
 			       const char *branch_top,
 			       const char *msg,
 			       struct transport *transport,
-			       int check_connectivity)
+			       int check_connectivity,
+			       int check_refs_only)
 {
 	const struct ref *rm = mapped_refs;
 
@@ -658,6 +682,7 @@ static void update_remote_refs(const str
 
 		opt.transport = transport;
 		opt.progress = transport->progress;
+		opt.check_refs_only = !!check_refs_only;
 
 		if (check_connected(iterate_ref_map, &rm, &opt))
 			die(_("remote did not send all necessary objects"));
@@ -695,7 +720,8 @@ static void update_head(const struct ref
 			install_branch_config(0, head, option_origin, our->name);
 		}
 	} else if (our) {
-		struct commit *c = lookup_commit_reference(&our->old_oid);
+		struct commit *c = lookup_commit_reference(the_repository,
+							   &our->old_oid);
 		/* --branch specifies a non-branch (i.e. tags), detach HEAD */
 		update_ref(msg, "HEAD", &c->object.oid, NULL, REF_NO_DEREF,
 			   UPDATE_REFS_DIE_ON_ERR);
@@ -710,6 +736,27 @@ static void update_head(const struct ref
 	}
 }
 
+static int git_sparse_checkout_init(const char *repo)
+{
+	struct argv_array argv = ARGV_ARRAY_INIT;
+	int result = 0;
+	argv_array_pushl(&argv, "-C", repo, "sparse-checkout", "init", NULL);
+
+	/*
+	 * We must apply the setting in the current process
+	 * for the later checkout to use the sparse-checkout file.
+	 */
+	core_apply_sparse_checkout = 1;
+
+	if (run_command_v_opt(argv.argv, RUN_GIT_CMD)) {
+		error(_("failed to initialize sparse-checkout"));
+		result = 1;
+	}
+
+	argv_array_clear(&argv);
+	return result;
+}
+
 static int checkout(int submodule_progress)
 {
 	struct object_id oid;
@@ -746,6 +793,7 @@ static int checkout(int submodule_progre
 	memset(&opts, 0, sizeof opts);
 	opts.update = 1;
 	opts.merge = 1;
+	opts.clone = 1;
 	opts.fn = oneway_merge;
 	opts.verbose_update = (option_verbosity >= 0);
 	opts.src_index = &the_index;
@@ -760,12 +808,12 @@ static int checkout(int submodule_progre
 	if (write_locked_index(&the_index, &lock_file, COMMIT_LOCK))
 		die(_("unable to write new index file"));
 
-	err |= run_hook_le(NULL, "post-checkout", sha1_to_hex(null_sha1),
+	err |= run_hook_le(NULL, "post-checkout", oid_to_hex(&null_oid),
 			   oid_to_hex(&oid), "1", NULL);
 
 	if (!err && (option_recurse_submodules.nr > 0)) {
 		struct argv_array args = ARGV_ARRAY_INIT;
-		argv_array_pushl(&args, "submodule", "update", "--init", "--recursive", NULL);
+		argv_array_pushl(&args, "submodule", "update", "--require-init", "--recursive", NULL);
 
 		if (option_shallow_submodules == 1)
 			argv_array_push(&args, "--depth=1");
@@ -779,6 +827,11 @@ static int checkout(int submodule_progre
 		if (option_verbosity < 0)
 			argv_array_push(&args, "--quiet");
 
+		if (option_remote_submodules) {
+			argv_array_push(&args, "--remote");
+			argv_array_push(&args, "--no-fetch");
+		}
+
 		err = run_command_v_opt(args.argv, RUN_GIT_CMD);
 		argv_array_clear(&args);
 	}
@@ -870,7 +923,7 @@ static void dissociate_from_references(v
 	free(alternates);
 }
 
-static int dir_exists(const char *path)
+static int path_exists(const char *path)
 {
 	struct stat sb;
 	return !stat(path, &sb);
@@ -887,7 +940,8 @@ int cmd_clone(int argc, const char **arg
 	const struct ref *our_head_points_at;
 	struct ref *mapped_refs;
 	const struct ref *ref;
-	struct strbuf key = STRBUF_INIT, value = STRBUF_INIT;
+	struct strbuf key = STRBUF_INIT;
+	struct strbuf default_refspec = STRBUF_INIT;
 	struct strbuf branch_top = STRBUF_INIT, reflog_msg = STRBUF_INIT;
 	struct transport *transport = NULL;
 	const char *src_ref_prefix = "refs/heads/";
@@ -895,9 +949,7 @@ int cmd_clone(int argc, const char **arg
 	int err = 0, complete_refs_before_fetch = 1;
 	int submodule_progress;
 
-	struct refspec_item refspec;
-
-	fetch_if_missing = 0;
+	struct argv_array ref_prefixes = ARGV_ARRAY_INIT;
 
 	packet_trace_identity("clone");
 	argc = parse_options(argc, argv, prefix, builtin_clone_options,
@@ -951,7 +1003,7 @@ int cmd_clone(int argc, const char **arg
 		dir = guess_dir_name(repo_name, is_bundle, option_bare);
 	strip_trailing_slashes(dir);
 
-	dest_exists = dir_exists(dir);
+	dest_exists = path_exists(dir);
 	if (dest_exists && !is_empty_dir(dir))
 		die(_("destination path '%s' already exists and is not "
 			"an empty directory."), dir);
@@ -962,7 +1014,7 @@ int cmd_clone(int argc, const char **arg
 		work_tree = NULL;
 	else {
 		work_tree = getenv("GIT_WORK_TREE");
-		if (work_tree && dir_exists(work_tree))
+		if (work_tree && path_exists(work_tree))
 			die(_("working tree '%s' already exists."), work_tree);
 	}
 
@@ -990,7 +1042,7 @@ int cmd_clone(int argc, const char **arg
 	}
 
 	if (real_git_dir) {
-		if (dir_exists(real_git_dir))
+		if (path_exists(real_git_dir))
 			junk_git_dir_flags |= REMOVE_DIR_KEEP_TOPLEVEL;
 		junk_git_dir = real_git_dir;
 	} else {
@@ -1063,7 +1115,6 @@ int cmd_clone(int argc, const char **arg
 		strbuf_addf(&branch_top, "refs/remotes/%s/", option_origin);
 	}
 
-	strbuf_addf(&value, "+%s*:%s*", src_ref_prefix, branch_top.buf);
 	strbuf_addf(&key, "remote.%s.url", option_origin);
 	git_config_set(key.buf, repo);
 	strbuf_reset(&key);
@@ -1077,11 +1128,15 @@ int cmd_clone(int argc, const char **arg
 	if (option_required_reference.nr || option_optional_reference.nr)
 		setup_reference();
 
-	refspec_item_init(&refspec, value.buf, REFSPEC_FETCH);
-
-	strbuf_reset(&value);
+	if (option_sparse_checkout && git_sparse_checkout_init(repo))
+		return 1;
 
 	remote = remote_get(option_origin);
+
+	strbuf_addf(&default_refspec, "+%s*:%s*", src_ref_prefix,
+		    branch_top.buf);
+	refspec_append(&remote->fetch, default_refspec.buf);
+
 	transport = transport_get(remote, remote->url[0]);
 	transport_set_verbosity(transport, option_verbosity, option_progress);
 	transport->family = family;
@@ -1125,19 +1180,32 @@ int cmd_clone(int argc, const char **arg
 		transport_set_option(transport, TRANS_OPT_UPLOADPACK,
 				     option_upload_pack);
 
+	if (server_options.nr)
+		transport->server_options = &server_options;
+
 	if (filter_options.choice) {
+		const char *spec =
+			expand_list_objects_filter_spec(&filter_options);
 		transport_set_option(transport, TRANS_OPT_LIST_OBJECTS_FILTER,
-				     filter_options.filter_spec);
+				     spec);
 		transport_set_option(transport, TRANS_OPT_FROM_PROMISOR, "1");
 	}
 
 	if (transport->smart_options && !deepen && !filter_options.choice)
 		transport->smart_options->check_self_contained_and_connected = 1;
 
-	refs = transport_get_remote_refs(transport, NULL);
+
+	argv_array_push(&ref_prefixes, "HEAD");
+	refspec_ref_prefixes(&remote->fetch, &ref_prefixes);
+	if (option_branch)
+		expand_ref_prefix(&ref_prefixes, option_branch);
+	if (!option_no_tags)
+		argv_array_push(&ref_prefixes, "refs/tags/");
+
+	refs = transport_get_remote_refs(transport, &ref_prefixes);
 
 	if (refs) {
-		mapped_refs = wanted_peer_refs(refs, &refspec);
+		mapped_refs = wanted_peer_refs(refs, &remote->fetch);
 		/*
 		 * transport_get_remote_refs() may return refs with null sha-1
 		 * in mapped_refs (see struct transport->get_refs_list
@@ -1192,7 +1260,7 @@ int cmd_clone(int argc, const char **arg
 			remote_head_points_at, &branch_top);
 
 	if (filter_options.choice)
-		partial_clone_register("origin", &filter_options);
+		partial_clone_register(option_origin, &filter_options);
 
 	if (is_local)
 		clone_local(path, git_dir);
@@ -1201,7 +1269,7 @@ int cmd_clone(int argc, const char **arg
 
 	update_remote_refs(refs, mapped_refs, remote_head_points_at,
 			   branch_top.buf, reflog_msg.buf, transport,
-			   !is_local && !filter_options.choice);
+			   !is_local, filter_options.choice);
 
 	update_head(our_head_points_at, remote_head, reflog_msg.buf);
 
@@ -1217,20 +1285,19 @@ int cmd_clone(int argc, const char **arg
 	transport_disconnect(transport);
 
 	if (option_dissociate) {
-		close_all_packs(the_repository->objects);
+		close_object_store(the_repository->objects);
 		dissociate_from_references();
 	}
 
 	junk_mode = JUNK_LEAVE_REPO;
-	fetch_if_missing = 1;
 	err = checkout(submodule_progress);
 
 	strbuf_release(&reflog_msg);
 	strbuf_release(&branch_top);
 	strbuf_release(&key);
-	strbuf_release(&value);
+	strbuf_release(&default_refspec);
 	junk_mode = JUNK_LEAVE_ALL;
 
-	refspec_item_clear(&refspec);
+	argv_array_clear(&ref_prefixes);
 	return err;
 }
diff -pruN 1.2.1+git2.18.0-1/git/builtin/column.c 1.2.3+git2.25.1-1/git/builtin/column.c
--- 1.2.1+git2.18.0-1/git/builtin/column.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/builtin/column.c	2020-02-17 04:47:35.000000000 +0000
@@ -43,7 +43,7 @@ int cmd_column(int argc, const char **ar
 
 	memset(&copts, 0, sizeof(copts));
 	copts.padding = 1;
-	argc = parse_options(argc, argv, "", options, builtin_column_usage, 0);
+	argc = parse_options(argc, argv, prefix, options, builtin_column_usage, 0);
 	if (argc)
 		usage_with_options(builtin_column_usage, options);
 	if (real_command || command) {
diff -pruN 1.2.1+git2.18.0-1/git/builtin/commit.c 1.2.3+git2.25.1-1/git/builtin/commit.c
--- 1.2.1+git2.18.0-1/git/builtin/commit.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/builtin/commit.c	2020-02-17 04:47:35.000000000 +0000
@@ -5,6 +5,7 @@
  * Based on git-commit.sh by Junio C Hamano and Linus Torvalds
  */
 
+#define USE_THE_INDEX_COMPATIBILITY_MACROS
 #include "cache.h"
 #include "config.h"
 #include "lockfile.h"
@@ -32,6 +33,9 @@
 #include "column.h"
 #include "sequencer.h"
 #include "mailmap.h"
+#include "help.h"
+#include "commit-reach.h"
+#include "commit-graph.h"
 
 static const char * const builtin_commit_usage[] = {
 	N_("git commit [<options>] [--] <pathspec>..."),
@@ -56,15 +60,30 @@ N_("The previous cherry-pick is now empt
 "\n");
 
 static const char empty_cherry_pick_advice_single[] =
-N_("Otherwise, please use 'git reset'\n");
+N_("Otherwise, please use 'git cherry-pick --skip'\n");
 
 static const char empty_cherry_pick_advice_multi[] =
-N_("If you wish to skip this commit, use:\n"
+N_("and then use:\n"
 "\n"
-"    git reset\n"
+"    git cherry-pick --continue\n"
 "\n"
-"Then \"git cherry-pick --continue\" will resume cherry-picking\n"
-"the remaining commits.\n");
+"to resume cherry-picking the remaining commits.\n"
+"If you wish to skip this commit, use:\n"
+"\n"
+"    git cherry-pick --skip\n"
+"\n");
+
+static const char *color_status_slots[] = {
+	[WT_STATUS_HEADER]	  = "header",
+	[WT_STATUS_UPDATED]	  = "updated",
+	[WT_STATUS_CHANGED]	  = "changed",
+	[WT_STATUS_UNTRACKED]	  = "untracked",
+	[WT_STATUS_NOBRANCH]	  = "noBranch",
+	[WT_STATUS_UNMERGED]	  = "unmerged",
+	[WT_STATUS_LOCAL_BRANCH]  = "localBranch",
+	[WT_STATUS_REMOTE_BRANCH] = "remoteBranch",
+	[WT_STATUS_ONBRANCH]	  = "branch",
+};
 
 static const char *use_message_buffer;
 static struct lock_file index_lock; /* real index */
@@ -88,9 +107,9 @@ static int all, also, interactive, patch
 static int edit_flag = -1; /* unspecified */
 static int quiet, verbose, no_verify, allow_empty, dry_run, renew_authorship;
 static int config_commit_verbose = -1; /* unspecified */
-static int no_post_rewrite, allow_empty_message;
+static int no_post_rewrite, allow_empty_message, pathspec_file_nul;
 static char *untracked_files_arg, *force_date, *ignore_submodule_arg, *ignored_arg;
-static char *sign_commit;
+static char *sign_commit, *pathspec_from_file;
 
 /*
  * The default commit message cleanup mode will remove the lines
@@ -146,6 +165,9 @@ static int opt_parse_m(const struct opti
 static int opt_parse_rename_score(const struct option *opt, const char *arg, int unset)
 {
 	const char **value = opt->value;
+
+	BUG_ON_OPT_NEG(unset);
+
 	if (arg != NULL && *arg == '=')
 		arg = arg + 1;
 
@@ -155,9 +177,9 @@ static int opt_parse_rename_score(const
 
 static void determine_whence(struct wt_status *s)
 {
-	if (file_exists(git_path_merge_head()))
+	if (file_exists(git_path_merge_head(the_repository)))
 		whence = FROM_MERGE;
-	else if (file_exists(git_path_cherry_pick_head())) {
+	else if (file_exists(git_path_cherry_pick_head(the_repository))) {
 		whence = FROM_CHERRY_PICK;
 		if (file_exists(git_path_seq_dir()))
 			sequencer_in_use = 1;
@@ -170,7 +192,7 @@ static void determine_whence(struct wt_s
 
 static void status_init_config(struct wt_status *s, config_fn_t fn)
 {
-	wt_status_prepare(s);
+	wt_status_prepare(the_repository, s);
 	init_diff_ui_defaults();
 	git_config(fn, s);
 	determine_whence(s);
@@ -216,7 +238,7 @@ static int commit_index_files(void)
  * and return the paths that match the given pattern in list.
  */
 static int list_paths(struct string_list *list, const char *with_tree,
-		      const char *prefix, const struct pathspec *pattern)
+		      const struct pathspec *pattern)
 {
 	int i, ret;
 	char *m;
@@ -238,14 +260,14 @@ static int list_paths(struct string_list
 
 		if (ce->ce_flags & CE_UPDATE)
 			continue;
-		if (!ce_path_match(ce, pattern, m))
+		if (!ce_path_match(&the_index, ce, pattern, m))
 			continue;
 		item = string_list_insert(list, ce->name);
 		if (ce_skip_worktree(ce))
 			item->util = item; /* better a valid pointer than a fake one */
 	}
 
-	ret = report_path_error(m, pattern, prefix);
+	ret = report_path_error(m, pattern);
 	free(m);
 	return ret;
 }
@@ -321,6 +343,26 @@ static const char *prepare_index(int arg
 		       PATHSPEC_PREFER_FULL,
 		       prefix, argv);
 
+	if (pathspec_from_file) {
+		if (interactive)
+			die(_("--pathspec-from-file is incompatible with --interactive/--patch"));
+
+		if (all)
+			die(_("--pathspec-from-file with -a does not make sense"));
+
+		if (pathspec.nr)
+			die(_("--pathspec-from-file is incompatible with pathspec arguments"));
+
+		parse_pathspec_file(&pathspec, 0,
+				    PATHSPEC_PREFER_FULL,
+				    prefix, pathspec_from_file, pathspec_file_nul);
+	} else if (pathspec_file_nul) {
+		die(_("--pathspec-file-nul requires --pathspec-from-file"));
+	}
+
+	if (!pathspec.nr && (also || (only && !amend && !allow_empty)))
+		die(_("No paths with --include/--only does not make sense."));
+
 	if (read_cache_preload(&pathspec) < 0)
 		die(_("index file corrupt"));
 
@@ -333,7 +375,7 @@ static const char *prepare_index(int arg
 		if (write_locked_index(&the_index, &index_lock, 0))
 			die(_("unable to create temporary index"));
 
-		old_index_env = getenv(INDEX_ENVIRONMENT);
+		old_index_env = xstrdup_or_null(getenv(INDEX_ENVIRONMENT));
 		setenv(INDEX_ENVIRONMENT, get_lock_file_path(&index_lock), 1);
 
 		if (interactive_add(argc, argv, prefix, patch_interactive) != 0)
@@ -343,6 +385,7 @@ static const char *prepare_index(int arg
 			setenv(INDEX_ENVIRONMENT, old_index_env, 1);
 		else
 			unsetenv(INDEX_ENVIRONMENT);
+		FREE_AND_NULL(old_index_env);
 
 		discard_cache();
 		read_cache_from(get_lock_file_path(&index_lock));
@@ -434,7 +477,7 @@ static const char *prepare_index(int arg
 			die(_("cannot do a partial commit during a cherry-pick."));
 	}
 
-	if (list_paths(&partial, !current_head ? NULL : "HEAD", prefix, &pathspec))
+	if (list_paths(&partial, !current_head ? NULL : "HEAD", &pathspec))
 		exit(1);
 
 	discard_cache();
@@ -487,14 +530,15 @@ static int run_status(FILE *fp, const ch
 	s->nowarn = nowarn;
 	s->is_initial = get_oid(s->reference, &oid) ? 1 : 0;
 	if (!s->is_initial)
-		hashcpy(s->sha1_commit, oid.hash);
+		oidcpy(&s->oid_commit, &oid);
 	s->status_format = status_format;
 	s->ignore_submodule_arg = ignore_submodule_arg;
 
 	wt_status_collect(s);
 	wt_status_print(s);
+	wt_status_collect_free_buffers(s);
 
-	return s->commitable;
+	return s->committable;
 }
 
 static int is_a_merge(const struct commit *current_head)
@@ -513,7 +557,7 @@ static void export_one(const char *var,
 	struct strbuf buf = STRBUF_INIT;
 	if (hack)
 		strbuf_addch(&buf, hack);
-	strbuf_addf(&buf, "%.*s", (int)(e - s), s);
+	strbuf_add(&buf, s, e - s);
 	setenv(var, buf.buf, 1);
 	strbuf_release(&buf);
 }
@@ -588,7 +632,8 @@ static void determine_author_info(struct
 		set_ident_var(&date, strbuf_detach(&date_buf, NULL));
 	}
 
-	strbuf_addstr(author_ident, fmt_ident(name, email, date, IDENT_STRICT));
+	strbuf_addstr(author_ident, fmt_ident(name, email, WANT_AUTHOR_IDENT, date,
+				IDENT_STRICT));
 	assert_split_ident(&author, author_ident);
 	export_one("GIT_AUTHOR_NAME", author.name_begin, author.name_end, 0);
 	export_one("GIT_AUTHOR_EMAIL", author.mail_begin, author.mail_end, 0);
@@ -640,12 +685,13 @@ static int prepare_to_commit(const char
 {
 	struct stat statbuf;
 	struct strbuf committer_ident = STRBUF_INIT;
-	int commitable;
+	int committable;
 	struct strbuf sb = STRBUF_INIT;
 	const char *hook_arg1 = NULL;
 	const char *hook_arg2 = NULL;
 	int clean_message_contents = (cleanup_mode != COMMIT_MSG_CLEANUP_NONE);
 	int old_display_comment_prefix;
+	int merge_contains_scissors = 0;
 
 	/* This checks and barfs if author is badly specified */
 	determine_author_info(author_ident);
@@ -705,21 +751,31 @@ static int prepare_to_commit(const char
 		if (have_option_m)
 			strbuf_addbuf(&sb, &message);
 		hook_arg1 = "message";
-	} else if (!stat(git_path_merge_msg(), &statbuf)) {
+	} else if (!stat(git_path_merge_msg(the_repository), &statbuf)) {
+		size_t merge_msg_start;
+
 		/*
 		 * prepend SQUASH_MSG here if it exists and a
 		 * "merge --squash" was originally performed
 		 */
-		if (!stat(git_path_squash_msg(), &statbuf)) {
-			if (strbuf_read_file(&sb, git_path_squash_msg(), 0) < 0)
+		if (!stat(git_path_squash_msg(the_repository), &statbuf)) {
+			if (strbuf_read_file(&sb, git_path_squash_msg(the_repository), 0) < 0)
 				die_errno(_("could not read SQUASH_MSG"));
 			hook_arg1 = "squash";
 		} else
 			hook_arg1 = "merge";
-		if (strbuf_read_file(&sb, git_path_merge_msg(), 0) < 0)
+
+		merge_msg_start = sb.len;
+		if (strbuf_read_file(&sb, git_path_merge_msg(the_repository), 0) < 0)
 			die_errno(_("could not read MERGE_MSG"));
-	} else if (!stat(git_path_squash_msg(), &statbuf)) {
-		if (strbuf_read_file(&sb, git_path_squash_msg(), 0) < 0)
+
+		if (cleanup_mode == COMMIT_MSG_CLEANUP_SCISSORS &&
+		    wt_status_locate_end(sb.buf + merge_msg_start,
+					 sb.len - merge_msg_start) <
+				sb.len - merge_msg_start)
+			merge_contains_scissors = 1;
+	} else if (!stat(git_path_squash_msg(the_repository), &statbuf)) {
+		if (strbuf_read_file(&sb, git_path_squash_msg(the_repository), 0) < 0)
 			die_errno(_("could not read SQUASH_MSG"));
 		hook_arg1 = "squash";
 	} else if (template_file) {
@@ -785,7 +841,8 @@ static int prepare_to_commit(const char
 		struct ident_split ci, ai;
 
 		if (whence != FROM_COMMIT) {
-			if (cleanup_mode == COMMIT_MSG_CLEANUP_SCISSORS)
+			if (cleanup_mode == COMMIT_MSG_CLEANUP_SCISSORS &&
+				!merge_contains_scissors)
 				wt_status_add_cut_line(s->fp);
 			status_printf_ln(s, GIT_COLOR_NORMAL,
 			    whence == FROM_MERGE
@@ -800,8 +857,8 @@ static int prepare_to_commit(const char
 					"	%s\n"
 					"and try again.\n"),
 				whence == FROM_MERGE ?
-					git_path_merge_head() :
-					git_path_cherry_pick_head());
+					git_path_merge_head(the_repository) :
+					git_path_cherry_pick_head(the_repository));
 		}
 
 		fprintf(s->fp, "\n");
@@ -810,10 +867,10 @@ static int prepare_to_commit(const char
 				_("Please enter the commit message for your changes."
 				  " Lines starting\nwith '%c' will be ignored, and an empty"
 				  " message aborts the commit.\n"), comment_line_char);
-		else if (cleanup_mode == COMMIT_MSG_CLEANUP_SCISSORS &&
-			 whence == FROM_COMMIT)
-			wt_status_add_cut_line(s->fp);
-		else /* COMMIT_MSG_CLEANUP_SPACE, that is. */
+		else if (cleanup_mode == COMMIT_MSG_CLEANUP_SCISSORS) {
+			if (whence == FROM_COMMIT && !merge_contains_scissors)
+				wt_status_add_cut_line(s->fp);
+		} else /* COMMIT_MSG_CLEANUP_SPACE, that is. */
 			status_printf(s, GIT_COLOR_NORMAL,
 				_("Please enter the commit message for your changes."
 				  " Lines starting\n"
@@ -857,8 +914,9 @@ static int prepare_to_commit(const char
 
 		saved_color_setting = s->use_color;
 		s->use_color = 0;
-		commitable = run_status(s->fp, index_file, prefix, 1, s);
+		committable = run_status(s->fp, index_file, prefix, 1, s);
 		s->use_color = saved_color_setting;
+		string_list_clear(&s->change, 1);
 	} else {
 		struct object_id oid;
 		const char *parent = "HEAD";
@@ -875,7 +933,7 @@ static int prepare_to_commit(const char
 			for (i = 0; i < active_nr; i++)
 				if (ce_intent_to_add(active_cache[i]))
 					ita_nr++;
-			commitable = active_nr - ita_nr > 0;
+			committable = active_nr - ita_nr > 0;
 		} else {
 			/*
 			 * Unless the user did explicitly request a submodule
@@ -891,7 +949,8 @@ static int prepare_to_commit(const char
 			if (ignore_submodule_arg &&
 			    !strcmp(ignore_submodule_arg, "all"))
 				flags.ignore_submodules = 1;
-			commitable = index_differs_from(parent, &flags, 1);
+			committable = index_differs_from(the_repository,
+							 parent, &flags, 1);
 		}
 	}
 	strbuf_release(&committer_ident);
@@ -903,8 +962,9 @@ static int prepare_to_commit(const char
 	 * explicit --allow-empty. In the cherry-pick case, it may be
 	 * empty due to conflict resolution, which the user should okay.
 	 */
-	if (!commitable && whence != FROM_MERGE && !allow_empty &&
+	if (!committable && whence != FROM_MERGE && !allow_empty &&
 	    !(amend && is_a_merge(current_head))) {
+		s->hints = advice_status_hints;
 		s->display_comment_prefix = old_display_comment_prefix;
 		run_status(stdout, index_file, prefix, 0, s);
 		if (amend)
@@ -967,7 +1027,7 @@ static const char *find_author_by_nickna
 	const char *av[20];
 	int ac = 0;
 
-	init_revisions(&revs, NULL);
+	repo_init_revisions(the_repository, &revs, NULL);
 	strbuf_addf(&buf, "--author=%s", name);
 	av[++ac] = "--all";
 	av[++ac] = "-i";
@@ -1015,6 +1075,10 @@ static void handle_untracked_files_arg(s
 		s->show_untracked_files = SHOW_NORMAL_UNTRACKED_FILES;
 	else if (!strcmp(untracked_files_arg, "all"))
 		s->show_untracked_files = SHOW_ALL_UNTRACKED_FILES;
+	/*
+	 * Please update $__git_untracked_file_modes in
+	 * git-completion.bash when you add new options
+	 */
 	else
 		die(_("Invalid untracked files mode '%s'"), untracked_files_arg);
 }
@@ -1038,9 +1102,11 @@ static const char *read_commit_message(c
 static struct status_deferred_config {
 	enum wt_status_format status_format;
 	int show_branch;
+	enum ahead_behind_flags ahead_behind;
 } status_deferred_config = {
 	STATUS_FORMAT_UNSPECIFIED,
-	-1 /* unspecified */
+	-1, /* unspecified */
+	AHEAD_BEHIND_UNSPECIFIED,
 };
 
 static void finalize_deferred_config(struct wt_status *s)
@@ -1067,6 +1133,17 @@ static void finalize_deferred_config(str
 	if (s->show_branch < 0)
 		s->show_branch = 0;
 
+	/*
+	 * If the user did not give a "--[no]-ahead-behind" command
+	 * line argument *AND* we will print in a human-readable format
+	 * (short, long etc.) then we inherit from the status.aheadbehind
+	 * config setting.  In all other cases (and porcelain V[12] formats
+	 * in particular), we inherit _FULL for backwards compatibility.
+	 */
+	if (use_deferred_config &&
+	    s->ahead_behind_flags == AHEAD_BEHIND_UNSPECIFIED)
+		s->ahead_behind_flags = status_deferred_config.ahead_behind;
+
 	if (s->ahead_behind_flags == AHEAD_BEHIND_UNSPECIFIED)
 		s->ahead_behind_flags = AHEAD_BEHIND_FULL;
 }
@@ -1142,27 +1219,13 @@ static int parse_and_validate_options(in
 
 	if (also + only + all + interactive > 1)
 		die(_("Only one of --include/--only/--all/--interactive/--patch can be used."));
-	if (argc == 0 && (also || (only && !amend && !allow_empty)))
-		die(_("No paths with --include/--only does not make sense."));
-	if (!cleanup_arg || !strcmp(cleanup_arg, "default"))
-		cleanup_mode = use_editor ? COMMIT_MSG_CLEANUP_ALL :
-					    COMMIT_MSG_CLEANUP_SPACE;
-	else if (!strcmp(cleanup_arg, "verbatim"))
-		cleanup_mode = COMMIT_MSG_CLEANUP_NONE;
-	else if (!strcmp(cleanup_arg, "whitespace"))
-		cleanup_mode = COMMIT_MSG_CLEANUP_SPACE;
-	else if (!strcmp(cleanup_arg, "strip"))
-		cleanup_mode = COMMIT_MSG_CLEANUP_ALL;
-	else if (!strcmp(cleanup_arg, "scissors"))
-		cleanup_mode = use_editor ? COMMIT_MSG_CLEANUP_SCISSORS :
-					    COMMIT_MSG_CLEANUP_SPACE;
-	else
-		die(_("Invalid cleanup mode %s"), cleanup_arg);
+	cleanup_mode = get_cleanup_mode(cleanup_arg, use_editor);
 
 	handle_untracked_files_arg(s);
 
 	if (all && argc > 0)
-		die(_("Paths with -a does not make sense."));
+		die(_("paths '%s ...' with -a does not make sense"),
+		    argv[0]);
 
 	if (status_format != STATUS_FORMAT_NONE)
 		dry_run = 1;
@@ -1173,37 +1236,24 @@ static int parse_and_validate_options(in
 static int dry_run_commit(int argc, const char **argv, const char *prefix,
 			  const struct commit *current_head, struct wt_status *s)
 {
-	int commitable;
+	int committable;
 	const char *index_file;
 
 	index_file = prepare_index(argc, argv, prefix, current_head, 1);
-	commitable = run_status(stdout, index_file, prefix, 0, s);
+	committable = run_status(stdout, index_file, prefix, 0, s);
 	rollback_index_files();
 
-	return commitable ? 0 : 1;
+	return committable ? 0 : 1;
 }
 
+define_list_config_array_extra(color_status_slots, {"added"});
+
 static int parse_status_slot(const char *slot)
 {
-	if (!strcasecmp(slot, "header"))
-		return WT_STATUS_HEADER;
-	if (!strcasecmp(slot, "branch"))
-		return WT_STATUS_ONBRANCH;
-	if (!strcasecmp(slot, "updated") || !strcasecmp(slot, "added"))
+	if (!strcasecmp(slot, "added"))
 		return WT_STATUS_UPDATED;
-	if (!strcasecmp(slot, "changed"))
-		return WT_STATUS_CHANGED;
-	if (!strcasecmp(slot, "untracked"))
-		return WT_STATUS_UNTRACKED;
-	if (!strcasecmp(slot, "nobranch"))
-		return WT_STATUS_NOBRANCH;
-	if (!strcasecmp(slot, "unmerged"))
-		return WT_STATUS_UNMERGED;
-	if (!strcasecmp(slot, "localBranch"))
-		return WT_STATUS_LOCAL_BRANCH;
-	if (!strcasecmp(slot, "remoteBranch"))
-		return WT_STATUS_REMOTE_BRANCH;
-	return -1;
+
+	return LOOKUP_CONFIG(color_status_slots, slot);
 }
 
 static int git_status_config(const char *k, const char *v, void *cb)
@@ -1231,6 +1281,10 @@ static int git_status_config(const char
 		status_deferred_config.show_branch = git_config_bool(k, v);
 		return 0;
 	}
+	if (!strcmp(k, "status.aheadbehind")) {
+		status_deferred_config.ahead_behind = git_config_bool(k, v);
+		return 0;
+	}
 	if (!strcmp(k, "status.showstash")) {
 		s->show_stash = git_config_bool(k, v);
 		return 0;
@@ -1295,6 +1349,7 @@ int cmd_status(int argc, const char **ar
 	static int no_renames = -1;
 	static const char *rename_score_arg = (const char *)-1;
 	static struct wt_status s;
+	unsigned int progress_flag = 0;
 	int fd;
 	struct object_id oid;
 	static struct option builtin_status_options[] = {
@@ -1330,7 +1385,7 @@ int cmd_status(int argc, const char **ar
 		OPT_BOOL(0, "no-renames", &no_renames, N_("do not detect renames")),
 		{ OPTION_CALLBACK, 'M', "find-renames", &rename_score_arg,
 		  N_("n"), N_("detect renames, optionally set similarity index"),
-		  PARSE_OPT_OPTARG, opt_parse_rename_score },
+		  PARSE_OPT_OPTARG | PARSE_OPT_NONEG, opt_parse_rename_score },
 		OPT_END(),
 	};
 
@@ -1355,8 +1410,13 @@ int cmd_status(int argc, const char **ar
 		       PATHSPEC_PREFER_FULL,
 		       prefix, argv);
 
-	read_cache_preload(&s.pathspec);
-	refresh_index(&the_index, REFRESH_QUIET|REFRESH_UNMERGED, &s.pathspec, NULL, NULL);
+	if (status_format != STATUS_FORMAT_PORCELAIN &&
+	    status_format != STATUS_FORMAT_PORCELAIN_V2)
+		progress_flag = REFRESH_PROGRESS;
+	repo_read_index(the_repository);
+	refresh_index(&the_index,
+		      REFRESH_QUIET|REFRESH_UNMERGED|progress_flag,
+		      &s.pathspec, NULL, NULL);
 
 	if (use_optional_locks())
 		fd = hold_locked_index(&index_lock, 0);
@@ -1365,7 +1425,7 @@ int cmd_status(int argc, const char **ar
 
 	s.is_initial = get_oid(s.reference, &oid) ? 1 : 0;
 	if (!s.is_initial)
-		hashcpy(s.sha1_commit, oid.hash);
+		oidcpy(&s.oid_commit, &oid);
 
 	s.ignore_submodule_arg = ignore_submodule_arg;
 	s.status_format = status_format;
@@ -1382,12 +1442,14 @@ int cmd_status(int argc, const char **ar
 	wt_status_collect(&s);
 
 	if (0 <= fd)
-		update_index_if_able(&the_index, &index_lock);
+		repo_update_index_if_able(the_repository, &index_lock);
 
 	if (s.relative_paths)
 		s.prefix = prefix;
 
 	wt_status_print(&s);
+	wt_status_collect_free_buffers(&s);
+
 	return 0;
 }
 
@@ -1420,28 +1482,6 @@ static int git_commit_config(const char
 	return git_status_config(k, v, s);
 }
 
-int run_commit_hook(int editor_is_used, const char *index_file, const char *name, ...)
-{
-	struct argv_array hook_env = ARGV_ARRAY_INIT;
-	va_list args;
-	int ret;
-
-	argv_array_pushf(&hook_env, "GIT_INDEX_FILE=%s", index_file);
-
-	/*
-	 * Let the hook know that no editor will be launched.
-	 */
-	if (!editor_is_used)
-		argv_array_push(&hook_env, "GIT_EDITOR=:");
-
-	va_start(args, name);
-	ret = run_hook_ve(hook_env.argv,name, args);
-	va_end(args);
-	argv_array_clear(&hook_env);
-
-	return ret;
-}
-
 int cmd_commit(int argc, const char **argv, const char *prefix)
 {
 	const char *argv_gc_auto[] = {"gc", "--auto", NULL};
@@ -1463,7 +1503,7 @@ int cmd_commit(int argc, const char **ar
 		OPT_BOOL('s', "signoff", &signoff, N_("add Signed-off-by:")),
 		OPT_FILENAME('t', "template", &template_file, N_("use specified template file")),
 		OPT_BOOL('e', "edit", &edit_flag, N_("force edit of commit")),
-		OPT_STRING(0, "cleanup", &cleanup_arg, N_("default"), N_("how to strip spaces and #comments from message")),
+		OPT_CLEANUP(&cleanup_arg),
 		OPT_BOOL(0, "status", &include_status, N_("include status in commit message template")),
 		{ OPTION_STRING, 'S', "gpg-sign", &sign_commit, N_("key-id"),
 		  N_("GPG sign commit"), PARSE_OPT_OPTARG, NULL, (intptr_t) "" },
@@ -1492,6 +1532,8 @@ int cmd_commit(int argc, const char **ar
 		OPT_BOOL(0, "amend", &amend, N_("amend previous commit")),
 		OPT_BOOL(0, "no-post-rewrite", &no_post_rewrite, N_("bypass post-rewrite hook")),
 		{ OPTION_STRING, 'u', "untracked-files", &untracked_files_arg, N_("mode"), N_("show untracked files, optional modes: all, normal, no. (Default: all)"), PARSE_OPT_OPTARG, NULL, (intptr_t)"all" },
+		OPT_PATHSPEC_FROM_FILE(&pathspec_from_file),
+		OPT_PATHSPEC_FILE_NUL(&pathspec_file_nul),
 		/* end commit contents options */
 
 		OPT_HIDDEN_BOOL(0, "allow-empty", &allow_empty,
@@ -1564,7 +1606,7 @@ int cmd_commit(int argc, const char **ar
 		if (!reflog_msg)
 			reflog_msg = "commit (merge)";
 		pptr = commit_list_append(current_head, pptr);
-		fp = xfopen(git_path_merge_head(), "r");
+		fp = xfopen(git_path_merge_head(the_repository), "r");
 		while (strbuf_getline_lf(&m, fp) != EOF) {
 			struct commit *parent;
 
@@ -1575,8 +1617,8 @@ int cmd_commit(int argc, const char **ar
 		}
 		fclose(fp);
 		strbuf_release(&m);
-		if (!stat(git_path_merge_mode(), &statbuf)) {
-			if (strbuf_read_file(&sb, git_path_merge_mode(), 0) < 0)
+		if (!stat(git_path_merge_mode(the_repository), &statbuf)) {
+			if (strbuf_read_file(&sb, git_path_merge_mode(the_repository), 0) < 0)
 				die_errno(_("could not read MERGE_MODE"));
 			if (!strcmp(sb.buf, "no-ff"))
 				allow_fast_forward = 0;
@@ -1599,11 +1641,7 @@ int cmd_commit(int argc, const char **ar
 		die(_("could not read commit message: %s"), strerror(saved_errno));
 	}
 
-	if (verbose || /* Truncate the message just before the diff, if any. */
-	    cleanup_mode == COMMIT_MSG_CLEANUP_SCISSORS)
-		strbuf_setlen(&sb, wt_status_locate_end(sb.buf, sb.len));
-	if (cleanup_mode != COMMIT_MSG_CLEANUP_NONE)
-		strbuf_stripspace(&sb, cleanup_mode == COMMIT_MSG_CLEANUP_ALL);
+	cleanup_message(&sb, cleanup_mode, verbose);
 
 	if (message_is_empty(&sb, cleanup_mode) && !allow_empty_message) {
 		rollback_index_files();
@@ -1639,23 +1677,26 @@ int cmd_commit(int argc, const char **ar
 		die("%s", err.buf);
 	}
 
-	unlink(git_path_cherry_pick_head());
-	unlink(git_path_revert_head());
-	unlink(git_path_merge_head());
-	unlink(git_path_merge_msg());
-	unlink(git_path_merge_mode());
-	unlink(git_path_squash_msg());
+	sequencer_post_commit_cleanup(the_repository, 0);
+	unlink(git_path_merge_head(the_repository));
+	unlink(git_path_merge_msg(the_repository));
+	unlink(git_path_merge_mode(the_repository));
+	unlink(git_path_squash_msg(the_repository));
 
 	if (commit_index_files())
-		die (_("Repository has been updated, but unable to write\n"
-		     "new_index file. Check that disk is not full and quota is\n"
-		     "not exceeded, and then \"git reset HEAD\" to recover."));
+		die(_("repository has been updated, but unable to write\n"
+		      "new_index file. Check that disk is not full and quota is\n"
+		      "not exceeded, and then \"git restore --staged :/\" to recover."));
+
+	if (git_env_bool(GIT_TEST_COMMIT_GRAPH, 0) &&
+	    write_commit_graph_reachable(get_object_directory(), 0, NULL))
+		return 1;
 
-	rerere(0);
+	repo_rerere(the_repository, 0);
 	run_command_v_opt(argv_gc_auto, RUN_GIT_CMD);
 	run_commit_hook(use_editor, get_index_file(), "post-commit", NULL);
 	if (amend && !no_post_rewrite) {
-		commit_post_rewrite(current_head, &oid);
+		commit_post_rewrite(the_repository, current_head, &oid);
 	}
 	if (!quiet) {
 		unsigned int flags = 0;
@@ -1664,7 +1705,8 @@ int cmd_commit(int argc, const char **ar
 			flags |= SUMMARY_INITIAL_COMMIT;
 		if (author_date_is_interesting())
 			flags |= SUMMARY_SHOW_AUTHOR_DATE;
-		print_commit_summary(prefix, &oid, flags);
+		print_commit_summary(the_repository, prefix,
+				     &oid, flags);
 	}
 
 	UNLEAK(err);
diff -pruN 1.2.1+git2.18.0-1/git/builtin/commit-graph.c 1.2.3+git2.25.1-1/git/builtin/commit-graph.c
--- 1.2.1+git2.18.0-1/git/builtin/commit-graph.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/builtin/commit-graph.c	2020-02-17 04:47:35.000000000 +0000
@@ -3,141 +3,181 @@
 #include "dir.h"
 #include "lockfile.h"
 #include "parse-options.h"
+#include "repository.h"
 #include "commit-graph.h"
+#include "object-store.h"
 
 static char const * const builtin_commit_graph_usage[] = {
-	N_("git commit-graph [--object-dir <objdir>]"),
-	N_("git commit-graph read [--object-dir <objdir>]"),
-	N_("git commit-graph write [--object-dir <objdir>] [--append] [--stdin-packs|--stdin-commits]"),
+	N_("git commit-graph verify [--object-dir <objdir>] [--shallow] [--[no-]progress]"),
+	N_("git commit-graph write [--object-dir <objdir>] [--append|--split] [--reachable|--stdin-packs|--stdin-commits] [--[no-]progress] <split options>"),
 	NULL
 };
 
-static const char * const builtin_commit_graph_read_usage[] = {
-	N_("git commit-graph read [--object-dir <objdir>]"),
+static const char * const builtin_commit_graph_verify_usage[] = {
+	N_("git commit-graph verify [--object-dir <objdir>] [--shallow] [--[no-]progress]"),
 	NULL
 };
 
 static const char * const builtin_commit_graph_write_usage[] = {
-	N_("git commit-graph write [--object-dir <objdir>] [--append] [--stdin-packs|--stdin-commits]"),
+	N_("git commit-graph write [--object-dir <objdir>] [--append|--split] [--reachable|--stdin-packs|--stdin-commits] [--[no-]progress] <split options>"),
 	NULL
 };
 
 static struct opts_commit_graph {
 	const char *obj_dir;
+	int reachable;
 	int stdin_packs;
 	int stdin_commits;
 	int append;
+	int split;
+	int shallow;
+	int progress;
 } opts;
 
-static int graph_read(int argc, const char **argv)
+static int graph_verify(int argc, const char **argv)
 {
 	struct commit_graph *graph = NULL;
 	char *graph_name;
+	int open_ok;
+	int fd;
+	struct stat st;
+	int flags = 0;
 
-	static struct option builtin_commit_graph_read_options[] = {
+	static struct option builtin_commit_graph_verify_options[] = {
 		OPT_STRING(0, "object-dir", &opts.obj_dir,
-			N_("dir"),
-			N_("The object directory to store the graph")),
+			   N_("dir"),
+			   N_("The object directory to store the graph")),
+		OPT_BOOL(0, "shallow", &opts.shallow,
+			 N_("if the commit-graph is split, only verify the tip file")),
+		OPT_BOOL(0, "progress", &opts.progress, N_("force progress reporting")),
 		OPT_END(),
 	};
 
+	trace2_cmd_mode("verify");
+
+	opts.progress = isatty(2);
 	argc = parse_options(argc, argv, NULL,
-			     builtin_commit_graph_read_options,
-			     builtin_commit_graph_read_usage, 0);
+			     builtin_commit_graph_verify_options,
+			     builtin_commit_graph_verify_usage, 0);
 
 	if (!opts.obj_dir)
 		opts.obj_dir = get_object_directory();
+	if (opts.shallow)
+		flags |= COMMIT_GRAPH_VERIFY_SHALLOW;
+	if (opts.progress)
+		flags |= COMMIT_GRAPH_WRITE_PROGRESS;
 
 	graph_name = get_commit_graph_filename(opts.obj_dir);
-	graph = load_commit_graph_one(graph_name);
+	open_ok = open_commit_graph(graph_name, &fd, &st);
+	if (!open_ok && errno != ENOENT)
+		die_errno(_("Could not open commit-graph '%s'"), graph_name);
 
-	if (!graph)
-		die("graph file %s does not exist", graph_name);
 	FREE_AND_NULL(graph_name);
 
-	printf("header: %08x %d %d %d %d\n",
-		ntohl(*(uint32_t*)graph->data),
-		*(unsigned char*)(graph->data + 4),
-		*(unsigned char*)(graph->data + 5),
-		*(unsigned char*)(graph->data + 6),
-		*(unsigned char*)(graph->data + 7));
-	printf("num_commits: %u\n", graph->num_commits);
-	printf("chunks:");
-
-	if (graph->chunk_oid_fanout)
-		printf(" oid_fanout");
-	if (graph->chunk_oid_lookup)
-		printf(" oid_lookup");
-	if (graph->chunk_commit_data)
-		printf(" commit_metadata");
-	if (graph->chunk_large_edges)
-		printf(" large_edges");
-	printf("\n");
+	if (open_ok)
+		graph = load_commit_graph_one_fd_st(fd, &st);
+	 else
+		graph = read_commit_graph_one(the_repository, opts.obj_dir);
 
-	return 0;
+	/* Return failure if open_ok predicted success */
+	if (!graph)
+		return !!open_ok;
+
+	UNLEAK(graph);
+	return verify_commit_graph(the_repository, graph, flags);
 }
 
+extern int read_replace_refs;
+static struct split_commit_graph_opts split_opts;
+
 static int graph_write(int argc, const char **argv)
 {
-	const char **pack_indexes = NULL;
-	int packs_nr = 0;
-	const char **commit_hex = NULL;
-	int commits_nr = 0;
-	const char **lines = NULL;
-	int lines_nr = 0;
-	int lines_alloc = 0;
+	struct string_list *pack_indexes = NULL;
+	struct string_list *commit_hex = NULL;
+	struct string_list lines;
+	int result = 0;
+	enum commit_graph_write_flags flags = 0;
 
 	static struct option builtin_commit_graph_write_options[] = {
 		OPT_STRING(0, "object-dir", &opts.obj_dir,
 			N_("dir"),
 			N_("The object directory to store the graph")),
+		OPT_BOOL(0, "reachable", &opts.reachable,
+			N_("start walk at all refs")),
 		OPT_BOOL(0, "stdin-packs", &opts.stdin_packs,
 			N_("scan pack-indexes listed by stdin for commits")),
 		OPT_BOOL(0, "stdin-commits", &opts.stdin_commits,
 			N_("start walk at commits listed by stdin")),
 		OPT_BOOL(0, "append", &opts.append,
 			N_("include all commits already in the commit-graph file")),
+		OPT_BOOL(0, "progress", &opts.progress, N_("force progress reporting")),
+		OPT_BOOL(0, "split", &opts.split,
+			N_("allow writing an incremental commit-graph file")),
+		OPT_INTEGER(0, "max-commits", &split_opts.max_commits,
+			N_("maximum number of commits in a non-base split commit-graph")),
+		OPT_INTEGER(0, "size-multiple", &split_opts.size_multiple,
+			N_("maximum ratio between two levels of a split commit-graph")),
+		OPT_EXPIRY_DATE(0, "expire-time", &split_opts.expire_time,
+			N_("maximum number of commits in a non-base split commit-graph")),
 		OPT_END(),
 	};
 
+	opts.progress = isatty(2);
+	split_opts.size_multiple = 2;
+	split_opts.max_commits = 0;
+	split_opts.expire_time = 0;
+
+	trace2_cmd_mode("write");
+
 	argc = parse_options(argc, argv, NULL,
 			     builtin_commit_graph_write_options,
 			     builtin_commit_graph_write_usage, 0);
 
-	if (opts.stdin_packs && opts.stdin_commits)
-		die(_("cannot use both --stdin-commits and --stdin-packs"));
+	if (opts.reachable + opts.stdin_packs + opts.stdin_commits > 1)
+		die(_("use at most one of --reachable, --stdin-commits, or --stdin-packs"));
 	if (!opts.obj_dir)
 		opts.obj_dir = get_object_directory();
+	if (opts.append)
+		flags |= COMMIT_GRAPH_WRITE_APPEND;
+	if (opts.split)
+		flags |= COMMIT_GRAPH_WRITE_SPLIT;
+	if (opts.progress)
+		flags |= COMMIT_GRAPH_WRITE_PROGRESS;
+
+	read_replace_refs = 0;
+
+	if (opts.reachable) {
+		if (write_commit_graph_reachable(opts.obj_dir, flags, &split_opts))
+			return 1;
+		return 0;
+	}
 
+	string_list_init(&lines, 0);
 	if (opts.stdin_packs || opts.stdin_commits) {
 		struct strbuf buf = STRBUF_INIT;
-		lines_nr = 0;
-		lines_alloc = 128;
-		ALLOC_ARRAY(lines, lines_alloc);
-
-		while (strbuf_getline(&buf, stdin) != EOF) {
-			ALLOC_GROW(lines, lines_nr + 1, lines_alloc);
-			lines[lines_nr++] = strbuf_detach(&buf, NULL);
-		}
 
-		if (opts.stdin_packs) {
-			pack_indexes = lines;
-			packs_nr = lines_nr;
-		}
+		while (strbuf_getline(&buf, stdin) != EOF)
+			string_list_append(&lines, strbuf_detach(&buf, NULL));
+
+		if (opts.stdin_packs)
+			pack_indexes = &lines;
 		if (opts.stdin_commits) {
-			commit_hex = lines;
-			commits_nr = lines_nr;
+			commit_hex = &lines;
+			flags |= COMMIT_GRAPH_WRITE_CHECK_OIDS;
 		}
+
+		UNLEAK(buf);
 	}
 
-	write_commit_graph(opts.obj_dir,
-			   pack_indexes,
-			   packs_nr,
-			   commit_hex,
-			   commits_nr,
-			   opts.append);
+	if (write_commit_graph(opts.obj_dir,
+			       pack_indexes,
+			       commit_hex,
+			       flags,
+			       &split_opts))
+		result = 1;
 
-	return 0;
+	UNLEAK(lines);
+	return result;
 }
 
 int cmd_commit_graph(int argc, const char **argv, const char *prefix)
@@ -159,9 +199,11 @@ int cmd_commit_graph(int argc, const cha
 			     builtin_commit_graph_usage,
 			     PARSE_OPT_STOP_AT_NON_OPTION);
 
+	save_commit_buffer = 0;
+
 	if (argc > 0) {
-		if (!strcmp(argv[0], "read"))
-			return graph_read(argc, argv);
+		if (!strcmp(argv[0], "verify"))
+			return graph_verify(argc, argv);
 		if (!strcmp(argv[0], "write"))
 			return graph_write(argc, argv);
 	}
diff -pruN 1.2.1+git2.18.0-1/git/builtin/commit-tree.c 1.2.3+git2.25.1-1/git/builtin/commit-tree.c
--- 1.2.1+git2.18.0-1/git/builtin/commit-tree.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/builtin/commit-tree.c	2020-02-17 04:47:35.000000000 +0000
@@ -5,13 +5,20 @@
  */
 #include "cache.h"
 #include "config.h"
+#include "object-store.h"
+#include "repository.h"
 #include "commit.h"
 #include "tree.h"
 #include "builtin.h"
 #include "utf8.h"
 #include "gpg-interface.h"
+#include "parse-options.h"
 
-static const char commit_tree_usage[] = "git commit-tree [(-p <sha1>)...] [-S[<keyid>]] [-m <message>] [-F <file>] <sha1>";
+static const char * const commit_tree_usage[] = {
+	N_("git commit-tree [(-p <parent>)...] [-S[<keyid>]] [(-m <message>)...] "
+		"[(-F <file>)...] <tree>"),
+	NULL
+};
 
 static const char *sign_commit;
 
@@ -21,7 +28,7 @@ static void new_parent(struct commit *pa
 	struct commit_list *parents;
 	for (parents = *parents_p; parents; parents = parents->next) {
 		if (parents->item == parent) {
-			error("duplicate parent %s ignored", oid_to_hex(oid));
+			error(_("duplicate parent %s ignored"), oid_to_hex(oid));
 			return;
 		}
 		parents_p = &parents->next;
@@ -37,84 +44,100 @@ static int commit_tree_config(const char
 	return git_default_config(var, value, cb);
 }
 
+static int parse_parent_arg_callback(const struct option *opt,
+		const char *arg, int unset)
+{
+	struct object_id oid;
+	struct commit_list **parents = opt->value;
+
+	BUG_ON_OPT_NEG_NOARG(unset, arg);
+
+	if (get_oid_commit(arg, &oid))
+		die(_("not a valid object name %s"), arg);
+
+	assert_oid_type(&oid, OBJ_COMMIT);
+	new_parent(lookup_commit(the_repository, &oid), parents);
+	return 0;
+}
+
+static int parse_message_arg_callback(const struct option *opt,
+		const char *arg, int unset)
+{
+	struct strbuf *buf = opt->value;
+
+	BUG_ON_OPT_NEG_NOARG(unset, arg);
+
+	if (buf->len)
+		strbuf_addch(buf, '\n');
+	strbuf_addstr(buf, arg);
+	strbuf_complete_line(buf);
+
+	return 0;
+}
+
+static int parse_file_arg_callback(const struct option *opt,
+		const char *arg, int unset)
+{
+	int fd;
+	struct strbuf *buf = opt->value;
+
+	BUG_ON_OPT_NEG_NOARG(unset, arg);
+
+	if (buf->len)
+		strbuf_addch(buf, '\n');
+	if (!strcmp(arg, "-"))
+		fd = 0;
+	else {
+		fd = open(arg, O_RDONLY);
+		if (fd < 0)
+			die_errno(_("git commit-tree: failed to open '%s'"), arg);
+	}
+	if (strbuf_read(buf, fd, 0) < 0)
+		die_errno(_("git commit-tree: failed to read '%s'"), arg);
+	if (fd && close(fd))
+		die_errno(_("git commit-tree: failed to close '%s'"), arg);
+
+	return 0;
+}
+
 int cmd_commit_tree(int argc, const char **argv, const char *prefix)
 {
-	int i, got_tree = 0;
+	static struct strbuf buffer = STRBUF_INIT;
 	struct commit_list *parents = NULL;
 	struct object_id tree_oid;
 	struct object_id commit_oid;
-	struct strbuf buffer = STRBUF_INIT;
+
+	struct option options[] = {
+		{ OPTION_CALLBACK, 'p', NULL, &parents, N_("parent"),
+			N_("id of a parent commit object"), PARSE_OPT_NONEG,
+			parse_parent_arg_callback },
+		{ OPTION_CALLBACK, 'm', NULL, &buffer, N_("message"),
+			N_("commit message"), PARSE_OPT_NONEG,
+			parse_message_arg_callback },
+		{ OPTION_CALLBACK, 'F', NULL, &buffer, N_("file"),
+			N_("read commit log message from file"), PARSE_OPT_NONEG,
+			parse_file_arg_callback },
+		{ OPTION_STRING, 'S', "gpg-sign", &sign_commit, N_("key-id"),
+			N_("GPG sign commit"), PARSE_OPT_OPTARG, NULL, (intptr_t) "" },
+		OPT_END()
+	};
 
 	git_config(commit_tree_config, NULL);
 
 	if (argc < 2 || !strcmp(argv[1], "-h"))
-		usage(commit_tree_usage);
-
-	for (i = 1; i < argc; i++) {
-		const char *arg = argv[i];
-		if (!strcmp(arg, "-p")) {
-			struct object_id oid;
-			if (argc <= ++i)
-				usage(commit_tree_usage);
-			if (get_oid_commit(argv[i], &oid))
-				die("Not a valid object name %s", argv[i]);
-			assert_oid_type(&oid, OBJ_COMMIT);
-			new_parent(lookup_commit(&oid), &parents);
-			continue;
-		}
+		usage_with_options(commit_tree_usage, options);
 
-		if (skip_prefix(arg, "-S", &sign_commit))
-			continue;
+	argc = parse_options(argc, argv, prefix, options, commit_tree_usage, 0);
 
-		if (!strcmp(arg, "--no-gpg-sign")) {
-			sign_commit = NULL;
-			continue;
-		}
-
-		if (!strcmp(arg, "-m")) {
-			if (argc <= ++i)
-				usage(commit_tree_usage);
-			if (buffer.len)
-				strbuf_addch(&buffer, '\n');
-			strbuf_addstr(&buffer, argv[i]);
-			strbuf_complete_line(&buffer);
-			continue;
-		}
-
-		if (!strcmp(arg, "-F")) {
-			int fd;
+	if (argc != 1)
+		die(_("must give exactly one tree"));
 
-			if (argc <= ++i)
-				usage(commit_tree_usage);
-			if (buffer.len)
-				strbuf_addch(&buffer, '\n');
-			if (!strcmp(argv[i], "-"))
-				fd = 0;
-			else {
-				fd = open(argv[i], O_RDONLY);
-				if (fd < 0)
-					die_errno("git commit-tree: failed to open '%s'",
-						  argv[i]);
-			}
-			if (strbuf_read(&buffer, fd, 0) < 0)
-				die_errno("git commit-tree: failed to read '%s'",
-					  argv[i]);
-			if (fd && close(fd))
-				die_errno("git commit-tree: failed to close '%s'",
-					  argv[i]);
-			continue;
-		}
-
-		if (get_oid_tree(arg, &tree_oid))
-			die("Not a valid object name %s", arg);
-		if (got_tree)
-			die("Cannot give more than one trees");
-		got_tree = 1;
-	}
+	if (get_oid_tree(argv[0], &tree_oid))
+		die(_("not a valid object name %s"), argv[0]);
 
 	if (!buffer.len) {
 		if (strbuf_read(&buffer, 0, 0) < 0)
-			die_errno("git commit-tree: failed to read");
+			die_errno(_("git commit-tree: failed to read"));
 	}
 
 	if (commit_tree(buffer.buf, buffer.len, &tree_oid, parents, &commit_oid,
diff -pruN 1.2.1+git2.18.0-1/git/builtin/config.c 1.2.3+git2.25.1-1/git/builtin/config.c
--- 1.2.1+git2.18.0-1/git/builtin/config.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/builtin/config.c	2020-02-17 04:47:35.000000000 +0000
@@ -5,6 +5,7 @@
 #include "parse-options.h"
 #include "urlmatch.h"
 #include "quote.h"
+#include "worktree.h"
 
 static const char *const builtin_config_usage[] = {
 	N_("git config [<options>]"),
@@ -24,6 +25,7 @@ static char key_delim = ' ';
 static char term = '\n';
 
 static int use_global_config, use_system_config, use_local_config;
+static int use_worktree_config;
 static struct git_config_source given_config_source;
 static int actions, type;
 static char *default_value;
@@ -67,7 +69,7 @@ static int show_origin;
 	{ OPTION_CALLBACK, (s), (l), (v), NULL, (h), PARSE_OPT_NOARG | \
 	PARSE_OPT_NONEG, option_parse_type, (i) }
 
-static struct option builtin_config_options[];
+static NORETURN void usage_builtin_config(void);
 
 static int option_parse_type(const struct option *opt, const char *arg,
 			     int unset)
@@ -110,9 +112,8 @@ static int option_parse_type(const struc
 		 * --int' and '--type=bool
 		 * --type=int'.
 		 */
-		error("only one type at a time.");
-		usage_with_options(builtin_config_usage,
-			builtin_config_options);
+		error(_("only one type at a time"));
+		usage_builtin_config();
 	}
 	*to_type = new_type;
 
@@ -124,6 +125,7 @@ static struct option builtin_config_opti
 	OPT_BOOL(0, "global", &use_global_config, N_("use global config file")),
 	OPT_BOOL(0, "system", &use_system_config, N_("use system config file")),
 	OPT_BOOL(0, "local", &use_local_config, N_("use repository config file")),
+	OPT_BOOL(0, "worktree", &use_worktree_config, N_("use per-worktree config file")),
 	OPT_STRING('f', "file", &given_config_source.file, N_("file"), N_("use given config file")),
 	OPT_STRING(0, "blob", &given_config_source.blob, N_("blob-id"), N_("read config from given blob object")),
 	OPT_GROUP(N_("Action")),
@@ -157,11 +159,21 @@ static struct option builtin_config_opti
 	OPT_END(),
 };
 
-static void check_argc(int argc, int min, int max) {
+static NORETURN void usage_builtin_config(void)
+{
+	usage_with_options(builtin_config_usage, builtin_config_options);
+}
+
+static void check_argc(int argc, int min, int max)
+{
 	if (argc >= min && argc <= max)
 		return;
-	error("wrong number of arguments");
-	usage_with_options(builtin_config_usage, builtin_config_options);
+	if (min == max)
+		error(_("wrong number of arguments, should be %d"), min);
+	else
+		error(_("wrong number of arguments, should be from %d to %d"),
+		      min, max);
+	usage_builtin_config();
 }
 
 static void show_config_origin(struct strbuf *buf)
@@ -293,7 +305,7 @@ static int get_value(const char *key_, c
 
 		key_regexp = (regex_t*)xmalloc(sizeof(regex_t));
 		if (regcomp(key_regexp, key, REG_EXTENDED)) {
-			error("invalid key pattern: %s", key_);
+			error(_("invalid key pattern: %s"), key_);
 			FREE_AND_NULL(key_regexp);
 			ret = CONFIG_INVALID_PATTERN;
 			goto free_strings;
@@ -313,7 +325,7 @@ static int get_value(const char *key_, c
 
 		regexp = (regex_t*)xmalloc(sizeof(regex_t));
 		if (regcomp(regexp, regex_, REG_EXTENDED)) {
-			error("invalid pattern: %s", regex_);
+			error(_("invalid pattern: %s"), regex_);
 			FREE_AND_NULL(regexp);
 			ret = CONFIG_INVALID_PATTERN;
 			goto free_strings;
@@ -386,7 +398,7 @@ static char *normalize_value(const char
 	if (type == TYPE_COLOR) {
 		char v[COLOR_MAXLEN];
 		if (git_config_color(v, key, value))
-			die("cannot parse color '%s'", value);
+			die(_("cannot parse color '%s'"), value);
 
 		/*
 		 * The contents of `v` now contain an ANSI escape
@@ -481,13 +493,13 @@ static int get_colorbool(const char *var
 static void check_write(void)
 {
 	if (!given_config_source.file && !startup_info->have_repository)
-		die("not in a git directory");
+		die(_("not in a git directory"));
 
 	if (given_config_source.use_stdin)
-		die("writing to stdin is not supported");
+		die(_("writing to stdin is not supported"));
 
 	if (given_config_source.blob)
-		die("writing config blobs is not supported");
+		die(_("writing config blobs is not supported"));
 }
 
 struct urlmatch_current_candidate_value {
@@ -587,16 +599,17 @@ int cmd_config(int argc, const char **ar
 	int nongit = !startup_info->have_repository;
 	char *value;
 
-	given_config_source.file = getenv(CONFIG_ENVIRONMENT);
+	given_config_source.file = xstrdup_or_null(getenv(CONFIG_ENVIRONMENT));
 
 	argc = parse_options(argc, argv, prefix, builtin_config_options,
 			     builtin_config_usage,
 			     PARSE_OPT_STOP_AT_NON_OPTION);
 
 	if (use_global_config + use_system_config + use_local_config +
+	    use_worktree_config +
 	    !!given_config_source.file + !!given_config_source.blob > 1) {
-		error("only one config file at a time.");
-		usage_with_options(builtin_config_usage, builtin_config_options);
+		error(_("only one config file at a time"));
+		usage_builtin_config();
 	}
 
 	if (use_local_config && nongit)
@@ -622,7 +635,7 @@ int cmd_config(int argc, const char **ar
 			 * location; error out even if XDG_CONFIG_HOME
 			 * is set and points at a sane location.
 			 */
-			die("$HOME not set");
+			die(_("$HOME not set"));
 
 		if (access_or_warn(user_config, R_OK, 0) &&
 		    xdg_config && !access_or_warn(xdg_config, R_OK, 0)) {
@@ -637,7 +650,20 @@ int cmd_config(int argc, const char **ar
 		given_config_source.file = git_etc_gitconfig();
 	else if (use_local_config)
 		given_config_source.file = git_pathdup("config");
-	else if (given_config_source.file) {
+	else if (use_worktree_config) {
+		struct worktree **worktrees = get_worktrees(0);
+		if (repository_format_worktree_config)
+			given_config_source.file = git_pathdup("config.worktree");
+		else if (worktrees[0] && worktrees[1])
+			die(_("--worktree cannot be used with multiple "
+			      "working trees unless the config\n"
+			      "extension worktreeConfig is enabled. "
+			      "Please read \"CONFIGURATION FILE\"\n"
+			      "section in \"git help worktree\" for details"));
+		else
+			given_config_source.file = git_pathdup("config");
+		free_worktrees(worktrees);
+	} else if (given_config_source.file) {
 		if (!is_absolute_path(given_config_source.file) && prefix)
 			given_config_source.file =
 				prefix_filename(prefix, given_config_source.file);
@@ -659,13 +685,13 @@ int cmd_config(int argc, const char **ar
 	}
 
 	if ((actions & (ACTION_GET_COLOR|ACTION_GET_COLORBOOL)) && type) {
-		error("--get-color and variable type are incoherent");
-		usage_with_options(builtin_config_usage, builtin_config_options);
+		error(_("--get-color and variable type are incoherent"));
+		usage_builtin_config();
 	}
 
 	if (HAS_MULTI_BITS(actions)) {
-		error("only one action at a time.");
-		usage_with_options(builtin_config_usage, builtin_config_options);
+		error(_("only one action at a time"));
+		usage_builtin_config();
 	}
 	if (actions == 0)
 		switch (argc) {
@@ -673,25 +699,24 @@ int cmd_config(int argc, const char **ar
 		case 2: actions = ACTION_SET; break;
 		case 3: actions = ACTION_SET_ALL; break;
 		default:
-			usage_with_options(builtin_config_usage, builtin_config_options);
+			usage_builtin_config();
 		}
 	if (omit_values &&
 	    !(actions == ACTION_LIST || actions == ACTION_GET_REGEXP)) {
-		error("--name-only is only applicable to --list or --get-regexp");
-		usage_with_options(builtin_config_usage, builtin_config_options);
+		error(_("--name-only is only applicable to --list or --get-regexp"));
+		usage_builtin_config();
 	}
 
 	if (show_origin && !(actions &
 		(ACTION_GET|ACTION_GET_ALL|ACTION_GET_REGEXP|ACTION_LIST))) {
-		error("--show-origin is only applicable to --get, --get-all, "
-			  "--get-regexp, and --list.");
-		usage_with_options(builtin_config_usage, builtin_config_options);
+		error(_("--show-origin is only applicable to --get, --get-all, "
+			"--get-regexp, and --list"));
+		usage_builtin_config();
 	}
 
 	if (default_value && !(actions & ACTION_GET)) {
-		error("--default is only applicable to --get");
-		usage_with_options(builtin_config_usage,
-			builtin_config_options);
+		error(_("--default is only applicable to --get"));
+		usage_builtin_config();
 	}
 
 	if (actions & PAGING_ACTIONS)
@@ -703,10 +728,10 @@ int cmd_config(int argc, const char **ar
 					&given_config_source,
 					&config_options) < 0) {
 			if (given_config_source.file)
-				die_errno("unable to read config file '%s'",
+				die_errno(_("unable to read config file '%s'"),
 					  given_config_source.file);
 			else
-				die("error processing config file(s)");
+				die(_("error processing config file(s)"));
 		}
 	}
 	else if (actions == ACTION_EDIT) {
@@ -714,11 +739,11 @@ int cmd_config(int argc, const char **ar
 
 		check_argc(argc, 0, 0);
 		if (!given_config_source.file && nongit)
-			die("not in a git directory");
+			die(_("not in a git directory"));
 		if (given_config_source.use_stdin)
-			die("editing stdin is not supported");
+			die(_("editing stdin is not supported"));
 		if (given_config_source.blob)
-			die("editing blobs is not supported");
+			die(_("editing blobs is not supported"));
 		git_config(git_default_config, NULL);
 		config_file = given_config_source.file ?
 				xstrdup(given_config_source.file) :
@@ -819,7 +844,7 @@ int cmd_config(int argc, const char **ar
 		if (ret < 0)
 			return ret;
 		if (ret == 0)
-			die("No such section!");
+			die(_("no such section: %s"), argv[0]);
 	}
 	else if (actions == ACTION_REMOVE_SECTION) {
 		int ret;
@@ -830,7 +855,7 @@ int cmd_config(int argc, const char **ar
 		if (ret < 0)
 			return ret;
 		if (ret == 0)
-			die("No such section!");
+			die(_("no such section: %s"), argv[0]);
 	}
 	else if (actions == ACTION_GET_COLOR) {
 		check_argc(argc, 1, 2);
diff -pruN 1.2.1+git2.18.0-1/git/builtin/count-objects.c 1.2.3+git2.25.1-1/git/builtin/count-objects.c
--- 1.2.1+git2.18.0-1/git/builtin/count-objects.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/builtin/count-objects.c	2020-02-17 04:47:35.000000000 +0000
@@ -78,10 +78,10 @@ static int count_cruft(const char *basen
 	return 0;
 }
 
-static int print_alternate(struct alternate_object_database *alt, void *data)
+static int print_alternate(struct object_directory *odb, void *data)
 {
 	printf("alternate: ");
-	quote_c_style(alt->path, NULL, stdout, 0);
+	quote_c_style(odb->path, NULL, stdout, 0);
 	putchar('\n');
 	return 0;
 }
@@ -123,7 +123,7 @@ int cmd_count_objects(int argc, const ch
 		struct strbuf pack_buf = STRBUF_INIT;
 		struct strbuf garbage_buf = STRBUF_INIT;
 
-		for (p = get_packed_git(the_repository); p; p = p->next) {
+		for (p = get_all_packs(the_repository); p; p = p->next) {
 			if (!p->pack_local)
 				continue;
 			if (open_pack_index(p))
diff -pruN 1.2.1+git2.18.0-1/git/builtin/describe.c 1.2.3+git2.25.1-1/git/builtin/describe.c
--- 1.2.1+git2.18.0-1/git/builtin/describe.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/builtin/describe.c	2020-02-17 04:47:35.000000000 +0000
@@ -1,3 +1,4 @@
+#define USE_THE_INDEX_COMPATIBILITY_MACROS
 #include "cache.h"
 #include "config.h"
 #include "lockfile.h"
@@ -13,11 +14,14 @@
 #include "hashmap.h"
 #include "argv-array.h"
 #include "run-command.h"
-#include "revision.h"
+#include "object-store.h"
 #include "list-objects.h"
+#include "commit-slab.h"
 
 #define MAX_TAGS	(FLAG_BITS - 1)
 
+define_commit_slab(commit_names, struct commit_name *);
+
 static const char * const describe_usage[] = {
 	N_("git describe [<options>] [<commit-ish>...]"),
 	N_("git describe [<options>] --dirty"),
@@ -37,6 +41,7 @@ static struct string_list patterns = STR
 static struct string_list exclude_patterns = STRING_LIST_INIT_NODUP;
 static int always;
 static const char *suffix, *dirty, *broken;
+static struct commit_names commit_names;
 
 /* diff-index command arguments to check if working tree is dirty. */
 static const char *diff_index_args[] = {
@@ -57,20 +62,23 @@ static const char *prio_names[] = {
 	N_("head"), N_("lightweight"), N_("annotated"),
 };
 
-static int commit_name_cmp(const void *unused_cmp_data,
-			   const void *entry,
-			   const void *entry_or_key,
+static int commit_name_neq(const void *unused_cmp_data,
+			   const struct hashmap_entry *eptr,
+			   const struct hashmap_entry *entry_or_key,
 			   const void *peeled)
 {
-	const struct commit_name *cn1 = entry;
-	const struct commit_name *cn2 = entry_or_key;
+	const struct commit_name *cn1, *cn2;
+
+	cn1 = container_of(eptr, const struct commit_name, entry);
+	cn2 = container_of(entry_or_key, const struct commit_name, entry);
 
-	return oidcmp(&cn1->peeled, peeled ? peeled : &cn2->peeled);
+	return !oideq(&cn1->peeled, peeled ? peeled : &cn2->peeled);
 }
 
 static inline struct commit_name *find_commit_name(const struct object_id *peeled)
 {
-	return hashmap_get_from_hash(&names, sha1hash(peeled->hash), peeled->hash);
+	return hashmap_get_entry_from_hash(&names, oidhash(peeled), peeled,
+						struct commit_name, entry);
 }
 
 static int replace_name(struct commit_name *e,
@@ -88,13 +96,13 @@ static int replace_name(struct commit_na
 		struct tag *t;
 
 		if (!e->tag) {
-			t = lookup_tag(&e->oid);
+			t = lookup_tag(the_repository, &e->oid);
 			if (!t || parse_tag(t))
 				return 1;
 			e->tag = t;
 		}
 
-		t = lookup_tag(oid);
+		t = lookup_tag(the_repository, oid);
 		if (!t || parse_tag(t))
 			return 0;
 		*tag = t;
@@ -117,8 +125,8 @@ static void add_to_known_names(const cha
 		if (!e) {
 			e = xmalloc(sizeof(struct commit_name));
 			oidcpy(&e->peeled, peeled);
-			hashmap_entry_init(e, sha1hash(peeled->hash));
-			hashmap_add(&names, e);
+			hashmap_entry_init(&e->entry, oidhash(peeled));
+			hashmap_add(&names, &e->entry);
 			e->path = NULL;
 		}
 		e->tag = tag;
@@ -185,7 +193,7 @@ static int get_name(const char *path, co
 
 	/* Is it annotated? */
 	if (!peel_ref(path, &peeled)) {
-		is_annotated = !!oidcmp(oid, &peeled);
+		is_annotated = !oideq(oid, &peeled);
 	} else {
 		oidcpy(&peeled, oid);
 		is_annotated = 0;
@@ -262,7 +270,7 @@ static unsigned long finish_depth_comput
 static void append_name(struct commit_name *n, struct strbuf *dst)
 {
 	if (n->prio == 2 && !n->tag) {
-		n->tag = lookup_tag(&n->oid);
+		n->tag = lookup_tag(the_repository, &n->oid);
 		if (!n->tag || parse_tag(n->tag))
 			die(_("annotated tag %s not available"), n->path);
 	}
@@ -298,7 +306,7 @@ static void describe_commit(struct objec
 	unsigned long seen_commits = 0;
 	unsigned int unannotated_cnt = 0;
 
-	cmit = lookup_commit_reference(oid);
+	cmit = lookup_commit_reference(the_repository, oid);
 
 	n = find_commit_name(&cmit->object.oid);
 	if (n && (tags || all || n->prio == 2)) {
@@ -307,7 +315,7 @@ static void describe_commit(struct objec
 		 */
 		append_name(n, dst);
 		if (longformat)
-			append_suffix(0, n->tag ? &n->tag->tagged->oid : oid, dst);
+			append_suffix(0, n->tag ? get_tagged_oid(n->tag) : oid, dst);
 		if (suffix)
 			strbuf_addstr(dst, suffix);
 		return;
@@ -321,11 +329,15 @@ static void describe_commit(struct objec
 	if (!have_util) {
 		struct hashmap_iter iter;
 		struct commit *c;
-		struct commit_name *n = hashmap_iter_first(&names, &iter);
-		for (; n; n = hashmap_iter_next(&iter)) {
-			c = lookup_commit_reference_gently(&n->peeled, 1);
+		struct commit_name *n;
+
+		init_commit_names(&commit_names);
+		hashmap_for_each_entry(&names, &iter, n,
+					entry /* member name */) {
+			c = lookup_commit_reference_gently(the_repository,
+							   &n->peeled, 1);
 			if (c)
-				c->util = n;
+				*commit_names_at(&commit_names, c) = n;
 		}
 		have_util = 1;
 	}
@@ -336,8 +348,11 @@ static void describe_commit(struct objec
 	while (list) {
 		struct commit *c = pop_commit(&list);
 		struct commit_list *parents = c->parents;
+		struct commit_name **slot;
+
 		seen_commits++;
-		n = c->util;
+		slot = commit_names_peek(&commit_names, c);
+		n = slot ? *slot : NULL;
 		if (n) {
 			if (!tags && !all && n->prio < 2) {
 				unannotated_cnt++;
@@ -457,7 +472,7 @@ static void process_object(struct object
 {
 	struct process_commit_data *pcd = data;
 
-	if (!oidcmp(&pcd->looking_for, &obj->oid) && !pcd->dst->len) {
+	if (oideq(&pcd->looking_for, &obj->oid) && !pcd->dst->len) {
 		reset_revision_walk();
 		describe_commit(&pcd->current_commit, pcd->dst);
 		strbuf_addf(pcd->dst, ":%s", path);
@@ -476,7 +491,7 @@ static void describe_blob(struct object_
 		"--objects", "--in-commit-order", "--reverse", "HEAD",
 		NULL);
 
-	init_revisions(&revs, NULL);
+	repo_init_revisions(the_repository, &revs, NULL);
 	if (setup_revisions(args.argc, args.argv, &revs, NULL) > 1)
 		BUG("setup_revisions could not handle all args?");
 
@@ -498,7 +513,7 @@ static void describe(const char *arg, in
 
 	if (get_oid(arg, &oid))
 		die(_("Not a valid object name %s"), arg);
-	cmit = lookup_commit_reference_gently(&oid, 1);
+	cmit = lookup_commit_reference_gently(the_repository, &oid, 1);
 
 	if (cmit)
 		describe_commit(&oid, &sb);
@@ -584,7 +599,7 @@ int cmd_describe(int argc, const char **
 		return cmd_name_rev(args.argc, args.argv, prefix);
 	}
 
-	hashmap_init(&names, commit_name_cmp, NULL, 0);
+	hashmap_init(&names, commit_name_neq, NULL, 0);
 	for_each_rawref(get_name, NULL);
 	if (!hashmap_get_size(&names) && !always)
 		die(_("No names found, cannot describe anything."));
@@ -617,14 +632,15 @@ int cmd_describe(int argc, const char **
 			struct argv_array args = ARGV_ARRAY_INIT;
 			int fd, result;
 
-			read_cache_preload(NULL);
+			setup_work_tree();
+			read_cache();
 			refresh_index(&the_index, REFRESH_QUIET|REFRESH_UNMERGED,
 				      NULL, NULL, NULL);
 			fd = hold_locked_index(&index_lock, 0);
 			if (0 <= fd)
-				update_index_if_able(&the_index, &index_lock);
+				repo_update_index_if_able(the_repository, &index_lock);
 
-			init_revisions(&revs, prefix);
+			repo_init_revisions(the_repository, &revs, prefix);
 			argv_array_pushv(&args, diff_index_args);
 			if (setup_revisions(args.argc, args.argv, &revs, NULL) != 1)
 				BUG("malformed internal diff-index command line");
diff -pruN 1.2.1+git2.18.0-1/git/builtin/diff.c 1.2.3+git2.25.1-1/git/builtin/diff.c
--- 1.2.1+git2.18.0-1/git/builtin/diff.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/builtin/diff.c	2020-02-17 04:47:35.000000000 +0000
@@ -3,6 +3,7 @@
  *
  * Copyright (c) 2006 Junio C Hamano
  */
+#define USE_THE_INDEX_COMPATIBILITY_MACROS
 #include "cache.h"
 #include "config.h"
 #include "lockfile.h"
@@ -41,7 +42,7 @@ static void stuff_change(struct diff_opt
 	struct diff_filespec *one, *two;
 
 	if (!is_null_oid(old_oid) && !is_null_oid(new_oid) &&
-	    !oidcmp(old_oid, new_oid) && (old_mode == new_mode))
+	    oideq(old_oid, new_oid) && (old_mode == new_mode))
 		return;
 
 	if (opt->flags.reverse_diff) {
@@ -102,7 +103,7 @@ static int builtin_diff_blobs(struct rev
 			      int argc, const char **argv,
 			      struct object_array_entry **blob)
 {
-	unsigned mode = canon_mode(S_IFREG | 0644);
+	const unsigned mode = canon_mode(S_IFREG | 0644);
 
 	if (argc > 1)
 		usage(builtin_diff_usage);
@@ -212,7 +213,7 @@ static void refresh_index_quietly(void)
 	discard_cache();
 	read_cache();
 	refresh_cache(REFRESH_QUIET|REFRESH_UNMERGED);
-	update_index_if_able(&the_index, &lock_file);
+	repo_update_index_if_able(the_repository, &lock_file);
 }
 
 static int builtin_diff_files(struct rev_info *revs, int argc, const char **argv)
@@ -318,39 +319,32 @@ int cmd_diff(int argc, const char **argv
 	git_config(git_diff_ui_config, NULL);
 	precompose_argv(argc, argv);
 
-	init_revisions(&rev, prefix);
+	repo_init_revisions(the_repository, &rev, prefix);
 
-	if (no_index && argc != i + 2) {
-		if (no_index == DIFF_NO_INDEX_IMPLICIT) {
-			/*
-			 * There was no --no-index and there were not two
-			 * paths. It is possible that the user intended
-			 * to do an inside-repository operation.
-			 */
-			fprintf(stderr, "Not a git repository\n");
-			fprintf(stderr,
-				"To compare two paths outside a working tree:\n");
-		}
-		/* Give the usage message for non-repository usage and exit. */
-		usagef("git diff %s <path> <path>",
-		       no_index == DIFF_NO_INDEX_EXPLICIT ?
-		       "--no-index" : "[--no-index]");
+	/* Set up defaults that will apply to both no-index and regular diffs. */
+	rev.diffopt.stat_width = -1;
+	rev.diffopt.stat_graph_width = -1;
+	rev.diffopt.flags.allow_external = 1;
+	rev.diffopt.flags.allow_textconv = 1;
 
-	}
+	/* If this is a no-index diff, just run it and exit there. */
 	if (no_index)
-		/* If this is a no-index diff, just run it and exit there. */
-		diff_no_index(&rev, argc, argv);
+		exit(diff_no_index(&rev, no_index == DIFF_NO_INDEX_IMPLICIT,
+				   argc, argv));
 
-	/* Otherwise, we are doing the usual "git" diff */
-	rev.diffopt.skip_stat_unmatch = !!diff_auto_refresh_index;
 
-	/* Scale to real terminal size and respect statGraphWidth config */
-	rev.diffopt.stat_width = -1;
-	rev.diffopt.stat_graph_width = -1;
+	/*
+	 * Otherwise, we are doing the usual "git" diff; set up any
+	 * further defaults that apply to regular diffs.
+	 */
+	rev.diffopt.skip_stat_unmatch = !!diff_auto_refresh_index;
 
-	/* Default to let external and textconv be used */
-	rev.diffopt.flags.allow_external = 1;
-	rev.diffopt.flags.allow_textconv = 1;
+	/*
+	 * Default to intent-to-add entries invisible in the
+	 * index. This makes them show up as new files in diff-files
+	 * and not at all in diff-cached.
+	 */
+	rev.diffopt.ita_invisible_in_index = 1;
 
 	if (nongit)
 		die(_("Not a git repository"));
@@ -379,7 +373,8 @@ int cmd_diff(int argc, const char **argv
 				add_head_to_pending(&rev);
 				if (!rev.pending.nr) {
 					struct tree *tree;
-					tree = lookup_tree(the_hash_algo->empty_tree);
+					tree = lookup_tree(the_repository,
+							   the_repository->hash_algo->empty_tree);
 					add_pending_object(&rev, &tree->object, "HEAD");
 				}
 				break;
@@ -393,8 +388,8 @@ int cmd_diff(int argc, const char **argv
 		const char *name = entry->name;
 		int flags = (obj->flags & UNINTERESTING);
 		if (!obj->parsed)
-			obj = parse_object(&obj->oid);
-		obj = deref_tag(obj, NULL, 0);
+			obj = parse_object(the_repository, &obj->oid);
+		obj = deref_tag(the_repository, obj, NULL, 0);
 		if (!obj)
 			die(_("invalid object '%s' given."), name);
 		if (obj->type == OBJ_COMMIT)
diff -pruN 1.2.1+git2.18.0-1/git/builtin/diff-files.c 1.2.3+git2.25.1-1/git/builtin/diff-files.c
--- 1.2.1+git2.18.0-1/git/builtin/diff-files.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/builtin/diff-files.c	2020-02-17 04:47:35.000000000 +0000
@@ -3,6 +3,7 @@
  *
  * Copyright (C) Linus Torvalds, 2005
  */
+#define USE_THE_INDEX_COMPATIBILITY_MACROS
 #include "cache.h"
 #include "config.h"
 #include "diff.h"
@@ -25,7 +26,7 @@ int cmd_diff_files(int argc, const char
 		usage(diff_files_usage);
 
 	git_config(git_diff_basic_config, NULL); /* no "diff" UI options */
-	init_revisions(&rev, prefix);
+	repo_init_revisions(the_repository, &rev, prefix);
 	rev.abbrev = 0;
 	precompose_argv(argc, argv);
 
diff -pruN 1.2.1+git2.18.0-1/git/builtin/diff-index.c 1.2.3+git2.25.1-1/git/builtin/diff-index.c
--- 1.2.1+git2.18.0-1/git/builtin/diff-index.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/builtin/diff-index.c	2020-02-17 04:47:35.000000000 +0000
@@ -1,3 +1,4 @@
+#define USE_THE_INDEX_COMPATIBILITY_MACROS
 #include "cache.h"
 #include "config.h"
 #include "diff.h"
@@ -22,7 +23,7 @@ int cmd_diff_index(int argc, const char
 		usage(diff_cache_usage);
 
 	git_config(git_diff_basic_config, NULL); /* no "diff" UI options */
-	init_revisions(&rev, prefix);
+	repo_init_revisions(the_repository, &rev, prefix);
 	rev.abbrev = 0;
 	precompose_argv(argc, argv);
 
diff -pruN 1.2.1+git2.18.0-1/git/builtin/difftool.c 1.2.3+git2.25.1-1/git/builtin/difftool.c
--- 1.2.1+git2.18.0-1/git/builtin/difftool.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/builtin/difftool.c	2020-02-17 04:47:35.000000000 +0000
@@ -11,6 +11,7 @@
  *
  * Copyright (C) 2016 Johannes Schindelin
  */
+#define USE_THE_INDEX_COMPATIBILITY_MACROS
 #include "cache.h"
 #include "config.h"
 #include "builtin.h"
@@ -20,9 +21,9 @@
 #include "argv-array.h"
 #include "strbuf.h"
 #include "lockfile.h"
+#include "object-store.h"
 #include "dir.h"
 
-static char *diff_gui_tool;
 static int trust_exit_code;
 
 static const char *const builtin_difftool_usage[] = {
@@ -32,11 +33,6 @@ static const char *const builtin_difftoo
 
 static int difftool_config(const char *var, const char *value, void *cb)
 {
-	if (!strcmp(var, "diff.guitool")) {
-		diff_gui_tool = xstrdup(value);
-		return 0;
-	}
-
 	if (!strcmp(var, "difftool.trustexitcode")) {
 		trust_exit_code = git_config_bool(var, value);
 		return 0;
@@ -63,14 +59,12 @@ static int parse_index_info(char *p, int
 	*mode2 = (int)strtol(p + 1, &p, 8);
 	if (*p != ' ')
 		return error("expected ' ', got '%c'", *p);
-	if (get_oid_hex(++p, oid1))
-		return error("expected object ID, got '%s'", p + 1);
-	p += GIT_SHA1_HEXSZ;
+	if (parse_oid_hex(++p, oid1, (const char **)&p))
+		return error("expected object ID, got '%s'", p);
 	if (*p != ' ')
 		return error("expected ' ', got '%c'", *p);
-	if (get_oid_hex(++p, oid2))
-		return error("expected object ID, got '%s'", p + 1);
-	p += GIT_SHA1_HEXSZ;
+	if (parse_oid_hex(++p, oid2, (const char **)&p))
+		return error("expected object ID, got '%s'", p);
 	if (*p != ' ')
 		return error("expected ' ', got '%c'", *p);
 	*status = *++p;
@@ -111,11 +105,11 @@ static int use_wt_file(const char *workd
 		int fd = open(buf.buf, O_RDONLY);
 
 		if (fd >= 0 &&
-		    !index_fd(&wt_oid, fd, &st, OBJ_BLOB, name, 0)) {
+		    !index_fd(&the_index, &wt_oid, fd, &st, OBJ_BLOB, name, 0)) {
 			if (is_null_oid(oid)) {
 				oidcpy(oid, &wt_oid);
 				use = 1;
-			} else if (!oidcmp(oid, &wt_oid))
+			} else if (oideq(oid, &wt_oid))
 				use = 1;
 		}
 	}
@@ -131,12 +125,15 @@ struct working_tree_entry {
 };
 
 static int working_tree_entry_cmp(const void *unused_cmp_data,
-				  const void *entry,
-				  const void *entry_or_key,
+				  const struct hashmap_entry *eptr,
+				  const struct hashmap_entry *entry_or_key,
 				  const void *unused_keydata)
 {
-	const struct working_tree_entry *a = entry;
-	const struct working_tree_entry *b = entry_or_key;
+	const struct working_tree_entry *a, *b;
+
+	a = container_of(eptr, const struct working_tree_entry, entry);
+	b = container_of(entry_or_key, const struct working_tree_entry, entry);
+
 	return strcmp(a->path, b->path);
 }
 
@@ -151,12 +148,14 @@ struct pair_entry {
 };
 
 static int pair_cmp(const void *unused_cmp_data,
-		    const void *entry,
-		    const void *entry_or_key,
+		    const struct hashmap_entry *eptr,
+		    const struct hashmap_entry *entry_or_key,
 		    const void *unused_keydata)
 {
-	const struct pair_entry *a = entry;
-	const struct pair_entry *b = entry_or_key;
+	const struct pair_entry *a, *b;
+
+	a = container_of(eptr, const struct pair_entry, entry);
+	b = container_of(entry_or_key, const struct pair_entry, entry);
 
 	return strcmp(a->path, b->path);
 }
@@ -167,14 +166,14 @@ static void add_left_or_right(struct has
 	struct pair_entry *e, *existing;
 
 	FLEX_ALLOC_STR(e, path, path);
-	hashmap_entry_init(e, strhash(path));
-	existing = hashmap_get(map, e, NULL);
+	hashmap_entry_init(&e->entry, strhash(path));
+	existing = hashmap_get_entry(map, e, entry, NULL);
 	if (existing) {
 		free(e);
 		e = existing;
 	} else {
 		e->left[0] = e->right[0] = '\0';
-		hashmap_add(map, e);
+		hashmap_add(map, &e->entry);
 	}
 	strlcpy(is_right ? e->right : e->left, content, PATH_MAX);
 }
@@ -185,12 +184,14 @@ struct path_entry {
 };
 
 static int path_entry_cmp(const void *unused_cmp_data,
-			  const void *entry,
-			  const void *entry_or_key,
+			  const struct hashmap_entry *eptr,
+			  const struct hashmap_entry *entry_or_key,
 			  const void *key)
 {
-	const struct path_entry *a = entry;
-	const struct path_entry *b = entry_or_key;
+	const struct path_entry *a, *b;
+
+	a = container_of(eptr, const struct path_entry, entry);
+	b = container_of(entry_or_key, const struct path_entry, entry);
 
 	return strcmp(a->path, key ? key : b->path);
 }
@@ -240,8 +241,8 @@ static void changed_files(struct hashmap
 	while (!strbuf_getline_nul(&buf, fp)) {
 		struct path_entry *entry;
 		FLEX_ALLOC_STR(entry, path, buf.buf);
-		hashmap_entry_init(entry, strhash(buf.buf));
-		hashmap_add(result, entry);
+		hashmap_entry_init(&entry->entry, strhash(buf.buf));
+		hashmap_add(result, &entry->entry);
 	}
 	fclose(fp);
 	if (finish_command(&diff_files))
@@ -321,10 +322,10 @@ static int checkout_path(unsigned mode,
 	struct cache_entry *ce;
 	int ret;
 
-	ce = make_cache_entry(mode, oid->hash, path, 0, 0);
-	ret = checkout_entry(ce, state, NULL);
+	ce = make_transient_cache_entry(mode, oid, path, 0);
+	ret = checkout_entry(ce, state, NULL, NULL);
 
-	free(ce);
+	discard_cache_entry(ce);
 	return ret;
 }
 
@@ -437,7 +438,7 @@ static int run_dir_diff(const char *extc
 			strbuf_reset(&buf);
 			strbuf_addf(&buf, "Subproject commit %s",
 				    oid_to_hex(&roid));
-			if (!oidcmp(&loid, &roid))
+			if (oideq(&loid, &roid))
 				strbuf_addstr(&buf, "-dirty");
 			add_left_or_right(&submodules, dst_path, buf.buf, 1);
 			continue;
@@ -467,12 +468,13 @@ static int run_dir_diff(const char *extc
 
 			/* Avoid duplicate working_tree entries */
 			FLEX_ALLOC_STR(entry, path, dst_path);
-			hashmap_entry_init(entry, strhash(dst_path));
-			if (hashmap_get(&working_tree_dups, entry, NULL)) {
+			hashmap_entry_init(&entry->entry, strhash(dst_path));
+			if (hashmap_get(&working_tree_dups, &entry->entry,
+					NULL)) {
 				free(entry);
 				continue;
 			}
-			hashmap_add(&working_tree_dups, entry);
+			hashmap_add(&working_tree_dups, &entry->entry);
 
 			if (!use_wt_file(workdir, dst_path, &roid)) {
 				if (checkout_path(rmode, &roid, dst_path,
@@ -488,7 +490,7 @@ static int run_dir_diff(const char *extc
 				 * index.
 				 */
 				struct cache_entry *ce2 =
-					make_cache_entry(rmode, roid.hash,
+					make_cache_entry(&wtindex, rmode, &roid,
 							 dst_path, 0, 0);
 
 				add_index_entry(&wtindex, ce2,
@@ -536,8 +538,8 @@ static int run_dir_diff(const char *extc
 	 * temporary file to both the left and right directories to show the
 	 * change in the recorded SHA1 for the submodule.
 	 */
-	hashmap_iter_init(&submodules, &iter);
-	while ((entry = hashmap_iter_next(&iter))) {
+	hashmap_for_each_entry(&submodules, &iter, entry,
+				entry /* member name */) {
 		if (*entry->left) {
 			add_path(&ldir, ldir_len, entry->path);
 			ensure_leading_directories(ldir.buf);
@@ -555,8 +557,8 @@ static int run_dir_diff(const char *extc
 	 * shows only the link itself, not the contents of the link target.
 	 * This loop replicates that behavior.
 	 */
-	hashmap_iter_init(&symlinks2, &iter);
-	while ((entry = hashmap_iter_next(&iter))) {
+	hashmap_for_each_entry(&symlinks2, &iter, entry,
+				entry /* member name */) {
 		if (*entry->left) {
 			add_path(&ldir, ldir_len, entry->path);
 			ensure_leading_directories(ldir.buf);
@@ -688,7 +690,7 @@ static int run_file_diff(int prompt, con
 int cmd_difftool(int argc, const char **argv, const char *prefix)
 {
 	int use_gui_tool = 0, dir_diff = 0, prompt = -1, symlinks = 0,
-	    tool_help = 0;
+	    tool_help = 0, no_index = 0;
 	static char *difftool_cmd = NULL, *extcmd = NULL;
 	struct option builtin_difftool_options[] = {
 		OPT_BOOL('g', "gui", &use_gui_tool,
@@ -702,7 +704,7 @@ int cmd_difftool(int argc, const char **
 			1, PARSE_OPT_NONEG | PARSE_OPT_HIDDEN),
 		OPT_BOOL(0, "symlinks", &symlinks,
 			 N_("use symlinks in dir-diff mode")),
-		OPT_STRING('t', "tool", &difftool_cmd, N_("<tool>"),
+		OPT_STRING('t', "tool", &difftool_cmd, N_("tool"),
 			   N_("use the specified diff tool")),
 		OPT_BOOL(0, "tool-help", &tool_help,
 			 N_("print a list of diff tools that may be used with "
@@ -710,8 +712,9 @@ int cmd_difftool(int argc, const char **
 		OPT_BOOL(0, "trust-exit-code", &trust_exit_code,
 			 N_("make 'git-difftool' exit when an invoked diff "
 			    "tool returns a non - zero exit code")),
-		OPT_STRING('x', "extcmd", &extcmd, N_("<command>"),
+		OPT_STRING('x', "extcmd", &extcmd, N_("command"),
 			   N_("specify a custom command for viewing diffs")),
+		OPT_ARGUMENT("no-index", &no_index, N_("passed to `diff`")),
 		OPT_END()
 	};
 
@@ -725,12 +728,21 @@ int cmd_difftool(int argc, const char **
 	if (tool_help)
 		return print_tool_help();
 
-	/* NEEDSWORK: once we no longer spawn anything, remove this */
-	setenv(GIT_DIR_ENVIRONMENT, absolute_path(get_git_dir()), 1);
-	setenv(GIT_WORK_TREE_ENVIRONMENT, absolute_path(get_git_work_tree()), 1);
+	if (!no_index && !startup_info->have_repository)
+		die(_("difftool requires worktree or --no-index"));
+
+	if (!no_index){
+		setup_work_tree();
+		setenv(GIT_DIR_ENVIRONMENT, absolute_path(get_git_dir()), 1);
+		setenv(GIT_WORK_TREE_ENVIRONMENT, absolute_path(get_git_work_tree()), 1);
+	} else if (dir_diff)
+		die(_("--dir-diff is incompatible with --no-index"));
+
+	if (use_gui_tool + !!difftool_cmd + !!extcmd > 1)
+		die(_("--gui, --tool and --extcmd are mutually exclusive"));
 
-	if (use_gui_tool && diff_gui_tool && *diff_gui_tool)
-		setenv("GIT_DIFF_TOOL", diff_gui_tool, 1);
+	if (use_gui_tool)
+		setenv("GIT_MERGETOOL_GUI", "true", 1);
 	else if (difftool_cmd) {
 		if (*difftool_cmd)
 			setenv("GIT_DIFF_TOOL", difftool_cmd, 1);
diff -pruN 1.2.1+git2.18.0-1/git/builtin/diff-tree.c 1.2.3+git2.25.1-1/git/builtin/diff-tree.c
--- 1.2.1+git2.18.0-1/git/builtin/diff-tree.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/builtin/diff-tree.c	2020-02-17 04:47:35.000000000 +0000
@@ -1,3 +1,4 @@
+#define USE_THE_INDEX_COMPATIBILITY_MACROS
 #include "cache.h"
 #include "config.h"
 #include "diff.h"
@@ -5,12 +6,13 @@
 #include "log-tree.h"
 #include "builtin.h"
 #include "submodule.h"
+#include "repository.h"
 
 static struct rev_info log_tree_opt;
 
 static int diff_tree_commit_oid(const struct object_id *oid)
 {
-	struct commit *commit = lookup_commit_reference(oid);
+	struct commit *commit = lookup_commit_reference(the_repository, oid);
 	if (!commit)
 		return -1;
 	return log_tree_commit(&log_tree_opt, commit);
@@ -24,7 +26,7 @@ static int stdin_diff_commit(struct comm
 
 	/* Graft the fake parents locally to the commit */
 	while (isspace(*p++) && !parse_oid_hex(p, &oid, &p)) {
-		struct commit *parent = lookup_commit(&oid);
+		struct commit *parent = lookup_commit(the_repository, &oid);
 		if (!pptr) {
 			/* Free the real parent list */
 			free_commit_list(commit->parents);
@@ -45,7 +47,7 @@ static int stdin_diff_trees(struct tree
 	struct tree *tree2;
 	if (!isspace(*p++) || parse_oid_hex(p, &oid, &p) || *p)
 		return error("Need exactly two trees, separated by a space");
-	tree2 = lookup_tree(&oid);
+	tree2 = lookup_tree(the_repository, &oid);
 	if (!tree2 || parse_tree(tree2))
 		return -1;
 	printf("%s %s\n", oid_to_hex(&tree1->object.oid),
@@ -68,7 +70,7 @@ static int diff_tree_stdin(char *line)
 	line[len-1] = 0;
 	if (parse_oid_hex(line, &oid, &p))
 		return -1;
-	obj = parse_object(&oid);
+	obj = parse_object(the_repository, &oid);
 	if (!obj)
 		return -1;
 	if (obj->type == OBJ_COMMIT)
@@ -81,9 +83,13 @@ static int diff_tree_stdin(char *line)
 }
 
 static const char diff_tree_usage[] =
-"git diff-tree [--stdin] [-m] [-c] [--cc] [-s] [-v] [--pretty] [-t] [-r] [--root] "
+"git diff-tree [--stdin] [-m] [-c | --cc] [-s] [-v] [--pretty] [-t] [-r] [--root] "
 "[<common-diff-options>] <tree-ish> [<tree-ish>] [<path>...]\n"
 "  -r            diff recursively\n"
+"  -c            show combined diff for merge commits\n"
+"  --cc          show combined diff for merge commits removing uninteresting hunks\n"
+"  --combined-all-paths\n"
+"                show name of file in all parents for combined diffs\n"
 "  --root        include the initial commit as diff against /dev/null\n"
 COMMON_DIFF_OPTIONS_HELP;
 
@@ -109,7 +115,7 @@ int cmd_diff_tree(int argc, const char *
 		usage(diff_tree_usage);
 
 	git_config(git_diff_basic_config, NULL); /* no "diff" UI options */
-	init_revisions(opt, prefix);
+	repo_init_revisions(the_repository, opt, prefix);
 	if (read_cache() < 0)
 		die(_("index file corrupt"));
 	opt->abbrev = 0;
@@ -162,9 +168,11 @@ int cmd_diff_tree(int argc, const char *
 		int saved_nrl = 0;
 		int saved_dcctc = 0;
 
-		if (opt->diffopt.detect_rename)
-			opt->diffopt.setup |= (DIFF_SETUP_USE_SIZE_CACHE |
-					       DIFF_SETUP_USE_CACHE);
+		if (opt->diffopt.detect_rename) {
+			if (!the_index.cache)
+				repo_read_index(the_repository);
+			opt->diffopt.setup |= DIFF_SETUP_USE_SIZE_CACHE;
+		}
 		while (fgets(line, sizeof(line), stdin)) {
 			struct object_id oid;
 
diff -pruN 1.2.1+git2.18.0-1/git/builtin/env--helper.c 1.2.3+git2.25.1-1/git/builtin/env--helper.c
--- 1.2.1+git2.18.0-1/git/builtin/env--helper.c	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/builtin/env--helper.c	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,95 @@
+#include "builtin.h"
+#include "config.h"
+#include "parse-options.h"
+
+static char const * const env__helper_usage[] = {
+	N_("git env--helper --type=[bool|ulong] <options> <env-var>"),
+	NULL
+};
+
+static enum {
+	ENV_HELPER_TYPE_BOOL = 1,
+	ENV_HELPER_TYPE_ULONG
+} cmdmode = 0;
+
+static int option_parse_type(const struct option *opt, const char *arg,
+			     int unset)
+{
+	if (!strcmp(arg, "bool"))
+		cmdmode = ENV_HELPER_TYPE_BOOL;
+	else if (!strcmp(arg, "ulong"))
+		cmdmode = ENV_HELPER_TYPE_ULONG;
+	else
+		die(_("unrecognized --type argument, %s"), arg);
+
+	return 0;
+}
+
+int cmd_env__helper(int argc, const char **argv, const char *prefix)
+{
+	int exit_code = 0;
+	const char *env_variable = NULL;
+	const char *env_default = NULL;
+	int ret;
+	int ret_int, default_int;
+	unsigned long ret_ulong, default_ulong;
+	struct option opts[] = {
+		OPT_CALLBACK_F(0, "type", &cmdmode, N_("type"),
+			       N_("value is given this type"), PARSE_OPT_NONEG,
+			       option_parse_type),
+		OPT_STRING(0, "default", &env_default, N_("value"),
+			   N_("default for git_env_*(...) to fall back on")),
+		OPT_BOOL(0, "exit-code", &exit_code,
+			 N_("be quiet only use git_env_*() value as exit code")),
+		OPT_END(),
+	};
+
+	argc = parse_options(argc, argv, prefix, opts, env__helper_usage,
+			     PARSE_OPT_KEEP_UNKNOWN);
+	if (env_default && !*env_default)
+		usage_with_options(env__helper_usage, opts);
+	if (!cmdmode)
+		usage_with_options(env__helper_usage, opts);
+	if (argc != 1)
+		usage_with_options(env__helper_usage, opts);
+	env_variable = argv[0];
+
+	switch (cmdmode) {
+	case ENV_HELPER_TYPE_BOOL:
+		if (env_default) {
+			default_int = git_parse_maybe_bool(env_default);
+			if (default_int == -1) {
+				error(_("option `--default' expects a boolean value with `--type=bool`, not `%s`"),
+				      env_default);
+				usage_with_options(env__helper_usage, opts);
+			}
+		} else {
+			default_int = 0;
+		}
+		ret_int = git_env_bool(env_variable, default_int);
+		if (!exit_code)
+			puts(ret_int ? "true" : "false");
+		ret = ret_int;
+		break;
+	case ENV_HELPER_TYPE_ULONG:
+		if (env_default) {
+			if (!git_parse_ulong(env_default, &default_ulong)) {
+				error(_("option `--default' expects an unsigned long value with `--type=ulong`, not `%s`"),
+				      env_default);
+				usage_with_options(env__helper_usage, opts);
+			}
+		} else {
+			default_ulong = 0;
+		}
+		ret_ulong = git_env_ulong(env_variable, default_ulong);
+		if (!exit_code)
+			printf("%lu\n", ret_ulong);
+		ret = ret_ulong;
+		break;
+	default:
+		BUG("unknown <type> value");
+		break;
+	}
+
+	return !ret;
+}
diff -pruN 1.2.1+git2.18.0-1/git/builtin/fast-export.c 1.2.3+git2.25.1-1/git/builtin/fast-export.c
--- 1.2.1+git2.18.0-1/git/builtin/fast-export.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/builtin/fast-export.c	2020-02-17 04:47:35.000000000 +0000
@@ -8,6 +8,7 @@
 #include "config.h"
 #include "refs.h"
 #include "refspec.h"
+#include "object-store.h"
 #include "commit.h"
 #include "object.h"
 #include "tag.h"
@@ -22,6 +23,7 @@
 #include "quote.h"
 #include "remote.h"
 #include "blob.h"
+#include "commit-slab.h"
 
 static const char *fast_export_usage[] = {
 	N_("git fast-export [rev-list-opts]"),
@@ -29,21 +31,27 @@ static const char *fast_export_usage[] =
 };
 
 static int progress;
-static enum { ABORT, VERBATIM, WARN, WARN_STRIP, STRIP } signed_tag_mode = ABORT;
-static enum { ERROR, DROP, REWRITE } tag_of_filtered_mode = ERROR;
+static enum { SIGNED_TAG_ABORT, VERBATIM, WARN, WARN_STRIP, STRIP } signed_tag_mode = SIGNED_TAG_ABORT;
+static enum { TAG_FILTERING_ABORT, DROP, REWRITE } tag_of_filtered_mode = TAG_FILTERING_ABORT;
+static enum { REENCODE_ABORT, REENCODE_YES, REENCODE_NO } reencode_mode = REENCODE_ABORT;
 static int fake_missing_tagger;
 static int use_done_feature;
 static int no_data;
 static int full_tree;
+static int reference_excluded_commits;
+static int show_original_ids;
+static int mark_tags;
 static struct string_list extra_refs = STRING_LIST_INIT_NODUP;
+static struct string_list tag_refs = STRING_LIST_INIT_NODUP;
 static struct refspec refspecs = REFSPEC_INIT_FETCH;
 static int anonymize;
+static struct revision_sources revision_sources;
 
 static int parse_opt_signed_tag_mode(const struct option *opt,
 				     const char *arg, int unset)
 {
 	if (unset || !strcmp(arg, "abort"))
-		signed_tag_mode = ABORT;
+		signed_tag_mode = SIGNED_TAG_ABORT;
 	else if (!strcmp(arg, "verbatim") || !strcmp(arg, "ignore"))
 		signed_tag_mode = VERBATIM;
 	else if (!strcmp(arg, "warn"))
@@ -61,7 +69,7 @@ static int parse_opt_tag_of_filtered_mod
 					  const char *arg, int unset)
 {
 	if (unset || !strcmp(arg, "abort"))
-		tag_of_filtered_mode = ERROR;
+		tag_of_filtered_mode = TAG_FILTERING_ABORT;
 	else if (!strcmp(arg, "drop"))
 		tag_of_filtered_mode = DROP;
 	else if (!strcmp(arg, "rewrite"))
@@ -71,6 +79,31 @@ static int parse_opt_tag_of_filtered_mod
 	return 0;
 }
 
+static int parse_opt_reencode_mode(const struct option *opt,
+				   const char *arg, int unset)
+{
+	if (unset) {
+		reencode_mode = REENCODE_ABORT;
+		return 0;
+	}
+
+	switch (git_parse_maybe_bool(arg)) {
+	case 0:
+		reencode_mode = REENCODE_NO;
+		break;
+	case 1:
+		reencode_mode = REENCODE_YES;
+		break;
+	default:
+		if (!strcasecmp(arg, "abort"))
+			reencode_mode = REENCODE_ABORT;
+		else
+			return error("Unknown reencoding mode: %s", arg);
+	}
+
+	return 0;
+}
+
 static struct decoration idnums;
 static uint32_t last_idnum;
 
@@ -94,10 +127,15 @@ struct anonymized_entry {
 };
 
 static int anonymized_entry_cmp(const void *unused_cmp_data,
-				const void *va, const void *vb,
+				const struct hashmap_entry *eptr,
+				const struct hashmap_entry *entry_or_key,
 				const void *unused_keydata)
 {
-	const struct anonymized_entry *a = va, *b = vb;
+	const struct anonymized_entry *a, *b;
+
+	a = container_of(eptr, const struct anonymized_entry, hash);
+	b = container_of(entry_or_key, const struct anonymized_entry, hash);
+
 	return a->orig_len != b->orig_len ||
 		memcmp(a->orig, b->orig, a->orig_len);
 }
@@ -116,10 +154,10 @@ static const void *anonymize_mem(struct
 	if (!map->cmpfn)
 		hashmap_init(map, anonymized_entry_cmp, NULL, 0);
 
-	hashmap_entry_init(&key, memhash(orig, *len));
+	hashmap_entry_init(&key.hash, memhash(orig, *len));
 	key.orig = orig;
 	key.orig_len = *len;
-	ret = hashmap_get(map, &key, NULL);
+	ret = hashmap_get_entry(map, &key, hash, NULL);
 
 	if (!ret) {
 		ret = xmalloc(sizeof(*ret));
@@ -128,7 +166,7 @@ static const void *anonymize_mem(struct
 		ret->orig_len = *len;
 		ret->anon = generate(orig, len);
 		ret->anon_len = *len;
-		hashmap_put(map, ret);
+		hashmap_put(map, &ret->hash);
 	}
 
 	*len = ret->anon_len;
@@ -184,6 +222,22 @@ static int get_object_mark(struct object
 	return ptr_to_mark(decoration);
 }
 
+static struct commit *rewrite_commit(struct commit *p)
+{
+	for (;;) {
+		if (p->parents && p->parents->next)
+			break;
+		if (p->object.flags & UNINTERESTING)
+			break;
+		if (!(p->object.flags & TREESAME))
+			break;
+		if (!p->parents)
+			return NULL;
+		p = p->parents->item;
+	}
+	return p;
+}
+
 static void show_progress(void)
 {
 	static int counter = 0;
@@ -227,21 +281,22 @@ static void export_blob(const struct obj
 	if (is_null_oid(oid))
 		return;
 
-	object = lookup_object(oid->hash);
+	object = lookup_object(the_repository, oid);
 	if (object && object->flags & SHOWN)
 		return;
 
 	if (anonymize) {
 		buf = anonymize_blob(&size);
-		object = (struct object *)lookup_blob(oid);
+		object = (struct object *)lookup_blob(the_repository, oid);
 		eaten = 0;
 	} else {
 		buf = read_object_file(oid, &type, &size);
 		if (!buf)
-			die ("Could not read blob %s", oid_to_hex(oid));
+			die("could not read blob %s", oid_to_hex(oid));
 		if (check_object_signature(oid, buf, size, type_name(type)) < 0)
-			die("sha1 mismatch in blob %s", oid_to_hex(oid));
-		object = parse_object_buffer(oid, type, size, buf, &eaten);
+			die("oid mismatch in blob %s", oid_to_hex(oid));
+		object = parse_object_buffer(the_repository, oid, type,
+					     size, buf, &eaten);
 	}
 
 	if (!object)
@@ -249,9 +304,12 @@ static void export_blob(const struct obj
 
 	mark_next_object(object);
 
-	printf("blob\nmark :%"PRIu32"\ndata %lu\n", last_idnum, size);
+	printf("blob\nmark :%"PRIu32"\n", last_idnum);
+	if (show_original_ids)
+		printf("original-oid %s\n", oid_to_hex(oid));
+	printf("data %"PRIuMAX"\n", (uintmax_t)size);
 	if (size && fwrite(buf, size, 1, stdout) != 1)
-		die_errno ("Could not write blob '%s'", oid_to_hex(oid));
+		die_errno("could not write blob '%s'", oid_to_hex(oid));
 	printf("\n");
 
 	show_progress();
@@ -326,17 +384,18 @@ static void print_path(const char *path)
 
 static void *generate_fake_oid(const void *old, size_t *len)
 {
-	static uint32_t counter = 1; /* avoid null sha1 */
-	unsigned char *out = xcalloc(GIT_SHA1_RAWSZ, 1);
-	put_be32(out + GIT_SHA1_RAWSZ - 4, counter++);
+	static uint32_t counter = 1; /* avoid null oid */
+	const unsigned hashsz = the_hash_algo->rawsz;
+	unsigned char *out = xcalloc(hashsz, 1);
+	put_be32(out + hashsz - 4, counter++);
 	return out;
 }
 
-static const unsigned char *anonymize_sha1(const struct object_id *oid)
+static const struct object_id *anonymize_oid(const struct object_id *oid)
 {
-	static struct hashmap sha1s;
-	size_t len = GIT_SHA1_RAWSZ;
-	return anonymize_mem(&sha1s, generate_fake_oid, oid, &len);
+	static struct hashmap objs;
+	size_t len = the_hash_algo->rawsz;
+	return anonymize_mem(&objs, generate_fake_oid, oid, &len);
 }
 
 static void show_filemodify(struct diff_queue_struct *q,
@@ -380,7 +439,7 @@ static void show_filemodify(struct diff_
 				string_list_insert(changed, spec->path);
 				putchar('\n');
 
-				if (!oidcmp(&ospec->oid, &spec->oid) &&
+				if (oideq(&ospec->oid, &spec->oid) &&
 				    ospec->mode == spec->mode)
 					break;
 			}
@@ -395,11 +454,12 @@ static void show_filemodify(struct diff_
 			 */
 			if (no_data || S_ISGITLINK(spec->mode))
 				printf("M %06o %s ", spec->mode,
-				       sha1_to_hex(anonymize ?
-						   anonymize_sha1(&spec->oid) :
-						   spec->oid.hash));
+				       oid_to_hex(anonymize ?
+						  anonymize_oid(&spec->oid) :
+						  &spec->oid));
 			else {
-				struct object *object = lookup_object(spec->oid.hash);
+				struct object *object = lookup_object(the_repository,
+								      &spec->oid);
 				printf("M %06o :%d ", spec->mode,
 				       get_object_mark(object));
 			}
@@ -425,7 +485,7 @@ static const char *find_encoding(const c
 	bol = memmem(begin, end ? end - begin : strlen(begin),
 		     needle, strlen(needle));
 	if (!bol)
-		return git_commit_encoding;
+		return NULL;
 	bol += strlen(needle);
 	eol = strchrnul(bol, '\n');
 	*eol = '\0';
@@ -558,14 +618,14 @@ static void handle_commit(struct commit
 	commit_buffer = get_commit_buffer(commit, NULL);
 	author = strstr(commit_buffer, "\nauthor ");
 	if (!author)
-		die ("Could not find author in commit %s",
-		     oid_to_hex(&commit->object.oid));
+		die("could not find author in commit %s",
+		    oid_to_hex(&commit->object.oid));
 	author++;
 	author_end = strchrnul(author, '\n');
 	committer = strstr(author_end, "\ncommitter ");
 	if (!committer)
-		die ("Could not find committer in commit %s",
-		     oid_to_hex(&commit->object.oid));
+		die("could not find committer in commit %s",
+		    oid_to_hex(&commit->object.oid));
 	committer++;
 	committer_end = strchrnul(committer, '\n');
 	message = strstr(committer_end, "\n\n");
@@ -574,7 +634,8 @@ static void handle_commit(struct commit
 		message += 2;
 
 	if (commit->parents &&
-	    get_object_mark(&commit->parents->item->object) != 0 &&
+	    (get_object_mark(&commit->parents->item->object) != 0 ||
+	     reference_excluded_commits) &&
 	    !full_tree) {
 		parse_commit_or_die(commit->parents->item);
 		diff_tree_oid(get_commit_tree_oid(commit->parents->item),
@@ -589,7 +650,14 @@ static void handle_commit(struct commit
 		if (!S_ISGITLINK(diff_queued_diff.queue[i]->two->mode))
 			export_blob(&diff_queued_diff.queue[i]->two->oid);
 
-	refname = commit->util;
+	refname = *revision_sources_at(&revision_sources, commit);
+	/*
+	 * FIXME: string_list_remove() below for each ref is overall
+	 * O(N^2).  Compared to a history walk and diffing trees, this is
+	 * just lost in the noise in practice.  However, theoretically a
+	 * repo may have enough refs for this to become slow.
+	 */
+	string_list_remove(&extra_refs, refname, 0);
 	if (anonymize) {
 		refname = anonymize_refname(refname);
 		anonymize_ident_line(&committer, &committer_end);
@@ -597,16 +665,32 @@ static void handle_commit(struct commit
 	}
 
 	mark_next_object(&commit->object);
-	if (anonymize)
+	if (anonymize) {
 		reencoded = anonymize_commit_message(message);
-	else if (!is_encoding_utf8(encoding))
-		reencoded = reencode_string(message, "UTF-8", encoding);
+	} else if (encoding) {
+		switch(reencode_mode) {
+		case REENCODE_YES:
+			reencoded = reencode_string(message, "UTF-8", encoding);
+			break;
+		case REENCODE_NO:
+			break;
+		case REENCODE_ABORT:
+			die("Encountered commit-specific encoding %s in commit "
+			    "%s; use --reencode=[yes|no] to handle it",
+			    encoding, oid_to_hex(&commit->object.oid));
+		}
+	}
 	if (!commit->parents)
 		printf("reset %s\n", refname);
-	printf("commit %s\nmark :%"PRIu32"\n%.*s\n%.*s\ndata %u\n%s",
-	       refname, last_idnum,
+	printf("commit %s\nmark :%"PRIu32"\n", refname, last_idnum);
+	if (show_original_ids)
+		printf("original-oid %s\n", oid_to_hex(&commit->object.oid));
+	printf("%.*s\n%.*s\n",
 	       (int)(author_end - author), author,
-	       (int)(committer_end - committer), committer,
+	       (int)(committer_end - committer), committer);
+	if (!reencoded && encoding)
+		printf("encoding %s\n", encoding);
+	printf("data %u\n%s",
 	       (unsigned)(reencoded
 			  ? strlen(reencoded) : message
 			  ? strlen(message) : 0),
@@ -615,13 +699,21 @@ static void handle_commit(struct commit
 	unuse_commit_buffer(commit, commit_buffer);
 
 	for (i = 0, p = commit->parents; p; p = p->next) {
-		int mark = get_object_mark(&p->item->object);
-		if (!mark)
+		struct object *obj = &p->item->object;
+		int mark = get_object_mark(obj);
+
+		if (!mark && !reference_excluded_commits)
 			continue;
 		if (i == 0)
-			printf("from :%d\n", mark);
+			printf("from ");
+		else
+			printf("merge ");
+		if (mark)
+			printf(":%d\n", mark);
 		else
-			printf("merge :%d\n", mark);
+			printf("%s\n", oid_to_hex(anonymize ?
+						  anonymize_oid(&obj->oid) :
+						  &obj->oid));
 		i++;
 	}
 
@@ -686,7 +778,7 @@ static void handle_tag(const char *name,
 
 	buf = read_object_file(&tag->object.oid, &type, &size);
 	if (!buf)
-		die ("Could not read tag %s", oid_to_hex(&tag->object.oid));
+		die("could not read tag %s", oid_to_hex(&tag->object.oid));
 	message = memmem(buf, size, "\n\n", 2);
 	if (message) {
 		message += 2;
@@ -722,19 +814,19 @@ static void handle_tag(const char *name,
 					       "\n-----BEGIN PGP SIGNATURE-----\n");
 		if (signature)
 			switch(signed_tag_mode) {
-			case ABORT:
-				die ("Encountered signed tag %s; use "
-				     "--signed-tags=<mode> to handle it.",
-				     oid_to_hex(&tag->object.oid));
+			case SIGNED_TAG_ABORT:
+				die("encountered signed tag %s; use "
+				    "--signed-tags=<mode> to handle it",
+				    oid_to_hex(&tag->object.oid));
 			case WARN:
-				warning ("Exporting signed tag %s",
-					 oid_to_hex(&tag->object.oid));
+				warning("exporting signed tag %s",
+					oid_to_hex(&tag->object.oid));
 				/* fallthru */
 			case VERBATIM:
 				break;
 			case WARN_STRIP:
-				warning ("Stripping signature from tag %s",
-					 oid_to_hex(&tag->object.oid));
+				warning("stripping signature from tag %s",
+					oid_to_hex(&tag->object.oid));
 				/* fallthru */
 			case STRIP:
 				message_size = signature + 1 - message;
@@ -747,41 +839,52 @@ static void handle_tag(const char *name,
 	tagged_mark = get_object_mark(tagged);
 	if (!tagged_mark) {
 		switch(tag_of_filtered_mode) {
-		case ABORT:
-			die ("Tag %s tags unexported object; use "
-			     "--tag-of-filtered-object=<mode> to handle it.",
-			     oid_to_hex(&tag->object.oid));
+		case TAG_FILTERING_ABORT:
+			die("tag %s tags unexported object; use "
+			    "--tag-of-filtered-object=<mode> to handle it",
+			    oid_to_hex(&tag->object.oid));
 		case DROP:
 			/* Ignore this tag altogether */
 			free(buf);
 			return;
 		case REWRITE:
-			if (tagged->type != OBJ_COMMIT) {
-				die ("Tag %s tags unexported %s!",
-				     oid_to_hex(&tag->object.oid),
-				     type_name(tagged->type));
+			if (tagged->type == OBJ_TAG && !mark_tags) {
+				die(_("Error: Cannot export nested tags unless --mark-tags is specified."));
+			} else if (tagged->type == OBJ_COMMIT) {
+				p = rewrite_commit((struct commit *)tagged);
+				if (!p) {
+					printf("reset %s\nfrom %s\n\n",
+					       name, oid_to_hex(&null_oid));
+					free(buf);
+					return;
+				}
+				tagged_mark = get_object_mark(&p->object);
+			} else {
+				/* tagged->type is either OBJ_BLOB or OBJ_TAG */
+				tagged_mark = get_object_mark(tagged);
 			}
-			p = (struct commit *)tagged;
-			for (;;) {
-				if (p->parents && p->parents->next)
-					break;
-				if (p->object.flags & UNINTERESTING)
-					break;
-				if (!(p->object.flags & TREESAME))
-					break;
-				if (!p->parents)
-					die ("Can't find replacement commit for tag %s\n",
-					     oid_to_hex(&tag->object.oid));
-				p = p->parents->item;
-			}
-			tagged_mark = get_object_mark(&p->object);
 		}
 	}
 
+	if (tagged->type == OBJ_TAG) {
+		printf("reset %s\nfrom %s\n\n",
+		       name, oid_to_hex(&null_oid));
+	}
 	if (starts_with(name, "refs/tags/"))
 		name += 10;
-	printf("tag %s\nfrom :%d\n%.*s%sdata %d\n%.*s\n",
-	       name, tagged_mark,
+	printf("tag %s\n", name);
+	if (mark_tags) {
+		mark_next_object(&tag->object);
+		printf("mark :%"PRIu32"\n", last_idnum);
+	}
+	if (tagged_mark)
+		printf("from :%d\n", tagged_mark);
+	else
+		printf("from %s\n", oid_to_hex(&tagged->oid));
+
+	if (show_original_ids)
+		printf("original-oid %s\n", oid_to_hex(&tag->object.oid));
+	printf("%.*s%sdata %d\n%.*s\n",
 	       (int)(tagger_end - tagger), tagger,
 	       tagger == tagger_end ? "" : "\n",
 	       (int)message_size, (int)message_size, message ? message : "");
@@ -798,8 +901,8 @@ static struct commit *get_commit(struct
 
 		/* handle nested tags */
 		while (tag && tag->object.type == OBJ_TAG) {
-			parse_object(&tag->object.oid);
-			string_list_append(&extra_refs, full_name)->util = tag;
+			parse_object(the_repository, &tag->object.oid);
+			string_list_append(&tag_refs, full_name)->util = tag;
 			tag = (struct tag *)tag->tagged;
 		}
 		if (!tag)
@@ -858,24 +961,30 @@ static void get_tags_and_duplicates(stru
 		}
 
 		/*
-		 * This ref will not be updated through a commit, lets make
-		 * sure it gets properly updated eventually.
+		 * Make sure this ref gets properly updated eventually, whether
+		 * through a commit or manually at the end.
 		 */
-		if (commit->util || commit->object.flags & SHOWN)
+		if (e->item->type != OBJ_TAG)
 			string_list_append(&extra_refs, full_name)->util = commit;
-		if (!commit->util)
-			commit->util = full_name;
+
+		if (!*revision_sources_at(&revision_sources, commit))
+			*revision_sources_at(&revision_sources, commit) = full_name;
 	}
+
+	string_list_sort(&extra_refs);
+	string_list_remove_duplicates(&extra_refs, 0);
 }
 
-static void handle_tags_and_duplicates(void)
+static void handle_tags_and_duplicates(struct string_list *extras)
 {
 	struct commit *commit;
 	int i;
 
-	for (i = extra_refs.nr - 1; i >= 0; i--) {
-		const char *name = extra_refs.items[i].string;
-		struct object *object = extra_refs.items[i].util;
+	for (i = extras->nr - 1; i >= 0; i--) {
+		const char *name = extras->items[i].string;
+		struct object *object = extras->items[i].util;
+		int mark;
+
 		switch (object->type) {
 		case OBJ_TAG:
 			handle_tag(name, (struct tag *)object);
@@ -884,9 +993,45 @@ static void handle_tags_and_duplicates(v
 			if (anonymize)
 				name = anonymize_refname(name);
 			/* create refs pointing to already seen commits */
-			commit = (struct commit *)object;
-			printf("reset %s\nfrom :%d\n\n", name,
-			       get_object_mark(&commit->object));
+			commit = rewrite_commit((struct commit *)object);
+			if (!commit) {
+				/*
+				 * Neither this object nor any of its
+				 * ancestors touch any relevant paths, so
+				 * it has been filtered to nothing.  Delete
+				 * it.
+				 */
+				printf("reset %s\nfrom %s\n\n",
+				       name, oid_to_hex(&null_oid));
+				continue;
+			}
+
+			mark = get_object_mark(&commit->object);
+			if (!mark) {
+				/*
+				 * Getting here means we have a commit which
+				 * was excluded by a negative refspec (e.g.
+				 * fast-export ^master master).  If we are
+				 * referencing excluded commits, set the ref
+				 * to the exact commit.  Otherwise, the user
+				 * wants the branch exported but every commit
+				 * in its history to be deleted, which basically
+				 * just means deletion of the ref.
+				 */
+				if (!reference_excluded_commits) {
+					/* delete the ref */
+					printf("reset %s\nfrom %s\n\n",
+					       name, oid_to_hex(&null_oid));
+					continue;
+				}
+				/* set ref to commit using oid, not mark */
+				printf("reset %s\nfrom %s\n\n", name,
+				       oid_to_hex(&commit->object.oid));
+				continue;
+			}
+
+			printf("reset %s\nfrom :%d\n\n", name, mark
+			       );
 			show_progress();
 			break;
 		}
@@ -923,11 +1068,16 @@ static void export_marks(char *file)
 		error("Unable to write marks file %s.", file);
 }
 
-static void import_marks(char *input_file)
+static void import_marks(char *input_file, int check_exists)
 {
 	char line[512];
-	FILE *f = xfopen(input_file, "r");
+	FILE *f;
+	struct stat sb;
 
+	if (check_exists && stat(input_file, &sb))
+		return;
+
+	f = xfopen(input_file, "r");
 	while (fgets(line, sizeof(line), f)) {
 		uint32_t mark;
 		char *line_end, *mark_end;
@@ -957,7 +1107,7 @@ static void import_marks(char *input_fil
 			/* only commits */
 			continue;
 
-		commit = lookup_commit(&oid);
+		commit = lookup_commit(the_repository, &oid);
 		if (!commit)
 			die("not a commit? can't happen: %s", oid_to_hex(&oid));
 
@@ -982,7 +1132,7 @@ static void handle_deletes(void)
 			continue;
 
 		printf("reset %s\nfrom %s\n\n",
-				refspec->dst, sha1_to_hex(null_sha1));
+				refspec->dst, oid_to_hex(&null_oid));
 	}
 }
 
@@ -991,7 +1141,9 @@ int cmd_fast_export(int argc, const char
 	struct rev_info revs;
 	struct object_array commits = OBJECT_ARRAY_INIT;
 	struct commit *commit;
-	char *export_filename = NULL, *import_filename = NULL;
+	char *export_filename = NULL,
+	     *import_filename = NULL,
+	     *import_filename_if_exists = NULL;
 	uint32_t lastimportid;
 	struct string_list refspecs_list = STRING_LIST_INIT_NODUP;
 	struct string_list paths_of_changed_objects = STRING_LIST_INIT_DUP;
@@ -1004,10 +1156,17 @@ int cmd_fast_export(int argc, const char
 		OPT_CALLBACK(0, "tag-of-filtered-object", &tag_of_filtered_mode, N_("mode"),
 			     N_("select handling of tags that tag filtered objects"),
 			     parse_opt_tag_of_filtered_mode),
+		OPT_CALLBACK(0, "reencode", &reencode_mode, N_("mode"),
+			     N_("select handling of commit messages in an alternate encoding"),
+			     parse_opt_reencode_mode),
 		OPT_STRING(0, "export-marks", &export_filename, N_("file"),
 			     N_("Dump marks to this file")),
 		OPT_STRING(0, "import-marks", &import_filename, N_("file"),
 			     N_("Import marks from this file")),
+		OPT_STRING(0, "import-marks-if-exists",
+			     &import_filename_if_exists,
+			     N_("file"),
+			     N_("Import marks from this file if it exists")),
 		OPT_BOOL(0, "fake-missing-tagger", &fake_missing_tagger,
 			 N_("Fake a tagger when tags lack one")),
 		OPT_BOOL(0, "full-tree", &full_tree,
@@ -1018,6 +1177,13 @@ int cmd_fast_export(int argc, const char
 		OPT_STRING_LIST(0, "refspec", &refspecs_list, N_("refspec"),
 			     N_("Apply refspec to exported refs")),
 		OPT_BOOL(0, "anonymize", &anonymize, N_("anonymize output")),
+		OPT_BOOL(0, "reference-excluded-parents",
+			 &reference_excluded_commits, N_("Reference parents which are not in fast-export stream by object id")),
+		OPT_BOOL(0, "show-original-ids", &show_original_ids,
+			    N_("Show original object ids of blobs/commits")),
+		OPT_BOOL(0, "mark-tags", &mark_tags,
+			    N_("Label tags with mark ids")),
+
 		OPT_END()
 	};
 
@@ -1027,9 +1193,10 @@ int cmd_fast_export(int argc, const char
 	/* we handle encodings */
 	git_config(git_default_config, NULL);
 
-	init_revisions(&revs, prefix);
+	repo_init_revisions(the_repository, &revs, prefix);
+	init_revision_sources(&revision_sources);
 	revs.topo_order = 1;
-	revs.show_source = 1;
+	revs.sources = &revision_sources;
 	revs.rewrite_parents = 1;
 	argc = parse_options(argc, argv, prefix, options, fast_export_usage,
 			PARSE_OPT_KEEP_ARGV0 | PARSE_OPT_KEEP_UNKNOWN);
@@ -1049,8 +1216,12 @@ int cmd_fast_export(int argc, const char
 	if (use_done_feature)
 		printf("feature done\n");
 
+	if (import_filename && import_filename_if_exists)
+		die(_("Cannot pass both --import-marks and --import-marks-if-exists"));
 	if (import_filename)
-		import_marks(import_filename);
+		import_marks(import_filename, 0);
+	else if (import_filename_if_exists)
+		import_marks(import_filename_if_exists, 1);
 	lastimportid = last_idnum;
 
 	if (import_filename && revs.prune_data.nr)
@@ -1073,7 +1244,8 @@ int cmd_fast_export(int argc, const char
 		}
 	}
 
-	handle_tags_and_duplicates();
+	handle_tags_and_duplicates(&extra_refs);
+	handle_tags_and_duplicates(&tag_refs);
 	handle_deletes();
 
 	if (export_filename && lastimportid != last_idnum)
diff -pruN 1.2.1+git2.18.0-1/git/builtin/fetch.c 1.2.3+git2.25.1-1/git/builtin/fetch.c
--- 1.2.1+git2.18.0-1/git/builtin/fetch.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/builtin/fetch.c	2020-02-17 04:47:35.000000000 +0000
@@ -6,6 +6,8 @@
 #include "repository.h"
 #include "refs.h"
 #include "refspec.h"
+#include "object-store.h"
+#include "oidset.h"
 #include "commit.h"
 #include "builtin.h"
 #include "string-list.h"
@@ -21,6 +23,12 @@
 #include "utf8.h"
 #include "packfile.h"
 #include "list-objects-filter-options.h"
+#include "commit-reach.h"
+#include "branch.h"
+#include "promisor-remote.h"
+#include "commit-graph.h"
+
+#define FORCED_UPDATES_DELAY_WARNING_IN_MS (10 * 1000)
 
 static const char * const builtin_fetch_usage[] = {
 	N_("git fetch [<options>] [<repository> [<refspec>...]]"),
@@ -37,6 +45,8 @@ enum {
 };
 
 static int fetch_prune_config = -1; /* unspecified */
+static int fetch_show_forced_updates = 1;
+static uint64_t forced_updates_ms = 0;
 static int prune = -1; /* unspecified */
 #define PRUNE_BY_DEFAULT 0 /* do we prune by default? */
 
@@ -44,10 +54,13 @@ static int fetch_prune_tags_config = -1;
 static int prune_tags = -1; /* unspecified */
 #define PRUNE_TAGS_BY_DEFAULT 0 /* do we prune tags by default? */
 
-static int all, append, dry_run, force, keep, multiple, update_head_ok, verbosity, deepen_relative;
+static int all, append, dry_run, force, keep, multiple, update_head_ok;
+static int verbosity, deepen_relative, set_upstream;
 static int progress = -1;
+static int enable_auto_gc = 1;
 static int tags = TAGS_DEFAULT, unshallow, update_shallow, deepen;
-static int max_children = 1;
+static int max_jobs = -1, submodule_fetch_jobs_config = -1;
+static int fetch_parallel_config = 1;
 static enum transport_family family;
 static const char *depth;
 static const char *deepen_since;
@@ -63,6 +76,8 @@ static int shown_url = 0;
 static struct refspec refmap = REFSPEC_INIT_FETCH;
 static struct list_objects_filter_options filter_options;
 static struct string_list server_options = STRING_LIST_INIT_DUP;
+static struct string_list negotiation_tip = STRING_LIST_INIT_NODUP;
+static int fetch_write_commit_graph = -1;
 
 static int git_fetch_config(const char *k, const char *v, void *cb)
 {
@@ -76,6 +91,11 @@ static int git_fetch_config(const char *
 		return 0;
 	}
 
+	if (!strcmp(k, "fetch.showforcedupdates")) {
+		fetch_show_forced_updates = git_config_bool(k, v);
+		return 0;
+	}
+
 	if (!strcmp(k, "submodule.recurse")) {
 		int r = git_config_bool(k, v) ?
 			RECURSE_SUBMODULES_ON : RECURSE_SUBMODULES_OFF;
@@ -83,31 +103,27 @@ static int git_fetch_config(const char *
 	}
 
 	if (!strcmp(k, "submodule.fetchjobs")) {
-		max_children = parse_submodule_fetchjobs(k, v);
+		submodule_fetch_jobs_config = parse_submodule_fetchjobs(k, v);
 		return 0;
 	} else if (!strcmp(k, "fetch.recursesubmodules")) {
 		recurse_submodules = parse_fetch_recurse_submodules_arg(k, v);
 		return 0;
 	}
 
-	return git_default_config(k, v, cb);
-}
-
-static int gitmodules_fetch_config(const char *var, const char *value, void *cb)
-{
-	if (!strcmp(var, "submodule.fetchjobs")) {
-		max_children = parse_submodule_fetchjobs(var, value);
-		return 0;
-	} else if (!strcmp(var, "fetch.recursesubmodules")) {
-		recurse_submodules = parse_fetch_recurse_submodules_arg(var, value);
+	if (!strcmp(k, "fetch.parallel")) {
+		fetch_parallel_config = git_config_int(k, v);
+		if (fetch_parallel_config < 0)
+			die(_("fetch.parallel cannot be negative"));
 		return 0;
 	}
 
-	return 0;
+	return git_default_config(k, v, cb);
 }
 
 static int parse_refmap_arg(const struct option *opt, const char *arg, int unset)
 {
+	BUG_ON_OPT_NEG(unset);
+
 	/*
 	 * "git fetch --refmap='' origin foo"
 	 * can be used to tell the command not to store anywhere
@@ -121,18 +137,20 @@ static struct option builtin_fetch_optio
 	OPT__VERBOSITY(&verbosity),
 	OPT_BOOL(0, "all", &all,
 		 N_("fetch from all remotes")),
+	OPT_BOOL(0, "set-upstream", &set_upstream,
+		 N_("set upstream for git pull/fetch")),
 	OPT_BOOL('a', "append", &append,
 		 N_("append to .git/FETCH_HEAD instead of overwriting")),
 	OPT_STRING(0, "upload-pack", &upload_pack, N_("path"),
 		   N_("path to upload pack on remote end")),
-	OPT__FORCE(&force, N_("force overwrite of local branch"), 0),
+	OPT__FORCE(&force, N_("force overwrite of local reference"), 0),
 	OPT_BOOL('m', "multiple", &multiple,
 		 N_("fetch from multiple remotes")),
 	OPT_SET_INT('t', "tags", &tags,
 		    N_("fetch all tags and associated objects"), TAGS_SET),
 	OPT_SET_INT('n', NULL, &tags,
 		    N_("do not fetch all tags (--no-tags)"), TAGS_UNSET),
-	OPT_INTEGER('j', "jobs", &max_children,
+	OPT_INTEGER('j', "jobs", &max_jobs,
 		    N_("number of submodules fetched in parallel")),
 	OPT_BOOL('p', "prune", &prune,
 		 N_("prune remote-tracking branches no longer on remote")),
@@ -174,7 +192,15 @@ static struct option builtin_fetch_optio
 			TRANSPORT_FAMILY_IPV4),
 	OPT_SET_INT('6', "ipv6", &family, N_("use IPv6 addresses only"),
 			TRANSPORT_FAMILY_IPV6),
+	OPT_STRING_LIST(0, "negotiation-tip", &negotiation_tip, N_("revision"),
+			N_("report that we have only objects reachable from this object")),
 	OPT_PARSE_LIST_OBJECTS_FILTER(&filter_options),
+	OPT_BOOL(0, "auto-gc", &enable_auto_gc,
+		 N_("run 'gc --auto' after fetching")),
+	OPT_BOOL(0, "show-forced-updates", &fetch_show_forced_updates,
+		 N_("check for forced-updates on all updated branches")),
+	OPT_BOOL(0, "write-commit-graph", &fetch_write_commit_graph,
+		 N_("write the commit-graph after fetching")),
 	OPT_END()
 };
 
@@ -231,40 +257,91 @@ static void add_merge_config(struct ref
 	}
 }
 
-static int add_existing(const char *refname, const struct object_id *oid,
-			int flag, void *cbdata)
-{
-	struct string_list *list = (struct string_list *)cbdata;
-	struct string_list_item *item = string_list_insert(list, refname);
-	struct object_id *old_oid = xmalloc(sizeof(*old_oid));
-
-	oidcpy(old_oid, oid);
-	item->util = old_oid;
-	return 0;
-}
-
-static int will_fetch(struct ref **head, const unsigned char *sha1)
+static void create_fetch_oidset(struct ref **head, struct oidset *out)
 {
 	struct ref *rm = *head;
 	while (rm) {
-		if (!hashcmp(rm->old_oid.hash, sha1))
-			return 1;
+		oidset_insert(out, &rm->old_oid);
 		rm = rm->next;
 	}
+}
+
+struct refname_hash_entry {
+	struct hashmap_entry ent;
+	struct object_id oid;
+	int ignore;
+	char refname[FLEX_ARRAY];
+};
+
+static int refname_hash_entry_cmp(const void *hashmap_cmp_fn_data,
+				  const struct hashmap_entry *eptr,
+				  const struct hashmap_entry *entry_or_key,
+				  const void *keydata)
+{
+	const struct refname_hash_entry *e1, *e2;
+
+	e1 = container_of(eptr, const struct refname_hash_entry, ent);
+	e2 = container_of(entry_or_key, const struct refname_hash_entry, ent);
+	return strcmp(e1->refname, keydata ? keydata : e2->refname);
+}
+
+static struct refname_hash_entry *refname_hash_add(struct hashmap *map,
+						   const char *refname,
+						   const struct object_id *oid)
+{
+	struct refname_hash_entry *ent;
+	size_t len = strlen(refname);
+
+	FLEX_ALLOC_MEM(ent, refname, refname, len);
+	hashmap_entry_init(&ent->ent, strhash(refname));
+	oidcpy(&ent->oid, oid);
+	hashmap_add(map, &ent->ent);
+	return ent;
+}
+
+static int add_one_refname(const char *refname,
+			   const struct object_id *oid,
+			   int flag, void *cbdata)
+{
+	struct hashmap *refname_map = cbdata;
+
+	(void) refname_hash_add(refname_map, refname, oid);
 	return 0;
 }
 
-static void find_non_local_tags(struct transport *transport,
-			struct ref **head,
-			struct ref ***tail)
+static void refname_hash_init(struct hashmap *map)
 {
-	struct string_list existing_refs = STRING_LIST_INIT_DUP;
-	struct string_list remote_refs = STRING_LIST_INIT_NODUP;
+	hashmap_init(map, refname_hash_entry_cmp, NULL, 0);
+}
+
+static int refname_hash_exists(struct hashmap *map, const char *refname)
+{
+	return !!hashmap_get_from_hash(map, strhash(refname), refname);
+}
+
+static void clear_item(struct refname_hash_entry *item)
+{
+	item->ignore = 1;
+}
+
+static void find_non_local_tags(const struct ref *refs,
+				struct ref **head,
+				struct ref ***tail)
+{
+	struct hashmap existing_refs;
+	struct hashmap remote_refs;
+	struct oidset fetch_oids = OIDSET_INIT;
+	struct string_list remote_refs_list = STRING_LIST_INIT_NODUP;
+	struct string_list_item *remote_ref_item;
 	const struct ref *ref;
-	struct string_list_item *item = NULL;
+	struct refname_hash_entry *item = NULL;
+
+	refname_hash_init(&existing_refs);
+	refname_hash_init(&remote_refs);
+	create_fetch_oidset(head, &fetch_oids);
 
-	for_each_ref(add_existing, &existing_refs);
-	for (ref = transport_get_remote_refs(transport, NULL); ref; ref = ref->next) {
+	for_each_ref(add_one_refname, &existing_refs);
+	for (ref = refs; ref; ref = ref->next) {
 		if (!starts_with(ref->name, "refs/tags/"))
 			continue;
 
@@ -278,11 +355,10 @@ static void find_non_local_tags(struct t
 			if (item &&
 			    !has_object_file_with_flags(&ref->old_oid,
 							OBJECT_INFO_QUICK) &&
-			    !will_fetch(head, ref->old_oid.hash) &&
-			    !has_sha1_file_with_flags(item->util,
-						      OBJECT_INFO_QUICK) &&
-			    !will_fetch(head, item->util))
-				item->util = NULL;
+			    !oidset_contains(&fetch_oids, &ref->old_oid) &&
+			    !has_object_file_with_flags(&item->oid, OBJECT_INFO_QUICK) &&
+			    !oidset_contains(&fetch_oids, &item->oid))
+				clear_item(item);
 			item = NULL;
 			continue;
 		}
@@ -294,51 +370,62 @@ static void find_non_local_tags(struct t
 		 * fetch.
 		 */
 		if (item &&
-		    !has_sha1_file_with_flags(item->util, OBJECT_INFO_QUICK) &&
-		    !will_fetch(head, item->util))
-			item->util = NULL;
+		    !has_object_file_with_flags(&item->oid, OBJECT_INFO_QUICK) &&
+		    !oidset_contains(&fetch_oids, &item->oid))
+			clear_item(item);
 
 		item = NULL;
 
 		/* skip duplicates and refs that we already have */
-		if (string_list_has_string(&remote_refs, ref->name) ||
-		    string_list_has_string(&existing_refs, ref->name))
+		if (refname_hash_exists(&remote_refs, ref->name) ||
+		    refname_hash_exists(&existing_refs, ref->name))
 			continue;
 
-		item = string_list_insert(&remote_refs, ref->name);
-		item->util = (void *)&ref->old_oid;
+		item = refname_hash_add(&remote_refs, ref->name, &ref->old_oid);
+		string_list_insert(&remote_refs_list, ref->name);
 	}
-	string_list_clear(&existing_refs, 1);
+	hashmap_free_entries(&existing_refs, struct refname_hash_entry, ent);
 
 	/*
 	 * We may have a final lightweight tag that needs to be
 	 * checked to see if it needs fetching.
 	 */
 	if (item &&
-	    !has_sha1_file_with_flags(item->util, OBJECT_INFO_QUICK) &&
-	    !will_fetch(head, item->util))
-		item->util = NULL;
+	    !has_object_file_with_flags(&item->oid, OBJECT_INFO_QUICK) &&
+	    !oidset_contains(&fetch_oids, &item->oid))
+		clear_item(item);
 
 	/*
-	 * For all the tags in the remote_refs string list,
+	 * For all the tags in the remote_refs_list,
 	 * add them to the list of refs to be fetched
 	 */
-	for_each_string_list_item(item, &remote_refs) {
+	for_each_string_list_item(remote_ref_item, &remote_refs_list) {
+		const char *refname = remote_ref_item->string;
+		struct ref *rm;
+		unsigned int hash = strhash(refname);
+
+		item = hashmap_get_entry_from_hash(&remote_refs, hash, refname,
+					struct refname_hash_entry, ent);
+		if (!item)
+			BUG("unseen remote ref?");
+
 		/* Unless we have already decided to ignore this item... */
-		if (item->util)
-		{
-			struct ref *rm = alloc_ref(item->string);
-			rm->peer_ref = alloc_ref(item->string);
-			oidcpy(&rm->old_oid, item->util);
-			**tail = rm;
-			*tail = &rm->next;
-		}
-	}
+		if (item->ignore)
+			continue;
 
-	string_list_clear(&remote_refs, 0);
+		rm = alloc_ref(item->refname);
+		rm->peer_ref = alloc_ref(item->refname);
+		oidcpy(&rm->old_oid, &item->oid);
+		**tail = rm;
+		*tail = &rm->next;
+	}
+	hashmap_free_entries(&remote_refs, struct refname_hash_entry, ent);
+	string_list_clear(&remote_refs_list, 0);
+	oidset_clear(&fetch_oids);
 }
 
-static struct ref *get_ref_map(struct transport *transport,
+static struct ref *get_ref_map(struct remote *remote,
+			       const struct ref *remote_refs,
 			       struct refspec *rs,
 			       int tags, int *autotags)
 {
@@ -346,26 +433,11 @@ static struct ref *get_ref_map(struct tr
 	struct ref *rm;
 	struct ref *ref_map = NULL;
 	struct ref **tail = &ref_map;
-	struct argv_array ref_prefixes = ARGV_ARRAY_INIT;
 
 	/* opportunistically-updated references: */
 	struct ref *orefs = NULL, **oref_tail = &orefs;
 
-	const struct ref *remote_refs;
-
-	if (rs->nr)
-		refspec_ref_prefixes(rs, &ref_prefixes);
-	else if (transport->remote && transport->remote->fetch.nr)
-		refspec_ref_prefixes(&transport->remote->fetch, &ref_prefixes);
-
-	if (ref_prefixes.argc &&
-	    (tags == TAGS_SET || (tags == TAGS_DEFAULT && !rs->nr))) {
-		argv_array_push(&ref_prefixes, "refs/tags/");
-	}
-
-	remote_refs = transport_get_remote_refs(transport, &ref_prefixes);
-
-	argv_array_clear(&ref_prefixes);
+	struct hashmap existing_refs;
 
 	if (rs->nr) {
 		struct refspec *fetch_refspec;
@@ -402,7 +474,7 @@ static struct ref *get_ref_map(struct tr
 		if (refmap.nr)
 			fetch_refspec = &refmap;
 		else
-			fetch_refspec = &transport->remote->fetch;
+			fetch_refspec = &remote->fetch;
 
 		for (i = 0; i < fetch_refspec->nr; i++)
 			get_fetch_map(ref_map, &fetch_refspec->items[i], &oref_tail, 1);
@@ -410,7 +482,6 @@ static struct ref *get_ref_map(struct tr
 		die("--refmap option is only meaningful with command-line refspec(s).");
 	} else {
 		/* Use the defaults */
-		struct remote *remote = transport->remote;
 		struct branch *branch = branch_get(NULL);
 		int has_merge = branch_has_merge_config(branch);
 		if (remote &&
@@ -449,7 +520,7 @@ static struct ref *get_ref_map(struct tr
 		/* also fetch all tags */
 		get_fetch_map(remote_refs, tag_refspec, &tail, 0);
 	else if (tags == TAGS_DEFAULT && *autotags)
-		find_non_local_tags(transport, &ref_map, &tail);
+		find_non_local_tags(remote_refs, &ref_map, &tail);
 
 	/* Now append any refs to be updated opportunistically: */
 	*tail = orefs;
@@ -458,7 +529,29 @@ static struct ref *get_ref_map(struct tr
 		tail = &rm->next;
 	}
 
-	return ref_remove_duplicates(ref_map);
+	ref_map = ref_remove_duplicates(ref_map);
+
+	refname_hash_init(&existing_refs);
+	for_each_ref(add_one_refname, &existing_refs);
+
+	for (rm = ref_map; rm; rm = rm->next) {
+		if (rm->peer_ref) {
+			const char *refname = rm->peer_ref->name;
+			struct refname_hash_entry *peer_item;
+			unsigned int hash = strhash(refname);
+
+			peer_item = hashmap_get_entry_from_hash(&existing_refs,
+						hash, refname,
+						struct refname_hash_entry, ent);
+			if (peer_item) {
+				struct object_id *old_oid = &peer_item->oid;
+				oidcpy(&rm->peer_ref->old_oid, old_oid);
+			}
+		}
+	}
+	hashmap_free_entries(&existing_refs, struct refname_hash_entry, ent);
+
+	return ref_map;
 }
 
 #define STORE_REF_ERROR_OTHER 1
@@ -515,7 +608,7 @@ static void adjust_refcol_width(const st
 	int max, rlen, llen, len;
 
 	/* uptodate lines are only shown on high verbosity level */
-	if (!verbosity && !oidcmp(&ref->peer_ref->old_oid, &ref->old_oid))
+	if (!verbosity && oideq(&ref->peer_ref->old_oid, &ref->old_oid))
 		return;
 
 	max    = term_columns();
@@ -580,9 +673,14 @@ static int find_and_replace(struct strbu
 			    const char *needle,
 			    const char *placeholder)
 {
-	const char *p = strstr(haystack->buf, needle);
+	const char *p = NULL;
 	int plen, nlen;
 
+	nlen = strlen(needle);
+	if (ends_with(haystack->buf, needle))
+		p = haystack->buf + haystack->len - nlen;
+	else
+		p = strstr(haystack->buf, needle);
 	if (!p)
 		return 0;
 
@@ -590,7 +688,6 @@ static int find_and_replace(struct strbu
 		return 0;
 
 	plen = strlen(p);
-	nlen = strlen(needle);
 	if (plen > nlen && p[nlen] != '/')
 		return 0;
 
@@ -647,12 +744,13 @@ static int update_local_ref(struct ref *
 	enum object_type type;
 	struct branch *current_branch = branch_get(NULL);
 	const char *pretty_ref = prettify_refname(ref->name);
+	int fast_forward = 0;
 
 	type = oid_object_info(the_repository, &ref->new_oid, NULL);
 	if (type < 0)
 		die(_("object %s not found"), oid_to_hex(&ref->new_oid));
 
-	if (!oidcmp(&ref->old_oid, &ref->new_oid)) {
+	if (oideq(&ref->old_oid, &ref->new_oid)) {
 		if (verbosity > 0)
 			format_display(display, '=', _("[up to date]"), NULL,
 				       remote, pretty_ref, summary_width);
@@ -675,16 +773,24 @@ static int update_local_ref(struct ref *
 
 	if (!is_null_oid(&ref->old_oid) &&
 	    starts_with(ref->name, "refs/tags/")) {
-		int r;
-		r = s_update_ref("updating tag", ref, 0);
-		format_display(display, r ? '!' : 't', _("[tag update]"),
-			       r ? _("unable to update local ref") : NULL,
-			       remote, pretty_ref, summary_width);
-		return r;
+		if (force || ref->force) {
+			int r;
+			r = s_update_ref("updating tag", ref, 0);
+			format_display(display, r ? '!' : 't', _("[tag update]"),
+				       r ? _("unable to update local ref") : NULL,
+				       remote, pretty_ref, summary_width);
+			return r;
+		} else {
+			format_display(display, '!', _("[rejected]"), _("would clobber existing tag"),
+				       remote, pretty_ref, summary_width);
+			return 1;
+		}
 	}
 
-	current = lookup_commit_reference_gently(&ref->old_oid, 1);
-	updated = lookup_commit_reference_gently(&ref->new_oid, 1);
+	current = lookup_commit_reference_gently(the_repository,
+						 &ref->old_oid, 1);
+	updated = lookup_commit_reference_gently(the_repository,
+						 &ref->new_oid, 1);
 	if (!current || !updated) {
 		const char *msg;
 		const char *what;
@@ -706,9 +812,6 @@ static int update_local_ref(struct ref *
 			what = _("[new ref]");
 		}
 
-		if ((recurse_submodules != RECURSE_SUBMODULES_OFF) &&
-		    (recurse_submodules != RECURSE_SUBMODULES_ON))
-			check_for_new_submodule_commits(&ref->new_oid);
 		r = s_update_ref(msg, ref, 0);
 		format_display(display, r ? '!' : '*', what,
 			       r ? _("unable to update local ref") : NULL,
@@ -716,15 +819,21 @@ static int update_local_ref(struct ref *
 		return r;
 	}
 
-	if (in_merge_bases(current, updated)) {
+	if (fetch_show_forced_updates) {
+		uint64_t t_before = getnanotime();
+		fast_forward = in_merge_bases(current, updated);
+		forced_updates_ms += (getnanotime() - t_before) / 1000000;
+	} else {
+		fast_forward = 1;
+	}
+
+	if (fast_forward) {
 		struct strbuf quickref = STRBUF_INIT;
 		int r;
+
 		strbuf_add_unique_abbrev(&quickref, &current->object.oid, DEFAULT_ABBREV);
 		strbuf_addstr(&quickref, "..");
 		strbuf_add_unique_abbrev(&quickref, &ref->new_oid, DEFAULT_ABBREV);
-		if ((recurse_submodules != RECURSE_SUBMODULES_OFF) &&
-		    (recurse_submodules != RECURSE_SUBMODULES_ON))
-			check_for_new_submodule_commits(&ref->new_oid);
 		r = s_update_ref("fast-forward", ref, 1);
 		format_display(display, r ? '!' : ' ', quickref.buf,
 			       r ? _("unable to update local ref") : NULL,
@@ -737,9 +846,6 @@ static int update_local_ref(struct ref *
 		strbuf_add_unique_abbrev(&quickref, &current->object.oid, DEFAULT_ABBREV);
 		strbuf_addstr(&quickref, "...");
 		strbuf_add_unique_abbrev(&quickref, &ref->new_oid, DEFAULT_ABBREV);
-		if ((recurse_submodules != RECURSE_SUBMODULES_OFF) &&
-		    (recurse_submodules != RECURSE_SUBMODULES_ON))
-			check_for_new_submodule_commits(&ref->new_oid);
 		r = s_update_ref("forced-update", ref, 1);
 		format_display(display, r ? '!' : '+', quickref.buf,
 			       r ? _("unable to update local ref") : _("forced update"),
@@ -767,8 +873,17 @@ static int iterate_ref_map(void *cb_data
 	return 0;
 }
 
+static const char warn_show_forced_updates[] =
+N_("Fetch normally indicates which branches had a forced update,\n"
+   "but that check has been disabled. To re-enable, use '--show-forced-updates'\n"
+   "flag or run 'git config fetch.showForcedUpdates true'.");
+static const char warn_time_show_forced_updates[] =
+N_("It took %.2f seconds to check forced updates. You can use\n"
+   "'--no-show-forced-updates' or run 'git config fetch.showForcedUpdates false'\n"
+   " to avoid this check.\n");
+
 static int store_updated_refs(const char *raw_url, const char *remote_name,
-		struct ref *ref_map)
+			      int connectivity_checked, struct ref *ref_map)
 {
 	FILE *fp;
 	struct commit *commit;
@@ -777,7 +892,7 @@ static int store_updated_refs(const char
 	const char *what, *kind;
 	struct ref *rm;
 	char *url;
-	const char *filename = dry_run ? "/dev/null" : git_path_fetch_head();
+	const char *filename = dry_run ? "/dev/null" : git_path_fetch_head(the_repository);
 	int want_status;
 	int summary_width = transport_summary_width(ref_map);
 
@@ -790,10 +905,12 @@ static int store_updated_refs(const char
 	else
 		url = xstrdup("foreign");
 
-	rm = ref_map;
-	if (check_connected(iterate_ref_map, &rm, NULL)) {
-		rc = error(_("%s did not send all necessary objects\n"), url);
-		goto abort;
+	if (!connectivity_checked) {
+		rm = ref_map;
+		if (check_connected(iterate_ref_map, &rm, NULL)) {
+			rc = error(_("%s did not send all necessary objects\n"), url);
+			goto abort;
+		}
 	}
 
 	prepare_format_display(ref_map);
@@ -817,7 +934,8 @@ static int store_updated_refs(const char
 				continue;
 			}
 
-			commit = lookup_commit_reference_gently(&rm->old_oid,
+			commit = lookup_commit_reference_gently(the_repository,
+								&rm->old_oid,
 								1);
 			if (!commit)
 				rm->fetch_head_status = FETCH_HEAD_NOT_FOR_MERGE;
@@ -832,23 +950,19 @@ static int store_updated_refs(const char
 				ref->force = rm->peer_ref->force;
 			}
 
+			if (recurse_submodules != RECURSE_SUBMODULES_OFF)
+				check_for_new_submodule_commits(&rm->old_oid);
 
 			if (!strcmp(rm->name, "HEAD")) {
 				kind = "";
 				what = "";
 			}
-			else if (starts_with(rm->name, "refs/heads/")) {
+			else if (skip_prefix(rm->name, "refs/heads/", &what))
 				kind = "branch";
-				what = rm->name + 11;
-			}
-			else if (starts_with(rm->name, "refs/tags/")) {
+			else if (skip_prefix(rm->name, "refs/tags/", &what))
 				kind = "tag";
-				what = rm->name + 10;
-			}
-			else if (starts_with(rm->name, "refs/remotes/")) {
+			else if (skip_prefix(rm->name, "refs/remotes/", &what))
 				kind = "remote-tracking branch";
-				what = rm->name + 13;
-			}
 			else {
 				kind = "";
 				what = rm->name;
@@ -915,6 +1029,15 @@ static int store_updated_refs(const char
 		      " 'git remote prune %s' to remove any old, conflicting "
 		      "branches"), remote_name);
 
+	if (advice_fetch_show_forced_updates) {
+		if (!fetch_show_forced_updates) {
+			warning(_(warn_show_forced_updates));
+		} else if (forced_updates_ms > FORCED_UPDATES_DELAY_WARNING_IN_MS) {
+			warning(_(warn_time_show_forced_updates),
+				forced_updates_ms / 1000.0);
+		}
+	}
+
  abort:
 	strbuf_release(&note);
 	free(url);
@@ -927,10 +1050,11 @@ static int store_updated_refs(const char
  * everything we are going to fetch already exists and is connected
  * locally.
  */
-static int quickfetch(struct ref *ref_map)
+static int check_exist_and_connected(struct ref *ref_map)
 {
 	struct ref *rm = ref_map;
 	struct check_connected_options opt = CHECK_CONNECTED_INIT;
+	struct ref *r;
 
 	/*
 	 * If we are deepening a shallow clone we already have these
@@ -941,23 +1065,55 @@ static int quickfetch(struct ref *ref_ma
 	 */
 	if (deepen)
 		return -1;
+
+	/*
+	 * check_connected() allows objects to merely be promised, but
+	 * we need all direct targets to exist.
+	 */
+	for (r = rm; r; r = r->next) {
+		if (!has_object_file_with_flags(&r->old_oid,
+						OBJECT_INFO_SKIP_FETCH_OBJECT))
+			return -1;
+	}
+
 	opt.quiet = 1;
 	return check_connected(iterate_ref_map, &rm, &opt);
 }
 
 static int fetch_refs(struct transport *transport, struct ref *ref_map)
 {
-	int ret = quickfetch(ref_map);
-	if (ret)
+	int ret = check_exist_and_connected(ref_map);
+	if (ret) {
+		trace2_region_enter("fetch", "fetch_refs", the_repository);
 		ret = transport_fetch_refs(transport, ref_map);
+		trace2_region_leave("fetch", "fetch_refs", the_repository);
+	}
 	if (!ret)
-		ret |= store_updated_refs(transport->url,
-				transport->remote->name,
-				ref_map);
+		/*
+		 * Keep the new pack's ".keep" file around to allow the caller
+		 * time to update refs to reference the new objects.
+		 */
+		return 0;
 	transport_unlock_pack(transport);
 	return ret;
 }
 
+/* Update local refs based on the ref values fetched from a remote */
+static int consume_refs(struct transport *transport, struct ref *ref_map)
+{
+	int connectivity_checked = transport->smart_options
+		? transport->smart_options->connectivity_checked : 0;
+	int ret;
+	trace2_region_enter("fetch", "consume_refs", the_repository);
+	ret = store_updated_refs(transport->url,
+				 transport->remote->name,
+				 connectivity_checked,
+				 ref_map);
+	transport_unlock_pack(transport);
+	trace2_region_leave("fetch", "consume_refs", the_repository);
+	return ret;
+}
+
 static int prune_refs(struct refspec *rs, struct ref *ref_map,
 		      const char *raw_url)
 {
@@ -1029,7 +1185,7 @@ static void check_not_current_branch(str
 
 static int truncate_fetch_head(void)
 {
-	const char *filename = git_path_fetch_head();
+	const char *filename = git_path_fetch_head(the_repository);
 	FILE *fp = fopen_for_writing(filename);
 
 	if (!fp)
@@ -1049,9 +1205,44 @@ static void set_option(struct transport
 			name, transport->url);
 }
 
+
+static int add_oid(const char *refname, const struct object_id *oid, int flags,
+		   void *cb_data)
+{
+	struct oid_array *oids = cb_data;
+
+	oid_array_append(oids, oid);
+	return 0;
+}
+
+static void add_negotiation_tips(struct git_transport_options *smart_options)
+{
+	struct oid_array *oids = xcalloc(1, sizeof(*oids));
+	int i;
+
+	for (i = 0; i < negotiation_tip.nr; i++) {
+		const char *s = negotiation_tip.items[i].string;
+		int old_nr;
+		if (!has_glob_specials(s)) {
+			struct object_id oid;
+			if (get_oid(s, &oid))
+				die("%s is not a valid object", s);
+			oid_array_append(oids, &oid);
+			continue;
+		}
+		old_nr = oids->nr;
+		for_each_glob_ref(add_oid, s, oids);
+		if (old_nr == oids->nr)
+			warning("Ignoring --negotiation-tip=%s because it does not match any refs",
+				s);
+	}
+	smart_options->negotiation_tips = oids;
+}
+
 static struct transport *prepare_transport(struct remote *remote, int deepen)
 {
 	struct transport *transport;
+
 	transport = transport_get(remote, NULL);
 	transport_set_verbosity(transport, verbosity, progress);
 	transport->family = family;
@@ -1071,10 +1262,17 @@ static struct transport *prepare_transpo
 	if (update_shallow)
 		set_option(transport, TRANS_OPT_UPDATE_SHALLOW, "yes");
 	if (filter_options.choice) {
-		set_option(transport, TRANS_OPT_LIST_OBJECTS_FILTER,
-			   filter_options.filter_spec);
+		const char *spec =
+			expand_list_objects_filter_spec(&filter_options);
+		set_option(transport, TRANS_OPT_LIST_OBJECTS_FILTER, spec);
 		set_option(transport, TRANS_OPT_FROM_PROMISOR, "1");
 	}
+	if (negotiation_tip.nr) {
+		if (transport->smart_options)
+			add_negotiation_tips(transport->smart_options);
+		else
+			warning("Ignoring --negotiation-tip because the protocol does not support it.");
+	}
 	return transport;
 }
 
@@ -1099,7 +1297,8 @@ static void backfill_tags(struct transpo
 	transport_set_option(transport, TRANS_OPT_FOLLOWTAGS, NULL);
 	transport_set_option(transport, TRANS_OPT_DEPTH, "0");
 	transport_set_option(transport, TRANS_OPT_DEEPEN_RELATIVE, NULL);
-	fetch_refs(transport, ref_map);
+	if (!fetch_refs(transport, ref_map))
+		consume_refs(transport, ref_map);
 
 	if (gsecondary) {
 		transport_disconnect(gsecondary);
@@ -1110,13 +1309,12 @@ static void backfill_tags(struct transpo
 static int do_fetch(struct transport *transport,
 		    struct refspec *rs)
 {
-	struct string_list existing_refs = STRING_LIST_INIT_DUP;
 	struct ref *ref_map;
-	struct ref *rm;
 	int autotags = (transport->remote->fetch_tags == 1);
 	int retcode = 0;
-
-	for_each_ref(add_existing, &existing_refs);
+	const struct ref *remote_refs;
+	struct argv_array ref_prefixes = ARGV_ARRAY_INIT;
+	int must_list_refs = 1;
 
 	if (tags == TAGS_DEFAULT) {
 		if (transport->remote->fetch_tags == 2)
@@ -1132,22 +1330,45 @@ static int do_fetch(struct transport *tr
 			goto cleanup;
 	}
 
-	ref_map = get_ref_map(transport, rs, tags, &autotags);
-	if (!update_head_ok)
-		check_not_current_branch(ref_map);
+	if (rs->nr) {
+		int i;
 
-	for (rm = ref_map; rm; rm = rm->next) {
-		if (rm->peer_ref) {
-			struct string_list_item *peer_item =
-				string_list_lookup(&existing_refs,
-						   rm->peer_ref->name);
-			if (peer_item) {
-				struct object_id *old_oid = peer_item->util;
-				oidcpy(&rm->peer_ref->old_oid, old_oid);
+		refspec_ref_prefixes(rs, &ref_prefixes);
+
+		/*
+		 * We can avoid listing refs if all of them are exact
+		 * OIDs
+		 */
+		must_list_refs = 0;
+		for (i = 0; i < rs->nr; i++) {
+			if (!rs->items[i].exact_sha1) {
+				must_list_refs = 1;
+				break;
 			}
 		}
+	} else if (transport->remote && transport->remote->fetch.nr)
+		refspec_ref_prefixes(&transport->remote->fetch, &ref_prefixes);
+
+	if (tags == TAGS_SET || tags == TAGS_DEFAULT) {
+		must_list_refs = 1;
+		if (ref_prefixes.argc)
+			argv_array_push(&ref_prefixes, "refs/tags/");
 	}
 
+	if (must_list_refs) {
+		trace2_region_enter("fetch", "remote_refs", the_repository);
+		remote_refs = transport_get_remote_refs(transport, &ref_prefixes);
+		trace2_region_leave("fetch", "remote_refs", the_repository);
+	} else
+		remote_refs = NULL;
+
+	argv_array_clear(&ref_prefixes);
+
+	ref_map = get_ref_map(transport->remote, remote_refs, rs,
+			      tags, &autotags);
+	if (!update_head_ok)
+		check_not_current_branch(ref_map);
+
 	if (tags == TAGS_DEFAULT && autotags)
 		transport_set_option(transport, TRANS_OPT_FOLLOWTAGS, "1");
 	if (prune) {
@@ -1164,11 +1385,56 @@ static int do_fetch(struct transport *tr
 				   transport->url);
 		}
 	}
-	if (fetch_refs(transport, ref_map)) {
+	if (fetch_refs(transport, ref_map) || consume_refs(transport, ref_map)) {
 		free_refs(ref_map);
 		retcode = 1;
 		goto cleanup;
 	}
+
+	if (set_upstream) {
+		struct branch *branch = branch_get("HEAD");
+		struct ref *rm;
+		struct ref *source_ref = NULL;
+
+		/*
+		 * We're setting the upstream configuration for the
+		 * current branch. The relevant upstream is the
+		 * fetched branch that is meant to be merged with the
+		 * current one, i.e. the one fetched to FETCH_HEAD.
+		 *
+		 * When there are several such branches, consider the
+		 * request ambiguous and err on the safe side by doing
+		 * nothing and just emit a warning.
+		 */
+		for (rm = ref_map; rm; rm = rm->next) {
+			if (!rm->peer_ref) {
+				if (source_ref) {
+					warning(_("multiple branches detected, incompatible with --set-upstream"));
+					goto skip;
+				} else {
+					source_ref = rm;
+				}
+			}
+		}
+		if (source_ref) {
+			if (!strcmp(source_ref->name, "HEAD") ||
+			    starts_with(source_ref->name, "refs/heads/"))
+				install_branch_config(0,
+						      branch->name,
+						      transport->remote->name,
+						      source_ref->name);
+			else if (starts_with(source_ref->name, "refs/remotes/"))
+				warning(_("not setting upstream for a remote remote-tracking branch"));
+			else if (starts_with(source_ref->name, "refs/tags/"))
+				warning(_("not setting upstream for a remote tag"));
+			else
+				warning(_("unknown branch type"));
+		} else {
+			warning(_("no source branch found.\n"
+				"you need to specify exactly one branch with the --set-upstream option."));
+		}
+	}
+ skip:
 	free_refs(ref_map);
 
 	/* if neither --no-tags nor --tags was specified, do automated tag
@@ -1176,14 +1442,13 @@ static int do_fetch(struct transport *tr
 	if (tags == TAGS_DEFAULT && autotags) {
 		struct ref **tail = &ref_map;
 		ref_map = NULL;
-		find_non_local_tags(transport, &ref_map, &tail);
+		find_non_local_tags(remote_refs, &ref_map, &tail);
 		if (ref_map)
 			backfill_tags(transport, ref_map);
 		free_refs(ref_map);
 	}
 
  cleanup:
-	string_list_clear(&existing_refs, 1);
 	return retcode;
 }
 
@@ -1266,7 +1531,62 @@ static void add_options_to_argv(struct a
 
 }
 
-static int fetch_multiple(struct string_list *list)
+/* Fetch multiple remotes in parallel */
+
+struct parallel_fetch_state {
+	const char **argv;
+	struct string_list *remotes;
+	int next, result;
+};
+
+static int fetch_next_remote(struct child_process *cp, struct strbuf *out,
+			     void *cb, void **task_cb)
+{
+	struct parallel_fetch_state *state = cb;
+	char *remote;
+
+	if (state->next < 0 || state->next >= state->remotes->nr)
+		return 0;
+
+	remote = state->remotes->items[state->next++].string;
+	*task_cb = remote;
+
+	argv_array_pushv(&cp->args, state->argv);
+	argv_array_push(&cp->args, remote);
+	cp->git_cmd = 1;
+
+	if (verbosity >= 0)
+		printf(_("Fetching %s\n"), remote);
+
+	return 1;
+}
+
+static int fetch_failed_to_start(struct strbuf *out, void *cb, void *task_cb)
+{
+	struct parallel_fetch_state *state = cb;
+	const char *remote = task_cb;
+
+	state->result = error(_("Could not fetch %s"), remote);
+
+	return 0;
+}
+
+static int fetch_finished(int result, struct strbuf *out,
+			  void *cb, void *task_cb)
+{
+	struct parallel_fetch_state *state = cb;
+	const char *remote = task_cb;
+
+	if (result) {
+		strbuf_addf(out, _("could not fetch '%s' (exit code: %d)\n"),
+			    remote, result);
+		state->result = -1;
+	}
+
+	return 0;
+}
+
+static int fetch_multiple(struct string_list *list, int max_children)
 {
 	int i, result = 0;
 	struct argv_array argv = ARGV_ARRAY_INIT;
@@ -1277,23 +1597,38 @@ static int fetch_multiple(struct string_
 			return errcode;
 	}
 
-	argv_array_pushl(&argv, "fetch", "--append", NULL);
+	argv_array_pushl(&argv, "fetch", "--append", "--no-auto-gc",
+			"--no-write-commit-graph", NULL);
 	add_options_to_argv(&argv);
 
-	for (i = 0; i < list->nr; i++) {
-		const char *name = list->items[i].string;
-		argv_array_push(&argv, name);
-		if (verbosity >= 0)
-			printf(_("Fetching %s\n"), name);
-		if (run_command_v_opt(argv.argv, RUN_GIT_CMD)) {
-			error(_("Could not fetch %s"), name);
-			result = 1;
+	if (max_children != 1 && list->nr != 1) {
+		struct parallel_fetch_state state = { argv.argv, list, 0, 0 };
+
+		argv_array_push(&argv, "--end-of-options");
+		result = run_processes_parallel_tr2(max_children,
+						    &fetch_next_remote,
+						    &fetch_failed_to_start,
+						    &fetch_finished,
+						    &state,
+						    "fetch", "parallel/fetch");
+
+		if (!result)
+			result = state.result;
+	} else
+		for (i = 0; i < list->nr; i++) {
+			const char *name = list->items[i].string;
+			argv_array_push(&argv, name);
+			if (verbosity >= 0)
+				printf(_("Fetching %s\n"), name);
+			if (run_command_v_opt(argv.argv, RUN_GIT_CMD)) {
+				error(_("Could not fetch %s"), name);
+				result = 1;
+			}
+			argv_array_pop(&argv);
 		}
-		argv_array_pop(&argv);
-	}
 
 	argv_array_clear(&argv);
-	return result;
+	return !!result;
 }
 
 /*
@@ -1313,36 +1648,27 @@ static inline void fetch_one_setup_parti
 	 * If no prior partial clone/fetch and the current fetch DID NOT
 	 * request a partial-fetch, do a normal fetch.
 	 */
-	if (!repository_format_partial_clone && !filter_options.choice)
+	if (!has_promisor_remote() && !filter_options.choice)
 		return;
 
 	/*
-	 * If this is the FIRST partial-fetch request, we enable partial
-	 * on this repo and remember the given filter-spec as the default
-	 * for subsequent fetches to this remote.
+	 * If this is a partial-fetch request, we enable partial on
+	 * this repo if not already enabled and remember the given
+	 * filter-spec as the default for subsequent fetches to this
+	 * remote.
 	 */
-	if (!repository_format_partial_clone && filter_options.choice) {
+	if (filter_options.choice) {
 		partial_clone_register(remote->name, &filter_options);
 		return;
 	}
 
 	/*
-	 * We are currently limited to only ONE promisor remote and only
-	 * allow partial-fetches from the promisor remote.
-	 */
-	if (strcmp(remote->name, repository_format_partial_clone)) {
-		if (filter_options.choice)
-			die(_("--filter can only be used with the remote configured in core.partialClone"));
-		return;
-	}
-
-	/*
 	 * Do a partial-fetch from the promisor remote using either the
 	 * explicitly given filter-spec or inherit the filter-spec from
 	 * the config.
 	 */
 	if (!filter_options.choice)
-		partial_clone_get_default_filter_spec(&filter_options);
+		partial_clone_get_default_filter_spec(&filter_options, remote->name);
 	return;
 }
 
@@ -1408,7 +1734,9 @@ static int fetch_one(struct remote *remo
 
 	sigchain_push_common(unlock_pack_on_signal);
 	atexit(unlock_pack);
+	sigchain_push(SIGPIPE, SIG_IGN);
 	exit_code = do_fetch(gtransport, &rs);
+	sigchain_pop(SIGPIPE);
 	refspec_clear(&rs);
 	transport_disconnect(gtransport);
 	gtransport = NULL;
@@ -1426,14 +1754,13 @@ int cmd_fetch(int argc, const char **arg
 
 	packet_trace_identity("fetch");
 
-	fetch_if_missing = 0;
-
 	/* Record the command line for the reflog */
 	strbuf_addstr(&default_rla, "fetch");
 	for (i = 1; i < argc; i++)
 		strbuf_addf(&default_rla, " %s", argv[i]);
 
-	config_from_gitmodules(gitmodules_fetch_config, NULL);
+	fetch_config_from_gitmodules(&submodule_fetch_jobs_config,
+				     &recurse_submodules);
 	git_config(git_fetch_config, NULL);
 
 	argc = parse_options(argc, argv, prefix,
@@ -1449,7 +1776,7 @@ int cmd_fetch(int argc, const char **arg
 	if (unshallow) {
 		if (depth)
 			die(_("--depth and --unshallow cannot be used together"));
-		else if (!is_repository_shallow())
+		else if (!is_repository_shallow(the_repository))
 			die(_("--unshallow on a complete repository does not make sense"));
 		else
 			depth = xstrfmt("%d", INFINITE_DEPTH);
@@ -1461,7 +1788,7 @@ int cmd_fetch(int argc, const char **arg
 	if (depth || deepen_since || deepen_not.nr)
 		deepen = 1;
 
-	if (filter_options.choice && !repository_format_partial_clone)
+	if (filter_options.choice && !has_promisor_remote())
 		die("--filter can only be used when extensions.partialClone is set");
 
 	if (all) {
@@ -1495,18 +1822,31 @@ int cmd_fetch(int argc, const char **arg
 	}
 
 	if (remote) {
-		if (filter_options.choice || repository_format_partial_clone)
+		if (filter_options.choice || has_promisor_remote())
 			fetch_one_setup_partial(remote);
 		result = fetch_one(remote, argc, argv, prune_tags_ok);
 	} else {
+		int max_children = max_jobs;
+
 		if (filter_options.choice)
-			die(_("--filter can only be used with the remote configured in core.partialClone"));
+			die(_("--filter can only be used with the remote "
+			      "configured in extensions.partialclone"));
+
+		if (max_children < 0)
+			max_children = fetch_parallel_config;
+
 		/* TODO should this also die if we have a previous partial-clone? */
-		result = fetch_multiple(&list);
+		result = fetch_multiple(&list, max_children);
 	}
 
 	if (!result && (recurse_submodules != RECURSE_SUBMODULES_OFF)) {
 		struct argv_array options = ARGV_ARRAY_INIT;
+		int max_children = max_jobs;
+
+		if (max_children < 0)
+			max_children = submodule_fetch_jobs_config;
+		if (max_children < 0)
+			max_children = fetch_parallel_config;
 
 		add_options_to_argv(&options);
 		result = fetch_populated_submodules(the_repository,
@@ -1521,13 +1861,29 @@ int cmd_fetch(int argc, const char **arg
 
 	string_list_clear(&list, 0);
 
-	close_all_packs(the_repository->objects);
-
-	argv_array_pushl(&argv_gc_auto, "gc", "--auto", NULL);
-	if (verbosity < 0)
-		argv_array_push(&argv_gc_auto, "--quiet");
-	run_command_v_opt(argv_gc_auto.argv, RUN_GIT_CMD);
-	argv_array_clear(&argv_gc_auto);
+	prepare_repo_settings(the_repository);
+	if (fetch_write_commit_graph > 0 ||
+	    (fetch_write_commit_graph < 0 &&
+	     the_repository->settings.fetch_write_commit_graph)) {
+		int commit_graph_flags = COMMIT_GRAPH_WRITE_SPLIT;
+
+		if (progress)
+			commit_graph_flags |= COMMIT_GRAPH_WRITE_PROGRESS;
+
+		write_commit_graph_reachable(get_object_directory(),
+					     commit_graph_flags,
+					     NULL);
+	}
+
+	close_object_store(the_repository->objects);
+
+	if (enable_auto_gc) {
+		argv_array_pushl(&argv_gc_auto, "gc", "--auto", NULL);
+		if (verbosity < 0)
+			argv_array_push(&argv_gc_auto, "--quiet");
+		run_command_v_opt(argv_gc_auto.argv, RUN_GIT_CMD);
+		argv_array_clear(&argv_gc_auto);
+	}
 
 	return result;
 }
diff -pruN 1.2.1+git2.18.0-1/git/builtin/fetch-pack.c 1.2.3+git2.25.1-1/git/builtin/fetch-pack.c
--- 1.2.1+git2.18.0-1/git/builtin/fetch-pack.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/builtin/fetch-pack.c	2020-02-17 04:47:35.000000000 +0000
@@ -16,13 +16,14 @@ static void add_sought_entry(struct ref
 {
 	struct ref *ref;
 	struct object_id oid;
+	const char *p;
 
-	if (!get_oid_hex(name, &oid)) {
-		if (name[GIT_SHA1_HEXSZ] == ' ') {
-			/* <sha1> <ref>, find refname */
-			name += GIT_SHA1_HEXSZ + 1;
-		} else if (name[GIT_SHA1_HEXSZ] == '\0') {
-			; /* <sha1>, leave sha1 as name */
+	if (!parse_oid_hex(name, &oid, &p)) {
+		if (*p == ' ') {
+			/* <oid> <ref>, find refname */
+			name = p + 1;
+		} else if (*p == '\0') {
+			; /* <oid>, leave oid as name */
 		} else {
 			/* <ref>, clear cruft from oid */
 			oidclr(&oid);
@@ -54,6 +55,7 @@ int cmd_fetch_pack(int argc, const char
 	struct oid_array shallow = OID_ARRAY_INIT;
 	struct string_list deepen_not = STRING_LIST_INIT_DUP;
 	struct packet_reader reader;
+	enum protocol_version version;
 
 	fetch_if_missing = 0;
 
@@ -216,11 +218,14 @@ int cmd_fetch_pack(int argc, const char
 
 	packet_reader_init(&reader, fd[0], NULL, 0,
 			   PACKET_READ_CHOMP_NEWLINE |
-			   PACKET_READ_GENTLE_ON_EOF);
+			   PACKET_READ_GENTLE_ON_EOF |
+			   PACKET_READ_DIE_ON_ERR_PACKET);
 
-	switch (discover_version(&reader)) {
+	version = discover_version(&reader);
+	switch (version) {
 	case protocol_v2:
-		die("support for protocol v2 not implemented yet");
+		get_remote_refs(fd[1], &reader, &ref, 0, NULL, NULL);
+		break;
 	case protocol_v1:
 	case protocol_v0:
 		get_remote_heads(&reader, &ref, 0, NULL, &shallow);
@@ -229,8 +234,8 @@ int cmd_fetch_pack(int argc, const char
 		BUG("unknown protocol version");
 	}
 
-	ref = fetch_pack(&args, fd, conn, ref, dest, sought, nr_sought,
-			 &shallow, pack_lockfile_ptr, protocol_v0);
+	ref = fetch_pack(&args, fd, ref, sought, nr_sought,
+			 &shallow, pack_lockfile_ptr, version);
 	if (pack_lockfile) {
 		printf("lock %s\n", pack_lockfile);
 		fflush(stdout);
diff -pruN 1.2.1+git2.18.0-1/git/builtin/fmt-merge-msg.c 1.2.3+git2.25.1-1/git/builtin/fmt-merge-msg.c
--- 1.2.1+git2.18.0-1/git/builtin/fmt-merge-msg.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/builtin/fmt-merge-msg.c	2020-02-17 04:47:35.000000000 +0000
@@ -2,6 +2,7 @@
 #include "cache.h"
 #include "config.h"
 #include "refs.h"
+#include "object-store.h"
 #include "commit.h"
 #include "diff.h"
 #include "revision.h"
@@ -10,6 +11,8 @@
 #include "branch.h"
 #include "fmt-merge-msg.h"
 #include "gpg-interface.h"
+#include "repository.h"
+#include "commit-reach.h"
 
 static const char * const fmt_merge_msg_usage[] = {
 	N_("git fmt-merge-msg [-m <message>] [--log[=<n>] | --no-log] [--file <file>]"),
@@ -76,9 +79,9 @@ static struct merge_parent *find_merge_p
 {
 	int i;
 	for (i = 0; i < table->nr; i++) {
-		if (given && oidcmp(&table->item[i].given, given))
+		if (given && !oideq(&table->item[i].given, given))
 			continue;
-		if (commit && oidcmp(&table->item[i].commit, commit))
+		if (commit && !oideq(&table->item[i].commit, commit))
 			continue;
 		return &table->item[i];
 	}
@@ -103,19 +106,20 @@ static int handle_line(char *line, struc
 	int i, len = strlen(line);
 	struct origin_data *origin_data;
 	char *src;
-	const char *origin;
+	const char *origin, *tag_name;
 	struct src_data *src_data;
 	struct string_list_item *item;
 	int pulling_head = 0;
 	struct object_id oid;
+	const unsigned hexsz = the_hash_algo->hexsz;
 
-	if (len < GIT_SHA1_HEXSZ + 3 || line[GIT_SHA1_HEXSZ] != '\t')
+	if (len < hexsz + 3 || line[hexsz] != '\t')
 		return 1;
 
-	if (starts_with(line + GIT_SHA1_HEXSZ + 1, "not-for-merge"))
+	if (starts_with(line + hexsz + 1, "not-for-merge"))
 		return 0;
 
-	if (line[GIT_SHA1_HEXSZ + 1] != '\t')
+	if (line[hexsz + 1] != '\t')
 		return 2;
 
 	i = get_oid_hex(line, &oid);
@@ -130,7 +134,7 @@ static int handle_line(char *line, struc
 
 	if (line[len - 1] == '\n')
 		line[len - 1] = 0;
-	line += GIT_SHA1_HEXSZ + 2;
+	line += hexsz + 2;
 
 	/*
 	 * At this point, line points at the beginning of comment e.g.
@@ -158,14 +162,13 @@ static int handle_line(char *line, struc
 	if (pulling_head) {
 		origin = src;
 		src_data->head_status |= 1;
-	} else if (starts_with(line, "branch ")) {
+	} else if (skip_prefix(line, "branch ", &origin)) {
 		origin_data->is_local_branch = 1;
-		origin = line + 7;
 		string_list_append(&src_data->branch, origin);
 		src_data->head_status |= 2;
-	} else if (starts_with(line, "tag ")) {
+	} else if (skip_prefix(line, "tag ", &tag_name)) {
 		origin = line;
-		string_list_append(&src_data->tag, origin + 4);
+		string_list_append(&src_data->tag, tag_name);
 		src_data->head_status |= 2;
 	} else if (skip_prefix(line, "remote-tracking branch ", &origin)) {
 		string_list_append(&src_data->r_branch, origin);
@@ -342,7 +345,9 @@ static void shortlog(const char *name,
 	const struct object_id *oid = &origin_data->oid;
 	int limit = opts->shortlog_len;
 
-	branch = deref_tag(parse_object(oid), oid_to_hex(oid), GIT_SHA1_HEXSZ);
+	branch = deref_tag(the_repository, parse_object(the_repository, oid),
+			   oid_to_hex(oid),
+			   the_hash_algo->hexsz);
 	if (!branch || branch->type != OBJ_COMMIT)
 		return;
 
@@ -489,6 +494,7 @@ static void fmt_merge_msg_sigs(struct st
 		enum object_type type;
 		unsigned long size, len;
 		char *buf = read_object_file(oid, &type, &size);
+		struct signature_check sigc = { 0 };
 		struct strbuf sig = STRBUF_INIT;
 
 		if (!buf || type != OBJ_TAG)
@@ -497,10 +503,12 @@ static void fmt_merge_msg_sigs(struct st
 
 		if (size == len)
 			; /* merely annotated */
-		else if (verify_signed_buffer(buf, len, buf + len, size - len, &sig, NULL)) {
-			if (!sig.len)
-				strbuf_addstr(&sig, "gpg verification failed.\n");
-		}
+		else if (!check_signature(buf, len, buf + len, size - len,
+					  &sigc)) {
+			strbuf_addstr(&sig, sigc.gpg_output);
+			signature_check_clear(&sigc);
+		} else
+			strbuf_addstr(&sig, "gpg verification failed.\n");
 
 		if (!tag_number++) {
 			fmt_tag_signature(&tagbuf, &sig, buf, len);
@@ -545,6 +553,7 @@ static void find_merge_parents(struct me
 		int len;
 		char *p = in->buf + pos;
 		char *newline = strchr(p, '\n');
+		const char *q;
 		struct object_id oid;
 		struct commit *parent;
 		struct object *obj;
@@ -552,24 +561,23 @@ static void find_merge_parents(struct me
 		len = newline ? newline - p : strlen(p);
 		pos += len + !!newline;
 
-		if (len < GIT_SHA1_HEXSZ + 3 ||
-		    get_oid_hex(p, &oid) ||
-		    p[GIT_SHA1_HEXSZ] != '\t' ||
-		    p[GIT_SHA1_HEXSZ + 1] != '\t')
+		if (parse_oid_hex(p, &oid, &q) ||
+		    q[0] != '\t' ||
+		    q[1] != '\t')
 			continue; /* skip not-for-merge */
 		/*
 		 * Do not use get_merge_parent() here; we do not have
 		 * "name" here and we do not want to contaminate its
 		 * util field yet.
 		 */
-		obj = parse_object(&oid);
+		obj = parse_object(the_repository, &oid);
 		parent = (struct commit *)peel_to_type(NULL, 0, obj, OBJ_COMMIT);
 		if (!parent)
 			continue;
 		commit_list_insert(parent, &parents);
 		add_merge_parent(result, &obj->oid, &parent->object.oid);
 	}
-	head_commit = lookup_commit(head);
+	head_commit = lookup_commit(the_repository, head);
 	if (head_commit)
 		commit_list_insert(head_commit, &parents);
 	reduce_heads_replace(&parents);
@@ -577,7 +585,7 @@ static void find_merge_parents(struct me
 	while (parents) {
 		struct commit *cmit = pop_commit(&parents);
 		for (i = 0; i < result->nr; i++)
-			if (!oidcmp(&result->item[i].commit, &cmit->object.oid))
+			if (oideq(&result->item[i].commit, &cmit->object.oid))
 				result->item[i].used = 1;
 	}
 
@@ -623,7 +631,7 @@ int fmt_merge_msg(struct strbuf *in, str
 		i++;
 		p[len] = 0;
 		if (handle_line(p, &merge_parents))
-			die ("Error in line %d: %.*s", i, len, p);
+			die("error in line %d: %.*s", i, len, p);
 	}
 
 	if (opts->add_title && srcs.nr)
@@ -637,7 +645,7 @@ int fmt_merge_msg(struct strbuf *in, str
 		struct rev_info rev;
 
 		head = lookup_commit_or_die(&head_oid, "HEAD");
-		init_revisions(&rev, NULL);
+		repo_init_revisions(the_repository, &rev, NULL);
 		rev.commit_format = CMIT_FMT_ONELINE;
 		rev.ignore_merges = 1;
 		rev.limited = 1;
diff -pruN 1.2.1+git2.18.0-1/git/builtin/for-each-ref.c 1.2.3+git2.25.1-1/git/builtin/for-each-ref.c
--- 1.2.1+git2.18.0-1/git/builtin/for-each-ref.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/builtin/for-each-ref.c	2020-02-17 04:47:35.000000000 +0000
@@ -37,8 +37,7 @@ int cmd_for_each_ref(int argc, const cha
 		OPT_INTEGER( 0 , "count", &maxcount, N_("show only <n> matched refs")),
 		OPT_STRING(  0 , "format", &format.format, N_("format"), N_("format to use for the output")),
 		OPT__COLOR(&format.use_color, N_("respect format colors")),
-		OPT_CALLBACK(0 , "sort", sorting_tail, N_("key"),
-			    N_("field name to sort on"), &parse_opt_ref_sorting),
+		OPT_REF_SORT(sorting_tail),
 		OPT_CALLBACK(0, "points-at", &filter.points_at,
 			     N_("object"), N_("print only refs which points at the given object"),
 			     parse_opt_object_name),
diff -pruN 1.2.1+git2.18.0-1/git/builtin/fsck.c 1.2.3+git2.25.1-1/git/builtin/fsck.c
--- 1.2.1+git2.18.0-1/git/builtin/fsck.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/builtin/fsck.c	2020-02-17 04:47:35.000000000 +0000
@@ -1,3 +1,4 @@
+#define USE_THE_INDEX_COMPATIBILITY_MACROS
 #include "builtin.h"
 #include "cache.h"
 #include "repository.h"
@@ -18,6 +19,8 @@
 #include "decorate.h"
 #include "packfile.h"
 #include "object-store.h"
+#include "run-command.h"
+#include "worktree.h"
 
 #define REACHABLE 0x0001
 #define SEEN      0x0002
@@ -35,8 +38,6 @@ static int check_strict;
 static int keep_cache_objects;
 static struct fsck_options fsck_walk_options = FSCK_OPTIONS_DEFAULT;
 static struct fsck_options fsck_obj_options = FSCK_OPTIONS_DEFAULT;
-static struct object_id head_oid;
-static const char *head_points_at;
 static int errors_found;
 static int write_lost_and_found;
 static int verbose;
@@ -47,35 +48,24 @@ static int name_objects;
 #define ERROR_REACHABLE 02
 #define ERROR_PACK 04
 #define ERROR_REFS 010
+#define ERROR_COMMIT_GRAPH 020
 
-static const char *describe_object(struct object *obj)
+static const char *describe_object(const struct object_id *oid)
 {
-	static struct strbuf buf = STRBUF_INIT;
-	char *name = name_objects ?
-		lookup_decoration(fsck_walk_options.object_names, obj) : NULL;
-
-	strbuf_reset(&buf);
-	strbuf_addstr(&buf, oid_to_hex(&obj->oid));
-	if (name)
-		strbuf_addf(&buf, " (%s)", name);
-
-	return buf.buf;
+	return fsck_describe_object(&fsck_walk_options, oid);
 }
 
-static const char *printable_type(struct object *obj)
+static const char *printable_type(const struct object_id *oid,
+				  enum object_type type)
 {
 	const char *ret;
 
-	if (obj->type == OBJ_NONE) {
-		enum object_type type = oid_object_info(the_repository,
-							&obj->oid, NULL);
-		if (type > 0)
-			object_as_type(obj, type, 0);
-	}
+	if (type == OBJ_NONE)
+		type = oid_object_info(the_repository, oid, NULL);
 
-	ret = type_name(obj->type);
+	ret = type_name(type);
 	if (!ret)
-		ret = "unknown";
+		ret = _("unknown");
 
 	return ret;
 }
@@ -103,25 +93,38 @@ static int fsck_config(const char *var,
 	return git_default_config(var, value, cb);
 }
 
-static void objreport(struct object *obj, const char *msg_type,
-			const char *err)
-{
-	fprintf(stderr, "%s in %s %s: %s\n",
-		msg_type, printable_type(obj), describe_object(obj), err);
-}
-
 static int objerror(struct object *obj, const char *err)
 {
 	errors_found |= ERROR_OBJECT;
-	objreport(obj, "error", err);
+	/* TRANSLATORS: e.g. error in tree 01bfda: <more explanation> */
+	fprintf_ln(stderr, _("error in %s %s: %s"),
+		   printable_type(&obj->oid, obj->type),
+		   describe_object(&obj->oid), err);
 	return -1;
 }
 
 static int fsck_error_func(struct fsck_options *o,
-	struct object *obj, int type, const char *message)
-{
-	objreport(obj, (type == FSCK_WARN) ? "warning" : "error", message);
-	return (type == FSCK_WARN) ? 0 : 1;
+			   const struct object_id *oid,
+			   enum object_type object_type,
+			   int msg_type, const char *message)
+{
+	switch (msg_type) {
+	case FSCK_WARN:
+		/* TRANSLATORS: e.g. warning in tree 01bfda: <more explanation> */
+		fprintf_ln(stderr, _("warning in %s %s: %s"),
+			   printable_type(oid, object_type),
+			   describe_object(oid), message);
+		return 0;
+	case FSCK_ERROR:
+		/* TRANSLATORS: e.g. error in tree 01bfda: <more explanation> */
+		fprintf_ln(stderr, _("error in %s %s: %s"),
+			   printable_type(oid, object_type),
+			   describe_object(oid), message);
+		return 1;
+	default:
+		BUG("%d (FSCK_IGNORE?) should never trigger this callback",
+		    msg_type);
+	}
 }
 
 static struct object_array pending;
@@ -137,17 +140,19 @@ static int mark_object(struct object *ob
 	 */
 	if (!obj) {
 		/* ... these references to parent->fld are safe here */
-		printf("broken link from %7s %s\n",
-			   printable_type(parent), describe_object(parent));
-		printf("broken link from %7s %s\n",
-			   (type == OBJ_ANY ? "unknown" : type_name(type)), "unknown");
+		printf_ln(_("broken link from %7s %s"),
+			  printable_type(&parent->oid, parent->type),
+			  describe_object(&parent->oid));
+		printf_ln(_("broken link from %7s %s"),
+			  (type == OBJ_ANY ? _("unknown") : type_name(type)),
+			  _("unknown"));
 		errors_found |= ERROR_REACHABLE;
 		return 1;
 	}
 
 	if (type != OBJ_ANY && obj->type != type)
 		/* ... and the reference to parent is safe here */
-		objerror(parent, "wrong object type in link");
+		objerror(parent, _("wrong object type in link"));
 
 	if (obj->flags & REACHABLE)
 		return 0;
@@ -163,10 +168,12 @@ static int mark_object(struct object *ob
 
 	if (!(obj->flags & HAS_OBJ)) {
 		if (parent && !has_object_file(&obj->oid)) {
-			printf("broken link from %7s %s\n",
-				 printable_type(parent), describe_object(parent));
-			printf("              to %7s %s\n",
-				 printable_type(obj), describe_object(obj));
+			printf_ln(_("broken link from %7s %s\n"
+				    "              to %7s %s"),
+				  printable_type(&parent->oid, parent->type),
+				  describe_object(&parent->oid),
+				  printable_type(&obj->oid, obj->type),
+				  describe_object(&obj->oid));
 			errors_found |= ERROR_REACHABLE;
 		}
 		return 1;
@@ -215,6 +222,48 @@ static int mark_used(struct object *obj,
 	return 0;
 }
 
+static void mark_unreachable_referents(const struct object_id *oid)
+{
+	struct fsck_options options = FSCK_OPTIONS_DEFAULT;
+	struct object *obj = lookup_object(the_repository, oid);
+
+	if (!obj || !(obj->flags & HAS_OBJ))
+		return; /* not part of our original set */
+	if (obj->flags & REACHABLE)
+		return; /* reachable objects already traversed */
+
+	/*
+	 * Avoid passing OBJ_NONE to fsck_walk, which will parse the object
+	 * (and we want to avoid parsing blobs).
+	 */
+	if (obj->type == OBJ_NONE) {
+		enum object_type type = oid_object_info(the_repository,
+							&obj->oid, NULL);
+		if (type > 0)
+			object_as_type(the_repository, obj, type, 0);
+	}
+
+	options.walk = mark_used;
+	fsck_walk(obj, NULL, &options);
+}
+
+static int mark_loose_unreachable_referents(const struct object_id *oid,
+					    const char *path,
+					    void *data)
+{
+	mark_unreachable_referents(oid);
+	return 0;
+}
+
+static int mark_packed_unreachable_referents(const struct object_id *oid,
+					     struct packed_git *pack,
+					     uint32_t pos,
+					     void *data)
+{
+	mark_unreachable_referents(oid);
+	return 0;
+}
+
 /*
  * Check a single reachable object
  */
@@ -230,8 +279,9 @@ static void check_reachable_object(struc
 			return;
 		if (has_object_pack(&obj->oid))
 			return; /* it is in pack - forget about it */
-		printf("missing %s %s\n", printable_type(obj),
-			describe_object(obj));
+		printf_ln(_("missing %s %s"),
+			  printable_type(&obj->oid, obj->type),
+			  describe_object(&obj->oid));
 		errors_found |= ERROR_REACHABLE;
 		return;
 	}
@@ -256,8 +306,9 @@ static void check_unreachable_object(str
 	 * since this is something that is prunable.
 	 */
 	if (show_unreachable) {
-		printf("unreachable %s %s\n", printable_type(obj),
-			describe_object(obj));
+		printf_ln(_("unreachable %s %s"),
+			  printable_type(&obj->oid, obj->type),
+			  describe_object(&obj->oid));
 		return;
 	}
 
@@ -275,27 +326,28 @@ static void check_unreachable_object(str
 	 */
 	if (!(obj->flags & USED)) {
 		if (show_dangling)
-			printf("dangling %s %s\n", printable_type(obj),
-			       describe_object(obj));
+			printf_ln(_("dangling %s %s"),
+				  printable_type(&obj->oid, obj->type),
+				  describe_object(&obj->oid));
 		if (write_lost_and_found) {
 			char *filename = git_pathdup("lost-found/%s/%s",
 				obj->type == OBJ_COMMIT ? "commit" : "other",
-				describe_object(obj));
+				describe_object(&obj->oid));
 			FILE *f;
 
 			if (safe_create_leading_directories_const(filename)) {
-				error("Could not create lost-found");
+				error(_("could not create lost-found"));
 				free(filename);
 				return;
 			}
 			f = xfopen(filename, "w");
 			if (obj->type == OBJ_BLOB) {
 				if (stream_blob_to_fd(fileno(f), &obj->oid, NULL, 1))
-					die_errno("Could not write '%s'", filename);
+					die_errno(_("could not write '%s'"), filename);
 			} else
-				fprintf(f, "%s\n", describe_object(obj));
+				fprintf(f, "%s\n", describe_object(&obj->oid));
 			if (fclose(f))
-				die_errno("Could not finish '%s'",
+				die_errno(_("could not finish '%s'"),
 					  filename);
 			free(filename);
 		}
@@ -312,7 +364,7 @@ static void check_unreachable_object(str
 static void check_object(struct object *obj)
 {
 	if (verbose)
-		fprintf(stderr, "Checking %s\n", describe_object(obj));
+		fprintf_ln(stderr, _("Checking %s"), describe_object(&obj->oid));
 
 	if (obj->flags & REACHABLE)
 		check_reachable_object(obj);
@@ -327,10 +379,30 @@ static void check_connectivity(void)
 	/* Traverse the pending reachable objects */
 	traverse_reachable();
 
+	/*
+	 * With --connectivity-only, we won't have actually opened and marked
+	 * unreachable objects with USED. Do that now to make --dangling, etc
+	 * accurate.
+	 */
+	if (connectivity_only && (show_dangling || write_lost_and_found)) {
+		/*
+		 * Even though we already have a "struct object" for each of
+		 * these in memory, we must not iterate over the internal
+		 * object hash as we do below. Our loop would potentially
+		 * resize the hash, making our iteration invalid.
+		 *
+		 * Instead, we'll just go back to the source list of objects,
+		 * and ignore any that weren't present in our earlier
+		 * traversal.
+		 */
+		for_each_loose_object(mark_loose_unreachable_referents, NULL, 0);
+		for_each_packed_object(mark_packed_unreachable_referents, NULL, 0);
+	}
+
 	/* Look up all the requirements, warn about missing objects.. */
 	max = get_max_object_index();
 	if (verbose)
-		fprintf(stderr, "Checking connectivity (%d objects)\n", max);
+		fprintf_ln(stderr, _("Checking connectivity (%d objects)"), max);
 
 	for (i = 0; i < max; i++) {
 		struct object *obj = get_indexed_object(i);
@@ -349,11 +421,12 @@ static int fsck_obj(struct object *obj,
 	obj->flags |= SEEN;
 
 	if (verbose)
-		fprintf(stderr, "Checking %s %s\n",
-			printable_type(obj), describe_object(obj));
+		fprintf_ln(stderr, _("Checking %s %s"),
+			   printable_type(&obj->oid, obj->type),
+			   describe_object(&obj->oid));
 
 	if (fsck_walk(obj, NULL, &fsck_obj_options))
-		objerror(obj, "broken links");
+		objerror(obj, _("broken links"));
 	err = fsck_object(obj, buffer, size, &fsck_obj_options);
 	if (err)
 		goto out;
@@ -362,17 +435,19 @@ static int fsck_obj(struct object *obj,
 		struct commit *commit = (struct commit *) obj;
 
 		if (!commit->parents && show_root)
-			printf("root %s\n", describe_object(&commit->object));
+			printf_ln(_("root %s"),
+				  describe_object(&commit->object.oid));
 	}
 
 	if (obj->type == OBJ_TAG) {
 		struct tag *tag = (struct tag *) obj;
 
 		if (show_tags && tag->tagged) {
-			printf("tagged %s %s", printable_type(tag->tagged),
-				describe_object(tag->tagged));
-			printf(" (%s) in %s\n", tag->tag,
-				describe_object(&tag->object));
+			printf_ln(_("tagged %s %s (%s) in %s"),
+				  printable_type(&tag->tagged->oid, tag->tagged->type),
+				  describe_object(&tag->tagged->oid),
+				  tag->tag,
+				  describe_object(&tag->object.oid));
 		}
 	}
 
@@ -380,7 +455,8 @@ out:
 	if (obj->type == OBJ_TREE)
 		free_tree_buffer((struct tree *)obj);
 	if (obj->type == OBJ_COMMIT)
-		free_commit_buffer((struct commit *)obj);
+		free_commit_buffer(the_repository->parsed_objects,
+				   (struct commit *)obj);
 	return err;
 }
 
@@ -392,10 +468,12 @@ static int fsck_obj_buffer(const struct
 	 * verify_packfile(), data_valid variable for details.
 	 */
 	struct object *obj;
-	obj = parse_object_buffer(oid, type, size, buffer, eaten);
+	obj = parse_object_buffer(the_repository, oid, type, size, buffer,
+				  eaten);
 	if (!obj) {
 		errors_found |= ERROR_OBJECT;
-		return error("%s: object corrupt or missing", oid_to_hex(oid));
+		return error(_("%s: object corrupt or missing"),
+			     oid_to_hex(oid));
 	}
 	obj->flags &= ~(REACHABLE | SEEN);
 	obj->flags |= HAS_OBJ;
@@ -410,16 +488,17 @@ static void fsck_handle_reflog_oid(const
 	struct object *obj;
 
 	if (!is_null_oid(oid)) {
-		obj = lookup_object(oid->hash);
+		obj = lookup_object(the_repository, oid);
 		if (obj && (obj->flags & HAS_OBJ)) {
-			if (timestamp && name_objects)
-				add_decoration(fsck_walk_options.object_names,
-					obj,
-					xstrfmt("%s@{%"PRItime"}", refname, timestamp));
+			if (timestamp)
+				fsck_put_object_name(&fsck_walk_options, oid,
+						     "%s@{%"PRItime"}",
+						     refname, timestamp);
 			obj->flags |= USED;
 			mark_object_reachable(obj);
 		} else if (!is_promisor_object(oid)) {
-			error("%s: invalid reflog entry %s", refname, oid_to_hex(oid));
+			error(_("%s: invalid reflog entry %s"),
+			      refname, oid_to_hex(oid));
 			errors_found |= ERROR_REACHABLE;
 		}
 	}
@@ -432,8 +511,8 @@ static int fsck_handle_reflog_ent(struct
 	const char *refname = cb_data;
 
 	if (verbose)
-		fprintf(stderr, "Checking reflog %s->%s\n",
-			oid_to_hex(ooid), oid_to_hex(noid));
+		fprintf_ln(stderr, _("Checking reflog %s->%s"),
+			   oid_to_hex(ooid), oid_to_hex(noid));
 
 	fsck_handle_reflog_oid(refname, ooid, 0);
 	fsck_handle_reflog_oid(refname, noid, timestamp);
@@ -443,7 +522,11 @@ static int fsck_handle_reflog_ent(struct
 static int fsck_handle_reflog(const char *logname, const struct object_id *oid,
 			      int flag, void *cb_data)
 {
-	for_each_reflog_ent(logname, fsck_handle_reflog_ent, (void *)logname);
+	struct strbuf refname = STRBUF_INIT;
+
+	strbuf_worktree_ref(cb_data, &refname, logname);
+	for_each_reflog_ent(refname.buf, fsck_handle_reflog_ent, refname.buf);
+	strbuf_release(&refname);
 	return 0;
 }
 
@@ -452,7 +535,7 @@ static int fsck_handle_ref(const char *r
 {
 	struct object *obj;
 
-	obj = parse_object(oid);
+	obj = parse_object(the_repository, oid);
 	if (!obj) {
 		if (is_promisor_object(oid)) {
 			/*
@@ -462,32 +545,53 @@ static int fsck_handle_ref(const char *r
 			 default_refs++;
 			 return 0;
 		}
-		error("%s: invalid sha1 pointer %s", refname, oid_to_hex(oid));
+		error(_("%s: invalid sha1 pointer %s"),
+		      refname, oid_to_hex(oid));
 		errors_found |= ERROR_REACHABLE;
 		/* We'll continue with the rest despite the error.. */
 		return 0;
 	}
 	if (obj->type != OBJ_COMMIT && is_branch(refname)) {
-		error("%s: not a commit", refname);
+		error(_("%s: not a commit"), refname);
 		errors_found |= ERROR_REFS;
 	}
 	default_refs++;
 	obj->flags |= USED;
-	if (name_objects)
-		add_decoration(fsck_walk_options.object_names,
-			obj, xstrdup(refname));
+	fsck_put_object_name(&fsck_walk_options,
+			     oid, "%s", refname);
 	mark_object_reachable(obj);
 
 	return 0;
 }
 
+static int fsck_head_link(const char *head_ref_name,
+			  const char **head_points_at,
+			  struct object_id *head_oid);
+
 static void get_default_heads(void)
 {
-	if (head_points_at && !is_null_oid(&head_oid))
-		fsck_handle_ref("HEAD", &head_oid, 0, NULL);
+	struct worktree **worktrees, **p;
+	const char *head_points_at;
+	struct object_id head_oid;
+
 	for_each_rawref(fsck_handle_ref, NULL);
-	if (include_reflogs)
-		for_each_reflog(fsck_handle_reflog, NULL);
+
+	worktrees = get_worktrees(0);
+	for (p = worktrees; *p; p++) {
+		struct worktree *wt = *p;
+		struct strbuf ref = STRBUF_INIT;
+
+		strbuf_worktree_ref(wt, &ref, "HEAD");
+		fsck_head_link(ref.buf, &head_points_at, &head_oid);
+		if (head_points_at && !is_null_oid(&head_oid))
+			fsck_handle_ref(ref.buf, &head_oid, 0, NULL);
+		strbuf_release(&ref);
+
+		if (include_reflogs)
+			refs_for_each_reflog(get_worktree_ref_store(wt),
+					     fsck_handle_reflog, wt);
+	}
+	free_worktrees(worktrees);
 
 	/*
 	 * Not having any default heads isn't really fatal, but
@@ -502,7 +606,7 @@ static void get_default_heads(void)
 	 * "show_unreachable" flag.
 	 */
 	if (!default_refs) {
-		fprintf(stderr, "notice: No default references\n");
+		fprintf_ln(stderr, _("notice: No default references"));
 		show_unreachable = 0;
 	}
 }
@@ -517,7 +621,7 @@ static int fsck_loose(const struct objec
 
 	if (read_loose_object(path, oid, &type, &size, &contents) < 0) {
 		errors_found |= ERROR_OBJECT;
-		error("%s: object corrupt or missing: %s",
+		error(_("%s: object corrupt or missing: %s"),
 		      oid_to_hex(oid), path);
 		return 0; /* keep checking other objects */
 	}
@@ -525,10 +629,12 @@ static int fsck_loose(const struct objec
 	if (!contents && type != OBJ_BLOB)
 		BUG("read_loose_object streamed a non-blob");
 
-	obj = parse_object_buffer(oid, type, size, contents, &eaten);
+	obj = parse_object_buffer(the_repository, oid, type, size,
+				  contents, &eaten);
+
 	if (!obj) {
 		errors_found |= ERROR_OBJECT;
-		error("%s: object could not be parsed: %s",
+		error(_("%s: object could not be parsed: %s"),
 		      oid_to_hex(oid), path);
 		if (!eaten)
 			free(contents);
@@ -548,7 +654,7 @@ static int fsck_loose(const struct objec
 static int fsck_cruft(const char *basename, const char *path, void *data)
 {
 	if (!starts_with(basename, "tmp_obj_"))
-		fprintf(stderr, "bad sha1 file: %s\n", path);
+		fprintf_ln(stderr, _("bad sha1 file: %s"), path);
 	return 0;
 }
 
@@ -563,7 +669,7 @@ static void fsck_object_dir(const char *
 	struct progress *progress = NULL;
 
 	if (verbose)
-		fprintf(stderr, "Checking object directory\n");
+		fprintf_ln(stderr, _("Checking object directory"));
 
 	if (show_progress)
 		progress = start_progress(_("Checking object directories"), 256);
@@ -574,33 +680,37 @@ static void fsck_object_dir(const char *
 	stop_progress(&progress);
 }
 
-static int fsck_head_link(void)
+static int fsck_head_link(const char *head_ref_name,
+			  const char **head_points_at,
+			  struct object_id *head_oid)
 {
 	int null_is_error = 0;
 
 	if (verbose)
-		fprintf(stderr, "Checking HEAD link\n");
+		fprintf_ln(stderr, _("Checking %s link"), head_ref_name);
 
-	head_points_at = resolve_ref_unsafe("HEAD", 0, &head_oid, NULL);
-	if (!head_points_at) {
+	*head_points_at = resolve_ref_unsafe(head_ref_name, 0, head_oid, NULL);
+	if (!*head_points_at) {
 		errors_found |= ERROR_REFS;
-		return error("Invalid HEAD");
+		return error(_("invalid %s"), head_ref_name);
 	}
-	if (!strcmp(head_points_at, "HEAD"))
+	if (!strcmp(*head_points_at, head_ref_name))
 		/* detached HEAD */
 		null_is_error = 1;
-	else if (!starts_with(head_points_at, "refs/heads/")) {
+	else if (!starts_with(*head_points_at, "refs/heads/")) {
 		errors_found |= ERROR_REFS;
-		return error("HEAD points to something strange (%s)",
-			     head_points_at);
+		return error(_("%s points to something strange (%s)"),
+			     head_ref_name, *head_points_at);
 	}
-	if (is_null_oid(&head_oid)) {
+	if (is_null_oid(head_oid)) {
 		if (null_is_error) {
 			errors_found |= ERROR_REFS;
-			return error("HEAD: detached HEAD points at nothing");
+			return error(_("%s: detached HEAD points at nothing"),
+				     head_ref_name);
 		}
-		fprintf(stderr, "notice: HEAD points to an unborn branch (%s)\n",
-			head_points_at + 11);
+		fprintf_ln(stderr,
+			   _("notice: %s points to an unborn branch (%s)"),
+			   head_ref_name, *head_points_at + 11);
 	}
 	return 0;
 }
@@ -611,23 +721,21 @@ static int fsck_cache_tree(struct cache_
 	int err = 0;
 
 	if (verbose)
-		fprintf(stderr, "Checking cache tree\n");
+		fprintf_ln(stderr, _("Checking cache tree"));
 
 	if (0 <= it->entry_count) {
-		struct object *obj = parse_object(&it->oid);
+		struct object *obj = parse_object(the_repository, &it->oid);
 		if (!obj) {
-			error("%s: invalid sha1 pointer in cache-tree",
+			error(_("%s: invalid sha1 pointer in cache-tree"),
 			      oid_to_hex(&it->oid));
 			errors_found |= ERROR_REFS;
 			return 1;
 		}
 		obj->flags |= USED;
-		if (name_objects)
-			add_decoration(fsck_walk_options.object_names,
-				obj, xstrdup(":"));
+		fsck_put_object_name(&fsck_walk_options, &it->oid, ":");
 		mark_object_reachable(obj);
 		if (obj->type != OBJ_TREE)
-			err |= objerror(obj, "non-tree in cache-tree");
+			err |= objerror(obj, _("non-tree in cache-tree"));
 	}
 	for (i = 0; i < it->subtree_nr; i++)
 		err |= fsck_cache_tree(it->down[i]->cache_tree);
@@ -636,7 +744,7 @@ static int fsck_cache_tree(struct cache_
 
 static void mark_object_for_connectivity(const struct object_id *oid)
 {
-	struct object *obj = lookup_unknown_object(oid->hash);
+	struct object *obj = lookup_unknown_object(oid);
 	obj->flags |= HAS_OBJ;
 }
 
@@ -683,13 +791,13 @@ static struct option fsck_opts[] = {
 int cmd_fsck(int argc, const char **argv, const char *prefix)
 {
 	int i;
-	struct alternate_object_database *alt;
+	struct object_directory *odb;
 
 	/* fsck knows how to handle missing promisor objects */
 	fetch_if_missing = 0;
 
 	errors_found = 0;
-	check_replace_refs = 0;
+	read_replace_refs = 0;
 
 	argc = parse_options(argc, argv, prefix, fsck_opts, fsck_usage, 0);
 
@@ -710,24 +818,17 @@ int cmd_fsck(int argc, const char **argv
 	}
 
 	if (name_objects)
-		fsck_walk_options.object_names =
-			xcalloc(1, sizeof(struct decoration));
+		fsck_enable_object_names(&fsck_walk_options);
 
 	git_config(fsck_config, NULL);
 
-	fsck_head_link();
 	if (connectivity_only) {
 		for_each_loose_object(mark_loose_for_connectivity, NULL, 0);
 		for_each_packed_object(mark_packed_for_connectivity, NULL, 0);
 	} else {
-		struct alternate_object_database *alt_odb_list;
-
-		fsck_object_dir(get_object_directory());
-
 		prepare_alt_odb(the_repository);
-		alt_odb_list = the_repository->objects->alt_odb_list;
-		for (alt = alt_odb_list; alt; alt = alt->next)
-			fsck_object_dir(alt->path);
+		for (odb = the_repository->objects->odb; odb; odb = odb->next)
+			fsck_object_dir(odb->path);
 
 		if (check_full) {
 			struct packed_git *p;
@@ -735,7 +836,7 @@ int cmd_fsck(int argc, const char **argv
 			struct progress *progress = NULL;
 
 			if (show_progress) {
-				for (p = get_packed_git(the_repository); p;
+				for (p = get_all_packs(the_repository); p;
 				     p = p->next) {
 					if (open_pack_index(p))
 						continue;
@@ -744,10 +845,11 @@ int cmd_fsck(int argc, const char **argv
 
 				progress = start_progress(_("Checking objects"), total);
 			}
-			for (p = get_packed_git(the_repository); p;
+			for (p = get_all_packs(the_repository); p;
 			     p = p->next) {
 				/* verify gives error messages itself */
-				if (verify_pack(p, fsck_obj_buffer,
+				if (verify_pack(the_repository,
+						p, fsck_obj_buffer,
 						progress, count))
 					errors_found |= ERROR_PACK;
 				count += p->num_objects;
@@ -763,24 +865,24 @@ int cmd_fsck(int argc, const char **argv
 		const char *arg = argv[i];
 		struct object_id oid;
 		if (!get_oid(arg, &oid)) {
-			struct object *obj = lookup_object(oid.hash);
+			struct object *obj = lookup_object(the_repository,
+							   &oid);
 
 			if (!obj || !(obj->flags & HAS_OBJ)) {
 				if (is_promisor_object(&oid))
 					continue;
-				error("%s: object missing", oid_to_hex(&oid));
+				error(_("%s: object missing"), oid_to_hex(&oid));
 				errors_found |= ERROR_OBJECT;
 				continue;
 			}
 
 			obj->flags |= USED;
-			if (name_objects)
-				add_decoration(fsck_walk_options.object_names,
-					obj, xstrdup(arg));
+			fsck_put_object_name(&fsck_walk_options, &oid,
+					     "%s", arg);
 			mark_object_reachable(obj);
 			continue;
 		}
-		error("invalid parameter: expected sha1, got '%s'", arg);
+		error(_("invalid parameter: expected sha1, got '%s'"), arg);
 		errors_found |= ERROR_OBJECT;
 	}
 
@@ -806,15 +908,14 @@ int cmd_fsck(int argc, const char **argv
 			mode = active_cache[i]->ce_mode;
 			if (S_ISGITLINK(mode))
 				continue;
-			blob = lookup_blob(&active_cache[i]->oid);
+			blob = lookup_blob(the_repository,
+					   &active_cache[i]->oid);
 			if (!blob)
 				continue;
 			obj = &blob->object;
 			obj->flags |= USED;
-			if (name_objects)
-				add_decoration(fsck_walk_options.object_names,
-					obj,
-					xstrfmt(":%s", active_cache[i]->name));
+			fsck_put_object_name(&fsck_walk_options, &obj->oid,
+					     ":%s", active_cache[i]->name);
 			mark_object_reachable(obj);
 		}
 		if (active_cache_tree)
@@ -822,5 +923,38 @@ int cmd_fsck(int argc, const char **argv
 	}
 
 	check_connectivity();
+
+	if (!git_config_get_bool("core.commitgraph", &i) && i) {
+		struct child_process commit_graph_verify = CHILD_PROCESS_INIT;
+		const char *verify_argv[] = { "commit-graph", "verify", NULL, NULL, NULL };
+
+		prepare_alt_odb(the_repository);
+		for (odb = the_repository->objects->odb; odb; odb = odb->next) {
+			child_process_init(&commit_graph_verify);
+			commit_graph_verify.argv = verify_argv;
+			commit_graph_verify.git_cmd = 1;
+			verify_argv[2] = "--object-dir";
+			verify_argv[3] = odb->path;
+			if (run_command(&commit_graph_verify))
+				errors_found |= ERROR_COMMIT_GRAPH;
+		}
+	}
+
+	if (!git_config_get_bool("core.multipackindex", &i) && i) {
+		struct child_process midx_verify = CHILD_PROCESS_INIT;
+		const char *midx_argv[] = { "multi-pack-index", "verify", NULL, NULL, NULL };
+
+		prepare_alt_odb(the_repository);
+		for (odb = the_repository->objects->odb; odb; odb = odb->next) {
+			child_process_init(&midx_verify);
+			midx_verify.argv = midx_argv;
+			midx_verify.git_cmd = 1;
+			midx_argv[2] = "--object-dir";
+			midx_argv[3] = odb->path;
+			if (run_command(&midx_verify))
+				errors_found |= ERROR_COMMIT_GRAPH;
+		}
+	}
+
 	return errors_found;
 }
diff -pruN 1.2.1+git2.18.0-1/git/builtin/gc.c 1.2.3+git2.25.1-1/git/builtin/gc.c
--- 1.2.1+git2.18.0-1/git/builtin/gc.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/builtin/gc.c	2020-02-17 04:47:35.000000000 +0000
@@ -20,12 +20,14 @@
 #include "sigchain.h"
 #include "argv-array.h"
 #include "commit.h"
+#include "commit-graph.h"
 #include "packfile.h"
 #include "object-store.h"
 #include "pack.h"
 #include "pack-objects.h"
 #include "blob.h"
 #include "tree.h"
+#include "promisor-remote.h"
 
 #define FAILED_RUN "failed to run %s"
 
@@ -114,6 +116,19 @@ static void process_log_file_on_signal(i
 	raise(signo);
 }
 
+static int gc_config_is_timestamp_never(const char *var)
+{
+	const char *value;
+	timestamp_t expire;
+
+	if (!git_config_get_value(var, &value) && value) {
+		if (parse_expiry_date(value, &expire))
+			die(_("failed to parse '%s' value '%s'"), var, value);
+		return expire == 0;
+	}
+	return 0;
+}
+
 static void gc_config(void)
 {
 	const char *value;
@@ -125,6 +140,10 @@ static void gc_config(void)
 			pack_refs = git_config_bool("gc.packrefs", value);
 	}
 
+	if (gc_config_is_timestamp_never("gc.reflogexpire") &&
+	    gc_config_is_timestamp_never("gc.reflogexpireunreachable"))
+		prune_reflogs = 0;
+
 	git_config_get_int("gc.aggressivewindow", &aggressive_window);
 	git_config_get_int("gc.aggressivedepth", &aggressive_depth);
 	git_config_get_int("gc.auto", &gc_auto_threshold);
@@ -153,9 +172,7 @@ static int too_many_loose_objects(void)
 	int auto_threshold;
 	int num_loose = 0;
 	int needed = 0;
-
-	if (gc_auto_threshold <= 0)
-		return 0;
+	const unsigned hexsz_loose = the_hash_algo->hexsz - 2;
 
 	dir = opendir(git_path("objects/17"));
 	if (!dir)
@@ -163,8 +180,8 @@ static int too_many_loose_objects(void)
 
 	auto_threshold = DIV_ROUND_UP(gc_auto_threshold, 256);
 	while ((ent = readdir(dir)) != NULL) {
-		if (strspn(ent->d_name, "0123456789abcdef") != 38 ||
-		    ent->d_name[38] != '\0')
+		if (strspn(ent->d_name, "0123456789abcdef") != hexsz_loose ||
+		    ent->d_name[hexsz_loose] != '\0')
 			continue;
 		if (++num_loose > auto_threshold) {
 			needed = 1;
@@ -180,7 +197,7 @@ static struct packed_git *find_base_pack
 {
 	struct packed_git *p, *base = NULL;
 
-	for (p = get_packed_git(the_repository); p; p = p->next) {
+	for (p = get_all_packs(the_repository); p; p = p->next) {
 		if (!p->pack_local)
 			continue;
 		if (limit) {
@@ -205,7 +222,7 @@ static int too_many_packs(void)
 	if (gc_auto_pack_limit <= 0)
 		return 0;
 
-	for (cnt = 0, p = get_packed_git(the_repository); p; p = p->next) {
+	for (cnt = 0, p = get_all_packs(the_repository); p; p = p->next) {
 		if (!p->pack_local)
 			continue;
 		if (p->pack_keep)
@@ -314,7 +331,7 @@ static void add_repack_all_option(struct
 
 static void add_repack_incremental_option(void)
 {
-       argv_array_push(&repack, "--no-write-bitmap-index");
+	argv_array_push(&repack, "--no-write-bitmap-index");
 }
 
 static int need_to_gc(void)
@@ -438,10 +455,16 @@ static const char *lock_repo_for_gc(int
 	return NULL;
 }
 
+/*
+ * Returns 0 if there was no previous error and gc can proceed, 1 if
+ * gc should not proceed due to an error in the last run. Prints a
+ * message and returns -1 if an error occurred while reading gc.log
+ */
 static int report_last_gc_error(void)
 {
 	struct strbuf sb = STRBUF_INIT;
 	int ret = 0;
+	ssize_t len;
 	struct stat st;
 	char *gc_log_path = git_pathdup("gc.log");
 
@@ -449,39 +472,53 @@ static int report_last_gc_error(void)
 		if (errno == ENOENT)
 			goto done;
 
-		ret = error_errno(_("Can't stat %s"), gc_log_path);
+		ret = error_errno(_("cannot stat '%s'"), gc_log_path);
 		goto done;
 	}
 
 	if (st.st_mtime < gc_log_expire_time)
 		goto done;
 
-	ret = strbuf_read_file(&sb, gc_log_path, 0);
-	if (ret > 0)
-		ret = error(_("The last gc run reported the following. "
+	len = strbuf_read_file(&sb, gc_log_path, 0);
+	if (len < 0)
+		ret = error_errno(_("cannot read '%s'"), gc_log_path);
+	else if (len > 0) {
+		/*
+		 * A previous gc failed.  Report the error, and don't
+		 * bother with an automatic gc run since it is likely
+		 * to fail in the same way.
+		 */
+		warning(_("The last gc run reported the following. "
 			       "Please correct the root cause\n"
 			       "and remove %s.\n"
 			       "Automatic cleanup will not be performed "
 			       "until the file is removed.\n\n"
 			       "%s"),
 			    gc_log_path, sb.buf);
+		ret = 1;
+	}
 	strbuf_release(&sb);
 done:
 	free(gc_log_path);
 	return ret;
 }
 
-static int gc_before_repack(void)
+static void gc_before_repack(void)
 {
+	/*
+	 * We may be called twice, as both the pre- and
+	 * post-daemonized phases will call us, but running these
+	 * commands more than once is pointless and wasteful.
+	 */
+	static int done = 0;
+	if (done++)
+		return;
+
 	if (pack_refs && run_command_v_opt(pack_refs_cmd.argv, RUN_GIT_CMD))
-		return error(FAILED_RUN, pack_refs_cmd.argv[0]);
+		die(FAILED_RUN, pack_refs_cmd.argv[0]);
 
 	if (prune_reflogs && run_command_v_opt(reflog.argv, RUN_GIT_CMD))
-		return error(FAILED_RUN, reflog.argv[0]);
-
-	pack_refs = 0;
-	prune_reflogs = 0;
-	return 0;
+		die(FAILED_RUN, reflog.argv[0]);
 }
 
 int cmd_gc(int argc, const char **argv, const char *prefix)
@@ -562,13 +599,17 @@ int cmd_gc(int argc, const char **argv,
 			fprintf(stderr, _("See \"git help gc\" for manual housekeeping.\n"));
 		}
 		if (detach_auto) {
-			if (report_last_gc_error())
-				return -1;
+			int ret = report_last_gc_error();
+			if (ret < 0)
+				/* an I/O error occurred, already reported */
+				exit(128);
+			if (ret == 1)
+				/* Last gc --auto failed. Skip this one. */
+				return 0;
 
 			if (lock_repo_for_gc(force, &pid))
 				return 0;
-			if (gc_before_repack())
-				return -1;
+			gc_before_repack(); /* dies on failure */
 			delete_tempfile(&pidfile);
 
 			/*
@@ -608,38 +649,46 @@ int cmd_gc(int argc, const char **argv,
 		atexit(process_log_file_at_exit);
 	}
 
-	if (gc_before_repack())
-		return -1;
+	gc_before_repack();
 
 	if (!repository_format_precious_objects) {
+		close_object_store(the_repository->objects);
 		if (run_command_v_opt(repack.argv, RUN_GIT_CMD))
-			return error(FAILED_RUN, repack.argv[0]);
+			die(FAILED_RUN, repack.argv[0]);
 
 		if (prune_expire) {
 			argv_array_push(&prune, prune_expire);
 			if (quiet)
 				argv_array_push(&prune, "--no-progress");
-			if (repository_format_partial_clone)
+			if (has_promisor_remote())
 				argv_array_push(&prune,
 						"--exclude-promisor-objects");
 			if (run_command_v_opt(prune.argv, RUN_GIT_CMD))
-				return error(FAILED_RUN, prune.argv[0]);
+				die(FAILED_RUN, prune.argv[0]);
 		}
 	}
 
 	if (prune_worktrees_expire) {
 		argv_array_push(&prune_worktrees, prune_worktrees_expire);
 		if (run_command_v_opt(prune_worktrees.argv, RUN_GIT_CMD))
-			return error(FAILED_RUN, prune_worktrees.argv[0]);
+			die(FAILED_RUN, prune_worktrees.argv[0]);
 	}
 
 	if (run_command_v_opt(rerere.argv, RUN_GIT_CMD))
-		return error(FAILED_RUN, rerere.argv[0]);
+		die(FAILED_RUN, rerere.argv[0]);
 
 	report_garbage = report_pack_garbage;
 	reprepare_packed_git(the_repository);
-	if (pack_garbage.nr > 0)
+	if (pack_garbage.nr > 0) {
+		close_object_store(the_repository->objects);
 		clean_pack_garbage();
+	}
+
+	prepare_repo_settings(the_repository);
+	if (the_repository->settings.gc_write_commit_graph == 1)
+		write_commit_graph_reachable(get_object_directory(),
+					     !quiet && !daemonized ? COMMIT_GRAPH_WRITE_PROGRESS : 0,
+					     NULL);
 
 	if (auto_gc && too_many_loose_objects())
 		warning(_("There are too many unreachable loose objects; "
diff -pruN 1.2.1+git2.18.0-1/git/builtin/get-tar-commit-id.c 1.2.3+git2.25.1-1/git/builtin/get-tar-commit-id.c
--- 1.2.1+git2.18.0-1/git/builtin/get-tar-commit-id.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/builtin/get-tar-commit-id.c	2020-02-17 04:47:35.000000000 +0000
@@ -21,6 +21,8 @@ int cmd_get_tar_commit_id(int argc, cons
 	char *content = buffer + RECORDSIZE;
 	const char *comment;
 	ssize_t n;
+	long len;
+	char *end;
 
 	if (argc != 1)
 		usage(builtin_get_tar_commit_id_usage);
@@ -32,10 +34,18 @@ int cmd_get_tar_commit_id(int argc, cons
 		die_errno("git get-tar-commit-id: EOF before reading tar header");
 	if (header->typeflag[0] != 'g')
 		return 1;
-	if (!skip_prefix(content, "52 comment=", &comment))
+
+	len = strtol(content, &end, 10);
+	if (errno == ERANGE || end == content || len < 0)
+		return 1;
+	if (!skip_prefix(end, " comment=", &comment))
+		return 1;
+	len -= comment - content;
+	if (len < 1 || !(len % 2) ||
+	    hash_algo_by_length((len - 1) / 2) == GIT_HASH_UNKNOWN)
 		return 1;
 
-	if (write_in_full(1, comment, 41) < 0)
+	if (write_in_full(1, comment, len) < 0)
 		die_errno("git get-tar-commit-id: write error");
 
 	return 0;
diff -pruN 1.2.1+git2.18.0-1/git/builtin/grep.c 1.2.3+git2.25.1-1/git/builtin/grep.c
--- 1.2.1+git2.18.0-1/git/builtin/grep.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/builtin/grep.c	2020-02-17 04:47:35.000000000 +0000
@@ -3,6 +3,7 @@
  *
  * Copyright (c) 2006 Junio C Hamano
  */
+#define USE_THE_INDEX_COMPATIBILITY_MACROS
 #include "cache.h"
 #include "repository.h"
 #include "config.h"
@@ -34,7 +35,6 @@ static int recurse_submodules;
 #define GREP_NUM_THREADS_DEFAULT 8
 static int num_threads;
 
-#ifndef NO_PTHREADS
 static pthread_t *threads;
 
 /* We use one producer thread and THREADS consumer
@@ -70,13 +70,11 @@ static pthread_mutex_t grep_mutex;
 
 static inline void grep_lock(void)
 {
-	assert(num_threads);
 	pthread_mutex_lock(&grep_mutex);
 }
 
 static inline void grep_unlock(void)
 {
-	assert(num_threads);
 	pthread_mutex_unlock(&grep_mutex);
 }
 
@@ -103,7 +101,8 @@ static void add_work(struct grep_opt *op
 
 	todo[todo_end].source = *gs;
 	if (opt->binary != GREP_BINARY_TEXT)
-		grep_source_load_driver(&todo[todo_end].source);
+		grep_source_load_driver(&todo[todo_end].source,
+					opt->repo->index);
 	todo[todo_end].done = 0;
 	strbuf_reset(&todo[todo_end].out);
 	todo_end = (todo_end + 1) % ARRAY_SIZE(todo);
@@ -233,6 +232,9 @@ static int wait_all(void)
 	int hit = 0;
 	int i;
 
+	if (!HAVE_THREADS)
+		BUG("Never call this function unless you have started threads");
+
 	grep_lock();
 	all_work_added = 1;
 
@@ -264,13 +266,6 @@ static int wait_all(void)
 
 	return hit;
 }
-#else /* !NO_PTHREADS */
-
-static int wait_all(void)
-{
-	return 0;
-}
-#endif
 
 static int grep_cmd_config(const char *var, const char *value, void *cb)
 {
@@ -283,17 +278,15 @@ static int grep_cmd_config(const char *v
 		if (num_threads < 0)
 			die(_("invalid number of threads specified (%d) for %s"),
 			    num_threads, var);
-#ifdef NO_PTHREADS
-		else if (num_threads && num_threads != 1) {
+		else if (!HAVE_THREADS && num_threads > 1) {
 			/*
 			 * TRANSLATORS: %s is the configuration
 			 * variable for tweaking threads, currently
 			 * grep.threads
 			 */
 			warning(_("no threads support, ignoring %s"), var);
-			num_threads = 0;
+			num_threads = 1;
 		}
-#endif
 	}
 
 	if (!strcmp(var, "submodule.recurse"))
@@ -329,17 +322,14 @@ static int grep_oid(struct grep_opt *opt
 	grep_source_init(&gs, GREP_SOURCE_OID, pathbuf.buf, path, oid);
 	strbuf_release(&pathbuf);
 
-#ifndef NO_PTHREADS
-	if (num_threads) {
+	if (num_threads > 1) {
 		/*
 		 * add_work() copies gs and thus assumes ownership of
 		 * its fields, so do not call grep_source_clear()
 		 */
 		add_work(opt, &gs);
 		return 0;
-	} else
-#endif
-	{
+	} else {
 		int hit;
 
 		hit = grep_source(opt, &gs);
@@ -362,17 +352,14 @@ static int grep_file(struct grep_opt *op
 	grep_source_init(&gs, GREP_SOURCE_FILE, buf.buf, filename, filename);
 	strbuf_release(&buf);
 
-#ifndef NO_PTHREADS
-	if (num_threads) {
+	if (num_threads > 1) {
 		/*
 		 * add_work() copies gs and thus assumes ownership of
 		 * its fields, so do not call grep_source_clear()
 		 */
 		add_work(opt, &gs);
 		return 0;
-	} else
-#endif
-	{
+	} else {
 		int hit;
 
 		hit = grep_source(opt, &gs);
@@ -407,27 +394,43 @@ static void run_pager(struct grep_opt *o
 		exit(status);
 }
 
-static int grep_cache(struct grep_opt *opt, struct repository *repo,
+static int grep_cache(struct grep_opt *opt,
 		      const struct pathspec *pathspec, int cached);
 static int grep_tree(struct grep_opt *opt, const struct pathspec *pathspec,
 		     struct tree_desc *tree, struct strbuf *base, int tn_len,
-		     int check_attr, struct repository *repo);
+		     int check_attr);
 
-static int grep_submodule(struct grep_opt *opt, struct repository *superproject,
+static int grep_submodule(struct grep_opt *opt,
 			  const struct pathspec *pathspec,
 			  const struct object_id *oid,
-			  const char *filename, const char *path)
+			  const char *filename, const char *path, int cached)
 {
-	struct repository submodule;
+	struct repository subrepo;
+	struct repository *superproject = opt->repo;
+	const struct submodule *sub = submodule_from_path(superproject,
+							  &null_oid, path);
+	struct grep_opt subopt;
 	int hit;
 
-	if (!is_submodule_active(superproject, path))
+	/*
+	 * NEEDSWORK: submodules functions need to be protected because they
+	 * access the object store via config_from_gitmodules(): the latter
+	 * uses get_oid() which, for now, relies on the global the_repository
+	 * object.
+	 */
+	grep_read_lock();
+
+	if (!is_submodule_active(superproject, path)) {
+		grep_read_unlock();
 		return 0;
+	}
 
-	if (repo_submodule_init(&submodule, superproject, path))
+	if (repo_submodule_init(&subrepo, superproject, sub)) {
+		grep_read_unlock();
 		return 0;
+	}
 
-	repo_read_gitmodules(&submodule);
+	repo_read_gitmodules(&subrepo);
 
 	/*
 	 * NEEDSWORK: This adds the submodule's object directory to the list of
@@ -439,10 +442,12 @@ static int grep_submodule(struct grep_op
 	 * store is no longer global and instead is a member of the repository
 	 * object.
 	 */
-	grep_read_lock();
-	add_to_alternates_memory(submodule.objects->objectdir);
+	add_to_alternates_memory(subrepo.objects->odb->path);
 	grep_read_unlock();
 
+	memcpy(&subopt, opt, sizeof(subopt));
+	subopt.repo = &subrepo;
+
 	if (oid) {
 		struct object *object;
 		struct tree_desc tree;
@@ -453,7 +458,8 @@ static int grep_submodule(struct grep_op
 		object = parse_object_or_die(oid, oid_to_hex(oid));
 
 		grep_read_lock();
-		data = read_object_with_reference(&object->oid, tree_type,
+		data = read_object_with_reference(&subrepo,
+						  &object->oid, tree_type,
 						  &size, NULL);
 		grep_read_unlock();
 
@@ -464,21 +470,22 @@ static int grep_submodule(struct grep_op
 		strbuf_addch(&base, '/');
 
 		init_tree_desc(&tree, data, size);
-		hit = grep_tree(opt, pathspec, &tree, &base, base.len,
-				object->type == OBJ_COMMIT, &submodule);
+		hit = grep_tree(&subopt, pathspec, &tree, &base, base.len,
+				object->type == OBJ_COMMIT);
 		strbuf_release(&base);
 		free(data);
 	} else {
-		hit = grep_cache(opt, &submodule, pathspec, 1);
+		hit = grep_cache(&subopt, pathspec, cached);
 	}
 
-	repo_clear(&submodule);
+	repo_clear(&subrepo);
 	return hit;
 }
 
-static int grep_cache(struct grep_opt *opt, struct repository *repo,
+static int grep_cache(struct grep_opt *opt,
 		      const struct pathspec *pathspec, int cached)
 {
+	struct repository *repo = opt->repo;
 	int hit = 0;
 	int nr;
 	struct strbuf name = STRBUF_INIT;
@@ -489,7 +496,7 @@ static int grep_cache(struct grep_opt *o
 	}
 
 	if (repo_read_index(repo) < 0)
-		die("index file corrupt");
+		die(_("index file corrupt"));
 
 	for (nr = 0; nr < repo->index->cache_nr; nr++) {
 		const struct cache_entry *ce = repo->index->cache[nr];
@@ -497,7 +504,7 @@ static int grep_cache(struct grep_opt *o
 		strbuf_addstr(&name, ce->name);
 
 		if (S_ISREG(ce->ce_mode) &&
-		    match_pathspec(pathspec, name.buf, name.len, 0, NULL,
+		    match_pathspec(repo->index, pathspec, name.buf, name.len, 0, NULL,
 				   S_ISDIR(ce->ce_mode) ||
 				   S_ISGITLINK(ce->ce_mode))) {
 			/*
@@ -515,8 +522,9 @@ static int grep_cache(struct grep_opt *o
 				hit |= grep_file(opt, name.buf);
 			}
 		} else if (recurse_submodules && S_ISGITLINK(ce->ce_mode) &&
-			   submodule_path_match(pathspec, name.buf, NULL)) {
-			hit |= grep_submodule(opt, repo, pathspec, NULL, ce->name, ce->name);
+			   submodule_path_match(repo->index, pathspec, name.buf, NULL)) {
+			hit |= grep_submodule(opt, pathspec, NULL, ce->name,
+					      ce->name, cached);
 		} else {
 			continue;
 		}
@@ -538,8 +546,9 @@ static int grep_cache(struct grep_opt *o
 
 static int grep_tree(struct grep_opt *opt, const struct pathspec *pathspec,
 		     struct tree_desc *tree, struct strbuf *base, int tn_len,
-		     int check_attr, struct repository *repo)
+		     int check_attr)
 {
+	struct repository *repo = opt->repo;
 	int hit = 0;
 	enum interesting match = entry_not_interesting;
 	struct name_entry entry;
@@ -556,7 +565,8 @@ static int grep_tree(struct grep_opt *op
 
 		if (match != all_entries_interesting) {
 			strbuf_addstr(&name, base->buf + tn_len);
-			match = tree_entry_interesting(&entry, &name,
+			match = tree_entry_interesting(repo->index,
+						       &entry, &name,
 						       0, pathspec);
 			strbuf_setlen(&name, name_base_len);
 
@@ -569,7 +579,7 @@ static int grep_tree(struct grep_opt *op
 		strbuf_add(base, entry.path, te_len);
 
 		if (S_ISREG(entry.mode)) {
-			hit |= grep_oid(opt, entry.oid, base->buf, tn_len,
+			hit |= grep_oid(opt, &entry.oid, base->buf, tn_len,
 					 check_attr ? base->buf + tn_len : NULL);
 		} else if (S_ISDIR(entry.mode)) {
 			enum object_type type;
@@ -577,19 +587,20 @@ static int grep_tree(struct grep_opt *op
 			void *data;
 			unsigned long size;
 
-			data = lock_and_read_oid_file(entry.oid, &type, &size);
+			data = lock_and_read_oid_file(&entry.oid, &type, &size);
 			if (!data)
 				die(_("unable to read tree (%s)"),
-				    oid_to_hex(entry.oid));
+				    oid_to_hex(&entry.oid));
 
 			strbuf_addch(base, '/');
 			init_tree_desc(&sub, data, size);
 			hit |= grep_tree(opt, pathspec, &sub, base, tn_len,
-					 check_attr, repo);
+					 check_attr);
 			free(data);
 		} else if (recurse_submodules && S_ISGITLINK(entry.mode)) {
-			hit |= grep_submodule(opt, repo, pathspec, entry.oid,
-					      base->buf, base->buf + tn_len);
+			hit |= grep_submodule(opt, pathspec, &entry.oid,
+					      base->buf, base->buf + tn_len,
+					      1); /* ignored */
 		}
 
 		strbuf_setlen(base, old_baselen);
@@ -615,7 +626,8 @@ static int grep_object(struct grep_opt *
 		int hit, len;
 
 		grep_read_lock();
-		data = read_object_with_reference(&obj->oid, tree_type,
+		data = read_object_with_reference(opt->repo,
+						  &obj->oid, tree_type,
 						  &size, NULL);
 		grep_read_unlock();
 
@@ -630,7 +642,7 @@ static int grep_object(struct grep_opt *
 		}
 		init_tree_desc(&tree, data, size);
 		hit = grep_tree(opt, pathspec, &tree, &base, base.len,
-				obj->type == OBJ_COMMIT, the_repository);
+				obj->type == OBJ_COMMIT);
 		strbuf_release(&base);
 		free(data);
 		return hit;
@@ -647,11 +659,12 @@ static int grep_objects(struct grep_opt
 
 	for (i = 0; i < nr; i++) {
 		struct object *real_obj;
-		real_obj = deref_tag(list->objects[i].item, NULL, 0);
+		real_obj = deref_tag(opt->repo, list->objects[i].item,
+				     NULL, 0);
 
 		/* load the gitmodules file for this rev */
 		if (recurse_submodules) {
-			submodule_free(the_repository);
+			submodule_free(opt->repo);
 			gitmodules_config_oid(&real_obj->oid);
 		}
 		if (grep_object(opt, pathspec, real_obj, list->objects[i].name,
@@ -676,9 +689,9 @@ static int grep_directory(struct grep_op
 	if (exc_std)
 		setup_standard_excludes(&dir);
 
-	fill_directory(&dir, &the_index, pathspec);
+	fill_directory(&dir, opt->repo->index, pathspec);
 	for (i = 0; i < dir.nr; i++) {
-		if (!dir_path_match(dir.entries[i], pathspec, 0, NULL))
+		if (!dir_path_match(opt->repo->index, dir.entries[i], pathspec, 0, NULL))
 			continue;
 		hit |= grep_file(opt, dir.entries[i]->name);
 		if (hit && opt->status_only)
@@ -710,11 +723,14 @@ static int context_callback(const struct
 static int file_callback(const struct option *opt, const char *arg, int unset)
 {
 	struct grep_opt *grep_opt = opt->value;
-	int from_stdin = !strcmp(arg, "-");
+	int from_stdin;
 	FILE *patterns;
 	int lno = 0;
 	struct strbuf sb = STRBUF_INIT;
 
+	BUG_ON_OPT_NEG(unset);
+
+	from_stdin = !strcmp(arg, "-");
 	patterns = from_stdin ? stdin : fopen(arg, "r");
 	if (!patterns)
 		die_errno(_("cannot open '%s'"), arg);
@@ -735,6 +751,8 @@ static int file_callback(const struct op
 static int not_callback(const struct option *opt, const char *arg, int unset)
 {
 	struct grep_opt *grep_opt = opt->value;
+	BUG_ON_OPT_NEG(unset);
+	BUG_ON_OPT_ARG(arg);
 	append_grep_pattern(grep_opt, "--not", "command line", 0, GREP_NOT);
 	return 0;
 }
@@ -742,6 +760,8 @@ static int not_callback(const struct opt
 static int and_callback(const struct option *opt, const char *arg, int unset)
 {
 	struct grep_opt *grep_opt = opt->value;
+	BUG_ON_OPT_NEG(unset);
+	BUG_ON_OPT_ARG(arg);
 	append_grep_pattern(grep_opt, "--and", "command line", 0, GREP_AND);
 	return 0;
 }
@@ -749,6 +769,8 @@ static int and_callback(const struct opt
 static int open_callback(const struct option *opt, const char *arg, int unset)
 {
 	struct grep_opt *grep_opt = opt->value;
+	BUG_ON_OPT_NEG(unset);
+	BUG_ON_OPT_ARG(arg);
 	append_grep_pattern(grep_opt, "(", "command line", 0, GREP_OPEN_PAREN);
 	return 0;
 }
@@ -756,6 +778,8 @@ static int open_callback(const struct op
 static int close_callback(const struct option *opt, const char *arg, int unset)
 {
 	struct grep_opt *grep_opt = opt->value;
+	BUG_ON_OPT_NEG(unset);
+	BUG_ON_OPT_ARG(arg);
 	append_grep_pattern(grep_opt, ")", "command line", 0, GREP_CLOSE_PAREN);
 	return 0;
 }
@@ -764,6 +788,7 @@ static int pattern_callback(const struct
 			    int unset)
 {
 	struct grep_opt *grep_opt = opt->value;
+	BUG_ON_OPT_NEG(unset);
 	append_grep_pattern(grep_opt, arg, "-e option", 0, GREP_PATTERN);
 	return 0;
 }
@@ -810,6 +835,8 @@ int cmd_grep(int argc, const char **argv
 			GREP_BINARY_NOMATCH),
 		OPT_BOOL(0, "textconv", &opt.allow_textconv,
 			 N_("process binary files with textconv filters")),
+		OPT_SET_INT('r', "recursive", &opt.max_depth,
+			    N_("search in subdirectories (default)"), -1),
 		{ OPTION_INTEGER, 0, "max-depth", &opt.max_depth, N_("depth"),
 			N_("descend at most <depth> levels"), PARSE_OPT_NONEG,
 			NULL, 1 },
@@ -828,6 +855,7 @@ int cmd_grep(int argc, const char **argv
 			    GREP_PATTERN_TYPE_PCRE),
 		OPT_GROUP(""),
 		OPT_BOOL('n', "line-number", &opt.linenum, N_("show line numbers")),
+		OPT_BOOL(0, "column", &opt.columnnum, N_("show column number of first match")),
 		OPT_NEGBIT('h', NULL, &opt.pathname, N_("don't show filenames"), 1),
 		OPT_BIT('H', NULL, &opt.pathname, N_("show filenames"), 1),
 		OPT_NEGBIT(0, "full-name", &opt.relative,
@@ -842,6 +870,8 @@ int cmd_grep(int argc, const char **argv
 		OPT_BOOL_F('z', "null", &opt.null_following_name,
 			   N_("print NUL after filenames"),
 			   PARSE_OPT_NOCOMPLETE),
+		OPT_BOOL('o', "only-matching", &opt.only_matching,
+			N_("show only matching parts of a line")),
 		OPT_BOOL('c', "count", &opt.count,
 			N_("show the number of matches instead of matching lines")),
 		OPT__COLOR(&opt.color, N_("highlight matches")),
@@ -900,9 +930,9 @@ int cmd_grep(int argc, const char **argv
 		OPT_END()
 	};
 
-	init_grep_defaults();
+	init_grep_defaults(the_repository);
 	git_config(grep_cmd_config, NULL);
-	grep_init(&opt, prefix);
+	grep_init(&opt, the_repository, prefix);
 
 	/*
 	 * If there is no -- then the paths must exist in the working
@@ -928,6 +958,9 @@ int cmd_grep(int argc, const char **argv
 			/* die the same way as if we did it at the beginning */
 			setup_git_directory();
 	}
+	/* Ignore --recurse-submodules if --no-index is given or implied */
+	if (!use_index)
+		recurse_submodules = 0;
 
 	/*
 	 * skip a -- separator; we know it cannot be
@@ -959,7 +992,11 @@ int cmd_grep(int argc, const char **argv
 	}
 
 	if (!opt.pattern_list)
-		die(_("no pattern given."));
+		die(_("no pattern given"));
+
+	/* --only-matching has no effect with --invert. */
+	if (opt.invert)
+		opt.only_matching = 0;
 
 	/*
 	 * We have to find "--" in a separate pass, because its presence
@@ -995,7 +1032,8 @@ int cmd_grep(int argc, const char **argv
 			break;
 		}
 
-		if (get_oid_with_context(arg, GET_OID_RECORD_PATH,
+		if (get_oid_with_context(the_repository, arg,
+					 GET_OID_RECORD_PATH,
 					 &oid, &oc)) {
 			if (seen_dashdash)
 				die(_("unable to resolve revision: %s"), arg);
@@ -1027,39 +1065,35 @@ int cmd_grep(int argc, const char **argv
 	pathspec.recursive = 1;
 	pathspec.recurse_submodules = !!recurse_submodules;
 
-#ifndef NO_PTHREADS
-	if (list.nr || cached || show_in_pager)
-		num_threads = 0;
-	else if (num_threads == 0)
-		num_threads = GREP_NUM_THREADS_DEFAULT;
-	else if (num_threads < 0)
-		die(_("invalid number of threads specified (%d)"), num_threads);
-	if (num_threads == 1)
-		num_threads = 0;
-#else
-	if (num_threads)
+	if (list.nr || cached || show_in_pager) {
+		if (num_threads > 1)
+			warning(_("invalid option combination, ignoring --threads"));
+		num_threads = 1;
+	} else if (!HAVE_THREADS && num_threads > 1) {
 		warning(_("no threads support, ignoring --threads"));
-	num_threads = 0;
-#endif
+		num_threads = 1;
+	} else if (num_threads < 0)
+		die(_("invalid number of threads specified (%d)"), num_threads);
+	else if (num_threads == 0)
+		num_threads = HAVE_THREADS ? GREP_NUM_THREADS_DEFAULT : 1;
 
-	if (!num_threads)
+	if (num_threads > 1) {
+		if (!HAVE_THREADS)
+			BUG("Somebody got num_threads calculation wrong!");
+		if (!(opt.name_only || opt.unmatch_name_only || opt.count)
+		    && (opt.pre_context || opt.post_context ||
+			opt.file_break || opt.funcbody))
+			skip_first_line = 1;
+		start_threads(&opt);
+	} else {
 		/*
 		 * The compiled patterns on the main path are only
 		 * used when not using threading. Otherwise
-		 * start_threads() below calls compile_grep_patterns()
+		 * start_threads() above calls compile_grep_patterns()
 		 * for each thread.
 		 */
 		compile_grep_patterns(&opt);
-
-#ifndef NO_PTHREADS
-	if (num_threads) {
-		if (!(opt.name_only || opt.unmatch_name_only || opt.count)
-		    && (opt.pre_context || opt.post_context ||
-			opt.file_break || opt.funcbody))
-			skip_first_line = 1;
-		start_threads(&opt);
 	}
-#endif
 
 	if (show_in_pager && (cached || list.nr))
 		die(_("--open-files-in-pager only works on the worktree"));
@@ -1079,42 +1113,43 @@ int cmd_grep(int argc, const char **argv
 			strbuf_addf(&buf, "+/%s%s",
 					strcmp("less", pager) ? "" : "*",
 					opt.pattern_list->pattern);
-			string_list_append(&path_list, buf.buf);
-			strbuf_detach(&buf, NULL);
+			string_list_append(&path_list,
+					   strbuf_detach(&buf, NULL));
 		}
 	}
 
-	if (recurse_submodules && (!use_index || untracked))
-		die(_("option not supported with --recurse-submodules."));
+	if (recurse_submodules && untracked)
+		die(_("--untracked not supported with --recurse-submodules"));
 
 	if (!show_in_pager && !opt.status_only)
 		setup_pager();
 
 	if (!use_index && (untracked || cached))
-		die(_("--cached or --untracked cannot be used with --no-index."));
+		die(_("--cached or --untracked cannot be used with --no-index"));
 
 	if (!use_index || untracked) {
 		int use_exclude = (opt_exclude < 0) ? use_index : !!opt_exclude;
 		hit = grep_directory(&opt, &pathspec, use_exclude, use_index);
 	} else if (0 <= opt_exclude) {
-		die(_("--[no-]exclude-standard cannot be used for tracked contents."));
+		die(_("--[no-]exclude-standard cannot be used for tracked contents"));
 	} else if (!list.nr) {
 		if (!cached)
 			setup_work_tree();
 
-		hit = grep_cache(&opt, the_repository, &pathspec, cached);
+		hit = grep_cache(&opt, &pathspec, cached);
 	} else {
 		if (cached)
-			die(_("both --cached and trees are given."));
+			die(_("both --cached and trees are given"));
 
 		hit = grep_objects(&opt, &pathspec, &list);
 	}
 
-	if (num_threads)
+	if (num_threads > 1)
 		hit |= wait_all();
 	if (hit && show_in_pager)
 		run_pager(&opt, prefix);
 	clear_pathspec(&pathspec);
 	free_grep_patterns(&opt);
+	grep_destroy();
 	return !hit;
 }
diff -pruN 1.2.1+git2.18.0-1/git/builtin/hash-object.c 1.2.3+git2.25.1-1/git/builtin/hash-object.c
--- 1.2.1+git2.18.0-1/git/builtin/hash-object.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/builtin/hash-object.c	2020-02-17 04:47:35.000000000 +0000
@@ -6,6 +6,7 @@
  */
 #include "builtin.h"
 #include "config.h"
+#include "object-store.h"
 #include "blob.h"
 #include "quote.h"
 #include "parse-options.h"
@@ -39,7 +40,8 @@ static void hash_fd(int fd, const char *
 	if (fstat(fd, &st) < 0 ||
 	    (literally
 	     ? hash_literally(&oid, fd, type, flags)
-	     : index_fd(&oid, fd, &st, type_from_string(type), path, flags)))
+	     : index_fd(the_repository->index, &oid, fd, &st,
+			type_from_string(type), path, flags)))
 		die((flags & HASH_WRITE_OBJECT)
 		    ? "Unable to add %s to database"
 		    : "Unable to hash %s", path);
@@ -106,7 +108,7 @@ int cmd_hash_object(int argc, const char
 	int i;
 	const char *errstr = NULL;
 
-	argc = parse_options(argc, argv, NULL, hash_object_options,
+	argc = parse_options(argc, argv, prefix, hash_object_options,
 			     hash_object_usage, 0);
 
 	if (flags & HASH_WRITE_OBJECT)
diff -pruN 1.2.1+git2.18.0-1/git/builtin/help.c 1.2.3+git2.25.1-1/git/builtin/help.c
--- 1.2.1+git2.18.0-1/git/builtin/help.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/builtin/help.c	2020-02-17 04:47:35.000000000 +0000
@@ -37,7 +37,8 @@ static const char *html_path;
 
 static int show_all = 0;
 static int show_guides = 0;
-static int verbose;
+static int show_config;
+static int verbose = 1;
 static unsigned int colopts;
 static enum help_format help_format = HELP_FORMAT_NONE;
 static int exclude_guides;
@@ -45,6 +46,8 @@ static struct option builtin_help_option
 	OPT_BOOL('a', "all", &show_all, N_("print all available commands")),
 	OPT_HIDDEN_BOOL(0, "exclude-guides", &exclude_guides, N_("exclude guides")),
 	OPT_BOOL('g', "guides", &show_guides, N_("print list of useful guides")),
+	OPT_BOOL('c', "config", &show_config, N_("print all configuration variable names")),
+	OPT_SET_INT_F(0, "config-for-completion", &show_config, "", 2, PARSE_OPT_HIDDEN),
 	OPT_SET_INT('m', "man", &help_format, N_("show man page"), HELP_FORMAT_MAN),
 	OPT_SET_INT('w', "web", &help_format, N_("show manual in web browser"),
 			HELP_FORMAT_WEB),
@@ -67,6 +70,10 @@ static enum help_format parse_help_forma
 		return HELP_FORMAT_INFO;
 	if (!strcmp(format, "web") || !strcmp(format, "html"))
 		return HELP_FORMAT_WEB;
+	/*
+	 * Please update _git_config() in git-completion.bash when you
+	 * add new help formats.
+	 */
 	die(_("unrecognized help format '%s'"), format);
 }
 
@@ -412,9 +419,37 @@ static const char *check_git_cmd(const c
 
 	alias = alias_lookup(cmd);
 	if (alias) {
-		printf_ln(_("'%s' is aliased to '%s'"), cmd, alias);
-		free(alias);
-		exit(0);
+		const char **argv;
+		int count;
+
+		/*
+		 * handle_builtin() in git.c rewrites "git cmd --help"
+		 * to "git help --exclude-guides cmd", so we can use
+		 * exclude_guides to distinguish "git cmd --help" from
+		 * "git help cmd". In the latter case, or if cmd is an
+		 * alias for a shell command, just print the alias
+		 * definition.
+		 */
+		if (!exclude_guides || alias[0] == '!') {
+			printf_ln(_("'%s' is aliased to '%s'"), cmd, alias);
+			free(alias);
+			exit(0);
+		}
+		/*
+		 * Otherwise, we pretend that the command was "git
+		 * word0 --help". We use split_cmdline() to get the
+		 * first word of the alias, to ensure that we use the
+		 * same rules as when the alias is actually
+		 * used. split_cmdline() modifies alias in-place.
+		 */
+		fprintf_ln(stderr, _("'%s' is aliased to '%s'"), cmd, alias);
+		count = split_cmdline(alias, &argv);
+		if (count < 0)
+			die(_("bad alias.%s string: %s"), cmd,
+			    split_cmdline_strerror(count));
+		free(argv);
+		UNLEAK(alias);
+		return alias;
 	}
 
 	if (exclude_guides)
@@ -444,6 +479,19 @@ int cmd_help(int argc, const char **argv
 		list_commands(colopts, &main_cmds, &other_cmds);
 	}
 
+	if (show_config) {
+		int for_human = show_config == 1;
+
+		if (!for_human) {
+			list_config_help(for_human);
+			return 0;
+		}
+		setup_pager();
+		list_config_help(for_human);
+		printf("\n%s\n", _("'git help config' for more information"));
+		return 0;
+	}
+
 	if (show_guides)
 		list_common_guides_help();
 
diff -pruN 1.2.1+git2.18.0-1/git/builtin/index-pack.c 1.2.3+git2.25.1-1/git/builtin/index-pack.c
--- 1.2.1+git2.18.0-1/git/builtin/index-pack.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/builtin/index-pack.c	2020-02-17 04:47:35.000000000 +0000
@@ -14,6 +14,7 @@
 #include "thread-utils.h"
 #include "packfile.h"
 #include "object-store.h"
+#include "promisor-remote.h"
 
 static const char index_pack_usage[] =
 "git index-pack [-v] [-o <index-file>] [--keep | --keep=<msg>] [--verify] [--strict] (<pack-file> | --stdin [--fix-thin] [<pack-file>])";
@@ -42,9 +43,7 @@ struct base_data {
 };
 
 struct thread_local {
-#ifndef NO_PTHREADS
 	pthread_t thread;
-#endif
 	struct base_data *base_cache;
 	size_t base_cache_used;
 	int pack_fd;
@@ -98,8 +97,6 @@ static uint32_t input_crc32;
 static int input_fd, output_fd;
 static const char *curr_pack;
 
-#ifndef NO_PTHREADS
-
 static struct thread_local *thread_data;
 static int nr_dispatched;
 static int threads_active;
@@ -179,26 +176,6 @@ static void cleanup_thread(void)
 	free(thread_data);
 }
 
-#else
-
-#define read_lock()
-#define read_unlock()
-
-#define counter_lock()
-#define counter_unlock()
-
-#define work_lock()
-#define work_unlock()
-
-#define deepest_delta_lock()
-#define deepest_delta_unlock()
-
-#define type_cas_lock()
-#define type_cas_unlock()
-
-#endif
-
-
 static int mark_link(struct object *obj, int type, void *data, struct fsck_options *options)
 {
 	if (!obj)
@@ -243,8 +220,16 @@ static unsigned check_objects(void)
 	unsigned i, max, foreign_nr = 0;
 
 	max = get_max_object_index();
-	for (i = 0; i < max; i++)
+
+	if (verbose)
+		progress = start_delayed_progress(_("Checking objects"), max);
+
+	for (i = 0; i < max; i++) {
 		foreign_nr += check_object(get_indexed_object(i));
+		display_progress(progress, i + 1);
+	}
+
+	stop_progress(&progress);
 	return foreign_nr;
 }
 
@@ -364,22 +349,20 @@ static NORETURN void bad_object(off_t of
 
 static inline struct thread_local *get_thread_data(void)
 {
-#ifndef NO_PTHREADS
-	if (threads_active)
-		return pthread_getspecific(key);
-	assert(!threads_active &&
-	       "This should only be reached when all threads are gone");
-#endif
+	if (HAVE_THREADS) {
+		if (threads_active)
+			return pthread_getspecific(key);
+		assert(!threads_active &&
+		       "This should only be reached when all threads are gone");
+	}
 	return &nothread_data;
 }
 
-#ifndef NO_PTHREADS
 static void set_thread_data(struct thread_local *data)
 {
 	if (threads_active)
 		pthread_setspecific(key, data);
 }
-#endif
 
 static struct base_data *alloc_base_data(void)
 {
@@ -450,7 +433,8 @@ static void *unpack_entry_data(off_t off
 	int hdrlen;
 
 	if (!is_delta_type(type)) {
-		hdrlen = xsnprintf(hdr, sizeof(hdr), "%s %lu", type_name(type), size) + 1;
+		hdrlen = xsnprintf(hdr, sizeof(hdr), "%s %"PRIuMAX,
+				   type_name(type),(uintmax_t)size) + 1;
 		the_hash_algo->init_fn(&c);
 		the_hash_algo->update_fn(&c, hdr, hdrlen);
 	} else
@@ -719,9 +703,9 @@ static void find_ref_delta_children(cons
 		*last_index = -1;
 		return;
 	}
-	while (first > 0 && !oidcmp(&ref_deltas[first - 1].oid, oid))
+	while (first > 0 && oideq(&ref_deltas[first - 1].oid, oid))
 		--first;
-	while (last < end && !oidcmp(&ref_deltas[last + 1].oid, oid))
+	while (last < end && oideq(&ref_deltas[last + 1].oid, oid))
 		++last;
 	*first_index = first;
 	*last_index = last;
@@ -797,7 +781,7 @@ static void sha1_object(const void *data
 	if (startup_info->have_repository) {
 		read_lock();
 		collision_test_needed =
-			has_sha1_file_with_flags(oid->hash, OBJECT_INFO_QUICK);
+			has_object_file_with_flags(oid, OBJECT_INFO_QUICK);
 		read_unlock();
 	}
 
@@ -832,7 +816,7 @@ static void sha1_object(const void *data
 	if (strict || do_fsck_object) {
 		read_lock();
 		if (type == OBJ_BLOB) {
-			struct blob *blob = lookup_blob(oid);
+			struct blob *blob = lookup_blob(the_repository, oid);
 			if (blob)
 				blob->object.flags |= FLAG_CHECKED;
 			else
@@ -851,7 +835,8 @@ static void sha1_object(const void *data
 			 * we do not need to free the memory here, as the
 			 * buf is deleted by the caller.
 			 */
-			obj = parse_object_buffer(oid, type, size, buf,
+			obj = parse_object_buffer(the_repository, oid, type,
+						  size, buf,
 						  &eaten);
 			if (!obj)
 				die(_("invalid %s"), type_name(type));
@@ -1091,7 +1076,6 @@ static void resolve_base(struct object_e
 	find_unresolved_deltas(base_obj);
 }
 
-#ifndef NO_PTHREADS
 static void *threaded_second_pass(void *data)
 {
 	set_thread_data(data);
@@ -1115,7 +1099,6 @@ static void *threaded_second_pass(void *
 	}
 	return NULL;
 }
-#endif
 
 /*
  * First pass:
@@ -1165,7 +1148,7 @@ static void parse_pack_objects(unsigned
 	/* Check pack integrity */
 	flush();
 	the_hash_algo->final_fn(hash, &input_ctx);
-	if (hashcmp(fill(the_hash_algo->rawsz), hash))
+	if (!hasheq(fill(the_hash_algo->rawsz), hash))
 		die(_("pack is corrupted (SHA1 mismatch)"));
 	use(the_hash_algo->rawsz);
 
@@ -1212,7 +1195,6 @@ static void resolve_deltas(void)
 		progress = start_progress(_("Resolving deltas"),
 					  nr_ref_deltas + nr_ofs_deltas);
 
-#ifndef NO_PTHREADS
 	nr_dispatched = 0;
 	if (nr_threads > 1 || getenv("GIT_FORCE_THREADS")) {
 		init_thread();
@@ -1228,7 +1210,6 @@ static void resolve_deltas(void)
 		cleanup_thread();
 		return;
 	}
-#endif
 
 	for (i = 0; i < nr_objects; i++) {
 		struct object_entry *obj = &objects[i];
@@ -1279,7 +1260,7 @@ static void conclude_pack(int fix_thin_p
 		fixup_pack_header_footer(output_fd, pack_hash,
 					 curr_pack, nr_objects,
 					 read_hash, consumed_bytes-the_hash_algo->rawsz);
-		if (hashcmp(read_hash, tail_hash) != 0)
+		if (!hasheq(read_hash, tail_hash))
 			die(_("Unexpected tail checksum for %s "
 			      "(disk corruption?)"), curr_pack);
 	}
@@ -1371,6 +1352,25 @@ static void fix_unresolved_deltas(struct
 		sorted_by_pos[i] = &ref_deltas[i];
 	QSORT(sorted_by_pos, nr_ref_deltas, delta_pos_compare);
 
+	if (has_promisor_remote()) {
+		/*
+		 * Prefetch the delta bases.
+		 */
+		struct oid_array to_fetch = OID_ARRAY_INIT;
+		for (i = 0; i < nr_ref_deltas; i++) {
+			struct ref_delta_entry *d = sorted_by_pos[i];
+			if (!oid_object_info_extended(the_repository, &d->oid,
+						      NULL,
+						      OBJECT_INFO_FOR_PREFETCH))
+				continue;
+			oid_array_append(&to_fetch, &d->oid);
+		}
+		if (to_fetch.nr)
+			promisor_remote_get_direct(the_repository,
+						   to_fetch.oid, to_fetch.nr);
+		oid_array_clear(&to_fetch);
+	}
+
 	for (i = 0; i < nr_ref_deltas; i++) {
 		struct ref_delta_entry *d = sorted_by_pos[i];
 		enum object_type type;
@@ -1490,11 +1490,11 @@ static void final(const char *final_pack
 	}
 
 	if (!from_stdin) {
-		printf("%s\n", sha1_to_hex(hash));
+		printf("%s\n", hash_to_hex(hash));
 	} else {
 		struct strbuf buf = STRBUF_INIT;
 
-		strbuf_addf(&buf, "%s\t%s\n", report, sha1_to_hex(hash));
+		strbuf_addf(&buf, "%s\t%s\n", report, hash_to_hex(hash));
 		write_or_die(1, buf.buf, buf.len);
 		strbuf_release(&buf);
 
@@ -1530,11 +1530,10 @@ static int git_index_pack_config(const c
 		if (nr_threads < 0)
 			die(_("invalid number of threads specified (%d)"),
 			    nr_threads);
-#ifdef NO_PTHREADS
-		if (nr_threads != 1)
+		if (!HAVE_THREADS && nr_threads != 1) {
 			warning(_("no threads support, ignoring %s"), k);
-		nr_threads = 1;
-#endif
+			nr_threads = 1;
+		}
 		return 0;
 	}
 	return git_default_config(k, v, cb);
@@ -1627,10 +1626,10 @@ static void show_pack_info(int stat_only
 			chain_histogram[obj_stat[i].delta_depth - 1]++;
 		if (stat_only)
 			continue;
-		printf("%s %-6s %lu %lu %"PRIuMAX,
+		printf("%s %-6s %"PRIuMAX" %"PRIuMAX" %"PRIuMAX,
 		       oid_to_hex(&obj->idx.oid),
-		       type_name(obj->real_type), obj->size,
-		       (unsigned long)(obj[1].idx.offset - obj->idx.offset),
+		       type_name(obj->real_type), (uintmax_t)obj->size,
+		       (uintmax_t)(obj[1].idx.offset - obj->idx.offset),
 		       (uintmax_t)obj->idx.offset);
 		if (is_delta_type(obj->type)) {
 			struct object_entry *bobj = &objects[obj_stat[i].base_object_no];
@@ -1671,15 +1670,17 @@ int cmd_index_pack(int argc, const char
 	int report_end_of_input = 0;
 
 	/*
-	 * index-pack never needs to fetch missing objects, since it only
-	 * accesses the repo to do hash collision checks
+	 * index-pack never needs to fetch missing objects except when
+	 * REF_DELTA bases are missing (which are explicitly handled). It only
+	 * accesses the repo to do hash collision checks and to check which
+	 * REF_DELTA bases need to be fetched.
 	 */
 	fetch_if_missing = 0;
 
 	if (argc == 2 && !strcmp(argv[1], "-h"))
 		usage(index_pack_usage);
 
-	check_replace_refs = 0;
+	read_replace_refs = 0;
 	fsck_options.walk = mark_link;
 
 	reset_pack_idx_option(&opts);
@@ -1722,12 +1723,10 @@ int cmd_index_pack(int argc, const char
 				nr_threads = strtoul(arg+10, &end, 0);
 				if (!arg[10] || *end || nr_threads < 0)
 					usage(index_pack_usage);
-#ifdef NO_PTHREADS
-				if (nr_threads != 1)
-					warning(_("no threads support, "
-						  "ignoring %s"), arg);
-				nr_threads = 1;
-#endif
+				if (!HAVE_THREADS && nr_threads != 1) {
+					warning(_("no threads support, ignoring %s"), arg);
+					nr_threads = 1;
+				}
 			} else if (starts_with(arg, "--pack_header=")) {
 				struct pack_header *hdr;
 				char *c;
@@ -1790,14 +1789,12 @@ int cmd_index_pack(int argc, const char
 	if (strict)
 		opts.flags |= WRITE_IDX_STRICT;
 
-#ifndef NO_PTHREADS
-	if (!nr_threads) {
+	if (HAVE_THREADS && !nr_threads) {
 		nr_threads = online_cpus();
 		/* An experiment showed that more threads does not mean faster */
 		if (nr_threads > 3)
 			nr_threads = 3;
 	}
-#endif
 
 	curr_pack = open_pack_file(pack_name);
 	parse_pack_header();
diff -pruN 1.2.1+git2.18.0-1/git/builtin/init-db.c 1.2.3+git2.25.1-1/git/builtin/init-db.c
--- 1.2.1+git2.18.0-1/git/builtin/init-db.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/builtin/init-db.c	2020-02-17 04:47:35.000000000 +0000
@@ -73,7 +73,8 @@ static void copy_templates_1(struct strb
 			continue;
 		else if (S_ISLNK(st_template.st_mode)) {
 			struct strbuf lnk = STRBUF_INIT;
-			if (strbuf_readlink(&lnk, template_path->buf, 0) < 0)
+			if (strbuf_readlink(&lnk, template_path->buf,
+					    st_template.st_size) < 0)
 				die_errno(_("cannot readlink '%s'"), template_path->buf);
 			if (symlink(lnk.buf, path->buf))
 				die_errno(_("cannot symlink '%s' '%s'"),
@@ -95,7 +96,7 @@ static void copy_templates(const char *t
 	struct strbuf path = STRBUF_INIT;
 	struct strbuf template_path = STRBUF_INIT;
 	size_t template_len;
-	struct repository_format template_format;
+	struct repository_format template_format = REPOSITORY_FORMAT_INIT;
 	struct strbuf err = STRBUF_INIT;
 	DIR *dir;
 	char *to_free = NULL;
@@ -147,6 +148,7 @@ free_return:
 	free(to_free);
 	strbuf_release(&path);
 	strbuf_release(&template_path);
+	clear_repository_format(&template_format);
 }
 
 static int git_init_db_config(const char *k, const char *v, void *cb)
@@ -154,6 +156,9 @@ static int git_init_db_config(const char
 	if (!strcmp(k, "init.templatedir"))
 		return git_config_pathname(&init_db_template_dir, k, v);
 
+	if (starts_with(k, "core."))
+		return platform_core_config(k, v, cb);
+
 	return 0;
 }
 
@@ -184,6 +189,7 @@ static int create_default_files(const ch
 	struct strbuf err = STRBUF_INIT;
 
 	/* Just look for `init.templatedir` */
+	init_db_template_dir = NULL; /* re-set in case it was set before */
 	git_config(git_init_db_config, NULL);
 
 	/*
@@ -360,6 +366,9 @@ int init_db(const char *git_dir, const c
 	}
 	startup_info->have_repository = 1;
 
+	/* Just look for `core.hidedotfiles` */
+	git_config(git_init_db_config, NULL);
+
 	safe_create_dir(git_dir, 0);
 
 	init_is_bare_repository = is_bare_repository();
@@ -450,6 +459,7 @@ static int guess_repository_type(const c
 
 static int shared_callback(const struct option *opt, const char *arg, int unset)
 {
+	BUG_ON_OPT_NEG(unset);
 	*((int *) opt->value) = (arg) ? git_config_perm("arg", arg) : PERM_GROUP;
 	return 0;
 }
@@ -492,6 +502,9 @@ int cmd_init_db(int argc, const char **a
 	if (real_git_dir && !is_absolute_path(real_git_dir))
 		real_git_dir = real_pathdup(real_git_dir, 1);
 
+	if (template_dir && *template_dir && !is_absolute_path(template_dir))
+		template_dir = absolute_pathdup(template_dir);
+
 	if (argc == 1) {
 		int mkdir_tried = 0;
 	retry:
@@ -540,8 +553,8 @@ int cmd_init_db(int argc, const char **a
 	 * GIT_WORK_TREE makes sense only in conjunction with GIT_DIR
 	 * without --bare.  Catch the error early.
 	 */
-	git_dir = getenv(GIT_DIR_ENVIRONMENT);
-	work_tree = getenv(GIT_WORK_TREE_ENVIRONMENT);
+	git_dir = xstrdup_or_null(getenv(GIT_DIR_ENVIRONMENT));
+	work_tree = xstrdup_or_null(getenv(GIT_WORK_TREE_ENVIRONMENT));
 	if ((!git_dir || is_bare_repository_cfg == 1) && work_tree)
 		die(_("%s (or --work-tree=<directory>) not allowed without "
 			  "specifying %s (or --git-dir=<directory>)"),
@@ -580,6 +593,8 @@ int cmd_init_db(int argc, const char **a
 	}
 
 	UNLEAK(real_git_dir);
+	UNLEAK(git_dir);
+	UNLEAK(work_tree);
 
 	flags |= INIT_DB_EXIST_OK;
 	return init_db(git_dir, real_git_dir, template_dir, flags);
diff -pruN 1.2.1+git2.18.0-1/git/builtin/interpret-trailers.c 1.2.3+git2.25.1-1/git/builtin/interpret-trailers.c
--- 1.2.1+git2.18.0-1/git/builtin/interpret-trailers.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/builtin/interpret-trailers.c	2020-02-17 04:47:35.000000000 +0000
@@ -10,6 +10,7 @@
 #include "parse-options.h"
 #include "string-list.h"
 #include "trailer.h"
+#include "config.h"
 
 static const char * const git_interpret_trailers_usage[] = {
 	N_("git interpret-trailers [--in-place] [--trim-empty] [(--trailer <token>[(=|:)<value>])...] [<file>...]"),
@@ -80,6 +81,8 @@ static int parse_opt_parse(const struct
 	v->only_trailers = 1;
 	v->only_input = 1;
 	v->unfold = 1;
+	BUG_ON_OPT_NEG(unset);
+	BUG_ON_OPT_ARG(arg);
 	return 0;
 }
 
@@ -104,11 +107,14 @@ int cmd_interpret_trailers(int argc, con
 		OPT_BOOL(0, "unfold", &opts.unfold, N_("join whitespace-continued values")),
 		{ OPTION_CALLBACK, 0, "parse", &opts, NULL, N_("set parsing options"),
 			PARSE_OPT_NOARG | PARSE_OPT_NONEG, parse_opt_parse },
+		OPT_BOOL(0, "no-divider", &opts.no_divider, N_("do not treat --- specially")),
 		OPT_CALLBACK(0, "trailer", &trailers, N_("trailer"),
 				N_("trailer(s) to add"), option_parse_trailer),
 		OPT_END()
 	};
 
+	git_config(git_default_config, NULL);
+
 	argc = parse_options(argc, argv, prefix, options,
 			     git_interpret_trailers_usage, 0);
 
diff -pruN 1.2.1+git2.18.0-1/git/builtin/log.c 1.2.3+git2.25.1-1/git/builtin/log.c
--- 1.2.1+git2.18.0-1/git/builtin/log.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/builtin/log.c	2020-02-17 04:47:35.000000000 +0000
@@ -4,9 +4,11 @@
  * (C) Copyright 2006 Linus Torvalds
  *		 2006 Junio Hamano
  */
+#define USE_THE_INDEX_COMPATIBILITY_MACROS
 #include "cache.h"
 #include "config.h"
 #include "refs.h"
+#include "object-store.h"
 #include "color.h"
 #include "commit.h"
 #include "diff.h"
@@ -28,8 +30,14 @@
 #include "mailmap.h"
 #include "gpg-interface.h"
 #include "progress.h"
+#include "commit-slab.h"
+#include "repository.h"
+#include "commit-reach.h"
+#include "interdiff.h"
+#include "range-diff.h"
 
 #define MAIL_DEFAULT_WRAP 72
+#define COVER_FROM_AUTO_MAX_SUBJECT_LEN 100
 
 /* Set a default date-time format for git log ("log.date" config variable) */
 static const char *default_date_mode = NULL;
@@ -40,7 +48,7 @@ static int default_follow;
 static int default_show_signature;
 static int decoration_style;
 static int decoration_given;
-static int use_mailmap_config;
+static int use_mailmap_config = 1;
 static const char *fmt_patch_subject_prefix = "PATCH";
 static const char *fmt_pretty;
 
@@ -56,9 +64,14 @@ struct line_opt_callback_data {
 	struct string_list args;
 };
 
+static int session_is_interactive(void)
+{
+	return isatty(1) || pager_in_use();
+}
+
 static int auto_decoration_style(void)
 {
-	return (isatty(1) || pager_in_use()) ? DECORATE_SHORT_REFS : 0;
+	return session_is_interactive() ? DECORATE_SHORT_REFS : 0;
 }
 
 static int parse_decoration_style(const char *value)
@@ -77,6 +90,10 @@ static int parse_decoration_style(const
 		return DECORATE_SHORT_REFS;
 	else if (!strcmp(value, "auto"))
 		return auto_decoration_style();
+	/*
+	 * Please update _git_log() in git-completion.bash when you
+	 * add new decoration styles.
+	 */
 	return -1;
 }
 
@@ -101,6 +118,8 @@ static int log_line_range_callback(const
 {
 	struct line_opt_callback_data *data = option->value;
 
+	BUG_ON_OPT_NEG(unset);
+
 	if (!arg)
 		return -1;
 
@@ -112,7 +131,7 @@ static int log_line_range_callback(const
 
 static void init_log_defaults(void)
 {
-	init_grep_defaults();
+	init_grep_defaults(the_repository);
 	init_diff_ui_defaults();
 
 	decoration_style = auto_decoration_style();
@@ -142,12 +161,13 @@ static void cmd_log_init_finish(int argc
 			 struct rev_info *rev, struct setup_revision_opt *opt)
 {
 	struct userformat_want w;
-	int quiet = 0, source = 0, mailmap = 0;
+	int quiet = 0, source = 0, mailmap;
 	static struct line_opt_callback_data line_cb = {NULL, NULL, STRING_LIST_INIT_DUP};
 	static struct string_list decorate_refs_exclude = STRING_LIST_INIT_NODUP;
 	static struct string_list decorate_refs_include = STRING_LIST_INIT_NODUP;
 	struct decoration_filter decoration_filter = {&decorate_refs_include,
 						      &decorate_refs_exclude};
+	static struct revision_sources revision_sources;
 
 	const struct option builtin_log_options[] = {
 		OPT__QUIET(&quiet, N_("suppress diff output")),
@@ -188,14 +208,16 @@ static void cmd_log_init_finish(int argc
 	if (!rev->show_notes_given && (!rev->pretty_given || w.notes))
 		rev->show_notes = 1;
 	if (rev->show_notes)
-		init_display_notes(&rev->notes_opt);
+		load_display_notes(&rev->notes_opt);
 
 	if ((rev->diffopt.pickaxe_opts & DIFF_PICKAXE_KINDS_MASK) ||
 	    rev->diffopt.filter || rev->diffopt.flags.follow_renames)
 		rev->always_show_header = 0;
 
-	if (source)
-		rev->show_source = 1;
+	if (source || w.source) {
+		init_revision_sources(&revision_sources);
+		rev->sources = &revision_sources;
+	}
 
 	if (mailmap) {
 		rev->mailmap = xcalloc(1, sizeof(struct string_list));
@@ -235,7 +257,7 @@ static void cmd_log_init(int argc, const
  * This gives a rough estimate for how many commits we
  * will print out in the list.
  */
-static int estimate_commit_count(struct rev_info *rev, struct commit_list *list)
+static int estimate_commit_count(struct commit_list *list)
 {
 	int n = 0;
 
@@ -273,7 +295,7 @@ static void log_show_early(struct rev_in
 		switch (simplify_commit(revs, commit)) {
 		case commit_show:
 			if (show_header) {
-				int n = estimate_commit_count(revs, list);
+				int n = estimate_commit_count(list);
 				show_early_header(revs, "incomplete", n);
 				show_header = 0;
 			}
@@ -317,7 +339,7 @@ static void early_output(int signal)
 	show_early_output = log_show_early;
 }
 
-static void setup_early_output(struct rev_info *rev)
+static void setup_early_output(void)
 {
 	struct sigaction sa;
 
@@ -348,7 +370,7 @@ static void setup_early_output(struct re
 
 static void finish_early_output(struct rev_info *rev)
 {
-	int n = estimate_commit_count(rev, rev->commits);
+	int n = estimate_commit_count(rev->commits);
 	signal(SIGALRM, SIG_IGN);
 	show_early_header(rev, "done", n);
 }
@@ -360,7 +382,7 @@ static int cmd_log_walk(struct rev_info
 	int saved_dcctc = 0, close_file = rev->diffopt.close_file;
 
 	if (rev->early_output)
-		setup_early_output(rev);
+		setup_early_output();
 
 	if (prepare_revision_walk(rev))
 		die(_("revision walk setup failed"));
@@ -386,7 +408,8 @@ static int cmd_log_walk(struct rev_info
 			 * We may show a given commit multiple times when
 			 * walking the reflogs.
 			 */
-			free_commit_buffer(commit);
+			free_commit_buffer(the_repository->parsed_objects,
+					   commit);
 			free_commit_list(commit->parents);
 			commit->parents = NULL;
 		}
@@ -461,7 +484,7 @@ int cmd_whatchanged(int argc, const char
 	init_log_defaults();
 	git_config(git_log_config, NULL);
 
-	init_revisions(&rev, prefix);
+	repo_init_revisions(the_repository, &rev, prefix);
 	rev.diff = 1;
 	rev.simplify_history = 0;
 	memset(&opt, 0, sizeof(opt));
@@ -473,7 +496,7 @@ int cmd_whatchanged(int argc, const char
 	return cmd_log_walk(&rev);
 }
 
-static void show_tagger(char *buf, int len, struct rev_info *rev)
+static void show_tagger(const char *buf, struct rev_info *rev)
 {
 	struct strbuf out = STRBUF_INIT;
 	struct pretty_print_context pp = {0};
@@ -497,11 +520,13 @@ static int show_blob_object(const struct
 	    !rev->diffopt.flags.allow_textconv)
 		return stream_blob_to_fd(1, oid, NULL, 0);
 
-	if (get_oid_with_context(obj_name, GET_OID_RECORD_PATH,
+	if (get_oid_with_context(the_repository, obj_name,
+				 GET_OID_RECORD_PATH,
 				 &oidc, &obj_context))
-		die(_("Not a valid object name %s"), obj_name);
+		die(_("not a valid object name %s"), obj_name);
 	if (!obj_context.path ||
-	    !textconv_object(obj_context.path, obj_context.mode, &oidc, 1, &buf, &size)) {
+	    !textconv_object(the_repository, obj_context.path,
+			     obj_context.mode, &oidc, 1, &buf, &size)) {
 		free(obj_context.path);
 		return stream_blob_to_fd(1, oid, NULL, 0);
 	}
@@ -522,16 +547,16 @@ static int show_tag_object(const struct
 	int offset = 0;
 
 	if (!buf)
-		return error(_("Could not read object %s"), oid_to_hex(oid));
+		return error(_("could not read object %s"), oid_to_hex(oid));
 
 	assert(type == OBJ_TAG);
 	while (offset < size && buf[offset] != '\n') {
 		int new_offset = offset + 1;
+		const char *ident;
 		while (new_offset < size && buf[new_offset++] != '\n')
 			; /* do nothing */
-		if (starts_with(buf + offset, "tagger "))
-			show_tagger(buf + offset + 7,
-				    new_offset - offset - 7, rev);
+		if (skip_prefix(buf + offset, "tagger ", &ident))
+			show_tagger(ident, rev);
 		offset = new_offset;
 	}
 
@@ -578,7 +603,7 @@ int cmd_show(int argc, const char **argv
 	git_config(git_log_config, NULL);
 
 	memset(&match_all, 0, sizeof(match_all));
-	init_revisions(&rev, prefix);
+	repo_init_revisions(the_repository, &rev, prefix);
 	rev.diff = 1;
 	rev.always_show_header = 1;
 	rev.no_walk = REVISION_WALK_NO_WALK_SORTED;
@@ -603,6 +628,7 @@ int cmd_show(int argc, const char **argv
 			break;
 		case OBJ_TAG: {
 			struct tag *t = (struct tag *)o;
+			struct object_id *oid = get_tagged_oid(t);
 
 			if (rev.shown_one)
 				putchar('\n');
@@ -614,10 +640,10 @@ int cmd_show(int argc, const char **argv
 			rev.shown_one = 1;
 			if (ret)
 				break;
-			o = parse_object(&t->tagged->oid);
+			o = parse_object(the_repository, oid);
 			if (!o)
-				ret = error(_("Could not read object %s"),
-					    oid_to_hex(&t->tagged->oid));
+				ret = error(_("could not read object %s"),
+					    oid_to_hex(oid));
 			objects[i].item = o;
 			i--;
 			break;
@@ -629,8 +655,9 @@ int cmd_show(int argc, const char **argv
 					diff_get_color_opt(&rev.diffopt, DIFF_COMMIT),
 					name,
 					diff_get_color_opt(&rev.diffopt, DIFF_RESET));
-			read_tree_recursive((struct tree *)o, "", 0, 0, &match_all,
-					show_tree_object, rev.diffopt.file);
+			read_tree_recursive(the_repository, (struct tree *)o, "",
+					    0, 0, &match_all, show_tree_object,
+					    rev.diffopt.file);
 			rev.shown_one = 1;
 			break;
 		case OBJ_COMMIT:
@@ -640,7 +667,7 @@ int cmd_show(int argc, const char **argv
 			ret = cmd_log_walk(&rev);
 			break;
 		default:
-			ret = error(_("Unknown type: %d"), o->type);
+			ret = error(_("unknown type: %d"), o->type);
 		}
 	}
 	free(objects);
@@ -658,7 +685,7 @@ int cmd_log_reflog(int argc, const char
 	init_log_defaults();
 	git_config(git_log_config, NULL);
 
-	init_revisions(&rev, prefix);
+	repo_init_revisions(the_repository, &rev, prefix);
 	init_reflog_walk(&rev.reflog_info);
 	rev.verbose_header = 1;
 	memset(&opt, 0, sizeof(opt));
@@ -697,7 +724,7 @@ int cmd_log(int argc, const char **argv,
 	init_log_defaults();
 	git_config(git_log_config, NULL);
 
-	init_revisions(&rev, prefix);
+	repo_init_revisions(the_repository, &rev, prefix);
 	rev.always_show_header = 1;
 	memset(&opt, 0, sizeof(opt));
 	opt.def = "HEAD";
@@ -739,23 +766,53 @@ static void add_header(const char *value
 	item->string[len] = '\0';
 }
 
-#define THREAD_SHALLOW 1
-#define THREAD_DEEP 2
-static int thread;
+enum cover_setting {
+	COVER_UNSET,
+	COVER_OFF,
+	COVER_ON,
+	COVER_AUTO
+};
+
+enum thread_level {
+	THREAD_UNSET,
+	THREAD_SHALLOW,
+	THREAD_DEEP
+};
+
+enum cover_from_description {
+	COVER_FROM_NONE,
+	COVER_FROM_MESSAGE,
+	COVER_FROM_SUBJECT,
+	COVER_FROM_AUTO
+};
+
+static enum thread_level thread;
 static int do_signoff;
 static int base_auto;
 static char *from;
 static const char *signature = git_version_string;
 static const char *signature_file;
-static int config_cover_letter;
+static enum cover_setting config_cover_letter;
 static const char *config_output_directory;
-
-enum {
-	COVER_UNSET,
-	COVER_OFF,
-	COVER_ON,
-	COVER_AUTO
-};
+static enum cover_from_description cover_from_description_mode = COVER_FROM_MESSAGE;
+static int show_notes;
+static struct display_notes_opt notes_opt;
+
+static enum cover_from_description parse_cover_from_description(const char *arg)
+{
+	if (!arg || !strcmp(arg, "default"))
+		return COVER_FROM_MESSAGE;
+	else if (!strcmp(arg, "none"))
+		return COVER_FROM_NONE;
+	else if (!strcmp(arg, "message"))
+		return COVER_FROM_MESSAGE;
+	else if (!strcmp(arg, "subject"))
+		return COVER_FROM_SUBJECT;
+	else if (!strcmp(arg, "auto"))
+		return COVER_FROM_AUTO;
+	else
+		die(_("%s: invalid cover from description mode"), arg);
+}
 
 static int git_format_config(const char *var, const char *value, void *cb)
 {
@@ -808,7 +865,7 @@ static int git_format_config(const char
 			thread = THREAD_SHALLOW;
 			return 0;
 		}
-		thread = git_config_bool(var, value) && THREAD_SHALLOW;
+		thread = git_config_bool(var, value) ? THREAD_SHALLOW : THREAD_UNSET;
 		return 0;
 	}
 	if (!strcmp(var, "format.signoff")) {
@@ -844,6 +901,20 @@ static int git_format_config(const char
 			from = NULL;
 		return 0;
 	}
+	if (!strcmp(var, "format.notes")) {
+		int b = git_parse_maybe_bool(value);
+		if (b < 0)
+			enable_ref_display_notes(&notes_opt, &show_notes, value);
+		else if (b)
+			enable_default_display_notes(&notes_opt, &show_notes);
+		else
+			disable_display_notes(&notes_opt, &show_notes);
+		return 0;
+	}
+	if (!strcmp(var, "format.coverfromdescription")) {
+		cover_from_description_mode = parse_cover_from_description(value);
+		return 0;
+	}
 
 	return git_log_config(var, value, cb);
 }
@@ -878,7 +949,7 @@ static int open_next_file(struct commit
 		printf("%s\n", filename.buf + outdir_offset);
 
 	if ((rev->diffopt.file = fopen(filename.buf, "w")) == NULL) {
-		error_errno(_("Cannot open patch file %s"), filename.buf);
+		error_errno(_("cannot open patch file %s"), filename.buf);
 		strbuf_release(&filename);
 		return -1;
 	}
@@ -895,22 +966,22 @@ static void get_patch_ids(struct rev_inf
 	unsigned flags1, flags2;
 
 	if (rev->pending.nr != 2)
-		die(_("Need exactly one range."));
+		die(_("need exactly one range"));
 
 	o1 = rev->pending.objects[0].item;
 	o2 = rev->pending.objects[1].item;
 	flags1 = o1->flags;
 	flags2 = o2->flags;
-	c1 = lookup_commit_reference(&o1->oid);
-	c2 = lookup_commit_reference(&o2->oid);
+	c1 = lookup_commit_reference(the_repository, &o1->oid);
+	c2 = lookup_commit_reference(the_repository, &o2->oid);
 
 	if ((flags1 & UNINTERESTING) == (flags2 & UNINTERESTING))
-		die(_("Not a range."));
+		die(_("not a range"));
 
-	init_patch_ids(ids);
+	init_patch_ids(the_repository, ids);
 
 	/* given a range a..b get all patch ids for b..a */
-	init_revisions(&check_rev, rev->prefix);
+	repo_init_revisions(the_repository, &check_rev, rev->prefix);
 	check_rev.max_parents = 1;
 	o1->flags ^= UNINTERESTING;
 	o2->flags ^= UNINTERESTING;
@@ -950,20 +1021,6 @@ static void print_signature(FILE *file)
 	putc('\n', file);
 }
 
-static void add_branch_description(struct strbuf *buf, const char *branch_name)
-{
-	struct strbuf desc = STRBUF_INIT;
-	if (!branch_name || !*branch_name)
-		return;
-	read_branch_desc(&desc, branch_name);
-	if (desc.len) {
-		strbuf_addch(buf, '\n');
-		strbuf_addbuf(buf, &desc);
-		strbuf_addch(buf, '\n');
-	}
-	strbuf_release(&desc);
-}
-
 static char *find_branch_name(struct rev_info *rev)
 {
 	int i, positive = -1;
@@ -986,12 +1043,87 @@ static char *find_branch_name(struct rev
 	tip_oid = &rev->cmdline.rev[positive].item->oid;
 	if (dwim_ref(ref, strlen(ref), &branch_oid, &full_ref) &&
 	    skip_prefix(full_ref, "refs/heads/", &v) &&
-	    !oidcmp(tip_oid, &branch_oid))
+	    oideq(tip_oid, &branch_oid))
 		branch = xstrdup(v);
 	free(full_ref);
 	return branch;
 }
 
+static void show_diffstat(struct rev_info *rev,
+			  struct commit *origin, struct commit *head)
+{
+	struct diff_options opts;
+
+	memcpy(&opts, &rev->diffopt, sizeof(opts));
+	opts.output_format = DIFF_FORMAT_SUMMARY | DIFF_FORMAT_DIFFSTAT;
+	diff_setup_done(&opts);
+
+	diff_tree_oid(get_commit_tree_oid(origin),
+		      get_commit_tree_oid(head),
+		      "", &opts);
+	diffcore_std(&opts);
+	diff_flush(&opts);
+
+	fprintf(rev->diffopt.file, "\n");
+}
+
+static void prepare_cover_text(struct pretty_print_context *pp,
+			       const char *branch_name,
+			       struct strbuf *sb,
+			       const char *encoding,
+			       int need_8bit_cte)
+{
+	const char *subject = "*** SUBJECT HERE ***";
+	const char *body = "*** BLURB HERE ***";
+	struct strbuf description_sb = STRBUF_INIT;
+	struct strbuf subject_sb = STRBUF_INIT;
+
+	if (cover_from_description_mode == COVER_FROM_NONE)
+		goto do_pp;
+
+	if (branch_name && *branch_name)
+		read_branch_desc(&description_sb, branch_name);
+	if (!description_sb.len)
+		goto do_pp;
+
+	if (cover_from_description_mode == COVER_FROM_SUBJECT ||
+			cover_from_description_mode == COVER_FROM_AUTO)
+		body = format_subject(&subject_sb, description_sb.buf, " ");
+
+	if (cover_from_description_mode == COVER_FROM_MESSAGE ||
+			(cover_from_description_mode == COVER_FROM_AUTO &&
+			 subject_sb.len > COVER_FROM_AUTO_MAX_SUBJECT_LEN))
+		body = description_sb.buf;
+	else
+		subject = subject_sb.buf;
+
+do_pp:
+	pp_title_line(pp, &subject, sb, encoding, need_8bit_cte);
+	pp_remainder(pp, &body, sb, 0);
+
+	strbuf_release(&description_sb);
+	strbuf_release(&subject_sb);
+}
+
+static int get_notes_refs(struct string_list_item *item, void *arg)
+{
+	argv_array_pushf(arg, "--notes=%s", item->string);
+	return 0;
+}
+
+static void get_notes_args(struct argv_array *arg, struct rev_info *rev)
+{
+	if (!rev->show_notes) {
+		argv_array_push(arg, "--no-notes");
+	} else if (rev->notes_opt.use_default_notes > 0 ||
+		   (rev->notes_opt.use_default_notes == -1 &&
+		    !rev->notes_opt.extra_notes_refs.nr)) {
+		argv_array_push(arg, "--notes");
+	} else {
+		for_each_string_list(&rev->notes_opt.extra_notes_refs, get_notes_refs, arg);
+	}
+}
+
 static void make_cover_letter(struct rev_info *rev, int use_stdout,
 			      struct commit *origin,
 			      int nr, struct commit **list,
@@ -999,25 +1131,22 @@ static void make_cover_letter(struct rev
 			      int quiet)
 {
 	const char *committer;
-	const char *body = "*** SUBJECT HERE ***\n\n*** BLURB HERE ***\n";
-	const char *msg;
 	struct shortlog log;
 	struct strbuf sb = STRBUF_INIT;
 	int i;
 	const char *encoding = "UTF-8";
-	struct diff_options opts;
 	int need_8bit_cte = 0;
 	struct pretty_print_context pp = {0};
 	struct commit *head = list[0];
 
 	if (!cmit_fmt_is_mail(rev->commit_format))
-		die(_("Cover letter needs email format"));
+		die(_("cover letter needs email format"));
 
 	committer = git_committer_info(0);
 
 	if (!use_stdout &&
 	    open_next_file(NULL, rev->numbered_files ? NULL : "cover-letter", rev, quiet))
-		return;
+		die(_("failed to create cover-letter file"));
 
 	log_write_email_headers(rev, head, &pp.after_subject, &need_8bit_cte, 0);
 
@@ -1031,15 +1160,12 @@ static void make_cover_letter(struct rev
 	if (!branch_name)
 		branch_name = find_branch_name(rev);
 
-	msg = body;
 	pp.fmt = CMIT_FMT_EMAIL;
 	pp.date_mode.type = DATE_RFC2822;
 	pp.rev = rev;
 	pp.print_email_subject = 1;
 	pp_user_info(&pp, NULL, &sb, committer, encoding);
-	pp_title_line(&pp, &msg, &sb, encoding, need_8bit_cte);
-	pp_remainder(&pp, &msg, &sb, 0);
-	add_branch_description(&sb, branch_name);
+	prepare_cover_text(&pp, branch_name, &sb, encoding, need_8bit_cte);
 	fprintf(rev->diffopt.file, "%s\n", sb.buf);
 
 	strbuf_release(&sb);
@@ -1055,25 +1181,32 @@ static void make_cover_letter(struct rev
 
 	shortlog_output(&log);
 
-	/*
-	 * We can only do diffstat with a unique reference point
-	 */
-	if (!origin)
-		return;
+	/* We can only do diffstat with a unique reference point */
+	if (origin)
+		show_diffstat(rev, origin, head);
 
-	memcpy(&opts, &rev->diffopt, sizeof(opts));
-	opts.output_format = DIFF_FORMAT_SUMMARY | DIFF_FORMAT_DIFFSTAT;
-	opts.stat_width = MAIL_DEFAULT_WRAP;
-
-	diff_setup_done(&opts);
-
-	diff_tree_oid(get_commit_tree_oid(origin),
-		      get_commit_tree_oid(head),
-		      "", &opts);
-	diffcore_std(&opts);
-	diff_flush(&opts);
+	if (rev->idiff_oid1) {
+		fprintf_ln(rev->diffopt.file, "%s", rev->idiff_title);
+		show_interdiff(rev, 0);
+	}
 
-	fprintf(rev->diffopt.file, "\n");
+	if (rev->rdiff1) {
+		/*
+		 * Pass minimum required diff-options to range-diff; others
+		 * can be added later if deemed desirable.
+		 */
+		struct diff_options opts;
+		struct argv_array other_arg = ARGV_ARRAY_INIT;
+		diff_setup(&opts);
+		opts.file = rev->diffopt.file;
+		opts.use_color = rev->diffopt.use_color;
+		diff_setup_done(&opts);
+		fprintf_ln(rev->diffopt.file, "%s", rev->rdiff_title);
+		get_notes_args(&other_arg, rev);
+		show_range_diff(rev->rdiff1, rev->rdiff2,
+				rev->creation_factor, 1, &opts, &other_arg);
+		argv_array_clear(&other_arg);
+	}
 }
 
 static const char *clean_message_id(const char *msg_id)
@@ -1127,6 +1260,8 @@ static int keep_subject = 0;
 
 static int keep_callback(const struct option *opt, const char *arg, int unset)
 {
+	BUG_ON_OPT_NEG(unset);
+	BUG_ON_OPT_ARG(arg);
 	((struct rev_info *)opt->value)->total = -1;
 	keep_subject = 1;
 	return 0;
@@ -1137,6 +1272,7 @@ static int subject_prefix = 0;
 static int subject_prefix_callback(const struct option *opt, const char *arg,
 			    int unset)
 {
+	BUG_ON_OPT_NEG(unset);
 	subject_prefix = 1;
 	((struct rev_info *)opt->value)->subject_prefix = arg;
 	return 0;
@@ -1144,6 +1280,8 @@ static int subject_prefix_callback(const
 
 static int rfc_callback(const struct option *opt, const char *arg, int unset)
 {
+	BUG_ON_OPT_NEG(unset);
+	BUG_ON_OPT_ARG(arg);
 	return subject_prefix_callback(opt, "RFC PATCH", unset);
 }
 
@@ -1152,6 +1290,7 @@ static int numbered_cmdline_opt = 0;
 static int numbered_callback(const struct option *opt, const char *arg,
 			     int unset)
 {
+	BUG_ON_OPT_ARG(arg);
 	*(int *)opt->value = numbered_cmdline_opt = unset ? 0 : 1;
 	if (unset)
 		auto_number =  0;
@@ -1161,6 +1300,7 @@ static int numbered_callback(const struc
 static int no_numbered_callback(const struct option *opt, const char *arg,
 				int unset)
 {
+	BUG_ON_OPT_NEG(unset);
 	return numbered_callback(opt, arg, 1);
 }
 
@@ -1168,21 +1308,26 @@ static int output_directory_callback(con
 			      int unset)
 {
 	const char **dir = (const char **)opt->value;
+	BUG_ON_OPT_NEG(unset);
 	if (*dir)
-		die(_("Two output directories?"));
+		die(_("two output directories?"));
 	*dir = arg;
 	return 0;
 }
 
 static int thread_callback(const struct option *opt, const char *arg, int unset)
 {
-	int *thread = (int *)opt->value;
+	enum thread_level *thread = (enum thread_level *)opt->value;
 	if (unset)
-		*thread = 0;
+		*thread = THREAD_UNSET;
 	else if (!arg || !strcmp(arg, "shallow"))
 		*thread = THREAD_SHALLOW;
 	else if (!strcmp(arg, "deep"))
 		*thread = THREAD_DEEP;
+	/*
+	 * Please update _git_formatpatch() in git-completion.bash
+	 * when you add new options.
+	 */
 	else
 		return 1;
 	return 0;
@@ -1221,7 +1366,7 @@ static int header_callback(const struct
 		string_list_clear(&extra_to, 0);
 		string_list_clear(&extra_cc, 0);
 	} else {
-	    add_header(arg);
+		add_header(arg);
 	}
 	return 0;
 }
@@ -1276,8 +1421,8 @@ static struct commit *get_base_commit(co
 	if (base_commit && strcmp(base_commit, "auto")) {
 		base = lookup_commit_reference_by_name(base_commit);
 		if (!base)
-			die(_("Unknown commit %s"), base_commit);
-	} else if ((base_commit && !strcmp(base_commit, "auto")) || base_auto) {
+			die(_("unknown commit %s"), base_commit);
+	} else if ((base_commit && !strcmp(base_commit, "auto"))) {
 		struct branch *curr_branch = branch_get(NULL);
 		const char *upstream = branch_get_upstream(curr_branch, NULL);
 		if (upstream) {
@@ -1286,18 +1431,18 @@ static struct commit *get_base_commit(co
 			struct object_id oid;
 
 			if (get_oid(upstream, &oid))
-				die(_("Failed to resolve '%s' as a valid ref."), upstream);
+				die(_("failed to resolve '%s' as a valid ref"), upstream);
 			commit = lookup_commit_or_die(&oid, "upstream base");
 			base_list = get_merge_bases_many(commit, total, list);
 			/* There should be one and only one merge base. */
 			if (!base_list || base_list->next)
-				die(_("Could not find exact merge base."));
+				die(_("could not find exact merge base"));
 			base = base_list->item;
 			free_commit_list(base_list);
 		} else {
-			die(_("Failed to get upstream, if you want to record base commit automatically,\n"
+			die(_("failed to get upstream, if you want to record base commit automatically,\n"
 			      "please use git branch --set-upstream-to to track a remote branch.\n"
-			      "Or you could specify base commit by --base=<base-commit-id> manually."));
+			      "Or you could specify base commit by --base=<base-commit-id> manually"));
 		}
 	}
 
@@ -1315,7 +1460,7 @@ static struct commit *get_base_commit(co
 			struct commit_list *merge_base;
 			merge_base = get_merge_bases(rev[2 * i], rev[2 * i + 1]);
 			if (!merge_base || merge_base->next)
-				die(_("Failed to find exact merge base"));
+				die(_("failed to find exact merge base"));
 
 			rev[i] = merge_base->item;
 		}
@@ -1337,6 +1482,8 @@ static struct commit *get_base_commit(co
 	return base;
 }
 
+define_commit_slab(commit_base, int);
+
 static void prepare_bases(struct base_tree_info *bases,
 			  struct commit *base,
 			  struct commit **list,
@@ -1345,24 +1492,26 @@ static void prepare_bases(struct base_tr
 	struct commit *commit;
 	struct rev_info revs;
 	struct diff_options diffopt;
+	struct commit_base commit_base;
 	int i;
 
 	if (!base)
 		return;
 
-	diff_setup(&diffopt);
+	init_commit_base(&commit_base);
+	repo_diff_setup(the_repository, &diffopt);
 	diffopt.flags.recursive = 1;
 	diff_setup_done(&diffopt);
 
 	oidcpy(&bases->base_commit, &base->object.oid);
 
-	init_revisions(&revs, NULL);
+	repo_init_revisions(the_repository, &revs, NULL);
 	revs.max_parents = 1;
 	revs.topo_order = 1;
 	for (i = 0; i < total; i++) {
 		list[i]->object.flags &= ~UNINTERESTING;
 		add_pending_object(&revs, &list[i]->object, "rev_list");
-		list[i]->util = (void *)1;
+		*commit_base_at(&commit_base, list[i]) = 1;
 	}
 	base->object.flags |= UNINTERESTING;
 	add_pending_object(&revs, &base->object, "base");
@@ -1376,15 +1525,16 @@ static void prepare_bases(struct base_tr
 	while ((commit = get_revision(&revs)) != NULL) {
 		struct object_id oid;
 		struct object_id *patch_id;
-		if (commit->util)
+		if (*commit_base_at(&commit_base, commit))
 			continue;
-		if (commit_patch_id(commit, &diffopt, &oid, 0))
+		if (commit_patch_id(commit, &diffopt, &oid, 0, 1))
 			die(_("cannot get patch id"));
 		ALLOC_GROW(bases->patch_id, bases->nr_patch_id + 1, bases->alloc_patch_id);
 		patch_id = bases->patch_id + bases->nr_patch_id;
 		oidcpy(patch_id, &oid);
 		bases->nr_patch_id++;
 	}
+	clear_commit_base(&commit_base);
 }
 
 static void print_bases(struct base_tree_info *bases, FILE *file)
@@ -1408,6 +1558,36 @@ static void print_bases(struct base_tree
 	oidclr(&bases->base_commit);
 }
 
+static const char *diff_title(struct strbuf *sb, int reroll_count,
+		       const char *generic, const char *rerolled)
+{
+	if (reroll_count <= 0)
+		strbuf_addstr(sb, generic);
+	else /* RFC may be v0, so allow -v1 to diff against v0 */
+		strbuf_addf(sb, rerolled, reroll_count - 1);
+	return sb->buf;
+}
+
+static void infer_range_diff_ranges(struct strbuf *r1,
+				    struct strbuf *r2,
+				    const char *prev,
+				    struct commit *origin,
+				    struct commit *head)
+{
+	const char *head_oid = oid_to_hex(&head->object.oid);
+
+	if (!strstr(prev, "..")) {
+		strbuf_addf(r1, "%s..%s", head_oid, prev);
+		strbuf_addf(r2, "%s..%s", prev, head_oid);
+	} else if (!origin) {
+		die(_("failed to infer range-diff ranges"));
+	} else {
+		strbuf_addstr(r1, prev);
+		strbuf_addf(r2, "%s..%s",
+			    oid_to_hex(&origin->object.oid), head_oid);
+	}
+}
+
 int cmd_format_patch(int argc, const char **argv, const char *prefix)
 {
 	struct commit *commit;
@@ -1430,11 +1610,19 @@ int cmd_format_patch(int argc, const cha
 	int use_patch_format = 0;
 	int quiet = 0;
 	int reroll_count = -1;
+	char *cover_from_description_arg = NULL;
 	char *branch_name = NULL;
 	char *base_commit = NULL;
 	struct base_tree_info bases;
 	int show_progress = 0;
 	struct progress *progress = NULL;
+	struct oid_array idiff_prev = OID_ARRAY_INIT;
+	struct strbuf idiff_title = STRBUF_INIT;
+	const char *rdiff_prev = NULL;
+	struct strbuf rdiff1 = STRBUF_INIT;
+	struct strbuf rdiff2 = STRBUF_INIT;
+	struct strbuf rdiff_title = STRBUF_INIT;
+	int creation_factor = -1;
 
 	const struct option builtin_format_patch_options[] = {
 		{ OPTION_CALLBACK, 'n', "numbered", &numbered, NULL,
@@ -1442,7 +1630,7 @@ int cmd_format_patch(int argc, const cha
 			    PARSE_OPT_NOARG, numbered_callback },
 		{ OPTION_CALLBACK, 'N', "no-numbered", &numbered, NULL,
 			    N_("use [PATCH] even with multiple patches"),
-			    PARSE_OPT_NOARG, no_numbered_callback },
+			    PARSE_OPT_NOARG | PARSE_OPT_NONEG, no_numbered_callback },
 		OPT_BOOL('s', "signoff", &do_signoff, N_("add Signed-off-by:")),
 		OPT_BOOL(0, "stdout", &use_stdout,
 			    N_("print patches to standard out")),
@@ -1459,6 +1647,9 @@ int cmd_format_patch(int argc, const cha
 		{ OPTION_CALLBACK, 0, "rfc", &rev, NULL,
 			    N_("Use [RFC PATCH] instead of [PATCH]"),
 			    PARSE_OPT_NOARG | PARSE_OPT_NONEG, rfc_callback },
+		OPT_STRING(0, "cover-from-description", &cover_from_description_arg,
+			    N_("cover-from-description-mode"),
+			    N_("generate parts of a cover letter based on a branch's description")),
 		{ OPTION_CALLBACK, 0, "subject-prefix", &rev, N_("prefix"),
 			    N_("Use [<prefix>] instead of [PATCH]"),
 			    PARSE_OPT_NONEG, subject_prefix_callback },
@@ -1508,6 +1699,13 @@ int cmd_format_patch(int argc, const cha
 		OPT__QUIET(&quiet, N_("don't print the patch filenames")),
 		OPT_BOOL(0, "progress", &show_progress,
 			 N_("show progress while generating patches")),
+		OPT_CALLBACK(0, "interdiff", &idiff_prev, N_("rev"),
+			     N_("show changes against <rev> in cover letter or single patch"),
+			     parse_opt_object_name),
+		OPT_STRING(0, "range-diff", &rdiff_prev, N_("refspec"),
+			   N_("show changes against <refspec> in cover letter or single patch")),
+		OPT_INTEGER(0, "creation-factor", &creation_factor,
+			    N_("percentage by which creation is weighted")),
 		OPT_END()
 	};
 
@@ -1515,8 +1713,11 @@ int cmd_format_patch(int argc, const cha
 	extra_to.strdup_strings = 1;
 	extra_cc.strdup_strings = 1;
 	init_log_defaults();
+	init_display_notes(&notes_opt);
 	git_config(git_format_config, NULL);
-	init_revisions(&rev, prefix);
+	repo_init_revisions(the_repository, &rev, prefix);
+	rev.show_notes = show_notes;
+	memcpy(&rev.notes_opt, &notes_opt, sizeof(notes_opt));
 	rev.commit_format = CMIT_FMT_EMAIL;
 	rev.expand_tabs_in_log_default = 0;
 	rev.verbose_header = 1;
@@ -1528,6 +1729,9 @@ int cmd_format_patch(int argc, const cha
 	s_r_opt.def = "HEAD";
 	s_r_opt.revarg_opt = REVARG_COMMITTISH;
 
+	if (base_auto)
+		base_commit = "auto";
+
 	if (default_attach) {
 		rev.mime_boundary = default_attach;
 		rev.no_inline = 1;
@@ -1543,6 +1747,9 @@ int cmd_format_patch(int argc, const cha
 			     PARSE_OPT_KEEP_ARGV0 | PARSE_OPT_KEEP_UNKNOWN |
 			     PARSE_OPT_KEEP_DASHDASH);
 
+	if (cover_from_description_arg)
+		cover_from_description_mode = parse_cover_from_description(cover_from_description_arg);
+
 	if (0 < reroll_count) {
 		struct strbuf sprefix = STRBUF_INIT;
 		strbuf_addf(&sprefix, "%s v%d",
@@ -1597,14 +1804,14 @@ int cmd_format_patch(int argc, const cha
 		numbered = 0;
 
 	if (numbered && keep_subject)
-		die (_("-n and -k are mutually exclusive."));
+		die(_("-n and -k are mutually exclusive"));
 	if (keep_subject && subject_prefix)
-		die (_("--subject-prefix/--rfc and -k are mutually exclusive."));
+		die(_("--subject-prefix/--rfc and -k are mutually exclusive"));
 	rev.preserve_subject = keep_subject;
 
 	argc = setup_revisions(argc, argv, &rev, &s_r_opt);
 	if (argc > 1)
-		die (_("unrecognized argument: %s"), argv[1]);
+		die(_("unrecognized argument: %s"), argv[1]);
 
 	if (rev.diffopt.output_format & DIFF_FORMAT_NAME)
 		die(_("--name-only does not make sense"));
@@ -1629,7 +1836,7 @@ int cmd_format_patch(int argc, const cha
 		rev.diffopt.flags.binary = 1;
 
 	if (rev.show_notes)
-		init_display_notes(&rev.notes_opt);
+		load_display_notes(&rev.notes_opt);
 
 	if (!output_directory && !use_stdout)
 		output_directory = config_output_directory;
@@ -1640,12 +1847,28 @@ int cmd_format_patch(int argc, const cha
 		setup_pager();
 
 	if (output_directory) {
+		int saved;
 		if (rev.diffopt.use_color != GIT_COLOR_ALWAYS)
 			rev.diffopt.use_color = GIT_COLOR_NEVER;
 		if (use_stdout)
 			die(_("standard output, or directory, which one?"));
+		/*
+		 * We consider <outdir> as 'outside of gitdir', therefore avoid
+		 * applying adjust_shared_perm in s-c-l-d.
+		 */
+		saved = get_shared_repository();
+		set_shared_repository(0);
+		switch (safe_create_leading_directories_const(output_directory)) {
+		case SCLD_OK:
+		case SCLD_EXISTS:
+			break;
+		default:
+			die(_("could not create leading directories "
+			      "of '%s'"), output_directory);
+		}
+		set_shared_repository(saved);
 		if (mkdir(output_directory, 0777) < 0 && errno != EEXIST)
-			die_errno(_("Could not create directory '%s'"),
+			die_errno(_("could not create directory '%s'"),
 				  output_directory);
 	}
 
@@ -1692,8 +1915,8 @@ int cmd_format_patch(int argc, const cha
 		/* Don't say anything if head and upstream are the same. */
 		if (rev.pending.nr == 2) {
 			struct object_array_entry *o = rev.pending.objects;
-			if (oidcmp(&o[0].item->oid, &o[1].item->oid) == 0)
-				return 0;
+			if (oideq(&o[0].item->oid, &o[1].item->oid))
+				goto done;
 		}
 		get_patch_ids(&rev, &ids);
 	}
@@ -1717,7 +1940,7 @@ int cmd_format_patch(int argc, const cha
 	}
 	if (nr == 0)
 		/* nothing to do */
-		return 0;
+		goto done;
 	total = nr;
 	if (cover_letter == -1) {
 		if (config_cover_letter == COVER_AUTO)
@@ -1730,6 +1953,35 @@ int cmd_format_patch(int argc, const cha
 	if (numbered)
 		rev.total = total + start_number - 1;
 
+	if (idiff_prev.nr) {
+		if (!cover_letter && total != 1)
+			die(_("--interdiff requires --cover-letter or single patch"));
+		rev.idiff_oid1 = &idiff_prev.oid[idiff_prev.nr - 1];
+		rev.idiff_oid2 = get_commit_tree_oid(list[0]);
+		rev.idiff_title = diff_title(&idiff_title, reroll_count,
+					     _("Interdiff:"),
+					     _("Interdiff against v%d:"));
+	}
+
+	if (creation_factor < 0)
+		creation_factor = RANGE_DIFF_CREATION_FACTOR_DEFAULT;
+	else if (!rdiff_prev)
+		die(_("--creation-factor requires --range-diff"));
+
+	if (rdiff_prev) {
+		if (!cover_letter && total != 1)
+			die(_("--range-diff requires --cover-letter or single patch"));
+
+		infer_range_diff_ranges(&rdiff1, &rdiff2, rdiff_prev,
+					origin, list[0]);
+		rev.rdiff1 = rdiff1.buf;
+		rev.rdiff2 = rdiff2.buf;
+		rev.creation_factor = creation_factor;
+		rev.rdiff_title = diff_title(&rdiff_title, reroll_count,
+					     _("Range-diff:"),
+					     _("Range-diff against v%d:"));
+	}
+
 	if (!signature) {
 		; /* --no-signature inhibits all signatures */
 	} else if (signature && signature != git_version_string) {
@@ -1743,9 +1995,10 @@ int cmd_format_patch(int argc, const cha
 	}
 
 	memset(&bases, 0, sizeof(bases));
-	if (base_commit || base_auto) {
+	if (base_commit) {
 		struct commit *base = get_base_commit(base_commit, list, nr);
 		reset_revision_walk();
+		clear_object_flags(UNINTERESTING);
 		prepare_bases(&bases, base, list, nr);
 	}
 
@@ -1766,6 +2019,9 @@ int cmd_format_patch(int argc, const cha
 		print_signature(rev.diffopt.file);
 		total++;
 		start_number--;
+		/* interdiff/range-diff in cover-letter; omit from patches */
+		rev.idiff_oid1 = NULL;
+		rev.rdiff1 = NULL;
 	}
 	rev.add_signoff = do_signoff;
 
@@ -1814,9 +2070,10 @@ int cmd_format_patch(int argc, const cha
 
 		if (!use_stdout &&
 		    open_next_file(rev.numbered_files ? NULL : commit, NULL, &rev, quiet))
-			die(_("Failed to create output files"));
+			die(_("failed to create output files"));
 		shown = log_tree_commit(&rev, commit);
-		free_commit_buffer(commit);
+		free_commit_buffer(the_repository->parsed_objects,
+				   commit);
 
 		/* We put one extra blank line between formatted
 		 * patches and this flag is used by log-tree code
@@ -1846,6 +2103,13 @@ int cmd_format_patch(int argc, const cha
 	string_list_clear(&extra_hdr, 0);
 	if (ignore_if_in_upstream)
 		free_patch_ids(&ids);
+
+done:
+	oid_array_clear(&idiff_prev);
+	strbuf_release(&idiff_title);
+	strbuf_release(&rdiff1);
+	strbuf_release(&rdiff2);
+	strbuf_release(&rdiff_title);
 	return 0;
 }
 
@@ -1853,7 +2117,8 @@ static int add_pending_commit(const char
 {
 	struct object_id oid;
 	if (get_oid(arg, &oid) == 0) {
-		struct commit *commit = lookup_commit_reference(&oid);
+		struct commit *commit = lookup_commit_reference(the_repository,
+								&oid);
 		if (commit) {
 			commit->object.flags |= flags;
 			add_pending_object(revs, &commit->object, arg);
@@ -1925,25 +2190,25 @@ int cmd_cherry(int argc, const char **ar
 		}
 	}
 
-	init_revisions(&revs, prefix);
+	repo_init_revisions(the_repository, &revs, prefix);
 	revs.max_parents = 1;
 
 	if (add_pending_commit(head, &revs, 0))
-		die(_("Unknown commit %s"), head);
+		die(_("unknown commit %s"), head);
 	if (add_pending_commit(upstream, &revs, UNINTERESTING))
-		die(_("Unknown commit %s"), upstream);
+		die(_("unknown commit %s"), upstream);
 
 	/* Don't say anything if head and upstream are the same. */
 	if (revs.pending.nr == 2) {
 		struct object_array_entry *o = revs.pending.objects;
-		if (oidcmp(&o[0].item->oid, &o[1].item->oid) == 0)
+		if (oideq(&o[0].item->oid, &o[1].item->oid))
 			return 0;
 	}
 
 	get_patch_ids(&revs, &ids);
 
 	if (limit && add_pending_commit(limit, &revs, UNINTERESTING))
-		die(_("Unknown commit %s"), limit);
+		die(_("unknown commit %s"), limit);
 
 	/* reverse the list of commits */
 	if (prepare_revision_walk(&revs))
diff -pruN 1.2.1+git2.18.0-1/git/builtin/ls-files.c 1.2.3+git2.25.1-1/git/builtin/ls-files.c
--- 1.2.1+git2.18.0-1/git/builtin/ls-files.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/builtin/ls-files.c	2020-02-17 04:47:35.000000000 +0000
@@ -5,7 +5,6 @@
  *
  * Copyright (C) Linus Torvalds, 2005
  */
-#define NO_THE_INDEX_COMPATIBILITY_MACROS
 #include "cache.h"
 #include "repository.h"
 #include "config.h"
@@ -63,7 +62,7 @@ static void write_eolinfo(const struct i
 		struct stat st;
 		const char *i_txt = "";
 		const char *w_txt = "";
-		const char *a_txt = get_convert_attr_ascii(path);
+		const char *a_txt = get_convert_attr_ascii(istate, path);
 		if (ce && S_ISREG(ce->ce_mode))
 			i_txt = get_cached_convert_stats_ascii(istate,
 							       ce->name);
@@ -113,26 +112,27 @@ static void print_debug(const struct cac
 	if (debug_mode) {
 		const struct stat_data *sd = &ce->ce_stat_data;
 
-		printf("  ctime: %d:%d\n", sd->sd_ctime.sec, sd->sd_ctime.nsec);
-		printf("  mtime: %d:%d\n", sd->sd_mtime.sec, sd->sd_mtime.nsec);
-		printf("  dev: %d\tino: %d\n", sd->sd_dev, sd->sd_ino);
-		printf("  uid: %d\tgid: %d\n", sd->sd_uid, sd->sd_gid);
-		printf("  size: %d\tflags: %x\n", sd->sd_size, ce->ce_flags);
+		printf("  ctime: %u:%u\n", sd->sd_ctime.sec, sd->sd_ctime.nsec);
+		printf("  mtime: %u:%u\n", sd->sd_mtime.sec, sd->sd_mtime.nsec);
+		printf("  dev: %u\tino: %u\n", sd->sd_dev, sd->sd_ino);
+		printf("  uid: %u\tgid: %u\n", sd->sd_uid, sd->sd_gid);
+		printf("  size: %u\tflags: %x\n", sd->sd_size, ce->ce_flags);
 	}
 }
 
-static void show_dir_entry(const char *tag, struct dir_entry *ent)
+static void show_dir_entry(const struct index_state *istate,
+			   const char *tag, struct dir_entry *ent)
 {
 	int len = max_prefix_len;
 
 	if (len > ent->len)
 		die("git ls-files: internal error - directory entry not superset of prefix");
 
-	if (!dir_path_match(ent, &pathspec, len, ps_matched))
+	if (!dir_path_match(istate, ent, &pathspec, len, ps_matched))
 		return;
 
 	fputs(tag, stdout);
-	write_eolinfo(NULL, NULL, ent->name);
+	write_eolinfo(istate, NULL, ent->name);
 	write_name(ent->name);
 }
 
@@ -145,7 +145,7 @@ static void show_other_files(const struc
 		struct dir_entry *ent = dir->entries[i];
 		if (!index_name_is_other(istate, ent->name, ent->len))
 			continue;
-		show_dir_entry(tag_other, ent);
+		show_dir_entry(istate, tag_other, ent);
 	}
 }
 
@@ -196,7 +196,7 @@ static void show_killed_files(const stru
 			}
 		}
 		if (killed)
-			show_dir_entry(tag_killed, dir->entries[i]);
+			show_dir_entry(istate, tag_killed, dir->entries[i]);
 	}
 }
 
@@ -205,17 +205,19 @@ static void show_files(struct repository
 static void show_submodule(struct repository *superproject,
 			   struct dir_struct *dir, const char *path)
 {
-	struct repository submodule;
+	struct repository subrepo;
+	const struct submodule *sub = submodule_from_path(superproject,
+							  &null_oid, path);
 
-	if (repo_submodule_init(&submodule, superproject, path))
+	if (repo_submodule_init(&subrepo, superproject, sub))
 		return;
 
-	if (repo_read_index(&submodule) < 0)
+	if (repo_read_index(&subrepo) < 0)
 		die("index file corrupt");
 
-	show_files(&submodule, dir);
+	show_files(&subrepo, dir);
 
-	repo_clear(&submodule);
+	repo_clear(&subrepo);
 }
 
 static void show_ce(struct repository *repo, struct dir_struct *dir,
@@ -228,7 +230,7 @@ static void show_ce(struct repository *r
 	if (recurse_submodules && S_ISGITLINK(ce->ce_mode) &&
 	    is_submodule_active(repo, ce->name)) {
 		show_submodule(repo, dir, ce->name);
-	} else if (match_pathspec(&pathspec, fullname, strlen(fullname),
+	} else if (match_pathspec(repo->index, &pathspec, fullname, strlen(fullname),
 				  max_prefix_len, ps_matched,
 				  S_ISDIR(ce->ce_mode) ||
 				  S_ISGITLINK(ce->ce_mode))) {
@@ -264,7 +266,7 @@ static void show_ru_info(const struct in
 		len = strlen(path);
 		if (len < max_prefix_len)
 			continue; /* outside of the prefix */
-		if (!match_pathspec(&pathspec, path, len,
+		if (!match_pathspec(istate, &pathspec, path, len,
 				    max_prefix_len, ps_matched, 0))
 			continue; /* uninterested */
 		for (i = 0; i < 3; i++) {
@@ -371,7 +373,7 @@ static void prune_index(struct index_sta
 	first = pos;
 	last = istate->cache_nr;
 	while (last > first) {
-		int next = (last + first) >> 1;
+		int next = first + ((last - first) >> 1);
 		const struct cache_entry *ce = istate->cache[next];
 		if (!strncmp(ce->name, prefix, prefixlen)) {
 			first = next+1;
@@ -440,7 +442,7 @@ void overlay_tree_on_index(struct index_
 			       PATHSPEC_PREFER_CWD, prefix, matchbuf);
 	} else
 		memset(&pathspec, 0, sizeof(pathspec));
-	if (read_tree(tree, 1, &pathspec, istate))
+	if (read_tree(the_repository, tree, 1, &pathspec, istate))
 		die("unable to read tree entries %s", tree_name);
 
 	for (i = 0; i < istate->cache_nr; i++) {
@@ -474,6 +476,8 @@ static int option_parse_exclude(const st
 {
 	struct string_list *exclude_list = opt->value;
 
+	BUG_ON_OPT_NEG(unset);
+
 	exc_given = 1;
 	string_list_append(exclude_list, arg);
 
@@ -485,8 +489,10 @@ static int option_parse_exclude_from(con
 {
 	struct dir_struct *dir = opt->value;
 
+	BUG_ON_OPT_NEG(unset);
+
 	exc_given = 1;
-	add_excludes_from_file(dir, arg);
+	add_patterns_from_file(dir, arg);
 
 	return 0;
 }
@@ -496,6 +502,9 @@ static int option_parse_exclude_standard
 {
 	struct dir_struct *dir = opt->value;
 
+	BUG_ON_OPT_NEG(unset);
+	BUG_ON_OPT_ARG(arg);
+
 	exc_given = 1;
 	setup_standard_excludes(dir);
 
@@ -507,7 +516,7 @@ int cmd_ls_files(int argc, const char **
 	int require_work_tree = 0, show_tag = 0, i;
 	const char *max_prefix;
 	struct dir_struct dir;
-	struct exclude_list *el;
+	struct pattern_list *pl;
 	struct string_list exclude_list = STRING_LIST_INIT_NODUP;
 	struct option builtin_ls_files_options[] = {
 		/* Think twice before adding "--nul" synonym to this */
@@ -547,15 +556,16 @@ int cmd_ls_files(int argc, const char **
 			    N_("show resolve-undo information")),
 		{ OPTION_CALLBACK, 'x', "exclude", &exclude_list, N_("pattern"),
 			N_("skip files matching pattern"),
-			0, option_parse_exclude },
+			PARSE_OPT_NONEG, option_parse_exclude },
 		{ OPTION_CALLBACK, 'X', "exclude-from", &dir, N_("file"),
 			N_("exclude patterns are read from <file>"),
-			0, option_parse_exclude_from },
+			PARSE_OPT_NONEG, option_parse_exclude_from },
 		OPT_STRING(0, "exclude-per-directory", &dir.exclude_per_dir, N_("file"),
 			N_("read additional per-directory exclude patterns in <file>")),
 		{ OPTION_CALLBACK, 0, "exclude-standard", &dir, NULL,
 			N_("add the standard git exclusions"),
-			PARSE_OPT_NOARG, option_parse_exclude_standard },
+			PARSE_OPT_NOARG | PARSE_OPT_NONEG,
+			option_parse_exclude_standard },
 		OPT_SET_INT_F(0, "full-name", &prefix_len,
 			      N_("make the output relative to the project top directory"),
 			      0, PARSE_OPT_NONEG),
@@ -584,9 +594,9 @@ int cmd_ls_files(int argc, const char **
 
 	argc = parse_options(argc, argv, prefix, builtin_ls_files_options,
 			ls_files_usage, 0);
-	el = add_exclude_list(&dir, EXC_CMDL, "--exclude option");
+	pl = add_pattern_list(&dir, EXC_CMDL, "--exclude option");
 	for (i = 0; i < exclude_list.nr; i++) {
-		add_exclude(exclude_list.items[i].string, "", 0, el, --exclude_args);
+		add_pattern(exclude_list.items[i].string, "", 0, pl, --exclude_args);
 	}
 	if (show_tag || show_valid_bit || show_fsmonitor_bit) {
 		tag_cached = "H ";
@@ -670,7 +680,7 @@ int cmd_ls_files(int argc, const char **
 
 	if (ps_matched) {
 		int bad;
-		bad = report_path_error(ps_matched, &pathspec, prefix);
+		bad = report_path_error(ps_matched, &pathspec);
 		if (bad)
 			fprintf(stderr, "Did you forget to 'git add'?\n");
 
diff -pruN 1.2.1+git2.18.0-1/git/builtin/ls-remote.c 1.2.3+git2.25.1-1/git/builtin/ls-remote.c
--- 1.2.1+git2.18.0-1/git/builtin/ls-remote.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/builtin/ls-remote.c	2020-02-17 04:47:35.000000000 +0000
@@ -67,8 +67,7 @@ int cmd_ls_remote(int argc, const char *
 		OPT_BIT(0, "refs", &flags, N_("do not show peeled tags"), REF_NORMAL),
 		OPT_BOOL(0, "get-url", &get_url,
 			 N_("take url.<base>.insteadOf into account")),
-		OPT_CALLBACK(0 , "sort", sorting_tail, N_("key"),
-			     N_("field name to sort on"), &parse_opt_ref_sorting),
+		OPT_REF_SORT(sorting_tail),
 		OPT_SET_INT_F(0, "exit-code", &status,
 			      N_("exit with exit code 2 if no matching refs are found"),
 			      2, PARSE_OPT_NOCOMPLETE),
@@ -88,18 +87,15 @@ int cmd_ls_remote(int argc, const char *
 		int i;
 		pattern = xcalloc(argc, sizeof(const char *));
 		for (i = 1; i < argc; i++) {
-			const char *glob;
 			pattern[i - 1] = xstrfmt("*/%s", argv[i]);
-
-			glob = strchr(argv[i], '*');
-			if (glob)
-				argv_array_pushf(&ref_prefixes, "%.*s",
-						 (int)(glob - argv[i]), argv[i]);
-			else
-				expand_ref_prefix(&ref_prefixes, argv[i]);
 		}
 	}
 
+	if (flags & REF_TAGS)
+		argv_array_push(&ref_prefixes, "refs/tags/");
+	if (flags & REF_HEADS)
+		argv_array_push(&ref_prefixes, "refs/heads/");
+
 	remote = remote_get(dest);
 	if (!remote) {
 		if (dest)
@@ -151,6 +147,6 @@ int cmd_ls_remote(int argc, const char *
 	}
 
 	UNLEAK(sorting);
-	UNLEAK(ref_array);
+	ref_array_clear(&ref_array);
 	return status;
 }
diff -pruN 1.2.1+git2.18.0-1/git/builtin/ls-tree.c 1.2.3+git2.25.1-1/git/builtin/ls-tree.c
--- 1.2.1+git2.18.0-1/git/builtin/ls-tree.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/builtin/ls-tree.c	2020-02-17 04:47:35.000000000 +0000
@@ -5,6 +5,7 @@
  */
 #include "cache.h"
 #include "config.h"
+#include "object-store.h"
 #include "blob.h"
 #include "tree.h"
 #include "commit.h"
@@ -99,7 +100,7 @@ static int show_tree(const struct object
 						  "BAD");
 				else
 					xsnprintf(size_text, sizeof(size_text),
-						  "%lu", size);
+						  "%"PRIuMAX, (uintmax_t)size);
 			} else
 				xsnprintf(size_text, sizeof(size_text), "-");
 			printf("%06o %s %s %7s\t", mode, type,
@@ -184,5 +185,6 @@ int cmd_ls_tree(int argc, const char **a
 	tree = parse_tree_indirect(&oid);
 	if (!tree)
 		die("not a tree object");
-	return !!read_tree_recursive(tree, "", 0, 0, &pathspec, show_tree, NULL);
+	return !!read_tree_recursive(the_repository, tree, "", 0, 0,
+				     &pathspec, show_tree, NULL);
 }
diff -pruN 1.2.1+git2.18.0-1/git/builtin/merge-base.c 1.2.3+git2.25.1-1/git/builtin/merge-base.c
--- 1.2.1+git2.18.0-1/git/builtin/merge-base.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/builtin/merge-base.c	2020-02-17 04:47:35.000000000 +0000
@@ -6,6 +6,8 @@
 #include "diff.h"
 #include "revision.h"
 #include "parse-options.h"
+#include "repository.h"
+#include "commit-reach.h"
 
 static int show_merge_base(struct commit **rev, int rev_nr, int show_all)
 {
@@ -42,7 +44,7 @@ static struct commit *get_commit_referen
 
 	if (get_oid(arg, &revkey))
 		die("Not a valid object name %s", arg);
-	r = lookup_commit_reference(&revkey);
+	r = lookup_commit_reference(the_repository, &revkey);
 	if (!r)
 		die("Not a valid commit name %s", arg);
 
@@ -109,54 +111,12 @@ static int handle_is_ancestor(int argc,
 		return 1;
 }
 
-struct rev_collect {
-	struct commit **commit;
-	int nr;
-	int alloc;
-	unsigned int initial : 1;
-};
-
-static void add_one_commit(struct object_id *oid, struct rev_collect *revs)
-{
-	struct commit *commit;
-
-	if (is_null_oid(oid))
-		return;
-
-	commit = lookup_commit(oid);
-	if (!commit ||
-	    (commit->object.flags & TMP_MARK) ||
-	    parse_commit(commit))
-		return;
-
-	ALLOC_GROW(revs->commit, revs->nr + 1, revs->alloc);
-	revs->commit[revs->nr++] = commit;
-	commit->object.flags |= TMP_MARK;
-}
-
-static int collect_one_reflog_ent(struct object_id *ooid, struct object_id *noid,
-				  const char *ident, timestamp_t timestamp,
-				  int tz, const char *message, void *cbdata)
-{
-	struct rev_collect *revs = cbdata;
-
-	if (revs->initial) {
-		revs->initial = 0;
-		add_one_commit(ooid, revs);
-	}
-	add_one_commit(noid, revs);
-	return 0;
-}
-
 static int handle_fork_point(int argc, const char **argv)
 {
 	struct object_id oid;
 	char *refname;
+	struct commit *derived, *fork_point;
 	const char *commitname;
-	struct rev_collect revs;
-	struct commit *derived;
-	struct commit_list *bases;
-	int i, ret = 0;
 
 	switch (dwim_ref(argv[0], strlen(argv[0]), &oid, &refname)) {
 	case 0:
@@ -171,42 +131,15 @@ static int handle_fork_point(int argc, c
 	if (get_oid(commitname, &oid))
 		die("Not a valid object name: '%s'", commitname);
 
-	derived = lookup_commit_reference(&oid);
-	memset(&revs, 0, sizeof(revs));
-	revs.initial = 1;
-	for_each_reflog_ent(refname, collect_one_reflog_ent, &revs);
-
-	if (!revs.nr && !get_oid(refname, &oid))
-		add_one_commit(&oid, &revs);
-
-	for (i = 0; i < revs.nr; i++)
-		revs.commit[i]->object.flags &= ~TMP_MARK;
-
-	bases = get_merge_bases_many_dirty(derived, revs.nr, revs.commit);
-
-	/*
-	 * There should be one and only one merge base, when we found
-	 * a common ancestor among reflog entries.
-	 */
-	if (!bases || bases->next) {
-		ret = 1;
-		goto cleanup_return;
-	}
+	derived = lookup_commit_reference(the_repository, &oid);
 
-	/* And the found one must be one of the reflog entries */
-	for (i = 0; i < revs.nr; i++)
-		if (&bases->item->object == &revs.commit[i]->object)
-			break; /* found */
-	if (revs.nr <= i) {
-		ret = 1; /* not found */
-		goto cleanup_return;
-	}
+	fork_point = get_fork_point(refname, derived);
 
-	printf("%s\n", oid_to_hex(&bases->item->object.oid));
+	if (!fork_point)
+		return 1;
 
-cleanup_return:
-	free_commit_list(bases);
-	return ret;
+	printf("%s\n", oid_to_hex(&fork_point->object.oid));
+	return 0;
 }
 
 int cmd_merge_base(int argc, const char **argv, const char *prefix)
diff -pruN 1.2.1+git2.18.0-1/git/builtin/merge.c 1.2.3+git2.25.1-1/git/builtin/merge.c
--- 1.2.1+git2.18.0-1/git/builtin/merge.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/builtin/merge.c	2020-02-17 04:47:35.000000000 +0000
@@ -6,6 +6,7 @@
  * Based on git-merge.sh by Junio C Hamano.
  */
 
+#define USE_THE_INDEX_COMPATIBILITY_MACROS
 #include "cache.h"
 #include "config.h"
 #include "parse-options.h"
@@ -36,6 +37,9 @@
 #include "packfile.h"
 #include "tag.h"
 #include "alias.h"
+#include "branch.h"
+#include "commit-reach.h"
+#include "wt-status.h"
 
 #define DEFAULT_TWOHEAD (1<<0)
 #define DEFAULT_OCTOPUS (1<<1)
@@ -55,7 +59,7 @@ static const char * const builtin_merge_
 };
 
 static int show_diffstat = 1, shortlog_len = -1, squash;
-static int option_commit = 1;
+static int option_commit = -1;
 static int option_edit = -1;
 static int allow_trivial = 1, have_message, verify_signatures;
 static int overwrite_ignore = 1;
@@ -70,13 +74,14 @@ static int option_renormalize;
 static int verbosity;
 static int allow_rerere_auto;
 static int abort_current_merge;
+static int quit_current_merge;
 static int continue_current_merge;
 static int allow_unrelated_histories;
 static int show_progress = -1;
 static int default_to_upstream = 1;
 static int signoff;
 static const char *sign_commit;
-static int verify_msg = 1;
+static int no_verify;
 
 static struct strategy all_strategy[] = {
 	{ "recursive",  DEFAULT_TWOHEAD | NO_TRIVIAL },
@@ -96,6 +101,9 @@ enum ff_type {
 
 static enum ff_type fast_forward = FF_ALLOW;
 
+static const char *cleanup_arg;
+static enum commit_msg_cleanup_mode cleanup_mode;
+
 static int option_parse_message(const struct option *opt,
 				const char *arg, int unset)
 {
@@ -111,6 +119,38 @@ static int option_parse_message(const st
 	return 0;
 }
 
+static enum parse_opt_result option_read_message(struct parse_opt_ctx_t *ctx,
+						 const struct option *opt,
+						 const char *arg_not_used,
+						 int unset)
+{
+	struct strbuf *buf = opt->value;
+	const char *arg;
+
+	BUG_ON_OPT_ARG(arg_not_used);
+	if (unset)
+		BUG("-F cannot be negated");
+
+	if (ctx->opt) {
+		arg = ctx->opt;
+		ctx->opt = NULL;
+	} else if (ctx->argc > 1) {
+		ctx->argc--;
+		arg = *++ctx->argv;
+	} else
+		return error(_("option `%s' requires a value"), opt->long_name);
+
+	if (buf->len)
+		strbuf_addch(buf, '\n');
+	if (ctx->prefix && !is_absolute_path(arg))
+		arg = prefix_filename(ctx->prefix, arg);
+	if (strbuf_read_file(buf, arg, 0) < 0)
+		return error(_("could not read file '%s'"), arg);
+	have_message = 1;
+
+	return 0;
+}
+
 static struct strategy *get_strategy(const char *name)
 {
 	int i;
@@ -194,6 +234,7 @@ static int option_parse_x(const struct o
 static int option_parse_n(const struct option *opt,
 			  const char *arg, int unset)
 {
+	BUG_ON_OPT_ARG(arg);
 	show_diffstat = unset;
 	return 0;
 }
@@ -214,6 +255,7 @@ static struct option builtin_merge_optio
 		N_("perform a commit if the merge succeeds (default)")),
 	OPT_BOOL('e', "edit", &option_edit,
 		N_("edit message before committing")),
+	OPT_CLEANUP(&cleanup_arg),
 	OPT_SET_INT(0, "ff", &fast_forward, N_("allow fast-forward (default)"), FF_ALLOW),
 	OPT_SET_INT_F(0, "ff-only", &fast_forward,
 		      N_("abort if fast-forward is not possible"),
@@ -228,9 +270,14 @@ static struct option builtin_merge_optio
 	OPT_CALLBACK('m', "message", &merge_msg, N_("message"),
 		N_("merge commit message (for a non-fast-forward merge)"),
 		option_parse_message),
+	{ OPTION_LOWLEVEL_CALLBACK, 'F', "file", &merge_msg, N_("path"),
+		N_("read message from file"), PARSE_OPT_NONEG,
+		NULL, 0, option_read_message },
 	OPT__VERBOSITY(&verbosity),
 	OPT_BOOL(0, "abort", &abort_current_merge,
 		N_("abort the current in-progress merge")),
+	OPT_BOOL(0, "quit", &quit_current_merge,
+		N_("--abort but leave index and working tree alone")),
 	OPT_BOOL(0, "continue", &continue_current_merge,
 		N_("continue the current in-progress merge")),
 	OPT_BOOL(0, "allow-unrelated-histories", &allow_unrelated_histories,
@@ -240,18 +287,10 @@ static struct option builtin_merge_optio
 	  N_("GPG sign commit"), PARSE_OPT_OPTARG, NULL, (intptr_t) "" },
 	OPT_BOOL(0, "overwrite-ignore", &overwrite_ignore, N_("update ignored files (default)")),
 	OPT_BOOL(0, "signoff", &signoff, N_("add Signed-off-by:")),
-	OPT_BOOL(0, "verify", &verify_msg, N_("verify commit-msg hook")),
+	OPT_BOOL(0, "no-verify", &no_verify, N_("bypass pre-merge-commit and commit-msg hooks")),
 	OPT_END()
 };
 
-/* Cleans up metadata that is uninteresting after a succeeded merge. */
-static void drop_save(void)
-{
-	unlink(git_path_merge_head());
-	unlink(git_path_merge_msg());
-	unlink(git_path_merge_mode());
-}
-
 static int save_state(struct object_id *stash)
 {
 	int len;
@@ -345,7 +384,7 @@ static void finish_up_to_date(const char
 {
 	if (verbosity >= 0)
 		printf("%s%s\n", squash ? _(" (nothing to squash)") : "", msg);
-	drop_save();
+	remove_merge_branch_state(the_repository);
 }
 
 static void squash_message(struct commit *commit, struct commit_list *remoteheads)
@@ -357,7 +396,7 @@ static void squash_message(struct commit
 
 	printf(_("Squash commit -- not updating HEAD\n"));
 
-	init_revisions(&rev, NULL);
+	repo_init_revisions(the_repository, &rev, NULL);
 	rev.ignore_merges = 1;
 	rev.commit_format = CMIT_FMT_MEDIUM;
 
@@ -382,7 +421,7 @@ static void squash_message(struct commit
 			oid_to_hex(&commit->object.oid));
 		pretty_print_commit(&ctx, commit, &out);
 	}
-	write_file_buf(git_path_squash_msg(), out.buf, out.len);
+	write_file_buf(git_path_squash_msg(the_repository), out.buf, out.len);
 	strbuf_release(&out);
 }
 
@@ -414,13 +453,13 @@ static void finish(struct commit *head_c
 			 * We ignore errors in 'gc --auto', since the
 			 * user should see them.
 			 */
-			close_all_packs(the_repository->objects);
+			close_object_store(the_repository->objects);
 			run_command_v_opt(argv_gc_auto, RUN_GIT_CMD);
 		}
 	}
 	if (new_head && show_diffstat) {
 		struct diff_options opts;
-		diff_setup(&opts);
+		repo_diff_setup(the_repository, &opts);
 		opts.stat_width = -1; /* use full terminal width */
 		opts.stat_graph_width = -1; /* respect statGraphWidth config */
 		opts.output_format |=
@@ -445,6 +484,7 @@ static void merge_name(const char *remot
 	struct object_id branch_head;
 	struct strbuf buf = STRBUF_INIT;
 	struct strbuf bname = STRBUF_INIT;
+	struct merge_remote_desc *desc;
 	const char *ptr;
 	char *found_ref;
 	int len, early;
@@ -517,16 +557,13 @@ static void merge_name(const char *remot
 		strbuf_release(&truname);
 	}
 
-	if (remote_head->util) {
-		struct merge_remote_desc *desc;
-		desc = merge_remote_util(remote_head);
-		if (desc && desc->obj && desc->obj->type == OBJ_TAG) {
-			strbuf_addf(msg, "%s\t\t%s '%s'\n",
-				    oid_to_hex(&desc->obj->oid),
-				    type_name(desc->obj->type),
-				    remote);
-			goto cleanup;
-		}
+	desc = merge_remote_util(remote_head);
+	if (desc && desc->obj && desc->obj->type == OBJ_TAG) {
+		strbuf_addf(msg, "%s\t\t%s '%s'\n",
+			    oid_to_hex(&desc->obj->oid),
+			    type_name(desc->obj->type),
+			    remote);
+		goto cleanup;
 	}
 
 	strbuf_addf(msg, "%s\t\tcommit '%s'\n",
@@ -546,7 +583,7 @@ static void parse_branch_merge_options(c
 	argc = split_cmdline(bmo, &argv);
 	if (argc < 0)
 		die(_("Bad branch.%s.mergeoptions string: %s"), branch,
-		    split_cmdline_strerror(argc));
+		    _(split_cmdline_strerror(argc)));
 	REALLOC_ARRAY(argv, argc + 2);
 	MOVE_ARRAY(argv + 1, argv, argc + 1);
 	argc++;
@@ -576,6 +613,8 @@ static int git_merge_config(const char *
 		return git_config_string(&pull_twohead, k, v);
 	else if (!strcmp(k, "pull.octopus"))
 		return git_config_string(&pull_octopus, k, v);
+	else if (!strcmp(k, "commit.cleanup"))
+		return git_config_string(&cleanup_arg, k, v);
 	else if (!strcmp(k, "merge.renormalize"))
 		option_renormalize = git_config_bool(k, v);
 	else if (!strcmp(k, "merge.ff")) {
@@ -649,16 +688,13 @@ static int try_merge_strategy(const char
 			      struct commit_list *remoteheads,
 			      struct commit *head)
 {
-	struct lock_file lock = LOCK_INIT;
 	const char *head_arg = "HEAD";
 
-	hold_locked_index(&lock, LOCK_DIE_ON_ERROR);
-	refresh_cache(REFRESH_QUIET);
-	if (write_locked_index(&the_index, &lock,
-			       COMMIT_LOCK | SKIP_IF_UNCHANGED))
+	if (refresh_and_write_cache(REFRESH_QUIET, SKIP_IF_UNCHANGED, 0) < 0)
 		return error(_("Unable to write index."));
 
 	if (!strcmp(strategy, "recursive") || !strcmp(strategy, "subtree")) {
+		struct lock_file lock = LOCK_INIT;
 		int clean, x;
 		struct commit *result;
 		struct commit_list *reversed = NULL;
@@ -670,7 +706,7 @@ static int try_merge_strategy(const char
 			return 2;
 		}
 
-		init_merge_options(&o);
+		init_merge_options(&o, the_repository);
 		if (!strcmp(strategy, "subtree"))
 			o.subtree_shift = "";
 
@@ -695,11 +731,12 @@ static int try_merge_strategy(const char
 			exit(128);
 		if (write_locked_index(&the_index, &lock,
 				       COMMIT_LOCK | SKIP_IF_UNCHANGED))
-			die (_("unable to write %s"), get_index_file());
+			die(_("unable to write %s"), get_index_file());
 		return clean ? 0 : 1;
 	} else {
-		return try_merge_command(strategy, xopts_nr, xopts,
-						common, head_arg, remoteheads);
+		return try_merge_command(the_repository,
+					 strategy, xopts_nr, xopts,
+					 common, head_arg, remoteheads);
 	}
 }
 
@@ -743,7 +780,7 @@ static void add_strategies(const char *s
 
 static void read_merge_msg(struct strbuf *msg)
 {
-	const char *filename = git_path_merge_msg();
+	const char *filename = git_path_merge_msg(the_repository);
 	strbuf_reset(msg);
 	if (strbuf_read_file(msg, filename, 0) < 0)
 		die_errno(_("Could not read from '%s'"), filename);
@@ -763,39 +800,64 @@ static void abort_commit(struct commit_l
 static const char merge_editor_comment[] =
 N_("Please enter a commit message to explain why this merge is necessary,\n"
    "especially if it merges an updated upstream into a topic branch.\n"
-   "\n"
-   "Lines starting with '%c' will be ignored, and an empty message aborts\n"
+   "\n");
+
+static const char scissors_editor_comment[] =
+N_("An empty message aborts the commit.\n");
+
+static const char no_scissors_editor_comment[] =
+N_("Lines starting with '%c' will be ignored, and an empty message aborts\n"
    "the commit.\n");
 
 static void write_merge_heads(struct commit_list *);
 static void prepare_to_commit(struct commit_list *remoteheads)
 {
 	struct strbuf msg = STRBUF_INIT;
+	const char *index_file = get_index_file();
+
+	if (!no_verify && run_commit_hook(0 < option_edit, index_file, "pre-merge-commit", NULL))
+		abort_commit(remoteheads, NULL);
+	/*
+	 * Re-read the index as pre-merge-commit hook could have updated it,
+	 * and write it out as a tree.  We must do this before we invoke
+	 * the editor and after we invoke run_status above.
+	 */
+	if (find_hook("pre-merge-commit"))
+		discard_cache();
+	read_cache_from(index_file);
 	strbuf_addbuf(&msg, &merge_msg);
-	strbuf_addch(&msg, '\n');
 	if (squash)
 		BUG("the control must not reach here under --squash");
-	if (0 < option_edit)
-		strbuf_commented_addf(&msg, _(merge_editor_comment), comment_line_char);
+	if (0 < option_edit) {
+		strbuf_addch(&msg, '\n');
+		if (cleanup_mode == COMMIT_MSG_CLEANUP_SCISSORS) {
+			wt_status_append_cut_line(&msg);
+			strbuf_commented_addf(&msg, "\n");
+		}
+		strbuf_commented_addf(&msg, _(merge_editor_comment));
+		strbuf_commented_addf(&msg, _(cleanup_mode == COMMIT_MSG_CLEANUP_SCISSORS ?
+			scissors_editor_comment :
+			no_scissors_editor_comment), comment_line_char);
+	}
 	if (signoff)
 		append_signoff(&msg, ignore_non_trailer(msg.buf, msg.len), 0);
 	write_merge_heads(remoteheads);
-	write_file_buf(git_path_merge_msg(), msg.buf, msg.len);
+	write_file_buf(git_path_merge_msg(the_repository), msg.buf, msg.len);
 	if (run_commit_hook(0 < option_edit, get_index_file(), "prepare-commit-msg",
-			    git_path_merge_msg(), "merge", NULL))
+			    git_path_merge_msg(the_repository), "merge", NULL))
 		abort_commit(remoteheads, NULL);
 	if (0 < option_edit) {
-		if (launch_editor(git_path_merge_msg(), NULL, NULL))
+		if (launch_editor(git_path_merge_msg(the_repository), NULL, NULL))
 			abort_commit(remoteheads, NULL);
 	}
 
-	if (verify_msg && run_commit_hook(0 < option_edit, get_index_file(),
+	if (!no_verify && run_commit_hook(0 < option_edit, get_index_file(),
 					  "commit-msg",
-					  git_path_merge_msg(), NULL))
+					  git_path_merge_msg(the_repository), NULL))
 		abort_commit(remoteheads, NULL);
 
 	read_merge_msg(&msg);
-	strbuf_stripspace(&msg, 0 < option_edit);
+	cleanup_message(&msg, cleanup_mode, 0);
 	if (!msg.len)
 		abort_commit(remoteheads, _("Empty commit message."));
 	strbuf_release(&merge_msg);
@@ -807,12 +869,8 @@ static int merge_trivial(struct commit *
 {
 	struct object_id result_tree, result_commit;
 	struct commit_list *parents, **pptr = &parents;
-	struct lock_file lock = LOCK_INIT;
 
-	hold_locked_index(&lock, LOCK_DIE_ON_ERROR);
-	refresh_cache(REFRESH_QUIET);
-	if (write_locked_index(&the_index, &lock,
-			       COMMIT_LOCK | SKIP_IF_UNCHANGED))
+	if (refresh_and_write_cache(REFRESH_QUIET, SKIP_IF_UNCHANGED, 0) < 0)
 		return error(_("Unable to write index."));
 
 	write_tree_trivial(&result_tree);
@@ -824,7 +882,7 @@ static int merge_trivial(struct commit *
 			&result_commit, NULL, sign_commit))
 		die(_("failed to write commit object"));
 	finish(head, remoteheads, &result_commit, "In-index merge");
-	drop_save();
+	remove_merge_branch_state(the_repository);
 	return 0;
 }
 
@@ -839,11 +897,11 @@ static int finish_automerge(struct commi
 	struct strbuf buf = STRBUF_INIT;
 	struct object_id result_commit;
 
+	write_tree_trivial(result_tree);
 	free_commit_list(common);
 	parents = remoteheads;
 	if (!head_subsumed || fast_forward == FF_NO)
 		commit_list_insert(head, &parents);
-	strbuf_addch(&merge_msg, '\n');
 	prepare_to_commit(remoteheads);
 	if (commit_tree(merge_msg.buf, merge_msg.len, result_tree, parents,
 			&result_commit, NULL, sign_commit))
@@ -851,7 +909,7 @@ static int finish_automerge(struct commi
 	strbuf_addf(&buf, "Merge made by the '%s' strategy.", wt_strategy);
 	finish(head, remoteheads, &result_commit, buf.buf);
 	strbuf_release(&buf);
-	drop_save();
+	remove_merge_branch_state(the_repository);
 	return 0;
 }
 
@@ -861,14 +919,22 @@ static int suggest_conflicts(void)
 	FILE *fp;
 	struct strbuf msgbuf = STRBUF_INIT;
 
-	filename = git_path_merge_msg();
+	filename = git_path_merge_msg(the_repository);
 	fp = xfopen(filename, "a");
 
-	append_conflicts_hint(&msgbuf);
+	/*
+	 * We can't use cleanup_mode because if we're not using the editor,
+	 * get_cleanup_mode will return COMMIT_MSG_CLEANUP_SPACE instead, even
+	 * though the message is meant to be processed later by git-commit.
+	 * Thus, we will get the cleanup mode which is returned when we _are_
+	 * using an editor.
+	 */
+	append_conflicts_hint(&the_index, &msgbuf,
+			      get_cleanup_mode(cleanup_arg, 1));
 	fputs(msgbuf.buf, fp);
 	strbuf_release(&msgbuf);
 	fclose(fp);
-	rerere(allow_rerere_auto);
+	repo_rerere(the_repository, allow_rerere_auto);
 	printf(_("Automatic merge failed; "
 			"fix conflicts and then commit the result.\n"));
 	return 1;
@@ -880,7 +946,7 @@ static int evaluate_result(void)
 	struct rev_info rev;
 
 	/* Check how many files differ. */
-	init_revisions(&rev, "");
+	repo_init_revisions(the_repository, &rev, "");
 	setup_revisions(0, NULL, &rev, NULL);
 	rev.diffopt.output_format |=
 		DIFF_FORMAT_CALLBACK;
@@ -934,19 +1000,22 @@ static void write_merge_heads(struct com
 	for (j = remoteheads; j; j = j->next) {
 		struct object_id *oid;
 		struct commit *c = j->item;
-		if (c->util && merge_remote_util(c)->obj) {
-			oid = &merge_remote_util(c)->obj->oid;
+		struct merge_remote_desc *desc;
+
+		desc = merge_remote_util(c);
+		if (desc && desc->obj) {
+			oid = &desc->obj->oid;
 		} else {
 			oid = &c->object.oid;
 		}
 		strbuf_addf(&buf, "%s\n", oid_to_hex(oid));
 	}
-	write_file_buf(git_path_merge_head(), buf.buf, buf.len);
+	write_file_buf(git_path_merge_head(the_repository), buf.buf, buf.len);
 
 	strbuf_reset(&buf);
 	if (fast_forward == FF_NO)
 		strbuf_addstr(&buf, "no-ff");
-	write_file_buf(git_path_merge_mode(), buf.buf, buf.len);
+	write_file_buf(git_path_merge_mode(the_repository), buf.buf, buf.len);
 	strbuf_release(&buf);
 }
 
@@ -954,7 +1023,8 @@ static void write_merge_state(struct com
 {
 	write_merge_heads(remoteheads);
 	strbuf_addch(&merge_msg, '\n');
-	write_file_buf(git_path_merge_msg(), merge_msg.buf, merge_msg.len);
+	write_file_buf(git_path_merge_msg(the_repository), merge_msg.buf,
+		       merge_msg.len);
 }
 
 static int default_edit_option(void)
@@ -1033,11 +1103,12 @@ static void handle_fetch_head(struct com
 	const char *filename;
 	int fd, pos, npos;
 	struct strbuf fetch_head_file = STRBUF_INIT;
+	const unsigned hexsz = the_hash_algo->hexsz;
 
 	if (!merge_names)
 		merge_names = &fetch_head_file;
 
-	filename = git_path_fetch_head();
+	filename = git_path_fetch_head(the_repository);
 	fd = open(filename, O_RDONLY);
 	if (fd < 0)
 		die_errno(_("could not open '%s' for reading"), filename);
@@ -1058,16 +1129,16 @@ static void handle_fetch_head(struct com
 		else
 			npos = merge_names->len;
 
-		if (npos - pos < GIT_SHA1_HEXSZ + 2 ||
+		if (npos - pos < hexsz + 2 ||
 		    get_oid_hex(merge_names->buf + pos, &oid))
 			commit = NULL; /* bad */
-		else if (memcmp(merge_names->buf + pos + GIT_SHA1_HEXSZ, "\t\t", 2))
+		else if (memcmp(merge_names->buf + pos + hexsz, "\t\t", 2))
 			continue; /* not-for-merge */
 		else {
-			char saved = merge_names->buf[pos + GIT_SHA1_HEXSZ];
-			merge_names->buf[pos + GIT_SHA1_HEXSZ] = '\0';
+			char saved = merge_names->buf[pos + hexsz];
+			merge_names->buf[pos + hexsz] = '\0';
 			commit = get_merge_parent(merge_names->buf + pos);
-			merge_names->buf[pos + GIT_SHA1_HEXSZ] = saved;
+			merge_names->buf[pos + hexsz] = saved;
 		}
 		if (!commit) {
 			if (ptr)
@@ -1154,7 +1225,7 @@ static int merging_a_throwaway_tag(struc
 	tag_ref = xstrfmt("refs/tags/%s",
 			  ((struct tag *)merge_remote_util(commit)->obj)->tag);
 	if (!read_ref(tag_ref, &oid) &&
-	    !oidcmp(&oid, &merge_remote_util(commit)->obj->oid))
+	    oideq(&oid, &merge_remote_util(commit)->obj->oid))
 		is_throwaway_tag = 0;
 	else
 		is_throwaway_tag = 1;
@@ -1185,14 +1256,15 @@ int cmd_merge(int argc, const char **arg
 	branch = branch_to_free = resolve_refdup("HEAD", 0, &head_oid, NULL);
 	if (branch)
 		skip_prefix(branch, "refs/heads/", &branch);
+
+	init_diff_ui_defaults();
+	git_config(git_merge_config, NULL);
+
 	if (!branch || is_null_oid(&head_oid))
 		head_commit = NULL;
 	else
 		head_commit = lookup_commit_or_die(&head_oid, "HEAD");
 
-	init_diff_ui_defaults();
-	git_config(git_merge_config, NULL);
-
 	if (branch_mergeoptions)
 		parse_branch_merge_options(branch_mergeoptions);
 	argc = parse_options(argc, argv, prefix, builtin_merge_options,
@@ -1211,7 +1283,7 @@ int cmd_merge(int argc, const char **arg
 			usage_msg_opt(_("--abort expects no arguments"),
 			      builtin_merge_usage, builtin_merge_options);
 
-		if (!file_exists(git_path_merge_head()))
+		if (!file_exists(git_path_merge_head(the_repository)))
 			die(_("There is no merge to abort (MERGE_HEAD missing)."));
 
 		/* Invoke 'git reset --merge' */
@@ -1219,6 +1291,16 @@ int cmd_merge(int argc, const char **arg
 		goto done;
 	}
 
+	if (quit_current_merge) {
+		if (orig_argc != 2)
+			usage_msg_opt(_("--quit expects no arguments"),
+				      builtin_merge_usage,
+				      builtin_merge_options);
+
+		remove_merge_branch_state(the_repository);
+		goto done;
+	}
+
 	if (continue_current_merge) {
 		int nargc = 1;
 		const char *nargv[] = {"commit", NULL};
@@ -1227,7 +1309,7 @@ int cmd_merge(int argc, const char **arg
 			usage_msg_opt(_("--continue expects no arguments"),
 			      builtin_merge_usage, builtin_merge_options);
 
-		if (!file_exists(git_path_merge_head()))
+		if (!file_exists(git_path_merge_head(the_repository)))
 			die(_("There is no merge in progress (MERGE_HEAD missing)."));
 
 		/* Invoke 'git commit' */
@@ -1238,7 +1320,7 @@ int cmd_merge(int argc, const char **arg
 	if (read_cache_unmerged())
 		die_resolve_conflict("merge");
 
-	if (file_exists(git_path_merge_head())) {
+	if (file_exists(git_path_merge_head(the_repository))) {
 		/*
 		 * There is no unmerged entry, don't advise 'git
 		 * add/rm <file>', just 'git commit'.
@@ -1249,7 +1331,7 @@ int cmd_merge(int argc, const char **arg
 		else
 			die(_("You have not concluded your merge (MERGE_HEAD exists)."));
 	}
-	if (file_exists(git_path_cherry_pick_head())) {
+	if (file_exists(git_path_cherry_pick_head(the_repository))) {
 		if (advice_resolve_conflict)
 			die(_("You have not concluded your cherry-pick (CHERRY_PICK_HEAD exists).\n"
 			    "Please, commit your changes before you merge."));
@@ -1258,15 +1340,30 @@ int cmd_merge(int argc, const char **arg
 	}
 	resolve_undo_clear();
 
+	if (option_edit < 0)
+		option_edit = default_edit_option();
+
+	cleanup_mode = get_cleanup_mode(cleanup_arg, 0 < option_edit);
+
 	if (verbosity < 0)
 		show_diffstat = 0;
 
 	if (squash) {
 		if (fast_forward == FF_NO)
 			die(_("You cannot combine --squash with --no-ff."));
+		if (option_commit > 0)
+			die(_("You cannot combine --squash with --commit."));
+		/*
+		 * squash can now silently disable option_commit - this is not
+		 * a problem as it is only overriding the default, not a user
+		 * supplied option.
+		 */
 		option_commit = 0;
 	}
 
+	if (option_commit < 0)
+		option_commit = 1;
+
 	if (!argc) {
 		if (default_to_upstream)
 			argc = setup_with_upstream(&argv);
@@ -1298,6 +1395,10 @@ int cmd_merge(int argc, const char **arg
 			die(_("%s - not something we can merge"), argv[0]);
 		if (remoteheads->next)
 			die(_("Can merge only exactly one commit into empty head"));
+
+		if (verify_signatures)
+			verify_merge_signature(remoteheads->item, verbosity);
+
 		remote_head_oid = &remoteheads->item->object.oid;
 		read_empty(remote_head_oid, 0);
 		update_ref("initial pull", "HEAD", remote_head_oid, NULL, 0,
@@ -1319,31 +1420,7 @@ int cmd_merge(int argc, const char **arg
 
 	if (verify_signatures) {
 		for (p = remoteheads; p; p = p->next) {
-			struct commit *commit = p->item;
-			char hex[GIT_MAX_HEXSZ + 1];
-			struct signature_check signature_check;
-			memset(&signature_check, 0, sizeof(signature_check));
-
-			check_commit_signature(commit, &signature_check);
-
-			find_unique_abbrev_r(hex, &commit->object.oid, DEFAULT_ABBREV);
-			switch (signature_check.result) {
-			case 'G':
-				break;
-			case 'U':
-				die(_("Commit %s has an untrusted GPG signature, "
-				      "allegedly by %s."), hex, signature_check.signer);
-			case 'B':
-				die(_("Commit %s has a bad GPG signature "
-				      "allegedly by %s."), hex, signature_check.signer);
-			default: /* 'N' */
-				die(_("Commit %s does not have a GPG signature."), hex);
-			}
-			if (verbosity >= 0 && signature_check.result == 'G')
-				printf(_("Commit %s has a good GPG signature by %s\n"),
-				       hex, signature_check.signer);
-
-			signature_check_clear(&signature_check);
+			verify_merge_signature(p->item, verbosity);
 		}
 	}
 
@@ -1363,9 +1440,6 @@ int cmd_merge(int argc, const char **arg
 			fast_forward = FF_NO;
 	}
 
-	if (option_edit < 0)
-		option_edit = default_edit_option();
-
 	if (!use_strategies) {
 		if (!remoteheads)
 			; /* already up-to-date */
@@ -1412,7 +1486,7 @@ int cmd_merge(int argc, const char **arg
 		goto done;
 	} else if (fast_forward != FF_NO && !remoteheads->next &&
 			!common->next &&
-			!oidcmp(&common->item->object.oid, &head_commit->object.oid)) {
+			oideq(&common->item->object.oid, &head_commit->object.oid)) {
 		/* Again the most common case of merging one remote. */
 		struct strbuf msg = STRBUF_INIT;
 		struct commit *commit;
@@ -1434,7 +1508,8 @@ int cmd_merge(int argc, const char **arg
 			goto done;
 		}
 
-		if (checkout_fast_forward(&head_commit->object.oid,
+		if (checkout_fast_forward(the_repository,
+					  &head_commit->object.oid,
 					  &commit->object.oid,
 					  overwrite_ignore)) {
 			ret = 1;
@@ -1442,7 +1517,7 @@ int cmd_merge(int argc, const char **arg
 		}
 
 		finish(head_commit, remoteheads, &commit->object.oid, msg.buf);
-		drop_save();
+		remove_merge_branch_state(the_repository);
 		goto done;
 	} else if (!remoteheads->next && common->next)
 		;
@@ -1485,7 +1560,7 @@ int cmd_merge(int argc, const char **arg
 			 * HEAD^^" would be missed.
 			 */
 			common_one = get_merge_bases(head_commit, j->item);
-			if (oidcmp(&common_one->item->object.oid, &j->item->object.oid)) {
+			if (!oideq(&common_one->item->object.oid, &j->item->object.oid)) {
 				up_to_date = 0;
 				break;
 			}
@@ -1517,8 +1592,8 @@ int cmd_merge(int argc, const char **arg
 	    save_state(&stash))
 		oidclr(&stash);
 
-	for (i = 0; i < use_strategies_nr; i++) {
-		int ret;
+	for (i = 0; !merge_was_ok && i < use_strategies_nr; i++) {
+		int ret, cnt;
 		if (i) {
 			printf(_("Rewinding the tree to pristine...\n"));
 			restore_state(&head_commit->object.oid, &stash);
@@ -1535,40 +1610,26 @@ int cmd_merge(int argc, const char **arg
 		ret = try_merge_strategy(use_strategies[i]->name,
 					 common, remoteheads,
 					 head_commit);
-		if (!option_commit && !ret) {
-			merge_was_ok = 1;
-			/*
-			 * This is necessary here just to avoid writing
-			 * the tree, but later we will *not* exit with
-			 * status code 1 because merge_was_ok is set.
-			 */
-			ret = 1;
-		}
-
-		if (ret) {
-			/*
-			 * The backend exits with 1 when conflicts are
-			 * left to be resolved, with 2 when it does not
-			 * handle the given merge at all.
-			 */
-			if (ret == 1) {
-				int cnt = evaluate_result();
-
-				if (best_cnt <= 0 || cnt <= best_cnt) {
-					best_strategy = use_strategies[i]->name;
-					best_cnt = cnt;
+		/*
+		 * The backend exits with 1 when conflicts are
+		 * left to be resolved, with 2 when it does not
+		 * handle the given merge at all.
+		 */
+		if (ret < 2) {
+			if (!ret) {
+				if (option_commit) {
+					/* Automerge succeeded. */
+					automerge_was_ok = 1;
+					break;
 				}
+				merge_was_ok = 1;
+			}
+			cnt = evaluate_result();
+			if (best_cnt <= 0 || cnt <= best_cnt) {
+				best_strategy = use_strategies[i]->name;
+				best_cnt = cnt;
 			}
-			if (merge_was_ok)
-				break;
-			else
-				continue;
 		}
-
-		/* Automerge succeeded. */
-		write_tree_trivial(&result_tree);
-		automerge_was_ok = 1;
-		break;
 	}
 
 	/*
diff -pruN 1.2.1+git2.18.0-1/git/builtin/merge-file.c 1.2.3+git2.25.1-1/git/builtin/merge-file.c
--- 1.2.1+git2.18.0-1/git/builtin/merge-file.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/builtin/merge-file.c	2020-02-17 04:47:35.000000000 +0000
@@ -15,6 +15,8 @@ static int label_cb(const struct option
 	static int label_count = 0;
 	const char **names = (const char **)opt->value;
 
+	BUG_ON_OPT_NEG(unset);
+
 	if (label_count >= 3)
 		return error("too many labels on the command line");
 	names[label_count++] = arg;
diff -pruN 1.2.1+git2.18.0-1/git/builtin/merge-index.c 1.2.3+git2.25.1-1/git/builtin/merge-index.c
--- 1.2.1+git2.18.0-1/git/builtin/merge-index.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/builtin/merge-index.c	2020-02-17 04:47:35.000000000 +0000
@@ -1,3 +1,4 @@
+#define USE_THE_INDEX_COMPATIBILITY_MACROS
 #include "builtin.h"
 #include "run-command.h"
 
diff -pruN 1.2.1+git2.18.0-1/git/builtin/merge-ours.c 1.2.3+git2.25.1-1/git/builtin/merge-ours.c
--- 1.2.1+git2.18.0-1/git/builtin/merge-ours.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/builtin/merge-ours.c	2020-02-17 04:47:35.000000000 +0000
@@ -7,6 +7,7 @@
  *
  * Pretend we resolved the heads, but declare our tree trumps everybody else.
  */
+#define USE_THE_INDEX_COMPATIBILITY_MACROS
 #include "git-compat-util.h"
 #include "builtin.h"
 #include "diff.h"
@@ -26,7 +27,7 @@ int cmd_merge_ours(int argc, const char
 	 */
 	if (read_cache() < 0)
 		die_errno("read_cache failed");
-	if (index_differs_from("HEAD", NULL, 0))
+	if (index_differs_from(the_repository, "HEAD", NULL, 0))
 		exit(2);
 	exit(0);
 }
diff -pruN 1.2.1+git2.18.0-1/git/builtin/merge-recursive.c 1.2.3+git2.25.1-1/git/builtin/merge-recursive.c
--- 1.2.1+git2.18.0-1/git/builtin/merge-recursive.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/builtin/merge-recursive.c	2020-02-17 04:47:35.000000000 +0000
@@ -1,3 +1,4 @@
+#include "cache.h"
 #include "builtin.h"
 #include "commit.h"
 #include "tag.h"
@@ -7,16 +8,16 @@
 static const char builtin_merge_recursive_usage[] =
 	"git %s <base>... -- <head> <remote> ...";
 
-static const char *better_branch_name(const char *branch)
+static char *better_branch_name(const char *branch)
 {
-	static char githead_env[8 + GIT_SHA1_HEXSZ + 1];
+	static char githead_env[8 + GIT_MAX_HEXSZ + 1];
 	char *name;
 
-	if (strlen(branch) != GIT_SHA1_HEXSZ)
-		return branch;
+	if (strlen(branch) != the_hash_algo->hexsz)
+		return xstrdup(branch);
 	xsnprintf(githead_env, sizeof(githead_env), "GITHEAD_%s", branch);
 	name = getenv(githead_env);
-	return name ? name : branch;
+	return xstrdup(name ? name : branch);
 }
 
 int cmd_merge_recursive(int argc, const char **argv, const char *prefix)
@@ -26,9 +27,10 @@ int cmd_merge_recursive(int argc, const
 	int i, failed;
 	struct object_id h1, h2;
 	struct merge_options o;
+	char *better1, *better2;
 	struct commit *result;
 
-	init_merge_options(&o);
+	init_merge_options(&o, the_repository);
 	if (argv[0] && ends_with(argv[0], "-subtree"))
 		o.subtree_shift = "";
 
@@ -62,6 +64,9 @@ int cmd_merge_recursive(int argc, const
 	if (argc - i != 3) /* "--" "<head>" "<remote>" */
 		die(_("not handling anything other than two heads merge."));
 
+	if (repo_read_index_unmerged(the_repository))
+		die_resolve_conflict("merge");
+
 	o.branch1 = argv[++i];
 	o.branch2 = argv[++i];
 
@@ -70,13 +75,17 @@ int cmd_merge_recursive(int argc, const
 	if (get_oid(o.branch2, &h2))
 		die(_("could not resolve ref '%s'"), o.branch2);
 
-	o.branch1 = better_branch_name(o.branch1);
-	o.branch2 = better_branch_name(o.branch2);
+	o.branch1 = better1 = better_branch_name(o.branch1);
+	o.branch2 = better2 = better_branch_name(o.branch2);
 
 	if (o.verbosity >= 3)
 		printf(_("Merging %s with %s\n"), o.branch1, o.branch2);
 
 	failed = merge_recursive_generic(&o, &h1, &h2, bases_count, bases, &result);
+
+	free(better1);
+	free(better2);
+
 	if (failed < 0)
 		return 128; /* die() error code */
 	return failed;
diff -pruN 1.2.1+git2.18.0-1/git/builtin/merge-tree.c 1.2.3+git2.25.1-1/git/builtin/merge-tree.c
--- 1.2.1+git2.18.0-1/git/builtin/merge-tree.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/builtin/merge-tree.c	2020-02-17 04:47:35.000000000 +0000
@@ -1,6 +1,9 @@
+#define USE_THE_INDEX_COMPATIBILITY_MACROS
 #include "builtin.h"
 #include "tree-walk.h"
 #include "xdiff-interface.h"
+#include "object-store.h"
+#include "repository.h"
 #include "blob.h"
 #include "exec-cmd.h"
 #include "merge-blobs.h"
@@ -74,7 +77,8 @@ static void *result(struct merge_list *e
 	their = NULL;
 	if (entry)
 		their = entry->blob;
-	return merge_blobs(path, base, our, their, size);
+	return merge_blobs(the_repository->index, path,
+			   base, our, their, size);
 }
 
 static void *origin(struct merge_list *entry, unsigned long *size)
@@ -108,7 +112,8 @@ static void show_diff(struct merge_list
 	xpp.flags = 0;
 	memset(&xecfg, 0, sizeof(xecfg));
 	xecfg.ctxlen = 3;
-	ecb.outf = show_outf;
+	ecb.out_hunk = NULL;
+	ecb.out_line = show_outf;
 	ecb.priv = NULL;
 
 	src.ptr = origin(entry, &size);
@@ -151,15 +156,15 @@ static void show_result(void)
 /* An empty entry never compares same, not even to another empty entry */
 static int same_entry(struct name_entry *a, struct name_entry *b)
 {
-	return	a->oid &&
-		b->oid &&
-		!oidcmp(a->oid, b->oid) &&
+	return	!is_null_oid(&a->oid) &&
+		!is_null_oid(&b->oid) &&
+		oideq(&a->oid, &b->oid) &&
 		a->mode == b->mode;
 }
 
 static int both_empty(struct name_entry *a, struct name_entry *b)
 {
-	return !(a->oid || b->oid);
+	return is_null_oid(&a->oid) && is_null_oid(&b->oid);
 }
 
 static struct merge_list *create_entry(unsigned stage, unsigned mode, const struct object_id *oid, const char *path)
@@ -169,14 +174,15 @@ static struct merge_list *create_entry(u
 	res->stage = stage;
 	res->path = path;
 	res->mode = mode;
-	res->blob = lookup_blob(oid);
+	res->blob = lookup_blob(the_repository, oid);
 	return res;
 }
 
 static char *traverse_path(const struct traverse_info *info, const struct name_entry *n)
 {
-	char *path = xmallocz(traverse_path_len(info, n));
-	return make_traverse_path(path, info, n);
+	struct strbuf buf = STRBUF_INIT;
+	strbuf_make_traverse_path(&buf, info, n->path, n->pathlen);
+	return strbuf_detach(&buf, NULL);
 }
 
 static void resolve(const struct traverse_info *info, struct name_entry *ours, struct name_entry *result)
@@ -189,8 +195,8 @@ static void resolve(const struct travers
 		return;
 
 	path = traverse_path(info, result);
-	orig = create_entry(2, ours->mode, ours->oid, path);
-	final = create_entry(0, result->mode, result->oid, path);
+	orig = create_entry(2, ours->mode, &ours->oid, path);
+	final = create_entry(0, result->mode, &result->oid, path);
 
 	final->link = orig;
 
@@ -200,6 +206,7 @@ static void resolve(const struct travers
 static void unresolved_directory(const struct traverse_info *info,
 				 struct name_entry n[3])
 {
+	struct repository *r = the_repository;
 	char *newbase;
 	struct name_entry *p;
 	struct tree_desc t[3];
@@ -214,10 +221,10 @@ static void unresolved_directory(const s
 
 	newbase = traverse_path(info, p);
 
-#define ENTRY_OID(e) (((e)->mode && S_ISDIR((e)->mode)) ? (e)->oid : NULL)
-	buf0 = fill_tree_descriptor(t + 0, ENTRY_OID(n + 0));
-	buf1 = fill_tree_descriptor(t + 1, ENTRY_OID(n + 1));
-	buf2 = fill_tree_descriptor(t + 2, ENTRY_OID(n + 2));
+#define ENTRY_OID(e) (((e)->mode && S_ISDIR((e)->mode)) ? &(e)->oid : NULL)
+	buf0 = fill_tree_descriptor(r, t + 0, ENTRY_OID(n + 0));
+	buf1 = fill_tree_descriptor(r, t + 1, ENTRY_OID(n + 1));
+	buf2 = fill_tree_descriptor(r, t + 2, ENTRY_OID(n + 2));
 #undef ENTRY_OID
 
 	merge_trees(t, newbase);
@@ -240,7 +247,7 @@ static struct merge_list *link_entry(uns
 		path = entry->path;
 	else
 		path = traverse_path(info, n);
-	link = create_entry(stage, n->mode, n->oid, path);
+	link = create_entry(stage, n->mode, &n->oid, path);
 	link->link = entry;
 	return link;
 }
@@ -315,7 +322,7 @@ static int threeway_callback(int n, unsi
 	}
 
 	if (same_entry(entry+0, entry+1)) {
-		if (entry[2].oid && !S_ISDIR(entry[2].mode)) {
+		if (!is_null_oid(&entry[2].oid) && !S_ISDIR(entry[2].mode)) {
 			/* We did not touch, they modified -- take theirs */
 			resolve(info, entry+1, entry+2);
 			return mask;
@@ -343,17 +350,19 @@ static void merge_trees(struct tree_desc
 
 	setup_traverse_info(&info, base);
 	info.fn = threeway_callback;
-	traverse_trees(3, t, &info);
+	traverse_trees(&the_index, 3, t, &info);
 }
 
-static void *get_tree_descriptor(struct tree_desc *desc, const char *rev)
+static void *get_tree_descriptor(struct repository *r,
+				 struct tree_desc *desc,
+				 const char *rev)
 {
 	struct object_id oid;
 	void *buf;
 
-	if (get_oid(rev, &oid))
+	if (repo_get_oid(r, rev, &oid))
 		die("unknown rev %s", rev);
-	buf = fill_tree_descriptor(desc, &oid);
+	buf = fill_tree_descriptor(r, desc, &oid);
 	if (!buf)
 		die("%s is not a tree", rev);
 	return buf;
@@ -361,15 +370,16 @@ static void *get_tree_descriptor(struct
 
 int cmd_merge_tree(int argc, const char **argv, const char *prefix)
 {
+	struct repository *r = the_repository;
 	struct tree_desc t[3];
 	void *buf1, *buf2, *buf3;
 
 	if (argc != 4)
 		usage(merge_tree_usage);
 
-	buf1 = get_tree_descriptor(t+0, argv[1]);
-	buf2 = get_tree_descriptor(t+1, argv[2]);
-	buf3 = get_tree_descriptor(t+2, argv[3]);
+	buf1 = get_tree_descriptor(r, t+0, argv[1]);
+	buf2 = get_tree_descriptor(r, t+1, argv[2]);
+	buf3 = get_tree_descriptor(r, t+2, argv[3]);
 	merge_trees(t, "");
 	free(buf1);
 	free(buf2);
diff -pruN 1.2.1+git2.18.0-1/git/builtin/mktag.c 1.2.3+git2.25.1-1/git/builtin/mktag.c
--- 1.2.1+git2.18.0-1/git/builtin/mktag.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/builtin/mktag.c	2020-02-17 04:47:35.000000000 +0000
@@ -1,6 +1,7 @@
 #include "builtin.h"
 #include "tag.h"
 #include "replace-object.h"
+#include "object-store.h"
 
 /*
  * A signature file has a very simple fixed format: four lines
diff -pruN 1.2.1+git2.18.0-1/git/builtin/mktree.c 1.2.3+git2.25.1-1/git/builtin/mktree.c
--- 1.2.1+git2.18.0-1/git/builtin/mktree.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/builtin/mktree.c	2020-02-17 04:47:35.000000000 +0000
@@ -7,6 +7,7 @@
 #include "quote.h"
 #include "tree.h"
 #include "parse-options.h"
+#include "object-store.h"
 
 static struct treeent {
 	unsigned mode;
@@ -66,7 +67,7 @@ static const char *mktree_usage[] = {
 	NULL
 };
 
-static void mktree_line(char *buf, size_t len, int nul_term_line, int allow_missing)
+static void mktree_line(char *buf, int nul_term_line, int allow_missing)
 {
 	char *ptr, *ntr;
 	const char *p;
@@ -97,7 +98,7 @@ static void mktree_line(char *buf, size_
 
 	*ntr++ = 0; /* now at the beginning of SHA1 */
 
-	path = ntr + 41;  /* at the beginning of name */
+	path = (char *)p + 1;  /* at the beginning of name */
 	if (!nul_term_line && path[0] == '"') {
 		struct strbuf p_uq = STRBUF_INIT;
 		if (unquote_c_style(&p_uq, path, NULL))
@@ -171,7 +172,7 @@ int cmd_mktree(int ac, const char **av,
 					break;
 				die("input format error: (blank line only valid in batch mode)");
 			}
-			mktree_line(sb.buf, sb.len, nul_term_line, allow_missing);
+			mktree_line(sb.buf, nul_term_line, allow_missing);
 		}
 		if (is_batch_mode && got_eof && used < 1) {
 			/*
diff -pruN 1.2.1+git2.18.0-1/git/builtin/multi-pack-index.c 1.2.3+git2.25.1-1/git/builtin/multi-pack-index.c
--- 1.2.1+git2.18.0-1/git/builtin/multi-pack-index.c	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/builtin/multi-pack-index.c	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,70 @@
+#include "builtin.h"
+#include "cache.h"
+#include "config.h"
+#include "parse-options.h"
+#include "midx.h"
+#include "trace2.h"
+
+static char const * const builtin_multi_pack_index_usage[] = {
+	N_("git multi-pack-index [<options>] (write|verify|expire|repack --batch-size=<size>)"),
+	NULL
+};
+
+static struct opts_multi_pack_index {
+	const char *object_dir;
+	unsigned long batch_size;
+	int progress;
+} opts;
+
+int cmd_multi_pack_index(int argc, const char **argv,
+			 const char *prefix)
+{
+	unsigned flags = 0;
+
+	static struct option builtin_multi_pack_index_options[] = {
+		OPT_FILENAME(0, "object-dir", &opts.object_dir,
+		  N_("object directory containing set of packfile and pack-index pairs")),
+		OPT_BOOL(0, "progress", &opts.progress, N_("force progress reporting")),
+		OPT_MAGNITUDE(0, "batch-size", &opts.batch_size,
+		  N_("during repack, collect pack-files of smaller size into a batch that is larger than this size")),
+		OPT_END(),
+	};
+
+	git_config(git_default_config, NULL);
+
+	opts.progress = isatty(2);
+	argc = parse_options(argc, argv, prefix,
+			     builtin_multi_pack_index_options,
+			     builtin_multi_pack_index_usage, 0);
+
+	if (!opts.object_dir)
+		opts.object_dir = get_object_directory();
+	if (opts.progress)
+		flags |= MIDX_PROGRESS;
+
+	if (argc == 0)
+		usage_with_options(builtin_multi_pack_index_usage,
+				   builtin_multi_pack_index_options);
+
+	if (argc > 1) {
+		die(_("too many arguments"));
+		return 1;
+	}
+
+	trace2_cmd_mode(argv[0]);
+
+	if (!strcmp(argv[0], "repack"))
+		return midx_repack(the_repository, opts.object_dir,
+			(size_t)opts.batch_size, flags);
+	if (opts.batch_size)
+		die(_("--batch-size option is only for 'repack' subcommand"));
+
+	if (!strcmp(argv[0], "write"))
+		return write_midx_file(opts.object_dir, flags);
+	if (!strcmp(argv[0], "verify"))
+		return verify_midx_file(the_repository, opts.object_dir, flags);
+	if (!strcmp(argv[0], "expire"))
+		return expire_midx_packs(the_repository, opts.object_dir, flags);
+
+	die(_("unrecognized subcommand: %s"), argv[0]);
+}
diff -pruN 1.2.1+git2.18.0-1/git/builtin/mv.c 1.2.3+git2.25.1-1/git/builtin/mv.c
--- 1.2.1+git2.18.0-1/git/builtin/mv.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/builtin/mv.c	2020-02-17 04:47:35.000000000 +0000
@@ -3,6 +3,7 @@
  *
  * Copyright (C) 2006 Johannes Schindelin
  */
+#define USE_THE_INDEX_COMPATIBILITY_MACROS
 #include "builtin.h"
 #include "config.h"
 #include "pathspec.h"
diff -pruN 1.2.1+git2.18.0-1/git/builtin/name-rev.c 1.2.3+git2.25.1-1/git/builtin/name-rev.c
--- 1.2.1+git2.18.0-1/git/builtin/name-rev.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/builtin/name-rev.c	2020-02-17 04:47:35.000000000 +0000
@@ -1,13 +1,20 @@
 #include "builtin.h"
 #include "cache.h"
+#include "repository.h"
 #include "config.h"
 #include "commit.h"
 #include "tag.h"
 #include "refs.h"
 #include "parse-options.h"
+#include "prio-queue.h"
 #include "sha1-lookup.h"
+#include "commit-slab.h"
 
-#define CUTOFF_DATE_SLOP 86400 /* one day */
+/*
+ * One day.  See the 'name a rev shortly after epoch' test in t6120 when
+ * changing this value
+ */
+#define CUTOFF_DATE_SLOP 86400
 
 typedef struct rev_name {
 	const char *tip_name;
@@ -17,15 +24,28 @@ typedef struct rev_name {
 	int from_tag;
 } rev_name;
 
+define_commit_slab(commit_rev_name, struct rev_name *);
+
 static timestamp_t cutoff = TIME_MAX;
+static struct commit_rev_name rev_names;
 
 /* How many generations are maximally preferred over _one_ merge traversal? */
 #define MERGE_TRAVERSAL_WEIGHT 65535
 
+static struct rev_name *get_commit_rev_name(struct commit *commit)
+{
+	struct rev_name **slot = commit_rev_name_peek(&rev_names, commit);
+
+	return slot ? *slot : NULL;
+}
+
+static void set_commit_rev_name(struct commit *commit, struct rev_name *name)
+{
+	*commit_rev_name_at(&rev_names, commit) = name;
+}
+
 static int is_better_name(struct rev_name *name,
-			  const char *tip_name,
 			  timestamp_t taggerdate,
-			  int generation,
 			  int distance,
 			  int from_tag)
 {
@@ -60,69 +80,116 @@ static int is_better_name(struct rev_nam
 	return 0;
 }
 
-static void name_rev(struct commit *commit,
-		const char *tip_name, timestamp_t taggerdate,
-		int generation, int distance, int from_tag,
-		int deref)
+static struct rev_name *create_or_update_name(struct commit *commit,
+					      const char *tip_name,
+					      timestamp_t taggerdate,
+					      int generation, int distance,
+					      int from_tag)
 {
-	struct rev_name *name = (struct rev_name *)commit->util;
-	struct commit_list *parents;
-	int parent_number = 1;
-	char *to_free = NULL;
-
-	parse_commit(commit);
-
-	if (commit->date < cutoff)
-		return;
-
-	if (deref) {
-		tip_name = to_free = xstrfmt("%s^0", tip_name);
-
-		if (generation)
-			die("generation: %d, but deref?", generation);
-	}
+	struct rev_name *name = get_commit_rev_name(commit);
 
 	if (name == NULL) {
-		name = xmalloc(sizeof(rev_name));
-		commit->util = name;
+		name = xmalloc(sizeof(*name));
+		set_commit_rev_name(commit, name);
 		goto copy_data;
-	} else if (is_better_name(name, tip_name, taggerdate,
-				  generation, distance, from_tag)) {
+	} else if (is_better_name(name, taggerdate, distance, from_tag)) {
 copy_data:
 		name->tip_name = tip_name;
 		name->taggerdate = taggerdate;
 		name->generation = generation;
 		name->distance = distance;
 		name->from_tag = from_tag;
-	} else {
+
+		return name;
+	} else
+		return NULL;
+}
+
+static void name_rev(struct commit *start_commit,
+		const char *tip_name, timestamp_t taggerdate,
+		int from_tag, int deref)
+{
+	struct prio_queue queue;
+	struct commit *commit;
+	struct commit **parents_to_queue = NULL;
+	size_t parents_to_queue_nr, parents_to_queue_alloc = 0;
+	char *to_free = NULL;
+
+	parse_commit(start_commit);
+	if (start_commit->date < cutoff)
+		return;
+
+	if (deref)
+		tip_name = to_free = xstrfmt("%s^0", tip_name);
+
+	if (!create_or_update_name(start_commit, tip_name, taggerdate, 0, 0,
+				   from_tag)) {
 		free(to_free);
 		return;
 	}
 
-	for (parents = commit->parents;
-			parents;
-			parents = parents->next, parent_number++) {
-		if (parent_number > 1) {
-			size_t len;
-			char *new_name;
-
-			strip_suffix(tip_name, "^0", &len);
-			if (generation > 0)
-				new_name = xstrfmt("%.*s~%d^%d", (int)len, tip_name,
-						   generation, parent_number);
-			else
-				new_name = xstrfmt("%.*s^%d", (int)len, tip_name,
-						   parent_number);
+	memset(&queue, 0, sizeof(queue)); /* Use the prio_queue as LIFO */
+	prio_queue_put(&queue, start_commit);
 
-			name_rev(parents->item, new_name, taggerdate, 0,
-				 distance + MERGE_TRAVERSAL_WEIGHT,
-				 from_tag, 0);
-		} else {
-			name_rev(parents->item, tip_name, taggerdate,
-				 generation + 1, distance + 1,
-				 from_tag, 0);
+	while ((commit = prio_queue_get(&queue))) {
+		struct rev_name *name = get_commit_rev_name(commit);
+		struct commit_list *parents;
+		int parent_number = 1;
+
+		parents_to_queue_nr = 0;
+
+		for (parents = commit->parents;
+				parents;
+				parents = parents->next, parent_number++) {
+			struct commit *parent = parents->item;
+			const char *new_name;
+			int generation, distance;
+
+			parse_commit(parent);
+			if (parent->date < cutoff)
+				continue;
+
+			if (parent_number > 1) {
+				size_t len;
+
+				strip_suffix(name->tip_name, "^0", &len);
+				if (name->generation > 0)
+					new_name = xstrfmt("%.*s~%d^%d",
+							   (int)len,
+							   name->tip_name,
+							   name->generation,
+							   parent_number);
+				else
+					new_name = xstrfmt("%.*s^%d", (int)len,
+							   name->tip_name,
+							   parent_number);
+				generation = 0;
+				distance = name->distance + MERGE_TRAVERSAL_WEIGHT;
+			} else {
+				new_name = name->tip_name;
+				generation = name->generation + 1;
+				distance = name->distance + 1;
+			}
+
+			if (create_or_update_name(parent, new_name, taggerdate,
+						  generation, distance,
+						  from_tag)) {
+				ALLOC_GROW(parents_to_queue,
+					   parents_to_queue_nr + 1,
+					   parents_to_queue_alloc);
+				parents_to_queue[parents_to_queue_nr] = parent;
+				parents_to_queue_nr++;
+			}
 		}
+
+		/* The first parent must come out first from the prio_queue */
+		while (parents_to_queue_nr)
+			prio_queue_put(&queue,
+				       parents_to_queue[--parents_to_queue_nr]);
 	}
+
+	clear_prio_queue(&queue);
+	free(parents_to_queue);
 }
 
 static int subpath_matches(const char *path, const char *filter)
@@ -143,10 +210,10 @@ static const char *name_ref_abbrev(const
 {
 	if (shorten_unambiguous)
 		refname = shorten_unambiguous_ref(refname, 0);
-	else if (starts_with(refname, "refs/heads/"))
-		refname = refname + 11;
-	else if (starts_with(refname, "refs/"))
-		refname = refname + 5;
+	else if (skip_prefix(refname, "refs/heads/", &refname))
+		; /* refname already advanced */
+	else
+		skip_prefix(refname, "refs/", &refname);
 	return refname;
 }
 
@@ -187,7 +254,7 @@ static int tipcmp(const void *a_, const
 
 static int name_ref(const char *path, const struct object_id *oid, int flags, void *cb_data)
 {
-	struct object *o = parse_object(oid);
+	struct object *o = parse_object(the_repository, oid);
 	struct name_ref_data *data = cb_data;
 	int can_abbreviate_output = data->tags_only && data->name_only;
 	int deref = 0;
@@ -245,7 +312,7 @@ static int name_ref(const char *path, co
 		struct tag *t = (struct tag *) o;
 		if (!t->tagged)
 			break; /* broken repository */
-		o = parse_object(&t->tagged->oid);
+		o = parse_object(the_repository, &t->tagged->oid);
 		deref = 1;
 		taggerdate = t->date;
 	}
@@ -254,10 +321,9 @@ static int name_ref(const char *path, co
 		int from_tag = starts_with(path, "refs/tags/");
 
 		if (taggerdate == TIME_MAX)
-			taggerdate = ((struct commit *)o)->date;
+			taggerdate = commit->date;
 		path = name_ref_abbrev(path, can_abbreviate_output);
-		name_rev(commit, xstrdup(path), taggerdate, 0, 0,
-			 from_tag, deref);
+		name_rev(commit, xstrdup(path), taggerdate, from_tag, deref);
 	}
 	return 0;
 }
@@ -296,18 +362,17 @@ static const char *get_rev_name(const st
 	if (o->type != OBJ_COMMIT)
 		return get_exact_ref_match(o);
 	c = (struct commit *) o;
-	n = c->util;
+	n = get_commit_rev_name(c);
 	if (!n)
 		return NULL;
 
 	if (!n->generation)
 		return n->tip_name;
 	else {
-		int len = strlen(n->tip_name);
-		if (len > 2 && !strcmp(n->tip_name + len - 2, "^0"))
-			len -= 2;
 		strbuf_reset(buf);
-		strbuf_addf(buf, "%.*s~%d", len, n->tip_name, n->generation);
+		strbuf_addstr(buf, n->tip_name);
+		strbuf_strip_suffix(buf, "^0");
+		strbuf_addf(buf, "~%d", n->generation);
 		return buf->buf;
 	}
 }
@@ -344,25 +409,27 @@ static char const * const name_rev_usage
 static void name_rev_line(char *p, struct name_ref_data *data)
 {
 	struct strbuf buf = STRBUF_INIT;
-	int forty = 0;
+	int counter = 0;
 	char *p_start;
+	const unsigned hexsz = the_hash_algo->hexsz;
+
 	for (p_start = p; *p; p++) {
 #define ishex(x) (isdigit((x)) || ((x) >= 'a' && (x) <= 'f'))
 		if (!ishex(*p))
-			forty = 0;
-		else if (++forty == GIT_SHA1_HEXSZ &&
+			counter = 0;
+		else if (++counter == hexsz &&
 			 !ishex(*(p+1))) {
 			struct object_id oid;
 			const char *name = NULL;
 			char c = *(p+1);
 			int p_len = p - p_start + 1;
 
-			forty = 0;
+			counter = 0;
 
 			*(p+1) = 0;
-			if (!get_oid(p - (GIT_SHA1_HEXSZ - 1), &oid)) {
+			if (!get_oid(p - (hexsz - 1), &oid)) {
 				struct object *o =
-					lookup_object(oid.hash);
+					lookup_object(the_repository, &oid);
 				if (o)
 					name = get_rev_name(o, &buf);
 			}
@@ -372,7 +439,7 @@ static void name_rev_line(char *p, struc
 				continue;
 
 			if (data->name_only)
-				printf("%.*s%s", p_len - GIT_SHA1_HEXSZ, p_start, name);
+				printf("%.*s%s", p_len - hexsz, p_start, name);
 			else
 				printf("%.*s (%s)", p_len, p_start, name);
 			p_start = p + 1;
@@ -413,6 +480,7 @@ int cmd_name_rev(int argc, const char **
 		OPT_END(),
 	};
 
+	init_commit_rev_name(&rev_names);
 	git_config(git_default_config, NULL);
 	argc = parse_options(argc, argv, prefix, opts, name_rev_usage, 0);
 	if (all + transform_stdin + !!argc > 1) {
@@ -434,9 +502,10 @@ int cmd_name_rev(int argc, const char **
 		}
 
 		commit = NULL;
-		object = parse_object(&oid);
+		object = parse_object(the_repository, &oid);
 		if (object) {
-			struct object *peeled = deref_tag(object, *argv, 0);
+			struct object *peeled = deref_tag(the_repository,
+							  object, *argv, 0);
 			if (peeled && peeled->type == OBJ_COMMIT)
 				commit = (struct commit *)peeled;
 		}
@@ -463,8 +532,13 @@ int cmd_name_rev(int argc, const char **
 		add_object_array(object, *argv, &revs);
 	}
 
-	if (cutoff)
-		cutoff = cutoff - CUTOFF_DATE_SLOP;
+	if (cutoff) {
+		/* check for undeflow */
+		if (cutoff > TIME_MIN + CUTOFF_DATE_SLOP)
+			cutoff = cutoff - CUTOFF_DATE_SLOP;
+		else
+			cutoff = TIME_MIN;
+	}
 	for_each_ref(name_ref, &data);
 
 	if (transform_stdin) {
diff -pruN 1.2.1+git2.18.0-1/git/builtin/notes.c 1.2.3+git2.25.1-1/git/builtin/notes.c
--- 1.2.1+git2.18.0-1/git/builtin/notes.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/builtin/notes.c	2020-02-17 04:47:35.000000000 +0000
@@ -11,6 +11,8 @@
 #include "config.h"
 #include "builtin.h"
 #include "notes.h"
+#include "object-store.h"
+#include "repository.h"
 #include "blob.h"
 #include "pretty.h"
 #include "refs.h"
@@ -213,6 +215,8 @@ static int parse_msg_arg(const struct op
 {
 	struct note_data *d = opt->value;
 
+	BUG_ON_OPT_NEG(unset);
+
 	strbuf_grow(&d->buf, strlen(arg) + 2);
 	if (d->buf.len)
 		strbuf_addch(&d->buf, '\n');
@@ -227,6 +231,8 @@ static int parse_file_arg(const struct o
 {
 	struct note_data *d = opt->value;
 
+	BUG_ON_OPT_NEG(unset);
+
 	if (d->buf.len)
 		strbuf_addch(&d->buf, '\n');
 	if (!strcmp(arg, "-")) {
@@ -248,15 +254,15 @@ static int parse_reuse_arg(const struct
 	enum object_type type;
 	unsigned long len;
 
+	BUG_ON_OPT_NEG(unset);
+
 	if (d->buf.len)
 		strbuf_addch(&d->buf, '\n');
 
 	if (get_oid(arg, &object))
 		die(_("failed to resolve '%s' as a valid ref."), arg);
-	if (!(buf = read_object_file(&object, &type, &len))) {
-		free(buf);
+	if (!(buf = read_object_file(&object, &type, &len)))
 		die(_("failed to read object '%s'."), arg);
-	}
 	if (type != OBJ_BLOB) {
 		free(buf);
 		die(_("cannot read note data from non-blob object '%s'."), arg);
@@ -271,6 +277,7 @@ static int parse_reuse_arg(const struct
 static int parse_reedit_arg(const struct option *opt, const char *arg, int unset)
 {
 	struct note_data *d = opt->value;
+	BUG_ON_OPT_NEG(unset);
 	d->use_editor = 1;
 	return parse_reuse_arg(opt, arg, unset);
 }
@@ -323,10 +330,10 @@ static int notes_copy_from_stdin(int for
 	}
 
 	if (!rewrite_cmd) {
-		commit_notes(t, msg);
+		commit_notes(the_repository, t, msg);
 		free_notes(t);
 	} else {
-		finish_copy_notes_for_rewrite(c, msg);
+		finish_copy_notes_for_rewrite(the_repository, c, msg);
 	}
 	strbuf_release(&buf);
 	return ret;
@@ -462,12 +469,14 @@ static int add(int argc, const char **ar
 		write_note_data(&d, &new_note);
 		if (add_note(t, &object, &new_note, combine_notes_overwrite))
 			BUG("combine_notes_overwrite failed");
-		commit_notes(t, "Notes added by 'git notes add'");
+		commit_notes(the_repository, t,
+			     "Notes added by 'git notes add'");
 	} else {
 		fprintf(stderr, _("Removing note for object %s\n"),
 			oid_to_hex(&object));
 		remove_note(t, object.hash);
-		commit_notes(t, "Notes removed by 'git notes add'");
+		commit_notes(the_repository, t,
+			     "Notes removed by 'git notes add'");
 	}
 
 	free_note_data(&d);
@@ -504,7 +513,7 @@ static int copy(int argc, const char **a
 		}
 	}
 
-	if (argc < 2) {
+	if (argc < 1) {
 		error(_("too few parameters"));
 		usage_with_options(git_notes_copy_usage, options);
 	}
@@ -545,7 +554,8 @@ static int copy(int argc, const char **a
 
 	if (add_note(t, &object, from_note, combine_notes_overwrite))
 		BUG("combine_notes_overwrite failed");
-	commit_notes(t, "Notes added by 'git notes copy'");
+	commit_notes(the_repository, t,
+		     "Notes added by 'git notes copy'");
 out:
 	free_notes(t);
 	return retval;
@@ -629,7 +639,7 @@ static int append_edit(int argc, const c
 		remove_note(t, object.hash);
 		logmsg = xstrfmt("Notes removed by 'git notes %s'", argv[0]);
 	}
-	commit_notes(t, logmsg);
+	commit_notes(the_repository, t, logmsg);
 
 	free(logmsg);
 	free_note_data(&d);
@@ -710,7 +720,7 @@ static int merge_commit(struct notes_mer
 
 	if (get_oid("NOTES_MERGE_PARTIAL", &oid))
 		die(_("failed to read ref NOTES_MERGE_PARTIAL"));
-	else if (!(partial = lookup_commit_reference(&oid)))
+	else if (!(partial = lookup_commit_reference(the_repository, &oid)))
 		die(_("could not find commit from NOTES_MERGE_PARTIAL."));
 	else if (parse_commit(partial))
 		die(_("could not parse commit from NOTES_MERGE_PARTIAL."));
@@ -806,7 +816,7 @@ static int merge(int argc, const char **
 		usage_with_options(git_notes_merge_usage, options);
 	}
 
-	init_notes_merge_options(&o);
+	init_notes_merge_options(the_repository, &o);
 	o.verbosity = verbosity + NOTES_MERGE_VERBOSITY_DEFAULT;
 
 	if (do_abort)
@@ -930,7 +940,8 @@ static int remove_cmd(int argc, const ch
 		strbuf_release(&sb);
 	}
 	if (!retval)
-		commit_notes(t, "Notes removed by 'git notes remove'");
+		commit_notes(the_repository, t,
+			     "Notes removed by 'git notes remove'");
 	free_notes(t);
 	return retval;
 }
@@ -958,7 +969,8 @@ static int prune(int argc, const char **
 	prune_notes(t, (verbose ? NOTES_PRUNE_VERBOSE : 0) |
 		(show_only ? NOTES_PRUNE_VERBOSE|NOTES_PRUNE_DRYRUN : 0) );
 	if (!show_only)
-		commit_notes(t, "Notes removed by 'git notes prune'");
+		commit_notes(the_repository, t,
+			     "Notes removed by 'git notes prune'");
 	free_notes(t);
 	return 0;
 }
diff -pruN 1.2.1+git2.18.0-1/git/builtin/pack-objects.c 1.2.3+git2.25.1-1/git/builtin/pack-objects.c
--- 1.2.1+git2.18.0-1/git/builtin/pack-objects.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/builtin/pack-objects.c	2020-02-17 04:47:35.000000000 +0000
@@ -24,6 +24,7 @@
 #include "streaming.h"
 #include "thread-utils.h"
 #include "pack-bitmap.h"
+#include "delta-islands.h"
 #include "reachable.h"
 #include "sha1-array.h"
 #include "argv-array.h"
@@ -31,6 +32,8 @@
 #include "packfile.h"
 #include "object-store.h"
 #include "dir.h"
+#include "midx.h"
+#include "trace2.h"
 
 #define IN_PACK(obj) oe_in_pack(&to_pack, obj)
 #define SIZE(obj) oe_size(&to_pack, obj)
@@ -40,6 +43,7 @@
 #define DELTA_CHILD(obj) oe_delta_child(&to_pack, obj)
 #define DELTA_SIBLING(obj) oe_delta_sibling(&to_pack, obj)
 #define SET_DELTA(obj, val) oe_set_delta(&to_pack, obj, val)
+#define SET_DELTA_EXT(obj, oid) oe_set_delta_ext(&to_pack, obj, oid)
 #define SET_DELTA_SIZE(obj, val) oe_set_delta_size(&to_pack, obj, val)
 #define SET_DELTA_CHILD(obj, val) oe_set_delta_child(&to_pack, obj, val)
 #define SET_DELTA_SIBLING(obj, val) oe_set_delta_sibling(&to_pack, obj, val)
@@ -59,6 +63,8 @@ static struct packing_data to_pack;
 
 static struct pack_idx_entry **written_list;
 static uint32_t nr_result, nr_written, nr_seen;
+static struct bitmap_index *bitmap_git;
+static uint32_t write_layer;
 
 static int non_empty;
 static int reuse_delta = 1, reuse_object = 1;
@@ -79,6 +85,8 @@ static unsigned long pack_size_limit;
 static int depth = 50;
 static int delta_search_threads;
 static int pack_to_stdout;
+static int sparse;
+static int thin;
 static int num_preferred_base;
 static struct progress *progress_state;
 
@@ -88,11 +96,17 @@ static off_t reuse_packfile_offset;
 
 static int use_bitmap_index_default = 1;
 static int use_bitmap_index = -1;
-static int write_bitmap_index;
-static uint16_t write_bitmap_options;
+static enum {
+	WRITE_BITMAP_FALSE = 0,
+	WRITE_BITMAP_QUIET,
+	WRITE_BITMAP_TRUE,
+} write_bitmap_index;
+static uint16_t write_bitmap_options = BITMAP_OPT_HASH_CACHE;
 
 static int exclude_promisor_objects;
 
+static int use_delta_islands;
+
 static unsigned long delta_cache_size = 0;
 static unsigned long max_delta_cache_size = DEFAULT_DELTA_CACHE_SIZE;
 static unsigned long cache_max_small_delta_size = 1000;
@@ -140,7 +154,7 @@ static void *get_delta(struct object_ent
 
 	buf = read_object_file(&entry->idx.oid, &type, &size);
 	if (!buf)
-		die("unable to read %s", oid_to_hex(&entry->idx.oid));
+		die(_("unable to read %s"), oid_to_hex(&entry->idx.oid));
 	base_buf = read_object_file(&DELTA(entry)->idx.oid, &type,
 				    &base_size);
 	if (!base_buf)
@@ -148,8 +162,13 @@ static void *get_delta(struct object_ent
 		    oid_to_hex(&DELTA(entry)->idx.oid));
 	delta_buf = diff_delta(base_buf, base_size,
 			       buf, size, &delta_size, 0);
+	/*
+	 * We successfully computed this delta once but dropped it for
+	 * memory reasons. Something is very wrong if this time we
+	 * recompute and create a different delta.
+	 */
 	if (!delta_buf || delta_size != DELTA_SIZE(entry))
-		die("delta size changed");
+		BUG("delta size changed");
 	free(buf);
 	free(base_buf);
 	return delta_buf;
@@ -406,7 +425,7 @@ static off_t write_reuse_object(struct h
 	datalen = revidx[1].offset - offset;
 	if (!pack_to_stdout && p->index_version > 1 &&
 	    check_pack_crc(p, &w_curs, offset, datalen, revidx->nr)) {
-		error("bad packed object CRC for %s",
+		error(_("bad packed object CRC for %s"),
 		      oid_to_hex(&entry->idx.oid));
 		unuse_pack(&w_curs);
 		return write_no_reuse_object(f, entry, limit, usable_delta);
@@ -417,7 +436,7 @@ static off_t write_reuse_object(struct h
 
 	if (!pack_to_stdout && p->index_version == 1 &&
 	    check_pack_inflate(p, &w_curs, offset, datalen, entry_size)) {
-		error("corrupt packed object for %s",
+		error(_("corrupt packed object for %s"),
 		      oid_to_hex(&entry->idx.oid));
 		unuse_pack(&w_curs);
 		return write_no_reuse_object(f, entry, limit, usable_delta);
@@ -548,7 +567,7 @@ static enum write_one_status write_one(s
 	 */
 	recursing = (e->idx.offset == 1);
 	if (recursing) {
-		warning("recursive delta detected for object %s",
+		warning(_("recursive delta detected for object %s"),
 			oid_to_hex(&e->idx.oid));
 		return WRITE_ONE_RECURSIVE;
 	} else if (e->idx.offset || e->preferred_base) {
@@ -582,7 +601,7 @@ static enum write_one_status write_one(s
 
 	/* make sure off_t is sufficiently large not to wrap */
 	if (signed_add_overflows(*offset, size))
-		die("pack too large for current definition of off_t");
+		die(_("pack too large for current definition of off_t"));
 	*offset += size;
 	return WRITE_ONE_WRITTEN;
 }
@@ -591,12 +610,12 @@ static int mark_tagged(const char *path,
 		       void *cb_data)
 {
 	struct object_id peeled;
-	struct object_entry *entry = packlist_find(&to_pack, oid->hash, NULL);
+	struct object_entry *entry = packlist_find(&to_pack, oid);
 
 	if (entry)
 		entry->tagged = 1;
 	if (!peel_ref(path, &peeled)) {
-		entry = packlist_find(&to_pack, peeled.hash, NULL);
+		entry = packlist_find(&to_pack, &peeled);
 		if (entry)
 			entry->tagged = 1;
 	}
@@ -607,7 +626,7 @@ static inline void add_to_write_order(st
 			       unsigned int *endp,
 			       struct object_entry *e)
 {
-	if (e->filled)
+	if (e->filled || oe_layer(&to_pack, e) != write_layer)
 		return;
 	wo[(*endp)++] = e;
 	e->filled = 1;
@@ -667,48 +686,15 @@ static void add_family_to_write_order(st
 	add_descendants_to_write_order(wo, endp, root);
 }
 
-static struct object_entry **compute_write_order(void)
+static void compute_layer_order(struct object_entry **wo, unsigned int *wo_end)
 {
-	unsigned int i, wo_end, last_untagged;
-
-	struct object_entry **wo;
+	unsigned int i, last_untagged;
 	struct object_entry *objects = to_pack.objects;
 
 	for (i = 0; i < to_pack.nr_objects; i++) {
-		objects[i].tagged = 0;
-		objects[i].filled = 0;
-		SET_DELTA_CHILD(&objects[i], NULL);
-		SET_DELTA_SIBLING(&objects[i], NULL);
-	}
-
-	/*
-	 * Fully connect delta_child/delta_sibling network.
-	 * Make sure delta_sibling is sorted in the original
-	 * recency order.
-	 */
-	for (i = to_pack.nr_objects; i > 0;) {
-		struct object_entry *e = &objects[--i];
-		if (!DELTA(e))
-			continue;
-		/* Mark me as the first child */
-		e->delta_sibling_idx = DELTA(e)->delta_child_idx;
-		SET_DELTA_CHILD(DELTA(e), e);
-	}
-
-	/*
-	 * Mark objects that are at the tip of tags.
-	 */
-	for_each_tag_ref(mark_tagged, NULL);
-
-	/*
-	 * Give the objects in the original recency order until
-	 * we see a tagged tip.
-	 */
-	ALLOC_ARRAY(wo, to_pack.nr_objects);
-	for (i = wo_end = 0; i < to_pack.nr_objects; i++) {
 		if (objects[i].tagged)
 			break;
-		add_to_write_order(wo, &wo_end, &objects[i]);
+		add_to_write_order(wo, wo_end, &objects[i]);
 	}
 	last_untagged = i;
 
@@ -717,7 +703,7 @@ static struct object_entry **compute_wri
 	 */
 	for (; i < to_pack.nr_objects; i++) {
 		if (objects[i].tagged)
-			add_to_write_order(wo, &wo_end, &objects[i]);
+			add_to_write_order(wo, wo_end, &objects[i]);
 	}
 
 	/*
@@ -727,7 +713,7 @@ static struct object_entry **compute_wri
 		if (oe_type(&objects[i]) != OBJ_COMMIT &&
 		    oe_type(&objects[i]) != OBJ_TAG)
 			continue;
-		add_to_write_order(wo, &wo_end, &objects[i]);
+		add_to_write_order(wo, wo_end, &objects[i]);
 	}
 
 	/*
@@ -736,19 +722,64 @@ static struct object_entry **compute_wri
 	for (i = last_untagged; i < to_pack.nr_objects; i++) {
 		if (oe_type(&objects[i]) != OBJ_TREE)
 			continue;
-		add_to_write_order(wo, &wo_end, &objects[i]);
+		add_to_write_order(wo, wo_end, &objects[i]);
 	}
 
 	/*
 	 * Finally all the rest in really tight order
 	 */
 	for (i = last_untagged; i < to_pack.nr_objects; i++) {
-		if (!objects[i].filled)
-			add_family_to_write_order(wo, &wo_end, &objects[i]);
+		if (!objects[i].filled && oe_layer(&to_pack, &objects[i]) == write_layer)
+			add_family_to_write_order(wo, wo_end, &objects[i]);
+	}
+}
+
+static struct object_entry **compute_write_order(void)
+{
+	uint32_t max_layers = 1;
+	unsigned int i, wo_end;
+
+	struct object_entry **wo;
+	struct object_entry *objects = to_pack.objects;
+
+	for (i = 0; i < to_pack.nr_objects; i++) {
+		objects[i].tagged = 0;
+		objects[i].filled = 0;
+		SET_DELTA_CHILD(&objects[i], NULL);
+		SET_DELTA_SIBLING(&objects[i], NULL);
 	}
 
+	/*
+	 * Fully connect delta_child/delta_sibling network.
+	 * Make sure delta_sibling is sorted in the original
+	 * recency order.
+	 */
+	for (i = to_pack.nr_objects; i > 0;) {
+		struct object_entry *e = &objects[--i];
+		if (!DELTA(e))
+			continue;
+		/* Mark me as the first child */
+		e->delta_sibling_idx = DELTA(e)->delta_child_idx;
+		SET_DELTA_CHILD(DELTA(e), e);
+	}
+
+	/*
+	 * Mark objects that are at the tip of tags.
+	 */
+	for_each_tag_ref(mark_tagged, NULL);
+
+	if (use_delta_islands)
+		max_layers = compute_pack_layers(&to_pack);
+
+	ALLOC_ARRAY(wo, to_pack.nr_objects);
+	wo_end = 0;
+
+	for (; write_layer < max_layers; ++write_layer)
+		compute_layer_order(wo, &wo_end);
+
 	if (wo_end != to_pack.nr_objects)
-		die("ordered %u objects, expected %"PRIu32, wo_end, to_pack.nr_objects);
+		die(_("ordered %u objects, expected %"PRIu32),
+		    wo_end, to_pack.nr_objects);
 
 	return wo;
 }
@@ -760,15 +791,15 @@ static off_t write_reused_pack(struct ha
 	int fd;
 
 	if (!is_pack_valid(reuse_packfile))
-		die("packfile is invalid: %s", reuse_packfile->pack_name);
+		die(_("packfile is invalid: %s"), reuse_packfile->pack_name);
 
 	fd = git_open(reuse_packfile->pack_name);
 	if (fd < 0)
-		die_errno("unable to open packfile for reuse: %s",
+		die_errno(_("unable to open packfile for reuse: %s"),
 			  reuse_packfile->pack_name);
 
 	if (lseek(fd, sizeof(struct pack_header), SEEK_SET) == -1)
-		die_errno("unable to seek in reused packfile");
+		die_errno(_("unable to seek in reused packfile"));
 
 	if (reuse_packfile_offset < 0)
 		reuse_packfile_offset = reuse_packfile->pack_size - the_hash_algo->rawsz;
@@ -779,7 +810,7 @@ static off_t write_reused_pack(struct ha
 		int read_pack = xread(fd, buffer, sizeof(buffer));
 
 		if (read_pack <= 0)
-			die_errno("unable to read from reused packfile");
+			die_errno(_("unable to read from reused packfile"));
 
 		if (read_pack > to_write)
 			read_pack = to_write;
@@ -865,7 +896,8 @@ static void write_pack_file(void)
 						 nr_written, oid.hash, offset);
 			close(fd);
 			if (write_bitmap_index) {
-				warning(_(no_split_warning));
+				if (write_bitmap_index != WRITE_BITMAP_QUIET)
+					warning(_(no_split_warning));
 				write_bitmap_index = 0;
 			}
 		}
@@ -882,7 +914,7 @@ static void write_pack_file(void)
 			 * to preserve this property.
 			 */
 			if (stat(pack_tmp_name, &st) < 0) {
-				warning_errno("failed to stat %s", pack_tmp_name);
+				warning_errno(_("failed to stat %s"), pack_tmp_name);
 			} else if (!last_mtime) {
 				last_mtime = st.st_mtime;
 			} else {
@@ -890,7 +922,7 @@ static void write_pack_file(void)
 				utb.actime = st.st_atime;
 				utb.modtime = --last_mtime;
 				if (utime(pack_tmp_name, &utb) < 0)
-					warning_errno("failed utime() on %s", pack_tmp_name);
+					warning_errno(_("failed utime() on %s"), pack_tmp_name);
 			}
 
 			strbuf_addf(&tmpname, "%s-", base_name);
@@ -935,8 +967,10 @@ static void write_pack_file(void)
 	free(write_order);
 	stop_progress(&progress_state);
 	if (written != nr_result)
-		die("wrote %"PRIu32" objects while expecting %"PRIu32,
-			written, nr_result);
+		die(_("wrote %"PRIu32" objects while expecting %"PRIu32),
+		    written, nr_result);
+	trace2_data_intmax("pack-objects", the_repository,
+			   "write_pack_file/wrote", nr_result);
 }
 
 static int no_try_delta(const char *path)
@@ -945,8 +979,7 @@ static int no_try_delta(const char *path
 
 	if (!check)
 		check = attr_check_initl("delta", NULL);
-	if (git_check_attr(path, check))
-		return 0;
+	git_check_attr(the_repository->index, path, check);
 	if (ATTR_FALSE(check->items[0].value))
 		return 1;
 	return 0;
@@ -963,12 +996,11 @@ static int no_try_delta(const char *path
  * few lines later when we want to add the new entry.
  */
 static int have_duplicate_entry(const struct object_id *oid,
-				int exclude,
-				uint32_t *index_pos)
+				int exclude)
 {
 	struct object_entry *entry;
 
-	entry = packlist_find(&to_pack, oid->hash, index_pos);
+	entry = packlist_find(&to_pack, oid);
 	if (!entry)
 		return 0;
 
@@ -1034,6 +1066,7 @@ static int want_object_in_pack(const str
 {
 	int want;
 	struct list_head *pos;
+	struct multi_pack_index *m;
 
 	if (!exclude && local && has_loose_object_nonlocal(oid))
 		return 0;
@@ -1048,6 +1081,32 @@ static int want_object_in_pack(const str
 		if (want != -1)
 			return want;
 	}
+
+	for (m = get_multi_pack_index(the_repository); m; m = m->next) {
+		struct pack_entry e;
+		if (fill_midx_entry(the_repository, oid, &e, m)) {
+			struct packed_git *p = e.p;
+			off_t offset;
+
+			if (p == *found_pack)
+				offset = *found_offset;
+			else
+				offset = find_pack_entry_one(oid->hash, p);
+
+			if (offset) {
+				if (!*found_pack) {
+					if (!is_pack_valid(p))
+						continue;
+					*found_offset = offset;
+					*found_pack = p;
+				}
+				want = want_found_object(exclude, p);
+				if (want != -1)
+					return want;
+			}
+		}
+	}
+
 	list_for_each(pos, get_packed_git_mru(the_repository)) {
 		struct packed_git *p = list_entry(pos, struct packed_git, mru);
 		off_t offset;
@@ -1081,13 +1140,12 @@ static void create_object_entry(const st
 				uint32_t hash,
 				int exclude,
 				int no_try_delta,
-				uint32_t index_pos,
 				struct packed_git *found_pack,
 				off_t found_offset)
 {
 	struct object_entry *entry;
 
-	entry = packlist_alloc(&to_pack, oid->hash, index_pos);
+	entry = packlist_alloc(&to_pack, oid);
 	entry->hash = hash;
 	oe_set_type(entry, type);
 	if (exclude)
@@ -1111,17 +1169,17 @@ static int add_object_entry(const struct
 {
 	struct packed_git *found_pack = NULL;
 	off_t found_offset = 0;
-	uint32_t index_pos;
 
 	display_progress(progress_state, ++nr_seen);
 
-	if (have_duplicate_entry(oid, exclude, &index_pos))
+	if (have_duplicate_entry(oid, exclude))
 		return 0;
 
 	if (!want_object_in_pack(oid, exclude, &found_pack, &found_offset)) {
 		/* The pack is missing an object, so it will not have closure */
 		if (write_bitmap_index) {
-			warning(_(no_closure_warning));
+			if (write_bitmap_index != WRITE_BITMAP_QUIET)
+				warning(_(no_closure_warning));
 			write_bitmap_index = 0;
 		}
 		return 0;
@@ -1129,7 +1187,7 @@ static int add_object_entry(const struct
 
 	create_object_entry(oid, type, pack_name_hash(name),
 			    exclude, name && no_try_delta(name),
-			    index_pos, found_pack, found_offset);
+			    found_pack, found_offset);
 	return 1;
 }
 
@@ -1138,17 +1196,15 @@ static int add_object_entry_from_bitmap(
 					int flags, uint32_t name_hash,
 					struct packed_git *pack, off_t offset)
 {
-	uint32_t index_pos;
-
 	display_progress(progress_state, ++nr_seen);
 
-	if (have_duplicate_entry(oid, 0, &index_pos))
+	if (have_duplicate_entry(oid, 0))
 		return 0;
 
 	if (!want_object_in_pack(oid, 0, &pack, &offset))
 		return 0;
 
-	create_object_entry(oid, type, name_hash, 0, 0, index_pos, pack, offset);
+	create_object_entry(oid, type, name_hash, 0, 0, pack, offset);
 	return 1;
 }
 
@@ -1196,7 +1252,7 @@ static struct pbase_tree_cache *pbase_tr
 	 */
 	for (neigh = 0; neigh < 8; neigh++) {
 		ent = pbase_tree_cache[my_ix];
-		if (ent && !oidcmp(&ent->oid, oid)) {
+		if (ent && oideq(&ent->oid, oid)) {
 			ent->ref++;
 			return ent;
 		}
@@ -1283,7 +1339,7 @@ static void add_pbase_object(struct tree
 		if (cmp < 0)
 			return;
 		if (name[cmplen] != '/') {
-			add_object_entry(entry.oid,
+			add_object_entry(&entry.oid,
 					 object_type(entry.mode),
 					 fullname, 1);
 			return;
@@ -1294,7 +1350,7 @@ static void add_pbase_object(struct tree
 			const char *down = name+cmplen+1;
 			int downlen = name_cmp_len(down);
 
-			tree = pbase_tree_get(entry.oid);
+			tree = pbase_tree_get(&entry.oid);
 			if (!tree)
 				return;
 			init_tree_desc(&sub, tree->tree_data, tree->tree_size);
@@ -1373,12 +1429,13 @@ static void add_preferred_base(struct ob
 	if (window <= num_preferred_base++)
 		return;
 
-	data = read_object_with_reference(oid, tree_type, &size, &tree_oid);
+	data = read_object_with_reference(the_repository, oid,
+					  tree_type, &size, &tree_oid);
 	if (!data)
 		return;
 
 	for (it = pbase_tree; it; it = it->next) {
-		if (!oidcmp(&it->pcache.oid, &tree_oid)) {
+		if (oideq(&it->pcache.oid, &tree_oid)) {
 			free(data);
 			return;
 		}
@@ -1418,6 +1475,58 @@ static void cleanup_preferred_base(void)
 	done_pbase_paths_num = done_pbase_paths_alloc = 0;
 }
 
+/*
+ * Return 1 iff the object specified by "delta" can be sent
+ * literally as a delta against the base in "base_sha1". If
+ * so, then *base_out will point to the entry in our packing
+ * list, or NULL if we must use the external-base list.
+ *
+ * Depth value does not matter - find_deltas() will
+ * never consider reused delta as the base object to
+ * deltify other objects against, in order to avoid
+ * circular deltas.
+ */
+static int can_reuse_delta(const unsigned char *base_sha1,
+			   struct object_entry *delta,
+			   struct object_entry **base_out)
+{
+	struct object_entry *base;
+	struct object_id base_oid;
+
+	if (!base_sha1)
+		return 0;
+
+	oidread(&base_oid, base_sha1);
+
+	/*
+	 * First see if we're already sending the base (or it's explicitly in
+	 * our "excluded" list).
+	 */
+	base = packlist_find(&to_pack, &base_oid);
+	if (base) {
+		if (!in_same_island(&delta->idx.oid, &base->idx.oid))
+			return 0;
+		*base_out = base;
+		return 1;
+	}
+
+	/*
+	 * Otherwise, reachability bitmaps may tell us if the receiver has it,
+	 * even if it was buried too deep in history to make it into the
+	 * packing list.
+	 */
+	if (thin && bitmap_has_oid_in_uninteresting(bitmap_git, &base_oid)) {
+		if (use_delta_islands) {
+			if (!in_same_island(&delta->idx.oid, &base_oid))
+				return 0;
+		}
+		*base_out = NULL;
+		return 1;
+	}
+
+	return 0;
+}
+
 static void check_object(struct object_entry *entry)
 {
 	unsigned long canonical_size;
@@ -1480,7 +1589,7 @@ static void check_object(struct object_e
 			while (c & 128) {
 				ofs += 1;
 				if (!ofs || MSB(ofs, 7)) {
-					error("delta base offset overflow in pack for %s",
+					error(_("delta base offset overflow in pack for %s"),
 					      oid_to_hex(&entry->idx.oid));
 					goto give_up;
 				}
@@ -1489,7 +1598,7 @@ static void check_object(struct object_e
 			}
 			ofs = entry->in_pack_offset - ofs;
 			if (ofs <= 0 || ofs >= entry->in_pack_offset) {
-				error("delta base offset out of bound for %s",
+				error(_("delta base offset out of bound for %s"),
 				      oid_to_hex(&entry->idx.oid));
 				goto give_up;
 			}
@@ -1504,23 +1613,19 @@ static void check_object(struct object_e
 			break;
 		}
 
-		if (base_ref && (base_entry = packlist_find(&to_pack, base_ref, NULL))) {
-			/*
-			 * If base_ref was set above that means we wish to
-			 * reuse delta data, and we even found that base
-			 * in the list of objects we want to pack. Goodie!
-			 *
-			 * Depth value does not matter - find_deltas() will
-			 * never consider reused delta as the base object to
-			 * deltify other objects against, in order to avoid
-			 * circular deltas.
-			 */
+		if (can_reuse_delta(base_ref, entry, &base_entry)) {
 			oe_set_type(entry, entry->in_pack_type);
 			SET_SIZE(entry, in_pack_size); /* delta size */
-			SET_DELTA(entry, base_entry);
 			SET_DELTA_SIZE(entry, in_pack_size);
-			entry->delta_sibling_idx = base_entry->delta_child_idx;
-			SET_DELTA_CHILD(base_entry, entry);
+
+			if (base_entry) {
+				SET_DELTA(entry, base_entry);
+				entry->delta_sibling_idx = base_entry->delta_child_idx;
+				SET_DELTA_CHILD(base_entry, entry);
+			} else {
+				SET_DELTA_EXT(entry, base_ref);
+			}
+
 			unuse_pack(&w_curs);
 			return;
 		}
@@ -1544,7 +1649,7 @@ static void check_object(struct object_e
 
 		/*
 		 * No choice but to fall back to the recursive delta walk
-		 * with sha1_object_info() to find about the object type
+		 * with oid_object_info() to find about the object type
 		 * at this point...
 		 */
 		give_up:
@@ -1620,7 +1725,7 @@ static void drop_reused_delta(struct obj
 	if (packed_object_info(the_repository, IN_PACK(entry), entry->in_pack_offset, &oi) < 0) {
 		/*
 		 * We failed to get the info from this pack for some reason;
-		 * fall back to sha1_object_info, which may find another copy.
+		 * fall back to oid_object_info, which may find another copy.
 		 * And if that fails, the error will be recorded in oe_type(entry)
 		 * and dealt with in prepare_pack().
 		 */
@@ -1803,10 +1908,10 @@ static int type_size_sort(const void *_a
 {
 	const struct object_entry *a = *(struct object_entry **)_a;
 	const struct object_entry *b = *(struct object_entry **)_b;
-	enum object_type a_type = oe_type(a);
-	enum object_type b_type = oe_type(b);
-	unsigned long a_size = SIZE(a);
-	unsigned long b_size = SIZE(b);
+	const enum object_type a_type = oe_type(a);
+	const enum object_type b_type = oe_type(b);
+	const unsigned long a_size = SIZE(a);
+	const unsigned long b_size = SIZE(b);
 
 	if (a_type > b_type)
 		return -1;
@@ -1820,6 +1925,11 @@ static int type_size_sort(const void *_a
 		return -1;
 	if (a->preferred_base < b->preferred_base)
 		return 1;
+	if (use_delta_islands) {
+		const int island_cmp = island_delta_cmp(&a->idx.oid, &b->idx.oid);
+		if (island_cmp)
+			return island_cmp;
+	}
 	if (a_size > b_size)
 		return -1;
 	if (a_size < b_size)
@@ -1850,30 +1960,25 @@ static int delta_cacheable(unsigned long
 	return 0;
 }
 
-#ifndef NO_PTHREADS
-
-static pthread_mutex_t read_mutex;
-#define read_lock()		pthread_mutex_lock(&read_mutex)
-#define read_unlock()		pthread_mutex_unlock(&read_mutex)
-
+/* Protect delta_cache_size */
 static pthread_mutex_t cache_mutex;
 #define cache_lock()		pthread_mutex_lock(&cache_mutex)
 #define cache_unlock()		pthread_mutex_unlock(&cache_mutex)
 
+/*
+ * Protect object list partitioning (e.g. struct thread_param) and
+ * progress_state
+ */
 static pthread_mutex_t progress_mutex;
 #define progress_lock()		pthread_mutex_lock(&progress_mutex)
 #define progress_unlock()	pthread_mutex_unlock(&progress_mutex)
 
-#else
-
-#define read_lock()		(void)0
-#define read_unlock()		(void)0
-#define cache_lock()		(void)0
-#define cache_unlock()		(void)0
-#define progress_lock()		(void)0
-#define progress_unlock()	(void)0
-
-#endif
+/*
+ * Access to struct object_entry is unprotected since each thread owns
+ * a portion of the main object list. Just don't access object entries
+ * ahead in the list because they can be stolen and would need
+ * progress_mutex for protection.
+ */
 
 /*
  * Return the size of the object without doing any delta
@@ -1890,11 +1995,11 @@ unsigned long oe_get_size_slow(struct pa
 	unsigned long used, avail, size;
 
 	if (e->type_ != OBJ_OFS_DELTA && e->type_ != OBJ_REF_DELTA) {
-		read_lock();
+		packing_data_lock(&to_pack);
 		if (oid_object_info(the_repository, &e->idx.oid, &size) < 0)
 			die(_("unable to get size of %s"),
 			    oid_to_hex(&e->idx.oid));
-		read_unlock();
+		packing_data_unlock(&to_pack);
 		return size;
 	}
 
@@ -1902,7 +2007,7 @@ unsigned long oe_get_size_slow(struct pa
 	if (!p)
 		BUG("when e->type is a delta, it must belong to a pack");
 
-	read_lock();
+	packing_data_lock(&to_pack);
 	w_curs = NULL;
 	buf = use_pack(p, &w_curs, e->in_pack_offset, &avail);
 	used = unpack_object_header_buffer(buf, avail, &type, &size);
@@ -1911,7 +2016,7 @@ unsigned long oe_get_size_slow(struct pa
 		    oid_to_hex(&e->idx.oid));
 
 	unuse_pack(&w_curs);
-	read_unlock();
+	packing_data_unlock(&to_pack);
 	return size;
 }
 
@@ -1968,29 +2073,32 @@ static int try_delta(struct unpacked *tr
 	if (trg_size < src_size / 32)
 		return 0;
 
+	if (!in_same_island(&trg->entry->idx.oid, &src->entry->idx.oid))
+		return 0;
+
 	/* Load data if not already done */
 	if (!trg->data) {
-		read_lock();
+		packing_data_lock(&to_pack);
 		trg->data = read_object_file(&trg_entry->idx.oid, &type, &sz);
-		read_unlock();
+		packing_data_unlock(&to_pack);
 		if (!trg->data)
-			die("object %s cannot be read",
+			die(_("object %s cannot be read"),
 			    oid_to_hex(&trg_entry->idx.oid));
 		if (sz != trg_size)
-			die("object %s inconsistent object length (%lu vs %lu)",
-			    oid_to_hex(&trg_entry->idx.oid), sz,
-			    trg_size);
+			die(_("object %s inconsistent object length (%"PRIuMAX" vs %"PRIuMAX")"),
+			    oid_to_hex(&trg_entry->idx.oid), (uintmax_t)sz,
+			    (uintmax_t)trg_size);
 		*mem_usage += sz;
 	}
 	if (!src->data) {
-		read_lock();
+		packing_data_lock(&to_pack);
 		src->data = read_object_file(&src_entry->idx.oid, &type, &sz);
-		read_unlock();
+		packing_data_unlock(&to_pack);
 		if (!src->data) {
 			if (src_entry->preferred_base) {
 				static int warned = 0;
 				if (!warned++)
-					warning("object %s cannot be read",
+					warning(_("object %s cannot be read"),
 						oid_to_hex(&src_entry->idx.oid));
 				/*
 				 * Those objects are not included in the
@@ -2000,13 +2108,13 @@ static int try_delta(struct unpacked *tr
 				 */
 				return 0;
 			}
-			die("object %s cannot be read",
+			die(_("object %s cannot be read"),
 			    oid_to_hex(&src_entry->idx.oid));
 		}
 		if (sz != src_size)
-			die("object %s inconsistent object length (%lu vs %lu)",
-			    oid_to_hex(&src_entry->idx.oid), sz,
-			    src_size);
+			die(_("object %s inconsistent object length (%"PRIuMAX" vs %"PRIuMAX")"),
+			    oid_to_hex(&src_entry->idx.oid), (uintmax_t)sz,
+			    (uintmax_t)src_size);
 		*mem_usage += sz;
 	}
 	if (!src->index) {
@@ -2014,7 +2122,7 @@ static int try_delta(struct unpacked *tr
 		if (!src->index) {
 			static int warned = 0;
 			if (!warned++)
-				warning("suboptimal pack - out of memory");
+				warning(_("suboptimal pack - out of memory"));
 			return 0;
 		}
 		*mem_usage += sizeof_delta_index(src->index);
@@ -2023,10 +2131,6 @@ static int try_delta(struct unpacked *tr
 	delta_buf = create_delta(src->index, trg->data, trg_size, &delta_size, max_size);
 	if (!delta_buf)
 		return 0;
-	if (delta_size >= (1U << OE_DELTA_SIZE_BITS)) {
-		free(delta_buf);
-		return 0;
-	}
 
 	if (DELTA(trg_entry)) {
 		/* Prefer only shallower same-sized deltas. */
@@ -2069,7 +2173,7 @@ static unsigned int check_delta_limit(st
 	struct object_entry *child = DELTA_CHILD(me);
 	unsigned int m = n;
 	while (child) {
-		unsigned int c = check_delta_limit(child, n + 1);
+		const unsigned int c = check_delta_limit(child, n + 1);
 		if (m < c)
 			m = c;
 		child = DELTA_SIBLING(child);
@@ -2124,7 +2228,7 @@ static void find_deltas(struct object_en
 		while (window_memory_limit &&
 		       mem_usage > window_memory_limit &&
 		       count > 1) {
-			uint32_t tail = (idx + window - count) % window;
+			const uint32_t tail = (idx + window - count) % window;
 			mem_usage -= free_unpacked(array + tail);
 			count--;
 		}
@@ -2233,24 +2337,20 @@ static void find_deltas(struct object_en
 	free(array);
 }
 
-#ifndef NO_PTHREADS
-
-static void try_to_free_from_threads(size_t size)
-{
-	read_lock();
-	release_pack_memory(size);
-	read_unlock();
-}
-
-static try_to_free_t old_try_to_free_routine;
-
 /*
+ * The main object list is split into smaller lists, each is handed to
+ * one worker.
+ *
  * The main thread waits on the condition that (at least) one of the workers
  * has stopped working (which is indicated in the .working member of
  * struct thread_params).
+ *
  * When a work thread has completed its work, it sets .working to 0 and
  * signals the main thread and waits on the condition that .data_ready
  * becomes 1.
+ *
+ * The main thread steals half of the work from the worker that has
+ * most work left to hand it to the idle worker.
  */
 
 struct thread_params {
@@ -2274,18 +2374,14 @@ static pthread_cond_t progress_cond;
  */
 static void init_threaded_search(void)
 {
-	init_recursive_mutex(&read_mutex);
 	pthread_mutex_init(&cache_mutex, NULL);
 	pthread_mutex_init(&progress_mutex, NULL);
 	pthread_cond_init(&progress_cond, NULL);
-	old_try_to_free_routine = set_try_to_free_routine(try_to_free_from_threads);
 }
 
 static void cleanup_threaded_search(void)
 {
-	set_try_to_free_routine(old_try_to_free_routine);
 	pthread_cond_destroy(&progress_cond);
-	pthread_mutex_destroy(&read_mutex);
 	pthread_mutex_destroy(&cache_mutex);
 	pthread_mutex_destroy(&progress_mutex);
 }
@@ -2341,8 +2437,8 @@ static void ll_find_deltas(struct object
 		return;
 	}
 	if (progress > pack_to_stdout)
-		fprintf(stderr, "Delta compression using up to %d threads.\n",
-				delta_search_threads);
+		fprintf_ln(stderr, _("Delta compression using up to %d threads"),
+			   delta_search_threads);
 	p = xcalloc(delta_search_threads, sizeof(*p));
 
 	/* Partition the work amongst work threads. */
@@ -2382,7 +2478,7 @@ static void ll_find_deltas(struct object
 		ret = pthread_create(&p[i].thread, NULL,
 				     threaded_find_deltas, &p[i]);
 		if (ret)
-			die("unable to create thread: %s", strerror(ret));
+			die(_("unable to create thread: %s"), strerror(ret));
 		active_threads++;
 	}
 
@@ -2456,10 +2552,6 @@ static void ll_find_deltas(struct object
 	free(p);
 }
 
-#else
-#define ll_find_deltas(l, s, w, d, p)	find_deltas(l, &s, w, d, p)
-#endif
-
 static void add_tag_chain(const struct object_id *oid)
 {
 	struct tag *tag;
@@ -2471,13 +2563,13 @@ static void add_tag_chain(const struct o
 	 * it was included via bitmaps, we would not have parsed it
 	 * previously).
 	 */
-	if (packlist_find(&to_pack, oid->hash, NULL))
+	if (packlist_find(&to_pack, oid))
 		return;
 
-	tag = lookup_tag(oid);
+	tag = lookup_tag(the_repository, oid);
 	while (1) {
 		if (!tag || parse_tag(tag) || !tag->tagged)
-			die("unable to pack objects reachable from tag %s",
+			die(_("unable to pack objects reachable from tag %s"),
 			    oid_to_hex(oid));
 
 		add_object_entry(&tag->object.oid, OBJ_TAG, NULL, 0);
@@ -2495,7 +2587,7 @@ static int add_ref_tag(const char *path,
 
 	if (starts_with(path, "refs/tags/") && /* is a tag? */
 	    !peel_ref(path, &peeled)    && /* peelable? */
-	    packlist_find(&to_pack, peeled.hash, NULL))      /* object packed? */
+	    packlist_find(&to_pack, &peeled))      /* object packed? */
 		add_tag_chain(oid);
 	return 0;
 }
@@ -2506,6 +2598,9 @@ static void prepare_pack(int window, int
 	uint32_t i, nr_deltas;
 	unsigned n;
 
+	if (use_delta_islands)
+		resolve_tree_islands(the_repository, progress, &to_pack);
+
 	get_object_details();
 
 	/*
@@ -2543,7 +2638,7 @@ static void prepare_pack(int window, int
 		if (!entry->preferred_base) {
 			nr_deltas++;
 			if (oe_type(entry) < 0)
-				die("unable to get type of object %s",
+				die(_("unable to get type of object %s"),
 				    oid_to_hex(&entry->idx.oid));
 		} else {
 			if (oe_type(entry) < 0) {
@@ -2567,7 +2662,7 @@ static void prepare_pack(int window, int
 		ll_find_deltas(delta_list, n, window+1, depth, &nr_done);
 		stop_progress(&progress_state);
 		if (nr_done != nr_deltas)
-			die("inconsistency with delta count");
+			die(_("inconsistency with delta count"));
 	}
 	free(delta_list);
 }
@@ -2607,20 +2702,18 @@ static int git_pack_config(const char *k
 	if (!strcmp(k, "pack.threads")) {
 		delta_search_threads = git_config_int(k, v);
 		if (delta_search_threads < 0)
-			die("invalid number of threads specified (%d)",
+			die(_("invalid number of threads specified (%d)"),
 			    delta_search_threads);
-#ifdef NO_PTHREADS
-		if (delta_search_threads != 1) {
-			warning("no threads support, ignoring %s", k);
+		if (!HAVE_THREADS && delta_search_threads != 1) {
+			warning(_("no threads support, ignoring %s"), k);
 			delta_search_threads = 0;
 		}
-#endif
 		return 0;
 	}
 	if (!strcmp(k, "pack.indexversion")) {
 		pack_idx_opts.version = git_config_int(k, v);
 		if (pack_idx_opts.version > 2)
-			die("bad pack.indexversion=%"PRIu32,
+			die(_("bad pack.indexversion=%"PRIu32),
 			    pack_idx_opts.version);
 		return 0;
 	}
@@ -2638,7 +2731,7 @@ static void read_object_list_from_stdin(
 			if (feof(stdin))
 				break;
 			if (!ferror(stdin))
-				die("fgets returned NULL, not EOF, not error!");
+				die("BUG: fgets returned NULL, not EOF, not error!");
 			if (errno != EINTR)
 				die_errno("fgets");
 			clearerr(stdin);
@@ -2646,13 +2739,13 @@ static void read_object_list_from_stdin(
 		}
 		if (line[0] == '-') {
 			if (get_oid_hex(line+1, &oid))
-				die("expected edge object ID, got garbage:\n %s",
+				die(_("expected edge object ID, got garbage:\n %s"),
 				    line);
 			add_preferred_base(&oid);
 			continue;
 		}
 		if (parse_oid_hex(line, &oid, &p))
-			die("expected object ID, got garbage:\n %s", line);
+			die(_("expected object ID, got garbage:\n %s"), line);
 
 		add_preferred_base_object(p + 1);
 		add_object_entry(&oid, OBJ_NONE, p + 1, 0);
@@ -2669,6 +2762,9 @@ static void show_commit(struct commit *c
 
 	if (write_bitmap_index)
 		index_commit_for_bitmap(commit);
+
+	if (use_delta_islands)
+		propagate_island_marks(commit);
 }
 
 static void show_object(struct object *obj, const char *name, void *data)
@@ -2676,6 +2772,21 @@ static void show_object(struct object *o
 	add_preferred_base_object(name);
 	add_object_entry(&obj->oid, obj->type, name, 0);
 	obj->flags |= OBJECT_ADDED;
+
+	if (use_delta_islands) {
+		const char *p;
+		unsigned depth;
+		struct object_entry *ent;
+
+		/* the empty string is a root tree, which is depth 0 */
+		depth = *name ? 1 : 0;
+		for (p = strchr(name, '/'); p; p = strchr(p + 1, '/'))
+			depth++;
+
+		ent = packlist_find(&to_pack, &obj->oid);
+		if (ent && depth > oe_tree_depth(&to_pack, ent))
+			oe_set_tree_depth(&to_pack, ent, depth);
+	}
 }
 
 static void show_object__ma_allow_any(struct object *obj, const char *name, void *data)
@@ -2776,7 +2887,7 @@ static int ofscmp(const void *a_, const
 		return oidcmp(&a->object->oid, &b->object->oid);
 }
 
-static void add_objects_in_unpacked_packs(struct rev_info *revs)
+static void add_objects_in_unpacked_packs(void)
 {
 	struct packed_git *p;
 	struct in_pack in_pack;
@@ -2784,14 +2895,14 @@ static void add_objects_in_unpacked_pack
 
 	memset(&in_pack, 0, sizeof(in_pack));
 
-	for (p = get_packed_git(the_repository); p; p = p->next) {
+	for (p = get_all_packs(the_repository); p; p = p->next) {
 		struct object_id oid;
 		struct object *o;
 
 		if (!p->pack_local || p->pack_keep || p->pack_keep_in_core)
 			continue;
 		if (open_pack_index(p))
-			die("cannot open pack index");
+			die(_("cannot open pack index"));
 
 		ALLOC_GROW(in_pack.array,
 			   in_pack.nr + p->num_objects,
@@ -2799,7 +2910,7 @@ static void add_objects_in_unpacked_pack
 
 		for (i = 0; i < p->num_objects; i++) {
 			nth_packed_object_oid(&oid, p, i);
-			o = lookup_unknown_object(oid.hash);
+			o = lookup_unknown_object(&oid);
 			if (!(o->flags & OBJECT_ADDED))
 				mark_in_pack_object(o, p, &in_pack);
 			o->flags |= OBJECT_ADDED;
@@ -2822,7 +2933,7 @@ static int add_loose_object(const struct
 	enum object_type type = oid_object_info(the_repository, oid, NULL);
 
 	if (type < 0) {
-		warning("loose object at %s could not be examined", path);
+		warning(_("loose object at %s could not be examined"), path);
 		return 0;
 	}
 
@@ -2848,7 +2959,7 @@ static int has_sha1_pack_kept_or_nonloca
 	struct packed_git *p;
 
 	p = (last_found != (void *)1) ? last_found :
-					get_packed_git(the_repository);
+					get_all_packs(the_repository);
 
 	while (p) {
 		if ((!p->pack_local || p->pack_keep ||
@@ -2858,7 +2969,7 @@ static int has_sha1_pack_kept_or_nonloca
 			return 1;
 		}
 		if (p == last_found)
-			p = get_packed_git(the_repository);
+			p = get_all_packs(the_repository);
 		else
 			p = p->next;
 		if (p == last_found)
@@ -2888,26 +2999,26 @@ static int loosened_object_can_be_discar
 	return 1;
 }
 
-static void loosen_unused_packed_objects(struct rev_info *revs)
+static void loosen_unused_packed_objects(void)
 {
 	struct packed_git *p;
 	uint32_t i;
 	struct object_id oid;
 
-	for (p = get_packed_git(the_repository); p; p = p->next) {
+	for (p = get_all_packs(the_repository); p; p = p->next) {
 		if (!p->pack_local || p->pack_keep || p->pack_keep_in_core)
 			continue;
 
 		if (open_pack_index(p))
-			die("cannot open pack index");
+			die(_("cannot open pack index"));
 
 		for (i = 0; i < p->num_objects; i++) {
 			nth_packed_object_oid(&oid, p, i);
-			if (!packlist_find(&to_pack, oid.hash, NULL) &&
+			if (!packlist_find(&to_pack, &oid) &&
 			    !has_sha1_pack_kept_or_nonlocal(&oid) &&
 			    !loosened_object_can_be_discarded(&oid, p->mtime))
 				if (force_object_loose(&oid, p->mtime))
-					die("unable to force loose object");
+					die(_("unable to force loose object"));
 		}
 	}
 }
@@ -2929,11 +3040,12 @@ static int pack_options_allow_reuse(void
 
 static int get_object_list_from_bitmap(struct rev_info *revs)
 {
-	if (prepare_bitmap_walk(revs) < 0)
+	if (!(bitmap_git = prepare_bitmap_walk(revs)))
 		return -1;
 
 	if (pack_options_allow_reuse() &&
 	    !reuse_partial_packfile_from_bitmap(
+			bitmap_git,
 			&reuse_packfile,
 			&reuse_packfile_objects,
 			&reuse_packfile_offset)) {
@@ -2942,7 +3054,7 @@ static int get_object_list_from_bitmap(s
 		display_progress(progress_state, nr_result);
 	}
 
-	traverse_bitmap_commit_list(&add_object_entry_from_bitmap);
+	traverse_bitmap_commit_list(bitmap_git, &add_object_entry_from_bitmap);
 	return 0;
 }
 
@@ -2961,15 +3073,22 @@ static void record_recent_commit(struct
 static void get_object_list(int ac, const char **av)
 {
 	struct rev_info revs;
+	struct setup_revision_opt s_r_opt = {
+		.allow_exclude_promisor_objects = 1,
+	};
 	char line[1000];
 	int flags = 0;
+	int save_warning;
 
-	init_revisions(&revs, NULL);
+	repo_init_revisions(the_repository, &revs, NULL);
 	save_commit_buffer = 0;
-	setup_revisions(ac, av, &revs, NULL);
+	setup_revisions(ac, av, &revs, &s_r_opt);
 
 	/* make sure shallows are read */
-	is_repository_shallow();
+	is_repository_shallow(the_repository);
+
+	save_warning = warn_on_object_refname_ambiguity;
+	warn_on_object_refname_ambiguity = 0;
 
 	while (fgets(line, sizeof(line), stdin) != NULL) {
 		int len = strlen(line);
@@ -2987,22 +3106,27 @@ static void get_object_list(int ac, cons
 				struct object_id oid;
 				if (get_oid_hex(line + 10, &oid))
 					die("not an SHA-1 '%s'", line + 10);
-				register_shallow(&oid);
+				register_shallow(the_repository, &oid);
 				use_bitmap_index = 0;
 				continue;
 			}
-			die("not a rev '%s'", line);
+			die(_("not a rev '%s'"), line);
 		}
 		if (handle_revision_arg(line, &revs, flags, REVARG_CANNOT_BE_FILENAME))
-			die("bad revision '%s'", line);
+			die(_("bad revision '%s'"), line);
 	}
 
+	warn_on_object_refname_ambiguity = save_warning;
+
 	if (use_bitmap_index && !get_object_list_from_bitmap(&revs))
 		return;
 
+	if (use_delta_islands)
+		load_delta_islands(the_repository, progress);
+
 	if (prepare_revision_walk(&revs))
-		die("revision walk setup failed");
-	mark_edges_uninteresting(&revs, show_edge);
+		die(_("revision walk setup failed"));
+	mark_edges_uninteresting(&revs, show_edge, sparse);
 
 	if (!fn_show_object)
 		fn_show_object = show_object;
@@ -3014,19 +3138,19 @@ static void get_object_list(int ac, cons
 		revs.ignore_missing_links = 1;
 		if (add_unseen_recent_objects_to_traversal(&revs,
 				unpack_unreachable_expiration))
-			die("unable to add recent objects");
+			die(_("unable to add recent objects"));
 		if (prepare_revision_walk(&revs))
-			die("revision walk setup failed");
+			die(_("revision walk setup failed"));
 		traverse_commit_list(&revs, record_recent_commit,
 				     record_recent_object, NULL);
 	}
 
 	if (keep_unreachable)
-		add_objects_in_unpacked_packs(&revs);
+		add_objects_in_unpacked_packs();
 	if (pack_loose_unreachable)
 		add_unreachable_loose_objects();
 	if (unpack_unreachable)
-		loosen_unused_packed_objects(&revs);
+		loosen_unused_packed_objects();
 
 	oid_array_clear(&recent_objects);
 }
@@ -3038,7 +3162,7 @@ static void add_extra_kept_packs(const s
 	if (!names->nr)
 		return;
 
-	for (p = get_packed_git(the_repository); p; p = p->next) {
+	for (p = get_all_packs(the_repository); p; p = p->next) {
 		const char *name = basename(p->pack_name);
 		int i;
 
@@ -3062,6 +3186,9 @@ static int option_parse_index_version(co
 {
 	char *c;
 	const char *val = arg;
+
+	BUG_ON_OPT_NEG(unset);
+
 	pack_idx_opts.version = strtoul(val, &c, 10);
 	if (pack_idx_opts.version > 2)
 		die(_("unsupported index version %s"), val);
@@ -3090,7 +3217,6 @@ static int option_parse_unpack_unreachab
 int cmd_pack_objects(int argc, const char **argv, const char *prefix)
 {
 	int use_internal_rev_list = 0;
-	int thin = 0;
 	int shallow = 0;
 	int all_progress_implied = 0;
 	struct argv_array rp = ARGV_ARRAY_INIT;
@@ -3107,9 +3233,9 @@ int cmd_pack_objects(int argc, const cha
 		OPT_BOOL(0, "all-progress-implied",
 			 &all_progress_implied,
 			 N_("similar to --all-progress when progress meter is shown")),
-		{ OPTION_CALLBACK, 0, "index-version", NULL, N_("version[,offset]"),
+		{ OPTION_CALLBACK, 0, "index-version", NULL, N_("<version>[,<offset>]"),
 		  N_("write the pack index file in the specified idx format version"),
-		  0, option_parse_index_version },
+		  PARSE_OPT_NONEG, option_parse_index_version },
 		OPT_MAGNITUDE(0, "max-pack-size", &pack_size_limit,
 			      N_("maximum size of each output pack file")),
 		OPT_BOOL(0, "local", &local,
@@ -3157,6 +3283,8 @@ int cmd_pack_objects(int argc, const cha
 		{ OPTION_CALLBACK, 0, "unpack-unreachable", NULL, N_("time"),
 		  N_("unpack unreachable objects newer than <time>"),
 		  PARSE_OPT_OPTARG, option_parse_unpack_unreachable },
+		OPT_BOOL(0, "sparse", &sparse,
+			 N_("use the sparse reachability algorithm")),
 		OPT_BOOL(0, "thin", &thin,
 			 N_("create thin packs")),
 		OPT_BOOL(0, "shallow", &shallow,
@@ -3171,21 +3299,33 @@ int cmd_pack_objects(int argc, const cha
 			    N_("do not hide commits by grafts"), 0),
 		OPT_BOOL(0, "use-bitmap-index", &use_bitmap_index,
 			 N_("use a bitmap index if available to speed up counting objects")),
-		OPT_BOOL(0, "write-bitmap-index", &write_bitmap_index,
-			 N_("write a bitmap index together with the pack index")),
+		OPT_SET_INT(0, "write-bitmap-index", &write_bitmap_index,
+			    N_("write a bitmap index together with the pack index"),
+			    WRITE_BITMAP_TRUE),
+		OPT_SET_INT_F(0, "write-bitmap-index-quiet",
+			      &write_bitmap_index,
+			      N_("write a bitmap index if possible"),
+			      WRITE_BITMAP_QUIET, PARSE_OPT_HIDDEN),
 		OPT_PARSE_LIST_OBJECTS_FILTER(&filter_options),
 		{ OPTION_CALLBACK, 0, "missing", NULL, N_("action"),
 		  N_("handling for missing objects"), PARSE_OPT_NONEG,
 		  option_parse_missing_action },
 		OPT_BOOL(0, "exclude-promisor-objects", &exclude_promisor_objects,
 			 N_("do not pack objects in promisor packfiles")),
+		OPT_BOOL(0, "delta-islands", &use_delta_islands,
+			 N_("respect islands during delta compression")),
 		OPT_END(),
 	};
 
 	if (DFS_NUM_STATES > (1 << OE_DFS_STATE_BITS))
 		BUG("too many dfs states, increase OE_DFS_STATE_BITS");
 
-	check_replace_refs = 0;
+	read_replace_refs = 0;
+
+	sparse = git_env_bool("GIT_TEST_PACK_SPARSE", 0);
+	prepare_repo_settings(the_repository);
+	if (!sparse && the_repository->settings.pack_use_sparse != -1)
+		sparse = the_repository->settings.pack_use_sparse;
 
 	reset_pack_idx_option(&pack_idx_opts);
 	git_config(git_pack_config, NULL);
@@ -3251,35 +3391,33 @@ int cmd_pack_objects(int argc, const cha
 	if (pack_compression_level == -1)
 		pack_compression_level = Z_DEFAULT_COMPRESSION;
 	else if (pack_compression_level < 0 || pack_compression_level > Z_BEST_COMPRESSION)
-		die("bad pack compression level %d", pack_compression_level);
+		die(_("bad pack compression level %d"), pack_compression_level);
 
 	if (!delta_search_threads)	/* --threads=0 means autodetect */
 		delta_search_threads = online_cpus();
 
-#ifdef NO_PTHREADS
-	if (delta_search_threads != 1)
-		warning("no threads support, ignoring --threads");
-#endif
+	if (!HAVE_THREADS && delta_search_threads != 1)
+		warning(_("no threads support, ignoring --threads"));
 	if (!pack_to_stdout && !pack_size_limit)
 		pack_size_limit = pack_size_limit_cfg;
 	if (pack_to_stdout && pack_size_limit)
-		die("--max-pack-size cannot be used to build a pack for transfer.");
+		die(_("--max-pack-size cannot be used to build a pack for transfer"));
 	if (pack_size_limit && pack_size_limit < 1024*1024) {
-		warning("minimum pack size limit is 1 MiB");
+		warning(_("minimum pack size limit is 1 MiB"));
 		pack_size_limit = 1024*1024;
 	}
 
 	if (!pack_to_stdout && thin)
-		die("--thin cannot be used to build an indexable pack.");
+		die(_("--thin cannot be used to build an indexable pack"));
 
 	if (keep_unreachable && unpack_unreachable)
-		die("--keep-unreachable and --unpack-unreachable are incompatible.");
+		die(_("--keep-unreachable and --unpack-unreachable are incompatible"));
 	if (!rev_list_all || !rev_list_reflog || !rev_list_index)
 		unpack_unreachable_expiration = 0;
 
 	if (filter_options.choice) {
 		if (!pack_to_stdout)
-			die("cannot use --filter without --stdout.");
+			die(_("cannot use --filter without --stdout"));
 		use_bitmap_index = 0;
 	}
 
@@ -3299,19 +3437,22 @@ int cmd_pack_objects(int argc, const cha
 		use_bitmap_index = use_bitmap_index_default;
 
 	/* "hard" reasons not to use bitmaps; these just won't work at all */
-	if (!use_internal_rev_list || (!pack_to_stdout && write_bitmap_index) || is_repository_shallow())
+	if (!use_internal_rev_list || (!pack_to_stdout && write_bitmap_index) || is_repository_shallow(the_repository))
 		use_bitmap_index = 0;
 
 	if (pack_to_stdout || !rev_list_all)
 		write_bitmap_index = 0;
 
+	if (use_delta_islands)
+		argv_array_push(&rp, "--topo-order");
+
 	if (progress && all_progress_implied)
 		progress = 2;
 
 	add_extra_kept_packs(&keep_pack_list);
 	if (ignore_packed_keep_on_disk) {
 		struct packed_git *p;
-		for (p = get_packed_git(the_repository); p; p = p->next)
+		for (p = get_all_packs(the_repository); p; p = p->next)
 			if (p->pack_local && p->pack_keep)
 				break;
 		if (!p) /* no keep-able packs found */
@@ -3324,7 +3465,7 @@ int cmd_pack_objects(int argc, const cha
 		 * it also covers non-local objects
 		 */
 		struct packed_git *p;
-		for (p = get_packed_git(the_repository); p; p = p->next) {
+		for (p = get_all_packs(the_repository); p; p = p->next) {
 			if (!p->pack_local) {
 				have_non_local_packs = 1;
 				break;
@@ -3332,7 +3473,9 @@ int cmd_pack_objects(int argc, const cha
 		}
 	}
 
-	prepare_packing_data(&to_pack);
+	trace2_region_enter("pack-objects", "enumerate-objects",
+			    the_repository);
+	prepare_packing_data(the_repository, &to_pack);
 
 	if (progress)
 		progress_state = start_progress(_("Enumerating objects"), 0);
@@ -3346,15 +3489,27 @@ int cmd_pack_objects(int argc, const cha
 	if (include_tag && nr_result)
 		for_each_ref(add_ref_tag, NULL);
 	stop_progress(&progress_state);
+	trace2_region_leave("pack-objects", "enumerate-objects",
+			    the_repository);
 
 	if (non_empty && !nr_result)
 		return 0;
-	if (nr_result)
+	if (nr_result) {
+		trace2_region_enter("pack-objects", "prepare-pack",
+				    the_repository);
 		prepare_pack(window, depth);
+		trace2_region_leave("pack-objects", "prepare-pack",
+				    the_repository);
+	}
+
+	trace2_region_enter("pack-objects", "write-pack-file", the_repository);
 	write_pack_file();
+	trace2_region_leave("pack-objects", "write-pack-file", the_repository);
+
 	if (progress)
-		fprintf(stderr, "Total %"PRIu32" (delta %"PRIu32"),"
-			" reused %"PRIu32" (delta %"PRIu32")\n",
-			written, written_delta, reused, reused_delta);
+		fprintf_ln(stderr,
+			   _("Total %"PRIu32" (delta %"PRIu32"),"
+			     " reused %"PRIu32" (delta %"PRIu32")"),
+			   written, written_delta, reused, reused_delta);
 	return 0;
 }
diff -pruN 1.2.1+git2.18.0-1/git/builtin/pack-redundant.c 1.2.3+git2.25.1-1/git/builtin/pack-redundant.c
--- 1.2.1+git2.18.0-1/git/builtin/pack-redundant.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/builtin/pack-redundant.c	2020-02-17 04:47:35.000000000 +0000
@@ -32,14 +32,10 @@ static struct pack_list {
 	struct pack_list *next;
 	struct packed_git *pack;
 	struct llist *unique_objects;
-	struct llist *all_objects;
+	struct llist *remaining_objects;
+	size_t all_objects_size;
 } *local_packs = NULL, *altodb_packs = NULL;
 
-struct pll {
-	struct pll *next;
-	struct pack_list *pl;
-};
-
 static struct llist_item *free_nodes;
 
 static inline void llist_item_put(struct llist_item *item)
@@ -63,15 +59,6 @@ static inline struct llist_item *llist_i
 	return new_item;
 }
 
-static void llist_free(struct llist *list)
-{
-	while ((list->back = list->front)) {
-		list->front = list->front->next;
-		llist_item_put(list->back);
-	}
-	free(list);
-}
-
 static inline void llist_init(struct llist **list)
 {
 	*list = xmalloc(sizeof(struct llist));
@@ -166,7 +153,7 @@ redo_from_start:
 	l = (hint == NULL) ? list->front : hint;
 	prev = NULL;
 	while (l) {
-		int cmp = oidcmp(l->oid, oid);
+		const int cmp = oidcmp(l->oid, oid);
 		if (cmp > 0) /* not in list, since sorted */
 			return prev;
 		if (!cmp) { /* found */
@@ -254,6 +241,11 @@ static void cmp_two_packs(struct pack_li
 	struct llist_item *p1_hint = NULL, *p2_hint = NULL;
 	const unsigned int hashsz = the_hash_algo->rawsz;
 
+	if (!p1->unique_objects)
+		p1->unique_objects = llist_copy(p1->remaining_objects);
+	if (!p2->unique_objects)
+		p2->unique_objects = llist_copy(p2->remaining_objects);
+
 	p1_base = p1->pack->index_data;
 	p2_base = p2->pack->index_data;
 	p1_base += 256 * 4 + ((p1->pack->index_version < 2) ? 4 : 8);
@@ -264,7 +256,7 @@ static void cmp_two_packs(struct pack_li
 	while (p1_off < p1->pack->num_objects * p1_step &&
 	       p2_off < p2->pack->num_objects * p2_step)
 	{
-		int cmp = hashcmp(p1_base + p1_off, p2_base + p2_off);
+		const int cmp = hashcmp(p1_base + p1_off, p2_base + p2_off);
 		/* cmp ~ p1 - p2 */
 		if (cmp == 0) {
 			p1_hint = llist_sorted_remove(p1->unique_objects,
@@ -285,78 +277,6 @@ static void cmp_two_packs(struct pack_li
 	}
 }
 
-static void pll_free(struct pll *l)
-{
-	struct pll *old;
-	struct pack_list *opl;
-
-	while (l) {
-		old = l;
-		while (l->pl) {
-			opl = l->pl;
-			l->pl = opl->next;
-			free(opl);
-		}
-		l = l->next;
-		free(old);
-	}
-}
-
-/* all the permutations have to be free()d at the same time,
- * since they refer to each other
- */
-static struct pll * get_permutations(struct pack_list *list, int n)
-{
-	struct pll *subset, *ret = NULL, *new_pll = NULL;
-
-	if (list == NULL || pack_list_size(list) < n || n == 0)
-		return NULL;
-
-	if (n == 1) {
-		while (list) {
-			new_pll = xmalloc(sizeof(*new_pll));
-			new_pll->pl = NULL;
-			pack_list_insert(&new_pll->pl, list);
-			new_pll->next = ret;
-			ret = new_pll;
-			list = list->next;
-		}
-		return ret;
-	}
-
-	while (list->next) {
-		subset = get_permutations(list->next, n - 1);
-		while (subset) {
-			new_pll = xmalloc(sizeof(*new_pll));
-			new_pll->pl = subset->pl;
-			pack_list_insert(&new_pll->pl, list);
-			new_pll->next = ret;
-			ret = new_pll;
-			subset = subset->next;
-		}
-		list = list->next;
-	}
-	return ret;
-}
-
-static int is_superset(struct pack_list *pl, struct llist *list)
-{
-	struct llist *diff;
-
-	diff = llist_copy(list);
-
-	while (pl) {
-		llist_sorted_difference_inplace(diff, pl->all_objects);
-		if (diff->size == 0) { /* we're done */
-			llist_free(diff);
-			return 1;
-		}
-		pl = pl->next;
-	}
-	llist_free(diff);
-	return 0;
-}
-
 static size_t sizeof_union(struct packed_git *p1, struct packed_git *p2)
 {
 	size_t ret = 0;
@@ -421,14 +341,58 @@ static inline off_t pack_set_bytecount(s
 	return ret;
 }
 
+static int cmp_remaining_objects(const void *a, const void *b)
+{
+	struct pack_list *pl_a = *((struct pack_list **)a);
+	struct pack_list *pl_b = *((struct pack_list **)b);
+
+	if (pl_a->remaining_objects->size == pl_b->remaining_objects->size) {
+		/* have the same remaining_objects, big pack first */
+		if (pl_a->all_objects_size == pl_b->all_objects_size)
+			return 0;
+		else if (pl_a->all_objects_size < pl_b->all_objects_size)
+			return 1;
+		else
+			return -1;
+	} else if (pl_a->remaining_objects->size < pl_b->remaining_objects->size) {
+		/* sort by remaining objects, more objects first */
+		return 1;
+	} else {
+		return -1;
+	}
+}
+
+/* Sort pack_list, greater size of remaining_objects first */
+static void sort_pack_list(struct pack_list **pl)
+{
+	struct pack_list **ary, *p;
+	int i;
+	size_t n = pack_list_size(*pl);
+
+	if (n < 2)
+		return;
+
+	/* prepare an array of packed_list for easier sorting */
+	ary = xcalloc(n, sizeof(struct pack_list *));
+	for (n = 0, p = *pl; p; p = p->next)
+		ary[n++] = p;
+
+	QSORT(ary, n, cmp_remaining_objects);
+
+	/* link them back again */
+	for (i = 0; i < n - 1; i++)
+		ary[i]->next = ary[i + 1];
+	ary[n - 1]->next = NULL;
+	*pl = ary[0];
+
+	free(ary);
+}
+
+
 static void minimize(struct pack_list **min)
 {
-	struct pack_list *pl, *unique = NULL,
-		*non_unique = NULL, *min_perm = NULL;
-	struct pll *perm, *perm_all, *perm_ok = NULL, *new_perm;
-	struct llist *missing;
-	off_t min_perm_size = 0, perm_size;
-	int n;
+	struct pack_list *pl, *unique = NULL, *non_unique = NULL;
+	struct llist *missing, *unique_pack_objects;
 
 	pl = local_packs;
 	while (pl) {
@@ -442,53 +406,41 @@ static void minimize(struct pack_list **
 	missing = llist_copy(all_objects);
 	pl = unique;
 	while (pl) {
-		llist_sorted_difference_inplace(missing, pl->all_objects);
+		llist_sorted_difference_inplace(missing, pl->remaining_objects);
 		pl = pl->next;
 	}
 
+	*min = unique;
+
 	/* return if there are no objects missing from the unique set */
 	if (missing->size == 0) {
-		*min = unique;
 		free(missing);
 		return;
 	}
 
-	/* find the permutations which contain all missing objects */
-	for (n = 1; n <= pack_list_size(non_unique) && !perm_ok; n++) {
-		perm_all = perm = get_permutations(non_unique, n);
-		while (perm) {
-			if (is_superset(perm->pl, missing)) {
-				new_perm = xmalloc(sizeof(struct pll));
-				memcpy(new_perm, perm, sizeof(struct pll));
-				new_perm->next = perm_ok;
-				perm_ok = new_perm;
-			}
-			perm = perm->next;
-		}
-		if (perm_ok)
-			break;
-		pll_free(perm_all);
-	}
-	if (perm_ok == NULL)
-		die("Internal error: No complete sets found!");
+	unique_pack_objects = llist_copy(all_objects);
+	llist_sorted_difference_inplace(unique_pack_objects, missing);
 
-	/* find the permutation with the smallest size */
-	perm = perm_ok;
-	while (perm) {
-		perm_size = pack_set_bytecount(perm->pl);
-		if (!min_perm_size || min_perm_size > perm_size) {
-			min_perm_size = perm_size;
-			min_perm = perm->pl;
-		}
-		perm = perm->next;
-	}
-	*min = min_perm;
-	/* add the unique packs to the list */
-	pl = unique;
+	/* remove unique pack objects from the non_unique packs */
+	pl = non_unique;
 	while (pl) {
-		pack_list_insert(min, pl);
+		llist_sorted_difference_inplace(pl->remaining_objects, unique_pack_objects);
 		pl = pl->next;
 	}
+
+	while (non_unique) {
+		/* sort the non_unique packs, greater size of remaining_objects first */
+		sort_pack_list(&non_unique);
+		if (non_unique->remaining_objects->size == 0)
+			break;
+
+		pack_list_insert(min, non_unique);
+
+		for (pl = non_unique->next; pl && pl->remaining_objects->size > 0;  pl = pl->next)
+			llist_sorted_difference_inplace(pl->remaining_objects, non_unique->remaining_objects);
+
+		non_unique = non_unique->next;
+	}
 }
 
 static void load_all_objects(void)
@@ -500,7 +452,7 @@ static void load_all_objects(void)
 
 	while (pl) {
 		hint = NULL;
-		l = pl->all_objects->front;
+		l = pl->remaining_objects->front;
 		while (l) {
 			hint = llist_insert_sorted_unique(all_objects,
 							  l->oid, hint);
@@ -511,7 +463,7 @@ static void load_all_objects(void)
 	/* remove objects present in remote packs */
 	pl = altodb_packs;
 	while (pl) {
-		llist_sorted_difference_inplace(all_objects, pl->all_objects);
+		llist_sorted_difference_inplace(all_objects, pl->remaining_objects);
 		pl = pl->next;
 	}
 }
@@ -536,11 +488,10 @@ static void scan_alt_odb_packs(void)
 	while (alt) {
 		local = local_packs;
 		while (local) {
-			llist_sorted_difference_inplace(local->unique_objects,
-							alt->all_objects);
+			llist_sorted_difference_inplace(local->remaining_objects,
+							alt->remaining_objects);
 			local = local->next;
 		}
-		llist_sorted_difference_inplace(all_objects, alt->all_objects);
 		alt = alt->next;
 	}
 }
@@ -555,7 +506,7 @@ static struct pack_list * add_pack(struc
 		return NULL;
 
 	l.pack = p;
-	llist_init(&l.all_objects);
+	llist_init(&l.remaining_objects);
 
 	if (open_pack_index(p))
 		return NULL;
@@ -564,11 +515,11 @@ static struct pack_list * add_pack(struc
 	base += 256 * 4 + ((p->index_version < 2) ? 4 : 8);
 	step = the_hash_algo->rawsz + ((p->index_version < 2) ? 4 : 0);
 	while (off < p->num_objects * step) {
-		llist_insert_back(l.all_objects, (const struct object_id *)(base + off));
+		llist_insert_back(l.remaining_objects, (const struct object_id *)(base + off));
 		off += step;
 	}
-	/* this list will be pruned in cmp_two_packs later */
-	l.unique_objects = llist_copy(l.all_objects);
+	l.all_objects_size = l.remaining_objects->size;
+	l.unique_objects = NULL;
 	if (p->pack_local)
 		return pack_list_insert(&local_packs, &l);
 	else
@@ -577,7 +528,7 @@ static struct pack_list * add_pack(struc
 
 static struct pack_list * add_pack_file(const char *filename)
 {
-	struct packed_git *p = get_packed_git(the_repository);
+	struct packed_git *p = get_all_packs(the_repository);
 
 	if (strlen(filename) < 40)
 		die("Bad pack filename: %s", filename);
@@ -592,7 +543,7 @@ static struct pack_list * add_pack_file(
 
 static void load_all(void)
 {
-	struct packed_git *p = get_packed_git(the_repository);
+	struct packed_git *p = get_all_packs(the_repository);
 
 	while (p) {
 		add_pack(p);
@@ -603,7 +554,7 @@ static void load_all(void)
 int cmd_pack_redundant(int argc, const char **argv, const char *prefix)
 {
 	int i;
-	struct pack_list *min, *red, *pl;
+	struct pack_list *min = NULL, *red, *pl;
 	struct llist *ignore;
 	struct object_id *oid;
 	char buf[GIT_MAX_HEXSZ + 2]; /* hex hash + \n + \0 */
@@ -646,7 +597,6 @@ int cmd_pack_redundant(int argc, const c
 
 	load_all_objects();
 
-	cmp_local_packs();
 	if (alt_odb)
 		scan_alt_odb_packs();
 
@@ -663,10 +613,12 @@ int cmd_pack_redundant(int argc, const c
 	llist_sorted_difference_inplace(all_objects, ignore);
 	pl = local_packs;
 	while (pl) {
-		llist_sorted_difference_inplace(pl->unique_objects, ignore);
+		llist_sorted_difference_inplace(pl->remaining_objects, ignore);
 		pl = pl->next;
 	}
 
+	cmp_local_packs();
+
 	minimize(&min);
 
 	if (verbose) {
@@ -689,7 +641,7 @@ int cmd_pack_redundant(int argc, const c
 	pl = red = pack_list_difference(local_packs, min);
 	while (pl) {
 		printf("%s\n%s\n",
-		       sha1_pack_index_name(pl->pack->sha1),
+		       sha1_pack_index_name(pl->pack->hash),
 		       pl->pack->pack_name);
 		pl = pl->next;
 	}
diff -pruN 1.2.1+git2.18.0-1/git/builtin/pack-refs.c 1.2.3+git2.25.1-1/git/builtin/pack-refs.c
--- 1.2.1+git2.18.0-1/git/builtin/pack-refs.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/builtin/pack-refs.c	2020-02-17 04:47:35.000000000 +0000
@@ -1,4 +1,5 @@
 #include "builtin.h"
+#include "config.h"
 #include "parse-options.h"
 #include "refs.h"
 #include "repository.h"
@@ -16,6 +17,7 @@ int cmd_pack_refs(int argc, const char *
 		OPT_BIT(0, "prune", &flags, N_("prune loose refs (default)"), PACK_REFS_PRUNE),
 		OPT_END(),
 	};
+	git_config(git_default_config, NULL);
 	if (parse_options(argc, argv, prefix, opts, pack_refs_usage, 0))
 		usage_with_options(pack_refs_usage, opts);
 	return refs_pack_refs(get_main_ref_store(the_repository), flags);
diff -pruN 1.2.1+git2.18.0-1/git/builtin/patch-id.c 1.2.3+git2.25.1-1/git/builtin/patch-id.c
--- 1.2.1+git2.18.0-1/git/builtin/patch-id.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/builtin/patch-id.c	2020-02-17 04:47:35.000000000 +0000
@@ -1,15 +1,12 @@
+#include "cache.h"
 #include "builtin.h"
 #include "config.h"
+#include "diff.h"
 
 static void flush_current_id(int patchlen, struct object_id *id, struct object_id *result)
 {
-	char name[50];
-
-	if (!patchlen)
-		return;
-
-	memcpy(name, oid_to_hex(id), GIT_SHA1_HEXSZ + 1);
-	printf("%s %s\n", oid_to_hex(result), name);
+	if (patchlen)
+		printf("%s %s\n", oid_to_hex(result), oid_to_hex(id));
 }
 
 static int remove_space(char *line)
@@ -54,30 +51,14 @@ static int scan_hunk_header(const char *
 	return 1;
 }
 
-static void flush_one_hunk(struct object_id *result, git_SHA_CTX *ctx)
-{
-	unsigned char hash[GIT_MAX_RAWSZ];
-	unsigned short carry = 0;
-	int i;
-
-	git_SHA1_Final(hash, ctx);
-	git_SHA1_Init(ctx);
-	/* 20-byte sum, with carry */
-	for (i = 0; i < GIT_SHA1_RAWSZ; ++i) {
-		carry += result->hash[i] + hash[i];
-		result->hash[i] = carry;
-		carry >>= 8;
-	}
-}
-
 static int get_one_patchid(struct object_id *next_oid, struct object_id *result,
 			   struct strbuf *line_buf, int stable)
 {
 	int patchlen = 0, found_next = 0;
 	int before = -1, after = -1;
-	git_SHA_CTX ctx;
+	git_hash_ctx ctx;
 
-	git_SHA1_Init(&ctx);
+	the_hash_algo->init_fn(&ctx);
 	oidclr(result);
 
 	while (strbuf_getwholeline(line_buf, stdin, '\n') != EOF) {
@@ -137,7 +118,7 @@ static int get_one_patchid(struct object
 		/* Compute the sha without whitespace */
 		len = remove_space(line);
 		patchlen += len;
-		git_SHA1_Update(&ctx, line, len);
+		the_hash_algo->update_fn(&ctx, line, len);
 	}
 
 	if (!found_next)
diff -pruN 1.2.1+git2.18.0-1/git/builtin/prune.c 1.2.3+git2.25.1-1/git/builtin/prune.c
--- 1.2.1+git2.18.0-1/git/builtin/prune.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/builtin/prune.c	2020-02-17 04:47:35.000000000 +0000
@@ -6,6 +6,7 @@
 #include "reachable.h"
 #include "parse-options.h"
 #include "progress.h"
+#include "object-store.h"
 
 static const char * const prune_usage[] = {
 	N_("git prune [-n] [-v] [--progress] [--expire <time>] [--] [<head>...]"),
@@ -30,16 +31,39 @@ static int prune_tmp_file(const char *fu
 	return 0;
 }
 
+static void perform_reachability_traversal(struct rev_info *revs)
+{
+	static int initialized;
+	struct progress *progress = NULL;
+
+	if (initialized)
+		return;
+
+	if (show_progress)
+		progress = start_delayed_progress(_("Checking connectivity"), 0);
+	mark_reachable_objects(revs, 1, expire, progress);
+	stop_progress(&progress);
+	initialized = 1;
+}
+
+static int is_object_reachable(const struct object_id *oid,
+			       struct rev_info *revs)
+{
+	struct object *obj;
+
+	perform_reachability_traversal(revs);
+
+	obj = lookup_object(the_repository, oid);
+	return obj && (obj->flags & SEEN);
+}
+
 static int prune_object(const struct object_id *oid, const char *fullpath,
 			void *data)
 {
+	struct rev_info *revs = data;
 	struct stat st;
 
-	/*
-	 * Do we know about this object?
-	 * It must have been reachable
-	 */
-	if (lookup_object(oid->hash))
+	if (is_object_reachable(oid, revs))
 		return 0;
 
 	if (lstat(fullpath, &st)) {
@@ -101,7 +125,6 @@ static void remove_temporary_files(const
 int cmd_prune(int argc, const char **argv, const char *prefix)
 {
 	struct rev_info revs;
-	struct progress *progress = NULL;
 	int exclude_promisor_objects = 0;
 	const struct option options[] = {
 		OPT__DRY_RUN(&show_only, N_("do not remove, show only")),
@@ -117,9 +140,9 @@ int cmd_prune(int argc, const char **arg
 
 	expire = TIME_MAX;
 	save_commit_buffer = 0;
-	check_replace_refs = 0;
+	read_replace_refs = 0;
 	ref_paranoia = 1;
-	init_revisions(&revs, prefix);
+	repo_init_revisions(the_repository, &revs, prefix);
 
 	argc = parse_options(argc, argv, prefix, options, prune_usage, 0);
 
@@ -141,17 +164,13 @@ int cmd_prune(int argc, const char **arg
 
 	if (show_progress == -1)
 		show_progress = isatty(2);
-	if (show_progress)
-		progress = start_delayed_progress(_("Checking connectivity"), 0);
 	if (exclude_promisor_objects) {
 		fetch_if_missing = 0;
 		revs.exclude_promisor_objects = 1;
 	}
 
-	mark_reachable_objects(&revs, 1, expire, progress);
-	stop_progress(&progress);
 	for_each_loose_file_in_objdir(get_object_directory(), prune_object,
-				      prune_cruft, prune_subdir, NULL);
+				      prune_cruft, prune_subdir, &revs);
 
 	prune_packed_objects(show_only ? PRUNE_PACKED_DRY_RUN : 0);
 	remove_temporary_files(get_object_directory());
@@ -159,8 +178,10 @@ int cmd_prune(int argc, const char **arg
 	remove_temporary_files(s);
 	free(s);
 
-	if (is_repository_shallow())
-		prune_shallow(show_only);
+	if (is_repository_shallow(the_repository)) {
+		perform_reachability_traversal(&revs);
+		prune_shallow(show_only ? PRUNE_SHOW_ONLY : 0);
+	}
 
 	return 0;
 }
diff -pruN 1.2.1+git2.18.0-1/git/builtin/prune-packed.c 1.2.3+git2.25.1-1/git/builtin/prune-packed.c
--- 1.2.1+git2.18.0-1/git/builtin/prune-packed.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/builtin/prune-packed.c	2020-02-17 04:47:35.000000000 +0000
@@ -3,6 +3,7 @@
 #include "progress.h"
 #include "parse-options.h"
 #include "packfile.h"
+#include "object-store.h"
 
 static const char * const prune_packed_usage[] = {
 	N_("git prune-packed [-n | --dry-run] [-q | --quiet]"),
@@ -62,6 +63,11 @@ int cmd_prune_packed(int argc, const cha
 	argc = parse_options(argc, argv, prefix, prune_packed_options,
 			     prune_packed_usage, 0);
 
+	if (argc > 0)
+		usage_msg_opt(_("too many arguments"),
+			      prune_packed_usage,
+			      prune_packed_options);
+
 	prune_packed_objects(opts);
 	return 0;
 }
diff -pruN 1.2.1+git2.18.0-1/git/builtin/pull.c 1.2.3+git2.25.1-1/git/builtin/pull.c
--- 1.2.1+git2.18.0-1/git/builtin/pull.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/builtin/pull.c	2020-02-17 04:47:35.000000000 +0000
@@ -5,6 +5,7 @@
  *
  * Fetch one or more remote refs and merge it/them into the current HEAD.
  */
+#define USE_THE_INDEX_COMPATIBILITY_MACROS
 #include "cache.h"
 #include "config.h"
 #include "builtin.h"
@@ -22,6 +23,8 @@
 #include "tempfile.h"
 #include "lockfile.h"
 #include "wt-status.h"
+#include "commit-reach.h"
+#include "sequencer.h"
 
 enum rebase_type {
 	REBASE_INVALID = -1,
@@ -48,12 +51,16 @@ static enum rebase_type parse_config_reb
 		return REBASE_FALSE;
 	else if (v > 0)
 		return REBASE_TRUE;
-	else if (!strcmp(value, "preserve"))
+	else if (!strcmp(value, "preserve") || !strcmp(value, "p"))
 		return REBASE_PRESERVE;
-	else if (!strcmp(value, "merges"))
+	else if (!strcmp(value, "merges") || !strcmp(value, "m"))
 		return REBASE_MERGES;
-	else if (!strcmp(value, "interactive"))
+	else if (!strcmp(value, "interactive") || !strcmp(value, "i"))
 		return REBASE_INTERACTIVE;
+	/*
+	 * Please update _git_config() in git-completion.bash when you
+	 * add new rebase modes.
+	 */
 
 	if (fatal)
 		die(_("Invalid value for %s: %s"), key, value);
@@ -95,6 +102,7 @@ static char *opt_signoff;
 static char *opt_squash;
 static char *opt_commit;
 static char *opt_edit;
+static char *cleanup_arg;
 static char *opt_ff;
 static char *opt_verify_signatures;
 static int opt_autostash = -1;
@@ -120,6 +128,8 @@ static char *opt_update_shallow;
 static char *opt_refmap;
 static char *opt_ipv4;
 static char *opt_ipv6;
+static int opt_show_forced_updates = -1;
+static char *set_upstream;
 
 static struct option pull_options[] = {
 	/* Shared options */
@@ -135,7 +145,7 @@ static struct option pull_options[] = {
 	/* Options passed to git-merge or git-rebase */
 	OPT_GROUP(N_("Options related to merging")),
 	{ OPTION_CALLBACK, 'r', "rebase", &opt_rebase,
-	  "false|true|merges|preserve|interactive",
+	  "(false|true|merges|preserve|interactive)",
 	  N_("incorporate changes by rebasing rather than merging"),
 	  PARSE_OPT_OPTARG, parse_opt_rebase },
 	OPT_PASSTHRU('n', NULL, &opt_diffstat, NULL,
@@ -162,6 +172,7 @@ static struct option pull_options[] = {
 	OPT_PASSTHRU(0, "edit", &opt_edit, NULL,
 		N_("edit message before committing"),
 		PARSE_OPT_NOARG),
+	OPT_CLEANUP(&cleanup_arg),
 	OPT_PASSTHRU(0, "ff", &opt_ff, NULL,
 		N_("allow fast-forward"),
 		PARSE_OPT_NOARG),
@@ -231,6 +242,11 @@ static struct option pull_options[] = {
 	OPT_PASSTHRU('6',  "ipv6", &opt_ipv6, NULL,
 		N_("use IPv6 addresses only"),
 		PARSE_OPT_NOARG),
+	OPT_BOOL(0, "show-forced-updates", &opt_show_forced_updates,
+		 N_("check for forced-updates on all updated branches")),
+	OPT_PASSTHRU(0, "set-upstream", &set_upstream, NULL,
+		N_("set upstream for git pull/fetch"),
+		PARSE_OPT_NOARG),
 
 	OPT_END()
 };
@@ -356,16 +372,17 @@ static int git_pull_config(const char *v
  */
 static void get_merge_heads(struct oid_array *merge_heads)
 {
-	const char *filename = git_path_fetch_head();
+	const char *filename = git_path_fetch_head(the_repository);
 	FILE *fp;
 	struct strbuf sb = STRBUF_INIT;
 	struct object_id oid;
 
 	fp = xfopen(filename, "r");
 	while (strbuf_getline_lf(&sb, fp) != EOF) {
-		if (get_oid_hex(sb.buf, &oid))
-			continue;  /* invalid line: does not start with SHA1 */
-		if (starts_with(sb.buf + GIT_SHA1_HEXSZ, "\tnot-for-merge\t"))
+		const char *p;
+		if (parse_oid_hex(sb.buf, &oid, &p))
+			continue;  /* invalid line: does not start with object ID */
+		if (starts_with(p, "\tnot-for-merge\t"))
 			continue;  /* ref is not-for-merge */
 		oid_array_append(merge_heads, &oid);
 	}
@@ -539,6 +556,12 @@ static int run_fetch(const char *repo, c
 		argv_array_push(&args, opt_ipv4);
 	if (opt_ipv6)
 		argv_array_push(&args, opt_ipv6);
+	if (opt_show_forced_updates > 0)
+		argv_array_push(&args, "--show-forced-updates");
+	else if (opt_show_forced_updates == 0)
+		argv_array_push(&args, "--no-show-forced-updates");
+	if (set_upstream)
+		argv_array_push(&args, set_upstream);
 
 	if (repo) {
 		argv_array_push(&args, repo);
@@ -556,13 +579,26 @@ static int run_fetch(const char *repo, c
 static int pull_into_void(const struct object_id *merge_head,
 		const struct object_id *curr_head)
 {
+	if (opt_verify_signatures) {
+		struct commit *commit;
+
+		commit = lookup_commit(the_repository, merge_head);
+		if (!commit)
+			die(_("unable to access commit %s"),
+			    oid_to_hex(merge_head));
+
+		verify_merge_signature(commit, opt_verbosity);
+	}
+
 	/*
 	 * Two-way merge: we treat the index as based on an empty tree,
 	 * and try to fast-forward to HEAD. This ensures we will not lose
 	 * index/worktree changes that the user already made on the unborn
 	 * branch.
 	 */
-	if (checkout_fast_forward(the_hash_algo->empty_tree, merge_head, 0))
+	if (checkout_fast_forward(the_repository,
+				  the_hash_algo->empty_tree,
+				  merge_head, 0))
 		return 1;
 
 	if (update_ref("initial pull", "HEAD", merge_head, curr_head, 0, UPDATE_REFS_DIE_ON_ERR))
@@ -625,6 +661,8 @@ static int run_merge(void)
 		argv_array_push(&args, opt_commit);
 	if (opt_edit)
 		argv_array_push(&args, opt_edit);
+	if (cleanup_arg)
+		argv_array_pushf(&args, "--cleanup=%s", cleanup_arg);
 	if (opt_ff)
 		argv_array_push(&args, opt_ff);
 	if (opt_verify_signatures)
@@ -684,7 +722,7 @@ static const char *get_tracking_branch(c
 	const char *spec_src;
 	const char *merge_branch;
 
-	refspec_item_init(&spec, refspec, REFSPEC_FETCH);
+	refspec_item_init_or_die(&spec, refspec, REFSPEC_FETCH);
 	spec_src = spec.src;
 	if (!*spec_src || !strcmp(spec_src, "HEAD"))
 		spec_src = "HEAD";
@@ -741,7 +779,7 @@ static int get_rebase_fork_point(struct
 	cp.no_stderr = 1;
 	cp.git_cmd = 1;
 
-	ret = capture_command(&cp, &sb, GIT_SHA1_HEXSZ);
+	ret = capture_command(&cp, &sb, GIT_MAX_HEXSZ);
 	if (ret)
 		goto cleanup;
 
@@ -765,10 +803,13 @@ static int get_octopus_merge_base(struct
 {
 	struct commit_list *revs = NULL, *result;
 
-	commit_list_insert(lookup_commit_reference(curr_head), &revs);
-	commit_list_insert(lookup_commit_reference(merge_head), &revs);
+	commit_list_insert(lookup_commit_reference(the_repository, curr_head),
+			   &revs);
+	commit_list_insert(lookup_commit_reference(the_repository, merge_head),
+			   &revs);
 	if (!is_null_oid(fork_point))
-		commit_list_insert(lookup_commit_reference(fork_point), &revs);
+		commit_list_insert(lookup_commit_reference(the_repository, fork_point),
+				   &revs);
 
 	result = get_octopus_merge_bases(revs);
 	free_commit_list(revs);
@@ -783,7 +824,7 @@ static int get_octopus_merge_base(struct
 }
 
 /**
- * Given the current HEAD SHA1, the merge head returned from git-fetch and the
+ * Given the current HEAD oid, the merge head returned from git-fetch and the
  * fork point calculated by get_rebase_fork_point(), runs git-rebase with the
  * appropriate arguments and returns its exit status.
  */
@@ -796,7 +837,7 @@ static int run_rebase(const struct objec
 	struct argv_array args = ARGV_ARRAY_INIT;
 
 	if (!get_octopus_merge_base(&oct_merge_base, curr_head, merge_head, fork_point))
-		if (!is_null_oid(fork_point) && !oidcmp(&oct_merge_base, fork_point))
+		if (!is_null_oid(fork_point) && oideq(&oct_merge_base, fork_point))
 			fork_point = NULL;
 
 	argv_array_push(&args, "rebase");
@@ -853,6 +894,13 @@ int cmd_pull(int argc, const char **argv
 
 	argc = parse_options(argc, argv, prefix, pull_options, pull_usage, 0);
 
+	if (cleanup_arg)
+		/*
+		 * this only checks the validity of cleanup_arg; we don't need
+		 * a valid value for use_editor
+		 */
+		get_cleanup_mode(cleanup_arg, 0);
+
 	parse_repo_refspecs(argc, argv, &repo, &refspecs);
 
 	if (!opt_ff)
@@ -864,7 +912,7 @@ int cmd_pull(int argc, const char **argv
 	if (read_cache_unmerged())
 		die_resolve_conflict("pull");
 
-	if (file_exists(git_path_merge_head()))
+	if (file_exists(git_path_merge_head(the_repository)))
 		die_conclude_merge();
 
 	if (get_oid("HEAD", &orig_head))
@@ -882,7 +930,8 @@ int cmd_pull(int argc, const char **argv
 			die(_("Updating an unborn branch with changes added to the index."));
 
 		if (!autostash)
-			require_clean_work_tree(N_("pull with rebase"),
+			require_clean_work_tree(the_repository,
+				N_("pull with rebase"),
 				_("please commit or stash them."), 1, 0);
 
 		if (get_rebase_fork_point(&rebase_fork_point, repo, *refspecs))
@@ -899,7 +948,7 @@ int cmd_pull(int argc, const char **argv
 		oidclr(&curr_head);
 
 	if (!is_null_oid(&orig_head) && !is_null_oid(&curr_head) &&
-			oidcmp(&orig_head, &curr_head)) {
+			!oideq(&orig_head, &curr_head)) {
 		/*
 		 * The fetch involved updating the current branch.
 		 *
@@ -912,7 +961,8 @@ int cmd_pull(int argc, const char **argv
 			"fast-forwarding your working tree from\n"
 			"commit %s."), oid_to_hex(&orig_head));
 
-		if (checkout_fast_forward(&orig_head, &curr_head, 0))
+		if (checkout_fast_forward(the_repository, &orig_head,
+					  &curr_head, 0))
 			die(_("Cannot fast-forward your working tree.\n"
 				"After making sure that you saved anything precious from\n"
 				"$ git diff %s\n"
@@ -938,15 +988,17 @@ int cmd_pull(int argc, const char **argv
 		int ret = 0;
 		if ((recurse_submodules == RECURSE_SUBMODULES_ON ||
 		     recurse_submodules == RECURSE_SUBMODULES_ON_DEMAND) &&
-		    submodule_touches_in_range(&rebase_fork_point, &curr_head))
+		    submodule_touches_in_range(the_repository, &rebase_fork_point, &curr_head))
 			die(_("cannot rebase with locally recorded submodule modifications"));
 		if (!autostash) {
 			struct commit_list *list = NULL;
 			struct commit *merge_head, *head;
 
-			head = lookup_commit_reference(&orig_head);
+			head = lookup_commit_reference(the_repository,
+						       &orig_head);
 			commit_list_insert(head, &list);
-			merge_head = lookup_commit_reference(&merge_heads.oid[0]);
+			merge_head = lookup_commit_reference(the_repository,
+							     &merge_heads.oid[0]);
 			if (is_descendant_of(merge_head, list)) {
 				/* we can fast-forward this without invoking rebase */
 				opt_ff = "--ff-only";
diff -pruN 1.2.1+git2.18.0-1/git/builtin/push.c 1.2.3+git2.25.1-1/git/builtin/push.c
--- 1.2.1+git2.18.0-1/git/builtin/push.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/builtin/push.c	2020-02-17 04:47:35.000000000 +0000
@@ -64,6 +64,7 @@ static struct string_list push_options_c
 static const char *map_refspec(const char *ref,
 			       struct remote *remote, struct ref *local_refs)
 {
+	const char *branch_name;
 	struct ref *matched = NULL;
 
 	/* Does "ref" uniquely name our ref? */
@@ -84,8 +85,8 @@ static const char *map_refspec(const cha
 	}
 
 	if (push_default == PUSH_DEFAULT_UPSTREAM &&
-	    starts_with(matched->name, "refs/heads/")) {
-		struct branch *branch = branch_get(matched->name + 11);
+	    skip_prefix(matched->name, "refs/heads/", &branch_name)) {
+		struct branch *branch = branch_get(branch_name);
 		if (branch->merge_nr == 1 && branch->merge[0]->src) {
 			struct strbuf buf = STRBUF_INIT;
 			strbuf_addf(&buf, "%s:%s",
@@ -143,7 +144,9 @@ static int push_url_of_remote(struct rem
 	return remote->url_nr;
 }
 
-static NORETURN int die_push_simple(struct branch *branch, struct remote *remote) {
+static NORETURN void die_push_simple(struct branch *branch,
+				     struct remote *remote)
+{
 	/*
 	 * There's no point in using shorten_unambiguous_ref here,
 	 * as the ambiguity would be on the remote side, not what
@@ -173,10 +176,10 @@ static NORETURN int die_push_simple(stru
 	      "\n"
 	      "To push to the branch of the same name on the remote, use\n"
 	      "\n"
-	      "    git push %s %s\n"
+	      "    git push %s HEAD\n"
 	      "%s"),
 	    remote->name, short_upstream,
-	    remote->name, branch->name, advice_maybe);
+	    remote->name, advice_maybe);
 }
 
 static const char message_detached_head_die[] =
@@ -355,7 +358,10 @@ static int push_with_options(struct tran
 
 	if (verbosity > 0)
 		fprintf(stderr, _("Pushing to %s\n"), transport->url);
-	err = transport_push(transport, rs, flags, &reject_reasons);
+	trace2_region_enter("push", "transport_push", the_repository);
+	err = transport_push(the_repository, transport,
+			     rs, flags, &reject_reasons);
+	trace2_region_leave("push", "transport_push", the_repository);
 	if (err != 0) {
 		fprintf(stderr, "%s", push_get_color(PUSH_COLOR_ERROR));
 		error(_("failed to push some refs to '%s'"), transport->url);
@@ -382,30 +388,14 @@ static int push_with_options(struct tran
 }
 
 static int do_push(const char *repo, int flags,
-		   const struct string_list *push_options)
+		   const struct string_list *push_options,
+		   struct remote *remote)
 {
 	int i, errs;
-	struct remote *remote = pushremote_get(repo);
 	const char **url;
 	int url_nr;
 	struct refspec *push_refspec = &rs;
 
-	if (!remote) {
-		if (repo)
-			die(_("bad repository '%s'"), repo);
-		die(_("No configured push destination.\n"
-		    "Either specify the URL from the command-line or configure a remote repository using\n"
-		    "\n"
-		    "    git remote add <name> <url>\n"
-		    "\n"
-		    "and then push using the remote name\n"
-		    "\n"
-		    "    git push <name>\n"));
-	}
-
-	if (remote->mirror)
-		flags |= (TRANSPORT_PUSH_MIRROR|TRANSPORT_PUSH_FORCE);
-
 	if (push_options->nr)
 		flags |= TRANSPORT_PUSH_OPTIONS;
 
@@ -545,6 +535,7 @@ int cmd_push(int argc, const char **argv
 	struct string_list push_options_cmdline = STRING_LIST_INIT_DUP;
 	struct string_list *push_options;
 	const struct string_list_item *item;
+	struct remote *remote;
 
 	struct option options[] = {
 		OPT__VERBOSITY(&verbosity),
@@ -558,10 +549,10 @@ int cmd_push(int argc, const char **argv
 		OPT_BIT( 0,  "porcelain", &flags, N_("machine-readable output"), TRANSPORT_PUSH_PORCELAIN),
 		OPT_BIT('f', "force", &flags, N_("force updates"), TRANSPORT_PUSH_FORCE),
 		{ OPTION_CALLBACK,
-		  0, CAS_OPT_NAME, &cas, N_("refname>:<expect"),
+		  0, CAS_OPT_NAME, &cas, N_("<refname>:<expect>"),
 		  N_("require old value of ref to be at this value"),
-		  PARSE_OPT_OPTARG, parseopt_push_cas_option },
-		{ OPTION_CALLBACK, 0, "recurse-submodules", &recurse_submodules, "check|on-demand|no",
+		  PARSE_OPT_OPTARG | PARSE_OPT_LITERAL_ARGHELP, parseopt_push_cas_option },
+		{ OPTION_CALLBACK, 0, "recurse-submodules", &recurse_submodules, "(check|on-demand|no)",
 			N_("control recursive pushing of submodules"),
 			PARSE_OPT_OPTARG, option_parse_recurse_submodules },
 		OPT_BOOL_F( 0 , "thin", &thin, N_("use thin pack"), PARSE_OPT_NOCOMPLETE),
@@ -576,7 +567,7 @@ int cmd_push(int argc, const char **argv
 		OPT_BIT(0, "follow-tags", &flags, N_("push missing but relevant tags"),
 			TRANSPORT_PUSH_FOLLOW_TAGS),
 		{ OPTION_CALLBACK,
-		  0, "signed", &push_cert, "yes|no|if-asked", N_("GPG sign the push"),
+		  0, "signed", &push_cert, "(yes|no|if-asked)", N_("GPG sign the push"),
 		  PARSE_OPT_OPTARG, option_parse_push_signed },
 		OPT_BIT(0, "atomic", &flags, N_("request atomic transaction on remote side"), TRANSPORT_PUSH_ATOMIC),
 		OPT_STRING_LIST('o', "push-option", &push_options_cmdline, N_("server-specific"), N_("option to transmit")),
@@ -599,20 +590,6 @@ int cmd_push(int argc, const char **argv
 		die(_("--delete is incompatible with --all, --mirror and --tags"));
 	if (deleterefs && argc < 2)
 		die(_("--delete doesn't make sense without any refs"));
-	if (flags & TRANSPORT_PUSH_ALL) {
-		if (tags)
-			die(_("--all and --tags are incompatible"));
-		if (argc >= 2)
-			die(_("--all can't be combined with refspecs"));
-	}
-	if (flags & TRANSPORT_PUSH_MIRROR) {
-		if (tags)
-			die(_("--mirror and --tags are incompatible"));
-		if (argc >= 2)
-			die(_("--mirror can't be combined with refspecs"));
-	}
-	if ((flags & TRANSPORT_PUSH_ALL) && (flags & TRANSPORT_PUSH_MIRROR))
-		die(_("--all and --mirror are incompatible"));
 
 	if (recurse_submodules == RECURSE_SUBMODULES_CHECK)
 		flags |= TRANSPORT_RECURSE_SUBMODULES_CHECK;
@@ -629,11 +606,43 @@ int cmd_push(int argc, const char **argv
 		set_refspecs(argv + 1, argc - 1, repo);
 	}
 
+	remote = pushremote_get(repo);
+	if (!remote) {
+		if (repo)
+			die(_("bad repository '%s'"), repo);
+		die(_("No configured push destination.\n"
+		    "Either specify the URL from the command-line or configure a remote repository using\n"
+		    "\n"
+		    "    git remote add <name> <url>\n"
+		    "\n"
+		    "and then push using the remote name\n"
+		    "\n"
+		    "    git push <name>\n"));
+	}
+
+	if (remote->mirror)
+		flags |= (TRANSPORT_PUSH_MIRROR|TRANSPORT_PUSH_FORCE);
+
+	if (flags & TRANSPORT_PUSH_ALL) {
+		if (tags)
+			die(_("--all and --tags are incompatible"));
+		if (argc >= 2)
+			die(_("--all can't be combined with refspecs"));
+	}
+	if (flags & TRANSPORT_PUSH_MIRROR) {
+		if (tags)
+			die(_("--mirror and --tags are incompatible"));
+		if (argc >= 2)
+			die(_("--mirror can't be combined with refspecs"));
+	}
+	if ((flags & TRANSPORT_PUSH_ALL) && (flags & TRANSPORT_PUSH_MIRROR))
+		die(_("--all and --mirror are incompatible"));
+
 	for_each_string_list_item(item, push_options)
 		if (strchr(item->string, '\n'))
 			die(_("push options must not have new line characters"));
 
-	rc = do_push(repo, flags, push_options);
+	rc = do_push(repo, flags, push_options, remote);
 	string_list_clear(&push_options_cmdline, 0);
 	string_list_clear(&push_options_config, 0);
 	if (rc == -1)
diff -pruN 1.2.1+git2.18.0-1/git/builtin/range-diff.c 1.2.3+git2.25.1-1/git/builtin/range-diff.c
--- 1.2.1+git2.18.0-1/git/builtin/range-diff.c	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/builtin/range-diff.c	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,92 @@
+#include "cache.h"
+#include "builtin.h"
+#include "parse-options.h"
+#include "range-diff.h"
+#include "config.h"
+
+static const char * const builtin_range_diff_usage[] = {
+N_("git range-diff [<options>] <old-base>..<old-tip> <new-base>..<new-tip>"),
+N_("git range-diff [<options>] <old-tip>...<new-tip>"),
+N_("git range-diff [<options>] <base> <old-tip> <new-tip>"),
+NULL
+};
+
+int cmd_range_diff(int argc, const char **argv, const char *prefix)
+{
+	int creation_factor = RANGE_DIFF_CREATION_FACTOR_DEFAULT;
+	struct diff_options diffopt = { NULL };
+	struct argv_array other_arg = ARGV_ARRAY_INIT;
+	int simple_color = -1;
+	struct option range_diff_options[] = {
+		OPT_INTEGER(0, "creation-factor", &creation_factor,
+			    N_("Percentage by which creation is weighted")),
+		OPT_BOOL(0, "no-dual-color", &simple_color,
+			    N_("use simple diff colors")),
+		OPT_PASSTHRU_ARGV(0, "notes", &other_arg,
+				  N_("notes"), N_("passed to 'git log'"),
+				  PARSE_OPT_OPTARG),
+		OPT_END()
+	};
+	struct option *options;
+	int res = 0;
+	struct strbuf range1 = STRBUF_INIT, range2 = STRBUF_INIT;
+
+	git_config(git_diff_ui_config, NULL);
+
+	repo_diff_setup(the_repository, &diffopt);
+
+	options = parse_options_concat(range_diff_options, diffopt.parseopts);
+	argc = parse_options(argc, argv, prefix, options,
+			     builtin_range_diff_usage, 0);
+
+	diff_setup_done(&diffopt);
+
+	/* force color when --dual-color was used */
+	if (!simple_color)
+		diffopt.use_color = 1;
+
+	if (argc == 2) {
+		if (!strstr(argv[0], ".."))
+			die(_("no .. in range: '%s'"), argv[0]);
+		strbuf_addstr(&range1, argv[0]);
+
+		if (!strstr(argv[1], ".."))
+			die(_("no .. in range: '%s'"), argv[1]);
+		strbuf_addstr(&range2, argv[1]);
+	} else if (argc == 3) {
+		strbuf_addf(&range1, "%s..%s", argv[0], argv[1]);
+		strbuf_addf(&range2, "%s..%s", argv[0], argv[2]);
+	} else if (argc == 1) {
+		const char *b = strstr(argv[0], "..."), *a = argv[0];
+		int a_len;
+
+		if (!b) {
+			error(_("single arg format must be symmetric range"));
+			usage_with_options(builtin_range_diff_usage, options);
+		}
+
+		a_len = (int)(b - a);
+		if (!a_len) {
+			a = "HEAD";
+			a_len = strlen(a);
+		}
+		b += 3;
+		if (!*b)
+			b = "HEAD";
+		strbuf_addf(&range1, "%s..%.*s", b, a_len, a);
+		strbuf_addf(&range2, "%.*s..%s", a_len, a, b);
+	} else {
+		error(_("need two commit ranges"));
+		usage_with_options(builtin_range_diff_usage, options);
+	}
+	FREE_AND_NULL(options);
+
+	res = show_range_diff(range1.buf, range2.buf, creation_factor,
+			      simple_color < 1, &diffopt, &other_arg);
+
+	argv_array_clear(&other_arg);
+	strbuf_release(&range1);
+	strbuf_release(&range2);
+
+	return res;
+}
diff -pruN 1.2.1+git2.18.0-1/git/builtin/read-tree.c 1.2.3+git2.25.1-1/git/builtin/read-tree.c
--- 1.2.1+git2.18.0-1/git/builtin/read-tree.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/builtin/read-tree.c	2020-02-17 04:47:35.000000000 +0000
@@ -4,6 +4,7 @@
  * Copyright (C) Linus Torvalds, 2005
  */
 
+#define USE_THE_INDEX_COMPATIBILITY_MACROS
 #include "cache.h"
 #include "config.h"
 #include "lockfile.h"
@@ -44,6 +45,7 @@ static const char * const read_tree_usag
 static int index_output_cb(const struct option *opt, const char *arg,
 				 int unset)
 {
+	BUG_ON_OPT_NEG(unset);
 	set_alternate_index_output(arg);
 	return 0;
 }
@@ -54,6 +56,8 @@ static int exclude_per_directory_cb(cons
 	struct dir_struct *dir;
 	struct unpack_trees_options *opts;
 
+	BUG_ON_OPT_NEG(unset);
+
 	opts = (struct unpack_trees_options *)opt->value;
 
 	if (opts->dir)
@@ -107,7 +111,7 @@ static int git_read_tree_config(const ch
 	return git_default_config(var, value, cb);
 }
 
-int cmd_read_tree(int argc, const char **argv, const char *unused_prefix)
+int cmd_read_tree(int argc, const char **argv, const char *cmd_prefix)
 {
 	int i, stage = 0;
 	struct object_id oid;
@@ -133,7 +137,7 @@ int cmd_read_tree(int argc, const char *
 			 N_("same as -m, but discard unmerged entries")),
 		{ OPTION_STRING, 0, "prefix", &opts.prefix, N_("<subdirectory>/"),
 		  N_("read the tree into the index under <subdirectory>/"),
-		  PARSE_OPT_NONEG | PARSE_OPT_LITERAL_ARGHELP },
+		  PARSE_OPT_NONEG },
 		OPT_BOOL('u', NULL, &opts.update,
 			 N_("update working tree with merge result")),
 		{ OPTION_CALLBACK, 0, "exclude-per-directory", &opts,
@@ -150,6 +154,7 @@ int cmd_read_tree(int argc, const char *
 		{ OPTION_CALLBACK, 0, "recurse-submodules", NULL,
 			    "checkout", "control recursive updating of submodules",
 			    PARSE_OPT_OPTARG, option_parse_recurse_submodules_worktree_updater },
+		OPT__QUIET(&opts.quiet, N_("suppress feedback messages")),
 		OPT_END()
 	};
 
@@ -160,7 +165,7 @@ int cmd_read_tree(int argc, const char *
 
 	git_config(git_read_tree_config, NULL);
 
-	argc = parse_options(argc, argv, unused_prefix, read_tree_options,
+	argc = parse_options(argc, argv, cmd_prefix, read_tree_options,
 			     read_tree_usage, 0);
 
 	hold_locked_index(&lock_file, LOCK_DIE_ON_ERROR);
@@ -180,7 +185,7 @@ int cmd_read_tree(int argc, const char *
 
 	if (opts.reset || opts.merge || opts.prefix) {
 		if (read_cache_unmerged() && (opts.prefix || opts.merge))
-			die("You need to resolve your current index first");
+			die(_("You need to resolve your current index first"));
 		stage = opts.merge = 1;
 	}
 	resolve_undo_clear();
@@ -255,7 +260,9 @@ int cmd_read_tree(int argc, const char *
 	 * what came from the tree.
 	 */
 	if (nr_trees == 1 && !opts.prefix)
-		prime_cache_tree(&the_index, trees[0]);
+		prime_cache_tree(the_repository,
+				 the_repository->index,
+				 trees[0]);
 
 	if (write_locked_index(&the_index, &lock_file, COMMIT_LOCK))
 		die("unable to write new index file");
diff -pruN 1.2.1+git2.18.0-1/git/builtin/rebase.c 1.2.3+git2.25.1-1/git/builtin/rebase.c
--- 1.2.1+git2.18.0-1/git/builtin/rebase.c	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/builtin/rebase.c	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,2199 @@
+/*
+ * "git rebase" builtin command
+ *
+ * Copyright (c) 2018 Pratik Karki
+ */
+
+#define USE_THE_INDEX_COMPATIBILITY_MACROS
+#include "builtin.h"
+#include "run-command.h"
+#include "exec-cmd.h"
+#include "argv-array.h"
+#include "dir.h"
+#include "packfile.h"
+#include "refs.h"
+#include "quote.h"
+#include "config.h"
+#include "cache-tree.h"
+#include "unpack-trees.h"
+#include "lockfile.h"
+#include "parse-options.h"
+#include "commit.h"
+#include "diff.h"
+#include "wt-status.h"
+#include "revision.h"
+#include "commit-reach.h"
+#include "rerere.h"
+#include "branch.h"
+#include "sequencer.h"
+#include "rebase-interactive.h"
+
+static char const * const builtin_rebase_usage[] = {
+	N_("git rebase [-i] [options] [--exec <cmd>] "
+		"[--onto <newbase> | --keep-base] [<upstream> [<branch>]]"),
+	N_("git rebase [-i] [options] [--exec <cmd>] [--onto <newbase>] "
+		"--root [<branch>]"),
+	N_("git rebase --continue | --abort | --skip | --edit-todo"),
+	NULL
+};
+
+static GIT_PATH_FUNC(path_squash_onto, "rebase-merge/squash-onto")
+static GIT_PATH_FUNC(path_interactive, "rebase-merge/interactive")
+static GIT_PATH_FUNC(apply_dir, "rebase-apply")
+static GIT_PATH_FUNC(merge_dir, "rebase-merge")
+
+enum rebase_type {
+	REBASE_UNSPECIFIED = -1,
+	REBASE_AM,
+	REBASE_MERGE,
+	REBASE_INTERACTIVE,
+	REBASE_PRESERVE_MERGES
+};
+
+struct rebase_options {
+	enum rebase_type type;
+	const char *state_dir;
+	struct commit *upstream;
+	const char *upstream_name;
+	const char *upstream_arg;
+	char *head_name;
+	struct object_id orig_head;
+	struct commit *onto;
+	const char *onto_name;
+	const char *revisions;
+	const char *switch_to;
+	int root, root_with_onto;
+	struct object_id *squash_onto;
+	struct commit *restrict_revision;
+	int dont_finish_rebase;
+	enum {
+		REBASE_NO_QUIET = 1<<0,
+		REBASE_VERBOSE = 1<<1,
+		REBASE_DIFFSTAT = 1<<2,
+		REBASE_FORCE = 1<<3,
+		REBASE_INTERACTIVE_EXPLICIT = 1<<4,
+	} flags;
+	struct argv_array git_am_opts;
+	const char *action;
+	int signoff;
+	int allow_rerere_autoupdate;
+	int keep_empty;
+	int autosquash;
+	char *gpg_sign_opt;
+	int autostash;
+	char *cmd;
+	int allow_empty_message;
+	int rebase_merges, rebase_cousins;
+	char *strategy, *strategy_opts;
+	struct strbuf git_format_patch_opt;
+	int reschedule_failed_exec;
+	int use_legacy_rebase;
+};
+
+#define REBASE_OPTIONS_INIT {			  	\
+		.type = REBASE_UNSPECIFIED,	  	\
+		.flags = REBASE_NO_QUIET, 		\
+		.git_am_opts = ARGV_ARRAY_INIT,		\
+		.git_format_patch_opt = STRBUF_INIT	\
+	}
+
+static struct replay_opts get_replay_opts(const struct rebase_options *opts)
+{
+	struct replay_opts replay = REPLAY_OPTS_INIT;
+
+	replay.action = REPLAY_INTERACTIVE_REBASE;
+	sequencer_init_config(&replay);
+
+	replay.signoff = opts->signoff;
+	replay.allow_ff = !(opts->flags & REBASE_FORCE);
+	if (opts->allow_rerere_autoupdate)
+		replay.allow_rerere_auto = opts->allow_rerere_autoupdate;
+	replay.allow_empty = 1;
+	replay.allow_empty_message = opts->allow_empty_message;
+	replay.verbose = opts->flags & REBASE_VERBOSE;
+	replay.reschedule_failed_exec = opts->reschedule_failed_exec;
+	replay.gpg_sign = xstrdup_or_null(opts->gpg_sign_opt);
+	replay.strategy = opts->strategy;
+	if (opts->strategy_opts)
+		parse_strategy_opts(&replay, opts->strategy_opts);
+
+	if (opts->squash_onto) {
+		oidcpy(&replay.squash_onto, opts->squash_onto);
+		replay.have_squash_onto = 1;
+	}
+
+	return replay;
+}
+
+enum action {
+	ACTION_NONE = 0,
+	ACTION_CONTINUE,
+	ACTION_SKIP,
+	ACTION_ABORT,
+	ACTION_QUIT,
+	ACTION_EDIT_TODO,
+	ACTION_SHOW_CURRENT_PATCH,
+	ACTION_SHORTEN_OIDS,
+	ACTION_EXPAND_OIDS,
+	ACTION_CHECK_TODO_LIST,
+	ACTION_REARRANGE_SQUASH,
+	ACTION_ADD_EXEC
+};
+
+static const char *action_names[] = { "undefined",
+				      "continue",
+				      "skip",
+				      "abort",
+				      "quit",
+				      "edit_todo",
+				      "show_current_patch" };
+
+static int add_exec_commands(struct string_list *commands)
+{
+	const char *todo_file = rebase_path_todo();
+	struct todo_list todo_list = TODO_LIST_INIT;
+	int res;
+
+	if (strbuf_read_file(&todo_list.buf, todo_file, 0) < 0)
+		return error_errno(_("could not read '%s'."), todo_file);
+
+	if (todo_list_parse_insn_buffer(the_repository, todo_list.buf.buf,
+					&todo_list)) {
+		todo_list_release(&todo_list);
+		return error(_("unusable todo list: '%s'"), todo_file);
+	}
+
+	todo_list_add_exec_commands(&todo_list, commands);
+	res = todo_list_write_to_file(the_repository, &todo_list,
+				      todo_file, NULL, NULL, -1, 0);
+	todo_list_release(&todo_list);
+
+	if (res)
+		return error_errno(_("could not write '%s'."), todo_file);
+	return 0;
+}
+
+static int rearrange_squash_in_todo_file(void)
+{
+	const char *todo_file = rebase_path_todo();
+	struct todo_list todo_list = TODO_LIST_INIT;
+	int res = 0;
+
+	if (strbuf_read_file(&todo_list.buf, todo_file, 0) < 0)
+		return error_errno(_("could not read '%s'."), todo_file);
+	if (todo_list_parse_insn_buffer(the_repository, todo_list.buf.buf,
+					&todo_list)) {
+		todo_list_release(&todo_list);
+		return error(_("unusable todo list: '%s'"), todo_file);
+	}
+
+	res = todo_list_rearrange_squash(&todo_list);
+	if (!res)
+		res = todo_list_write_to_file(the_repository, &todo_list,
+					      todo_file, NULL, NULL, -1, 0);
+
+	todo_list_release(&todo_list);
+
+	if (res)
+		return error_errno(_("could not write '%s'."), todo_file);
+	return 0;
+}
+
+static int transform_todo_file(unsigned flags)
+{
+	const char *todo_file = rebase_path_todo();
+	struct todo_list todo_list = TODO_LIST_INIT;
+	int res;
+
+	if (strbuf_read_file(&todo_list.buf, todo_file, 0) < 0)
+		return error_errno(_("could not read '%s'."), todo_file);
+
+	if (todo_list_parse_insn_buffer(the_repository, todo_list.buf.buf,
+					&todo_list)) {
+		todo_list_release(&todo_list);
+		return error(_("unusable todo list: '%s'"), todo_file);
+	}
+
+	res = todo_list_write_to_file(the_repository, &todo_list, todo_file,
+				      NULL, NULL, -1, flags);
+	todo_list_release(&todo_list);
+
+	if (res)
+		return error_errno(_("could not write '%s'."), todo_file);
+	return 0;
+}
+
+static int edit_todo_file(unsigned flags)
+{
+	const char *todo_file = rebase_path_todo();
+	struct todo_list todo_list = TODO_LIST_INIT,
+		new_todo = TODO_LIST_INIT;
+	int res = 0;
+
+	if (strbuf_read_file(&todo_list.buf, todo_file, 0) < 0)
+		return error_errno(_("could not read '%s'."), todo_file);
+
+	strbuf_stripspace(&todo_list.buf, 1);
+	res = edit_todo_list(the_repository, &todo_list, &new_todo, NULL, NULL, flags);
+	if (!res && todo_list_write_to_file(the_repository, &new_todo, todo_file,
+					    NULL, NULL, -1, flags & ~(TODO_LIST_SHORTEN_IDS)))
+		res = error_errno(_("could not write '%s'"), todo_file);
+
+	todo_list_release(&todo_list);
+	todo_list_release(&new_todo);
+
+	return res;
+}
+
+static int get_revision_ranges(struct commit *upstream, struct commit *onto,
+			       const char **head_hash,
+			       char **revisions, char **shortrevisions)
+{
+	struct commit *base_rev = upstream ? upstream : onto;
+	const char *shorthead;
+	struct object_id orig_head;
+
+	if (get_oid("HEAD", &orig_head))
+		return error(_("no HEAD?"));
+
+	*head_hash = find_unique_abbrev(&orig_head, GIT_MAX_HEXSZ);
+	*revisions = xstrfmt("%s...%s", oid_to_hex(&base_rev->object.oid),
+						   *head_hash);
+
+	shorthead = find_unique_abbrev(&orig_head, DEFAULT_ABBREV);
+
+	if (upstream) {
+		const char *shortrev;
+
+		shortrev = find_unique_abbrev(&base_rev->object.oid,
+					      DEFAULT_ABBREV);
+
+		*shortrevisions = xstrfmt("%s..%s", shortrev, shorthead);
+	} else
+		*shortrevisions = xstrdup(shorthead);
+
+	return 0;
+}
+
+static int init_basic_state(struct replay_opts *opts, const char *head_name,
+			    struct commit *onto, const char *orig_head)
+{
+	FILE *interactive;
+
+	if (!is_directory(merge_dir()) && mkdir_in_gitdir(merge_dir()))
+		return error_errno(_("could not create temporary %s"), merge_dir());
+
+	delete_reflog("REBASE_HEAD");
+
+	interactive = fopen(path_interactive(), "w");
+	if (!interactive)
+		return error_errno(_("could not mark as interactive"));
+	fclose(interactive);
+
+	return write_basic_state(opts, head_name, onto, orig_head);
+}
+
+static void split_exec_commands(const char *cmd, struct string_list *commands)
+{
+	if (cmd && *cmd) {
+		string_list_split(commands, cmd, '\n', -1);
+
+		/* rebase.c adds a new line to cmd after every command,
+		 * so here the last command is always empty */
+		string_list_remove_empty_items(commands, 0);
+	}
+}
+
+static int do_interactive_rebase(struct rebase_options *opts, unsigned flags)
+{
+	int ret;
+	const char *head_hash = NULL;
+	char *revisions = NULL, *shortrevisions = NULL;
+	struct argv_array make_script_args = ARGV_ARRAY_INIT;
+	struct todo_list todo_list = TODO_LIST_INIT;
+	struct replay_opts replay = get_replay_opts(opts);
+	struct string_list commands = STRING_LIST_INIT_DUP;
+
+	if (prepare_branch_to_be_rebased(the_repository, &replay,
+					 opts->switch_to))
+		return -1;
+
+	if (get_revision_ranges(opts->upstream, opts->onto, &head_hash,
+				&revisions, &shortrevisions))
+		return -1;
+
+	if (init_basic_state(&replay,
+			     opts->head_name ? opts->head_name : "detached HEAD",
+			     opts->onto, head_hash)) {
+		free(revisions);
+		free(shortrevisions);
+
+		return -1;
+	}
+
+	if (!opts->upstream && opts->squash_onto)
+		write_file(path_squash_onto(), "%s\n",
+			   oid_to_hex(opts->squash_onto));
+
+	argv_array_pushl(&make_script_args, "", revisions, NULL);
+	if (opts->restrict_revision)
+		argv_array_push(&make_script_args,
+				oid_to_hex(&opts->restrict_revision->object.oid));
+
+	ret = sequencer_make_script(the_repository, &todo_list.buf,
+				    make_script_args.argc, make_script_args.argv,
+				    flags);
+
+	if (ret)
+		error(_("could not generate todo list"));
+	else {
+		discard_cache();
+		if (todo_list_parse_insn_buffer(the_repository, todo_list.buf.buf,
+						&todo_list))
+			BUG("unusable todo list");
+
+		split_exec_commands(opts->cmd, &commands);
+		ret = complete_action(the_repository, &replay, flags,
+			shortrevisions, opts->onto_name, opts->onto, head_hash,
+			&commands, opts->autosquash, &todo_list);
+	}
+
+	string_list_clear(&commands, 0);
+	free(revisions);
+	free(shortrevisions);
+	todo_list_release(&todo_list);
+	argv_array_clear(&make_script_args);
+
+	return ret;
+}
+
+static int run_rebase_interactive(struct rebase_options *opts,
+				  enum action command)
+{
+	unsigned flags = 0;
+	int abbreviate_commands = 0, ret = 0;
+
+	git_config_get_bool("rebase.abbreviatecommands", &abbreviate_commands);
+
+	flags |= opts->keep_empty ? TODO_LIST_KEEP_EMPTY : 0;
+	flags |= abbreviate_commands ? TODO_LIST_ABBREVIATE_CMDS : 0;
+	flags |= opts->rebase_merges ? TODO_LIST_REBASE_MERGES : 0;
+	flags |= opts->rebase_cousins > 0 ? TODO_LIST_REBASE_COUSINS : 0;
+	flags |= opts->root_with_onto ? TODO_LIST_ROOT_WITH_ONTO : 0;
+	flags |= command == ACTION_SHORTEN_OIDS ? TODO_LIST_SHORTEN_IDS : 0;
+
+	switch (command) {
+	case ACTION_NONE: {
+		if (!opts->onto && !opts->upstream)
+			die(_("a base commit must be provided with --upstream or --onto"));
+
+		ret = do_interactive_rebase(opts, flags);
+		break;
+	}
+	case ACTION_SKIP: {
+		struct string_list merge_rr = STRING_LIST_INIT_DUP;
+
+		rerere_clear(the_repository, &merge_rr);
+	}
+		/* fallthrough */
+	case ACTION_CONTINUE: {
+		struct replay_opts replay_opts = get_replay_opts(opts);
+
+		ret = sequencer_continue(the_repository, &replay_opts);
+		break;
+	}
+	case ACTION_EDIT_TODO:
+		ret = edit_todo_file(flags);
+		break;
+	case ACTION_SHOW_CURRENT_PATCH: {
+		struct child_process cmd = CHILD_PROCESS_INIT;
+
+		cmd.git_cmd = 1;
+		argv_array_pushl(&cmd.args, "show", "REBASE_HEAD", "--", NULL);
+		ret = run_command(&cmd);
+
+		break;
+	}
+	case ACTION_SHORTEN_OIDS:
+	case ACTION_EXPAND_OIDS:
+		ret = transform_todo_file(flags);
+		break;
+	case ACTION_CHECK_TODO_LIST:
+		ret = check_todo_list_from_file(the_repository);
+		break;
+	case ACTION_REARRANGE_SQUASH:
+		ret = rearrange_squash_in_todo_file();
+		break;
+	case ACTION_ADD_EXEC: {
+		struct string_list commands = STRING_LIST_INIT_DUP;
+
+		split_exec_commands(opts->cmd, &commands);
+		ret = add_exec_commands(&commands);
+		string_list_clear(&commands, 0);
+		break;
+	}
+	default:
+		BUG("invalid command '%d'", command);
+	}
+
+	return ret;
+}
+
+static const char * const builtin_rebase_interactive_usage[] = {
+	N_("git rebase--interactive [<options>]"),
+	NULL
+};
+
+int cmd_rebase__interactive(int argc, const char **argv, const char *prefix)
+{
+	struct rebase_options opts = REBASE_OPTIONS_INIT;
+	struct object_id squash_onto = null_oid;
+	enum action command = ACTION_NONE;
+	struct option options[] = {
+		OPT_NEGBIT(0, "ff", &opts.flags, N_("allow fast-forward"),
+			   REBASE_FORCE),
+		OPT_BOOL(0, "keep-empty", &opts.keep_empty, N_("keep empty commits")),
+		OPT_BOOL(0, "allow-empty-message", &opts.allow_empty_message,
+			 N_("allow commits with empty messages")),
+		OPT_BOOL(0, "rebase-merges", &opts.rebase_merges, N_("rebase merge commits")),
+		OPT_BOOL(0, "rebase-cousins", &opts.rebase_cousins,
+			 N_("keep original branch points of cousins")),
+		OPT_BOOL(0, "autosquash", &opts.autosquash,
+			 N_("move commits that begin with squash!/fixup!")),
+		OPT_BOOL(0, "signoff", &opts.signoff, N_("sign commits")),
+		OPT_BIT('v', "verbose", &opts.flags,
+			N_("display a diffstat of what changed upstream"),
+			REBASE_NO_QUIET | REBASE_VERBOSE | REBASE_DIFFSTAT),
+		OPT_CMDMODE(0, "continue", &command, N_("continue rebase"),
+			    ACTION_CONTINUE),
+		OPT_CMDMODE(0, "skip", &command, N_("skip commit"), ACTION_SKIP),
+		OPT_CMDMODE(0, "edit-todo", &command, N_("edit the todo list"),
+			    ACTION_EDIT_TODO),
+		OPT_CMDMODE(0, "show-current-patch", &command, N_("show the current patch"),
+			    ACTION_SHOW_CURRENT_PATCH),
+		OPT_CMDMODE(0, "shorten-ids", &command,
+			N_("shorten commit ids in the todo list"), ACTION_SHORTEN_OIDS),
+		OPT_CMDMODE(0, "expand-ids", &command,
+			N_("expand commit ids in the todo list"), ACTION_EXPAND_OIDS),
+		OPT_CMDMODE(0, "check-todo-list", &command,
+			N_("check the todo list"), ACTION_CHECK_TODO_LIST),
+		OPT_CMDMODE(0, "rearrange-squash", &command,
+			N_("rearrange fixup/squash lines"), ACTION_REARRANGE_SQUASH),
+		OPT_CMDMODE(0, "add-exec-commands", &command,
+			N_("insert exec commands in todo list"), ACTION_ADD_EXEC),
+		{ OPTION_CALLBACK, 0, "onto", &opts.onto, N_("onto"), N_("onto"),
+		  PARSE_OPT_NONEG, parse_opt_commit, 0 },
+		{ OPTION_CALLBACK, 0, "restrict-revision", &opts.restrict_revision,
+		  N_("restrict-revision"), N_("restrict revision"),
+		  PARSE_OPT_NONEG, parse_opt_commit, 0 },
+		{ OPTION_CALLBACK, 0, "squash-onto", &squash_onto, N_("squash-onto"),
+		  N_("squash onto"), PARSE_OPT_NONEG, parse_opt_object_id, 0 },
+		{ OPTION_CALLBACK, 0, "upstream", &opts.upstream, N_("upstream"),
+		  N_("the upstream commit"), PARSE_OPT_NONEG, parse_opt_commit,
+		  0 },
+		OPT_STRING(0, "head-name", &opts.head_name, N_("head-name"), N_("head name")),
+		{ OPTION_STRING, 'S', "gpg-sign", &opts.gpg_sign_opt, N_("key-id"),
+			N_("GPG-sign commits"),
+			PARSE_OPT_OPTARG, NULL, (intptr_t) "" },
+		OPT_STRING(0, "strategy", &opts.strategy, N_("strategy"),
+			   N_("rebase strategy")),
+		OPT_STRING(0, "strategy-opts", &opts.strategy_opts, N_("strategy-opts"),
+			   N_("strategy options")),
+		OPT_STRING(0, "switch-to", &opts.switch_to, N_("switch-to"),
+			   N_("the branch or commit to checkout")),
+		OPT_STRING(0, "onto-name", &opts.onto_name, N_("onto-name"), N_("onto name")),
+		OPT_STRING(0, "cmd", &opts.cmd, N_("cmd"), N_("the command to run")),
+		OPT_RERERE_AUTOUPDATE(&opts.allow_rerere_autoupdate),
+		OPT_BOOL(0, "reschedule-failed-exec", &opts.reschedule_failed_exec,
+			 N_("automatically re-schedule any `exec` that fails")),
+		OPT_END()
+	};
+
+	opts.rebase_cousins = -1;
+
+	if (argc == 1)
+		usage_with_options(builtin_rebase_interactive_usage, options);
+
+	argc = parse_options(argc, argv, prefix, options,
+			builtin_rebase_interactive_usage, PARSE_OPT_KEEP_ARGV0);
+
+	if (!is_null_oid(&squash_onto))
+		opts.squash_onto = &squash_onto;
+
+	if (opts.rebase_cousins >= 0 && !opts.rebase_merges)
+		warning(_("--[no-]rebase-cousins has no effect without "
+			  "--rebase-merges"));
+
+	return !!run_rebase_interactive(&opts, command);
+}
+
+static int is_interactive(struct rebase_options *opts)
+{
+	return opts->type == REBASE_INTERACTIVE ||
+		opts->type == REBASE_PRESERVE_MERGES;
+}
+
+static void imply_interactive(struct rebase_options *opts, const char *option)
+{
+	switch (opts->type) {
+	case REBASE_AM:
+		die(_("%s requires an interactive rebase"), option);
+		break;
+	case REBASE_INTERACTIVE:
+	case REBASE_PRESERVE_MERGES:
+		break;
+	case REBASE_MERGE:
+		/* we now implement --merge via --interactive */
+	default:
+		opts->type = REBASE_INTERACTIVE; /* implied */
+		break;
+	}
+}
+
+/* Returns the filename prefixed by the state_dir */
+static const char *state_dir_path(const char *filename, struct rebase_options *opts)
+{
+	static struct strbuf path = STRBUF_INIT;
+	static size_t prefix_len;
+
+	if (!prefix_len) {
+		strbuf_addf(&path, "%s/", opts->state_dir);
+		prefix_len = path.len;
+	}
+
+	strbuf_setlen(&path, prefix_len);
+	strbuf_addstr(&path, filename);
+	return path.buf;
+}
+
+/* Read one file, then strip line endings */
+static int read_one(const char *path, struct strbuf *buf)
+{
+	if (strbuf_read_file(buf, path, 0) < 0)
+		return error_errno(_("could not read '%s'"), path);
+	strbuf_trim_trailing_newline(buf);
+	return 0;
+}
+
+/* Initialize the rebase options from the state directory. */
+static int read_basic_state(struct rebase_options *opts)
+{
+	struct strbuf head_name = STRBUF_INIT;
+	struct strbuf buf = STRBUF_INIT;
+	struct object_id oid;
+
+	if (read_one(state_dir_path("head-name", opts), &head_name) ||
+	    read_one(state_dir_path("onto", opts), &buf))
+		return -1;
+	opts->head_name = starts_with(head_name.buf, "refs/") ?
+		xstrdup(head_name.buf) : NULL;
+	strbuf_release(&head_name);
+	if (get_oid(buf.buf, &oid))
+		return error(_("could not get 'onto': '%s'"), buf.buf);
+	opts->onto = lookup_commit_or_die(&oid, buf.buf);
+
+	/*
+	 * We always write to orig-head, but interactive rebase used to write to
+	 * head. Fall back to reading from head to cover for the case that the
+	 * user upgraded git with an ongoing interactive rebase.
+	 */
+	strbuf_reset(&buf);
+	if (file_exists(state_dir_path("orig-head", opts))) {
+		if (read_one(state_dir_path("orig-head", opts), &buf))
+			return -1;
+	} else if (read_one(state_dir_path("head", opts), &buf))
+		return -1;
+	if (get_oid(buf.buf, &opts->orig_head))
+		return error(_("invalid orig-head: '%s'"), buf.buf);
+
+	if (file_exists(state_dir_path("quiet", opts)))
+		opts->flags &= ~REBASE_NO_QUIET;
+	else
+		opts->flags |= REBASE_NO_QUIET;
+
+	if (file_exists(state_dir_path("verbose", opts)))
+		opts->flags |= REBASE_VERBOSE;
+
+	if (file_exists(state_dir_path("signoff", opts))) {
+		opts->signoff = 1;
+		opts->flags |= REBASE_FORCE;
+	}
+
+	if (file_exists(state_dir_path("allow_rerere_autoupdate", opts))) {
+		strbuf_reset(&buf);
+		if (read_one(state_dir_path("allow_rerere_autoupdate", opts),
+			    &buf))
+			return -1;
+		if (!strcmp(buf.buf, "--rerere-autoupdate"))
+			opts->allow_rerere_autoupdate = RERERE_AUTOUPDATE;
+		else if (!strcmp(buf.buf, "--no-rerere-autoupdate"))
+			opts->allow_rerere_autoupdate = RERERE_NOAUTOUPDATE;
+		else
+			warning(_("ignoring invalid allow_rerere_autoupdate: "
+				  "'%s'"), buf.buf);
+	}
+
+	if (file_exists(state_dir_path("gpg_sign_opt", opts))) {
+		strbuf_reset(&buf);
+		if (read_one(state_dir_path("gpg_sign_opt", opts),
+			    &buf))
+			return -1;
+		free(opts->gpg_sign_opt);
+		opts->gpg_sign_opt = xstrdup(buf.buf);
+	}
+
+	if (file_exists(state_dir_path("strategy", opts))) {
+		strbuf_reset(&buf);
+		if (read_one(state_dir_path("strategy", opts), &buf))
+			return -1;
+		free(opts->strategy);
+		opts->strategy = xstrdup(buf.buf);
+	}
+
+	if (file_exists(state_dir_path("strategy_opts", opts))) {
+		strbuf_reset(&buf);
+		if (read_one(state_dir_path("strategy_opts", opts), &buf))
+			return -1;
+		free(opts->strategy_opts);
+		opts->strategy_opts = xstrdup(buf.buf);
+	}
+
+	strbuf_release(&buf);
+
+	return 0;
+}
+
+static int rebase_write_basic_state(struct rebase_options *opts)
+{
+	write_file(state_dir_path("head-name", opts), "%s",
+		   opts->head_name ? opts->head_name : "detached HEAD");
+	write_file(state_dir_path("onto", opts), "%s",
+		   opts->onto ? oid_to_hex(&opts->onto->object.oid) : "");
+	write_file(state_dir_path("orig-head", opts), "%s",
+		   oid_to_hex(&opts->orig_head));
+	write_file(state_dir_path("quiet", opts), "%s",
+		   opts->flags & REBASE_NO_QUIET ? "" : "t");
+	if (opts->flags & REBASE_VERBOSE)
+		write_file(state_dir_path("verbose", opts), "%s", "");
+	if (opts->strategy)
+		write_file(state_dir_path("strategy", opts), "%s",
+			   opts->strategy);
+	if (opts->strategy_opts)
+		write_file(state_dir_path("strategy_opts", opts), "%s",
+			   opts->strategy_opts);
+	if (opts->allow_rerere_autoupdate > 0)
+		write_file(state_dir_path("allow_rerere_autoupdate", opts),
+			   "-%s-rerere-autoupdate",
+			   opts->allow_rerere_autoupdate == RERERE_AUTOUPDATE ?
+				"" : "-no");
+	if (opts->gpg_sign_opt)
+		write_file(state_dir_path("gpg_sign_opt", opts), "%s",
+			   opts->gpg_sign_opt);
+	if (opts->signoff)
+		write_file(state_dir_path("signoff", opts), "--signoff");
+
+	return 0;
+}
+
+static int apply_autostash(struct rebase_options *opts)
+{
+	const char *path = state_dir_path("autostash", opts);
+	struct strbuf autostash = STRBUF_INIT;
+	struct child_process stash_apply = CHILD_PROCESS_INIT;
+
+	if (!file_exists(path))
+		return 0;
+
+	if (read_one(path, &autostash))
+		return error(_("Could not read '%s'"), path);
+	/* Ensure that the hash is not mistaken for a number */
+	strbuf_addstr(&autostash, "^0");
+	argv_array_pushl(&stash_apply.args,
+			 "stash", "apply", autostash.buf, NULL);
+	stash_apply.git_cmd = 1;
+	stash_apply.no_stderr = stash_apply.no_stdout =
+		stash_apply.no_stdin = 1;
+	if (!run_command(&stash_apply))
+		printf(_("Applied autostash.\n"));
+	else {
+		struct argv_array args = ARGV_ARRAY_INIT;
+		int res = 0;
+
+		argv_array_pushl(&args,
+				 "stash", "store", "-m", "autostash", "-q",
+				 autostash.buf, NULL);
+		if (run_command_v_opt(args.argv, RUN_GIT_CMD))
+			res = error(_("Cannot store %s"), autostash.buf);
+		argv_array_clear(&args);
+		strbuf_release(&autostash);
+		if (res)
+			return res;
+
+		fprintf(stderr,
+			_("Applying autostash resulted in conflicts.\n"
+			  "Your changes are safe in the stash.\n"
+			  "You can run \"git stash pop\" or \"git stash drop\" "
+			  "at any time.\n"));
+	}
+
+	strbuf_release(&autostash);
+	return 0;
+}
+
+static int finish_rebase(struct rebase_options *opts)
+{
+	struct strbuf dir = STRBUF_INIT;
+	const char *argv_gc_auto[] = { "gc", "--auto", NULL };
+	int ret = 0;
+
+	delete_ref(NULL, "REBASE_HEAD", NULL, REF_NO_DEREF);
+	apply_autostash(opts);
+	close_object_store(the_repository->objects);
+	/*
+	 * We ignore errors in 'gc --auto', since the
+	 * user should see them.
+	 */
+	run_command_v_opt(argv_gc_auto, RUN_GIT_CMD);
+	if (opts->type == REBASE_INTERACTIVE) {
+		struct replay_opts replay = REPLAY_OPTS_INIT;
+
+		replay.action = REPLAY_INTERACTIVE_REBASE;
+		ret = sequencer_remove_state(&replay);
+	} else {
+		strbuf_addstr(&dir, opts->state_dir);
+		if (remove_dir_recursively(&dir, 0))
+			ret = error(_("could not remove '%s'"),
+				    opts->state_dir);
+		strbuf_release(&dir);
+	}
+
+	return ret;
+}
+
+static struct commit *peel_committish(const char *name)
+{
+	struct object *obj;
+	struct object_id oid;
+
+	if (get_oid(name, &oid))
+		return NULL;
+	obj = parse_object(the_repository, &oid);
+	return (struct commit *)peel_to_type(name, 0, obj, OBJ_COMMIT);
+}
+
+static void add_var(struct strbuf *buf, const char *name, const char *value)
+{
+	if (!value)
+		strbuf_addf(buf, "unset %s; ", name);
+	else {
+		strbuf_addf(buf, "%s=", name);
+		sq_quote_buf(buf, value);
+		strbuf_addstr(buf, "; ");
+	}
+}
+
+#define GIT_REFLOG_ACTION_ENVIRONMENT "GIT_REFLOG_ACTION"
+
+#define RESET_HEAD_DETACH (1<<0)
+#define RESET_HEAD_HARD (1<<1)
+#define RESET_HEAD_RUN_POST_CHECKOUT_HOOK (1<<2)
+#define RESET_HEAD_REFS_ONLY (1<<3)
+#define RESET_ORIG_HEAD (1<<4)
+
+static int reset_head(struct object_id *oid, const char *action,
+		      const char *switch_to_branch, unsigned flags,
+		      const char *reflog_orig_head, const char *reflog_head)
+{
+	unsigned detach_head = flags & RESET_HEAD_DETACH;
+	unsigned reset_hard = flags & RESET_HEAD_HARD;
+	unsigned run_hook = flags & RESET_HEAD_RUN_POST_CHECKOUT_HOOK;
+	unsigned refs_only = flags & RESET_HEAD_REFS_ONLY;
+	unsigned update_orig_head = flags & RESET_ORIG_HEAD;
+	struct object_id head_oid;
+	struct tree_desc desc[2] = { { NULL }, { NULL } };
+	struct lock_file lock = LOCK_INIT;
+	struct unpack_trees_options unpack_tree_opts;
+	struct tree *tree;
+	const char *reflog_action;
+	struct strbuf msg = STRBUF_INIT;
+	size_t prefix_len;
+	struct object_id *orig = NULL, oid_orig,
+		*old_orig = NULL, oid_old_orig;
+	int ret = 0, nr = 0;
+
+	if (switch_to_branch && !starts_with(switch_to_branch, "refs/"))
+		BUG("Not a fully qualified branch: '%s'", switch_to_branch);
+
+	if (!refs_only && hold_locked_index(&lock, LOCK_REPORT_ON_ERROR) < 0) {
+		ret = -1;
+		goto leave_reset_head;
+	}
+
+	if ((!oid || !reset_hard) && get_oid("HEAD", &head_oid)) {
+		ret = error(_("could not determine HEAD revision"));
+		goto leave_reset_head;
+	}
+
+	if (!oid)
+		oid = &head_oid;
+
+	if (refs_only)
+		goto reset_head_refs;
+
+	memset(&unpack_tree_opts, 0, sizeof(unpack_tree_opts));
+	setup_unpack_trees_porcelain(&unpack_tree_opts, action);
+	unpack_tree_opts.head_idx = 1;
+	unpack_tree_opts.src_index = the_repository->index;
+	unpack_tree_opts.dst_index = the_repository->index;
+	unpack_tree_opts.fn = reset_hard ? oneway_merge : twoway_merge;
+	unpack_tree_opts.update = 1;
+	unpack_tree_opts.merge = 1;
+	if (!detach_head)
+		unpack_tree_opts.reset = 1;
+
+	if (repo_read_index_unmerged(the_repository) < 0) {
+		ret = error(_("could not read index"));
+		goto leave_reset_head;
+	}
+
+	if (!reset_hard && !fill_tree_descriptor(the_repository, &desc[nr++], &head_oid)) {
+		ret = error(_("failed to find tree of %s"),
+			    oid_to_hex(&head_oid));
+		goto leave_reset_head;
+	}
+
+	if (!fill_tree_descriptor(the_repository, &desc[nr++], oid)) {
+		ret = error(_("failed to find tree of %s"), oid_to_hex(oid));
+		goto leave_reset_head;
+	}
+
+	if (unpack_trees(nr, desc, &unpack_tree_opts)) {
+		ret = -1;
+		goto leave_reset_head;
+	}
+
+	tree = parse_tree_indirect(oid);
+	prime_cache_tree(the_repository, the_repository->index, tree);
+
+	if (write_locked_index(the_repository->index, &lock, COMMIT_LOCK) < 0) {
+		ret = error(_("could not write index"));
+		goto leave_reset_head;
+	}
+
+reset_head_refs:
+	reflog_action = getenv(GIT_REFLOG_ACTION_ENVIRONMENT);
+	strbuf_addf(&msg, "%s: ", reflog_action ? reflog_action : "rebase");
+	prefix_len = msg.len;
+
+	if (update_orig_head) {
+		if (!get_oid("ORIG_HEAD", &oid_old_orig))
+			old_orig = &oid_old_orig;
+		if (!get_oid("HEAD", &oid_orig)) {
+			orig = &oid_orig;
+			if (!reflog_orig_head) {
+				strbuf_addstr(&msg, "updating ORIG_HEAD");
+				reflog_orig_head = msg.buf;
+			}
+			update_ref(reflog_orig_head, "ORIG_HEAD", orig,
+				   old_orig, 0, UPDATE_REFS_MSG_ON_ERR);
+		} else if (old_orig)
+			delete_ref(NULL, "ORIG_HEAD", old_orig, 0);
+	}
+
+	if (!reflog_head) {
+		strbuf_setlen(&msg, prefix_len);
+		strbuf_addstr(&msg, "updating HEAD");
+		reflog_head = msg.buf;
+	}
+	if (!switch_to_branch)
+		ret = update_ref(reflog_head, "HEAD", oid, orig,
+				 detach_head ? REF_NO_DEREF : 0,
+				 UPDATE_REFS_MSG_ON_ERR);
+	else {
+		ret = update_ref(reflog_head, switch_to_branch, oid,
+				 NULL, 0, UPDATE_REFS_MSG_ON_ERR);
+		if (!ret)
+			ret = create_symref("HEAD", switch_to_branch,
+					    reflog_head);
+	}
+	if (run_hook)
+		run_hook_le(NULL, "post-checkout",
+			    oid_to_hex(orig ? orig : &null_oid),
+			    oid_to_hex(oid), "1", NULL);
+
+leave_reset_head:
+	strbuf_release(&msg);
+	rollback_lock_file(&lock);
+	while (nr)
+		free((void *)desc[--nr].buffer);
+	return ret;
+}
+
+static int move_to_original_branch(struct rebase_options *opts)
+{
+	struct strbuf orig_head_reflog = STRBUF_INIT, head_reflog = STRBUF_INIT;
+	int ret;
+
+	if (!opts->head_name)
+		return 0; /* nothing to move back to */
+
+	if (!opts->onto)
+		BUG("move_to_original_branch without onto");
+
+	strbuf_addf(&orig_head_reflog, "rebase finished: %s onto %s",
+		    opts->head_name, oid_to_hex(&opts->onto->object.oid));
+	strbuf_addf(&head_reflog, "rebase finished: returning to %s",
+		    opts->head_name);
+	ret = reset_head(NULL, "", opts->head_name, RESET_HEAD_REFS_ONLY,
+			 orig_head_reflog.buf, head_reflog.buf);
+
+	strbuf_release(&orig_head_reflog);
+	strbuf_release(&head_reflog);
+	return ret;
+}
+
+static const char *resolvemsg =
+N_("Resolve all conflicts manually, mark them as resolved with\n"
+"\"git add/rm <conflicted_files>\", then run \"git rebase --continue\".\n"
+"You can instead skip this commit: run \"git rebase --skip\".\n"
+"To abort and get back to the state before \"git rebase\", run "
+"\"git rebase --abort\".");
+
+static int run_am(struct rebase_options *opts)
+{
+	struct child_process am = CHILD_PROCESS_INIT;
+	struct child_process format_patch = CHILD_PROCESS_INIT;
+	struct strbuf revisions = STRBUF_INIT;
+	int status;
+	char *rebased_patches;
+
+	am.git_cmd = 1;
+	argv_array_push(&am.args, "am");
+
+	if (opts->action && !strcmp("continue", opts->action)) {
+		argv_array_push(&am.args, "--resolved");
+		argv_array_pushf(&am.args, "--resolvemsg=%s", resolvemsg);
+		if (opts->gpg_sign_opt)
+			argv_array_push(&am.args, opts->gpg_sign_opt);
+		status = run_command(&am);
+		if (status)
+			return status;
+
+		return move_to_original_branch(opts);
+	}
+	if (opts->action && !strcmp("skip", opts->action)) {
+		argv_array_push(&am.args, "--skip");
+		argv_array_pushf(&am.args, "--resolvemsg=%s", resolvemsg);
+		status = run_command(&am);
+		if (status)
+			return status;
+
+		return move_to_original_branch(opts);
+	}
+	if (opts->action && !strcmp("show-current-patch", opts->action)) {
+		argv_array_push(&am.args, "--show-current-patch");
+		return run_command(&am);
+	}
+
+	strbuf_addf(&revisions, "%s...%s",
+		    oid_to_hex(opts->root ?
+			       /* this is now equivalent to !opts->upstream */
+			       &opts->onto->object.oid :
+			       &opts->upstream->object.oid),
+		    oid_to_hex(&opts->orig_head));
+
+	rebased_patches = xstrdup(git_path("rebased-patches"));
+	format_patch.out = open(rebased_patches,
+				O_WRONLY | O_CREAT | O_TRUNC, 0666);
+	if (format_patch.out < 0) {
+		status = error_errno(_("could not open '%s' for writing"),
+				     rebased_patches);
+		free(rebased_patches);
+		argv_array_clear(&am.args);
+		return status;
+	}
+
+	format_patch.git_cmd = 1;
+	argv_array_pushl(&format_patch.args, "format-patch", "-k", "--stdout",
+			 "--full-index", "--cherry-pick", "--right-only",
+			 "--src-prefix=a/", "--dst-prefix=b/", "--no-renames",
+			 "--no-cover-letter", "--pretty=mboxrd", "--topo-order",
+			 "--no-base", NULL);
+	if (opts->git_format_patch_opt.len)
+		argv_array_split(&format_patch.args,
+				 opts->git_format_patch_opt.buf);
+	argv_array_push(&format_patch.args, revisions.buf);
+	if (opts->restrict_revision)
+		argv_array_pushf(&format_patch.args, "^%s",
+				 oid_to_hex(&opts->restrict_revision->object.oid));
+
+	status = run_command(&format_patch);
+	if (status) {
+		unlink(rebased_patches);
+		free(rebased_patches);
+		argv_array_clear(&am.args);
+
+		reset_head(&opts->orig_head, "checkout", opts->head_name, 0,
+			   "HEAD", NULL);
+		error(_("\ngit encountered an error while preparing the "
+			"patches to replay\n"
+			"these revisions:\n"
+			"\n    %s\n\n"
+			"As a result, git cannot rebase them."),
+		      opts->revisions);
+
+		strbuf_release(&revisions);
+		return status;
+	}
+	strbuf_release(&revisions);
+
+	am.in = open(rebased_patches, O_RDONLY);
+	if (am.in < 0) {
+		status = error_errno(_("could not open '%s' for reading"),
+				     rebased_patches);
+		free(rebased_patches);
+		argv_array_clear(&am.args);
+		return status;
+	}
+
+	argv_array_pushv(&am.args, opts->git_am_opts.argv);
+	argv_array_push(&am.args, "--rebasing");
+	argv_array_pushf(&am.args, "--resolvemsg=%s", resolvemsg);
+	argv_array_push(&am.args, "--patch-format=mboxrd");
+	if (opts->allow_rerere_autoupdate == RERERE_AUTOUPDATE)
+		argv_array_push(&am.args, "--rerere-autoupdate");
+	else if (opts->allow_rerere_autoupdate == RERERE_NOAUTOUPDATE)
+		argv_array_push(&am.args, "--no-rerere-autoupdate");
+	if (opts->gpg_sign_opt)
+		argv_array_push(&am.args, opts->gpg_sign_opt);
+	status = run_command(&am);
+	unlink(rebased_patches);
+	free(rebased_patches);
+
+	if (!status) {
+		return move_to_original_branch(opts);
+	}
+
+	if (is_directory(opts->state_dir))
+		rebase_write_basic_state(opts);
+
+	return status;
+}
+
+static int run_specific_rebase(struct rebase_options *opts, enum action action)
+{
+	const char *argv[] = { NULL, NULL };
+	struct strbuf script_snippet = STRBUF_INIT, buf = STRBUF_INIT;
+	int status;
+	const char *backend, *backend_func;
+
+	if (opts->type == REBASE_INTERACTIVE) {
+		/* Run builtin interactive rebase */
+		setenv("GIT_CHERRY_PICK_HELP", resolvemsg, 1);
+		if (!(opts->flags & REBASE_INTERACTIVE_EXPLICIT)) {
+			setenv("GIT_SEQUENCE_EDITOR", ":", 1);
+			opts->autosquash = 0;
+		}
+		if (opts->gpg_sign_opt) {
+			/* remove the leading "-S" */
+			char *tmp = xstrdup(opts->gpg_sign_opt + 2);
+			free(opts->gpg_sign_opt);
+			opts->gpg_sign_opt = tmp;
+		}
+
+		status = run_rebase_interactive(opts, action);
+		goto finished_rebase;
+	}
+
+	if (opts->type == REBASE_AM) {
+		status = run_am(opts);
+		goto finished_rebase;
+	}
+
+	add_var(&script_snippet, "GIT_DIR", absolute_path(get_git_dir()));
+	add_var(&script_snippet, "state_dir", opts->state_dir);
+
+	add_var(&script_snippet, "upstream_name", opts->upstream_name);
+	add_var(&script_snippet, "upstream", opts->upstream ?
+		oid_to_hex(&opts->upstream->object.oid) : NULL);
+	add_var(&script_snippet, "head_name",
+		opts->head_name ? opts->head_name : "detached HEAD");
+	add_var(&script_snippet, "orig_head", oid_to_hex(&opts->orig_head));
+	add_var(&script_snippet, "onto", opts->onto ?
+		oid_to_hex(&opts->onto->object.oid) : NULL);
+	add_var(&script_snippet, "onto_name", opts->onto_name);
+	add_var(&script_snippet, "revisions", opts->revisions);
+	add_var(&script_snippet, "restrict_revision", opts->restrict_revision ?
+		oid_to_hex(&opts->restrict_revision->object.oid) : NULL);
+	add_var(&script_snippet, "GIT_QUIET",
+		opts->flags & REBASE_NO_QUIET ? "" : "t");
+	sq_quote_argv_pretty(&buf, opts->git_am_opts.argv);
+	add_var(&script_snippet, "git_am_opt", buf.buf);
+	strbuf_release(&buf);
+	add_var(&script_snippet, "verbose",
+		opts->flags & REBASE_VERBOSE ? "t" : "");
+	add_var(&script_snippet, "diffstat",
+		opts->flags & REBASE_DIFFSTAT ? "t" : "");
+	add_var(&script_snippet, "force_rebase",
+		opts->flags & REBASE_FORCE ? "t" : "");
+	if (opts->switch_to)
+		add_var(&script_snippet, "switch_to", opts->switch_to);
+	add_var(&script_snippet, "action", opts->action ? opts->action : "");
+	add_var(&script_snippet, "signoff", opts->signoff ? "--signoff" : "");
+	add_var(&script_snippet, "allow_rerere_autoupdate",
+		opts->allow_rerere_autoupdate ?
+			opts->allow_rerere_autoupdate == RERERE_AUTOUPDATE ?
+			"--rerere-autoupdate" : "--no-rerere-autoupdate" : "");
+	add_var(&script_snippet, "keep_empty", opts->keep_empty ? "yes" : "");
+	add_var(&script_snippet, "autosquash", opts->autosquash ? "t" : "");
+	add_var(&script_snippet, "gpg_sign_opt", opts->gpg_sign_opt);
+	add_var(&script_snippet, "cmd", opts->cmd);
+	add_var(&script_snippet, "allow_empty_message",
+		opts->allow_empty_message ?  "--allow-empty-message" : "");
+	add_var(&script_snippet, "rebase_merges",
+		opts->rebase_merges ? "t" : "");
+	add_var(&script_snippet, "rebase_cousins",
+		opts->rebase_cousins ? "t" : "");
+	add_var(&script_snippet, "strategy", opts->strategy);
+	add_var(&script_snippet, "strategy_opts", opts->strategy_opts);
+	add_var(&script_snippet, "rebase_root", opts->root ? "t" : "");
+	add_var(&script_snippet, "squash_onto",
+		opts->squash_onto ? oid_to_hex(opts->squash_onto) : "");
+	add_var(&script_snippet, "git_format_patch_opt",
+		opts->git_format_patch_opt.buf);
+
+	if (is_interactive(opts) &&
+	    !(opts->flags & REBASE_INTERACTIVE_EXPLICIT)) {
+		strbuf_addstr(&script_snippet,
+			      "GIT_SEQUENCE_EDITOR=:; export GIT_SEQUENCE_EDITOR; ");
+		opts->autosquash = 0;
+	}
+
+	switch (opts->type) {
+	case REBASE_PRESERVE_MERGES:
+		backend = "git-rebase--preserve-merges";
+		backend_func = "git_rebase__preserve_merges";
+		break;
+	default:
+		BUG("Unhandled rebase type %d", opts->type);
+		break;
+	}
+
+	strbuf_addf(&script_snippet,
+		    ". git-sh-setup && . %s && %s", backend, backend_func);
+	argv[0] = script_snippet.buf;
+
+	status = run_command_v_opt(argv, RUN_USING_SHELL);
+finished_rebase:
+	if (opts->dont_finish_rebase)
+		; /* do nothing */
+	else if (opts->type == REBASE_INTERACTIVE)
+		; /* interactive rebase cleans up after itself */
+	else if (status == 0) {
+		if (!file_exists(state_dir_path("stopped-sha", opts)))
+			finish_rebase(opts);
+	} else if (status == 2) {
+		struct strbuf dir = STRBUF_INIT;
+
+		apply_autostash(opts);
+		strbuf_addstr(&dir, opts->state_dir);
+		remove_dir_recursively(&dir, 0);
+		strbuf_release(&dir);
+		die("Nothing to do");
+	}
+
+	strbuf_release(&script_snippet);
+
+	return status ? -1 : 0;
+}
+
+static int rebase_config(const char *var, const char *value, void *data)
+{
+	struct rebase_options *opts = data;
+
+	if (!strcmp(var, "rebase.stat")) {
+		if (git_config_bool(var, value))
+			opts->flags |= REBASE_DIFFSTAT;
+		else
+			opts->flags &= ~REBASE_DIFFSTAT;
+		return 0;
+	}
+
+	if (!strcmp(var, "rebase.autosquash")) {
+		opts->autosquash = git_config_bool(var, value);
+		return 0;
+	}
+
+	if (!strcmp(var, "commit.gpgsign")) {
+		free(opts->gpg_sign_opt);
+		opts->gpg_sign_opt = git_config_bool(var, value) ?
+			xstrdup("-S") : NULL;
+		return 0;
+	}
+
+	if (!strcmp(var, "rebase.autostash")) {
+		opts->autostash = git_config_bool(var, value);
+		return 0;
+	}
+
+	if (!strcmp(var, "rebase.reschedulefailedexec")) {
+		opts->reschedule_failed_exec = git_config_bool(var, value);
+		return 0;
+	}
+
+	if (!strcmp(var, "rebase.usebuiltin")) {
+		opts->use_legacy_rebase = !git_config_bool(var, value);
+		return 0;
+	}
+
+	return git_default_config(var, value, data);
+}
+
+/*
+ * Determines whether the commits in from..to are linear, i.e. contain
+ * no merge commits. This function *expects* `from` to be an ancestor of
+ * `to`.
+ */
+static int is_linear_history(struct commit *from, struct commit *to)
+{
+	while (to && to != from) {
+		parse_commit(to);
+		if (!to->parents)
+			return 1;
+		if (to->parents->next)
+			return 0;
+		to = to->parents->item;
+	}
+	return 1;
+}
+
+static int can_fast_forward(struct commit *onto, struct commit *upstream,
+			    struct commit *restrict_revision,
+			    struct object_id *head_oid, struct object_id *merge_base)
+{
+	struct commit *head = lookup_commit(the_repository, head_oid);
+	struct commit_list *merge_bases = NULL;
+	int res = 0;
+
+	if (!head)
+		goto done;
+
+	merge_bases = get_merge_bases(onto, head);
+	if (!merge_bases || merge_bases->next) {
+		oidcpy(merge_base, &null_oid);
+		goto done;
+	}
+
+	oidcpy(merge_base, &merge_bases->item->object.oid);
+	if (!oideq(merge_base, &onto->object.oid))
+		goto done;
+
+	if (restrict_revision && !oideq(&restrict_revision->object.oid, merge_base))
+		goto done;
+
+	if (!upstream)
+		goto done;
+
+	free_commit_list(merge_bases);
+	merge_bases = get_merge_bases(upstream, head);
+	if (!merge_bases || merge_bases->next)
+		goto done;
+
+	if (!oideq(&onto->object.oid, &merge_bases->item->object.oid))
+		goto done;
+
+	res = 1;
+
+done:
+	free_commit_list(merge_bases);
+	return res && is_linear_history(onto, head);
+}
+
+/* -i followed by -m is still -i */
+static int parse_opt_merge(const struct option *opt, const char *arg, int unset)
+{
+	struct rebase_options *opts = opt->value;
+
+	BUG_ON_OPT_NEG(unset);
+	BUG_ON_OPT_ARG(arg);
+
+	if (!is_interactive(opts))
+		opts->type = REBASE_MERGE;
+
+	return 0;
+}
+
+/* -i followed by -p is still explicitly interactive, but -p alone is not */
+static int parse_opt_interactive(const struct option *opt, const char *arg,
+				 int unset)
+{
+	struct rebase_options *opts = opt->value;
+
+	BUG_ON_OPT_NEG(unset);
+	BUG_ON_OPT_ARG(arg);
+
+	opts->type = REBASE_INTERACTIVE;
+	opts->flags |= REBASE_INTERACTIVE_EXPLICIT;
+
+	return 0;
+}
+
+static void NORETURN error_on_missing_default_upstream(void)
+{
+	struct branch *current_branch = branch_get(NULL);
+
+	printf(_("%s\n"
+		 "Please specify which branch you want to rebase against.\n"
+		 "See git-rebase(1) for details.\n"
+		 "\n"
+		 "    git rebase '<branch>'\n"
+		 "\n"),
+		current_branch ? _("There is no tracking information for "
+			"the current branch.") :
+			_("You are not currently on a branch."));
+
+	if (current_branch) {
+		const char *remote = current_branch->remote_name;
+
+		if (!remote)
+			remote = _("<remote>");
+
+		printf(_("If you wish to set tracking information for this "
+			 "branch you can do so with:\n"
+			 "\n"
+			 "    git branch --set-upstream-to=%s/<branch> %s\n"
+			 "\n"),
+		       remote, current_branch->name);
+	}
+	exit(1);
+}
+
+static void set_reflog_action(struct rebase_options *options)
+{
+	const char *env;
+	struct strbuf buf = STRBUF_INIT;
+
+	if (!is_interactive(options))
+		return;
+
+	env = getenv(GIT_REFLOG_ACTION_ENVIRONMENT);
+	if (env && strcmp("rebase", env))
+		return; /* only override it if it is "rebase" */
+
+	strbuf_addf(&buf, "rebase -i (%s)", options->action);
+	setenv(GIT_REFLOG_ACTION_ENVIRONMENT, buf.buf, 1);
+	strbuf_release(&buf);
+}
+
+static int check_exec_cmd(const char *cmd)
+{
+	if (strchr(cmd, '\n'))
+		return error(_("exec commands cannot contain newlines"));
+
+	/* Does the command consist purely of whitespace? */
+	if (!cmd[strspn(cmd, " \t\r\f\v")])
+		return error(_("empty exec command"));
+
+	return 0;
+}
+
+
+int cmd_rebase(int argc, const char **argv, const char *prefix)
+{
+	struct rebase_options options = REBASE_OPTIONS_INIT;
+	const char *branch_name;
+	int ret, flags, total_argc, in_progress = 0;
+	int keep_base = 0;
+	int ok_to_skip_pre_rebase = 0;
+	struct strbuf msg = STRBUF_INIT;
+	struct strbuf revisions = STRBUF_INIT;
+	struct strbuf buf = STRBUF_INIT;
+	struct object_id merge_base;
+	enum action action = ACTION_NONE;
+	const char *gpg_sign = NULL;
+	struct string_list exec = STRING_LIST_INIT_NODUP;
+	const char *rebase_merges = NULL;
+	int fork_point = -1;
+	struct string_list strategy_options = STRING_LIST_INIT_NODUP;
+	struct object_id squash_onto;
+	char *squash_onto_name = NULL;
+	int reschedule_failed_exec = -1;
+	struct option builtin_rebase_options[] = {
+		OPT_STRING(0, "onto", &options.onto_name,
+			   N_("revision"),
+			   N_("rebase onto given branch instead of upstream")),
+		OPT_BOOL(0, "keep-base", &keep_base,
+			 N_("use the merge-base of upstream and branch as the current base")),
+		OPT_BOOL(0, "no-verify", &ok_to_skip_pre_rebase,
+			 N_("allow pre-rebase hook to run")),
+		OPT_NEGBIT('q', "quiet", &options.flags,
+			   N_("be quiet. implies --no-stat"),
+			   REBASE_NO_QUIET| REBASE_VERBOSE | REBASE_DIFFSTAT),
+		OPT_BIT('v', "verbose", &options.flags,
+			N_("display a diffstat of what changed upstream"),
+			REBASE_NO_QUIET | REBASE_VERBOSE | REBASE_DIFFSTAT),
+		{OPTION_NEGBIT, 'n', "no-stat", &options.flags, NULL,
+			N_("do not show diffstat of what changed upstream"),
+			PARSE_OPT_NOARG, NULL, REBASE_DIFFSTAT },
+		OPT_BOOL(0, "signoff", &options.signoff,
+			 N_("add a Signed-off-by: line to each commit")),
+		OPT_PASSTHRU_ARGV(0, "ignore-whitespace", &options.git_am_opts,
+				  NULL, N_("passed to 'git am'"),
+				  PARSE_OPT_NOARG),
+		OPT_PASSTHRU_ARGV(0, "committer-date-is-author-date",
+				  &options.git_am_opts, NULL,
+				  N_("passed to 'git am'"), PARSE_OPT_NOARG),
+		OPT_PASSTHRU_ARGV(0, "ignore-date", &options.git_am_opts, NULL,
+				  N_("passed to 'git am'"), PARSE_OPT_NOARG),
+		OPT_PASSTHRU_ARGV('C', NULL, &options.git_am_opts, N_("n"),
+				  N_("passed to 'git apply'"), 0),
+		OPT_PASSTHRU_ARGV(0, "whitespace", &options.git_am_opts,
+				  N_("action"), N_("passed to 'git apply'"), 0),
+		OPT_BIT('f', "force-rebase", &options.flags,
+			N_("cherry-pick all commits, even if unchanged"),
+			REBASE_FORCE),
+		OPT_BIT(0, "no-ff", &options.flags,
+			N_("cherry-pick all commits, even if unchanged"),
+			REBASE_FORCE),
+		OPT_CMDMODE(0, "continue", &action, N_("continue"),
+			    ACTION_CONTINUE),
+		OPT_CMDMODE(0, "skip", &action,
+			    N_("skip current patch and continue"), ACTION_SKIP),
+		OPT_CMDMODE(0, "abort", &action,
+			    N_("abort and check out the original branch"),
+			    ACTION_ABORT),
+		OPT_CMDMODE(0, "quit", &action,
+			    N_("abort but keep HEAD where it is"), ACTION_QUIT),
+		OPT_CMDMODE(0, "edit-todo", &action, N_("edit the todo list "
+			    "during an interactive rebase"), ACTION_EDIT_TODO),
+		OPT_CMDMODE(0, "show-current-patch", &action,
+			    N_("show the patch file being applied or merged"),
+			    ACTION_SHOW_CURRENT_PATCH),
+		{ OPTION_CALLBACK, 'm', "merge", &options, NULL,
+			N_("use merging strategies to rebase"),
+			PARSE_OPT_NOARG | PARSE_OPT_NONEG,
+			parse_opt_merge },
+		{ OPTION_CALLBACK, 'i', "interactive", &options, NULL,
+			N_("let the user edit the list of commits to rebase"),
+			PARSE_OPT_NOARG | PARSE_OPT_NONEG,
+			parse_opt_interactive },
+		OPT_SET_INT_F('p', "preserve-merges", &options.type,
+			      N_("(DEPRECATED) try to recreate merges instead of "
+				 "ignoring them"),
+			      REBASE_PRESERVE_MERGES, PARSE_OPT_HIDDEN),
+		OPT_RERERE_AUTOUPDATE(&options.allow_rerere_autoupdate),
+		OPT_BOOL('k', "keep-empty", &options.keep_empty,
+			 N_("preserve empty commits during rebase")),
+		OPT_BOOL(0, "autosquash", &options.autosquash,
+			 N_("move commits that begin with "
+			    "squash!/fixup! under -i")),
+		{ OPTION_STRING, 'S', "gpg-sign", &gpg_sign, N_("key-id"),
+			N_("GPG-sign commits"),
+			PARSE_OPT_OPTARG, NULL, (intptr_t) "" },
+		OPT_BOOL(0, "autostash", &options.autostash,
+			 N_("automatically stash/stash pop before and after")),
+		OPT_STRING_LIST('x', "exec", &exec, N_("exec"),
+				N_("add exec lines after each commit of the "
+				   "editable list")),
+		OPT_BOOL(0, "allow-empty-message",
+			 &options.allow_empty_message,
+			 N_("allow rebasing commits with empty messages")),
+		{OPTION_STRING, 'r', "rebase-merges", &rebase_merges,
+			N_("mode"),
+			N_("try to rebase merges instead of skipping them"),
+			PARSE_OPT_OPTARG, NULL, (intptr_t)""},
+		OPT_BOOL(0, "fork-point", &fork_point,
+			 N_("use 'merge-base --fork-point' to refine upstream")),
+		OPT_STRING('s', "strategy", &options.strategy,
+			   N_("strategy"), N_("use the given merge strategy")),
+		OPT_STRING_LIST('X', "strategy-option", &strategy_options,
+				N_("option"),
+				N_("pass the argument through to the merge "
+				   "strategy")),
+		OPT_BOOL(0, "root", &options.root,
+			 N_("rebase all reachable commits up to the root(s)")),
+		OPT_BOOL(0, "reschedule-failed-exec",
+			 &reschedule_failed_exec,
+			 N_("automatically re-schedule any `exec` that fails")),
+		OPT_END(),
+	};
+	int i;
+
+	if (argc == 2 && !strcmp(argv[1], "-h"))
+		usage_with_options(builtin_rebase_usage,
+				   builtin_rebase_options);
+
+	options.allow_empty_message = 1;
+	git_config(rebase_config, &options);
+
+	if (options.use_legacy_rebase ||
+	    !git_env_bool("GIT_TEST_REBASE_USE_BUILTIN", -1))
+		warning(_("the rebase.useBuiltin support has been removed!\n"
+			  "See its entry in 'git help config' for details."));
+
+	strbuf_reset(&buf);
+	strbuf_addf(&buf, "%s/applying", apply_dir());
+	if(file_exists(buf.buf))
+		die(_("It looks like 'git am' is in progress. Cannot rebase."));
+
+	if (is_directory(apply_dir())) {
+		options.type = REBASE_AM;
+		options.state_dir = apply_dir();
+	} else if (is_directory(merge_dir())) {
+		strbuf_reset(&buf);
+		strbuf_addf(&buf, "%s/rewritten", merge_dir());
+		if (is_directory(buf.buf)) {
+			options.type = REBASE_PRESERVE_MERGES;
+			options.flags |= REBASE_INTERACTIVE_EXPLICIT;
+		} else {
+			strbuf_reset(&buf);
+			strbuf_addf(&buf, "%s/interactive", merge_dir());
+			if(file_exists(buf.buf)) {
+				options.type = REBASE_INTERACTIVE;
+				options.flags |= REBASE_INTERACTIVE_EXPLICIT;
+			} else
+				options.type = REBASE_MERGE;
+		}
+		options.state_dir = merge_dir();
+	}
+
+	if (options.type != REBASE_UNSPECIFIED)
+		in_progress = 1;
+
+	total_argc = argc;
+	argc = parse_options(argc, argv, prefix,
+			     builtin_rebase_options,
+			     builtin_rebase_usage, 0);
+
+	if (action != ACTION_NONE && total_argc != 2) {
+		usage_with_options(builtin_rebase_usage,
+				   builtin_rebase_options);
+	}
+
+	if (argc > 2)
+		usage_with_options(builtin_rebase_usage,
+				   builtin_rebase_options);
+
+	if (options.type == REBASE_PRESERVE_MERGES)
+		warning(_("git rebase --preserve-merges is deprecated. "
+			  "Use --rebase-merges instead."));
+
+	if (keep_base) {
+		if (options.onto_name)
+			die(_("cannot combine '--keep-base' with '--onto'"));
+		if (options.root)
+			die(_("cannot combine '--keep-base' with '--root'"));
+	}
+
+	if (action != ACTION_NONE && !in_progress)
+		die(_("No rebase in progress?"));
+	setenv(GIT_REFLOG_ACTION_ENVIRONMENT, "rebase", 0);
+
+	if (action == ACTION_EDIT_TODO && !is_interactive(&options))
+		die(_("The --edit-todo action can only be used during "
+		      "interactive rebase."));
+
+	if (trace2_is_enabled()) {
+		if (is_interactive(&options))
+			trace2_cmd_mode("interactive");
+		else if (exec.nr)
+			trace2_cmd_mode("interactive-exec");
+		else
+			trace2_cmd_mode(action_names[action]);
+	}
+
+	switch (action) {
+	case ACTION_CONTINUE: {
+		struct object_id head;
+		struct lock_file lock_file = LOCK_INIT;
+		int fd;
+
+		options.action = "continue";
+		set_reflog_action(&options);
+
+		/* Sanity check */
+		if (get_oid("HEAD", &head))
+			die(_("Cannot read HEAD"));
+
+		fd = hold_locked_index(&lock_file, 0);
+		if (repo_read_index(the_repository) < 0)
+			die(_("could not read index"));
+		refresh_index(the_repository->index, REFRESH_QUIET, NULL, NULL,
+			      NULL);
+		if (0 <= fd)
+			repo_update_index_if_able(the_repository, &lock_file);
+		rollback_lock_file(&lock_file);
+
+		if (has_unstaged_changes(the_repository, 1)) {
+			puts(_("You must edit all merge conflicts and then\n"
+			       "mark them as resolved using git add"));
+			exit(1);
+		}
+		if (read_basic_state(&options))
+			exit(1);
+		goto run_rebase;
+	}
+	case ACTION_SKIP: {
+		struct string_list merge_rr = STRING_LIST_INIT_DUP;
+
+		options.action = "skip";
+		set_reflog_action(&options);
+
+		rerere_clear(the_repository, &merge_rr);
+		string_list_clear(&merge_rr, 1);
+
+		if (reset_head(NULL, "reset", NULL, RESET_HEAD_HARD,
+			       NULL, NULL) < 0)
+			die(_("could not discard worktree changes"));
+		remove_branch_state(the_repository, 0);
+		if (read_basic_state(&options))
+			exit(1);
+		goto run_rebase;
+	}
+	case ACTION_ABORT: {
+		struct string_list merge_rr = STRING_LIST_INIT_DUP;
+		options.action = "abort";
+		set_reflog_action(&options);
+
+		rerere_clear(the_repository, &merge_rr);
+		string_list_clear(&merge_rr, 1);
+
+		if (read_basic_state(&options))
+			exit(1);
+		if (reset_head(&options.orig_head, "reset",
+			       options.head_name, RESET_HEAD_HARD,
+			       NULL, NULL) < 0)
+			die(_("could not move back to %s"),
+			    oid_to_hex(&options.orig_head));
+		remove_branch_state(the_repository, 0);
+		ret = !!finish_rebase(&options);
+		goto cleanup;
+	}
+	case ACTION_QUIT: {
+		if (options.type == REBASE_INTERACTIVE) {
+			struct replay_opts replay = REPLAY_OPTS_INIT;
+
+			replay.action = REPLAY_INTERACTIVE_REBASE;
+			ret = !!sequencer_remove_state(&replay);
+		} else {
+			strbuf_reset(&buf);
+			strbuf_addstr(&buf, options.state_dir);
+			ret = !!remove_dir_recursively(&buf, 0);
+			if (ret)
+				error(_("could not remove '%s'"),
+				       options.state_dir);
+		}
+		goto cleanup;
+	}
+	case ACTION_EDIT_TODO:
+		options.action = "edit-todo";
+		options.dont_finish_rebase = 1;
+		goto run_rebase;
+	case ACTION_SHOW_CURRENT_PATCH:
+		options.action = "show-current-patch";
+		options.dont_finish_rebase = 1;
+		goto run_rebase;
+	case ACTION_NONE:
+		break;
+	default:
+		BUG("action: %d", action);
+	}
+
+	/* Make sure no rebase is in progress */
+	if (in_progress) {
+		const char *last_slash = strrchr(options.state_dir, '/');
+		const char *state_dir_base =
+			last_slash ? last_slash + 1 : options.state_dir;
+		const char *cmd_live_rebase =
+			"git rebase (--continue | --abort | --skip)";
+		strbuf_reset(&buf);
+		strbuf_addf(&buf, "rm -fr \"%s\"", options.state_dir);
+		die(_("It seems that there is already a %s directory, and\n"
+		      "I wonder if you are in the middle of another rebase.  "
+		      "If that is the\n"
+		      "case, please try\n\t%s\n"
+		      "If that is not the case, please\n\t%s\n"
+		      "and run me again.  I am stopping in case you still "
+		      "have something\n"
+		      "valuable there.\n"),
+		    state_dir_base, cmd_live_rebase, buf.buf);
+	}
+
+	for (i = 0; i < options.git_am_opts.argc; i++) {
+		const char *option = options.git_am_opts.argv[i], *p;
+		if (!strcmp(option, "--committer-date-is-author-date") ||
+		    !strcmp(option, "--ignore-date") ||
+		    !strcmp(option, "--whitespace=fix") ||
+		    !strcmp(option, "--whitespace=strip"))
+			options.flags |= REBASE_FORCE;
+		else if (skip_prefix(option, "-C", &p)) {
+			while (*p)
+				if (!isdigit(*(p++)))
+					die(_("switch `C' expects a "
+					      "numerical value"));
+		} else if (skip_prefix(option, "--whitespace=", &p)) {
+			if (*p && strcmp(p, "warn") && strcmp(p, "nowarn") &&
+			    strcmp(p, "error") && strcmp(p, "error-all"))
+				die("Invalid whitespace option: '%s'", p);
+		}
+	}
+
+	for (i = 0; i < exec.nr; i++)
+		if (check_exec_cmd(exec.items[i].string))
+			exit(1);
+
+	if (!(options.flags & REBASE_NO_QUIET))
+		argv_array_push(&options.git_am_opts, "-q");
+
+	if (options.keep_empty)
+		imply_interactive(&options, "--keep-empty");
+
+	if (gpg_sign) {
+		free(options.gpg_sign_opt);
+		options.gpg_sign_opt = xstrfmt("-S%s", gpg_sign);
+	}
+
+	if (exec.nr) {
+		int i;
+
+		imply_interactive(&options, "--exec");
+
+		strbuf_reset(&buf);
+		for (i = 0; i < exec.nr; i++)
+			strbuf_addf(&buf, "exec %s\n", exec.items[i].string);
+		options.cmd = xstrdup(buf.buf);
+	}
+
+	if (rebase_merges) {
+		if (!*rebase_merges)
+			; /* default mode; do nothing */
+		else if (!strcmp("rebase-cousins", rebase_merges))
+			options.rebase_cousins = 1;
+		else if (strcmp("no-rebase-cousins", rebase_merges))
+			die(_("Unknown mode: %s"), rebase_merges);
+		options.rebase_merges = 1;
+		imply_interactive(&options, "--rebase-merges");
+	}
+
+	if (strategy_options.nr) {
+		int i;
+
+		if (!options.strategy)
+			options.strategy = "recursive";
+
+		strbuf_reset(&buf);
+		for (i = 0; i < strategy_options.nr; i++)
+			strbuf_addf(&buf, " --%s",
+				    strategy_options.items[i].string);
+		options.strategy_opts = xstrdup(buf.buf);
+	}
+
+	if (options.strategy) {
+		options.strategy = xstrdup(options.strategy);
+		switch (options.type) {
+		case REBASE_AM:
+			die(_("--strategy requires --merge or --interactive"));
+		case REBASE_MERGE:
+		case REBASE_INTERACTIVE:
+		case REBASE_PRESERVE_MERGES:
+			/* compatible */
+			break;
+		case REBASE_UNSPECIFIED:
+			options.type = REBASE_MERGE;
+			break;
+		default:
+			BUG("unhandled rebase type (%d)", options.type);
+		}
+	}
+
+	if (options.type == REBASE_MERGE)
+		imply_interactive(&options, "--merge");
+
+	if (options.root && !options.onto_name)
+		imply_interactive(&options, "--root without --onto");
+
+	if (isatty(2) && options.flags & REBASE_NO_QUIET)
+		strbuf_addstr(&options.git_format_patch_opt, " --progress");
+
+	switch (options.type) {
+	case REBASE_MERGE:
+	case REBASE_INTERACTIVE:
+	case REBASE_PRESERVE_MERGES:
+		options.state_dir = merge_dir();
+		break;
+	case REBASE_AM:
+		options.state_dir = apply_dir();
+		break;
+	default:
+		/* the default rebase backend is `--am` */
+		options.type = REBASE_AM;
+		options.state_dir = apply_dir();
+		break;
+	}
+
+	if (reschedule_failed_exec > 0 && !is_interactive(&options))
+		die(_("--reschedule-failed-exec requires "
+		      "--exec or --interactive"));
+	if (reschedule_failed_exec >= 0)
+		options.reschedule_failed_exec = reschedule_failed_exec;
+
+	if (options.git_am_opts.argc) {
+		/* all am options except -q are compatible only with --am */
+		for (i = options.git_am_opts.argc - 1; i >= 0; i--)
+			if (strcmp(options.git_am_opts.argv[i], "-q"))
+				break;
+
+		if (is_interactive(&options) && i >= 0)
+			die(_("cannot combine am options with either "
+			      "interactive or merge options"));
+	}
+
+	if (options.signoff) {
+		if (options.type == REBASE_PRESERVE_MERGES)
+			die("cannot combine '--signoff' with "
+			    "'--preserve-merges'");
+		argv_array_push(&options.git_am_opts, "--signoff");
+		options.flags |= REBASE_FORCE;
+	}
+
+	if (options.type == REBASE_PRESERVE_MERGES) {
+		/*
+		 * Note: incompatibility with --signoff handled in signoff block above
+		 * Note: incompatibility with --interactive is just a strong warning;
+		 *       git-rebase.txt caveats with "unless you know what you are doing"
+		 */
+		if (options.rebase_merges)
+			die(_("cannot combine '--preserve-merges' with "
+			      "'--rebase-merges'"));
+
+		if (options.reschedule_failed_exec)
+			die(_("error: cannot combine '--preserve-merges' with "
+			      "'--reschedule-failed-exec'"));
+	}
+
+	if (!options.root) {
+		if (argc < 1) {
+			struct branch *branch;
+
+			branch = branch_get(NULL);
+			options.upstream_name = branch_get_upstream(branch,
+								    NULL);
+			if (!options.upstream_name)
+				error_on_missing_default_upstream();
+			if (fork_point < 0)
+				fork_point = 1;
+		} else {
+			options.upstream_name = argv[0];
+			argc--;
+			argv++;
+			if (!strcmp(options.upstream_name, "-"))
+				options.upstream_name = "@{-1}";
+		}
+		options.upstream = peel_committish(options.upstream_name);
+		if (!options.upstream)
+			die(_("invalid upstream '%s'"), options.upstream_name);
+		options.upstream_arg = options.upstream_name;
+	} else {
+		if (!options.onto_name) {
+			if (commit_tree("", 0, the_hash_algo->empty_tree, NULL,
+					&squash_onto, NULL, NULL) < 0)
+				die(_("Could not create new root commit"));
+			options.squash_onto = &squash_onto;
+			options.onto_name = squash_onto_name =
+				xstrdup(oid_to_hex(&squash_onto));
+		} else
+			options.root_with_onto = 1;
+
+		options.upstream_name = NULL;
+		options.upstream = NULL;
+		if (argc > 1)
+			usage_with_options(builtin_rebase_usage,
+					   builtin_rebase_options);
+		options.upstream_arg = "--root";
+	}
+
+	/* Make sure the branch to rebase onto is valid. */
+	if (keep_base) {
+		strbuf_reset(&buf);
+		strbuf_addstr(&buf, options.upstream_name);
+		strbuf_addstr(&buf, "...");
+		options.onto_name = xstrdup(buf.buf);
+	} else if (!options.onto_name)
+		options.onto_name = options.upstream_name;
+	if (strstr(options.onto_name, "...")) {
+		if (get_oid_mb(options.onto_name, &merge_base) < 0) {
+			if (keep_base)
+				die(_("'%s': need exactly one merge base with branch"),
+				    options.upstream_name);
+			else
+				die(_("'%s': need exactly one merge base"),
+				    options.onto_name);
+		}
+		options.onto = lookup_commit_or_die(&merge_base,
+						    options.onto_name);
+	} else {
+		options.onto = peel_committish(options.onto_name);
+		if (!options.onto)
+			die(_("Does not point to a valid commit '%s'"),
+				options.onto_name);
+	}
+
+	/*
+	 * If the branch to rebase is given, that is the branch we will rebase
+	 * branch_name -- branch/commit being rebased, or
+	 * 		  HEAD (already detached)
+	 * orig_head -- commit object name of tip of the branch before rebasing
+	 * head_name -- refs/heads/<that-branch> or NULL (detached HEAD)
+	 */
+	if (argc == 1) {
+		/* Is it "rebase other branchname" or "rebase other commit"? */
+		branch_name = argv[0];
+		options.switch_to = argv[0];
+
+		/* Is it a local branch? */
+		strbuf_reset(&buf);
+		strbuf_addf(&buf, "refs/heads/%s", branch_name);
+		if (!read_ref(buf.buf, &options.orig_head))
+			options.head_name = xstrdup(buf.buf);
+		/* If not is it a valid ref (branch or commit)? */
+		else if (!get_oid(branch_name, &options.orig_head))
+			options.head_name = NULL;
+		else
+			die(_("fatal: no such branch/commit '%s'"),
+			    branch_name);
+	} else if (argc == 0) {
+		/* Do not need to switch branches, we are already on it. */
+		options.head_name =
+			xstrdup_or_null(resolve_ref_unsafe("HEAD", 0, NULL,
+					 &flags));
+		if (!options.head_name)
+			die(_("No such ref: %s"), "HEAD");
+		if (flags & REF_ISSYMREF) {
+			if (!skip_prefix(options.head_name,
+					 "refs/heads/", &branch_name))
+				branch_name = options.head_name;
+
+		} else {
+			FREE_AND_NULL(options.head_name);
+			branch_name = "HEAD";
+		}
+		if (get_oid("HEAD", &options.orig_head))
+			die(_("Could not resolve HEAD to a revision"));
+	} else
+		BUG("unexpected number of arguments left to parse");
+
+	if (fork_point > 0) {
+		struct commit *head =
+			lookup_commit_reference(the_repository,
+						&options.orig_head);
+		options.restrict_revision =
+			get_fork_point(options.upstream_name, head);
+	}
+
+	if (repo_read_index(the_repository) < 0)
+		die(_("could not read index"));
+
+	if (options.autostash) {
+		struct lock_file lock_file = LOCK_INIT;
+		int fd;
+
+		fd = hold_locked_index(&lock_file, 0);
+		refresh_cache(REFRESH_QUIET);
+		if (0 <= fd)
+			repo_update_index_if_able(the_repository, &lock_file);
+		rollback_lock_file(&lock_file);
+
+		if (has_unstaged_changes(the_repository, 1) ||
+		    has_uncommitted_changes(the_repository, 1)) {
+			const char *autostash =
+				state_dir_path("autostash", &options);
+			struct child_process stash = CHILD_PROCESS_INIT;
+			struct object_id oid;
+
+			argv_array_pushl(&stash.args,
+					 "stash", "create", "autostash", NULL);
+			stash.git_cmd = 1;
+			stash.no_stdin = 1;
+			strbuf_reset(&buf);
+			if (capture_command(&stash, &buf, GIT_MAX_HEXSZ))
+				die(_("Cannot autostash"));
+			strbuf_trim_trailing_newline(&buf);
+			if (get_oid(buf.buf, &oid))
+				die(_("Unexpected stash response: '%s'"),
+				    buf.buf);
+			strbuf_reset(&buf);
+			strbuf_add_unique_abbrev(&buf, &oid, DEFAULT_ABBREV);
+
+			if (safe_create_leading_directories_const(autostash))
+				die(_("Could not create directory for '%s'"),
+				    options.state_dir);
+			write_file(autostash, "%s", oid_to_hex(&oid));
+			printf(_("Created autostash: %s\n"), buf.buf);
+			if (reset_head(NULL, "reset --hard",
+				       NULL, RESET_HEAD_HARD, NULL, NULL) < 0)
+				die(_("could not reset --hard"));
+
+			if (discard_index(the_repository->index) < 0 ||
+				repo_read_index(the_repository) < 0)
+				die(_("could not read index"));
+		}
+	}
+
+	if (require_clean_work_tree(the_repository, "rebase",
+				    _("Please commit or stash them."), 1, 1)) {
+		ret = 1;
+		goto cleanup;
+	}
+
+	/*
+	 * Now we are rebasing commits upstream..orig_head (or with --root,
+	 * everything leading up to orig_head) on top of onto.
+	 */
+
+	/*
+	 * Check if we are already based on onto with linear history,
+	 * in which case we could fast-forward without replacing the commits
+	 * with new commits recreated by replaying their changes. This
+	 * optimization must not be done if this is an interactive rebase.
+	 */
+	if (can_fast_forward(options.onto, options.upstream, options.restrict_revision,
+		    &options.orig_head, &merge_base) &&
+	    !is_interactive(&options)) {
+		int flag;
+
+		if (!(options.flags & REBASE_FORCE)) {
+			/* Lazily switch to the target branch if needed... */
+			if (options.switch_to) {
+				struct object_id oid;
+
+				if (get_oid(options.switch_to, &oid) < 0) {
+					ret = !!error(_("could not parse '%s'"),
+						      options.switch_to);
+					goto cleanup;
+				}
+
+				strbuf_reset(&buf);
+				strbuf_addf(&buf, "%s: checkout %s",
+					    getenv(GIT_REFLOG_ACTION_ENVIRONMENT),
+					    options.switch_to);
+				if (reset_head(&oid, "checkout",
+					       options.head_name,
+					       RESET_HEAD_RUN_POST_CHECKOUT_HOOK,
+					       NULL, buf.buf) < 0) {
+					ret = !!error(_("could not switch to "
+							"%s"),
+						      options.switch_to);
+					goto cleanup;
+				}
+			}
+
+			if (!(options.flags & REBASE_NO_QUIET))
+				; /* be quiet */
+			else if (!strcmp(branch_name, "HEAD") &&
+				 resolve_ref_unsafe("HEAD", 0, NULL, &flag))
+				puts(_("HEAD is up to date."));
+			else
+				printf(_("Current branch %s is up to date.\n"),
+				       branch_name);
+			ret = !!finish_rebase(&options);
+			goto cleanup;
+		} else if (!(options.flags & REBASE_NO_QUIET))
+			; /* be quiet */
+		else if (!strcmp(branch_name, "HEAD") &&
+			 resolve_ref_unsafe("HEAD", 0, NULL, &flag))
+			puts(_("HEAD is up to date, rebase forced."));
+		else
+			printf(_("Current branch %s is up to date, rebase "
+				 "forced.\n"), branch_name);
+	}
+
+	/* If a hook exists, give it a chance to interrupt*/
+	if (!ok_to_skip_pre_rebase &&
+	    run_hook_le(NULL, "pre-rebase", options.upstream_arg,
+			argc ? argv[0] : NULL, NULL))
+		die(_("The pre-rebase hook refused to rebase."));
+
+	if (options.flags & REBASE_DIFFSTAT) {
+		struct diff_options opts;
+
+		if (options.flags & REBASE_VERBOSE) {
+			if (is_null_oid(&merge_base))
+				printf(_("Changes to %s:\n"),
+				       oid_to_hex(&options.onto->object.oid));
+			else
+				printf(_("Changes from %s to %s:\n"),
+				       oid_to_hex(&merge_base),
+				       oid_to_hex(&options.onto->object.oid));
+		}
+
+		/* We want color (if set), but no pager */
+		diff_setup(&opts);
+		opts.stat_width = -1; /* use full terminal width */
+		opts.stat_graph_width = -1; /* respect statGraphWidth config */
+		opts.output_format |=
+			DIFF_FORMAT_SUMMARY | DIFF_FORMAT_DIFFSTAT;
+		opts.detect_rename = DIFF_DETECT_RENAME;
+		diff_setup_done(&opts);
+		diff_tree_oid(is_null_oid(&merge_base) ?
+			      the_hash_algo->empty_tree : &merge_base,
+			      &options.onto->object.oid, "", &opts);
+		diffcore_std(&opts);
+		diff_flush(&opts);
+	}
+
+	if (is_interactive(&options))
+		goto run_rebase;
+
+	/* Detach HEAD and reset the tree */
+	if (options.flags & REBASE_NO_QUIET)
+		printf(_("First, rewinding head to replay your work on top of "
+			 "it...\n"));
+
+	strbuf_addf(&msg, "%s: checkout %s",
+		    getenv(GIT_REFLOG_ACTION_ENVIRONMENT), options.onto_name);
+	if (reset_head(&options.onto->object.oid, "checkout", NULL,
+		       RESET_HEAD_DETACH | RESET_ORIG_HEAD |
+		       RESET_HEAD_RUN_POST_CHECKOUT_HOOK,
+		       NULL, msg.buf))
+		die(_("Could not detach HEAD"));
+	strbuf_release(&msg);
+
+	/*
+	 * If the onto is a proper descendant of the tip of the branch, then
+	 * we just fast-forwarded.
+	 */
+	strbuf_reset(&msg);
+	if (oideq(&merge_base, &options.orig_head)) {
+		printf(_("Fast-forwarded %s to %s.\n"),
+			branch_name, options.onto_name);
+		strbuf_addf(&msg, "rebase finished: %s onto %s",
+			options.head_name ? options.head_name : "detached HEAD",
+			oid_to_hex(&options.onto->object.oid));
+		reset_head(NULL, "Fast-forwarded", options.head_name,
+			   RESET_HEAD_REFS_ONLY, "HEAD", msg.buf);
+		strbuf_release(&msg);
+		ret = !!finish_rebase(&options);
+		goto cleanup;
+	}
+
+	strbuf_addf(&revisions, "%s..%s",
+		    options.root ? oid_to_hex(&options.onto->object.oid) :
+		    (options.restrict_revision ?
+		     oid_to_hex(&options.restrict_revision->object.oid) :
+		     oid_to_hex(&options.upstream->object.oid)),
+		    oid_to_hex(&options.orig_head));
+
+	options.revisions = revisions.buf;
+
+run_rebase:
+	ret = !!run_specific_rebase(&options, action);
+
+cleanup:
+	strbuf_release(&buf);
+	strbuf_release(&revisions);
+	free(options.head_name);
+	free(options.gpg_sign_opt);
+	free(options.cmd);
+	free(squash_onto_name);
+	return ret;
+}
diff -pruN 1.2.1+git2.18.0-1/git/builtin/rebase--helper.c 1.2.3+git2.25.1-1/git/builtin/rebase--helper.c
--- 1.2.1+git2.18.0-1/git/builtin/rebase--helper.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/builtin/rebase--helper.c	1970-01-01 00:00:00.000000000 +0000
@@ -1,88 +0,0 @@
-#include "builtin.h"
-#include "cache.h"
-#include "config.h"
-#include "parse-options.h"
-#include "sequencer.h"
-
-static const char * const builtin_rebase_helper_usage[] = {
-	N_("git rebase--helper [<options>]"),
-	NULL
-};
-
-int cmd_rebase__helper(int argc, const char **argv, const char *prefix)
-{
-	struct replay_opts opts = REPLAY_OPTS_INIT;
-	unsigned flags = 0, keep_empty = 0, rebase_merges = 0;
-	int abbreviate_commands = 0, rebase_cousins = -1;
-	enum {
-		CONTINUE = 1, ABORT, MAKE_SCRIPT, SHORTEN_OIDS, EXPAND_OIDS,
-		CHECK_TODO_LIST, SKIP_UNNECESSARY_PICKS, REARRANGE_SQUASH,
-		ADD_EXEC
-	} command = 0;
-	struct option options[] = {
-		OPT_BOOL(0, "ff", &opts.allow_ff, N_("allow fast-forward")),
-		OPT_BOOL(0, "keep-empty", &keep_empty, N_("keep empty commits")),
-		OPT_BOOL(0, "allow-empty-message", &opts.allow_empty_message,
-			N_("allow commits with empty messages")),
-		OPT_BOOL(0, "rebase-merges", &rebase_merges, N_("rebase merge commits")),
-		OPT_BOOL(0, "rebase-cousins", &rebase_cousins,
-			 N_("keep original branch points of cousins")),
-		OPT_CMDMODE(0, "continue", &command, N_("continue rebase"),
-				CONTINUE),
-		OPT_CMDMODE(0, "abort", &command, N_("abort rebase"),
-				ABORT),
-		OPT_CMDMODE(0, "make-script", &command,
-			N_("make rebase script"), MAKE_SCRIPT),
-		OPT_CMDMODE(0, "shorten-ids", &command,
-			N_("shorten commit ids in the todo list"), SHORTEN_OIDS),
-		OPT_CMDMODE(0, "expand-ids", &command,
-			N_("expand commit ids in the todo list"), EXPAND_OIDS),
-		OPT_CMDMODE(0, "check-todo-list", &command,
-			N_("check the todo list"), CHECK_TODO_LIST),
-		OPT_CMDMODE(0, "skip-unnecessary-picks", &command,
-			N_("skip unnecessary picks"), SKIP_UNNECESSARY_PICKS),
-		OPT_CMDMODE(0, "rearrange-squash", &command,
-			N_("rearrange fixup/squash lines"), REARRANGE_SQUASH),
-		OPT_CMDMODE(0, "add-exec-commands", &command,
-			N_("insert exec commands in todo list"), ADD_EXEC),
-		OPT_END()
-	};
-
-	sequencer_init_config(&opts);
-	git_config_get_bool("rebase.abbreviatecommands", &abbreviate_commands);
-
-	opts.action = REPLAY_INTERACTIVE_REBASE;
-	opts.allow_ff = 1;
-	opts.allow_empty = 1;
-
-	argc = parse_options(argc, argv, NULL, options,
-			builtin_rebase_helper_usage, PARSE_OPT_KEEP_ARGV0);
-
-	flags |= keep_empty ? TODO_LIST_KEEP_EMPTY : 0;
-	flags |= abbreviate_commands ? TODO_LIST_ABBREVIATE_CMDS : 0;
-	flags |= rebase_merges ? TODO_LIST_REBASE_MERGES : 0;
-	flags |= rebase_cousins > 0 ? TODO_LIST_REBASE_COUSINS : 0;
-	flags |= command == SHORTEN_OIDS ? TODO_LIST_SHORTEN_IDS : 0;
-
-	if (rebase_cousins >= 0 && !rebase_merges)
-		warning(_("--[no-]rebase-cousins has no effect without "
-			  "--rebase-merges"));
-
-	if (command == CONTINUE && argc == 1)
-		return !!sequencer_continue(&opts);
-	if (command == ABORT && argc == 1)
-		return !!sequencer_remove_state(&opts);
-	if (command == MAKE_SCRIPT && argc > 1)
-		return !!sequencer_make_script(stdout, argc, argv, flags);
-	if ((command == SHORTEN_OIDS || command == EXPAND_OIDS) && argc == 1)
-		return !!transform_todos(flags);
-	if (command == CHECK_TODO_LIST && argc == 1)
-		return !!check_todo_list();
-	if (command == SKIP_UNNECESSARY_PICKS && argc == 1)
-		return !!skip_unnecessary_picks();
-	if (command == REARRANGE_SQUASH && argc == 1)
-		return !!rearrange_squash();
-	if (command == ADD_EXEC && argc == 2)
-		return !!sequencer_add_exec_commands(argv[1]);
-	usage_with_options(builtin_rebase_helper_usage, options);
-}
diff -pruN 1.2.1+git2.18.0-1/git/builtin/receive-pack.c 1.2.3+git2.25.1-1/git/builtin/receive-pack.c
--- 1.2.1+git2.18.0-1/git/builtin/receive-pack.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/builtin/receive-pack.c	2020-02-17 04:47:35.000000000 +0000
@@ -12,7 +12,6 @@
 #include "object.h"
 #include "remote.h"
 #include "connect.h"
-#include "transport.h"
 #include "string-list.h"
 #include "sha1-array.h"
 #include "connected.h"
@@ -25,7 +24,9 @@
 #include "tmp-objdir.h"
 #include "oidset.h"
 #include "packfile.h"
+#include "object-store.h"
 #include "protocol.h"
+#include "commit-reach.h"
 
 static const char * const receive_pack_usage[] = {
 	N_("git receive-pack <git-dir>"),
@@ -279,8 +280,7 @@ static int show_ref_cb(const char *path_
 	return 0;
 }
 
-static void show_one_alternate_ref(const char *refname,
-				   const struct object_id *oid,
+static void show_one_alternate_ref(const struct object_id *oid,
 				   void *data)
 {
 	struct oidset *seen = data;
@@ -417,24 +417,22 @@ static int copy_to_sideband(int in, int
 	return 0;
 }
 
-#define HMAC_BLOCK_SIZE 64
-
-static void hmac_sha1(unsigned char *out,
+static void hmac(unsigned char *out,
 		      const char *key_in, size_t key_len,
 		      const char *text, size_t text_len)
 {
-	unsigned char key[HMAC_BLOCK_SIZE];
-	unsigned char k_ipad[HMAC_BLOCK_SIZE];
-	unsigned char k_opad[HMAC_BLOCK_SIZE];
+	unsigned char key[GIT_MAX_BLKSZ];
+	unsigned char k_ipad[GIT_MAX_BLKSZ];
+	unsigned char k_opad[GIT_MAX_BLKSZ];
 	int i;
-	git_SHA_CTX ctx;
+	git_hash_ctx ctx;
 
 	/* RFC 2104 2. (1) */
-	memset(key, '\0', HMAC_BLOCK_SIZE);
-	if (HMAC_BLOCK_SIZE < key_len) {
-		git_SHA1_Init(&ctx);
-		git_SHA1_Update(&ctx, key_in, key_len);
-		git_SHA1_Final(key, &ctx);
+	memset(key, '\0', GIT_MAX_BLKSZ);
+	if (the_hash_algo->blksz < key_len) {
+		the_hash_algo->init_fn(&ctx);
+		the_hash_algo->update_fn(&ctx, key_in, key_len);
+		the_hash_algo->final_fn(key, &ctx);
 	} else {
 		memcpy(key, key_in, key_len);
 	}
@@ -446,29 +444,29 @@ static void hmac_sha1(unsigned char *out
 	}
 
 	/* RFC 2104 2. (3) & (4) */
-	git_SHA1_Init(&ctx);
-	git_SHA1_Update(&ctx, k_ipad, sizeof(k_ipad));
-	git_SHA1_Update(&ctx, text, text_len);
-	git_SHA1_Final(out, &ctx);
+	the_hash_algo->init_fn(&ctx);
+	the_hash_algo->update_fn(&ctx, k_ipad, sizeof(k_ipad));
+	the_hash_algo->update_fn(&ctx, text, text_len);
+	the_hash_algo->final_fn(out, &ctx);
 
 	/* RFC 2104 2. (6) & (7) */
-	git_SHA1_Init(&ctx);
-	git_SHA1_Update(&ctx, k_opad, sizeof(k_opad));
-	git_SHA1_Update(&ctx, out, GIT_SHA1_RAWSZ);
-	git_SHA1_Final(out, &ctx);
+	the_hash_algo->init_fn(&ctx);
+	the_hash_algo->update_fn(&ctx, k_opad, sizeof(k_opad));
+	the_hash_algo->update_fn(&ctx, out, the_hash_algo->rawsz);
+	the_hash_algo->final_fn(out, &ctx);
 }
 
 static char *prepare_push_cert_nonce(const char *path, timestamp_t stamp)
 {
 	struct strbuf buf = STRBUF_INIT;
-	unsigned char sha1[GIT_SHA1_RAWSZ];
+	unsigned char hash[GIT_MAX_RAWSZ];
 
 	strbuf_addf(&buf, "%s:%"PRItime, path, stamp);
-	hmac_sha1(sha1, buf.buf, buf.len, cert_nonce_seed, strlen(cert_nonce_seed));;
+	hmac(hash, buf.buf, buf.len, cert_nonce_seed, strlen(cert_nonce_seed));
 	strbuf_release(&buf);
 
 	/* RFC 2104 5. HMAC-SHA1-80 */
-	strbuf_addf(&buf, "%"PRItime"-%.*s", stamp, GIT_SHA1_HEXSZ, sha1_to_hex(sha1));
+	strbuf_addf(&buf, "%"PRItime"-%.*s", stamp, (int)the_hash_algo->hexsz, hash_to_hex(hash));
 	return strbuf_detach(&buf, NULL);
 }
 
@@ -629,8 +627,6 @@ static void prepare_push_cert_sha1(struc
 		return;
 
 	if (!already_done) {
-		struct strbuf gpg_output = STRBUF_INIT;
-		struct strbuf gpg_status = STRBUF_INIT;
 		int bogs /* beginning_of_gpg_sig */;
 
 		already_done = 1;
@@ -639,22 +635,11 @@ static void prepare_push_cert_sha1(struc
 			oidclr(&push_cert_oid);
 
 		memset(&sigcheck, '\0', sizeof(sigcheck));
-		sigcheck.result = 'N';
 
 		bogs = parse_signature(push_cert.buf, push_cert.len);
-		if (verify_signed_buffer(push_cert.buf, bogs,
-					 push_cert.buf + bogs, push_cert.len - bogs,
-					 &gpg_output, &gpg_status) < 0) {
-			; /* error running gpg */
-		} else {
-			sigcheck.payload = push_cert.buf;
-			sigcheck.gpg_output = gpg_output.buf;
-			sigcheck.gpg_status = gpg_status.buf;
-			parse_gpg_output(&sigcheck);
-		}
+		check_signature(push_cert.buf, bogs, push_cert.buf + bogs,
+				push_cert.len - bogs, &sigcheck);
 
-		strbuf_release(&gpg_output);
-		strbuf_release(&gpg_status);
 		nonce_status = check_nonce(push_cert.buf, bogs);
 	}
 	if (!is_null_oid(&push_cert_oid)) {
@@ -706,6 +691,8 @@ static int run_and_feed_hook(const char
 	proc.argv = argv;
 	proc.in = -1;
 	proc.stdout_to_stderr = 1;
+	proc.trace2_hook_name = hook_name;
+
 	if (feed_state->push_options) {
 		int i;
 		for (i = 0; i < feed_state->push_options->nr; i++)
@@ -819,6 +806,7 @@ static int run_update_hook(struct comman
 	proc.stdout_to_stderr = 1;
 	proc.err = use_sideband ? -1 : 0;
 	proc.argv = argv;
+	proc.trace2_hook_name = "update";
 
 	code = start_command(&proc);
 	if (code)
@@ -905,7 +893,7 @@ static int update_shallow_ref(struct com
 	 * not lose these new roots..
 	 */
 	for (i = 0; i < extra.nr; i++)
-		register_shallow(&extra.oid[i]);
+		register_shallow(the_repository, &extra.oid[i]);
 
 	si->shallow_ref[cmd->index] = 0;
 	oid_array_clear(&extra);
@@ -980,7 +968,7 @@ static const char *push_to_deploy(unsign
 	if (run_command(&child))
 		return "Working directory has staged changes";
 
-	read_tree[3] = sha1_to_hex(sha1);
+	read_tree[3] = hash_to_hex(sha1);
 	child_process_init(&child);
 	child.argv = read_tree;
 	child.env = env->argv;
@@ -997,13 +985,13 @@ static const char *push_to_deploy(unsign
 
 static const char *push_to_checkout_hook = "push-to-checkout";
 
-static const char *push_to_checkout(unsigned char *sha1,
+static const char *push_to_checkout(unsigned char *hash,
 				    struct argv_array *env,
 				    const char *work_tree)
 {
 	argv_array_pushf(env, "GIT_WORK_TREE=%s", absolute_path(work_tree));
 	if (run_hook_le(env->argv, push_to_checkout_hook,
-			sha1_to_hex(sha1), NULL))
+			hash_to_hex(hash), NULL))
 		return "push-to-checkout hook declined";
 	else
 		return NULL;
@@ -1037,6 +1025,7 @@ static const char *update(struct command
 	const char *ret;
 	struct object_id *old_oid = &cmd->old_oid;
 	struct object_id *new_oid = &cmd->new_oid;
+	int do_update_worktree = 0;
 
 	/* only refs/... are allowed */
 	if (!starts_with(name, "refs/") || check_refname_format(name + 5, 0)) {
@@ -1062,9 +1051,8 @@ static const char *update(struct command
 				refuse_unconfigured_deny();
 			return "branch is currently checked out";
 		case DENY_UPDATE_INSTEAD:
-			ret = update_worktree(new_oid->hash);
-			if (ret)
-				return ret;
+			/* pass -- let other checks intervene first */
+			do_update_worktree = 1;
 			break;
 		}
 	}
@@ -1107,8 +1095,8 @@ static const char *update(struct command
 		struct object *old_object, *new_object;
 		struct commit *old_commit, *new_commit;
 
-		old_object = parse_object(old_oid);
-		new_object = parse_object(new_oid);
+		old_object = parse_object(the_repository, old_oid);
+		new_object = parse_object(the_repository, new_oid);
 
 		if (!old_object || !new_object ||
 		    old_object->type != OBJ_COMMIT ||
@@ -1129,9 +1117,15 @@ static const char *update(struct command
 		return "hook declined";
 	}
 
+	if (do_update_worktree) {
+		ret = update_worktree(new_oid->hash);
+		if (ret)
+			return ret;
+	}
+
 	if (is_null_oid(new_oid)) {
 		struct strbuf err = STRBUF_INIT;
-		if (!parse_object(old_oid)) {
+		if (!parse_object(the_repository, old_oid)) {
 			old_oid = NULL;
 			if (ref_exists(name)) {
 				rp_warning("Allowing deletion of corrupt ref.");
@@ -1196,6 +1190,7 @@ static void run_update_post_hook(struct
 	proc.no_stdin = 1;
 	proc.stdout_to_stderr = 1;
 	proc.err = use_sideband ? -1 : 0;
+	proc.trace2_hook_name = "post-update";
 
 	if (!start_command(&proc)) {
 		if (use_sideband)
@@ -1204,17 +1199,12 @@ static void run_update_post_hook(struct
 	}
 }
 
-static void check_aliased_update(struct command *cmd, struct string_list *list)
+static void check_aliased_update_internal(struct command *cmd,
+					  struct string_list *list,
+					  const char *dst_name, int flag)
 {
-	struct strbuf buf = STRBUF_INIT;
-	const char *dst_name;
 	struct string_list_item *item;
 	struct command *dst_cmd;
-	int flag;
-
-	strbuf_addf(&buf, "%s%s", get_git_namespace(), cmd->ref_name);
-	dst_name = resolve_ref_unsafe(buf.buf, 0, NULL, &flag);
-	strbuf_release(&buf);
 
 	if (!(flag & REF_ISSYMREF))
 		return;
@@ -1234,8 +1224,8 @@ static void check_aliased_update(struct
 
 	dst_cmd = (struct command *) item->util;
 
-	if (!oidcmp(&cmd->old_oid, &dst_cmd->old_oid) &&
-	    !oidcmp(&cmd->new_oid, &dst_cmd->new_oid))
+	if (oideq(&cmd->old_oid, &dst_cmd->old_oid) &&
+	    oideq(&cmd->new_oid, &dst_cmd->new_oid))
 		return;
 
 	dst_cmd->skip_update = 1;
@@ -1253,6 +1243,18 @@ static void check_aliased_update(struct
 		"inconsistent aliased update";
 }
 
+static void check_aliased_update(struct command *cmd, struct string_list *list)
+{
+	struct strbuf buf = STRBUF_INIT;
+	const char *dst_name;
+	int flag;
+
+	strbuf_addf(&buf, "%s%s", get_git_namespace(), cmd->ref_name);
+	dst_name = resolve_ref_unsafe(buf.buf, 0, NULL, &flag);
+	check_aliased_update_internal(cmd, list, dst_name, flag);
+	strbuf_release(&buf);
+}
+
 static void check_aliased_updates(struct command *commands)
 {
 	struct command *cmd;
@@ -1575,30 +1577,29 @@ static void queue_commands_from_cert(str
 	}
 }
 
-static struct command *read_head_info(struct oid_array *shallow)
+static struct command *read_head_info(struct packet_reader *reader,
+				      struct oid_array *shallow)
 {
 	struct command *commands = NULL;
 	struct command **p = &commands;
 	for (;;) {
-		char *line;
-		int len, linelen;
+		int linelen;
 
-		line = packet_read_line(0, &len);
-		if (!line)
+		if (packet_reader_read(reader) != PACKET_READ_NORMAL)
 			break;
 
-		if (len > 8 && starts_with(line, "shallow ")) {
+		if (reader->pktlen > 8 && starts_with(reader->line, "shallow ")) {
 			struct object_id oid;
-			if (get_oid_hex(line + 8, &oid))
+			if (get_oid_hex(reader->line + 8, &oid))
 				die("protocol error: expected shallow sha, got '%s'",
-				    line + 8);
+				    reader->line + 8);
 			oid_array_append(shallow, &oid);
 			continue;
 		}
 
-		linelen = strlen(line);
-		if (linelen < len) {
-			const char *feature_list = line + linelen + 1;
+		linelen = strlen(reader->line);
+		if (linelen < reader->pktlen) {
+			const char *feature_list = reader->line + linelen + 1;
 			if (parse_feature_request(feature_list, "report-status"))
 				report_status = 1;
 			if (parse_feature_request(feature_list, "side-band-64k"))
@@ -1613,28 +1614,32 @@ static struct command *read_head_info(st
 				use_push_options = 1;
 		}
 
-		if (!strcmp(line, "push-cert")) {
+		if (!strcmp(reader->line, "push-cert")) {
 			int true_flush = 0;
-			char certbuf[1024];
+			int saved_options = reader->options;
+			reader->options &= ~PACKET_READ_CHOMP_NEWLINE;
 
 			for (;;) {
-				len = packet_read(0, NULL, NULL,
-						  certbuf, sizeof(certbuf), 0);
-				if (!len) {
+				packet_reader_read(reader);
+				if (reader->status == PACKET_READ_FLUSH) {
 					true_flush = 1;
 					break;
 				}
-				if (!strcmp(certbuf, "push-cert-end\n"))
+				if (reader->status != PACKET_READ_NORMAL) {
+					die("protocol error: got an unexpected packet");
+				}
+				if (!strcmp(reader->line, "push-cert-end\n"))
 					break; /* end of cert */
-				strbuf_addstr(&push_cert, certbuf);
+				strbuf_addstr(&push_cert, reader->line);
 			}
+			reader->options = saved_options;
 
 			if (true_flush)
 				break;
 			continue;
 		}
 
-		p = queue_command(p, line, linelen);
+		p = queue_command(p, reader->line, linelen);
 	}
 
 	if (push_cert.len)
@@ -1643,18 +1648,14 @@ static struct command *read_head_info(st
 	return commands;
 }
 
-static void read_push_options(struct string_list *options)
+static void read_push_options(struct packet_reader *reader,
+			      struct string_list *options)
 {
 	while (1) {
-		char *line;
-		int len;
-
-		line = packet_read_line(0, &len);
-
-		if (!line)
+		if (packet_reader_read(reader) != PACKET_READ_NORMAL)
 			break;
 
-		string_list_append(options, line);
+		string_list_append(options, reader->line);
 	}
 }
 
@@ -1805,8 +1806,7 @@ static const char *unpack_with_sideband(
 	return ret;
 }
 
-static void prepare_shallow_update(struct command *commands,
-				   struct shallow_info *si)
+static void prepare_shallow_update(struct shallow_info *si)
 {
 	int i, j, k, bitmap_size = DIV_ROUND_UP(si->ref->nr, 32);
 
@@ -1845,7 +1845,7 @@ static void prepare_shallow_update(struc
 	/*
 	 * keep hooks happy by forcing a temporary shallow file via
 	 * env variable because we can't add --shallow-file to every
-	 * command. check_everything_connected() will be done with
+	 * command. check_connected() will be done with
 	 * true .git/shallow though.
 	 */
 	setenv(GIT_SHALLOW_FILE_ENVIRONMENT, alt_shallow_file, 1);
@@ -1872,7 +1872,7 @@ static void update_shallow_info(struct c
 	si->ref = ref;
 
 	if (shallow_update) {
-		prepare_shallow_update(commands, si);
+		prepare_shallow_update(si);
 		return;
 	}
 
@@ -1930,6 +1930,7 @@ int cmd_receive_pack(int argc, const cha
 	struct oid_array shallow = OID_ARRAY_INIT;
 	struct oid_array ref = OID_ARRAY_INIT;
 	struct shallow_info si;
+	struct packet_reader reader;
 
 	struct option options[] = {
 		OPT__QUIET(&quiet, N_("quiet")),
@@ -1992,12 +1993,16 @@ int cmd_receive_pack(int argc, const cha
 	if (advertise_refs)
 		return 0;
 
-	if ((commands = read_head_info(&shallow)) != NULL) {
+	packet_reader_init(&reader, 0, NULL, 0,
+			   PACKET_READ_CHOMP_NEWLINE |
+			   PACKET_READ_DIE_ON_ERR_PACKET);
+
+	if ((commands = read_head_info(&reader, &shallow)) != NULL) {
 		const char *unpack_status = NULL;
 		struct string_list push_options = STRING_LIST_INIT_DUP;
 
 		if (use_push_options)
-			read_push_options(&push_options);
+			read_push_options(&reader, &push_options);
 		if (!check_cert_push_options(&push_options)) {
 			struct command *cmd;
 			for (cmd = commands; cmd; cmd = cmd->next)
@@ -2034,7 +2039,7 @@ int cmd_receive_pack(int argc, const cha
 			proc.git_cmd = 1;
 			proc.argv = argv_gc_auto;
 
-			close_all_packs(the_repository->objects);
+			close_object_store(the_repository->objects);
 			if (!start_command(&proc)) {
 				if (use_sideband)
 					copy_to_sideband(proc.err, -1, NULL);
diff -pruN 1.2.1+git2.18.0-1/git/builtin/reflog.c 1.2.3+git2.25.1-1/git/builtin/reflog.c
--- 1.2.1+git2.18.0-1/git/builtin/reflog.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/builtin/reflog.c	2020-02-17 04:47:35.000000000 +0000
@@ -1,6 +1,8 @@
 #include "builtin.h"
 #include "config.h"
 #include "lockfile.h"
+#include "object-store.h"
+#include "repository.h"
 #include "commit.h"
 #include "refs.h"
 #include "dir.h"
@@ -8,14 +10,19 @@
 #include "diff.h"
 #include "revision.h"
 #include "reachable.h"
+#include "worktree.h"
 
 /* NEEDSWORK: switch to using parse_options */
 static const char reflog_expire_usage[] =
-"git reflog expire [--expire=<time>] [--expire-unreachable=<time>] [--rewrite] [--updateref] [--stale-fix] [--dry-run | -n] [--verbose] [--all] <refs>...";
+N_("git reflog expire [--expire=<time>] "
+   "[--expire-unreachable=<time>] "
+   "[--rewrite] [--updateref] [--stale-fix] [--dry-run | -n] "
+   "[--verbose] [--all] <refs>...");
 static const char reflog_delete_usage[] =
-"git reflog delete [--rewrite] [--updateref] [--dry-run | -n] [--verbose] <refs>...";
+N_("git reflog delete [--rewrite] [--updateref] "
+   "[--dry-run | -n] [--verbose] <refs>...");
 static const char reflog_exists_usage[] =
-"git reflog exists <ref>";
+N_("git reflog exists <ref>");
 
 static timestamp_t default_reflog_expire;
 static timestamp_t default_reflog_expire_unreachable;
@@ -50,6 +57,7 @@ struct collect_reflog_cb {
 	struct collected_reflog **e;
 	int alloc;
 	int nr;
+	struct worktree *wt;
 };
 
 /* Remember to update object flag allocation in object.h */
@@ -64,7 +72,7 @@ static int tree_is_complete(const struct
 	int complete;
 	struct tree *tree;
 
-	tree = lookup_tree(oid);
+	tree = lookup_tree(the_repository, oid);
 	if (!tree)
 		return 0;
 	if (tree->object.flags & SEEN)
@@ -86,8 +94,8 @@ static int tree_is_complete(const struct
 	init_tree_desc(&desc, tree->buffer, tree->size);
 	complete = 1;
 	while (tree_entry(&desc, &entry)) {
-		if (!has_sha1_file(entry.oid->hash) ||
-		    (S_ISDIR(entry.mode) && !tree_is_complete(entry.oid))) {
+		if (!has_object_file(&entry.oid) ||
+		    (S_ISDIR(entry.mode) && !tree_is_complete(&entry.oid))) {
 			tree->object.flags |= INCOMPLETE;
 			complete = 0;
 		}
@@ -128,7 +136,7 @@ static int commit_is_complete(struct com
 		struct commit_list *parent;
 
 		c = (struct commit *)object_array_pop(&study);
-		if (!c->object.parsed && !parse_object(&c->object.oid))
+		if (!c->object.parsed && !parse_object(the_repository, &c->object.oid))
 			c->object.flags |= INCOMPLETE;
 
 		if (c->object.flags & INCOMPLETE) {
@@ -194,7 +202,7 @@ static int keep_entry(struct commit **it
 
 	if (is_null_oid(oid))
 		return 1;
-	commit = lookup_commit_reference_gently(oid, 1);
+	commit = lookup_commit_reference_gently(the_repository, oid, 1);
 	if (!commit)
 		return 0;
 
@@ -263,7 +271,8 @@ static int unreachable(struct expire_ref
 		if (is_null_oid(oid))
 			return 0;
 
-		commit = lookup_commit_reference_gently(oid, 1);
+		commit = lookup_commit_reference_gently(the_repository, oid,
+							1);
 
 		/* Not a commit -- keep it */
 		if (!commit)
@@ -320,24 +329,39 @@ static int push_tip_to_list(const char *
 	struct commit *tip_commit;
 	if (flags & REF_ISSYMREF)
 		return 0;
-	tip_commit = lookup_commit_reference_gently(oid, 1);
+	tip_commit = lookup_commit_reference_gently(the_repository, oid, 1);
 	if (!tip_commit)
 		return 0;
 	commit_list_insert(tip_commit, list);
 	return 0;
 }
 
+static int is_head(const char *refname)
+{
+	switch (ref_type(refname)) {
+	case REF_TYPE_OTHER_PSEUDOREF:
+	case REF_TYPE_MAIN_PSEUDOREF:
+		if (parse_worktree_ref(refname, NULL, NULL, &refname))
+			BUG("not a worktree ref: %s", refname);
+		break;
+	default:
+		break;
+	}
+	return !strcmp(refname, "HEAD");
+}
+
 static void reflog_expiry_prepare(const char *refname,
 				  const struct object_id *oid,
 				  void *cb_data)
 {
 	struct expire_reflog_policy_cb *cb = cb_data;
 
-	if (!cb->cmd.expire_unreachable || !strcmp(refname, "HEAD")) {
+	if (!cb->cmd.expire_unreachable || is_head(refname)) {
 		cb->tip_commit = NULL;
 		cb->unreachable_expire_kind = UE_HEAD;
 	} else {
-		cb->tip_commit = lookup_commit_reference_gently(oid, 1);
+		cb->tip_commit = lookup_commit_reference_gently(the_repository,
+								oid, 1);
 		if (!cb->tip_commit)
 			cb->unreachable_expire_kind = UE_ALWAYS;
 		else
@@ -384,8 +408,19 @@ static int collect_reflog(const char *re
 {
 	struct collected_reflog *e;
 	struct collect_reflog_cb *cb = cb_data;
+	struct strbuf newref = STRBUF_INIT;
+
+	/*
+	 * Avoid collecting the same shared ref multiple times because
+	 * they are available via all worktrees.
+	 */
+	if (!cb->wt->is_current && ref_type(ref) == REF_TYPE_NORMAL)
+		return 0;
+
+	strbuf_worktree_ref(cb->wt, &newref, ref);
+	FLEX_ALLOC_STR(e, reflog, newref.buf);
+	strbuf_release(&newref);
 
-	FLEX_ALLOC_STR(e, reflog, ref);
 	oidcpy(&e->oid, oid);
 	ALLOC_GROW(cb->e, cb->nr + 1, cb->alloc);
 	cb->e[cb->nr++] = e;
@@ -508,7 +543,7 @@ static int cmd_reflog_expire(int argc, c
 {
 	struct expire_reflog_policy_cb cb;
 	timestamp_t now = time(NULL);
-	int i, status, do_all;
+	int i, status, do_all, all_worktrees = 1;
 	int explicit_expiry = 0;
 	unsigned int flags = 0;
 
@@ -545,6 +580,8 @@ static int cmd_reflog_expire(int argc, c
 			flags |= EXPIRE_REFLOGS_UPDATE_REF;
 		else if (!strcmp(arg, "--all"))
 			do_all = 1;
+		else if (!strcmp(arg, "--single-worktree"))
+			all_worktrees = 0;
 		else if (!strcmp(arg, "--verbose"))
 			flags |= EXPIRE_REFLOGS_VERBOSE;
 		else if (!strcmp(arg, "--")) {
@@ -552,7 +589,7 @@ static int cmd_reflog_expire(int argc, c
 			break;
 		}
 		else if (arg[0] == '-')
-			usage(reflog_expire_usage);
+			usage(_(reflog_expire_usage));
 		else
 			break;
 	}
@@ -563,9 +600,9 @@ static int cmd_reflog_expire(int argc, c
 	 * from reflog if the repository was pruned with older git.
 	 */
 	if (cb.cmd.stalefix) {
-		init_revisions(&cb.cmd.revs, prefix);
+		repo_init_revisions(the_repository, &cb.cmd.revs, prefix);
 		if (flags & EXPIRE_REFLOGS_VERBOSE)
-			printf("Marking reachable objects...");
+			printf(_("Marking reachable objects..."));
 		mark_reachable_objects(&cb.cmd.revs, 0, 0, NULL);
 		if (flags & EXPIRE_REFLOGS_VERBOSE)
 			putchar('\n');
@@ -573,10 +610,19 @@ static int cmd_reflog_expire(int argc, c
 
 	if (do_all) {
 		struct collect_reflog_cb collected;
+		struct worktree **worktrees, **p;
 		int i;
 
 		memset(&collected, 0, sizeof(collected));
-		for_each_reflog(collect_reflog, &collected);
+		worktrees = get_worktrees(0);
+		for (p = worktrees; *p; p++) {
+			if (!all_worktrees && !(*p)->is_current)
+				continue;
+			collected.wt = *p;
+			refs_for_each_reflog(get_worktree_ref_store(*p),
+					     collect_reflog, &collected);
+		}
+		free_worktrees(worktrees);
 		for (i = 0; i < collected.nr; i++) {
 			struct collected_reflog *e = collected.e[i];
 			set_reflog_expiry_param(&cb.cmd, explicit_expiry, e->reflog);
@@ -594,7 +640,7 @@ static int cmd_reflog_expire(int argc, c
 		char *ref;
 		struct object_id oid;
 		if (!dwim_log(argv[i], strlen(argv[i]), &oid, &ref)) {
-			status |= error("%s points nowhere!", argv[i]);
+			status |= error(_("%s points nowhere!"), argv[i]);
 			continue;
 		}
 		set_reflog_expiry_param(&cb.cmd, explicit_expiry, ref);
@@ -640,13 +686,13 @@ static int cmd_reflog_delete(int argc, c
 			break;
 		}
 		else if (arg[0] == '-')
-			usage(reflog_delete_usage);
+			usage(_(reflog_delete_usage));
 		else
 			break;
 	}
 
 	if (argc - i < 1)
-		return error("Nothing to delete?");
+		return error(_("no reflog specified to delete"));
 
 	for ( ; i < argc; i++) {
 		const char *spec = strstr(argv[i], "@{");
@@ -655,12 +701,12 @@ static int cmd_reflog_delete(int argc, c
 		int recno;
 
 		if (!spec) {
-			status |= error("Not a reflog: %s", argv[i]);
+			status |= error(_("not a reflog: %s"), argv[i]);
 			continue;
 		}
 
 		if (!dwim_log(argv[i], spec - argv[i], &oid, &ref)) {
-			status |= error("no reflog for '%s'", argv[i]);
+			status |= error(_("no reflog for '%s'"), argv[i]);
 			continue;
 		}
 
@@ -695,7 +741,7 @@ static int cmd_reflog_exists(int argc, c
 			break;
 		}
 		else if (arg[0] == '-')
-			usage(reflog_exists_usage);
+			usage(_(reflog_exists_usage));
 		else
 			break;
 	}
@@ -703,10 +749,10 @@ static int cmd_reflog_exists(int argc, c
 	start = i;
 
 	if (argc - start != 1)
-		usage(reflog_exists_usage);
+		usage(_(reflog_exists_usage));
 
 	if (check_refname_format(argv[start], REFNAME_ALLOW_ONELEVEL))
-		die("invalid ref format: %s", argv[start]);
+		die(_("invalid ref format: %s"), argv[start]);
 	return !reflog_exists(argv[start]);
 }
 
@@ -715,12 +761,12 @@ static int cmd_reflog_exists(int argc, c
  */
 
 static const char reflog_usage[] =
-"git reflog [ show | expire | delete | exists ]";
+N_("git reflog [ show | expire | delete | exists ]");
 
 int cmd_reflog(int argc, const char **argv, const char *prefix)
 {
 	if (argc > 1 && !strcmp(argv[1], "-h"))
-		usage(reflog_usage);
+		usage(_(reflog_usage));
 
 	/* With no command, we default to showing it. */
 	if (argc < 2 || *argv[1] == '-')
diff -pruN 1.2.1+git2.18.0-1/git/builtin/remote.c 1.2.3+git2.25.1-1/git/builtin/remote.c
--- 1.2.1+git2.18.0-1/git/builtin/remote.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/builtin/remote.c	2020-02-17 04:47:35.000000000 +0000
@@ -8,7 +8,9 @@
 #include "run-command.h"
 #include "refs.h"
 #include "refspec.h"
+#include "object-store.h"
 #include "argv-array.h"
+#include "commit-reach.h"
 
 static const char * const builtin_remote_usage[] = {
 	N_("git remote [-v | --verbose]"),
@@ -167,7 +169,7 @@ static int add(int argc, const char **ar
 		OPT_STRING_LIST('t', "track", &track, N_("branch"),
 				N_("branch(es) to track")),
 		OPT_STRING('m', "master", &master, N_("branch"), N_("master branch")),
-		{ OPTION_CALLBACK, 0, "mirror", &mirror, N_("push|fetch"),
+		{ OPTION_CALLBACK, 0, "mirror", &mirror, "(push|fetch)",
 			N_("set up remote as a mirror to push to or fetch from"),
 			PARSE_OPT_OPTARG | PARSE_OPT_COMP_ARG, parse_mirror_opt },
 		OPT_END()
@@ -411,7 +413,7 @@ static int get_push_ref_states(const str
 
 		if (is_null_oid(&ref->new_oid)) {
 			info->status = PUSH_STATUS_DELETE;
-		} else if (!oidcmp(&ref->old_oid, &ref->new_oid))
+		} else if (oideq(&ref->old_oid, &ref->new_oid))
 			info->status = PUSH_STATUS_UPTODATE;
 		else if (is_null_oid(&ref->old_oid))
 			info->status = PUSH_STATUS_CREATE;
@@ -565,7 +567,7 @@ static int read_remote_branches(const ch
 
 	strbuf_addf(&buf, "refs/remotes/%s/", rename->old_name);
 	if (starts_with(refname, buf.buf)) {
-		item = string_list_append(rename->remote_branches, xstrdup(refname));
+		item = string_list_append(rename->remote_branches, refname);
 		symref = resolve_ref_unsafe(refname, RESOLVE_REF_READING,
 					    NULL, &flag);
 		if (symref && (flag & REF_ISSYMREF))
@@ -611,7 +613,7 @@ static int mv(int argc, const char **arg
 	struct remote *oldremote, *newremote;
 	struct strbuf buf = STRBUF_INIT, buf2 = STRBUF_INIT, buf3 = STRBUF_INIT,
 		old_remote_context = STRBUF_INIT;
-	struct string_list remote_branches = STRING_LIST_INIT_NODUP;
+	struct string_list remote_branches = STRING_LIST_INIT_DUP;
 	struct rename_info rename;
 	int i, refspec_updated = 0;
 
@@ -624,7 +626,7 @@ static int mv(int argc, const char **arg
 
 	oldremote = remote_get(rename.old_name);
 	if (!remote_is_configured(oldremote, 1))
-		die(_("No such remote: %s"), rename.old_name);
+		die(_("No such remote: '%s'"), rename.old_name);
 
 	if (!strcmp(rename.old_name, rename.new_name) && oldremote->origin != REMOTE_CONFIG)
 		return migrate_file(oldremote);
@@ -691,9 +693,8 @@ static int mv(int argc, const char **arg
 	for (i = 0; i < remote_branches.nr; i++) {
 		struct string_list_item *item = remote_branches.items + i;
 		int flag = 0;
-		struct object_id oid;
 
-		read_ref_full(item->string, RESOLVE_REF_READING, &oid, &flag);
+		read_ref_full(item->string, RESOLVE_REF_READING, NULL, &flag);
 		if (!(flag & REF_ISSYMREF))
 			continue;
 		if (delete_ref(NULL, item->string, NULL, REF_NO_DEREF))
@@ -733,6 +734,7 @@ static int mv(int argc, const char **arg
 		if (create_symref(buf.buf, buf2.buf, buf3.buf))
 			die(_("creating '%s' failed"), buf.buf);
 	}
+	string_list_clear(&remote_branches, 1);
 	return 0;
 }
 
@@ -759,7 +761,7 @@ static int rm(int argc, const char **arg
 
 	remote = remote_get(argv[1]);
 	if (!remote_is_configured(remote, 1))
-		die(_("No such remote: %s"), argv[1]);
+		die(_("No such remote: '%s'"), argv[1]);
 
 	known_remotes.to_delete = remote;
 	for_each_remote(add_known_remote, &known_remotes);
@@ -858,7 +860,7 @@ static int get_remote_ref_states(const c
 
 	states->remote = remote_get(name);
 	if (!states->remote)
-		return error(_("No such remote: %s"), name);
+		return error(_("No such remote: '%s'"), name);
 
 	read_branches();
 
@@ -1404,7 +1406,7 @@ static int update(int argc, const char *
 	return retval;
 }
 
-static int remove_all_fetch_refspecs(const char *remote, const char *key)
+static int remove_all_fetch_refspecs(const char *key)
 {
 	return git_config_set_multivar_gently(key, NULL, NULL, 1);
 }
@@ -1434,7 +1436,7 @@ static int set_remote_branches(const cha
 	if (!remote_is_configured(remote, 1))
 		die(_("No such remote '%s'"), remotename);
 
-	if (!add_mode && remove_all_fetch_refspecs(remotename, key.buf)) {
+	if (!add_mode && remove_all_fetch_refspecs(key.buf)) {
 		strbuf_release(&key);
 		return 1;
 	}
diff -pruN 1.2.1+git2.18.0-1/git/builtin/repack.c 1.2.3+git2.25.1-1/git/builtin/repack.c
--- 1.2.1+git2.18.0-1/git/builtin/repack.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/builtin/repack.c	2020-02-17 04:47:35.000000000 +0000
@@ -8,10 +8,15 @@
 #include "strbuf.h"
 #include "string-list.h"
 #include "argv-array.h"
+#include "midx.h"
+#include "packfile.h"
+#include "object-store.h"
+#include "promisor-remote.h"
 
 static int delta_base_offset = 1;
 static int pack_kept_objects = -1;
-static int write_bitmaps;
+static int write_bitmaps = -1;
+static int use_delta_islands;
 static char *packdir, *packtmp;
 
 static const char *const git_repack_usage[] = {
@@ -40,6 +45,10 @@ static int repack_config(const char *var
 		write_bitmaps = git_config_bool(var, value);
 		return 0;
 	}
+	if (!strcmp(var, "repack.usedeltaislands")) {
+		use_delta_islands = git_config_bool(var, value);
+		return 0;
+	}
 	return git_default_config(var, value, cb);
 }
 
@@ -83,7 +92,7 @@ static void remove_pack_on_signal(int si
 
 /*
  * Adds all packs hex strings to the fname list, which do not
- * have a corresponding .keep or .promisor file. These packs are not to
+ * have a corresponding .keep file. These packs are not to
  * be kept if we are going to pack everything into one file.
  */
 static void get_non_kept_pack_filenames(struct string_list *fname_list,
@@ -111,8 +120,7 @@ static void get_non_kept_pack_filenames(
 
 		fname = xmemdupz(e->d_name, len);
 
-		if (!file_exists(mkpath("%s/%s.keep", packdir, fname)) &&
-		    !file_exists(mkpath("%s/%s.promisor", packdir, fname)))
+		if (!file_exists(mkpath("%s/%s.keep", packdir, fname)))
 			string_list_append_nodup(fname_list, fname);
 		else
 			free(fname);
@@ -122,20 +130,128 @@ static void get_non_kept_pack_filenames(
 
 static void remove_redundant_pack(const char *dir_name, const char *base_name)
 {
-	const char *exts[] = {".pack", ".idx", ".keep", ".bitmap"};
-	int i;
 	struct strbuf buf = STRBUF_INIT;
-	size_t plen;
+	strbuf_addf(&buf, "%s/%s.pack", dir_name, base_name);
+	unlink_pack_path(buf.buf, 1);
+	strbuf_release(&buf);
+}
 
-	strbuf_addf(&buf, "%s/%s", dir_name, base_name);
-	plen = buf.len;
+struct pack_objects_args {
+	const char *window;
+	const char *window_memory;
+	const char *depth;
+	const char *threads;
+	const char *max_pack_size;
+	int no_reuse_delta;
+	int no_reuse_object;
+	int quiet;
+	int local;
+};
 
-	for (i = 0; i < ARRAY_SIZE(exts); i++) {
-		strbuf_setlen(&buf, plen);
-		strbuf_addstr(&buf, exts[i]);
-		unlink(buf.buf);
+static void prepare_pack_objects(struct child_process *cmd,
+				 const struct pack_objects_args *args)
+{
+	argv_array_push(&cmd->args, "pack-objects");
+	if (args->window)
+		argv_array_pushf(&cmd->args, "--window=%s", args->window);
+	if (args->window_memory)
+		argv_array_pushf(&cmd->args, "--window-memory=%s", args->window_memory);
+	if (args->depth)
+		argv_array_pushf(&cmd->args, "--depth=%s", args->depth);
+	if (args->threads)
+		argv_array_pushf(&cmd->args, "--threads=%s", args->threads);
+	if (args->max_pack_size)
+		argv_array_pushf(&cmd->args, "--max-pack-size=%s", args->max_pack_size);
+	if (args->no_reuse_delta)
+		argv_array_pushf(&cmd->args, "--no-reuse-delta");
+	if (args->no_reuse_object)
+		argv_array_pushf(&cmd->args, "--no-reuse-object");
+	if (args->local)
+		argv_array_push(&cmd->args,  "--local");
+	if (args->quiet)
+		argv_array_push(&cmd->args,  "--quiet");
+	if (delta_base_offset)
+		argv_array_push(&cmd->args,  "--delta-base-offset");
+	argv_array_push(&cmd->args, packtmp);
+	cmd->git_cmd = 1;
+	cmd->out = -1;
+}
+
+/*
+ * Write oid to the given struct child_process's stdin, starting it first if
+ * necessary.
+ */
+static int write_oid(const struct object_id *oid, struct packed_git *pack,
+		     uint32_t pos, void *data)
+{
+	struct child_process *cmd = data;
+
+	if (cmd->in == -1) {
+		if (start_command(cmd))
+			die(_("could not start pack-objects to repack promisor objects"));
 	}
-	strbuf_release(&buf);
+
+	xwrite(cmd->in, oid_to_hex(oid), the_hash_algo->hexsz);
+	xwrite(cmd->in, "\n", 1);
+	return 0;
+}
+
+static void repack_promisor_objects(const struct pack_objects_args *args,
+				    struct string_list *names)
+{
+	struct child_process cmd = CHILD_PROCESS_INIT;
+	FILE *out;
+	struct strbuf line = STRBUF_INIT;
+
+	prepare_pack_objects(&cmd, args);
+	cmd.in = -1;
+
+	/*
+	 * NEEDSWORK: Giving pack-objects only the OIDs without any ordering
+	 * hints may result in suboptimal deltas in the resulting pack. See if
+	 * the OIDs can be sent with fake paths such that pack-objects can use a
+	 * {type -> existing pack order} ordering when computing deltas instead
+	 * of a {type -> size} ordering, which may produce better deltas.
+	 */
+	for_each_packed_object(write_oid, &cmd,
+			       FOR_EACH_OBJECT_PROMISOR_ONLY);
+
+	if (cmd.in == -1)
+		/* No packed objects; cmd was never started */
+		return;
+
+	close(cmd.in);
+
+	out = xfdopen(cmd.out, "r");
+	while (strbuf_getline_lf(&line, out) != EOF) {
+		char *promisor_name;
+		int fd;
+		if (line.len != the_hash_algo->hexsz)
+			die(_("repack: Expecting full hex object ID lines only from pack-objects."));
+		string_list_append(names, line.buf);
+
+		/*
+		 * pack-objects creates the .pack and .idx files, but not the
+		 * .promisor file. Create the .promisor file, which is empty.
+		 *
+		 * NEEDSWORK: fetch-pack sometimes generates non-empty
+		 * .promisor files containing the ref names and associated
+		 * hashes at the point of generation of the corresponding
+		 * packfile, but this would not preserve their contents. Maybe
+		 * concatenate the contents of all .promisor files instead of
+		 * just creating a new empty file.
+		 */
+		promisor_name = mkpathdup("%s-%s.promisor", packtmp,
+					  line.buf);
+		fd = open(promisor_name, O_CREAT|O_EXCL|O_WRONLY, 0600);
+		if (fd < 0)
+			die_errno(_("unable to create '%s'"), promisor_name);
+		close(fd);
+		free(promisor_name);
+	}
+	fclose(out);
+	if (finish_command(&cmd))
+		die(_("could not finish pack-objects to repack promisor objects"));
 }
 
 #define ALL_INTO_ONE 1
@@ -150,6 +266,7 @@ int cmd_repack(int argc, const char **ar
 		{".pack"},
 		{".idx"},
 		{".bitmap", 1},
+		{".promisor", 1},
 	};
 	struct child_process cmd = CHILD_PROCESS_INIT;
 	struct string_list_item *item;
@@ -165,15 +282,10 @@ int cmd_repack(int argc, const char **ar
 	int delete_redundant = 0;
 	const char *unpack_unreachable = NULL;
 	int keep_unreachable = 0;
-	const char *window = NULL, *window_memory = NULL;
-	const char *depth = NULL;
-	const char *threads = NULL;
-	const char *max_pack_size = NULL;
 	struct string_list keep_pack_list = STRING_LIST_INIT_NODUP;
-	int no_reuse_delta = 0, no_reuse_object = 0;
 	int no_update_server_info = 0;
-	int quiet = 0;
-	int local = 0;
+	int midx_cleared = 0;
+	struct pack_objects_args po_args = {NULL};
 
 	struct option builtin_repack_options[] = {
 		OPT_BIT('a', NULL, &pack_everything,
@@ -183,30 +295,32 @@ int cmd_repack(int argc, const char **ar
 				   LOOSEN_UNREACHABLE | ALL_INTO_ONE),
 		OPT_BOOL('d', NULL, &delete_redundant,
 				N_("remove redundant packs, and run git-prune-packed")),
-		OPT_BOOL('f', NULL, &no_reuse_delta,
+		OPT_BOOL('f', NULL, &po_args.no_reuse_delta,
 				N_("pass --no-reuse-delta to git-pack-objects")),
-		OPT_BOOL('F', NULL, &no_reuse_object,
+		OPT_BOOL('F', NULL, &po_args.no_reuse_object,
 				N_("pass --no-reuse-object to git-pack-objects")),
 		OPT_BOOL('n', NULL, &no_update_server_info,
 				N_("do not run git-update-server-info")),
-		OPT__QUIET(&quiet, N_("be quiet")),
-		OPT_BOOL('l', "local", &local,
+		OPT__QUIET(&po_args.quiet, N_("be quiet")),
+		OPT_BOOL('l', "local", &po_args.local,
 				N_("pass --local to git-pack-objects")),
 		OPT_BOOL('b', "write-bitmap-index", &write_bitmaps,
 				N_("write bitmap index")),
+		OPT_BOOL('i', "delta-islands", &use_delta_islands,
+				N_("pass --delta-islands to git-pack-objects")),
 		OPT_STRING(0, "unpack-unreachable", &unpack_unreachable, N_("approxidate"),
 				N_("with -A, do not loosen objects older than this")),
 		OPT_BOOL('k', "keep-unreachable", &keep_unreachable,
 				N_("with -a, repack unreachable objects")),
-		OPT_STRING(0, "window", &window, N_("n"),
+		OPT_STRING(0, "window", &po_args.window, N_("n"),
 				N_("size of the window used for delta compression")),
-		OPT_STRING(0, "window-memory", &window_memory, N_("bytes"),
+		OPT_STRING(0, "window-memory", &po_args.window_memory, N_("bytes"),
 				N_("same as the above, but limit memory size instead of entries count")),
-		OPT_STRING(0, "depth", &depth, N_("n"),
+		OPT_STRING(0, "depth", &po_args.depth, N_("n"),
 				N_("limits the maximum delta depth")),
-		OPT_STRING(0, "threads", &threads, N_("n"),
+		OPT_STRING(0, "threads", &po_args.threads, N_("n"),
 				N_("limits the maximum number of threads")),
-		OPT_STRING(0, "max-pack-size", &max_pack_size, N_("bytes"),
+		OPT_STRING(0, "max-pack-size", &po_args.max_pack_size, N_("bytes"),
 				N_("maximum size of each packfile")),
 		OPT_BOOL(0, "pack-kept-objects", &pack_kept_objects,
 				N_("repack objects in packs marked with .keep")),
@@ -227,8 +341,13 @@ int cmd_repack(int argc, const char **ar
 	    (unpack_unreachable || (pack_everything & LOOSEN_UNREACHABLE)))
 		die(_("--keep-unreachable and -A are incompatible"));
 
+	if (write_bitmaps < 0) {
+		if (!(pack_everything & ALL_INTO_ONE) ||
+		    !is_bare_repository())
+			write_bitmaps = 0;
+	}
 	if (pack_kept_objects < 0)
-		pack_kept_objects = write_bitmaps;
+		pack_kept_objects = write_bitmaps > 0;
 
 	if (write_bitmaps && !(pack_everything & ALL_INTO_ONE))
 		die(_(incremental_bitmap_conflict_error));
@@ -238,7 +357,8 @@ int cmd_repack(int argc, const char **ar
 
 	sigchain_push_common(remove_pack_on_signal);
 
-	argv_array_push(&cmd.args, "pack-objects");
+	prepare_pack_objects(&cmd, &po_args);
+
 	argv_array_push(&cmd.args, "--keep-true-parents");
 	if (!pack_kept_objects)
 		argv_array_push(&cmd.args, "--honor-pack-keep");
@@ -249,28 +369,20 @@ int cmd_repack(int argc, const char **ar
 	argv_array_push(&cmd.args, "--all");
 	argv_array_push(&cmd.args, "--reflog");
 	argv_array_push(&cmd.args, "--indexed-objects");
-	if (repository_format_partial_clone)
+	if (has_promisor_remote())
 		argv_array_push(&cmd.args, "--exclude-promisor-objects");
-	if (window)
-		argv_array_pushf(&cmd.args, "--window=%s", window);
-	if (window_memory)
-		argv_array_pushf(&cmd.args, "--window-memory=%s", window_memory);
-	if (depth)
-		argv_array_pushf(&cmd.args, "--depth=%s", depth);
-	if (threads)
-		argv_array_pushf(&cmd.args, "--threads=%s", threads);
-	if (max_pack_size)
-		argv_array_pushf(&cmd.args, "--max-pack-size=%s", max_pack_size);
-	if (no_reuse_delta)
-		argv_array_pushf(&cmd.args, "--no-reuse-delta");
-	if (no_reuse_object)
-		argv_array_pushf(&cmd.args, "--no-reuse-object");
-	if (write_bitmaps)
+	if (write_bitmaps > 0)
 		argv_array_push(&cmd.args, "--write-bitmap-index");
+	else if (write_bitmaps < 0)
+		argv_array_push(&cmd.args, "--write-bitmap-index-quiet");
+	if (use_delta_islands)
+		argv_array_push(&cmd.args, "--delta-islands");
 
 	if (pack_everything & ALL_INTO_ONE) {
 		get_non_kept_pack_filenames(&existing_packs, &keep_pack_list);
 
+		repack_promisor_objects(&po_args, &names);
+
 		if (existing_packs.nr && delete_redundant) {
 			if (unpack_unreachable) {
 				argv_array_pushf(&cmd.args,
@@ -292,17 +404,6 @@ int cmd_repack(int argc, const char **ar
 		argv_array_push(&cmd.args, "--incremental");
 	}
 
-	if (local)
-		argv_array_push(&cmd.args,  "--local");
-	if (quiet)
-		argv_array_push(&cmd.args,  "--quiet");
-	if (delta_base_offset)
-		argv_array_push(&cmd.args,  "--delta-base-offset");
-
-	argv_array_push(&cmd.args, packtmp);
-
-	cmd.git_cmd = 1;
-	cmd.out = -1;
 	cmd.no_stdin = 1;
 
 	ret = start_command(&cmd);
@@ -311,8 +412,8 @@ int cmd_repack(int argc, const char **ar
 
 	out = xfdopen(cmd.out, "r");
 	while (strbuf_getline_lf(&line, out) != EOF) {
-		if (line.len != 40)
-			die("repack: Expecting 40 character sha1 lines only from pack-objects.");
+		if (line.len != the_hash_algo->hexsz)
+			die(_("repack: Expecting full hex object ID lines only from pack-objects."));
 		string_list_append(&names, line.buf);
 	}
 	fclose(out);
@@ -320,8 +421,10 @@ int cmd_repack(int argc, const char **ar
 	if (ret)
 		return ret;
 
-	if (!names.nr && !quiet)
-		printf("Nothing new to pack.\n");
+	if (!names.nr && !po_args.quiet)
+		printf_ln(_("Nothing new to pack."));
+
+	close_object_store(the_repository->objects);
 
 	/*
 	 * Ok we have prepared all new packfiles.
@@ -333,6 +436,12 @@ int cmd_repack(int argc, const char **ar
 	for_each_string_list_item(item, &names) {
 		for (ext = 0; ext < ARRAY_SIZE(exts); ext++) {
 			char *fname, *fname_old;
+
+			if (!midx_cleared) {
+				clear_midx_file(the_repository);
+				midx_cleared = 1;
+			}
+
 			fname = mkpathdup("%s/pack-%s%s", packdir,
 						item->string, exts[ext].name);
 			if (!file_exists(fname)) {
@@ -374,13 +483,13 @@ int cmd_repack(int argc, const char **ar
 		if (rollback_failure.nr) {
 			int i;
 			fprintf(stderr,
-				"WARNING: Some packs in use have been renamed by\n"
-				"WARNING: prefixing old- to their name, in order to\n"
-				"WARNING: replace them with the new version of the\n"
-				"WARNING: file.  But the operation failed, and the\n"
-				"WARNING: attempt to rename them back to their\n"
-				"WARNING: original names also failed.\n"
-				"WARNING: Please rename them in %s manually:\n", packdir);
+				_("WARNING: Some packs in use have been renamed by\n"
+				  "WARNING: prefixing old- to their name, in order to\n"
+				  "WARNING: replace them with the new version of the\n"
+				  "WARNING: file.  But the operation failed, and the\n"
+				  "WARNING: attempt to rename them back to their\n"
+				  "WARNING: original names also failed.\n"
+				  "WARNING: Please rename them in %s manually:\n"), packdir);
 			for (i = 0; i < rollback_failure.nr; i++)
 				fprintf(stderr, "WARNING:   old-%s -> %s\n",
 					rollback_failure.items[i].string,
@@ -429,26 +538,39 @@ int cmd_repack(int argc, const char **ar
 
 	/* End of pack replacement. */
 
+	reprepare_packed_git(the_repository);
+
 	if (delete_redundant) {
+		const int hexsz = the_hash_algo->hexsz;
 		int opts = 0;
 		string_list_sort(&names);
 		for_each_string_list_item(item, &existing_packs) {
 			char *sha1;
 			size_t len = strlen(item->string);
-			if (len < 40)
+			if (len < hexsz)
 				continue;
-			sha1 = item->string + len - 40;
+			sha1 = item->string + len - hexsz;
 			if (!string_list_has_string(&names, sha1))
 				remove_redundant_pack(packdir, item->string);
 		}
-		if (!quiet && isatty(2))
+		if (!po_args.quiet && isatty(2))
 			opts |= PRUNE_PACKED_VERBOSE;
 		prune_packed_objects(opts);
+
+		if (!keep_unreachable &&
+		    (!(pack_everything & LOOSEN_UNREACHABLE) ||
+		     unpack_unreachable) &&
+		    is_repository_shallow(the_repository))
+			prune_shallow(PRUNE_QUICK);
 	}
 
 	if (!no_update_server_info)
 		update_server_info(0);
 	remove_temporary_files();
+
+	if (git_env_bool(GIT_TEST_MULTI_PACK_INDEX, 0))
+		write_midx_file(get_object_directory(), 0);
+
 	string_list_clear(&names, 0);
 	string_list_clear(&rollback, 0);
 	string_list_clear(&existing_packs, 0);
diff -pruN 1.2.1+git2.18.0-1/git/builtin/replace.c 1.2.3+git2.25.1-1/git/builtin/replace.c
--- 1.2.1+git2.18.0-1/git/builtin/replace.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/builtin/replace.c	2020-02-17 04:47:35.000000000 +0000
@@ -39,7 +39,8 @@ struct show_data {
 	enum replace_format format;
 };
 
-static int show_reference(const char *refname, const struct object_id *oid,
+static int show_reference(struct repository *r, const char *refname,
+			  const struct object_id *oid,
 			  int flag, void *cb_data)
 {
 	struct show_data *data = cb_data;
@@ -54,11 +55,10 @@ static int show_reference(const char *re
 			enum object_type obj_type, repl_type;
 
 			if (get_oid(refname, &object))
-				return error("Failed to resolve '%s' as a valid ref.", refname);
+				return error(_("failed to resolve '%s' as a valid ref"), refname);
 
-			obj_type = oid_object_info(the_repository, &object,
-						   NULL);
-			repl_type = oid_object_info(the_repository, oid, NULL);
+			obj_type = oid_object_info(r, &object, NULL);
+			repl_type = oid_object_info(r, oid, NULL);
 
 			printf("%s (%s) -> %s (%s)\n", refname, type_name(obj_type),
 			       oid_to_hex(oid), type_name(repl_type));
@@ -82,9 +82,13 @@ static int list_replace_refs(const char
 		data.format = REPLACE_FORMAT_MEDIUM;
 	else if (!strcmp(format, "long"))
 		data.format = REPLACE_FORMAT_LONG;
+	/*
+	 * Please update _git_replace() in git-completion.bash when
+	 * you add new format
+	 */
 	else
-		return error("invalid replace format '%s'\n"
-			     "valid formats are 'short', 'medium' and 'long'\n",
+		return error(_("invalid replace format '%s'\n"
+			       "valid formats are 'short', 'medium' and 'long'"),
 			     format);
 
 	for_each_replace_ref(the_repository, show_reference, (void *)&data);
@@ -108,7 +112,7 @@ static int for_each_replace_name(const c
 
 	for (p = argv; *p; p++) {
 		if (get_oid(*p, &oid)) {
-			error("Failed to resolve '%s' as a valid ref.", *p);
+			error("failed to resolve '%s' as a valid ref", *p);
 			had_error = 1;
 			continue;
 		}
@@ -118,7 +122,7 @@ static int for_each_replace_name(const c
 		full_hex = ref.buf + base_len;
 
 		if (read_ref(ref.buf, &oid)) {
-			error("replace ref '%s' not found.", full_hex);
+			error(_("replace ref '%s' not found"), full_hex);
 			had_error = 1;
 			continue;
 		}
@@ -134,7 +138,7 @@ static int delete_replace_ref(const char
 {
 	if (delete_ref(NULL, ref, oid, 0))
 		return 1;
-	printf("Deleted replace ref '%s'\n", name);
+	printf_ln(_("Deleted replace ref '%s'"), name);
 	return 0;
 }
 
@@ -146,12 +150,12 @@ static int check_ref_valid(struct object
 	strbuf_reset(ref);
 	strbuf_addf(ref, "%s%s", git_replace_ref_base, oid_to_hex(object));
 	if (check_refname_format(ref->buf, 0))
-		return error("'%s' is not a valid ref name.", ref->buf);
+		return error(_("'%s' is not a valid ref name"), ref->buf);
 
 	if (read_ref(ref->buf, prev))
 		oidclr(prev);
 	else if (!force)
-		return error("replace ref '%s' already exists", ref->buf);
+		return error(_("replace ref '%s' already exists"), ref->buf);
 	return 0;
 }
 
@@ -171,10 +175,10 @@ static int replace_object_oid(const char
 	obj_type = oid_object_info(the_repository, object, NULL);
 	repl_type = oid_object_info(the_repository, repl, NULL);
 	if (!force && obj_type != repl_type)
-		return error("Objects must be of the same type.\n"
-			     "'%s' points to a replaced object of type '%s'\n"
-			     "while '%s' points to a replacement object of "
-			     "type '%s'.",
+		return error(_("Objects must be of the same type.\n"
+			       "'%s' points to a replaced object of type '%s'\n"
+			       "while '%s' points to a replacement object of "
+			       "type '%s'."),
 			     object_ref, type_name(obj_type),
 			     replace_ref, type_name(repl_type));
 
@@ -200,10 +204,10 @@ static int replace_object(const char *ob
 	struct object_id object, repl;
 
 	if (get_oid(object_ref, &object))
-		return error("Failed to resolve '%s' as a valid ref.",
+		return error(_("failed to resolve '%s' as a valid ref"),
 			     object_ref);
 	if (get_oid(replace_ref, &repl))
-		return error("Failed to resolve '%s' as a valid ref.",
+		return error(_("failed to resolve '%s' as a valid ref"),
 			     replace_ref);
 
 	return replace_object_oid(object_ref, &object, replace_ref, &repl, force);
@@ -222,7 +226,7 @@ static int export_object(const struct ob
 
 	fd = open(filename, O_WRONLY | O_CREAT | O_TRUNC, 0666);
 	if (fd < 0)
-		return error_errno("unable to open %s for writing", filename);
+		return error_errno(_("unable to open %s for writing"), filename);
 
 	argv_array_push(&cmd.args, "--no-replace-objects");
 	argv_array_push(&cmd.args, "cat-file");
@@ -235,7 +239,7 @@ static int export_object(const struct ob
 	cmd.out = fd;
 
 	if (run_command(&cmd))
-		return error("cat-file reported failure");
+		return error(_("cat-file reported failure"));
 	return 0;
 }
 
@@ -251,7 +255,7 @@ static int import_object(struct object_i
 
 	fd = open(filename, O_RDONLY);
 	if (fd < 0)
-		return error_errno("unable to open %s for reading", filename);
+		return error_errno(_("unable to open %s for reading"), filename);
 
 	if (!raw && type == OBJ_TREE) {
 		const char *argv[] = { "mktree", NULL };
@@ -265,11 +269,11 @@ static int import_object(struct object_i
 
 		if (start_command(&cmd)) {
 			close(fd);
-			return error("unable to spawn mktree");
+			return error(_("unable to spawn mktree"));
 		}
 
-		if (strbuf_read(&result, cmd.out, 41) < 0) {
-			error_errno("unable to read from mktree");
+		if (strbuf_read(&result, cmd.out, the_hash_algo->hexsz + 1) < 0) {
+			error_errno(_("unable to read from mktree"));
 			close(fd);
 			close(cmd.out);
 			return -1;
@@ -278,11 +282,11 @@ static int import_object(struct object_i
 
 		if (finish_command(&cmd)) {
 			strbuf_release(&result);
-			return error("mktree reported failure");
+			return error(_("mktree reported failure"));
 		}
 		if (get_oid_hex(result.buf, oid) < 0) {
 			strbuf_release(&result);
-			return error("mktree did not return an object name");
+			return error(_("mktree did not return an object name"));
 		}
 
 		strbuf_release(&result);
@@ -291,12 +295,12 @@ static int import_object(struct object_i
 		int flags = HASH_FORMAT_CHECK | HASH_WRITE_OBJECT;
 
 		if (fstat(fd, &st) < 0) {
-			error_errno("unable to fstat %s", filename);
+			error_errno(_("unable to fstat %s"), filename);
 			close(fd);
 			return -1;
 		}
-		if (index_fd(oid, fd, &st, type, NULL, flags) < 0)
-			return error("unable to write object to database");
+		if (index_fd(the_repository->index, oid, fd, &st, type, NULL, flags) < 0)
+			return error(_("unable to write object to database"));
 		/* index_fd close()s fd for us */
 	}
 
@@ -315,11 +319,11 @@ static int edit_and_replace(const char *
 	struct strbuf ref = STRBUF_INIT;
 
 	if (get_oid(object_ref, &old_oid) < 0)
-		return error("Not a valid object name: '%s'", object_ref);
+		return error(_("not a valid object name: '%s'"), object_ref);
 
 	type = oid_object_info(the_repository, &old_oid, NULL);
 	if (type < 0)
-		return error("unable to get object type for %s",
+		return error(_("unable to get object type for %s"),
 			     oid_to_hex(&old_oid));
 
 	if (check_ref_valid(&old_oid, &prev, &ref, force)) {
@@ -335,7 +339,7 @@ static int edit_and_replace(const char *
 	}
 	if (launch_editor(tmpfile, NULL, NULL) < 0) {
 		free(tmpfile);
-		return error("editing object file failed");
+		return error(_("editing object file failed"));
 	}
 	if (import_object(&new_oid, type, raw, tmpfile)) {
 		free(tmpfile);
@@ -343,8 +347,8 @@ static int edit_and_replace(const char *
 	}
 	free(tmpfile);
 
-	if (!oidcmp(&old_oid, &new_oid))
-		return error("new object is the same as the old one: '%s'", oid_to_hex(&old_oid));
+	if (oideq(&old_oid, &new_oid))
+		return error(_("new object is the same as the old one: '%s'"), oid_to_hex(&old_oid));
 
 	return replace_object_oid(object_ref, &old_oid, "replacement", &new_oid, force);
 }
@@ -354,28 +358,32 @@ static int replace_parents(struct strbuf
 	struct strbuf new_parents = STRBUF_INIT;
 	const char *parent_start, *parent_end;
 	int i;
+	const unsigned hexsz = the_hash_algo->hexsz;
 
 	/* find existing parents */
 	parent_start = buf->buf;
-	parent_start += GIT_SHA1_HEXSZ + 6; /* "tree " + "hex sha1" + "\n" */
+	parent_start += hexsz + 6; /* "tree " + "hex sha1" + "\n" */
 	parent_end = parent_start;
 
 	while (starts_with(parent_end, "parent "))
-		parent_end += 48; /* "parent " + "hex sha1" + "\n" */
+		parent_end += hexsz + 8; /* "parent " + "hex sha1" + "\n" */
 
 	/* prepare new parents */
 	for (i = 0; i < argc; i++) {
 		struct object_id oid;
+		struct commit *commit;
+
 		if (get_oid(argv[i], &oid) < 0) {
 			strbuf_release(&new_parents);
-			return error(_("Not a valid object name: '%s'"),
+			return error(_("not a valid object name: '%s'"),
 				     argv[i]);
 		}
-		if (!lookup_commit_reference(&oid)) {
+		commit = lookup_commit_reference(the_repository, &oid);
+		if (!commit) {
 			strbuf_release(&new_parents);
-			return error(_("could not parse %s"), argv[i]);
+			return error(_("could not parse %s as a commit"), argv[i]);
 		}
-		strbuf_addf(&new_parents, "parent %s\n", oid_to_hex(&oid));
+		strbuf_addf(&new_parents, "parent %s\n", oid_to_hex(&commit->object.oid));
 	}
 
 	/* replace existing parents with new ones */
@@ -402,19 +410,19 @@ static int check_one_mergetag(struct com
 	int i;
 
 	hash_object_file(extra->value, extra->len, type_name(OBJ_TAG), &tag_oid);
-	tag = lookup_tag(&tag_oid);
+	tag = lookup_tag(the_repository, &tag_oid);
 	if (!tag)
 		return error(_("bad mergetag in commit '%s'"), ref);
-	if (parse_tag_buffer(tag, extra->value, extra->len))
+	if (parse_tag_buffer(the_repository, tag, extra->value, extra->len))
 		return error(_("malformed mergetag in commit '%s'"), ref);
 
 	/* iterate over new parents */
 	for (i = 1; i < mergetag_data->argc; i++) {
 		struct object_id oid;
 		if (get_oid(mergetag_data->argv[i], &oid) < 0)
-			return error(_("Not a valid object name: '%s'"),
+			return error(_("not a valid object name: '%s'"),
 				     mergetag_data->argv[i]);
-		if (!oidcmp(&tag->tagged->oid, &oid))
+		if (oideq(get_tagged_oid(tag), &oid))
 			return 0; /* found */
 	}
 
@@ -442,8 +450,8 @@ static int create_graft(int argc, const
 	unsigned long size;
 
 	if (get_oid(old_ref, &old_oid) < 0)
-		return error(_("Not a valid object name: '%s'"), old_ref);
-	commit = lookup_commit_reference(&old_oid);
+		return error(_("not a valid object name: '%s'"), old_ref);
+	commit = lookup_commit_reference(the_repository, &old_oid);
 	if (!commit)
 		return error(_("could not parse %s"), old_ref);
 
@@ -457,7 +465,7 @@ static int create_graft(int argc, const
 	}
 
 	if (remove_signature(&buf)) {
-		warning(_("the original commit '%s' has a gpg signature."), old_ref);
+		warning(_("the original commit '%s' has a gpg signature"), old_ref);
 		warning(_("the signature will be removed in the replacement commit!"));
 	}
 
@@ -474,20 +482,23 @@ static int create_graft(int argc, const
 
 	strbuf_release(&buf);
 
-	if (!oidcmp(&old_oid, &new_oid)) {
+	if (oideq(&commit->object.oid, &new_oid)) {
 		if (gentle) {
-			warning("graft for '%s' unnecessary", oid_to_hex(&old_oid));
+			warning(_("graft for '%s' unnecessary"),
+				oid_to_hex(&commit->object.oid));
 			return 0;
 		}
-		return error("new commit is the same as the old one: '%s'", oid_to_hex(&old_oid));
+		return error(_("new commit is the same as the old one: '%s'"),
+			     oid_to_hex(&commit->object.oid));
 	}
 
-	return replace_object_oid(old_ref, &old_oid, "replacement", &new_oid, force);
+	return replace_object_oid(old_ref, &commit->object.oid,
+				  "replacement", &new_oid, force);
 }
 
 static int convert_graft_file(int force)
 {
-	const char *graft_file = get_graft_file();
+	const char *graft_file = get_graft_file(the_repository);
 	FILE *fp = fopen_or_warn(graft_file, "r");
 	struct strbuf buf = STRBUF_INIT, err = STRBUF_INIT;
 	struct argv_array args = ARGV_ARRAY_INIT;
@@ -495,6 +506,7 @@ static int convert_graft_file(int force)
 	if (!fp)
 		return -1;
 
+	advice_graft_file_deprecated = 0;
 	while (strbuf_getline(&buf, fp) != EOF) {
 		if (*buf.buf == '#')
 			continue;
@@ -544,7 +556,7 @@ int cmd_replace(int argc, const char **a
 		OPT_END()
 	};
 
-	check_replace_refs = 0;
+	read_replace_refs = 0;
 	git_config(git_default_config, NULL);
 
 	argc = parse_options(argc, argv, prefix, options, git_replace_usage, 0);
@@ -553,7 +565,7 @@ int cmd_replace(int argc, const char **a
 		cmdmode = argc ? MODE_REPLACE : MODE_LIST;
 
 	if (format && cmdmode != MODE_LIST)
-		usage_msg_opt("--format cannot be used when not listing",
+		usage_msg_opt(_("--format cannot be used when not listing"),
 			      git_replace_usage, options);
 
 	if (force &&
@@ -561,47 +573,47 @@ int cmd_replace(int argc, const char **a
 	    cmdmode != MODE_EDIT &&
 	    cmdmode != MODE_GRAFT &&
 	    cmdmode != MODE_CONVERT_GRAFT_FILE)
-		usage_msg_opt("-f only makes sense when writing a replacement",
+		usage_msg_opt(_("-f only makes sense when writing a replacement"),
 			      git_replace_usage, options);
 
 	if (raw && cmdmode != MODE_EDIT)
-		usage_msg_opt("--raw only makes sense with --edit",
+		usage_msg_opt(_("--raw only makes sense with --edit"),
 			      git_replace_usage, options);
 
 	switch (cmdmode) {
 	case MODE_DELETE:
 		if (argc < 1)
-			usage_msg_opt("-d needs at least one argument",
+			usage_msg_opt(_("-d needs at least one argument"),
 				      git_replace_usage, options);
 		return for_each_replace_name(argv, delete_replace_ref);
 
 	case MODE_REPLACE:
 		if (argc != 2)
-			usage_msg_opt("bad number of arguments",
+			usage_msg_opt(_("bad number of arguments"),
 				      git_replace_usage, options);
 		return replace_object(argv[0], argv[1], force);
 
 	case MODE_EDIT:
 		if (argc != 1)
-			usage_msg_opt("-e needs exactly one argument",
+			usage_msg_opt(_("-e needs exactly one argument"),
 				      git_replace_usage, options);
 		return edit_and_replace(argv[0], force, raw);
 
 	case MODE_GRAFT:
 		if (argc < 1)
-			usage_msg_opt("-g needs at least one argument",
+			usage_msg_opt(_("-g needs at least one argument"),
 				      git_replace_usage, options);
 		return create_graft(argc, argv, force, 0);
 
 	case MODE_CONVERT_GRAFT_FILE:
 		if (argc != 0)
-			usage_msg_opt("--convert-graft-file takes no argument",
+			usage_msg_opt(_("--convert-graft-file takes no argument"),
 				      git_replace_usage, options);
 		return !!convert_graft_file(force);
 
 	case MODE_LIST:
 		if (argc > 1)
-			usage_msg_opt("only one pattern can be given with -l",
+			usage_msg_opt(_("only one pattern can be given with -l"),
 				      git_replace_usage, options);
 		return list_replace_refs(argv[0], format);
 
diff -pruN 1.2.1+git2.18.0-1/git/builtin/rerere.c 1.2.3+git2.25.1-1/git/builtin/rerere.c
--- 1.2.1+git2.18.0-1/git/builtin/rerere.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/builtin/rerere.c	2020-02-17 04:47:35.000000000 +0000
@@ -41,7 +41,8 @@ static int diff_two(const char *file1, c
 	xpp.flags = 0;
 	memset(&xecfg, 0, sizeof(xecfg));
 	xecfg.ctxlen = 3;
-	ecb.outf = outf;
+	ecb.out_hunk = NULL;
+	ecb.out_line = outf;
 	ret = xdi_diff(&minus, &plus, &xpp, &xecfg, &ecb);
 
 	free(minus.ptr);
@@ -70,28 +71,29 @@ int cmd_rerere(int argc, const char **ar
 		flags = RERERE_NOAUTOUPDATE;
 
 	if (argc < 1)
-		return rerere(flags);
+		return repo_rerere(the_repository, flags);
 
 	if (!strcmp(argv[0], "forget")) {
 		struct pathspec pathspec;
 		if (argc < 2)
-			warning("'git rerere forget' without paths is deprecated");
+			warning(_("'git rerere forget' without paths is deprecated"));
 		parse_pathspec(&pathspec, 0, PATHSPEC_PREFER_CWD,
 			       prefix, argv + 1);
-		return rerere_forget(&pathspec);
+		return rerere_forget(the_repository, &pathspec);
 	}
 
 	if (!strcmp(argv[0], "clear")) {
-		rerere_clear(&merge_rr);
+		rerere_clear(the_repository, &merge_rr);
 	} else if (!strcmp(argv[0], "gc"))
-		rerere_gc(&merge_rr);
+		rerere_gc(the_repository, &merge_rr);
 	else if (!strcmp(argv[0], "status")) {
-		if (setup_rerere(&merge_rr, flags | RERERE_READONLY) < 0)
+		if (setup_rerere(the_repository, &merge_rr,
+				 flags | RERERE_READONLY) < 0)
 			return 0;
 		for (i = 0; i < merge_rr.nr; i++)
 			printf("%s\n", merge_rr.items[i].string);
 	} else if (!strcmp(argv[0], "remaining")) {
-		rerere_remaining(&merge_rr);
+		rerere_remaining(the_repository, &merge_rr);
 		for (i = 0; i < merge_rr.nr; i++) {
 			if (merge_rr.items[i].util != RERERE_RESOLVED)
 				printf("%s\n", merge_rr.items[i].string);
@@ -101,13 +103,14 @@ int cmd_rerere(int argc, const char **ar
 				merge_rr.items[i].util = NULL;
 		}
 	} else if (!strcmp(argv[0], "diff")) {
-		if (setup_rerere(&merge_rr, flags | RERERE_READONLY) < 0)
+		if (setup_rerere(the_repository, &merge_rr,
+				 flags | RERERE_READONLY) < 0)
 			return 0;
 		for (i = 0; i < merge_rr.nr; i++) {
 			const char *path = merge_rr.items[i].string;
 			const struct rerere_id *id = merge_rr.items[i].util;
 			if (diff_two(rerere_path(id, "preimage"), path, path, path))
-				die("unable to generate diff for %s", rerere_path(id, NULL));
+				die(_("unable to generate diff for '%s'"), rerere_path(id, NULL));
 		}
 	} else
 		usage_with_options(rerere_usage, options);
diff -pruN 1.2.1+git2.18.0-1/git/builtin/reset.c 1.2.3+git2.25.1-1/git/builtin/reset.c
--- 1.2.1+git2.18.0-1/git/builtin/reset.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/builtin/reset.c	2020-02-17 04:47:35.000000000 +0000
@@ -7,6 +7,7 @@
  *
  * Copyright (c) 2005, 2006 Linus Torvalds and Junio C Hamano
  */
+#define USE_THE_INDEX_COMPATIBILITY_MACROS
 #include "builtin.h"
 #include "config.h"
 #include "lockfile.h"
@@ -25,10 +26,13 @@
 #include "submodule.h"
 #include "submodule-config.h"
 
+#define REFRESH_INDEX_DELAY_WARNING_IN_MS (2 * 1000)
+
 static const char * const git_reset_usage[] = {
 	N_("git reset [--mixed | --soft | --hard | --merge | --keep] [-q] [<commit>]"),
-	N_("git reset [-q] [<tree-ish>] [--] <paths>..."),
-	N_("git reset --patch [<tree-ish>] [--] [<paths>...]"),
+	N_("git reset [-q] [<tree-ish>] [--] <pathspec>..."),
+	N_("git reset [-q] [--pathspec-from-file [--pathspec-file-nul]] [<tree-ish>]"),
+	N_("git reset --patch [<tree-ish>] [--] [<pathspec>...]"),
 	NULL
 };
 
@@ -39,7 +43,7 @@ static const char *reset_type_names[] =
 
 static inline int is_merge(void)
 {
-	return !access(git_path_merge_head(), F_OK);
+	return !access(git_path_merge_head(the_repository), F_OK);
 }
 
 static int reset_index(const struct object_id *oid, int reset_type, int quiet)
@@ -76,13 +80,13 @@ static int reset_index(const struct obje
 		struct object_id head_oid;
 		if (get_oid("HEAD", &head_oid))
 			return error(_("You do not have a valid HEAD."));
-		if (!fill_tree_descriptor(desc + nr, &head_oid))
+		if (!fill_tree_descriptor(the_repository, desc + nr, &head_oid))
 			return error(_("Failed to find tree of HEAD."));
 		nr++;
 		opts.fn = twoway_merge;
 	}
 
-	if (!fill_tree_descriptor(desc + nr, oid)) {
+	if (!fill_tree_descriptor(the_repository, desc + nr, oid)) {
 		error(_("Failed to find tree of %s."), oid_to_hex(oid));
 		goto out;
 	}
@@ -93,7 +97,7 @@ static int reset_index(const struct obje
 
 	if (reset_type == MIXED || reset_type == HARD) {
 		tree = parse_tree_indirect(oid);
-		prime_cache_tree(&the_index, tree);
+		prime_cache_tree(the_repository, the_repository->index, tree);
 	}
 
 	ret = 0;
@@ -134,7 +138,7 @@ static void update_index_from_diff(struc
 			continue;
 		}
 
-		ce = make_cache_entry(one->mode, one->oid.hash, one->path,
+		ce = make_cache_entry(&the_index, one->mode, &one->oid, one->path,
 				      0, 0);
 		if (!ce)
 			die(_("make_cache_entry failed for path '%s'"),
@@ -159,6 +163,7 @@ static int read_from_tree(const struct p
 	opt.format_callback = update_index_from_diff;
 	opt.format_callback_data = &intent_to_add;
 	opt.flags.override_submodule_config = 1;
+	opt.repo = the_repository;
 
 	if (do_diff_cache(tree_oid, &opt))
 		return 1;
@@ -280,8 +285,8 @@ static int git_reset_config(const char *
 int cmd_reset(int argc, const char **argv, const char *prefix)
 {
 	int reset_type = NONE, update_ref_status = 0, quiet = 0;
-	int patch_mode = 0, unborn;
-	const char *rev;
+	int patch_mode = 0, pathspec_file_nul = 0, unborn;
+	const char *rev, *pathspec_from_file = NULL;
 	struct object_id oid;
 	struct pathspec pathspec;
 	int intent_to_add = 0;
@@ -302,24 +307,41 @@ int cmd_reset(int argc, const char **arg
 		OPT_BOOL('p', "patch", &patch_mode, N_("select hunks interactively")),
 		OPT_BOOL('N', "intent-to-add", &intent_to_add,
 				N_("record only the fact that removed paths will be added later")),
+		OPT_PATHSPEC_FROM_FILE(&pathspec_from_file),
+		OPT_PATHSPEC_FILE_NUL(&pathspec_file_nul),
 		OPT_END()
 	};
 
 	git_config(git_reset_config, NULL);
+	git_config_get_bool("reset.quiet", &quiet);
 
 	argc = parse_options(argc, argv, prefix, options, git_reset_usage,
 						PARSE_OPT_KEEP_DASHDASH);
 	parse_args(&pathspec, argv, prefix, patch_mode, &rev);
 
+	if (pathspec_from_file) {
+		if (patch_mode)
+			die(_("--pathspec-from-file is incompatible with --patch"));
+
+		if (pathspec.nr)
+			die(_("--pathspec-from-file is incompatible with pathspec arguments"));
+
+		parse_pathspec_file(&pathspec, 0,
+				    PATHSPEC_PREFER_FULL,
+				    prefix, pathspec_from_file, pathspec_file_nul);
+	} else if (pathspec_file_nul) {
+		die(_("--pathspec-file-nul requires --pathspec-from-file"));
+	}
+
 	unborn = !strcmp(rev, "HEAD") && get_oid("HEAD", &oid);
 	if (unborn) {
 		/* reset on unborn branch: treat as reset to empty tree */
 		oidcpy(&oid, the_hash_algo->empty_tree);
-	} else if (!pathspec.nr) {
+	} else if (!pathspec.nr && !patch_mode) {
 		struct commit *commit;
 		if (get_oid_committish(rev, &oid))
 			die(_("Failed to resolve '%s' as a valid revision."), rev);
-		commit = lookup_commit_reference(&oid);
+		commit = lookup_commit_reference(the_repository, &oid);
 		if (!commit)
 			die(_("Could not parse object '%s'."), rev);
 		oidcpy(&oid, &commit->object.oid);
@@ -336,6 +358,7 @@ int cmd_reset(int argc, const char **arg
 	if (patch_mode) {
 		if (reset_type != NONE)
 			die(_("--patch is incompatible with --{hard,mixed,soft}"));
+		trace2_cmd_mode("patch-interactive");
 		return run_add_interactive(rev, "--patch=reset", &pathspec);
 	}
 
@@ -352,6 +375,11 @@ int cmd_reset(int argc, const char **arg
 	if (reset_type == NONE)
 		reset_type = MIXED; /* by default */
 
+	if (pathspec.nr)
+		trace2_cmd_mode("path");
+	else
+		trace2_cmd_mode(reset_type_names[reset_type]);
+
 	if (reset_type != SOFT && (reset_type != MIXED || get_git_work_tree()))
 		setup_work_tree();
 
@@ -375,9 +403,20 @@ int cmd_reset(int argc, const char **arg
 			int flags = quiet ? REFRESH_QUIET : REFRESH_IN_PORCELAIN;
 			if (read_from_tree(&pathspec, &oid, intent_to_add))
 				return 1;
-			if (get_git_work_tree())
+			the_index.updated_skipworktree = 1;
+			if (!quiet && get_git_work_tree()) {
+				uint64_t t_begin, t_delta_in_ms;
+
+				t_begin = getnanotime();
 				refresh_index(&the_index, flags, NULL, NULL,
 					      _("Unstaged changes after reset:"));
+				t_delta_in_ms = (getnanotime() - t_begin) / 1000000;
+				if (advice_reset_quiet_warning && t_delta_in_ms > REFRESH_INDEX_DELAY_WARNING_IN_MS) {
+					printf(_("\nIt took %.2f seconds to enumerate unstaged changes after reset.  You can\n"
+						"use '--quiet' to avoid this.  Set the config setting reset.quiet to true\n"
+						"to make this the default.\n"), t_delta_in_ms / 1000.0);
+				}
+			}
 		} else {
 			int err = reset_index(&oid, reset_type, quiet);
 			if (reset_type == KEEP && !err)
@@ -396,10 +435,10 @@ int cmd_reset(int argc, const char **arg
 		update_ref_status = reset_refs(rev, &oid);
 
 		if (reset_type == HARD && !update_ref_status && !quiet)
-			print_new_head_line(lookup_commit_reference(&oid));
+			print_new_head_line(lookup_commit_reference(the_repository, &oid));
 	}
 	if (!pathspec.nr)
-		remove_branch_state();
+		remove_branch_state(the_repository, 0);
 
 	return update_ref_status;
 }
diff -pruN 1.2.1+git2.18.0-1/git/builtin/revert.c 1.2.3+git2.25.1-1/git/builtin/revert.c
--- 1.2.1+git2.18.0-1/git/builtin/revert.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/builtin/revert.c	2020-02-17 04:47:35.000000000 +0000
@@ -7,6 +7,7 @@
 #include "rerere.h"
 #include "dir.h"
 #include "sequencer.h"
+#include "branch.h"
 
 /*
  * This implements the builtins revert and cherry-pick.
@@ -68,7 +69,8 @@ static int option_parse_m(const struct o
 
 	replay->mainline = strtol(arg, &end, 10);
 	if (*end || replay->mainline <= 0)
-		return opterror(opt, "expects a number greater than zero", 0);
+		return error(_("option `%s' expects a number greater than zero"),
+			     opt->long_name);
 
 	return 0;
 }
@@ -94,11 +96,14 @@ static int run_sequencer(int argc, const
 {
 	const char * const * usage_str = revert_or_cherry_pick_usage(opts);
 	const char *me = action_name(opts);
+	const char *cleanup_arg = NULL;
 	int cmd = 0;
 	struct option base_options[] = {
 		OPT_CMDMODE(0, "quit", &cmd, N_("end revert or cherry-pick sequence"), 'q'),
 		OPT_CMDMODE(0, "continue", &cmd, N_("resume revert or cherry-pick sequence"), 'c'),
 		OPT_CMDMODE(0, "abort", &cmd, N_("cancel revert or cherry-pick sequence"), 'a'),
+		OPT_CMDMODE(0, "skip", &cmd, N_("skip current commit and continue"), 's'),
+		OPT_CLEANUP(&cleanup_arg),
 		OPT_BOOL('n', "no-commit", &opts->no_commit, N_("don't automatically commit")),
 		OPT_BOOL('e', "edit", &opts->edit, N_("edit the commit message")),
 		OPT_NOOP_NOARG('r', NULL),
@@ -135,6 +140,11 @@ static int run_sequencer(int argc, const
 	if (opts->keep_redundant_commits)
 		opts->allow_empty = 1;
 
+	if (cleanup_arg) {
+		opts->default_msg_cleanup = get_cleanup_mode(cleanup_arg, 1);
+		opts->explicit_cleanup = 1;
+	}
+
 	/* Check for incompatible command line arguments */
 	if (cmd) {
 		char *this_operation;
@@ -142,6 +152,8 @@ static int run_sequencer(int argc, const
 			this_operation = "--quit";
 		else if (cmd == 'c')
 			this_operation = "--continue";
+		else if (cmd == 's')
+			this_operation = "--skip";
 		else {
 			assert(cmd == 'a');
 			this_operation = "--abort";
@@ -173,7 +185,7 @@ static int run_sequencer(int argc, const
 	} else {
 		struct setup_revision_opt s_r_opt;
 		opts->revs = xmalloc(sizeof(*opts->revs));
-		init_revisions(opts->revs, NULL);
+		repo_init_revisions(the_repository, opts->revs, NULL);
 		opts->revs->no_walk = REVISION_WALK_NO_WALK_UNSORTED;
 		if (argc < 2)
 			usage_with_options(usage_str, options);
@@ -191,13 +203,19 @@ static int run_sequencer(int argc, const
 	opts->gpg_sign = xstrdup_or_null(opts->gpg_sign);
 	opts->strategy = xstrdup_or_null(opts->strategy);
 
-	if (cmd == 'q')
-		return sequencer_remove_state(opts);
+	if (cmd == 'q') {
+		int ret = sequencer_remove_state(opts);
+		if (!ret)
+			remove_branch_state(the_repository, 0);
+		return ret;
+	}
 	if (cmd == 'c')
-		return sequencer_continue(opts);
+		return sequencer_continue(the_repository, opts);
 	if (cmd == 'a')
-		return sequencer_rollback(opts);
-	return sequencer_pick_revisions(opts);
+		return sequencer_rollback(the_repository, opts);
+	if (cmd == 's')
+		return sequencer_skip(the_repository, opts);
+	return sequencer_pick_revisions(the_repository, opts);
 }
 
 int cmd_revert(int argc, const char **argv, const char *prefix)
diff -pruN 1.2.1+git2.18.0-1/git/builtin/rev-list.c 1.2.3+git2.25.1-1/git/builtin/rev-list.c
--- 1.2.1+git2.18.0-1/git/builtin/rev-list.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/builtin/rev-list.c	2020-02-17 04:47:35.000000000 +0000
@@ -6,6 +6,8 @@
 #include "list-objects.h"
 #include "list-objects-filter.h"
 #include "list-objects-filter-options.h"
+#include "object.h"
+#include "object-store.h"
 #include "pack.h"
 #include "pack-bitmap.h"
 #include "builtin.h"
@@ -46,6 +48,7 @@ static const char rev_list_usage[] =
 "    --objects | --objects-edge\n"
 "    --unpacked\n"
 "    --header | --pretty\n"
+"    --[no-]object-names\n"
 "    --abbrev=<n> | --no-abbrev\n"
 "    --abbrev-commit\n"
 "    --left-right\n"
@@ -72,9 +75,12 @@ enum missing_action {
 };
 static enum missing_action arg_missing_action;
 
+/* display only the oid of each object encountered */
+static int arg_show_object_names = 1;
+
 #define DEFAULT_OIDSET_SIZE     (16*1024)
 
-static void finish_commit(struct commit *commit, void *data);
+static void finish_commit(struct commit *commit);
 static void show_commit(struct commit *commit, void *data)
 {
 	struct rev_list_info *info = data;
@@ -83,7 +89,7 @@ static void show_commit(struct commit *c
 	display_progress(progress, ++progress_counter);
 
 	if (info->flags & REV_LIST_QUIET) {
-		finish_commit(commit, data);
+		finish_commit(commit);
 		return;
 	}
 
@@ -96,7 +102,7 @@ static void show_commit(struct commit *c
 			revs->count_left++;
 		else
 			revs->count_right++;
-		finish_commit(commit, data);
+		finish_commit(commit);
 		return;
 	}
 
@@ -185,16 +191,17 @@ static void show_commit(struct commit *c
 			putchar('\n');
 	}
 	maybe_flush_or_die(stdout, "stdout");
-	finish_commit(commit, data);
+	finish_commit(commit);
 }
 
-static void finish_commit(struct commit *commit, void *data)
+static void finish_commit(struct commit *commit)
 {
 	if (commit->parents) {
 		free_commit_list(commit->parents);
 		commit->parents = NULL;
 	}
-	free_commit_buffer(commit);
+	free_commit_buffer(the_repository->parsed_objects,
+			   commit);
 }
 
 static inline void finish_object__ma(struct object *obj)
@@ -207,7 +214,8 @@ static inline void finish_object__ma(str
 	 */
 	switch (arg_missing_action) {
 	case MA_ERROR:
-		die("missing blob object '%s'", oid_to_hex(&obj->oid));
+		die("missing %s object '%s'",
+		    type_name(obj->type), oid_to_hex(&obj->oid));
 		return;
 
 	case MA_ALLOW_ANY:
@@ -220,8 +228,8 @@ static inline void finish_object__ma(str
 	case MA_ALLOW_PROMISOR:
 		if (is_promisor_object(&obj->oid))
 			return;
-		die("unexpected missing blob object '%s'",
-		    oid_to_hex(&obj->oid));
+		die("unexpected missing %s object '%s'",
+		    type_name(obj->type), oid_to_hex(&obj->oid));
 		return;
 
 	default:
@@ -233,12 +241,12 @@ static inline void finish_object__ma(str
 static int finish_object(struct object *obj, const char *name, void *cb_data)
 {
 	struct rev_list_info *info = cb_data;
-	if (obj->type == OBJ_BLOB && !has_object_file(&obj->oid)) {
+	if (oid_object_info_extended(the_repository, &obj->oid, NULL, 0) < 0) {
 		finish_object__ma(obj);
 		return 1;
 	}
 	if (info->revs->verify_objects && !obj->parsed && obj->type != OBJ_COMMIT)
-		parse_object(&obj->oid);
+		parse_object(the_repository, &obj->oid);
 	return 0;
 }
 
@@ -250,7 +258,10 @@ static void show_object(struct object *o
 	display_progress(progress, ++progress_counter);
 	if (info->flags & REV_LIST_QUIET)
 		return;
-	show_object_with_name(stdout, obj, name);
+	if (arg_show_object_names)
+		show_object_with_name(stdout, obj, name);
+	else
+		printf("%s\n", oid_to_hex(&obj->oid));
 }
 
 static void show_edge(struct commit *commit)
@@ -357,6 +368,9 @@ int cmd_rev_list(int argc, const char **
 {
 	struct rev_info revs;
 	struct rev_list_info info;
+	struct setup_revision_opt s_r_opt = {
+		.allow_exclude_promisor_objects = 1,
+	};
 	int i;
 	int bisect_list = 0;
 	int bisect_show_vars = 0;
@@ -368,7 +382,7 @@ int cmd_rev_list(int argc, const char **
 		usage(rev_list_usage);
 
 	git_config(git_default_config, NULL);
-	init_revisions(&revs, prefix);
+	repo_init_revisions(the_repository, &revs, prefix);
 	revs.abbrev = DEFAULT_ABBREV;
 	revs.commit_format = CMIT_FMT_UNSPECIFIED;
 
@@ -400,7 +414,10 @@ int cmd_rev_list(int argc, const char **
 		}
 	}
 
-	argc = setup_revisions(argc, argv, &revs, NULL);
+	if (arg_missing_action)
+		revs.do_not_die_on_missing_tree = 1;
+
+	argc = setup_revisions(argc, argv, &revs, &s_r_opt);
 
 	memset(&info, 0, sizeof(info));
 	info.revs = &revs;
@@ -453,10 +470,6 @@ int cmd_rev_list(int argc, const char **
 			parse_list_objects_filter(&filter_options, arg);
 			if (filter_options.choice && !revs.blob_objects)
 				die(_("object filtering requires --objects"));
-			if (filter_options.choice == LOFC_SPARSE_OID &&
-			    !filter_options.sparse_oid_value)
-				die(_("invalid sparse value '%s'"),
-				    filter_options.filter_spec);
 			continue;
 		}
 		if (!strcmp(arg, ("--no-" CL_ARG__FILTER))) {
@@ -473,6 +486,16 @@ int cmd_rev_list(int argc, const char **
 		if (skip_prefix(arg, "--missing=", &arg))
 			continue; /* already handled above */
 
+		if (!strcmp(arg, ("--no-object-names"))) {
+			arg_show_object_names = 0;
+			continue;
+		}
+
+		if (!strcmp(arg, ("--object-names"))) {
+			arg_show_object_names = 1;
+			continue;
+		}
+
 		usage(rev_list_usage);
 
 	}
@@ -491,7 +514,7 @@ int cmd_rev_list(int argc, const char **
 	if ((!revs.commits && reflog_walk_empty(revs.reflog_info) &&
 	     (!(revs.tag_objects || revs.tree_objects || revs.blob_objects) &&
 	      !revs.pending.nr) &&
-	     !revs.rev_input_given) ||
+	     !revs.rev_input_given && !revs.read_from_stdin) ||
 	    revs.diff)
 		usage(rev_list_usage);
 
@@ -514,17 +537,21 @@ int cmd_rev_list(int argc, const char **
 		if (revs.count && !revs.left_right && !revs.cherry_mark) {
 			uint32_t commit_count;
 			int max_count = revs.max_count;
-			if (!prepare_bitmap_walk(&revs)) {
-				count_bitmap_commit_list(&commit_count, NULL, NULL, NULL);
+			struct bitmap_index *bitmap_git;
+			if ((bitmap_git = prepare_bitmap_walk(&revs))) {
+				count_bitmap_commit_list(bitmap_git, &commit_count, NULL, NULL, NULL);
 				if (max_count >= 0 && max_count < commit_count)
 					commit_count = max_count;
 				printf("%d\n", commit_count);
+				free_bitmap_index(bitmap_git);
 				return 0;
 			}
 		} else if (revs.max_count < 0 &&
 			   revs.tag_objects && revs.tree_objects && revs.blob_objects) {
-			if (!prepare_bitmap_walk(&revs)) {
-				traverse_bitmap_commit_list(&show_object_fast);
+			struct bitmap_index *bitmap_git;
+			if ((bitmap_git = prepare_bitmap_walk(&revs))) {
+				traverse_bitmap_commit_list(bitmap_git, &show_object_fast);
+				free_bitmap_index(bitmap_git);
 				return 0;
 			}
 		}
@@ -533,7 +560,7 @@ int cmd_rev_list(int argc, const char **
 	if (prepare_revision_walk(&revs))
 		die("revision walk setup failed");
 	if (revs.tree_objects)
-		mark_edges_uninteresting(&revs, show_edge);
+		mark_edges_uninteresting(&revs, show_edge, 0);
 
 	if (bisect_list) {
 		int reaches, all;
diff -pruN 1.2.1+git2.18.0-1/git/builtin/rev-parse.c 1.2.3+git2.25.1-1/git/builtin/rev-parse.c
--- 1.2.1+git2.18.0-1/git/builtin/rev-parse.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/builtin/rev-parse.c	2020-02-17 04:47:35.000000000 +0000
@@ -3,6 +3,7 @@
  *
  * Copyright (C) Linus Torvalds, 2005
  */
+#define USE_THE_INDEX_COMPATIBILITY_MACROS
 #include "cache.h"
 #include "config.h"
 #include "commit.h"
@@ -14,6 +15,7 @@
 #include "revision.h"
 #include "split-index.h"
 #include "submodule.h"
+#include "commit-reach.h"
 
 #define DO_REVS		1
 #define DO_NOREV	2
@@ -280,8 +282,8 @@ static int try_difference(const char *ar
 		if (symmetric) {
 			struct commit_list *exclude;
 			struct commit *a, *b;
-			a = lookup_commit_reference(&start_oid);
-			b = lookup_commit_reference(&end_oid);
+			a = lookup_commit_reference(the_repository, &start_oid);
+			b = lookup_commit_reference(the_repository, &end_oid);
 			if (!a || !b) {
 				*dotdot = '.';
 				return 0;
@@ -333,7 +335,7 @@ static int try_parent_shorthands(const c
 
 	*dotdot = 0;
 	if (get_oid_committish(arg, &oid) ||
-	    !(commit = lookup_commit_reference(&oid))) {
+	    !(commit = lookup_commit_reference(the_repository, &oid))) {
 		*dotdot = '^';
 		return 0;
 	}
@@ -591,6 +593,7 @@ int cmd_rev_parse(int argc, const char *
 	const char *name = NULL;
 	struct object_context unused;
 	struct strbuf buf = STRBUF_INIT;
+	const int hexsz = the_hash_algo->hexsz;
 
 	if (argc > 1 && !strcmp("--parseopt", argv[1]))
 		return cmd_parseopt(argc - 1, argv + 1, prefix);
@@ -728,8 +731,8 @@ int cmd_rev_parse(int argc, const char *
 				abbrev = strtoul(arg, NULL, 10);
 				if (abbrev < MINIMUM_ABBREV)
 					abbrev = MINIMUM_ABBREV;
-				else if (40 <= abbrev)
-					abbrev = 40;
+				else if (hexsz <= abbrev)
+					abbrev = hexsz;
 				continue;
 			}
 			if (!strcmp(arg, "--sq")) {
@@ -764,6 +767,7 @@ int cmd_rev_parse(int argc, const char *
 			}
 			if (!strcmp(arg, "--all")) {
 				for_each_ref(show_reference, NULL);
+				clear_ref_exclusion(&ref_excludes);
 				continue;
 			}
 			if (skip_prefix(arg, "--disambiguate=", &arg)) {
@@ -799,6 +803,8 @@ int cmd_rev_parse(int argc, const char *
 				const char *work_tree = get_git_work_tree();
 				if (work_tree)
 					puts(work_tree);
+				else
+					die("this operation must be run in a work tree");
 				continue;
 			}
 			if (!strcmp(arg, "--show-superproject-working-tree")) {
@@ -883,7 +889,8 @@ int cmd_rev_parse(int argc, const char *
 				continue;
 			}
 			if (!strcmp(arg, "--is-shallow-repository")) {
-				printf("%s\n", is_repository_shallow() ? "true"
+				printf("%s\n",
+						is_repository_shallow(the_repository) ? "true"
 						: "false");
 				continue;
 			}
@@ -914,6 +921,17 @@ int cmd_rev_parse(int argc, const char *
 				show_datestring("--min-age=", arg);
 				continue;
 			}
+			if (opt_with_value(arg, "--show-object-format", &arg)) {
+				const char *val = arg ? arg : "storage";
+
+				if (strcmp(val, "storage") &&
+				    strcmp(val, "input") &&
+				    strcmp(val, "output"))
+					die("unknown mode for --show-object-format: %s",
+					    arg);
+				puts(the_hash_algo->name);
+				continue;
+			}
 			if (show_flag(arg) && verify)
 				die_no_single_rev(quiet);
 			continue;
@@ -930,7 +948,8 @@ int cmd_rev_parse(int argc, const char *
 			name++;
 			type = REVERSED;
 		}
-		if (!get_oid_with_context(name, flags, &oid, &unused)) {
+		if (!get_oid_with_context(the_repository, name,
+					  flags, &oid, &unused)) {
 			if (verify)
 				revs_count++;
 			else
diff -pruN 1.2.1+git2.18.0-1/git/builtin/rm.c 1.2.3+git2.25.1-1/git/builtin/rm.c
--- 1.2.1+git2.18.0-1/git/builtin/rm.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/builtin/rm.c	2020-02-17 04:47:35.000000000 +0000
@@ -3,6 +3,7 @@
  *
  * Copyright (C) Linus Torvalds 2006
  */
+#define USE_THE_INDEX_COMPATIBILITY_MACROS
 #include "builtin.h"
 #include "config.h"
 #include "lockfile.h"
@@ -60,7 +61,7 @@ static void print_error_files(struct str
 	}
 }
 
-static void submodules_absorb_gitdir_if_needed(const char *prefix)
+static void submodules_absorb_gitdir_if_needed(void)
 {
 	int i;
 	for (i = 0; i < list.nr; i++) {
@@ -82,7 +83,7 @@ static void submodules_absorb_gitdir_if_
 			continue;
 
 		if (!submodule_uses_gitfile(name))
-			absorb_git_dir_into_superproject(prefix, name,
+			absorb_git_dir_into_superproject(name,
 				ABSORB_GITDIR_RECURSE_SUBMODULES);
 	}
 }
@@ -109,7 +110,7 @@ static int check_local_mod(struct object
 		const struct cache_entry *ce;
 		const char *name = list.entry[i].name;
 		struct object_id oid;
-		unsigned mode;
+		unsigned short mode;
 		int local_changes = 0;
 		int staged_changes = 0;
 
@@ -178,9 +179,9 @@ static int check_local_mod(struct object
 		 * way as changed from the HEAD.
 		 */
 		if (no_head
-		     || get_tree_entry(head, name, &oid, &mode)
+		     || get_tree_entry(the_repository, head, name, &oid, &mode)
 		     || ce->ce_mode != create_ce_mode(mode)
-		     || oidcmp(&ce->oid, &oid))
+		     || !oideq(&ce->oid, &oid))
 			staged_changes = 1;
 
 		/*
@@ -272,20 +273,20 @@ int cmd_rm(int argc, const char **argv,
 	parse_pathspec(&pathspec, 0,
 		       PATHSPEC_PREFER_CWD,
 		       prefix, argv);
-	refresh_index(&the_index, REFRESH_QUIET, &pathspec, NULL, NULL);
+	refresh_index(&the_index, REFRESH_QUIET|REFRESH_UNMERGED, &pathspec, NULL, NULL);
 
 	seen = xcalloc(pathspec.nr, 1);
 
 	for (i = 0; i < active_nr; i++) {
 		const struct cache_entry *ce = active_cache[i];
-		if (!ce_path_match(ce, &pathspec, seen))
+		if (!ce_path_match(&the_index, ce, &pathspec, seen))
 			continue;
 		ALLOC_GROW(list.entry, list.nr + 1, list.alloc);
 		list.entry[list.nr].name = xstrdup(ce->name);
 		list.entry[list.nr].is_submodule = S_ISGITLINK(ce->ce_mode);
 		if (list.entry[list.nr++].is_submodule &&
 		    !is_staging_gitmodules_ok(&the_index))
-			die (_("Please stage your changes to .gitmodules or stash them to proceed"));
+			die(_("please stage your changes to .gitmodules or stash them to proceed"));
 	}
 
 	if (pathspec.nr) {
@@ -312,7 +313,7 @@ int cmd_rm(int argc, const char **argv,
 	}
 
 	if (!index_only)
-		submodules_absorb_gitdir_if_needed(prefix);
+		submodules_absorb_gitdir_if_needed();
 
 	/*
 	 * If not forced, the file, the index and the HEAD (if exists)
diff -pruN 1.2.1+git2.18.0-1/git/builtin/send-pack.c 1.2.3+git2.25.1-1/git/builtin/send-pack.c
--- 1.2.1+git2.18.0-1/git/builtin/send-pack.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/builtin/send-pack.c	2020-02-17 04:47:35.000000000 +0000
@@ -121,7 +121,7 @@ static int send_pack_config(const char *
 			}
 		}
 	}
-	return 0;
+	return git_default_config(k, v, cb);
 }
 
 int cmd_send_pack(int argc, const char **argv, const char *prefix)
@@ -166,7 +166,7 @@ int cmd_send_pack(int argc, const char *
 		OPT_BOOL(0, "mirror", &send_mirror, N_("mirror all refs")),
 		OPT_BOOL('f', "force", &force_update, N_("force updates")),
 		{ OPTION_CALLBACK,
-		  0, "signed", &push_cert, "yes|no|if-asked", N_("GPG sign the push"),
+		  0, "signed", &push_cert, "(yes|no|if-asked)", N_("GPG sign the push"),
 		  PARSE_OPT_OPTARG, option_parse_push_signed },
 		OPT_STRING_LIST(0, "push-option", &push_options,
 				N_("server-specific"),
@@ -178,7 +178,7 @@ int cmd_send_pack(int argc, const char *
 		OPT_BOOL(0, "stdin", &from_stdin, N_("read refs from stdin")),
 		OPT_BOOL(0, "helper-status", &helper_status, N_("print status from remote helper")),
 		{ OPTION_CALLBACK,
-		  0, CAS_OPT_NAME, &cas, N_("refname>:<expect"),
+		  0, CAS_OPT_NAME, &cas, N_("<refname>:<expect>"),
 		  N_("require old value of ref to be at this value"),
 		  PARSE_OPT_OPTARG, parseopt_push_cas_option },
 		OPT_END()
@@ -250,7 +250,8 @@ int cmd_send_pack(int argc, const char *
 
 	packet_reader_init(&reader, fd[0], NULL, 0,
 			   PACKET_READ_CHOMP_NEWLINE |
-			   PACKET_READ_GENTLE_ON_EOF);
+			   PACKET_READ_GENTLE_ON_EOF |
+			   PACKET_READ_DIE_ON_ERR_PACKET);
 
 	switch (discover_version(&reader)) {
 	case protocol_v2:
diff -pruN 1.2.1+git2.18.0-1/git/builtin/serve.c 1.2.3+git2.25.1-1/git/builtin/serve.c
--- 1.2.1+git2.18.0-1/git/builtin/serve.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/builtin/serve.c	1970-01-01 00:00:00.000000000 +0000
@@ -1,30 +0,0 @@
-#include "cache.h"
-#include "builtin.h"
-#include "parse-options.h"
-#include "serve.h"
-
-static char const * const serve_usage[] = {
-	N_("git serve [<options>]"),
-	NULL
-};
-
-int cmd_serve(int argc, const char **argv, const char *prefix)
-{
-	struct serve_options opts = SERVE_OPTIONS_INIT;
-
-	struct option options[] = {
-		OPT_BOOL(0, "stateless-rpc", &opts.stateless_rpc,
-			 N_("quit after a single request/response exchange")),
-		OPT_BOOL(0, "advertise-capabilities", &opts.advertise_capabilities,
-			 N_("exit immediately after advertising capabilities")),
-		OPT_END()
-	};
-
-	/* ignore all unknown cmdline switches for now */
-	argc = parse_options(argc, argv, prefix, options, serve_usage,
-			     PARSE_OPT_KEEP_DASHDASH |
-			     PARSE_OPT_KEEP_UNKNOWN);
-	serve(&opts);
-
-	return 0;
-}
diff -pruN 1.2.1+git2.18.0-1/git/builtin/shortlog.c 1.2.3+git2.25.1-1/git/builtin/shortlog.c
--- 1.2.1+git2.18.0-1/git/builtin/shortlog.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/builtin/shortlog.c	2020-02-17 04:47:35.000000000 +0000
@@ -268,8 +268,9 @@ int cmd_shortlog(int argc, const char **
 			 N_("Suppress commit descriptions, only provides commit count")),
 		OPT_BOOL('e', "email", &log.email,
 			 N_("Show the email address of each author")),
-		{ OPTION_CALLBACK, 'w', NULL, &log, N_("w[,i1[,i2]]"),
-			N_("Linewrap output"), PARSE_OPT_OPTARG, &parse_wrap_args },
+		{ OPTION_CALLBACK, 'w', NULL, &log, N_("<w>[,<i1>[,<i2>]]"),
+			N_("Linewrap output"), PARSE_OPT_OPTARG,
+			&parse_wrap_args },
 		OPT_END(),
 	};
 
@@ -277,7 +278,7 @@ int cmd_shortlog(int argc, const char **
 
 	git_config(git_default_config, NULL);
 	shortlog_init(&log);
-	init_revisions(&rev, prefix);
+	repo_init_revisions(the_repository, &rev, prefix);
 	parse_options_start(&ctx, argc, argv, prefix, options,
 			    PARSE_OPT_KEEP_DASHDASH | PARSE_OPT_KEEP_ARGV0);
 
@@ -286,6 +287,8 @@ int cmd_shortlog(int argc, const char **
 		case PARSE_OPT_HELP:
 		case PARSE_OPT_ERROR:
 			exit(129);
+		case PARSE_OPT_COMPLETE:
+			exit(0);
 		case PARSE_OPT_DONE:
 			goto parse_done;
 		}
diff -pruN 1.2.1+git2.18.0-1/git/builtin/show-branch.c 1.2.3+git2.25.1-1/git/builtin/show-branch.c
--- 1.2.1+git2.18.0-1/git/builtin/show-branch.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/builtin/show-branch.c	2020-02-17 04:47:35.000000000 +0000
@@ -7,6 +7,7 @@
 #include "argv-array.h"
 #include "parse-options.h"
 #include "dir.h"
+#include "commit-slab.h"
 
 static const char* show_branch_usage[] = {
     N_("git show-branch [-a | --all] [-r | --remotes] [--topo-order | --date-order]\n"
@@ -21,6 +22,11 @@ static int showbranch_use_color = -1;
 
 static struct argv_array default_args = ARGV_ARRAY_INIT;
 
+/*
+ * TODO: convert this use of commit->object.flags to commit-slab
+ * instead to store a pointer to ref name directly. Then use the same
+ * UNINTERESTING definition from revision.h here.
+ */
 #define UNINTERESTING	01
 
 #define REV_SHIFT	 2
@@ -59,15 +65,27 @@ struct commit_name {
 	int generation; /* how many parents away from head_name */
 };
 
+define_commit_slab(commit_name_slab, struct commit_name *);
+static struct commit_name_slab name_slab;
+
+static struct commit_name *commit_to_name(struct commit *commit)
+{
+	return *commit_name_slab_at(&name_slab, commit);
+}
+
+
 /* Name the commit as nth generation ancestor of head_name;
  * we count only the first-parent relationship for naming purposes.
  */
 static void name_commit(struct commit *commit, const char *head_name, int nth)
 {
 	struct commit_name *name;
-	if (!commit->util)
-		commit->util = xmalloc(sizeof(struct commit_name));
-	name = commit->util;
+
+	name = *commit_name_slab_at(&name_slab, commit);
+	if (!name) {
+		name = xmalloc(sizeof(*name));
+		*commit_name_slab_at(&name_slab, commit) = name;
+	}
 	name->head_name = head_name;
 	name->generation = nth;
 }
@@ -79,8 +97,8 @@ static void name_commit(struct commit *c
  */
 static void name_parent(struct commit *commit, struct commit *parent)
 {
-	struct commit_name *commit_name = commit->util;
-	struct commit_name *parent_name = parent->util;
+	struct commit_name *commit_name = commit_to_name(commit);
+	struct commit_name *parent_name = commit_to_name(parent);
 	if (!commit_name)
 		return;
 	if (!parent_name ||
@@ -94,12 +112,12 @@ static int name_first_parent_chain(struc
 	int i = 0;
 	while (c) {
 		struct commit *p;
-		if (!c->util)
+		if (!commit_to_name(c))
 			break;
 		if (!c->parents)
 			break;
 		p = c->parents->item;
-		if (!p->util) {
+		if (!commit_to_name(p)) {
 			name_parent(c, p);
 			i++;
 		}
@@ -122,7 +140,7 @@ static void name_commits(struct commit_l
 	/* First give names to the given heads */
 	for (cl = list; cl; cl = cl->next) {
 		c = cl->item;
-		if (c->util)
+		if (commit_to_name(c))
 			continue;
 		for (i = 0; i < num_rev; i++) {
 			if (rev[i] == c) {
@@ -148,9 +166,9 @@ static void name_commits(struct commit_l
 			struct commit_name *n;
 			int nth;
 			c = cl->item;
-			if (!c->util)
+			if (!commit_to_name(c))
 				continue;
-			n = c->util;
+			n = commit_to_name(c);
 			parents = c->parents;
 			nth = 0;
 			while (parents) {
@@ -158,7 +176,7 @@ static void name_commits(struct commit_l
 				struct strbuf newname = STRBUF_INIT;
 				parents = parents->next;
 				nth++;
-				if (p->util)
+				if (commit_to_name(p))
 					continue;
 				switch (n->generation) {
 				case 0:
@@ -271,7 +289,7 @@ static void show_one_commit(struct commi
 {
 	struct strbuf pretty = STRBUF_INIT;
 	const char *pretty_str = "(unavailable)";
-	struct commit_name *name = commit->util;
+	struct commit_name *name = commit_to_name(commit);
 
 	if (commit->object.parsed) {
 		pp_commit_easy(CMIT_FMT_ONELINE, commit, &pretty);
@@ -360,7 +378,8 @@ static void sort_ref_range(int bottom, i
 static int append_ref(const char *refname, const struct object_id *oid,
 		      int allow_dups)
 {
-	struct commit *commit = lookup_commit_reference_gently(oid, 1);
+	struct commit *commit = lookup_commit_reference_gently(the_repository,
+							       oid, 1);
 	int i;
 
 	if (!commit)
@@ -393,7 +412,7 @@ static int append_head_ref(const char *r
 	/* If both heads/foo and tags/foo exists, get_sha1 would
 	 * get confused.
 	 */
-	if (get_oid(refname + ofs, &tmp) || oidcmp(&tmp, oid))
+	if (get_oid(refname + ofs, &tmp) || !oideq(&tmp, oid))
 		ofs = 5;
 	return append_ref(refname + ofs, oid, 0);
 }
@@ -408,7 +427,7 @@ static int append_remote_ref(const char
 	/* If both heads/foo and tags/foo exists, get_sha1 would
 	 * get confused.
 	 */
-	if (get_oid(refname + ofs, &tmp) || oidcmp(&tmp, oid))
+	if (get_oid(refname + ofs, &tmp) || !oideq(&tmp, oid))
 		ofs = 5;
 	return append_ref(refname + ofs, oid, 0);
 }
@@ -466,7 +485,7 @@ static void snarf_refs(int head, int rem
 static int rev_is_head(const char *head, const char *name,
 		       unsigned char *head_sha1, unsigned char *sha1)
 {
-	if (!head || (head_sha1 && sha1 && hashcmp(head_sha1, sha1)))
+	if (!head || (head_sha1 && sha1 && !hasheq(head_sha1, sha1)))
 		return 0;
 	skip_prefix(head, "refs/heads/", &head);
 	if (!skip_prefix(name, "refs/heads/", &name))
@@ -495,7 +514,6 @@ static int show_merge_base(struct commit
 
 static int show_independent(struct commit **rev,
 			    int num_rev,
-			    char **ref_name,
 			    unsigned int *rev_mask)
 {
 	int i;
@@ -585,6 +603,7 @@ static int parse_reflog_param(const stru
 {
 	char *ep;
 	const char **base = (const char **)opt->value;
+	BUG_ON_OPT_NEG(unset);
 	if (!arg)
 		arg = "";
 	reflog = strtoul(arg, &ep, 10);
@@ -655,11 +674,13 @@ int cmd_show_branch(int ac, const char *
 		{ OPTION_CALLBACK, 'g', "reflog", &reflog_base, N_("<n>[,<base>]"),
 			    N_("show <n> most recent ref-log entries starting at "
 			       "base"),
-			    PARSE_OPT_OPTARG | PARSE_OPT_LITERAL_ARGHELP,
+			    PARSE_OPT_OPTARG | PARSE_OPT_NONEG,
 			    parse_reflog_param },
 		OPT_END()
 	};
 
+	init_commit_name_slab(&name_slab);
+
 	git_config(git_show_branch_config, NULL);
 
 	/* If nothing is specified, try the default first */
@@ -731,7 +752,8 @@ int cmd_show_branch(int ac, const char *
 				/* Ah, that is a date spec... */
 				timestamp_t at;
 				at = approxidate(reflog_base);
-				read_ref_at(ref, flags, at, -1, &oid, NULL,
+				read_ref_at(get_main_ref_store(the_repository),
+					    ref, flags, at, -1, &oid, NULL,
 					    NULL, NULL, &base);
 			}
 		}
@@ -743,7 +765,8 @@ int cmd_show_branch(int ac, const char *
 			timestamp_t timestamp;
 			int tz;
 
-			if (read_ref_at(ref, flags, 0, base + i, &oid, &logmsg,
+			if (read_ref_at(get_main_ref_store(the_repository),
+					ref, flags, 0, base + i, &oid, &logmsg,
 					&timestamp, &tz, NULL)) {
 				reflog = i;
 				break;
@@ -810,7 +833,7 @@ int cmd_show_branch(int ac, const char *
 			       MAX_REVS), MAX_REVS);
 		if (get_oid(ref_name[num_rev], &revkey))
 			die(_("'%s' is not a valid ref."), ref_name[num_rev]);
-		commit = lookup_commit_reference(&revkey);
+		commit = lookup_commit_reference(the_repository, &revkey);
 		if (!commit)
 			die(_("cannot find commit %s (%s)"),
 			    ref_name[num_rev], oid_to_hex(&revkey));
@@ -838,7 +861,7 @@ int cmd_show_branch(int ac, const char *
 		return show_merge_base(seen, num_rev);
 
 	if (independent)
-		return show_independent(rev, num_rev, ref_name, rev_mask);
+		return show_independent(rev, num_rev, rev_mask);
 
 	/* Show list; --more=-1 means list-only */
 	if (1 < num_rev || extra < 0) {
diff -pruN 1.2.1+git2.18.0-1/git/builtin/show-index.c 1.2.3+git2.25.1-1/git/builtin/show-index.c
--- 1.2.1+git2.18.0-1/git/builtin/show-index.c	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/builtin/show-index.c	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,87 @@
+#include "builtin.h"
+#include "cache.h"
+#include "pack.h"
+
+static const char show_index_usage[] =
+"git show-index";
+
+int cmd_show_index(int argc, const char **argv, const char *prefix)
+{
+	int i;
+	unsigned nr;
+	unsigned int version;
+	static unsigned int top_index[256];
+	const unsigned hashsz = the_hash_algo->rawsz;
+
+	if (argc != 1)
+		usage(show_index_usage);
+	if (fread(top_index, 2 * 4, 1, stdin) != 1)
+		die("unable to read header");
+	if (top_index[0] == htonl(PACK_IDX_SIGNATURE)) {
+		version = ntohl(top_index[1]);
+		if (version < 2 || version > 2)
+			die("unknown index version");
+		if (fread(top_index, 256 * 4, 1, stdin) != 1)
+			die("unable to read index");
+	} else {
+		version = 1;
+		if (fread(&top_index[2], 254 * 4, 1, stdin) != 1)
+			die("unable to read index");
+	}
+	nr = 0;
+	for (i = 0; i < 256; i++) {
+		unsigned n = ntohl(top_index[i]);
+		if (n < nr)
+			die("corrupt index file");
+		nr = n;
+	}
+	if (version == 1) {
+		for (i = 0; i < nr; i++) {
+			unsigned int offset, entry[(GIT_MAX_RAWSZ + 4) / sizeof(unsigned int)];
+
+			if (fread(entry, 4 + hashsz, 1, stdin) != 1)
+				die("unable to read entry %u/%u", i, nr);
+			offset = ntohl(entry[0]);
+			printf("%u %s\n", offset, hash_to_hex((void *)(entry+1)));
+		}
+	} else {
+		unsigned off64_nr = 0;
+		struct {
+			struct object_id oid;
+			uint32_t crc;
+			uint32_t off;
+		} *entries;
+		ALLOC_ARRAY(entries, nr);
+		for (i = 0; i < nr; i++)
+			if (fread(entries[i].oid.hash, hashsz, 1, stdin) != 1)
+				die("unable to read sha1 %u/%u", i, nr);
+		for (i = 0; i < nr; i++)
+			if (fread(&entries[i].crc, 4, 1, stdin) != 1)
+				die("unable to read crc %u/%u", i, nr);
+		for (i = 0; i < nr; i++)
+			if (fread(&entries[i].off, 4, 1, stdin) != 1)
+				die("unable to read 32b offset %u/%u", i, nr);
+		for (i = 0; i < nr; i++) {
+			uint64_t offset;
+			uint32_t off = ntohl(entries[i].off);
+			if (!(off & 0x80000000)) {
+				offset = off;
+			} else {
+				uint32_t off64[2];
+				if ((off & 0x7fffffff) != off64_nr)
+					die("inconsistent 64b offset index");
+				if (fread(off64, 8, 1, stdin) != 1)
+					die("unable to read 64b offset %u", off64_nr);
+				offset = (((uint64_t)ntohl(off64[0])) << 32) |
+						     ntohl(off64[1]);
+				off64_nr++;
+			}
+			printf("%" PRIuMAX " %s (%08"PRIx32")\n",
+			       (uintmax_t) offset,
+			       oid_to_hex(&entries[i].oid),
+			       ntohl(entries[i].crc));
+		}
+		free(entries);
+	}
+	return 0;
+}
diff -pruN 1.2.1+git2.18.0-1/git/builtin/show-ref.c 1.2.3+git2.25.1-1/git/builtin/show-ref.c
--- 1.2.1+git2.18.0-1/git/builtin/show-ref.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/builtin/show-ref.c	2020-02-17 04:47:35.000000000 +0000
@@ -1,6 +1,8 @@
 #include "builtin.h"
 #include "cache.h"
+#include "config.h"
 #include "refs.h"
+#include "object-store.h"
 #include "object.h"
 #include "tag.h"
 #include "string-list.h"
@@ -22,7 +24,7 @@ static void show_one(const char *refname
 	const char *hex;
 	struct object_id peeled;
 
-	if (!has_sha1_file(oid->hash))
+	if (!has_object_file(oid))
 		die("git show-ref: bad ref %s (%s)", refname,
 		    oid_to_hex(oid));
 
@@ -150,6 +152,7 @@ static int hash_callback(const struct op
 static int exclude_existing_callback(const struct option *opt, const char *arg,
 				     int unset)
 {
+	BUG_ON_OPT_NEG(unset);
 	exclude_arg = 1;
 	*(const char **)opt->value = arg;
 	return 0;
@@ -180,6 +183,8 @@ static const struct option show_ref_opti
 
 int cmd_show_ref(int argc, const char **argv, const char *prefix)
 {
+	git_config(git_default_config, NULL);
+
 	argc = parse_options(argc, argv, prefix, show_ref_options,
 			     show_ref_usage, 0);
 
diff -pruN 1.2.1+git2.18.0-1/git/builtin/sparse-checkout.c 1.2.3+git2.25.1-1/git/builtin/sparse-checkout.c
--- 1.2.1+git2.18.0-1/git/builtin/sparse-checkout.c	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/builtin/sparse-checkout.c	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,516 @@
+#include "builtin.h"
+#include "config.h"
+#include "dir.h"
+#include "parse-options.h"
+#include "pathspec.h"
+#include "repository.h"
+#include "run-command.h"
+#include "strbuf.h"
+#include "string-list.h"
+#include "cache.h"
+#include "cache-tree.h"
+#include "lockfile.h"
+#include "resolve-undo.h"
+#include "unpack-trees.h"
+#include "wt-status.h"
+
+static const char *empty_base = "";
+
+static char const * const builtin_sparse_checkout_usage[] = {
+	N_("git sparse-checkout (init|list|set|disable) <options>"),
+	NULL
+};
+
+static char *get_sparse_checkout_filename(void)
+{
+	return git_pathdup("info/sparse-checkout");
+}
+
+static void write_patterns_to_file(FILE *fp, struct pattern_list *pl)
+{
+	int i;
+
+	for (i = 0; i < pl->nr; i++) {
+		struct path_pattern *p = pl->patterns[i];
+
+		if (p->flags & PATTERN_FLAG_NEGATIVE)
+			fprintf(fp, "!");
+
+		fprintf(fp, "%s", p->pattern);
+
+		if (p->flags & PATTERN_FLAG_MUSTBEDIR)
+			fprintf(fp, "/");
+
+		fprintf(fp, "\n");
+	}
+}
+
+static int sparse_checkout_list(int argc, const char **argv)
+{
+	struct pattern_list pl;
+	char *sparse_filename;
+	int res;
+
+	memset(&pl, 0, sizeof(pl));
+
+	pl.use_cone_patterns = core_sparse_checkout_cone;
+
+	sparse_filename = get_sparse_checkout_filename();
+	res = add_patterns_from_file_to_list(sparse_filename, "", 0, &pl, NULL);
+	free(sparse_filename);
+
+	if (res < 0) {
+		warning(_("this worktree is not sparse (sparse-checkout file may not exist)"));
+		return 0;
+	}
+
+	if (pl.use_cone_patterns) {
+		int i;
+		struct pattern_entry *pe;
+		struct hashmap_iter iter;
+		struct string_list sl = STRING_LIST_INIT_DUP;
+
+		hashmap_for_each_entry(&pl.recursive_hashmap, &iter, pe, ent) {
+			/* pe->pattern starts with "/", skip it */
+			string_list_insert(&sl, pe->pattern + 1);
+		}
+
+		string_list_sort(&sl);
+
+		for (i = 0; i < sl.nr; i++)
+			printf("%s\n", sl.items[i].string);
+
+		return 0;
+	}
+
+	write_patterns_to_file(stdout, &pl);
+	clear_pattern_list(&pl);
+
+	return 0;
+}
+
+static int update_working_directory(struct pattern_list *pl)
+{
+	int result = 0;
+	struct unpack_trees_options o;
+	struct lock_file lock_file = LOCK_INIT;
+	struct object_id oid;
+	struct tree *tree;
+	struct tree_desc t;
+	struct repository *r = the_repository;
+
+	if (repo_read_index_unmerged(r))
+		die(_("you need to resolve your current index first"));
+
+	if (get_oid("HEAD", &oid))
+		return 0;
+
+	tree = parse_tree_indirect(&oid);
+	parse_tree(tree);
+	init_tree_desc(&t, tree->buffer, tree->size);
+
+	memset(&o, 0, sizeof(o));
+	o.verbose_update = isatty(2);
+	o.merge = 1;
+	o.update = 1;
+	o.fn = oneway_merge;
+	o.head_idx = -1;
+	o.src_index = r->index;
+	o.dst_index = r->index;
+	o.skip_sparse_checkout = 0;
+	o.pl = pl;
+	o.keep_pattern_list = !!pl;
+
+	resolve_undo_clear_index(r->index);
+	setup_work_tree();
+
+	cache_tree_free(&r->index->cache_tree);
+
+	repo_hold_locked_index(r, &lock_file, LOCK_DIE_ON_ERROR);
+
+	core_apply_sparse_checkout = 1;
+	result = unpack_trees(1, &t, &o);
+
+	if (!result) {
+		prime_cache_tree(r, r->index, tree);
+		write_locked_index(r->index, &lock_file, COMMIT_LOCK);
+	} else
+		rollback_lock_file(&lock_file);
+
+	return result;
+}
+
+static void write_cone_to_file(FILE *fp, struct pattern_list *pl)
+{
+	int i;
+	struct pattern_entry *pe;
+	struct hashmap_iter iter;
+	struct string_list sl = STRING_LIST_INIT_DUP;
+	struct strbuf parent_pattern = STRBUF_INIT;
+
+	hashmap_for_each_entry(&pl->parent_hashmap, &iter, pe, ent) {
+		if (hashmap_get_entry(&pl->recursive_hashmap, pe, ent, NULL))
+			continue;
+
+		if (!hashmap_contains_parent(&pl->recursive_hashmap,
+					     pe->pattern,
+					     &parent_pattern))
+			string_list_insert(&sl, pe->pattern);
+	}
+
+	string_list_sort(&sl);
+	string_list_remove_duplicates(&sl, 0);
+
+	fprintf(fp, "/*\n!/*/\n");
+
+	for (i = 0; i < sl.nr; i++) {
+		char *pattern = sl.items[i].string;
+
+		if (strlen(pattern))
+			fprintf(fp, "%s/\n!%s/*/\n", pattern, pattern);
+	}
+
+	string_list_clear(&sl, 0);
+
+	hashmap_for_each_entry(&pl->recursive_hashmap, &iter, pe, ent) {
+		if (!hashmap_contains_parent(&pl->recursive_hashmap,
+					     pe->pattern,
+					     &parent_pattern))
+			string_list_insert(&sl, pe->pattern);
+	}
+
+	strbuf_release(&parent_pattern);
+
+	string_list_sort(&sl);
+	string_list_remove_duplicates(&sl, 0);
+
+	for (i = 0; i < sl.nr; i++) {
+		char *pattern = sl.items[i].string;
+		fprintf(fp, "%s/\n", pattern);
+	}
+}
+
+static int write_patterns_and_update(struct pattern_list *pl)
+{
+	char *sparse_filename;
+	FILE *fp;
+	int fd;
+	struct lock_file lk = LOCK_INIT;
+	int result;
+
+	sparse_filename = get_sparse_checkout_filename();
+	fd = hold_lock_file_for_update(&lk, sparse_filename,
+				      LOCK_DIE_ON_ERROR);
+
+	result = update_working_directory(pl);
+	if (result) {
+		rollback_lock_file(&lk);
+		free(sparse_filename);
+		clear_pattern_list(pl);
+		update_working_directory(NULL);
+		return result;
+	}
+
+	fp = xfdopen(fd, "w");
+
+	if (core_sparse_checkout_cone)
+		write_cone_to_file(fp, pl);
+	else
+		write_patterns_to_file(fp, pl);
+
+	fflush(fp);
+	commit_lock_file(&lk);
+
+	free(sparse_filename);
+	clear_pattern_list(pl);
+
+	return 0;
+}
+
+enum sparse_checkout_mode {
+	MODE_NO_PATTERNS = 0,
+	MODE_ALL_PATTERNS = 1,
+	MODE_CONE_PATTERNS = 2,
+};
+
+static int set_config(enum sparse_checkout_mode mode)
+{
+	const char *config_path;
+
+	if (git_config_set_gently("extensions.worktreeConfig", "true")) {
+		error(_("failed to set extensions.worktreeConfig setting"));
+		return 1;
+	}
+
+	config_path = git_path("config.worktree");
+	git_config_set_in_file_gently(config_path,
+				      "core.sparseCheckout",
+				      mode ? "true" : NULL);
+
+	git_config_set_in_file_gently(config_path,
+				      "core.sparseCheckoutCone",
+				      mode == MODE_CONE_PATTERNS ? "true" : NULL);
+
+	return 0;
+}
+
+static char const * const builtin_sparse_checkout_init_usage[] = {
+	N_("git sparse-checkout init [--cone]"),
+	NULL
+};
+
+static struct sparse_checkout_init_opts {
+	int cone_mode;
+} init_opts;
+
+static int sparse_checkout_init(int argc, const char **argv)
+{
+	struct pattern_list pl;
+	char *sparse_filename;
+	int res;
+	struct object_id oid;
+	int mode;
+	struct strbuf pattern = STRBUF_INIT;
+
+	static struct option builtin_sparse_checkout_init_options[] = {
+		OPT_BOOL(0, "cone", &init_opts.cone_mode,
+			 N_("initialize the sparse-checkout in cone mode")),
+		OPT_END(),
+	};
+
+	repo_read_index(the_repository);
+	require_clean_work_tree(the_repository,
+				N_("initialize sparse-checkout"), NULL, 1, 0);
+
+	argc = parse_options(argc, argv, NULL,
+			     builtin_sparse_checkout_init_options,
+			     builtin_sparse_checkout_init_usage, 0);
+
+	if (init_opts.cone_mode) {
+		mode = MODE_CONE_PATTERNS;
+		core_sparse_checkout_cone = 1;
+	} else
+		mode = MODE_ALL_PATTERNS;
+
+	if (set_config(mode))
+		return 1;
+
+	memset(&pl, 0, sizeof(pl));
+
+	sparse_filename = get_sparse_checkout_filename();
+	res = add_patterns_from_file_to_list(sparse_filename, "", 0, &pl, NULL);
+
+	/* If we already have a sparse-checkout file, use it. */
+	if (res >= 0) {
+		free(sparse_filename);
+		core_apply_sparse_checkout = 1;
+		return update_working_directory(NULL);
+	}
+
+	if (get_oid("HEAD", &oid)) {
+		FILE *fp;
+
+		/* assume we are in a fresh repo, but update the sparse-checkout file */
+		fp = xfopen(sparse_filename, "w");
+		if (!fp)
+			die(_("failed to open '%s'"), sparse_filename);
+
+		free(sparse_filename);
+		fprintf(fp, "/*\n!/*/\n");
+		fclose(fp);
+		return 0;
+	}
+
+	strbuf_addstr(&pattern, "/*");
+	add_pattern(strbuf_detach(&pattern, NULL), empty_base, 0, &pl, 0);
+	strbuf_addstr(&pattern, "!/*/");
+	add_pattern(strbuf_detach(&pattern, NULL), empty_base, 0, &pl, 0);
+
+	return write_patterns_and_update(&pl);
+}
+
+static void insert_recursive_pattern(struct pattern_list *pl, struct strbuf *path)
+{
+	struct pattern_entry *e = xmalloc(sizeof(*e));
+	e->patternlen = path->len;
+	e->pattern = strbuf_detach(path, NULL);
+	hashmap_entry_init(&e->ent,
+			   ignore_case ?
+			   strihash(e->pattern) :
+			   strhash(e->pattern));
+
+	hashmap_add(&pl->recursive_hashmap, &e->ent);
+
+	while (e->patternlen) {
+		char *slash = strrchr(e->pattern, '/');
+		char *oldpattern = e->pattern;
+		size_t newlen;
+
+		if (slash == e->pattern)
+			break;
+
+		newlen = slash - e->pattern;
+		e = xmalloc(sizeof(struct pattern_entry));
+		e->patternlen = newlen;
+		e->pattern = xstrndup(oldpattern, newlen);
+		hashmap_entry_init(&e->ent,
+				   ignore_case ?
+				   strihash(e->pattern) :
+				   strhash(e->pattern));
+
+		if (!hashmap_get_entry(&pl->parent_hashmap, e, ent, NULL))
+			hashmap_add(&pl->parent_hashmap, &e->ent);
+	}
+}
+
+static void strbuf_to_cone_pattern(struct strbuf *line, struct pattern_list *pl)
+{
+	strbuf_trim(line);
+
+	strbuf_trim_trailing_dir_sep(line);
+
+	if (!line->len)
+		return;
+
+	if (line->buf[0] != '/')
+		strbuf_insert(line, 0, "/", 1);
+
+	insert_recursive_pattern(pl, line);
+}
+
+static char const * const builtin_sparse_checkout_set_usage[] = {
+	N_("git sparse-checkout set (--stdin | <patterns>)"),
+	NULL
+};
+
+static struct sparse_checkout_set_opts {
+	int use_stdin;
+} set_opts;
+
+static int sparse_checkout_set(int argc, const char **argv, const char *prefix)
+{
+	int i;
+	struct pattern_list pl;
+	int result;
+	int changed_config = 0;
+
+	static struct option builtin_sparse_checkout_set_options[] = {
+		OPT_BOOL(0, "stdin", &set_opts.use_stdin,
+			 N_("read patterns from standard in")),
+		OPT_END(),
+	};
+
+	repo_read_index(the_repository);
+	require_clean_work_tree(the_repository,
+				N_("set sparse-checkout patterns"), NULL, 1, 0);
+
+	memset(&pl, 0, sizeof(pl));
+
+	argc = parse_options(argc, argv, prefix,
+			     builtin_sparse_checkout_set_options,
+			     builtin_sparse_checkout_set_usage,
+			     PARSE_OPT_KEEP_UNKNOWN);
+
+	if (core_sparse_checkout_cone) {
+		struct strbuf line = STRBUF_INIT;
+
+		hashmap_init(&pl.recursive_hashmap, pl_hashmap_cmp, NULL, 0);
+		hashmap_init(&pl.parent_hashmap, pl_hashmap_cmp, NULL, 0);
+		pl.use_cone_patterns = 1;
+
+		if (set_opts.use_stdin) {
+			while (!strbuf_getline(&line, stdin))
+				strbuf_to_cone_pattern(&line, &pl);
+		} else {
+			for (i = 0; i < argc; i++) {
+				strbuf_setlen(&line, 0);
+				strbuf_addstr(&line, argv[i]);
+				strbuf_to_cone_pattern(&line, &pl);
+			}
+		}
+	} else {
+		if (set_opts.use_stdin) {
+			struct strbuf line = STRBUF_INIT;
+
+			while (!strbuf_getline(&line, stdin)) {
+				size_t len;
+				char *buf = strbuf_detach(&line, &len);
+				add_pattern(buf, empty_base, 0, &pl, 0);
+			}
+		} else {
+			for (i = 0; i < argc; i++)
+				add_pattern(argv[i], empty_base, 0, &pl, 0);
+		}
+	}
+
+	if (!core_apply_sparse_checkout) {
+		set_config(MODE_ALL_PATTERNS);
+		core_apply_sparse_checkout = 1;
+		changed_config = 1;
+	}
+
+	result = write_patterns_and_update(&pl);
+
+	if (result && changed_config)
+		set_config(MODE_NO_PATTERNS);
+
+	clear_pattern_list(&pl);
+	return result;
+}
+
+static int sparse_checkout_disable(int argc, const char **argv)
+{
+	struct pattern_list pl;
+	struct strbuf match_all = STRBUF_INIT;
+
+	repo_read_index(the_repository);
+	require_clean_work_tree(the_repository,
+				N_("disable sparse-checkout"), NULL, 1, 0);
+
+	memset(&pl, 0, sizeof(pl));
+	hashmap_init(&pl.recursive_hashmap, pl_hashmap_cmp, NULL, 0);
+	hashmap_init(&pl.parent_hashmap, pl_hashmap_cmp, NULL, 0);
+	pl.use_cone_patterns = 0;
+	core_apply_sparse_checkout = 1;
+
+	strbuf_addstr(&match_all, "/*");
+	add_pattern(strbuf_detach(&match_all, NULL), empty_base, 0, &pl, 0);
+
+	if (update_working_directory(&pl))
+		die(_("error while refreshing working directory"));
+
+	clear_pattern_list(&pl);
+	return set_config(MODE_NO_PATTERNS);
+}
+
+int cmd_sparse_checkout(int argc, const char **argv, const char *prefix)
+{
+	static struct option builtin_sparse_checkout_options[] = {
+		OPT_END(),
+	};
+
+	if (argc == 2 && !strcmp(argv[1], "-h"))
+		usage_with_options(builtin_sparse_checkout_usage,
+				   builtin_sparse_checkout_options);
+
+	argc = parse_options(argc, argv, prefix,
+			     builtin_sparse_checkout_options,
+			     builtin_sparse_checkout_usage,
+			     PARSE_OPT_STOP_AT_NON_OPTION);
+
+	git_config(git_default_config, NULL);
+
+	if (argc > 0) {
+		if (!strcmp(argv[0], "list"))
+			return sparse_checkout_list(argc, argv);
+		if (!strcmp(argv[0], "init"))
+			return sparse_checkout_init(argc, argv);
+		if (!strcmp(argv[0], "set"))
+			return sparse_checkout_set(argc, argv, prefix);
+		if (!strcmp(argv[0], "disable"))
+			return sparse_checkout_disable(argc, argv);
+	}
+
+	usage_with_options(builtin_sparse_checkout_usage,
+			   builtin_sparse_checkout_options);
+}
diff -pruN 1.2.1+git2.18.0-1/git/builtin/stash.c 1.2.3+git2.25.1-1/git/builtin/stash.c
--- 1.2.1+git2.18.0-1/git/builtin/stash.c	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/builtin/stash.c	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,1644 @@
+#define USE_THE_INDEX_COMPATIBILITY_MACROS
+#include "builtin.h"
+#include "config.h"
+#include "parse-options.h"
+#include "refs.h"
+#include "lockfile.h"
+#include "cache-tree.h"
+#include "unpack-trees.h"
+#include "merge-recursive.h"
+#include "argv-array.h"
+#include "run-command.h"
+#include "dir.h"
+#include "rerere.h"
+#include "revision.h"
+#include "log-tree.h"
+#include "diffcore.h"
+#include "exec-cmd.h"
+
+#define INCLUDE_ALL_FILES 2
+
+static const char * const git_stash_usage[] = {
+	N_("git stash list [<options>]"),
+	N_("git stash show [<options>] [<stash>]"),
+	N_("git stash drop [-q|--quiet] [<stash>]"),
+	N_("git stash ( pop | apply ) [--index] [-q|--quiet] [<stash>]"),
+	N_("git stash branch <branchname> [<stash>]"),
+	N_("git stash clear"),
+	N_("git stash [push [-p|--patch] [-k|--[no-]keep-index] [-q|--quiet]\n"
+	   "          [-u|--include-untracked] [-a|--all] [-m|--message <message>]\n"
+	   "          [--] [<pathspec>...]]"),
+	N_("git stash save [-p|--patch] [-k|--[no-]keep-index] [-q|--quiet]\n"
+	   "          [-u|--include-untracked] [-a|--all] [<message>]"),
+	NULL
+};
+
+static const char * const git_stash_list_usage[] = {
+	N_("git stash list [<options>]"),
+	NULL
+};
+
+static const char * const git_stash_show_usage[] = {
+	N_("git stash show [<options>] [<stash>]"),
+	NULL
+};
+
+static const char * const git_stash_drop_usage[] = {
+	N_("git stash drop [-q|--quiet] [<stash>]"),
+	NULL
+};
+
+static const char * const git_stash_pop_usage[] = {
+	N_("git stash pop [--index] [-q|--quiet] [<stash>]"),
+	NULL
+};
+
+static const char * const git_stash_apply_usage[] = {
+	N_("git stash apply [--index] [-q|--quiet] [<stash>]"),
+	NULL
+};
+
+static const char * const git_stash_branch_usage[] = {
+	N_("git stash branch <branchname> [<stash>]"),
+	NULL
+};
+
+static const char * const git_stash_clear_usage[] = {
+	N_("git stash clear"),
+	NULL
+};
+
+static const char * const git_stash_store_usage[] = {
+	N_("git stash store [-m|--message <message>] [-q|--quiet] <commit>"),
+	NULL
+};
+
+static const char * const git_stash_push_usage[] = {
+	N_("git stash [push [-p|--patch] [-k|--[no-]keep-index] [-q|--quiet]\n"
+	   "          [-u|--include-untracked] [-a|--all] [-m|--message <message>]\n"
+	   "          [--] [<pathspec>...]]"),
+	NULL
+};
+
+static const char * const git_stash_save_usage[] = {
+	N_("git stash save [-p|--patch] [-k|--[no-]keep-index] [-q|--quiet]\n"
+	   "          [-u|--include-untracked] [-a|--all] [<message>]"),
+	NULL
+};
+
+static const char *ref_stash = "refs/stash";
+static struct strbuf stash_index_path = STRBUF_INIT;
+
+/*
+ * w_commit is set to the commit containing the working tree
+ * b_commit is set to the base commit
+ * i_commit is set to the commit containing the index tree
+ * u_commit is set to the commit containing the untracked files tree
+ * w_tree is set to the working tree
+ * b_tree is set to the base tree
+ * i_tree is set to the index tree
+ * u_tree is set to the untracked files tree
+ */
+struct stash_info {
+	struct object_id w_commit;
+	struct object_id b_commit;
+	struct object_id i_commit;
+	struct object_id u_commit;
+	struct object_id w_tree;
+	struct object_id b_tree;
+	struct object_id i_tree;
+	struct object_id u_tree;
+	struct strbuf revision;
+	int is_stash_ref;
+	int has_u;
+};
+
+static void free_stash_info(struct stash_info *info)
+{
+	strbuf_release(&info->revision);
+}
+
+static void assert_stash_like(struct stash_info *info, const char *revision)
+{
+	if (get_oidf(&info->b_commit, "%s^1", revision) ||
+	    get_oidf(&info->w_tree, "%s:", revision) ||
+	    get_oidf(&info->b_tree, "%s^1:", revision) ||
+	    get_oidf(&info->i_tree, "%s^2:", revision))
+		die(_("'%s' is not a stash-like commit"), revision);
+}
+
+static int get_stash_info(struct stash_info *info, int argc, const char **argv)
+{
+	int ret;
+	char *end_of_rev;
+	char *expanded_ref;
+	const char *revision;
+	const char *commit = NULL;
+	struct object_id dummy;
+	struct strbuf symbolic = STRBUF_INIT;
+
+	if (argc > 1) {
+		int i;
+		struct strbuf refs_msg = STRBUF_INIT;
+
+		for (i = 0; i < argc; i++)
+			strbuf_addf(&refs_msg, " '%s'", argv[i]);
+
+		fprintf_ln(stderr, _("Too many revisions specified:%s"),
+			   refs_msg.buf);
+		strbuf_release(&refs_msg);
+
+		return -1;
+	}
+
+	if (argc == 1)
+		commit = argv[0];
+
+	strbuf_init(&info->revision, 0);
+	if (!commit) {
+		if (!ref_exists(ref_stash)) {
+			free_stash_info(info);
+			fprintf_ln(stderr, _("No stash entries found."));
+			return -1;
+		}
+
+		strbuf_addf(&info->revision, "%s@{0}", ref_stash);
+	} else if (strspn(commit, "0123456789") == strlen(commit)) {
+		strbuf_addf(&info->revision, "%s@{%s}", ref_stash, commit);
+	} else {
+		strbuf_addstr(&info->revision, commit);
+	}
+
+	revision = info->revision.buf;
+
+	if (get_oid(revision, &info->w_commit)) {
+		error(_("%s is not a valid reference"), revision);
+		free_stash_info(info);
+		return -1;
+	}
+
+	assert_stash_like(info, revision);
+
+	info->has_u = !get_oidf(&info->u_tree, "%s^3:", revision);
+
+	end_of_rev = strchrnul(revision, '@');
+	strbuf_add(&symbolic, revision, end_of_rev - revision);
+
+	ret = dwim_ref(symbolic.buf, symbolic.len, &dummy, &expanded_ref);
+	strbuf_release(&symbolic);
+	switch (ret) {
+	case 0: /* Not found, but valid ref */
+		info->is_stash_ref = 0;
+		break;
+	case 1:
+		info->is_stash_ref = !strcmp(expanded_ref, ref_stash);
+		break;
+	default: /* Invalid or ambiguous */
+		free_stash_info(info);
+	}
+
+	free(expanded_ref);
+	return !(ret == 0 || ret == 1);
+}
+
+static int do_clear_stash(void)
+{
+	struct object_id obj;
+	if (get_oid(ref_stash, &obj))
+		return 0;
+
+	return delete_ref(NULL, ref_stash, &obj, 0);
+}
+
+static int clear_stash(int argc, const char **argv, const char *prefix)
+{
+	struct option options[] = {
+		OPT_END()
+	};
+
+	argc = parse_options(argc, argv, prefix, options,
+			     git_stash_clear_usage,
+			     PARSE_OPT_STOP_AT_NON_OPTION);
+
+	if (argc)
+		return error(_("git stash clear with parameters is "
+			       "unimplemented"));
+
+	return do_clear_stash();
+}
+
+static int reset_tree(struct object_id *i_tree, int update, int reset)
+{
+	int nr_trees = 1;
+	struct unpack_trees_options opts;
+	struct tree_desc t[MAX_UNPACK_TREES];
+	struct tree *tree;
+	struct lock_file lock_file = LOCK_INIT;
+
+	read_cache_preload(NULL);
+	if (refresh_cache(REFRESH_QUIET))
+		return -1;
+
+	hold_locked_index(&lock_file, LOCK_DIE_ON_ERROR);
+
+	memset(&opts, 0, sizeof(opts));
+
+	tree = parse_tree_indirect(i_tree);
+	if (parse_tree(tree))
+		return -1;
+
+	init_tree_desc(t, tree->buffer, tree->size);
+
+	opts.head_idx = 1;
+	opts.src_index = &the_index;
+	opts.dst_index = &the_index;
+	opts.merge = 1;
+	opts.reset = reset;
+	opts.update = update;
+	opts.fn = oneway_merge;
+
+	if (unpack_trees(nr_trees, t, &opts))
+		return -1;
+
+	if (write_locked_index(&the_index, &lock_file, COMMIT_LOCK))
+		return error(_("unable to write new index file"));
+
+	return 0;
+}
+
+static int diff_tree_binary(struct strbuf *out, struct object_id *w_commit)
+{
+	struct child_process cp = CHILD_PROCESS_INIT;
+	const char *w_commit_hex = oid_to_hex(w_commit);
+
+	/*
+	 * Diff-tree would not be very hard to replace with a native function,
+	 * however it should be done together with apply_cached.
+	 */
+	cp.git_cmd = 1;
+	argv_array_pushl(&cp.args, "diff-tree", "--binary", NULL);
+	argv_array_pushf(&cp.args, "%s^2^..%s^2", w_commit_hex, w_commit_hex);
+
+	return pipe_command(&cp, NULL, 0, out, 0, NULL, 0);
+}
+
+static int apply_cached(struct strbuf *out)
+{
+	struct child_process cp = CHILD_PROCESS_INIT;
+
+	/*
+	 * Apply currently only reads either from stdin or a file, thus
+	 * apply_all_patches would have to be updated to optionally take a
+	 * buffer.
+	 */
+	cp.git_cmd = 1;
+	argv_array_pushl(&cp.args, "apply", "--cached", NULL);
+	return pipe_command(&cp, out->buf, out->len, NULL, 0, NULL, 0);
+}
+
+static int reset_head(void)
+{
+	struct child_process cp = CHILD_PROCESS_INIT;
+
+	/*
+	 * Reset is overall quite simple, however there is no current public
+	 * API for resetting.
+	 */
+	cp.git_cmd = 1;
+	argv_array_push(&cp.args, "reset");
+
+	return run_command(&cp);
+}
+
+static void add_diff_to_buf(struct diff_queue_struct *q,
+			    struct diff_options *options,
+			    void *data)
+{
+	int i;
+
+	for (i = 0; i < q->nr; i++) {
+		strbuf_addstr(data, q->queue[i]->one->path);
+
+		/* NUL-terminate: will be fed to update-index -z */
+		strbuf_addch(data, '\0');
+	}
+}
+
+static int get_newly_staged(struct strbuf *out, struct object_id *c_tree)
+{
+	struct child_process cp = CHILD_PROCESS_INIT;
+	const char *c_tree_hex = oid_to_hex(c_tree);
+
+	/*
+	 * diff-index is very similar to diff-tree above, and should be
+	 * converted together with update_index.
+	 */
+	cp.git_cmd = 1;
+	argv_array_pushl(&cp.args, "diff-index", "--cached", "--name-only",
+			 "--diff-filter=A", NULL);
+	argv_array_push(&cp.args, c_tree_hex);
+	return pipe_command(&cp, NULL, 0, out, 0, NULL, 0);
+}
+
+static int update_index(struct strbuf *out)
+{
+	struct child_process cp = CHILD_PROCESS_INIT;
+
+	/*
+	 * Update-index is very complicated and may need to have a public
+	 * function exposed in order to remove this forking.
+	 */
+	cp.git_cmd = 1;
+	argv_array_pushl(&cp.args, "update-index", "--add", "--stdin", NULL);
+	return pipe_command(&cp, out->buf, out->len, NULL, 0, NULL, 0);
+}
+
+static int restore_untracked(struct object_id *u_tree)
+{
+	int res;
+	struct child_process cp = CHILD_PROCESS_INIT;
+
+	/*
+	 * We need to run restore files from a given index, but without
+	 * affecting the current index, so we use GIT_INDEX_FILE with
+	 * run_command to fork processes that will not interfere.
+	 */
+	cp.git_cmd = 1;
+	argv_array_push(&cp.args, "read-tree");
+	argv_array_push(&cp.args, oid_to_hex(u_tree));
+	argv_array_pushf(&cp.env_array, "GIT_INDEX_FILE=%s",
+			 stash_index_path.buf);
+	if (run_command(&cp)) {
+		remove_path(stash_index_path.buf);
+		return -1;
+	}
+
+	child_process_init(&cp);
+	cp.git_cmd = 1;
+	argv_array_pushl(&cp.args, "checkout-index", "--all", NULL);
+	argv_array_pushf(&cp.env_array, "GIT_INDEX_FILE=%s",
+			 stash_index_path.buf);
+
+	res = run_command(&cp);
+	remove_path(stash_index_path.buf);
+	return res;
+}
+
+static int do_apply_stash(const char *prefix, struct stash_info *info,
+			  int index, int quiet)
+{
+	int ret;
+	int has_index = index;
+	struct merge_options o;
+	struct object_id c_tree;
+	struct object_id index_tree;
+	struct commit *result;
+	const struct object_id *bases[1];
+
+	read_cache_preload(NULL);
+	if (refresh_and_write_cache(REFRESH_QUIET, 0, 0))
+		return -1;
+
+	if (write_cache_as_tree(&c_tree, 0, NULL))
+		return error(_("cannot apply a stash in the middle of a merge"));
+
+	if (index) {
+		if (oideq(&info->b_tree, &info->i_tree) ||
+		    oideq(&c_tree, &info->i_tree)) {
+			has_index = 0;
+		} else {
+			struct strbuf out = STRBUF_INIT;
+
+			if (diff_tree_binary(&out, &info->w_commit)) {
+				strbuf_release(&out);
+				return error(_("could not generate diff %s^!."),
+					     oid_to_hex(&info->w_commit));
+			}
+
+			ret = apply_cached(&out);
+			strbuf_release(&out);
+			if (ret)
+				return error(_("conflicts in index."
+					       "Try without --index."));
+
+			discard_cache();
+			read_cache();
+			if (write_cache_as_tree(&index_tree, 0, NULL))
+				return error(_("could not save index tree"));
+
+			reset_head();
+			discard_cache();
+			read_cache();
+		}
+	}
+
+	if (info->has_u && restore_untracked(&info->u_tree))
+		return error(_("could not restore untracked files from stash"));
+
+	init_merge_options(&o, the_repository);
+
+	o.branch1 = "Updated upstream";
+	o.branch2 = "Stashed changes";
+
+	if (oideq(&info->b_tree, &c_tree))
+		o.branch1 = "Version stash was based on";
+
+	if (quiet)
+		o.verbosity = 0;
+
+	if (o.verbosity >= 3)
+		printf_ln(_("Merging %s with %s"), o.branch1, o.branch2);
+
+	bases[0] = &info->b_tree;
+
+	ret = merge_recursive_generic(&o, &c_tree, &info->w_tree, 1, bases,
+				      &result);
+	if (ret) {
+		rerere(0);
+
+		if (index)
+			fprintf_ln(stderr, _("Index was not unstashed."));
+
+		return ret;
+	}
+
+	if (has_index) {
+		if (reset_tree(&index_tree, 0, 0))
+			return -1;
+	} else {
+		struct strbuf out = STRBUF_INIT;
+
+		if (get_newly_staged(&out, &c_tree)) {
+			strbuf_release(&out);
+			return -1;
+		}
+
+		if (reset_tree(&c_tree, 0, 1)) {
+			strbuf_release(&out);
+			return -1;
+		}
+
+		ret = update_index(&out);
+		strbuf_release(&out);
+		if (ret)
+			return -1;
+
+		/* read back the result of update_index() back from the disk */
+		discard_cache();
+		read_cache();
+	}
+
+	if (!quiet) {
+		struct child_process cp = CHILD_PROCESS_INIT;
+
+		/*
+		 * Status is quite simple and could be replaced with calls to
+		 * wt_status in the future, but it adds complexities which may
+		 * require more tests.
+		 */
+		cp.git_cmd = 1;
+		cp.dir = prefix;
+		argv_array_pushf(&cp.env_array, GIT_WORK_TREE_ENVIRONMENT"=%s",
+				 absolute_path(get_git_work_tree()));
+		argv_array_pushf(&cp.env_array, GIT_DIR_ENVIRONMENT"=%s",
+				 absolute_path(get_git_dir()));
+		argv_array_push(&cp.args, "status");
+		run_command(&cp);
+	}
+
+	return 0;
+}
+
+static int apply_stash(int argc, const char **argv, const char *prefix)
+{
+	int ret;
+	int quiet = 0;
+	int index = 0;
+	struct stash_info info;
+	struct option options[] = {
+		OPT__QUIET(&quiet, N_("be quiet, only report errors")),
+		OPT_BOOL(0, "index", &index,
+			 N_("attempt to recreate the index")),
+		OPT_END()
+	};
+
+	argc = parse_options(argc, argv, prefix, options,
+			     git_stash_apply_usage, 0);
+
+	if (get_stash_info(&info, argc, argv))
+		return -1;
+
+	ret = do_apply_stash(prefix, &info, index, quiet);
+	free_stash_info(&info);
+	return ret;
+}
+
+static int do_drop_stash(struct stash_info *info, int quiet)
+{
+	int ret;
+	struct child_process cp_reflog = CHILD_PROCESS_INIT;
+	struct child_process cp = CHILD_PROCESS_INIT;
+
+	/*
+	 * reflog does not provide a simple function for deleting refs. One will
+	 * need to be added to avoid implementing too much reflog code here
+	 */
+
+	cp_reflog.git_cmd = 1;
+	argv_array_pushl(&cp_reflog.args, "reflog", "delete", "--updateref",
+			 "--rewrite", NULL);
+	argv_array_push(&cp_reflog.args, info->revision.buf);
+	ret = run_command(&cp_reflog);
+	if (!ret) {
+		if (!quiet)
+			printf_ln(_("Dropped %s (%s)"), info->revision.buf,
+				  oid_to_hex(&info->w_commit));
+	} else {
+		return error(_("%s: Could not drop stash entry"),
+			     info->revision.buf);
+	}
+
+	/*
+	 * This could easily be replaced by get_oid, but currently it will throw
+	 * a fatal error when a reflog is empty, which we can not recover from.
+	 */
+	cp.git_cmd = 1;
+	/* Even though --quiet is specified, rev-parse still outputs the hash */
+	cp.no_stdout = 1;
+	argv_array_pushl(&cp.args, "rev-parse", "--verify", "--quiet", NULL);
+	argv_array_pushf(&cp.args, "%s@{0}", ref_stash);
+	ret = run_command(&cp);
+
+	/* do_clear_stash if we just dropped the last stash entry */
+	if (ret)
+		do_clear_stash();
+
+	return 0;
+}
+
+static void assert_stash_ref(struct stash_info *info)
+{
+	if (!info->is_stash_ref) {
+		error(_("'%s' is not a stash reference"), info->revision.buf);
+		free_stash_info(info);
+		exit(1);
+	}
+}
+
+static int drop_stash(int argc, const char **argv, const char *prefix)
+{
+	int ret;
+	int quiet = 0;
+	struct stash_info info;
+	struct option options[] = {
+		OPT__QUIET(&quiet, N_("be quiet, only report errors")),
+		OPT_END()
+	};
+
+	argc = parse_options(argc, argv, prefix, options,
+			     git_stash_drop_usage, 0);
+
+	if (get_stash_info(&info, argc, argv))
+		return -1;
+
+	assert_stash_ref(&info);
+
+	ret = do_drop_stash(&info, quiet);
+	free_stash_info(&info);
+	return ret;
+}
+
+static int pop_stash(int argc, const char **argv, const char *prefix)
+{
+	int ret;
+	int index = 0;
+	int quiet = 0;
+	struct stash_info info;
+	struct option options[] = {
+		OPT__QUIET(&quiet, N_("be quiet, only report errors")),
+		OPT_BOOL(0, "index", &index,
+			 N_("attempt to recreate the index")),
+		OPT_END()
+	};
+
+	argc = parse_options(argc, argv, prefix, options,
+			     git_stash_pop_usage, 0);
+
+	if (get_stash_info(&info, argc, argv))
+		return -1;
+
+	assert_stash_ref(&info);
+	if ((ret = do_apply_stash(prefix, &info, index, quiet)))
+		printf_ln(_("The stash entry is kept in case "
+			    "you need it again."));
+	else
+		ret = do_drop_stash(&info, quiet);
+
+	free_stash_info(&info);
+	return ret;
+}
+
+static int branch_stash(int argc, const char **argv, const char *prefix)
+{
+	int ret;
+	const char *branch = NULL;
+	struct stash_info info;
+	struct child_process cp = CHILD_PROCESS_INIT;
+	struct option options[] = {
+		OPT_END()
+	};
+
+	argc = parse_options(argc, argv, prefix, options,
+			     git_stash_branch_usage, 0);
+
+	if (!argc) {
+		fprintf_ln(stderr, _("No branch name specified"));
+		return -1;
+	}
+
+	branch = argv[0];
+
+	if (get_stash_info(&info, argc - 1, argv + 1))
+		return -1;
+
+	cp.git_cmd = 1;
+	argv_array_pushl(&cp.args, "checkout", "-b", NULL);
+	argv_array_push(&cp.args, branch);
+	argv_array_push(&cp.args, oid_to_hex(&info.b_commit));
+	ret = run_command(&cp);
+	if (!ret)
+		ret = do_apply_stash(prefix, &info, 1, 0);
+	if (!ret && info.is_stash_ref)
+		ret = do_drop_stash(&info, 0);
+
+	free_stash_info(&info);
+
+	return ret;
+}
+
+static int list_stash(int argc, const char **argv, const char *prefix)
+{
+	struct child_process cp = CHILD_PROCESS_INIT;
+	struct option options[] = {
+		OPT_END()
+	};
+
+	argc = parse_options(argc, argv, prefix, options,
+			     git_stash_list_usage,
+			     PARSE_OPT_KEEP_UNKNOWN);
+
+	if (!ref_exists(ref_stash))
+		return 0;
+
+	cp.git_cmd = 1;
+	argv_array_pushl(&cp.args, "log", "--format=%gd: %gs", "-g",
+			 "--first-parent", "-m", NULL);
+	argv_array_pushv(&cp.args, argv);
+	argv_array_push(&cp.args, ref_stash);
+	argv_array_push(&cp.args, "--");
+	return run_command(&cp);
+}
+
+static int show_stat = 1;
+static int show_patch;
+
+static int git_stash_config(const char *var, const char *value, void *cb)
+{
+	if (!strcmp(var, "stash.showstat")) {
+		show_stat = git_config_bool(var, value);
+		return 0;
+	}
+	if (!strcmp(var, "stash.showpatch")) {
+		show_patch = git_config_bool(var, value);
+		return 0;
+	}
+	return git_default_config(var, value, cb);
+}
+
+static int show_stash(int argc, const char **argv, const char *prefix)
+{
+	int i;
+	int ret = 0;
+	struct stash_info info;
+	struct rev_info rev;
+	struct argv_array stash_args = ARGV_ARRAY_INIT;
+	struct argv_array revision_args = ARGV_ARRAY_INIT;
+	struct option options[] = {
+		OPT_END()
+	};
+
+	init_diff_ui_defaults();
+	git_config(git_diff_ui_config, NULL);
+	init_revisions(&rev, prefix);
+
+	argv_array_push(&revision_args, argv[0]);
+	for (i = 1; i < argc; i++) {
+		if (argv[i][0] != '-')
+			argv_array_push(&stash_args, argv[i]);
+		else
+			argv_array_push(&revision_args, argv[i]);
+	}
+
+	ret = get_stash_info(&info, stash_args.argc, stash_args.argv);
+	argv_array_clear(&stash_args);
+	if (ret)
+		return -1;
+
+	/*
+	 * The config settings are applied only if there are not passed
+	 * any options.
+	 */
+	if (revision_args.argc == 1) {
+		git_config(git_stash_config, NULL);
+		if (show_stat)
+			rev.diffopt.output_format = DIFF_FORMAT_DIFFSTAT;
+
+		if (show_patch)
+			rev.diffopt.output_format |= DIFF_FORMAT_PATCH;
+
+		if (!show_stat && !show_patch) {
+			free_stash_info(&info);
+			return 0;
+		}
+	}
+
+	argc = setup_revisions(revision_args.argc, revision_args.argv, &rev, NULL);
+	if (argc > 1) {
+		free_stash_info(&info);
+		usage_with_options(git_stash_show_usage, options);
+	}
+	if (!rev.diffopt.output_format) {
+		rev.diffopt.output_format = DIFF_FORMAT_PATCH;
+		diff_setup_done(&rev.diffopt);
+	}
+
+	rev.diffopt.flags.recursive = 1;
+	setup_diff_pager(&rev.diffopt);
+	diff_tree_oid(&info.b_commit, &info.w_commit, "", &rev.diffopt);
+	log_tree_diff_flush(&rev);
+
+	free_stash_info(&info);
+	return diff_result_code(&rev.diffopt, 0);
+}
+
+static int do_store_stash(const struct object_id *w_commit, const char *stash_msg,
+			  int quiet)
+{
+	if (!stash_msg)
+		stash_msg = "Created via \"git stash store\".";
+
+	if (update_ref(stash_msg, ref_stash, w_commit, NULL,
+		       REF_FORCE_CREATE_REFLOG,
+		       quiet ? UPDATE_REFS_QUIET_ON_ERR :
+		       UPDATE_REFS_MSG_ON_ERR)) {
+		if (!quiet) {
+			fprintf_ln(stderr, _("Cannot update %s with %s"),
+				   ref_stash, oid_to_hex(w_commit));
+		}
+		return -1;
+	}
+
+	return 0;
+}
+
+static int store_stash(int argc, const char **argv, const char *prefix)
+{
+	int quiet = 0;
+	const char *stash_msg = NULL;
+	struct object_id obj;
+	struct object_context dummy;
+	struct option options[] = {
+		OPT__QUIET(&quiet, N_("be quiet")),
+		OPT_STRING('m', "message", &stash_msg, "message",
+			   N_("stash message")),
+		OPT_END()
+	};
+
+	argc = parse_options(argc, argv, prefix, options,
+			     git_stash_store_usage,
+			     PARSE_OPT_KEEP_UNKNOWN);
+
+	if (argc != 1) {
+		if (!quiet)
+			fprintf_ln(stderr, _("\"git stash store\" requires one "
+					     "<commit> argument"));
+		return -1;
+	}
+
+	if (get_oid_with_context(the_repository,
+				 argv[0], quiet ? GET_OID_QUIETLY : 0, &obj,
+				 &dummy)) {
+		if (!quiet)
+			fprintf_ln(stderr, _("Cannot update %s with %s"),
+					     ref_stash, argv[0]);
+		return -1;
+	}
+
+	return do_store_stash(&obj, stash_msg, quiet);
+}
+
+static void add_pathspecs(struct argv_array *args,
+			  const struct pathspec *ps) {
+	int i;
+
+	for (i = 0; i < ps->nr; i++)
+		argv_array_push(args, ps->items[i].original);
+}
+
+/*
+ * `untracked_files` will be filled with the names of untracked files.
+ * The return value is:
+ *
+ * = 0 if there are not any untracked files
+ * > 0 if there are untracked files
+ */
+static int get_untracked_files(const struct pathspec *ps, int include_untracked,
+			       struct strbuf *untracked_files)
+{
+	int i;
+	int max_len;
+	int found = 0;
+	char *seen;
+	struct dir_struct dir;
+
+	memset(&dir, 0, sizeof(dir));
+	if (include_untracked != INCLUDE_ALL_FILES)
+		setup_standard_excludes(&dir);
+
+	seen = xcalloc(ps->nr, 1);
+
+	max_len = fill_directory(&dir, the_repository->index, ps);
+	for (i = 0; i < dir.nr; i++) {
+		struct dir_entry *ent = dir.entries[i];
+		if (dir_path_match(&the_index, ent, ps, max_len, seen)) {
+			found++;
+			strbuf_addstr(untracked_files, ent->name);
+			/* NUL-terminate: will be fed to update-index -z */
+			strbuf_addch(untracked_files, '\0');
+		}
+		free(ent);
+	}
+
+	free(seen);
+	free(dir.entries);
+	free(dir.ignored);
+	clear_directory(&dir);
+	return found;
+}
+
+/*
+ * The return value of `check_changes_tracked_files()` can be:
+ *
+ * < 0 if there was an error
+ * = 0 if there are no changes.
+ * > 0 if there are changes.
+ */
+static int check_changes_tracked_files(const struct pathspec *ps)
+{
+	int result;
+	struct rev_info rev;
+	struct object_id dummy;
+	int ret = 0;
+
+	/* No initial commit. */
+	if (get_oid("HEAD", &dummy))
+		return -1;
+
+	if (read_cache() < 0)
+		return -1;
+
+	init_revisions(&rev, NULL);
+	copy_pathspec(&rev.prune_data, ps);
+
+	rev.diffopt.flags.quick = 1;
+	rev.diffopt.flags.ignore_submodules = 1;
+	rev.abbrev = 0;
+
+	add_head_to_pending(&rev);
+	diff_setup_done(&rev.diffopt);
+
+	result = run_diff_index(&rev, 1);
+	if (diff_result_code(&rev.diffopt, result)) {
+		ret = 1;
+		goto done;
+	}
+
+	object_array_clear(&rev.pending);
+	result = run_diff_files(&rev, 0);
+	if (diff_result_code(&rev.diffopt, result)) {
+		ret = 1;
+		goto done;
+	}
+
+done:
+	clear_pathspec(&rev.prune_data);
+	return ret;
+}
+
+/*
+ * The function will fill `untracked_files` with the names of untracked files
+ * It will return 1 if there were any changes and 0 if there were not.
+ */
+static int check_changes(const struct pathspec *ps, int include_untracked,
+			 struct strbuf *untracked_files)
+{
+	int ret = 0;
+	if (check_changes_tracked_files(ps))
+		ret = 1;
+
+	if (include_untracked && get_untracked_files(ps, include_untracked,
+						     untracked_files))
+		ret = 1;
+
+	return ret;
+}
+
+static int save_untracked_files(struct stash_info *info, struct strbuf *msg,
+				struct strbuf files)
+{
+	int ret = 0;
+	struct strbuf untracked_msg = STRBUF_INIT;
+	struct child_process cp_upd_index = CHILD_PROCESS_INIT;
+	struct index_state istate = { NULL };
+
+	cp_upd_index.git_cmd = 1;
+	argv_array_pushl(&cp_upd_index.args, "update-index", "-z", "--add",
+			 "--remove", "--stdin", NULL);
+	argv_array_pushf(&cp_upd_index.env_array, "GIT_INDEX_FILE=%s",
+			 stash_index_path.buf);
+
+	strbuf_addf(&untracked_msg, "untracked files on %s\n", msg->buf);
+	if (pipe_command(&cp_upd_index, files.buf, files.len, NULL, 0,
+			 NULL, 0)) {
+		ret = -1;
+		goto done;
+	}
+
+	if (write_index_as_tree(&info->u_tree, &istate, stash_index_path.buf, 0,
+				NULL)) {
+		ret = -1;
+		goto done;
+	}
+
+	if (commit_tree(untracked_msg.buf, untracked_msg.len,
+			&info->u_tree, NULL, &info->u_commit, NULL, NULL)) {
+		ret = -1;
+		goto done;
+	}
+
+done:
+	discard_index(&istate);
+	strbuf_release(&untracked_msg);
+	remove_path(stash_index_path.buf);
+	return ret;
+}
+
+static int stash_patch(struct stash_info *info, const struct pathspec *ps,
+		       struct strbuf *out_patch, int quiet)
+{
+	int ret = 0;
+	struct child_process cp_read_tree = CHILD_PROCESS_INIT;
+	struct child_process cp_add_i = CHILD_PROCESS_INIT;
+	struct child_process cp_diff_tree = CHILD_PROCESS_INIT;
+	struct index_state istate = { NULL };
+
+	remove_path(stash_index_path.buf);
+
+	cp_read_tree.git_cmd = 1;
+	argv_array_pushl(&cp_read_tree.args, "read-tree", "HEAD", NULL);
+	argv_array_pushf(&cp_read_tree.env_array, "GIT_INDEX_FILE=%s",
+			 stash_index_path.buf);
+	if (run_command(&cp_read_tree)) {
+		ret = -1;
+		goto done;
+	}
+
+	/* Find out what the user wants. */
+	cp_add_i.git_cmd = 1;
+	argv_array_pushl(&cp_add_i.args, "add--interactive", "--patch=stash",
+			 "--", NULL);
+	add_pathspecs(&cp_add_i.args, ps);
+	argv_array_pushf(&cp_add_i.env_array, "GIT_INDEX_FILE=%s",
+			 stash_index_path.buf);
+	if (run_command(&cp_add_i)) {
+		ret = -1;
+		goto done;
+	}
+
+	/* State of the working tree. */
+	if (write_index_as_tree(&info->w_tree, &istate, stash_index_path.buf, 0,
+				NULL)) {
+		ret = -1;
+		goto done;
+	}
+
+	cp_diff_tree.git_cmd = 1;
+	argv_array_pushl(&cp_diff_tree.args, "diff-tree", "-p", "HEAD",
+			 oid_to_hex(&info->w_tree), "--", NULL);
+	if (pipe_command(&cp_diff_tree, NULL, 0, out_patch, 0, NULL, 0)) {
+		ret = -1;
+		goto done;
+	}
+
+	if (!out_patch->len) {
+		if (!quiet)
+			fprintf_ln(stderr, _("No changes selected"));
+		ret = 1;
+	}
+
+done:
+	discard_index(&istate);
+	remove_path(stash_index_path.buf);
+	return ret;
+}
+
+static int stash_working_tree(struct stash_info *info, const struct pathspec *ps)
+{
+	int ret = 0;
+	struct rev_info rev;
+	struct child_process cp_upd_index = CHILD_PROCESS_INIT;
+	struct strbuf diff_output = STRBUF_INIT;
+	struct index_state istate = { NULL };
+
+	init_revisions(&rev, NULL);
+	copy_pathspec(&rev.prune_data, ps);
+
+	set_alternate_index_output(stash_index_path.buf);
+	if (reset_tree(&info->i_tree, 0, 0)) {
+		ret = -1;
+		goto done;
+	}
+	set_alternate_index_output(NULL);
+
+	rev.diffopt.output_format = DIFF_FORMAT_CALLBACK;
+	rev.diffopt.format_callback = add_diff_to_buf;
+	rev.diffopt.format_callback_data = &diff_output;
+
+	if (read_cache_preload(&rev.diffopt.pathspec) < 0) {
+		ret = -1;
+		goto done;
+	}
+
+	add_pending_object(&rev, parse_object(the_repository, &info->b_commit),
+			   "");
+	if (run_diff_index(&rev, 0)) {
+		ret = -1;
+		goto done;
+	}
+
+	cp_upd_index.git_cmd = 1;
+	argv_array_pushl(&cp_upd_index.args, "update-index",
+			 "--ignore-skip-worktree-entries",
+			 "-z", "--add", "--remove", "--stdin", NULL);
+	argv_array_pushf(&cp_upd_index.env_array, "GIT_INDEX_FILE=%s",
+			 stash_index_path.buf);
+
+	if (pipe_command(&cp_upd_index, diff_output.buf, diff_output.len,
+			 NULL, 0, NULL, 0)) {
+		ret = -1;
+		goto done;
+	}
+
+	if (write_index_as_tree(&info->w_tree, &istate, stash_index_path.buf, 0,
+				NULL)) {
+		ret = -1;
+		goto done;
+	}
+
+done:
+	discard_index(&istate);
+	UNLEAK(rev);
+	object_array_clear(&rev.pending);
+	clear_pathspec(&rev.prune_data);
+	strbuf_release(&diff_output);
+	remove_path(stash_index_path.buf);
+	return ret;
+}
+
+static int do_create_stash(const struct pathspec *ps, struct strbuf *stash_msg_buf,
+			   int include_untracked, int patch_mode,
+			   struct stash_info *info, struct strbuf *patch,
+			   int quiet)
+{
+	int ret = 0;
+	int flags = 0;
+	int untracked_commit_option = 0;
+	const char *head_short_sha1 = NULL;
+	const char *branch_ref = NULL;
+	const char *branch_name = "(no branch)";
+	struct commit *head_commit = NULL;
+	struct commit_list *parents = NULL;
+	struct strbuf msg = STRBUF_INIT;
+	struct strbuf commit_tree_label = STRBUF_INIT;
+	struct strbuf untracked_files = STRBUF_INIT;
+
+	prepare_fallback_ident("git stash", "git@stash");
+
+	read_cache_preload(NULL);
+	if (refresh_and_write_cache(REFRESH_QUIET, 0, 0) < 0) {
+		ret = -1;
+		goto done;
+	}
+
+	if (get_oid("HEAD", &info->b_commit)) {
+		if (!quiet)
+			fprintf_ln(stderr, _("You do not have "
+					     "the initial commit yet"));
+		ret = -1;
+		goto done;
+	} else {
+		head_commit = lookup_commit(the_repository, &info->b_commit);
+	}
+
+	if (!check_changes(ps, include_untracked, &untracked_files)) {
+		ret = 1;
+		goto done;
+	}
+
+	branch_ref = resolve_ref_unsafe("HEAD", 0, NULL, &flags);
+	if (flags & REF_ISSYMREF)
+		branch_name = strrchr(branch_ref, '/') + 1;
+	head_short_sha1 = find_unique_abbrev(&head_commit->object.oid,
+					     DEFAULT_ABBREV);
+	strbuf_addf(&msg, "%s: %s ", branch_name, head_short_sha1);
+	pp_commit_easy(CMIT_FMT_ONELINE, head_commit, &msg);
+
+	strbuf_addf(&commit_tree_label, "index on %s\n", msg.buf);
+	commit_list_insert(head_commit, &parents);
+	if (write_cache_as_tree(&info->i_tree, 0, NULL) ||
+	    commit_tree(commit_tree_label.buf, commit_tree_label.len,
+			&info->i_tree, parents, &info->i_commit, NULL, NULL)) {
+		if (!quiet)
+			fprintf_ln(stderr, _("Cannot save the current "
+					     "index state"));
+		ret = -1;
+		goto done;
+	}
+
+	if (include_untracked) {
+		if (save_untracked_files(info, &msg, untracked_files)) {
+			if (!quiet)
+				fprintf_ln(stderr, _("Cannot save "
+						     "the untracked files"));
+			ret = -1;
+			goto done;
+		}
+		untracked_commit_option = 1;
+	}
+	if (patch_mode) {
+		ret = stash_patch(info, ps, patch, quiet);
+		if (ret < 0) {
+			if (!quiet)
+				fprintf_ln(stderr, _("Cannot save the current "
+						     "worktree state"));
+			goto done;
+		} else if (ret > 0) {
+			goto done;
+		}
+	} else {
+		if (stash_working_tree(info, ps)) {
+			if (!quiet)
+				fprintf_ln(stderr, _("Cannot save the current "
+						     "worktree state"));
+			ret = -1;
+			goto done;
+		}
+	}
+
+	if (!stash_msg_buf->len)
+		strbuf_addf(stash_msg_buf, "WIP on %s", msg.buf);
+	else
+		strbuf_insertf(stash_msg_buf, 0, "On %s: ", branch_name);
+
+	/*
+	 * `parents` will be empty after calling `commit_tree()`, so there is
+	 * no need to call `free_commit_list()`
+	 */
+	parents = NULL;
+	if (untracked_commit_option)
+		commit_list_insert(lookup_commit(the_repository,
+						 &info->u_commit),
+				   &parents);
+	commit_list_insert(lookup_commit(the_repository, &info->i_commit),
+			   &parents);
+	commit_list_insert(head_commit, &parents);
+
+	if (commit_tree(stash_msg_buf->buf, stash_msg_buf->len, &info->w_tree,
+			parents, &info->w_commit, NULL, NULL)) {
+		if (!quiet)
+			fprintf_ln(stderr, _("Cannot record "
+					     "working tree state"));
+		ret = -1;
+		goto done;
+	}
+
+done:
+	strbuf_release(&commit_tree_label);
+	strbuf_release(&msg);
+	strbuf_release(&untracked_files);
+	return ret;
+}
+
+static int create_stash(int argc, const char **argv, const char *prefix)
+{
+	int ret = 0;
+	struct strbuf stash_msg_buf = STRBUF_INIT;
+	struct stash_info info;
+	struct pathspec ps;
+
+	/* Starting with argv[1], since argv[0] is "create" */
+	strbuf_join_argv(&stash_msg_buf, argc - 1, ++argv, ' ');
+
+	memset(&ps, 0, sizeof(ps));
+	if (!check_changes_tracked_files(&ps))
+		return 0;
+
+	ret = do_create_stash(&ps, &stash_msg_buf, 0, 0, &info,
+			      NULL, 0);
+	if (!ret)
+		printf_ln("%s", oid_to_hex(&info.w_commit));
+
+	strbuf_release(&stash_msg_buf);
+	return ret;
+}
+
+static int do_push_stash(const struct pathspec *ps, const char *stash_msg, int quiet,
+			 int keep_index, int patch_mode, int include_untracked)
+{
+	int ret = 0;
+	struct stash_info info;
+	struct strbuf patch = STRBUF_INIT;
+	struct strbuf stash_msg_buf = STRBUF_INIT;
+	struct strbuf untracked_files = STRBUF_INIT;
+
+	if (patch_mode && keep_index == -1)
+		keep_index = 1;
+
+	if (patch_mode && include_untracked) {
+		fprintf_ln(stderr, _("Can't use --patch and --include-untracked"
+				     " or --all at the same time"));
+		ret = -1;
+		goto done;
+	}
+
+	read_cache_preload(NULL);
+	if (!include_untracked && ps->nr) {
+		int i;
+		char *ps_matched = xcalloc(ps->nr, 1);
+
+		for (i = 0; i < active_nr; i++)
+			ce_path_match(&the_index, active_cache[i], ps,
+				      ps_matched);
+
+		if (report_path_error(ps_matched, ps)) {
+			fprintf_ln(stderr, _("Did you forget to 'git add'?"));
+			ret = -1;
+			free(ps_matched);
+			goto done;
+		}
+		free(ps_matched);
+	}
+
+	if (refresh_and_write_cache(REFRESH_QUIET, 0, 0)) {
+		ret = -1;
+		goto done;
+	}
+
+	if (!check_changes(ps, include_untracked, &untracked_files)) {
+		if (!quiet)
+			printf_ln(_("No local changes to save"));
+		goto done;
+	}
+
+	if (!reflog_exists(ref_stash) && do_clear_stash()) {
+		ret = -1;
+		if (!quiet)
+			fprintf_ln(stderr, _("Cannot initialize stash"));
+		goto done;
+	}
+
+	if (stash_msg)
+		strbuf_addstr(&stash_msg_buf, stash_msg);
+	if (do_create_stash(ps, &stash_msg_buf, include_untracked, patch_mode,
+			    &info, &patch, quiet)) {
+		ret = -1;
+		goto done;
+	}
+
+	if (do_store_stash(&info.w_commit, stash_msg_buf.buf, 1)) {
+		ret = -1;
+		if (!quiet)
+			fprintf_ln(stderr, _("Cannot save the current status"));
+		goto done;
+	}
+
+	if (!quiet)
+		printf_ln(_("Saved working directory and index state %s"),
+			  stash_msg_buf.buf);
+
+	if (!patch_mode) {
+		if (include_untracked && !ps->nr) {
+			struct child_process cp = CHILD_PROCESS_INIT;
+
+			cp.git_cmd = 1;
+			argv_array_pushl(&cp.args, "clean", "--force",
+					 "--quiet", "-d", NULL);
+			if (include_untracked == INCLUDE_ALL_FILES)
+				argv_array_push(&cp.args, "-x");
+			if (run_command(&cp)) {
+				ret = -1;
+				goto done;
+			}
+		}
+		discard_cache();
+		if (ps->nr) {
+			struct child_process cp_add = CHILD_PROCESS_INIT;
+			struct child_process cp_diff = CHILD_PROCESS_INIT;
+			struct child_process cp_apply = CHILD_PROCESS_INIT;
+			struct strbuf out = STRBUF_INIT;
+
+			cp_add.git_cmd = 1;
+			argv_array_push(&cp_add.args, "add");
+			if (!include_untracked)
+				argv_array_push(&cp_add.args, "-u");
+			if (include_untracked == INCLUDE_ALL_FILES)
+				argv_array_push(&cp_add.args, "--force");
+			argv_array_push(&cp_add.args, "--");
+			add_pathspecs(&cp_add.args, ps);
+			if (run_command(&cp_add)) {
+				ret = -1;
+				goto done;
+			}
+
+			cp_diff.git_cmd = 1;
+			argv_array_pushl(&cp_diff.args, "diff-index", "-p",
+					 "--cached", "--binary", "HEAD", "--",
+					 NULL);
+			add_pathspecs(&cp_diff.args, ps);
+			if (pipe_command(&cp_diff, NULL, 0, &out, 0, NULL, 0)) {
+				ret = -1;
+				goto done;
+			}
+
+			cp_apply.git_cmd = 1;
+			argv_array_pushl(&cp_apply.args, "apply", "--index",
+					 "-R", NULL);
+			if (pipe_command(&cp_apply, out.buf, out.len, NULL, 0,
+					 NULL, 0)) {
+				ret = -1;
+				goto done;
+			}
+		} else {
+			struct child_process cp = CHILD_PROCESS_INIT;
+			cp.git_cmd = 1;
+			argv_array_pushl(&cp.args, "reset", "--hard", "-q",
+					 "--no-recurse-submodules", NULL);
+			if (run_command(&cp)) {
+				ret = -1;
+				goto done;
+			}
+		}
+
+		if (keep_index == 1 && !is_null_oid(&info.i_tree)) {
+			struct child_process cp = CHILD_PROCESS_INIT;
+
+			cp.git_cmd = 1;
+			argv_array_pushl(&cp.args, "checkout", "--no-overlay",
+					 oid_to_hex(&info.i_tree), "--", NULL);
+			if (!ps->nr)
+				argv_array_push(&cp.args, ":/");
+			else
+				add_pathspecs(&cp.args, ps);
+			if (run_command(&cp)) {
+				ret = -1;
+				goto done;
+			}
+		}
+		goto done;
+	} else {
+		struct child_process cp = CHILD_PROCESS_INIT;
+
+		cp.git_cmd = 1;
+		argv_array_pushl(&cp.args, "apply", "-R", NULL);
+
+		if (pipe_command(&cp, patch.buf, patch.len, NULL, 0, NULL, 0)) {
+			if (!quiet)
+				fprintf_ln(stderr, _("Cannot remove "
+						     "worktree changes"));
+			ret = -1;
+			goto done;
+		}
+
+		if (keep_index < 1) {
+			struct child_process cp = CHILD_PROCESS_INIT;
+
+			cp.git_cmd = 1;
+			argv_array_pushl(&cp.args, "reset", "-q", "--", NULL);
+			add_pathspecs(&cp.args, ps);
+			if (run_command(&cp)) {
+				ret = -1;
+				goto done;
+			}
+		}
+		goto done;
+	}
+
+done:
+	strbuf_release(&stash_msg_buf);
+	return ret;
+}
+
+static int push_stash(int argc, const char **argv, const char *prefix)
+{
+	int keep_index = -1;
+	int patch_mode = 0;
+	int include_untracked = 0;
+	int quiet = 0;
+	const char *stash_msg = NULL;
+	struct pathspec ps;
+	struct option options[] = {
+		OPT_BOOL('k', "keep-index", &keep_index,
+			 N_("keep index")),
+		OPT_BOOL('p', "patch", &patch_mode,
+			 N_("stash in patch mode")),
+		OPT__QUIET(&quiet, N_("quiet mode")),
+		OPT_BOOL('u', "include-untracked", &include_untracked,
+			 N_("include untracked files in stash")),
+		OPT_SET_INT('a', "all", &include_untracked,
+			    N_("include ignore files"), 2),
+		OPT_STRING('m', "message", &stash_msg, N_("message"),
+			   N_("stash message")),
+		OPT_END()
+	};
+
+	if (argc)
+		argc = parse_options(argc, argv, prefix, options,
+				     git_stash_push_usage,
+				     0);
+
+	parse_pathspec(&ps, 0, PATHSPEC_PREFER_FULL | PATHSPEC_PREFIX_ORIGIN,
+		       prefix, argv);
+	return do_push_stash(&ps, stash_msg, quiet, keep_index, patch_mode,
+			     include_untracked);
+}
+
+static int save_stash(int argc, const char **argv, const char *prefix)
+{
+	int keep_index = -1;
+	int patch_mode = 0;
+	int include_untracked = 0;
+	int quiet = 0;
+	int ret = 0;
+	const char *stash_msg = NULL;
+	struct pathspec ps;
+	struct strbuf stash_msg_buf = STRBUF_INIT;
+	struct option options[] = {
+		OPT_BOOL('k', "keep-index", &keep_index,
+			 N_("keep index")),
+		OPT_BOOL('p', "patch", &patch_mode,
+			 N_("stash in patch mode")),
+		OPT__QUIET(&quiet, N_("quiet mode")),
+		OPT_BOOL('u', "include-untracked", &include_untracked,
+			 N_("include untracked files in stash")),
+		OPT_SET_INT('a', "all", &include_untracked,
+			    N_("include ignore files"), 2),
+		OPT_STRING('m', "message", &stash_msg, "message",
+			   N_("stash message")),
+		OPT_END()
+	};
+
+	argc = parse_options(argc, argv, prefix, options,
+			     git_stash_save_usage,
+			     PARSE_OPT_KEEP_DASHDASH);
+
+	if (argc)
+		stash_msg = strbuf_join_argv(&stash_msg_buf, argc, argv, ' ');
+
+	memset(&ps, 0, sizeof(ps));
+	ret = do_push_stash(&ps, stash_msg, quiet, keep_index,
+			    patch_mode, include_untracked);
+
+	strbuf_release(&stash_msg_buf);
+	return ret;
+}
+
+static int use_builtin_stash(void)
+{
+	struct child_process cp = CHILD_PROCESS_INIT;
+	struct strbuf out = STRBUF_INIT;
+	int ret, env = git_env_bool("GIT_TEST_STASH_USE_BUILTIN", -1);
+
+	if (env != -1)
+		return env;
+
+	argv_array_pushl(&cp.args,
+			 "config", "--bool", "stash.usebuiltin", NULL);
+	cp.git_cmd = 1;
+	if (capture_command(&cp, &out, 6)) {
+		strbuf_release(&out);
+		return 1;
+	}
+
+	strbuf_trim(&out);
+	ret = !strcmp("true", out.buf);
+	strbuf_release(&out);
+	return ret;
+}
+
+int cmd_stash(int argc, const char **argv, const char *prefix)
+{
+	int i = -1;
+	pid_t pid = getpid();
+	const char *index_file;
+	struct argv_array args = ARGV_ARRAY_INIT;
+
+	struct option options[] = {
+		OPT_END()
+	};
+
+	if (!use_builtin_stash()) {
+		const char *path = mkpath("%s/git-legacy-stash",
+					  git_exec_path());
+
+		if (sane_execvp(path, (char **)argv) < 0)
+			die_errno(_("could not exec %s"), path);
+		else
+			BUG("sane_execvp() returned???");
+	}
+
+	prefix = setup_git_directory();
+	trace_repo_setup(prefix);
+	setup_work_tree();
+
+	git_config(git_diff_basic_config, NULL);
+
+	argc = parse_options(argc, argv, prefix, options, git_stash_usage,
+			     PARSE_OPT_KEEP_UNKNOWN | PARSE_OPT_KEEP_DASHDASH);
+
+	index_file = get_index_file();
+	strbuf_addf(&stash_index_path, "%s.stash.%" PRIuMAX, index_file,
+		    (uintmax_t)pid);
+
+	if (!argc)
+		return !!push_stash(0, NULL, prefix);
+	else if (!strcmp(argv[0], "apply"))
+		return !!apply_stash(argc, argv, prefix);
+	else if (!strcmp(argv[0], "clear"))
+		return !!clear_stash(argc, argv, prefix);
+	else if (!strcmp(argv[0], "drop"))
+		return !!drop_stash(argc, argv, prefix);
+	else if (!strcmp(argv[0], "pop"))
+		return !!pop_stash(argc, argv, prefix);
+	else if (!strcmp(argv[0], "branch"))
+		return !!branch_stash(argc, argv, prefix);
+	else if (!strcmp(argv[0], "list"))
+		return !!list_stash(argc, argv, prefix);
+	else if (!strcmp(argv[0], "show"))
+		return !!show_stash(argc, argv, prefix);
+	else if (!strcmp(argv[0], "store"))
+		return !!store_stash(argc, argv, prefix);
+	else if (!strcmp(argv[0], "create"))
+		return !!create_stash(argc, argv, prefix);
+	else if (!strcmp(argv[0], "push"))
+		return !!push_stash(argc, argv, prefix);
+	else if (!strcmp(argv[0], "save"))
+		return !!save_stash(argc, argv, prefix);
+	else if (*argv[0] != '-')
+		usage_msg_opt(xstrfmt(_("unknown subcommand: %s"), argv[0]),
+			      git_stash_usage, options);
+
+	if (strcmp(argv[0], "-p")) {
+		while (++i < argc && strcmp(argv[i], "--")) {
+			/*
+			 * `akpqu` is a string which contains all short options,
+			 * except `-m` which is verified separately.
+			 */
+			if ((strlen(argv[i]) == 2) && *argv[i] == '-' &&
+			    strchr("akpqu", argv[i][1]))
+				continue;
+
+			if (!strcmp(argv[i], "--all") ||
+			    !strcmp(argv[i], "--keep-index") ||
+			    !strcmp(argv[i], "--no-keep-index") ||
+			    !strcmp(argv[i], "--patch") ||
+			    !strcmp(argv[i], "--quiet") ||
+			    !strcmp(argv[i], "--include-untracked"))
+				continue;
+
+			/*
+			 * `-m` and `--message=` are verified separately because
+			 * they need to be immediately followed by a string
+			 * (i.e.`-m"foobar"` or `--message="foobar"`).
+			 */
+			if (starts_with(argv[i], "-m") ||
+			    starts_with(argv[i], "--message="))
+				continue;
+
+			usage_with_options(git_stash_usage, options);
+		}
+	}
+
+	argv_array_push(&args, "push");
+	argv_array_pushv(&args, argv);
+	return !!push_stash(args.argc, args.argv, prefix);
+}
diff -pruN 1.2.1+git2.18.0-1/git/builtin/stripspace.c 1.2.3+git2.25.1-1/git/builtin/stripspace.c
--- 1.2.1+git2.18.0-1/git/builtin/stripspace.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/builtin/stripspace.c	2020-02-17 04:47:35.000000000 +0000
@@ -30,6 +30,7 @@ int cmd_stripspace(int argc, const char
 {
 	struct strbuf buf = STRBUF_INIT;
 	enum stripspace_mode mode = STRIP_DEFAULT;
+	int nongit;
 
 	const struct option options[] = {
 		OPT_CMDMODE('s', "strip-comments", &mode,
@@ -46,7 +47,7 @@ int cmd_stripspace(int argc, const char
 		usage_with_options(stripspace_usage, options);
 
 	if (mode == STRIP_COMMENTS || mode == COMMENT_LINES) {
-		setup_git_directory_gently(NULL);
+		setup_git_directory_gently(&nongit);
 		git_config(git_default_config, NULL);
 	}
 
diff -pruN 1.2.1+git2.18.0-1/git/builtin/submodule--helper.c 1.2.3+git2.25.1-1/git/builtin/submodule--helper.c
--- 1.2.1+git2.18.0-1/git/builtin/submodule--helper.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/builtin/submodule--helper.c	2020-02-17 04:47:35.000000000 +0000
@@ -1,3 +1,4 @@
+#define USE_THE_INDEX_COMPATIBILITY_MACROS
 #include "builtin.h"
 #include "repository.h"
 #include "cache.h"
@@ -18,6 +19,8 @@
 #include "diffcore.h"
 #include "diff.h"
 #include "object-store.h"
+#include "dir.h"
+#include "advice.h"
 
 #define OPT_QUIET (1 << 0)
 #define OPT_CACHED (1 << 1)
@@ -55,7 +58,7 @@ static char *get_default_remote(void)
 
 static int print_default_remote(int argc, const char **argv, const char *prefix)
 {
-	const char *remote;
+	char *remote;
 
 	if (argc != 1)
 		die(_("submodule--helper print-default-remote takes no arguments"));
@@ -64,6 +67,7 @@ static int print_default_remote(int argc
 	if (remote)
 		printf("%s\n", remote);
 
+	free(remote);
 	return 0;
 }
 
@@ -330,7 +334,7 @@ static int module_list_compute(int argc,
 	for (i = 0; i < active_nr; i++) {
 		const struct cache_entry *ce = active_cache[i];
 
-		if (!match_pathspec(pathspec, ce->name, ce_namelen(ce),
+		if (!match_pathspec(&the_index, pathspec, ce->name, ce_namelen(ce),
 				    0, ps_matched, 1) ||
 		    !S_ISGITLINK(ce->ce_mode))
 			continue;
@@ -346,7 +350,7 @@ static int module_list_compute(int argc,
 			i++;
 	}
 
-	if (ps_matched && report_path_error(ps_matched, pathspec, prefix))
+	if (ps_matched && report_path_error(ps_matched, pathspec))
 		result = -1;
 
 	free(ps_matched);
@@ -422,7 +426,7 @@ static int module_list(int argc, const c
 		const struct cache_entry *ce = list.entries[i];
 
 		if (ce_stage(ce))
-			printf("%06o %s U\t", ce->ce_mode, sha1_to_hex(null_sha1));
+			printf("%06o %s U\t", ce->ce_mode, oid_to_hex(&null_oid));
 		else
 			printf("%06o %s %d\t", ce->ce_mode,
 			       oid_to_hex(&ce->oid), ce_stage(ce));
@@ -440,6 +444,170 @@ static void for_each_listed_submodule(co
 		fn(list->entries[i], cb_data);
 }
 
+struct cb_foreach {
+	int argc;
+	const char **argv;
+	const char *prefix;
+	int quiet;
+	int recursive;
+};
+#define CB_FOREACH_INIT { 0 }
+
+static void runcommand_in_submodule_cb(const struct cache_entry *list_item,
+				       void *cb_data)
+{
+	struct cb_foreach *info = cb_data;
+	const char *path = list_item->name;
+	const struct object_id *ce_oid = &list_item->oid;
+
+	const struct submodule *sub;
+	struct child_process cp = CHILD_PROCESS_INIT;
+	char *displaypath;
+
+	displaypath = get_submodule_displaypath(path, info->prefix);
+
+	sub = submodule_from_path(the_repository, &null_oid, path);
+
+	if (!sub)
+		die(_("No url found for submodule path '%s' in .gitmodules"),
+			displaypath);
+
+	if (!is_submodule_populated_gently(path, NULL))
+		goto cleanup;
+
+	prepare_submodule_repo_env(&cp.env_array);
+
+	/*
+	 * For the purpose of executing <command> in the submodule,
+	 * separate shell is used for the purpose of running the
+	 * child process.
+	 */
+	cp.use_shell = 1;
+	cp.dir = path;
+
+	/*
+	 * NEEDSWORK: the command currently has access to the variables $name,
+	 * $sm_path, $displaypath, $sha1 and $toplevel only when the command
+	 * contains a single argument. This is done for maintaining a faithful
+	 * translation from shell script.
+	 */
+	if (info->argc == 1) {
+		char *toplevel = xgetcwd();
+		struct strbuf sb = STRBUF_INIT;
+
+		argv_array_pushf(&cp.env_array, "name=%s", sub->name);
+		argv_array_pushf(&cp.env_array, "sm_path=%s", path);
+		argv_array_pushf(&cp.env_array, "displaypath=%s", displaypath);
+		argv_array_pushf(&cp.env_array, "sha1=%s",
+				oid_to_hex(ce_oid));
+		argv_array_pushf(&cp.env_array, "toplevel=%s", toplevel);
+
+		/*
+		 * Since the path variable was accessible from the script
+		 * before porting, it is also made available after porting.
+		 * The environment variable "PATH" has a very special purpose
+		 * on windows. And since environment variables are
+		 * case-insensitive in windows, it interferes with the
+		 * existing PATH variable. Hence, to avoid that, we expose
+		 * path via the args argv_array and not via env_array.
+		 */
+		sq_quote_buf(&sb, path);
+		argv_array_pushf(&cp.args, "path=%s; %s",
+				 sb.buf, info->argv[0]);
+		strbuf_release(&sb);
+		free(toplevel);
+	} else {
+		argv_array_pushv(&cp.args, info->argv);
+	}
+
+	if (!info->quiet)
+		printf(_("Entering '%s'\n"), displaypath);
+
+	if (info->argv[0] && run_command(&cp))
+		die(_("run_command returned non-zero status for %s\n."),
+			displaypath);
+
+	if (info->recursive) {
+		struct child_process cpr = CHILD_PROCESS_INIT;
+
+		cpr.git_cmd = 1;
+		cpr.dir = path;
+		prepare_submodule_repo_env(&cpr.env_array);
+
+		argv_array_pushl(&cpr.args, "--super-prefix", NULL);
+		argv_array_pushf(&cpr.args, "%s/", displaypath);
+		argv_array_pushl(&cpr.args, "submodule--helper", "foreach", "--recursive",
+				NULL);
+
+		if (info->quiet)
+			argv_array_push(&cpr.args, "--quiet");
+
+		argv_array_push(&cpr.args, "--");
+		argv_array_pushv(&cpr.args, info->argv);
+
+		if (run_command(&cpr))
+			die(_("run_command returned non-zero status while "
+				"recursing in the nested submodules of %s\n."),
+				displaypath);
+	}
+
+cleanup:
+	free(displaypath);
+}
+
+static int module_foreach(int argc, const char **argv, const char *prefix)
+{
+	struct cb_foreach info = CB_FOREACH_INIT;
+	struct pathspec pathspec;
+	struct module_list list = MODULE_LIST_INIT;
+
+	struct option module_foreach_options[] = {
+		OPT__QUIET(&info.quiet, N_("Suppress output of entering each submodule command")),
+		OPT_BOOL(0, "recursive", &info.recursive,
+			 N_("Recurse into nested submodules")),
+		OPT_END()
+	};
+
+	const char *const git_submodule_helper_usage[] = {
+		N_("git submodule--helper foreach [--quiet] [--recursive] [--] <command>"),
+		NULL
+	};
+
+	argc = parse_options(argc, argv, prefix, module_foreach_options,
+			     git_submodule_helper_usage, 0);
+
+	if (module_list_compute(0, NULL, prefix, &pathspec, &list) < 0)
+		return 1;
+
+	info.argc = argc;
+	info.argv = argv;
+	info.prefix = prefix;
+
+	for_each_listed_submodule(&list, runcommand_in_submodule_cb, &info);
+
+	return 0;
+}
+
+static char *compute_submodule_clone_url(const char *rel_url)
+{
+	char *remoteurl, *relurl;
+	char *remote = get_default_remote();
+	struct strbuf remotesb = STRBUF_INIT;
+
+	strbuf_addf(&remotesb, "remote.%s.url", remote);
+	if (git_config_get_string(remotesb.buf, &remoteurl)) {
+		warning(_("could not look up configuration '%s'. Assuming this repository is its own authoritative upstream."), remotesb.buf);
+		remoteurl = xgetcwd();
+	}
+	relurl = relative_url(remoteurl, rel_url, NULL);
+
+	free(remote);
+	free(remoteurl);
+	strbuf_release(&remotesb);
+
+	return relurl;
+}
+
 struct init_cb {
 	const char *prefix;
 	unsigned int flags;
@@ -490,21 +658,9 @@ static void init_submodule(const char *p
 		/* Possibly a url relative to parent */
 		if (starts_with_dot_dot_slash(url) ||
 		    starts_with_dot_slash(url)) {
-			char *remoteurl, *relurl;
-			char *remote = get_default_remote();
-			struct strbuf remotesb = STRBUF_INIT;
-			strbuf_addf(&remotesb, "remote.%s.url", remote);
-			free(remote);
-
-			if (git_config_get_string(remotesb.buf, &remoteurl)) {
-				warning(_("could not lookup configuration '%s'. Assuming this repository is its own authoritative upstream."), remotesb.buf);
-				remoteurl = xgetcwd();
-			}
-			relurl = relative_url(remoteurl, url, NULL);
-			strbuf_release(&remotesb);
-			free(remoteurl);
-			free(url);
-			url = relurl;
+			char *oldurl = url;
+			url = compute_submodule_clone_url(oldurl);
+			free(oldurl);
 		}
 
 		if (git_config_set_gently(sb.buf, url))
@@ -556,7 +712,7 @@ static int module_init(int argc, const c
 	};
 
 	const char *const git_submodule_helper_usage[] = {
-		N_("git submodule--helper init [<path>]"),
+		N_("git submodule--helper init [<options>] [<path>]"),
 		NULL
 	};
 
@@ -648,7 +804,8 @@ static void status_submodule(const char
 			 path, NULL);
 
 	git_config(git_diff_basic_config, NULL);
-	init_revisions(&rev, prefix);
+
+	repo_init_revisions(the_repository, &rev, NULL);
 	rev.abbrev = 0;
 	diff_files_args.argc = setup_revisions(diff_files_args.argc,
 					       diff_files_args.argv,
@@ -880,7 +1037,6 @@ static void sync_submodule_cb(const stru
 {
 	struct sync_cb *info = cb_data;
 	sync_submodule(list_item->name, info->prefix, info->flags);
-
 }
 
 static int module_sync(int argc, const char **argv, const char *prefix)
@@ -980,6 +1136,8 @@ static void deinit_submodule(const char
 		if (!(flags & OPT_QUIET))
 			printf(format, displaypath);
 
+		submodule_unset_core_worktree(sub);
+
 		strbuf_release(&sb_rm);
 	}
 
@@ -1090,6 +1248,7 @@ static int clone_submodule(const char *p
 	if (gitdir && *gitdir)
 		argv_array_pushl(&cp.args, "--separate-git-dir", gitdir, NULL);
 
+	argv_array_push(&cp.args, "--");
 	argv_array_push(&cp.args, url);
 	argv_array_push(&cp.args, path);
 
@@ -1112,20 +1271,28 @@ struct submodule_alternate_setup {
 #define SUBMODULE_ALTERNATE_SETUP_INIT { NULL, \
 	SUBMODULE_ALTERNATE_ERROR_IGNORE, NULL }
 
+static const char alternate_error_advice[] = N_(
+"An alternate computed from a superproject's alternate is invalid.\n"
+"To allow Git to clone without an alternate in such a case, set\n"
+"submodule.alternateErrorStrategy to 'info' or, equivalently, clone with\n"
+"'--reference-if-able' instead of '--reference'."
+);
+
 static int add_possible_reference_from_superproject(
-		struct alternate_object_database *alt, void *sas_cb)
+		struct object_directory *odb, void *sas_cb)
 {
 	struct submodule_alternate_setup *sas = sas_cb;
+	size_t len;
 
 	/*
 	 * If the alternate object store is another repository, try the
 	 * standard layout with .git/(modules/<name>)+/objects
 	 */
-	if (ends_with(alt->path, "/objects")) {
+	if (strip_suffix(odb->path, "/objects", &len)) {
 		char *sm_alternate;
 		struct strbuf sb = STRBUF_INIT;
 		struct strbuf err = STRBUF_INIT;
-		strbuf_add(&sb, alt->path, strlen(alt->path) - strlen("objects"));
+		strbuf_add(&sb, odb->path, len);
 
 		/*
 		 * We need to end the new path with '/' to mark it as a dir,
@@ -1133,7 +1300,7 @@ static int add_possible_reference_from_s
 		 * as the last part of a missing submodule reference would
 		 * be taken as a file name.
 		 */
-		strbuf_addf(&sb, "modules/%s/", sas->submodule_name);
+		strbuf_addf(&sb, "/modules/%s/", sas->submodule_name);
 
 		sm_alternate = compute_alternate_path(sb.buf, &err);
 		if (sm_alternate) {
@@ -1142,10 +1309,12 @@ static int add_possible_reference_from_s
 		} else {
 			switch (sas->error_mode) {
 			case SUBMODULE_ALTERNATE_ERROR_DIE:
+				if (advice_submodule_alternate_error_strategy_die)
+					advise(_(alternate_error_advice));
 				die(_("submodule '%s' cannot add alternate: %s"),
 				    sas->submodule_name, err.buf);
 			case SUBMODULE_ALTERNATE_ERROR_INFO:
-				fprintf(stderr, _("submodule '%s' cannot add alternate: %s"),
+				fprintf_ln(stderr, _("submodule '%s' cannot add alternate: %s"),
 					sas->submodule_name, err.buf);
 			case SUBMODULE_ALTERNATE_ERROR_IGNORE:
 				; /* nothing */
@@ -1202,7 +1371,7 @@ static int module_clone(int argc, const
 	char *p, *path = NULL, *sm_gitdir;
 	struct strbuf sb = STRBUF_INIT;
 	struct string_list reference = STRING_LIST_INIT_NODUP;
-	int dissociate = 0;
+	int dissociate = 0, require_init = 0;
 	char *sm_alternate = NULL, *error_strategy = NULL;
 
 	struct option module_clone_options[] = {
@@ -1229,6 +1398,8 @@ static int module_clone(int argc, const
 		OPT__QUIET(&quiet, "Suppress output for cloning a submodule"),
 		OPT_BOOL(0, "progress", &progress,
 			   N_("force cloning progress")),
+		OPT_BOOL(0, "require-init", &require_init,
+			   N_("disallow cloning into non-empty directory")),
 		OPT_END()
 	};
 
@@ -1256,6 +1427,10 @@ static int module_clone(int argc, const
 	} else
 		path = xstrdup(path);
 
+	if (validate_submodule_git_dir(sm_gitdir, name) < 0)
+		die(_("refusing to create/use '%s' in another submodule's "
+			"git dir"), sm_gitdir);
+
 	if (!file_exists(sm_gitdir)) {
 		if (safe_create_leading_directories_const(sm_gitdir) < 0)
 			die(_("could not create directory '%s'"), sm_gitdir);
@@ -1267,6 +1442,8 @@ static int module_clone(int argc, const
 			die(_("clone of '%s' into submodule path '%s' failed"),
 			    url, path);
 	} else {
+		if (require_init && !access(path, X_OK) && !is_empty_dir(path))
+			die(_("directory not empty: '%s'"), path);
 		if (safe_create_leading_directories_const(path) < 0)
 			die(_("could not create directory '%s'"), path);
 		strbuf_addf(&sb, "%s/index", sm_gitdir);
@@ -1300,6 +1477,72 @@ static int module_clone(int argc, const
 	return 0;
 }
 
+static void determine_submodule_update_strategy(struct repository *r,
+						int just_cloned,
+						const char *path,
+						const char *update,
+						struct submodule_update_strategy *out)
+{
+	const struct submodule *sub = submodule_from_path(r, &null_oid, path);
+	char *key;
+	const char *val;
+
+	key = xstrfmt("submodule.%s.update", sub->name);
+
+	if (update) {
+		if (parse_submodule_update_strategy(update, out) < 0)
+			die(_("Invalid update mode '%s' for submodule path '%s'"),
+				update, path);
+	} else if (!repo_config_get_string_const(r, key, &val)) {
+		if (parse_submodule_update_strategy(val, out) < 0)
+			die(_("Invalid update mode '%s' configured for submodule path '%s'"),
+				val, path);
+	} else if (sub->update_strategy.type != SM_UPDATE_UNSPECIFIED) {
+		if (sub->update_strategy.type == SM_UPDATE_COMMAND)
+			BUG("how did we read update = !command from .gitmodules?");
+		out->type = sub->update_strategy.type;
+		out->command = sub->update_strategy.command;
+	} else
+		out->type = SM_UPDATE_CHECKOUT;
+
+	if (just_cloned &&
+	    (out->type == SM_UPDATE_MERGE ||
+	     out->type == SM_UPDATE_REBASE ||
+	     out->type == SM_UPDATE_NONE))
+		out->type = SM_UPDATE_CHECKOUT;
+
+	free(key);
+}
+
+static int module_update_module_mode(int argc, const char **argv, const char *prefix)
+{
+	const char *path, *update = NULL;
+	int just_cloned;
+	struct submodule_update_strategy update_strategy = { .type = SM_UPDATE_CHECKOUT };
+
+	if (argc < 3 || argc > 4)
+		die("submodule--helper update-module-clone expects <just-cloned> <path> [<update>]");
+
+	just_cloned = git_config_int("just_cloned", argv[1]);
+	path = argv[2];
+
+	if (argc == 4)
+		update = argv[3];
+
+	determine_submodule_update_strategy(the_repository,
+					    just_cloned, path, update,
+					    &update_strategy);
+	fputs(submodule_strategy_to_string(&update_strategy), stdout);
+
+	return 0;
+}
+
+struct update_clone_data {
+	const struct submodule *sub;
+	struct object_id oid;
+	unsigned just_cloned;
+};
+
 struct submodule_update_clone {
 	/* index into 'list', the list of submodules to look into for cloning */
 	int current;
@@ -1315,12 +1558,14 @@ struct submodule_update_clone {
 	int recommend_shallow;
 	struct string_list references;
 	int dissociate;
+	unsigned require_init;
 	const char *depth;
 	const char *recursive_prefix;
 	const char *prefix;
 
-	/* Machine-readable status lines to be consumed by git-submodule.sh */
-	struct string_list projectlines;
+	/* to be consumed by git-submodule.sh */
+	struct update_clone_data *update_clone;
+	int update_clone_nr; int update_clone_alloc;
 
 	/* If we want to stop as fast as possible and return an error */
 	unsigned quickstop : 1;
@@ -1328,11 +1573,13 @@ struct submodule_update_clone {
 	/* failed clones to be retried again */
 	const struct cache_entry **failed_clones;
 	int failed_clones_nr, failed_clones_alloc;
+
+	int max_jobs;
 };
 #define SUBMODULE_UPDATE_CLONE_INIT {0, MODULE_LIST_INIT, 0, \
-	SUBMODULE_UPDATE_STRATEGY_INIT, 0, 0, -1, STRING_LIST_INIT_DUP, 0, \
+	SUBMODULE_UPDATE_STRATEGY_INIT, 0, 0, -1, STRING_LIST_INIT_DUP, 0, 0, \
 	NULL, NULL, NULL, \
-	STRING_LIST_INIT_DUP, 0, NULL, 0, 0}
+	NULL, 0, 0, 0, NULL, 0, 0, 1}
 
 
 static void next_submodule_warn_missing(struct submodule_update_clone *suc,
@@ -1371,6 +1618,7 @@ static int prepare_to_clone_next_submodu
 	struct strbuf sb = STRBUF_INIT;
 	const char *displaypath = NULL;
 	int needs_cloning = 0;
+	int need_free_url = 0;
 
 	if (ce_stage(ce)) {
 		if (suc->recursive_prefix)
@@ -1419,18 +1667,25 @@ static int prepare_to_clone_next_submodu
 
 	strbuf_reset(&sb);
 	strbuf_addf(&sb, "submodule.%s.url", sub->name);
-	if (repo_config_get_string_const(the_repository, sb.buf, &url))
-		url = sub->url;
+	if (repo_config_get_string_const(the_repository, sb.buf, &url)) {
+		if (starts_with_dot_slash(sub->url) ||
+		    starts_with_dot_dot_slash(sub->url)) {
+			url = compute_submodule_clone_url(sub->url);
+			need_free_url = 1;
+		} else
+			url = sub->url;
+	}
 
 	strbuf_reset(&sb);
 	strbuf_addf(&sb, "%s/.git", ce->name);
 	needs_cloning = !file_exists(sb.buf);
 
-	strbuf_reset(&sb);
-	strbuf_addf(&sb, "%06o %s %d %d\t%s\n", ce->ce_mode,
-			oid_to_hex(&ce->oid), ce_stage(ce),
-			needs_cloning, ce->name);
-	string_list_append(&suc->projectlines, sb.buf);
+	ALLOC_GROW(suc->update_clone, suc->update_clone_nr + 1,
+		   suc->update_clone_alloc);
+	oidcpy(&suc->update_clone[suc->update_clone_nr].oid, &ce->oid);
+	suc->update_clone[suc->update_clone_nr].just_cloned = needs_cloning;
+	suc->update_clone[suc->update_clone_nr].sub = sub;
+	suc->update_clone_nr++;
 
 	if (!needs_cloning)
 		goto cleanup;
@@ -1449,6 +1704,8 @@ static int prepare_to_clone_next_submodu
 		argv_array_pushl(&child->args, "--prefix", suc->prefix, NULL);
 	if (suc->recommend_shallow && sub->recommend_shallow == 1)
 		argv_array_push(&child->args, "--depth=1");
+	if (suc->require_init)
+		argv_array_push(&child->args, "--require-init");
 	argv_array_pushl(&child->args, "--path", sub->path, NULL);
 	argv_array_pushl(&child->args, "--name", sub->name, NULL);
 	argv_array_pushl(&child->args, "--url", url, NULL);
@@ -1465,6 +1722,8 @@ static int prepare_to_clone_next_submodu
 cleanup:
 	strbuf_reset(&displaypath_sb);
 	strbuf_reset(&sb);
+	if (need_free_url)
+		free((void*)url);
 
 	return needs_cloning;
 }
@@ -1562,8 +1821,8 @@ static int update_clone_task_finished(in
 	return 0;
 }
 
-static int gitmodules_update_clone_config(const char *var, const char *value,
-					  void *cb)
+static int git_update_clone_config(const char *var, const char *value,
+				   void *cb)
 {
 	int *max_jobs = cb;
 	if (!strcmp(var, "submodule.fetchjobs"))
@@ -1571,11 +1830,43 @@ static int gitmodules_update_clone_confi
 	return 0;
 }
 
+static void update_submodule(struct update_clone_data *ucd)
+{
+	fprintf(stdout, "dummy %s %d\t%s\n",
+		oid_to_hex(&ucd->oid),
+		ucd->just_cloned,
+		ucd->sub->path);
+}
+
+static int update_submodules(struct submodule_update_clone *suc)
+{
+	int i;
+
+	run_processes_parallel_tr2(suc->max_jobs, update_clone_get_next_task,
+				   update_clone_start_failure,
+				   update_clone_task_finished, suc, "submodule",
+				   "parallel/update");
+
+	/*
+	 * We saved the output and put it out all at once now.
+	 * That means:
+	 * - the listener does not have to interleave their (checkout)
+	 *   work with our fetching.  The writes involved in a
+	 *   checkout involve more straightforward sequential I/O.
+	 * - the listener can avoid doing any work if fetching failed.
+	 */
+	if (suc->quickstop)
+		return 1;
+
+	for (i = 0; i < suc->update_clone_nr; i++)
+		update_submodule(&suc->update_clone[i]);
+
+	return 0;
+}
+
 static int update_clone(int argc, const char **argv, const char *prefix)
 {
 	const char *update = NULL;
-	int max_jobs = 1;
-	struct string_list_item *item;
 	struct pathspec pathspec;
 	struct submodule_update_clone suc = SUBMODULE_UPDATE_CLONE_INIT;
 
@@ -1597,24 +1888,26 @@ static int update_clone(int argc, const
 		OPT_STRING(0, "depth", &suc.depth, "<depth>",
 			   N_("Create a shallow clone truncated to the "
 			      "specified number of revisions")),
-		OPT_INTEGER('j', "jobs", &max_jobs,
+		OPT_INTEGER('j', "jobs", &suc.max_jobs,
 			    N_("parallel jobs")),
 		OPT_BOOL(0, "recommend-shallow", &suc.recommend_shallow,
 			    N_("whether the initial clone should follow the shallow recommendation")),
 		OPT__QUIET(&suc.quiet, N_("don't print cloning progress")),
 		OPT_BOOL(0, "progress", &suc.progress,
 			    N_("force cloning progress")),
+		OPT_BOOL(0, "require-init", &suc.require_init,
+			   N_("disallow cloning into non-empty directory")),
 		OPT_END()
 	};
 
 	const char *const git_submodule_helper_usage[] = {
-		N_("git submodule--helper update_clone [--prefix=<path>] [<path>...]"),
+		N_("git submodule--helper update-clone [--prefix=<path>] [<path>...]"),
 		NULL
 	};
 	suc.prefix = prefix;
 
-	config_from_gitmodules(gitmodules_update_clone_config, &max_jobs);
-	git_config(gitmodules_update_clone_config, &max_jobs);
+	update_clone_config_from_gitmodules(&suc.max_jobs);
+	git_config(git_update_clone_config, &suc.max_jobs);
 
 	argc = parse_options(argc, argv, prefix, module_update_clone_options,
 			     git_submodule_helper_usage, 0);
@@ -1629,27 +1922,7 @@ static int update_clone(int argc, const
 	if (pathspec.nr)
 		suc.warn_if_uninitialized = 1;
 
-	run_processes_parallel(max_jobs,
-			       update_clone_get_next_task,
-			       update_clone_start_failure,
-			       update_clone_task_finished,
-			       &suc);
-
-	/*
-	 * We saved the output and put it out all at once now.
-	 * That means:
-	 * - the listener does not have to interleave their (checkout)
-	 *   work with our fetching.  The writes involved in a
-	 *   checkout involve more straightforward sequential I/O.
-	 * - the listener can avoid doing any work if fetching failed.
-	 */
-	if (suc.quickstop)
-		return 1;
-
-	for_each_string_list_item(item, &suc.projectlines)
-		fprintf(stdout, "%s", item->string);
-
-	return 0;
+	return update_submodules(&suc);
 }
 
 static int resolve_relative_path(int argc, const char **argv, const char *prefix)
@@ -1795,6 +2068,45 @@ static int push_check(int argc, const ch
 	return 0;
 }
 
+static int ensure_core_worktree(int argc, const char **argv, const char *prefix)
+{
+	const struct submodule *sub;
+	const char *path;
+	char *cw;
+	struct repository subrepo;
+
+	if (argc != 2)
+		BUG("submodule--helper ensure-core-worktree <path>");
+
+	path = argv[1];
+
+	sub = submodule_from_path(the_repository, &null_oid, path);
+	if (!sub)
+		BUG("We could get the submodule handle before?");
+
+	if (repo_submodule_init(&subrepo, the_repository, sub))
+		die(_("could not get a repository handle for submodule '%s'"), path);
+
+	if (!repo_config_get_string(&subrepo, "core.worktree", &cw)) {
+		char *cfg_file, *abs_path;
+		const char *rel_path;
+		struct strbuf sb = STRBUF_INIT;
+
+		cfg_file = repo_git_path(&subrepo, "config");
+
+		abs_path = absolute_pathdup(path);
+		rel_path = relative_path(abs_path, subrepo.gitdir, &sb);
+
+		git_config_set_in_file(cfg_file, "core.worktree", rel_path);
+
+		free(cfg_file);
+		free(abs_path);
+		strbuf_release(&sb);
+	}
+
+	return 0;
+}
+
 static int absorb_git_dirs(int argc, const char **argv, const char *prefix)
 {
 	int i;
@@ -1812,7 +2124,7 @@ static int absorb_git_dirs(int argc, con
 	};
 
 	const char *const git_submodule_helper_usage[] = {
-		N_("git submodule--helper embed-git-dir [<path>...]"),
+		N_("git submodule--helper absorb-git-dirs [<options>] [<path>...]"),
 		NULL
 	};
 
@@ -1823,8 +2135,7 @@ static int absorb_git_dirs(int argc, con
 		return 1;
 
 	for (i = 0; i < list.nr; i++)
-		absorb_git_dir_into_superproject(prefix,
-				list.entries[i]->name, flags);
+		absorb_git_dir_into_superproject(list.entries[i]->name, flags);
 
 	return 0;
 }
@@ -1860,6 +2171,52 @@ static int check_name(int argc, const ch
 	return 0;
 }
 
+static int module_config(int argc, const char **argv, const char *prefix)
+{
+	enum {
+		CHECK_WRITEABLE = 1,
+		DO_UNSET = 2
+	} command = 0;
+
+	struct option module_config_options[] = {
+		OPT_CMDMODE(0, "check-writeable", &command,
+			    N_("check if it is safe to write to the .gitmodules file"),
+			    CHECK_WRITEABLE),
+		OPT_CMDMODE(0, "unset", &command,
+			    N_("unset the config in the .gitmodules file"),
+			    DO_UNSET),
+		OPT_END()
+	};
+	const char *const git_submodule_helper_usage[] = {
+		N_("git submodule--helper config <name> [<value>]"),
+		N_("git submodule--helper config --unset <name>"),
+		N_("git submodule--helper config --check-writeable"),
+		NULL
+	};
+
+	argc = parse_options(argc, argv, prefix, module_config_options,
+			     git_submodule_helper_usage, PARSE_OPT_KEEP_ARGV0);
+
+	if (argc == 1 && command == CHECK_WRITEABLE)
+		return is_writing_gitmodules_ok() ? 0 : -1;
+
+	/* Equivalent to ACTION_GET in builtin/config.c */
+	if (argc == 2 && command != DO_UNSET)
+		return print_config_from_gitmodules(the_repository, argv[1]);
+
+	/* Equivalent to ACTION_SET in builtin/config.c */
+	if (argc == 3 || (argc == 2 && command == DO_UNSET)) {
+		const char *value = (argc == 3) ? argv[2] : NULL;
+
+		if (!is_writing_gitmodules_ok())
+			die(_("please make sure that the .gitmodules file is in the working tree"));
+
+		return config_set_in_gitmodules_file_gently(argv[1], value);
+	}
+
+	usage_with_options(git_submodule_helper_usage, module_config_options);
+}
+
 #define SUPPORT_SUPER_PREFIX (1<<0)
 
 struct cmd_struct {
@@ -1872,10 +2229,13 @@ static struct cmd_struct commands[] = {
 	{"list", module_list, 0},
 	{"name", module_name, 0},
 	{"clone", module_clone, 0},
+	{"update-module-mode", module_update_module_mode, 0},
 	{"update-clone", update_clone, 0},
+	{"ensure-core-worktree", ensure_core_worktree, 0},
 	{"relative-path", resolve_relative_path, 0},
 	{"resolve-relative-url", resolve_relative_url, 0},
 	{"resolve-relative-url-test", resolve_relative_url_test, 0},
+	{"foreach", module_foreach, SUPPORT_SUPER_PREFIX},
 	{"init", module_init, SUPPORT_SUPER_PREFIX},
 	{"status", module_status, SUPPORT_SUPER_PREFIX},
 	{"print-default-remote", print_default_remote, 0},
@@ -1886,6 +2246,7 @@ static struct cmd_struct commands[] = {
 	{"absorb-git-dirs", absorb_git_dirs, SUPPORT_SUPER_PREFIX},
 	{"is-active", is_active, 0},
 	{"check-name", check_name, 0},
+	{"config", module_config, 0},
 };
 
 int cmd_submodule__helper(int argc, const char **argv, const char *prefix)
diff -pruN 1.2.1+git2.18.0-1/git/builtin/tag.c 1.2.3+git2.25.1-1/git/builtin/tag.c
--- 1.2.1+git2.18.0-1/git/builtin/tag.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/builtin/tag.c	2020-02-17 04:47:35.000000000 +0000
@@ -10,6 +10,7 @@
 #include "config.h"
 #include "builtin.h"
 #include "refs.h"
+#include "object-store.h"
 #include "tag.h"
 #include "run-command.h"
 #include "parse-options.h"
@@ -21,16 +22,18 @@
 #include "ref-filter.h"
 
 static const char * const git_tag_usage[] = {
-	N_("git tag [-a | -s | -u <key-id>] [-f] [-m <msg> | -F <file>] <tagname> [<head>]"),
+	N_("git tag [-a | -s | -u <key-id>] [-f] [-m <msg> | -F <file>]\n"
+		"\t\t<tagname> [<head>]"),
 	N_("git tag -d <tagname>..."),
-	N_("git tag -l [-n[<num>]] [--contains <commit>] [--no-contains <commit>] [--points-at <object>]"
-		"\n\t\t[--format=<format>] [--[no-]merged [<commit>]] [<pattern>...]"),
+	N_("git tag -l [-n[<num>]] [--contains <commit>] [--no-contains <commit>] [--points-at <object>]\n"
+		"\t\t[--format=<format>] [--[no-]merged [<commit>]] [<pattern>...]"),
 	N_("git tag -v [--format=<format>] <tagname>..."),
 	NULL
 };
 
 static unsigned int colopts;
 static int force_sign_annotate;
+static int config_sign_tag = -1; /* unspecified */
 
 static int list_tags(struct ref_filter *filter, struct ref_sorting *sorting,
 		     struct ref_format *format)
@@ -142,6 +145,11 @@ static int git_tag_config(const char *va
 	int status;
 	struct ref_sorting **sorting_tail = (struct ref_sorting **)cb;
 
+	if (!strcmp(var, "tag.gpgsign")) {
+		config_sign_tag = git_config_bool(var, value);
+		return 0;
+	}
+
 	if (!strcmp(var, "tag.sort")) {
 		if (!value)
 			return config_error_nonbool(var);
@@ -204,7 +212,14 @@ struct create_tag_options {
 	} cleanup_mode;
 };
 
-static void create_tag(const struct object_id *object, const char *tag,
+static const char message_advice_nested_tag[] =
+	N_("You have created a nested tag. The object referred to by your new tag is\n"
+	   "already a tag. If you meant to tag the object that it points to, use:\n"
+	   "\n"
+	   "\tgit tag -f %s %s^{}");
+
+static void create_tag(const struct object_id *object, const char *object_ref,
+		       const char *tag,
 		       struct strbuf *buf, struct create_tag_options *opt,
 		       struct object_id *prev, struct object_id *result)
 {
@@ -214,7 +229,10 @@ static void create_tag(const struct obje
 
 	type = oid_object_info(the_repository, object, NULL);
 	if (type <= OBJ_NONE)
-	    die(_("bad object type."));
+		die(_("bad object type."));
+
+	if (type == OBJ_TAG && advice_nested_tag)
+		advise(_(message_advice_nested_tag), tag, object_ref);
 
 	strbuf_addf(&header,
 		    "object %s\n"
@@ -312,7 +330,7 @@ static void create_reflog_msg(const stru
 		}
 		free(buf);
 
-		if ((c = lookup_commit_reference(oid)) != NULL)
+		if ((c = lookup_commit_reference(the_repository, oid)) != NULL)
 			strbuf_addf(sb, ", %s", show_date(c->date, 0, DATE_MODE(SHORT)));
 		break;
 	case OBJ_TREE:
@@ -337,6 +355,8 @@ static int parse_msg_arg(const struct op
 {
 	struct msg_arg *msg = opt->value;
 
+	BUG_ON_OPT_NEG(unset);
+
 	if (!arg)
 		return -1;
 	if (msg->buf.len)
@@ -389,13 +409,12 @@ int cmd_tag(int argc, const char **argv,
 		OPT_GROUP(N_("Tag creation options")),
 		OPT_BOOL('a', "annotate", &annotate,
 					N_("annotated tag, needs a message")),
-		OPT_CALLBACK('m', "message", &msg, N_("message"),
-			     N_("tag message"), parse_msg_arg),
+		{ OPTION_CALLBACK, 'm', "message", &msg, N_("message"),
+		  N_("tag message"), PARSE_OPT_NONEG, parse_msg_arg },
 		OPT_FILENAME('F', "file", &msgfile, N_("read message from file")),
 		OPT_BOOL('e', "edit", &edit_flag, N_("force edit of tag message")),
 		OPT_BOOL('s', "sign", &opt.sign, N_("annotated and GPG-signed tag")),
-		OPT_STRING(0, "cleanup", &cleanup_arg, N_("mode"),
-			N_("how to strip spaces and #comments from message")),
+		OPT_CLEANUP(&cleanup_arg),
 		OPT_STRING('u', "local-user", &keyid, N_("key-id"),
 					N_("use another key to sign the tag")),
 		OPT__FORCE(&force, N_("replace the tag if exists"), 0),
@@ -409,8 +428,7 @@ int cmd_tag(int argc, const char **argv,
 		OPT_WITHOUT(&filter.no_commit, N_("print only tags that don't contain the commit")),
 		OPT_MERGED(&filter, N_("print only tags that are merged")),
 		OPT_NO_MERGED(&filter, N_("print only tags that are not merged")),
-		OPT_CALLBACK(0 , "sort", sorting_tail, N_("key"),
-			     N_("field name to sort on"), &parse_opt_ref_sorting),
+		OPT_REF_SORT(sorting_tail),
 		{
 			OPTION_CALLBACK, 0, "points-at", &filter.points_at, N_("object"),
 			N_("print only tags of the object"), PARSE_OPT_LASTARG_DEFAULT,
@@ -430,15 +448,10 @@ int cmd_tag(int argc, const char **argv,
 	memset(&opt, 0, sizeof(opt));
 	memset(&filter, 0, sizeof(filter));
 	filter.lines = -1;
+	opt.sign = -1;
 
 	argc = parse_options(argc, argv, prefix, options, git_tag_usage, 0);
 
-	if (keyid) {
-		opt.sign = 1;
-		set_signing_key(keyid);
-	}
-	create_tag_object = (opt.sign || annotate || msg.given || msgfile);
-
 	if (!cmdmode) {
 		if (argc == 0)
 			cmdmode = 'l';
@@ -451,6 +464,15 @@ int cmd_tag(int argc, const char **argv,
 	if (cmdmode == 'l')
 		setup_auto_pager("tag", 1);
 
+	if (opt.sign == -1)
+		opt.sign = cmdmode ? 0 : config_sign_tag > 0;
+
+	if (keyid) {
+		opt.sign = 1;
+		set_signing_key(keyid);
+	}
+	create_tag_object = (opt.sign || annotate || msg.given || msgfile);
+
 	if ((create_tag_object || force) && (cmdmode != 0))
 		usage_with_options(git_tag_usage, options);
 
@@ -547,7 +569,7 @@ int cmd_tag(int argc, const char **argv,
 	if (create_tag_object) {
 		if (force_sign_annotate && !annotate)
 			opt.sign = 1;
-		create_tag(&object, tag, &buf, &opt, &prev, &object);
+		create_tag(&object, object_ref, tag, &buf, &opt, &prev, &object);
 	}
 
 	transaction = ref_transaction_begin(&err);
@@ -558,7 +580,7 @@ int cmd_tag(int argc, const char **argv,
 	    ref_transaction_commit(transaction, &err))
 		die("%s", err.buf);
 	ref_transaction_free(transaction);
-	if (force && !is_null_oid(&prev) && oidcmp(&prev, &object))
+	if (force && !is_null_oid(&prev) && !oideq(&prev, &object))
 		printf(_("Updated tag '%s' (was %s)\n"), tag,
 		       find_unique_abbrev(&prev, DEFAULT_ABBREV));
 
diff -pruN 1.2.1+git2.18.0-1/git/builtin/unpack-file.c 1.2.3+git2.25.1-1/git/builtin/unpack-file.c
--- 1.2.1+git2.18.0-1/git/builtin/unpack-file.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/builtin/unpack-file.c	2020-02-17 04:47:35.000000000 +0000
@@ -1,5 +1,6 @@
 #include "builtin.h"
 #include "config.h"
+#include "object-store.h"
 
 static char *create_temp_file(struct object_id *oid)
 {
diff -pruN 1.2.1+git2.18.0-1/git/builtin/unpack-objects.c 1.2.3+git2.25.1-1/git/builtin/unpack-objects.c
--- 1.2.1+git2.18.0-1/git/builtin/unpack-objects.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/builtin/unpack-objects.c	2020-02-17 04:47:35.000000000 +0000
@@ -1,6 +1,7 @@
 #include "builtin.h"
 #include "cache.h"
 #include "config.h"
+#include "object-store.h"
 #include "object.h"
 #include "delta.h"
 #include "pack.h"
@@ -23,6 +24,7 @@ static off_t consumed_bytes;
 static off_t max_input_size;
 static git_hash_ctx ctx;
 static struct fsck_options fsck_options = FSCK_OPTIONS_STRICT;
+static struct progress *progress;
 
 /*
  * When running under --strict mode, objects whose reachability are
@@ -91,6 +93,7 @@ static void use(int bytes)
 	consumed_bytes += bytes;
 	if (max_input_size && consumed_bytes > max_input_size)
 		die(_("pack exceeds maximum allowed size"));
+	display_throughput(progress, consumed_bytes);
 }
 
 static void *get_data(unsigned long size)
@@ -253,7 +256,7 @@ static void write_object(unsigned nr, en
 		added_object(nr, type, buf, size);
 		free(buf);
 
-		blob = lookup_blob(&obj_list[nr].oid);
+		blob = lookup_blob(the_repository, &obj_list[nr].oid);
 		if (blob)
 			blob->object.flags |= FLAG_WRITTEN;
 		else
@@ -264,7 +267,8 @@ static void write_object(unsigned nr, en
 		int eaten;
 		hash_object_file(buf, size, type_name(type), &obj_list[nr].oid);
 		added_object(nr, type, buf, size);
-		obj = parse_object_buffer(&obj_list[nr].oid, type, size, buf,
+		obj = parse_object_buffer(the_repository, &obj_list[nr].oid,
+					  type, size, buf,
 					  &eaten);
 		if (!obj)
 			die("invalid %s", type_name(type));
@@ -301,7 +305,7 @@ static void added_object(unsigned nr, en
 	struct delta_info *info;
 
 	while ((info = *p) != NULL) {
-		if (!oidcmp(&info->base_oid, &obj_list[nr].oid) ||
+		if (oideq(&info->base_oid, &obj_list[nr].oid) ||
 		    info->base_offset == obj_list[nr].offset) {
 			*p = info->next;
 			p = &delta_list;
@@ -330,7 +334,7 @@ static int resolve_against_held(unsigned
 {
 	struct object *obj;
 	struct obj_buffer *obj_buffer;
-	obj = lookup_object(base->hash);
+	obj = lookup_object(the_repository, base);
 	if (!obj)
 		return 0;
 	obj_buffer = lookup_object_buffer(obj);
@@ -482,7 +486,6 @@ static void unpack_one(unsigned nr)
 static void unpack_all(void)
 {
 	int i;
-	struct progress *progress = NULL;
 	struct pack_header *hdr = fill(sizeof(struct pack_header));
 
 	nr_objects = ntohl(hdr->hdr_entries);
@@ -512,7 +515,7 @@ int cmd_unpack_objects(int argc, const c
 	int i;
 	struct object_id oid;
 
-	check_replace_refs = 0;
+	read_replace_refs = 0;
 
 	git_config(git_default_config, NULL);
 
@@ -577,7 +580,7 @@ int cmd_unpack_objects(int argc, const c
 		if (fsck_finish(&fsck_options))
 			die(_("fsck error in pack objects"));
 	}
-	if (hashcmp(fill(the_hash_algo->rawsz), oid.hash))
+	if (!hasheq(fill(the_hash_algo->rawsz), oid.hash))
 		die("final sha1 did not match");
 	use(the_hash_algo->rawsz);
 
diff -pruN 1.2.1+git2.18.0-1/git/builtin/update-index.c 1.2.3+git2.25.1-1/git/builtin/update-index.c
--- 1.2.1+git2.18.0-1/git/builtin/update-index.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/builtin/update-index.c	2020-02-17 04:47:35.000000000 +0000
@@ -3,6 +3,7 @@
  *
  * Copyright (C) Linus Torvalds, 2005
  */
+#define USE_THE_INDEX_COMPATIBILITY_MACROS
 #include "cache.h"
 #include "config.h"
 #include "lockfile.h"
@@ -34,6 +35,7 @@ static int verbose;
 static int mark_valid_only;
 static int mark_skip_worktree_only;
 static int mark_fsmonitor_only;
+static int ignore_skip_worktree_entries;
 #define MARK_FLAG 1
 #define UNMARK_FLAG 2
 static struct strbuf mtime_dir = STRBUF_INIT;
@@ -268,30 +270,29 @@ static int process_lstat_error(const cha
 
 static int add_one_path(const struct cache_entry *old, const char *path, int len, struct stat *st)
 {
-	int option, size;
+	int option;
 	struct cache_entry *ce;
 
 	/* Was the old index entry already up-to-date? */
 	if (old && !ce_stage(old) && !ce_match_stat(old, st, 0))
 		return 0;
 
-	size = cache_entry_size(len);
-	ce = xcalloc(1, size);
+	ce = make_empty_cache_entry(&the_index, len);
 	memcpy(ce->name, path, len);
 	ce->ce_flags = create_ce_flags(0);
 	ce->ce_namelen = len;
-	fill_stat_cache_info(ce, st);
+	fill_stat_cache_info(&the_index, ce, st);
 	ce->ce_mode = ce_mode_from_stat(old, st->st_mode);
 
-	if (index_path(&ce->oid, path, st,
+	if (index_path(&the_index, &ce->oid, path, st,
 		       info_only ? 0 : HASH_WRITE_OBJECT)) {
-		free(ce);
+		discard_cache_entry(ce);
 		return -1;
 	}
 	option = allow_add ? ADD_CACHE_OK_TO_ADD : 0;
 	option |= allow_replace ? ADD_CACHE_OK_TO_REPLACE : 0;
 	if (add_cache_entry(ce, option)) {
-		free(ce);
+		discard_cache_entry(ce);
 		return error("%s: cannot add to the index - missing --add option?", path);
 	}
 	return 0;
@@ -381,7 +382,8 @@ static int process_path(const char *path
 		 * so updating it does not make sense.
 		 * On the other hand, removing it from index should work
 		 */
-		if (allow_remove && remove_file_from_cache(path))
+		if (!ignore_skip_worktree_entries && allow_remove &&
+		    remove_file_from_cache(path))
 			return error("%s: cannot remove from the index", path);
 		return 0;
 	}
@@ -402,15 +404,14 @@ static int process_path(const char *path
 static int add_cacheinfo(unsigned int mode, const struct object_id *oid,
 			 const char *path, int stage)
 {
-	int size, len, option;
+	int len, option;
 	struct cache_entry *ce;
 
 	if (!verify_path(path, mode))
 		return error("Invalid path '%s'", path);
 
 	len = strlen(path);
-	size = cache_entry_size(len);
-	ce = xcalloc(1, size);
+	ce = make_empty_cache_entry(&the_index, len);
 
 	oidcpy(&ce->oid, oid);
 	memcpy(ce->name, path, len);
@@ -492,6 +493,7 @@ static void update_one(const char *path)
 
 static void read_index_info(int nul_term_line)
 {
+	const int hexsz = the_hash_algo->hexsz;
 	struct strbuf buf = STRBUF_INIT;
 	struct strbuf uq = STRBUF_INIT;
 	strbuf_getline_fn getline_fn;
@@ -529,7 +531,7 @@ static void read_index_info(int nul_term
 		mode = ul;
 
 		tab = strchr(ptr, '\t');
-		if (!tab || tab - ptr < GIT_SHA1_HEXSZ + 1)
+		if (!tab || tab - ptr < hexsz + 1)
 			goto bad_line;
 
 		if (tab[-2] == ' ' && '0' <= tab[-1] && tab[-1] <= '3') {
@@ -542,8 +544,8 @@ static void read_index_info(int nul_term
 			ptr = tab + 1; /* point at the head of path */
 		}
 
-		if (get_oid_hex(tab - GIT_SHA1_HEXSZ, &oid) ||
-			tab[-(GIT_SHA1_HEXSZ + 1)] != ' ')
+		if (get_oid_hex(tab - hexsz, &oid) ||
+			tab[-(hexsz + 1)] != ' ')
 			goto bad_line;
 
 		path_name = ptr;
@@ -571,7 +573,7 @@ static void read_index_info(int nul_term
 			 * ptr[-1] points at tab,
 			 * ptr[-41] is at the beginning of sha1
 			 */
-			ptr[-(GIT_SHA1_HEXSZ + 2)] = ptr[-1] = 0;
+			ptr[-(hexsz + 2)] = ptr[-1] = 0;
 			if (add_cacheinfo(mode, &oid, path_name, stage))
 				die("git update-index: unable to update %s",
 				    path_name);
@@ -597,12 +599,11 @@ static struct cache_entry *read_one_ent(
 					struct object_id *ent, const char *path,
 					int namelen, int stage)
 {
-	unsigned mode;
+	unsigned short mode;
 	struct object_id oid;
-	int size;
 	struct cache_entry *ce;
 
-	if (get_tree_entry(ent, path, &oid, &mode)) {
+	if (get_tree_entry(the_repository, ent, path, &oid, &mode)) {
 		if (which)
 			error("%s: not in %s branch.", path, which);
 		return NULL;
@@ -612,8 +613,7 @@ static struct cache_entry *read_one_ent(
 			error("%s: not a blob in %s branch.", path, which);
 		return NULL;
 	}
-	size = cache_entry_size(namelen);
-	ce = xcalloc(1, size);
+	ce = make_empty_cache_entry(&the_index, namelen);
 
 	oidcpy(&ce->oid, &oid);
 	memcpy(ce->name, path, namelen);
@@ -672,7 +672,7 @@ static int unresolve_one(const char *pat
 		ret = -1;
 		goto free_return;
 	}
-	if (!oidcmp(&ce_2->oid, &ce_3->oid) &&
+	if (oideq(&ce_2->oid, &ce_3->oid) &&
 	    ce_2->ce_mode == ce_3->ce_mode) {
 		fprintf(stderr, "%s: identical in both, skipping.\n",
 			path);
@@ -690,8 +690,8 @@ static int unresolve_one(const char *pat
 	error("%s: cannot add their version to the index.", path);
 	ret = -1;
  free_return:
-	free(ce_2);
-	free(ce_3);
+	discard_cache_entry(ce_2);
+	discard_cache_entry(ce_3);
 	return ret;
 }
 
@@ -726,7 +726,7 @@ static int do_unresolve(int ac, const ch
 }
 
 static int do_reupdate(int ac, const char **av,
-		       const char *prefix, int prefix_length)
+		       const char *prefix)
 {
 	/* Read HEAD and run update-index on paths that are
 	 * merged and already different between index and HEAD.
@@ -751,14 +751,14 @@ static int do_reupdate(int ac, const cha
 		int save_nr;
 		char *path;
 
-		if (ce_stage(ce) || !ce_path_match(ce, &pathspec, NULL))
+		if (ce_stage(ce) || !ce_path_match(&the_index, ce, &pathspec, NULL))
 			continue;
 		if (has_head)
 			old = read_one_ent(NULL, &head_oid,
 					   ce->name, ce_namelen(ce), 0);
 		if (old && ce->ce_mode == old->ce_mode &&
-		    !oidcmp(&ce->oid, &old->oid)) {
-			free(old);
+		    oideq(&ce->oid, &old->oid)) {
+			discard_cache_entry(old);
 			continue; /* unchanged */
 		}
 		/* Be careful.  The working tree may not have the
@@ -769,7 +769,7 @@ static int do_reupdate(int ac, const cha
 		path = xstrdup(ce->name);
 		update_one(path);
 		free(path);
-		free(old);
+		discard_cache_entry(old);
 		if (save_nr != active_nr)
 			goto redo;
 	}
@@ -785,7 +785,7 @@ struct refresh_params {
 static int refresh(struct refresh_params *o, unsigned int flag)
 {
 	setup_work_tree();
-	read_cache_preload(NULL);
+	read_cache();
 	*o->has_errors |= refresh_cache(o->flags | flag);
 	return 0;
 }
@@ -793,12 +793,16 @@ static int refresh(struct refresh_params
 static int refresh_callback(const struct option *opt,
 				const char *arg, int unset)
 {
+	BUG_ON_OPT_NEG(unset);
+	BUG_ON_OPT_ARG(arg);
 	return refresh(opt->value, 0);
 }
 
 static int really_refresh_callback(const struct option *opt,
 				const char *arg, int unset)
 {
+	BUG_ON_OPT_NEG(unset);
+	BUG_ON_OPT_ARG(arg);
 	return refresh(opt->value, REFRESH_REALLY);
 }
 
@@ -806,6 +810,7 @@ static int chmod_callback(const struct o
 				const char *arg, int unset)
 {
 	char *flip = opt->value;
+	BUG_ON_OPT_NEG(unset);
 	if ((arg[0] != '-' && arg[0] != '+') || arg[1] != 'x' || arg[2])
 		return error("option 'chmod' expects \"+x\" or \"-x\"");
 	*flip = arg[0];
@@ -815,6 +820,8 @@ static int chmod_callback(const struct o
 static int resolve_undo_clear_callback(const struct option *opt,
 				const char *arg, int unset)
 {
+	BUG_ON_OPT_NEG(unset);
+	BUG_ON_OPT_ARG(arg);
 	resolve_undo_clear();
 	return 0;
 }
@@ -826,6 +833,7 @@ static int parse_new_style_cacheinfo(con
 {
 	unsigned long ul;
 	char *endp;
+	const char *p;
 
 	if (!arg)
 		return -1;
@@ -836,19 +844,23 @@ static int parse_new_style_cacheinfo(con
 		return -1; /* not a new-style cacheinfo */
 	*mode = ul;
 	endp++;
-	if (get_oid_hex(endp, oid) || endp[GIT_SHA1_HEXSZ] != ',')
+	if (parse_oid_hex(endp, oid, &p) || *p != ',')
 		return -1;
-	*path = endp + GIT_SHA1_HEXSZ + 1;
+	*path = p + 1;
 	return 0;
 }
 
-static int cacheinfo_callback(struct parse_opt_ctx_t *ctx,
-				const struct option *opt, int unset)
+static enum parse_opt_result cacheinfo_callback(
+	struct parse_opt_ctx_t *ctx, const struct option *opt,
+	const char *arg, int unset)
 {
 	struct object_id oid;
 	unsigned int mode;
 	const char *path;
 
+	BUG_ON_OPT_NEG(unset);
+	BUG_ON_OPT_ARG(arg);
+
 	if (!parse_new_style_cacheinfo(ctx->argv[1], &mode, &oid, &path)) {
 		if (add_cacheinfo(mode, &oid, path, 0))
 			die("git update-index: --cacheinfo cannot add %s", path);
@@ -866,11 +878,15 @@ static int cacheinfo_callback(struct par
 	return 0;
 }
 
-static int stdin_cacheinfo_callback(struct parse_opt_ctx_t *ctx,
-			      const struct option *opt, int unset)
+static enum parse_opt_result stdin_cacheinfo_callback(
+	struct parse_opt_ctx_t *ctx, const struct option *opt,
+	const char *arg, int unset)
 {
 	int *nul_term_line = opt->value;
 
+	BUG_ON_OPT_NEG(unset);
+	BUG_ON_OPT_ARG(arg);
+
 	if (ctx->argc != 1)
 		return error("option '%s' must be the last argument", opt->long_name);
 	allow_add = allow_replace = allow_remove = 1;
@@ -878,23 +894,31 @@ static int stdin_cacheinfo_callback(stru
 	return 0;
 }
 
-static int stdin_callback(struct parse_opt_ctx_t *ctx,
-				const struct option *opt, int unset)
+static enum parse_opt_result stdin_callback(
+	struct parse_opt_ctx_t *ctx, const struct option *opt,
+	const char *arg, int unset)
 {
 	int *read_from_stdin = opt->value;
 
+	BUG_ON_OPT_NEG(unset);
+	BUG_ON_OPT_ARG(arg);
+
 	if (ctx->argc != 1)
 		return error("option '%s' must be the last argument", opt->long_name);
 	*read_from_stdin = 1;
 	return 0;
 }
 
-static int unresolve_callback(struct parse_opt_ctx_t *ctx,
-				const struct option *opt, int flags)
+static enum parse_opt_result unresolve_callback(
+	struct parse_opt_ctx_t *ctx, const struct option *opt,
+	const char *arg, int unset)
 {
 	int *has_errors = opt->value;
 	const char *prefix = startup_info->prefix;
 
+	BUG_ON_OPT_NEG(unset);
+	BUG_ON_OPT_ARG(arg);
+
 	/* consume remaining arguments. */
 	*has_errors = do_unresolve(ctx->argc, ctx->argv,
 				prefix, prefix ? strlen(prefix) : 0);
@@ -906,16 +930,19 @@ static int unresolve_callback(struct par
 	return 0;
 }
 
-static int reupdate_callback(struct parse_opt_ctx_t *ctx,
-				const struct option *opt, int flags)
+static enum parse_opt_result reupdate_callback(
+	struct parse_opt_ctx_t *ctx, const struct option *opt,
+	const char *arg, int unset)
 {
 	int *has_errors = opt->value;
 	const char *prefix = startup_info->prefix;
 
+	BUG_ON_OPT_NEG(unset);
+	BUG_ON_OPT_ARG(arg);
+
 	/* consume remaining arguments. */
 	setup_work_tree();
-	*has_errors = do_reupdate(ctx->argc, ctx->argv,
-				prefix, prefix ? strlen(prefix) : 0);
+	*has_errors = do_reupdate(ctx->argc, ctx->argv, prefix);
 	if (*has_errors)
 		active_cache_changed = 0;
 
@@ -941,6 +968,7 @@ int cmd_update_index(int argc, const cha
 	struct parse_opt_ctx_t ctx;
 	strbuf_getline_fn getline_fn;
 	int parseopt_state = PARSE_OPT_UNKNOWN;
+	struct repository *r = the_repository;
 	struct option options[] = {
 		OPT_BIT('q', NULL, &refresh_args.flags,
 			N_("continue refresh even when index needs update"),
@@ -970,10 +998,11 @@ int cmd_update_index(int argc, const cha
 			N_("add the specified entry to the index"),
 			PARSE_OPT_NOARG | /* disallow --cacheinfo=<mode> form */
 			PARSE_OPT_NONEG | PARSE_OPT_LITERAL_ARGHELP,
-			(parse_opt_cb *) cacheinfo_callback},
-		{OPTION_CALLBACK, 0, "chmod", &set_executable_bit, N_("(+/-)x"),
+			NULL, 0,
+			cacheinfo_callback},
+		{OPTION_CALLBACK, 0, "chmod", &set_executable_bit, "(+|-)x",
 			N_("override the executable bit of the listed files"),
-			PARSE_OPT_NONEG | PARSE_OPT_LITERAL_ARGHELP,
+			PARSE_OPT_NONEG,
 			chmod_callback},
 		{OPTION_SET_INT, 0, "assume-unchanged", &mark_valid_only, NULL,
 			N_("mark files as \"not changing\""),
@@ -987,6 +1016,8 @@ int cmd_update_index(int argc, const cha
 		{OPTION_SET_INT, 0, "no-skip-worktree", &mark_skip_worktree_only, NULL,
 			N_("clear skip-worktree bit"),
 			PARSE_OPT_NOARG | PARSE_OPT_NONEG, NULL, UNMARK_FLAG},
+		OPT_BOOL(0, "ignore-skip-worktree-entries", &ignore_skip_worktree_entries,
+			 N_("do not touch index-only entries")),
 		OPT_SET_INT(0, "info-only", &info_only,
 			N_("add to index only; do not add content to object database"), 1),
 		OPT_SET_INT(0, "force-remove", &force_remove,
@@ -996,19 +1027,19 @@ int cmd_update_index(int argc, const cha
 		{OPTION_LOWLEVEL_CALLBACK, 0, "stdin", &read_from_stdin, NULL,
 			N_("read list of paths to be updated from standard input"),
 			PARSE_OPT_NONEG | PARSE_OPT_NOARG,
-			(parse_opt_cb *) stdin_callback},
+			NULL, 0, stdin_callback},
 		{OPTION_LOWLEVEL_CALLBACK, 0, "index-info", &nul_term_line, NULL,
 			N_("add entries from standard input to the index"),
 			PARSE_OPT_NONEG | PARSE_OPT_NOARG,
-			(parse_opt_cb *) stdin_cacheinfo_callback},
+			NULL, 0, stdin_cacheinfo_callback},
 		{OPTION_LOWLEVEL_CALLBACK, 0, "unresolve", &has_errors, NULL,
 			N_("repopulate stages #2 and #3 for the listed paths"),
 			PARSE_OPT_NONEG | PARSE_OPT_NOARG,
-			(parse_opt_cb *) unresolve_callback},
+			NULL, 0, unresolve_callback},
 		{OPTION_LOWLEVEL_CALLBACK, 'g', "again", &has_errors, NULL,
 			N_("only update entries that differ from HEAD"),
 			PARSE_OPT_NONEG | PARSE_OPT_NOARG,
-			(parse_opt_cb *) reupdate_callback},
+			NULL, 0, reupdate_callback},
 		OPT_BIT(0, "ignore-missing", &refresh_args.flags,
 			N_("ignore files missing from worktree"),
 			REFRESH_IGNORE_MISSING),
@@ -1055,6 +1086,8 @@ int cmd_update_index(int argc, const cha
 	if (entries < 0)
 		die("cache corrupted");
 
+	the_index.updated_skipworktree = 1;
+
 	/*
 	 * Custom copy of parse_options() because we want to handle
 	 * filename arguments as they come.
@@ -1071,6 +1104,8 @@ int cmd_update_index(int argc, const cha
 		case PARSE_OPT_HELP:
 		case PARSE_OPT_ERROR:
 			exit(129);
+		case PARSE_OPT_COMPLETE:
+			exit(0);
 		case PARSE_OPT_NON_OPTION:
 		case PARSE_OPT_DONE:
 		{
@@ -1150,11 +1185,12 @@ int cmd_update_index(int argc, const cha
 		remove_split_index(&the_index);
 	}
 
+	prepare_repo_settings(r);
 	switch (untracked_cache) {
 	case UC_UNSPECIFIED:
 		break;
 	case UC_DISABLE:
-		if (git_config_get_untracked_cache() == 1)
+		if (r->settings.core_untracked_cache == UNTRACKED_CACHE_WRITE)
 			warning(_("core.untrackedCache is set to true; "
 				  "remove or change it, if you really want to "
 				  "disable the untracked cache"));
@@ -1166,7 +1202,7 @@ int cmd_update_index(int argc, const cha
 		return !test_if_untracked_cache_is_supported();
 	case UC_ENABLE:
 	case UC_FORCE:
-		if (git_config_get_untracked_cache() == 0)
+		if (r->settings.core_untracked_cache == UNTRACKED_CACHE_REMOVE)
 			warning(_("core.untrackedCache is set to false; "
 				  "remove or change it, if you really want to "
 				  "enable the untracked cache"));
diff -pruN 1.2.1+git2.18.0-1/git/builtin/update-ref.c 1.2.3+git2.25.1-1/git/builtin/update-ref.c
--- 1.2.1+git2.18.0-1/git/builtin/update-ref.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/builtin/update-ref.c	2020-02-17 04:47:35.000000000 +0000
@@ -14,7 +14,8 @@ static const char * const git_update_ref
 };
 
 static char line_termination = '\n';
-static int update_flags;
+static unsigned int update_flags;
+static unsigned int default_flags;
 static unsigned create_reflog_flag;
 static const char *msg;
 
@@ -205,7 +206,7 @@ static const char *parse_cmd_update(stru
 				   msg, &err))
 		die("%s", err.buf);
 
-	update_flags = 0;
+	update_flags = default_flags;
 	free(refname);
 	strbuf_release(&err);
 
@@ -237,7 +238,7 @@ static const char *parse_cmd_create(stru
 				   msg, &err))
 		die("%s", err.buf);
 
-	update_flags = 0;
+	update_flags = default_flags;
 	free(refname);
 	strbuf_release(&err);
 
@@ -273,7 +274,7 @@ static const char *parse_cmd_delete(stru
 				   update_flags, msg, &err))
 		die("%s", err.buf);
 
-	update_flags = 0;
+	update_flags = default_flags;
 	free(refname);
 	strbuf_release(&err);
 
@@ -302,7 +303,7 @@ static const char *parse_cmd_verify(stru
 				   update_flags, &err))
 		die("%s", err.buf);
 
-	update_flags = 0;
+	update_flags = default_flags;
 	free(refname);
 	strbuf_release(&err);
 
@@ -311,11 +312,12 @@ static const char *parse_cmd_verify(stru
 
 static const char *parse_cmd_option(struct strbuf *input, const char *next)
 {
-	if (!strncmp(next, "no-deref", 8) && next[8] == line_termination)
+	const char *rest;
+	if (skip_prefix(next, "no-deref", &rest) && *rest == line_termination)
 		update_flags |= REF_NO_DEREF;
 	else
 		die("option unknown: %s", next);
-	return next + 8;
+	return rest;
 }
 
 static void update_refs_stdin(struct ref_transaction *transaction)
@@ -332,16 +334,16 @@ static void update_refs_stdin(struct ref
 			die("empty command in input");
 		else if (isspace(*next))
 			die("whitespace before command: %s", next);
-		else if (starts_with(next, "update "))
-			next = parse_cmd_update(transaction, &input, next + 7);
-		else if (starts_with(next, "create "))
-			next = parse_cmd_create(transaction, &input, next + 7);
-		else if (starts_with(next, "delete "))
-			next = parse_cmd_delete(transaction, &input, next + 7);
-		else if (starts_with(next, "verify "))
-			next = parse_cmd_verify(transaction, &input, next + 7);
-		else if (starts_with(next, "option "))
-			next = parse_cmd_option(&input, next + 7);
+		else if (skip_prefix(next, "update ", &next))
+			next = parse_cmd_update(transaction, &input, next);
+		else if (skip_prefix(next, "create ", &next))
+			next = parse_cmd_create(transaction, &input, next);
+		else if (skip_prefix(next, "delete ", &next))
+			next = parse_cmd_delete(transaction, &input, next);
+		else if (skip_prefix(next, "verify ", &next))
+			next = parse_cmd_verify(transaction, &input, next);
+		else if (skip_prefix(next, "option ", &next))
+			next = parse_cmd_option(&input, next);
 		else
 			die("unknown command: %s", next);
 
@@ -356,7 +358,6 @@ int cmd_update_ref(int argc, const char
 	const char *refname, *oldval;
 	struct object_id oid, oldoid;
 	int delete = 0, no_deref = 0, read_stdin = 0, end_null = 0;
-	unsigned int flags = 0;
 	int create_reflog = 0;
 	struct option options[] = {
 		OPT_STRING( 'm', NULL, &msg, N_("reason"), N_("reason of the update")),
@@ -377,6 +378,11 @@ int cmd_update_ref(int argc, const char
 
 	create_reflog_flag = create_reflog ? REF_FORCE_CREATE_REFLOG : 0;
 
+	if (no_deref) {
+		default_flags = REF_NO_DEREF;
+		update_flags = default_flags;
+	}
+
 	if (read_stdin) {
 		struct strbuf err = STRBUF_INIT;
 		struct ref_transaction *transaction;
@@ -384,7 +390,7 @@ int cmd_update_ref(int argc, const char
 		transaction = ref_transaction_begin(&err);
 		if (!transaction)
 			die("%s", err.buf);
-		if (delete || no_deref || argc > 0)
+		if (delete || argc > 0)
 			usage_with_options(git_update_ref_usage, options);
 		if (end_null)
 			line_termination = '\0';
@@ -426,8 +432,6 @@ int cmd_update_ref(int argc, const char
 			die("%s: not a valid old SHA1", oldval);
 	}
 
-	if (no_deref)
-		flags = REF_NO_DEREF;
 	if (delete)
 		/*
 		 * For purposes of backwards compatibility, we treat
@@ -435,9 +439,9 @@ int cmd_update_ref(int argc, const char
 		 */
 		return delete_ref(msg, refname,
 				  (oldval && !is_null_oid(&oldoid)) ? &oldoid : NULL,
-				  flags);
+				  default_flags);
 	else
 		return update_ref(msg, refname, &oid, oldval ? &oldoid : NULL,
-				  flags | create_reflog_flag,
+				  default_flags | create_reflog_flag,
 				  UPDATE_REFS_DIE_ON_ERR);
 }
diff -pruN 1.2.1+git2.18.0-1/git/builtin/upload-archive.c 1.2.3+git2.25.1-1/git/builtin/upload-archive.c
--- 1.2.1+git2.18.0-1/git/builtin/upload-archive.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/builtin/upload-archive.c	2020-02-17 04:47:35.000000000 +0000
@@ -28,6 +28,8 @@ int cmd_upload_archive_writer(int argc,
 	if (!enter_repo(argv[1], 0))
 		die("'%s' does not appear to be a git repository", argv[1]);
 
+	init_archivers();
+
 	/* put received options in sent_argv[] */
 	argv_array_push(&sent_argv, "git-upload-archive");
 	for (;;) {
@@ -43,7 +45,8 @@ int cmd_upload_archive_writer(int argc,
 	}
 
 	/* parse all options sent by the client */
-	return write_archive(sent_argv.argc, sent_argv.argv, prefix, NULL, 1);
+	return write_archive(sent_argv.argc, sent_argv.argv, prefix,
+			     the_repository, NULL, 1);
 }
 
 __attribute__((format (printf, 1, 2)))
diff -pruN 1.2.1+git2.18.0-1/git/builtin/upload-pack.c 1.2.3+git2.25.1-1/git/builtin/upload-pack.c
--- 1.2.1+git2.18.0-1/git/builtin/upload-pack.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/builtin/upload-pack.c	2020-02-17 04:47:35.000000000 +0000
@@ -31,9 +31,9 @@ int cmd_upload_pack(int argc, const char
 	};
 
 	packet_trace_identity("upload-pack");
-	check_replace_refs = 0;
+	read_replace_refs = 0;
 
-	argc = parse_options(argc, argv, NULL, options, upload_pack_usage, 0);
+	argc = parse_options(argc, argv, prefix, options, upload_pack_usage, 0);
 
 	if (argc != 1)
 		usage_with_options(upload_pack_usage, options);
diff -pruN 1.2.1+git2.18.0-1/git/builtin/verify-commit.c 1.2.3+git2.25.1-1/git/builtin/verify-commit.c
--- 1.2.1+git2.18.0-1/git/builtin/verify-commit.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/builtin/verify-commit.c	2020-02-17 04:47:35.000000000 +0000
@@ -8,9 +8,10 @@
 #include "cache.h"
 #include "config.h"
 #include "builtin.h"
+#include "object-store.h"
+#include "repository.h"
 #include "commit.h"
 #include "run-command.h"
-#include <signal.h>
 #include "parse-options.h"
 #include "gpg-interface.h"
 
@@ -19,14 +20,14 @@ static const char * const verify_commit_
 		NULL
 };
 
-static int run_gpg_verify(const struct object_id *oid, const char *buf, unsigned long size, unsigned flags)
+static int run_gpg_verify(struct commit *commit, unsigned flags)
 {
 	struct signature_check signature_check;
 	int ret;
 
 	memset(&signature_check, 0, sizeof(signature_check));
 
-	ret = check_commit_signature(lookup_commit(oid), &signature_check);
+	ret = check_commit_signature(commit, &signature_check);
 	print_signature_buffer(&signature_check, flags);
 
 	signature_check_clear(&signature_check);
@@ -35,26 +36,20 @@ static int run_gpg_verify(const struct o
 
 static int verify_commit(const char *name, unsigned flags)
 {
-	enum object_type type;
 	struct object_id oid;
-	char *buf;
-	unsigned long size;
-	int ret;
+	struct object *obj;
 
 	if (get_oid(name, &oid))
 		return error("commit '%s' not found.", name);
 
-	buf = read_object_file(&oid, &type, &size);
-	if (!buf)
+	obj = parse_object(the_repository, &oid);
+	if (!obj)
 		return error("%s: unable to read file.", name);
-	if (type != OBJ_COMMIT)
+	if (obj->type != OBJ_COMMIT)
 		return error("%s: cannot verify a non-commit object of type %s.",
-				name, type_name(type));
-
-	ret = run_gpg_verify(&oid, buf, size, flags);
+				name, type_name(obj->type));
 
-	free(buf);
-	return ret;
+	return run_gpg_verify((struct commit *)obj, flags);
 }
 
 static int git_verify_commit_config(const char *var, const char *value, void *cb)
diff -pruN 1.2.1+git2.18.0-1/git/builtin/verify-tag.c 1.2.3+git2.25.1-1/git/builtin/verify-tag.c
--- 1.2.1+git2.18.0-1/git/builtin/verify-tag.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/builtin/verify-tag.c	2020-02-17 04:47:35.000000000 +0000
@@ -10,7 +10,6 @@
 #include "builtin.h"
 #include "tag.h"
 #include "run-command.h"
-#include <signal.h>
 #include "parse-options.h"
 #include "gpg-interface.h"
 #include "ref-filter.h"
diff -pruN 1.2.1+git2.18.0-1/git/builtin/worktree.c 1.2.3+git2.25.1-1/git/builtin/worktree.c
--- 1.2.1+git2.18.0-1/git/builtin/worktree.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/builtin/worktree.c	2020-02-17 04:47:35.000000000 +0000
@@ -9,7 +9,7 @@
 #include "refs.h"
 #include "run-command.h"
 #include "sigchain.h"
-#include "refs.h"
+#include "submodule.h"
 #include "utf8.h"
 #include "worktree.h"
 
@@ -27,6 +27,7 @@ static const char * const worktree_usage
 struct add_opts {
 	int force;
 	int detach;
+	int quiet;
 	int checkout;
 	int keep_locked;
 };
@@ -46,6 +47,26 @@ static int git_worktree_config(const cha
 	return git_default_config(var, value, cb);
 }
 
+static int delete_git_dir(const char *id)
+{
+	struct strbuf sb = STRBUF_INIT;
+	int ret;
+
+	strbuf_addstr(&sb, git_common_path("worktrees/%s", id));
+	ret = remove_dir_recursively(&sb, 0);
+	if (ret < 0 && errno == ENOTDIR)
+		ret = unlink(sb.buf);
+	if (ret)
+		error_errno(_("failed to delete '%s'"), sb.buf);
+	strbuf_release(&sb);
+	return ret;
+}
+
+static void delete_worktrees_dir_if_empty(void)
+{
+	rmdir(git_path("worktrees")); /* ignore failed removal */
+}
+
 static int prune_worktree(const char *id, struct strbuf *reason)
 {
 	struct stat st;
@@ -115,10 +136,8 @@ static int prune_worktree(const char *id
 static void prune_worktrees(void)
 {
 	struct strbuf reason = STRBUF_INIT;
-	struct strbuf path = STRBUF_INIT;
 	DIR *dir = opendir(git_path("worktrees"));
 	struct dirent *d;
-	int ret;
 	if (!dir)
 		return;
 	while ((d = readdir(dir)) != NULL) {
@@ -131,18 +150,12 @@ static void prune_worktrees(void)
 			printf("%s\n", reason.buf);
 		if (show_only)
 			continue;
-		git_path_buf(&path, "worktrees/%s", d->d_name);
-		ret = remove_dir_recursively(&path, 0);
-		if (ret < 0 && errno == ENOTDIR)
-			ret = unlink(path.buf);
-		if (ret)
-			error_errno(_("failed to remove '%s'"), path.buf);
+		delete_git_dir(d->d_name);
 	}
 	closedir(dir);
 	if (!show_only)
-		rmdir(git_path("worktrees"));
+		delete_worktrees_dir_if_empty();
 	strbuf_release(&reason);
-	strbuf_release(&path);
 }
 
 static int prune(int ac, const char **av, const char *prefix)
@@ -211,22 +224,59 @@ static const char *worktree_basename(con
 	return name;
 }
 
+static void validate_worktree_add(const char *path, const struct add_opts *opts)
+{
+	struct worktree **worktrees;
+	struct worktree *wt;
+	int locked;
+
+	if (file_exists(path) && !is_empty_dir(path))
+		die(_("'%s' already exists"), path);
+
+	worktrees = get_worktrees(0);
+	/*
+	 * find_worktree()'s suffix matching may undesirably find the main
+	 * rather than a linked worktree (for instance, when the basenames
+	 * of the main worktree and the one being created are the same).
+	 * We're only interested in linked worktrees, so skip the main
+	 * worktree with +1.
+	 */
+	wt = find_worktree(worktrees + 1, NULL, path);
+	if (!wt)
+		goto done;
+
+	locked = !!worktree_lock_reason(wt);
+	if ((!locked && opts->force) || (locked && opts->force > 1)) {
+		if (delete_git_dir(wt->id))
+		    die(_("unable to re-add worktree '%s'"), path);
+		goto done;
+	}
+
+	if (locked)
+		die(_("'%s' is a missing but locked worktree;\nuse 'add -f -f' to override, or 'unlock' and 'prune' or 'remove' to clear"), path);
+	else
+		die(_("'%s' is a missing but already registered worktree;\nuse 'add -f' to override, or 'prune' or 'remove' to clear"), path);
+
+done:
+	free_worktrees(worktrees);
+}
+
 static int add_worktree(const char *path, const char *refname,
 			const struct add_opts *opts)
 {
 	struct strbuf sb_git = STRBUF_INIT, sb_repo = STRBUF_INIT;
 	struct strbuf sb = STRBUF_INIT;
 	const char *name;
-	struct stat st;
 	struct child_process cp = CHILD_PROCESS_INIT;
 	struct argv_array child_env = ARGV_ARRAY_INIT;
-	int counter = 0, len, ret;
+	unsigned int counter = 0;
+	int len, ret;
 	struct strbuf symref = STRBUF_INIT;
 	struct commit *commit = NULL;
 	int is_branch = 0;
+	struct strbuf sb_name = STRBUF_INIT;
 
-	if (file_exists(path) && !is_empty_dir(path))
-		die(_("'%s' already exists"), path);
+	validate_worktree_add(path, opts);
 
 	/* is 'refname' a branch or commit? */
 	if (!opts->detach && !strbuf_check_branch_ref(&symref, refname) &&
@@ -240,13 +290,23 @@ static int add_worktree(const char *path
 		die(_("invalid reference: %s"), refname);
 
 	name = worktree_basename(path, &len);
-	git_path_buf(&sb_repo, "worktrees/%.*s", (int)(path + len - name), name);
+	strbuf_add(&sb, name, path + len - name);
+	sanitize_refname_component(sb.buf, &sb_name);
+	if (!sb_name.len)
+		BUG("How come '%s' becomes empty after sanitization?", sb.buf);
+	strbuf_reset(&sb);
+	name = sb_name.buf;
+	git_path_buf(&sb_repo, "worktrees/%s", name);
 	len = sb_repo.len;
 	if (safe_create_leading_directories_const(sb_repo.buf))
 		die_errno(_("could not create leading directories of '%s'"),
 			  sb_repo.buf);
-	while (!stat(sb_repo.buf, &st)) {
+
+	while (mkdir(sb_repo.buf, 0777)) {
 		counter++;
+		if ((errno != EEXIST) || !counter /* overflow */)
+			die_errno(_("could not create directory of '%s'"),
+				  sb_repo.buf);
 		strbuf_setlen(&sb_repo, len);
 		strbuf_addf(&sb_repo, "%d", counter);
 	}
@@ -256,8 +316,6 @@ static int add_worktree(const char *path
 	atexit(remove_junk);
 	sigchain_push_common(remove_junk_on_signal);
 
-	if (mkdir(sb_repo.buf, 0777))
-		die_errno(_("could not create directory of '%s'"), sb_repo.buf);
 	junk_git_dir = xstrdup(sb_repo.buf);
 	is_junk = 1;
 
@@ -291,7 +349,7 @@ static int add_worktree(const char *path
 	 */
 	strbuf_reset(&sb);
 	strbuf_addf(&sb, "%s/HEAD", sb_repo.buf);
-	write_file(sb.buf, "%s", sha1_to_hex(null_sha1));
+	write_file(sb.buf, "%s", oid_to_hex(&null_oid));
 	strbuf_reset(&sb);
 	strbuf_addf(&sb, "%s/commondir", sb_repo.buf);
 	write_file(sb.buf, "../..");
@@ -303,9 +361,13 @@ static int add_worktree(const char *path
 	if (!is_branch)
 		argv_array_pushl(&cp.args, "update-ref", "HEAD",
 				 oid_to_hex(&commit->object.oid), NULL);
-	else
+	else {
 		argv_array_pushl(&cp.args, "symbolic-ref", "HEAD",
 				 symref.buf, NULL);
+		if (opts->quiet)
+			argv_array_push(&cp.args, "--quiet");
+	}
+
 	cp.env = child_env.argv;
 	ret = run_command(&cp);
 	if (ret)
@@ -314,7 +376,9 @@ static int add_worktree(const char *path
 	if (opts->checkout) {
 		cp.argv = NULL;
 		argv_array_clear(&cp.args);
-		argv_array_pushl(&cp.args, "reset", "--hard", NULL);
+		argv_array_pushl(&cp.args, "reset", "--hard", "--no-recurse-submodules", NULL);
+		if (opts->quiet)
+			argv_array_push(&cp.args, "--quiet");
 		cp.env = child_env.argv;
 		ret = run_command(&cp);
 		if (ret)
@@ -346,6 +410,7 @@ done:
 			cp.dir = path;
 			cp.env = env;
 			cp.argv = NULL;
+			cp.trace2_hook_name = "post-checkout";
 			argv_array_pushl(&cp.args, absolute_path(hook),
 					 oid_to_hex(&null_oid),
 					 oid_to_hex(&commit->object.oid),
@@ -359,6 +424,7 @@ done:
 	strbuf_release(&symref);
 	strbuf_release(&sb_repo);
 	strbuf_release(&sb_git);
+	strbuf_release(&sb_name);
 	return ret;
 }
 
@@ -412,7 +478,7 @@ static const char *dwim_branch(const cha
 	if (guess_remote) {
 		struct object_id oid;
 		const char *remote =
-			unique_tracking_name(*new_branch, &oid);
+			unique_tracking_name(*new_branch, &oid, NULL);
 		return remote;
 	}
 	return NULL;
@@ -437,6 +503,7 @@ static int add(int ac, const char **av,
 		OPT_BOOL(0, "detach", &opts.detach, N_("detach HEAD at named commit")),
 		OPT_BOOL(0, "checkout", &opts.checkout, N_("populate the new working tree")),
 		OPT_BOOL(0, "lock", &opts.keep_locked, N_("keep the new working tree locked")),
+		OPT__QUIET(&opts.quiet, N_("suppress progress reporting")),
 		OPT_PASSTHRU(0, "track", &opt_track, NULL,
 			     N_("set up tracking mode (see git-branch(1))"),
 			     PARSE_OPT_NOARG | PARSE_OPT_OPTARG),
@@ -484,15 +551,15 @@ static int add(int ac, const char **av,
 
 		commit = lookup_commit_reference_by_name(branch);
 		if (!commit) {
-			remote = unique_tracking_name(branch, &oid);
+			remote = unique_tracking_name(branch, &oid, NULL);
 			if (remote) {
 				new_branch = branch;
 				branch = remote;
 			}
 		}
 	}
-
-	print_preparing_worktree_line(opts.detach, branch, new_branch, !!new_branch_force);
+	if (!opts.quiet)
+		print_preparing_worktree_line(opts.detach, branch, new_branch, !!new_branch_force);
 
 	if (new_branch) {
 		struct child_process cp = CHILD_PROCESS_INIT;
@@ -500,6 +567,8 @@ static int add(int ac, const char **av,
 		argv_array_push(&cp.args, "branch");
 		if (new_branch_force)
 			argv_array_push(&cp.args, "--force");
+		if (opts.quiet)
+			argv_array_push(&cp.args, "--quiet");
 		argv_array_push(&cp.args, new_branch);
 		argv_array_push(&cp.args, branch);
 		if (opt_track)
@@ -624,7 +693,7 @@ static int lock_worktree(int ac, const c
 	if (is_main_worktree(wt))
 		die(_("The main working tree cannot be locked or unlocked"));
 
-	old_reason = is_worktree_locked(wt);
+	old_reason = worktree_lock_reason(wt);
 	if (old_reason) {
 		if (*old_reason)
 			die(_("'%s' is already locked, reason: %s"),
@@ -656,7 +725,7 @@ static int unlock_worktree(int ac, const
 		die(_("'%s' is not a working tree"), av[0]);
 	if (is_main_worktree(wt))
 		die(_("The main working tree cannot be locked or unlocked"));
-	if (!is_worktree_locked(wt))
+	if (!worktree_lock_reason(wt))
 		die(_("'%s' is not locked"), av[0]);
 	ret = unlink_or_warn(git_common_path("worktrees/%s/locked", wt->id));
 	free_worktrees(worktrees);
@@ -666,20 +735,36 @@ static int unlock_worktree(int ac, const
 static void validate_no_submodules(const struct worktree *wt)
 {
 	struct index_state istate = { NULL };
+	struct strbuf path = STRBUF_INIT;
 	int i, found_submodules = 0;
 
-	if (read_index_from(&istate, worktree_git_path(wt, "index"),
-			    get_worktree_git_dir(wt)) > 0) {
+	if (is_directory(worktree_git_path(wt, "modules"))) {
+		/*
+		 * There could be false positives, e.g. the "modules"
+		 * directory exists but is empty. But it's a rare case and
+		 * this simpler check is probably good enough for now.
+		 */
+		found_submodules = 1;
+	} else if (read_index_from(&istate, worktree_git_path(wt, "index"),
+				   get_worktree_git_dir(wt)) > 0) {
 		for (i = 0; i < istate.cache_nr; i++) {
 			struct cache_entry *ce = istate.cache[i];
+			int err;
 
-			if (S_ISGITLINK(ce->ce_mode)) {
-				found_submodules = 1;
-				break;
-			}
+			if (!S_ISGITLINK(ce->ce_mode))
+				continue;
+
+			strbuf_reset(&path);
+			strbuf_addf(&path, "%s/%s", wt->path, ce->name);
+			if (!is_submodule_populated_gently(path.buf, &err))
+				continue;
+
+			found_submodules = 1;
+			break;
 		}
 	}
 	discard_index(&istate);
+	strbuf_release(&path);
 
 	if (found_submodules)
 		die(_("working trees containing submodules cannot be moved or removed"));
@@ -687,13 +772,17 @@ static void validate_no_submodules(const
 
 static int move_worktree(int ac, const char **av, const char *prefix)
 {
+	int force = 0;
 	struct option options[] = {
+		OPT__FORCE(&force,
+			 N_("force move even if worktree is dirty or locked"),
+			 PARSE_OPT_NOCOMPLETE),
 		OPT_END()
 	};
 	struct worktree **worktrees, *wt;
 	struct strbuf dst = STRBUF_INIT;
 	struct strbuf errmsg = STRBUF_INIT;
-	const char *reason;
+	const char *reason = NULL;
 	char *path;
 
 	ac = parse_options(ac, av, prefix, options, worktree_usage, 0);
@@ -724,12 +813,13 @@ static int move_worktree(int ac, const c
 
 	validate_no_submodules(wt);
 
-	reason = is_worktree_locked(wt);
+	if (force < 2)
+		reason = worktree_lock_reason(wt);
 	if (reason) {
 		if (*reason)
-			die(_("cannot move a locked working tree, lock reason: %s"),
+			die(_("cannot move a locked working tree, lock reason: %s\nuse 'move -f -f' to override or unlock first"),
 			    reason);
-		die(_("cannot move a locked working tree"));
+		die(_("cannot move a locked working tree;\nuse 'move -f -f' to override or unlock first"));
 	}
 	if (validate_worktree(wt, &errmsg, 0))
 		die(_("validation failed, cannot move working tree: %s"),
@@ -789,7 +879,7 @@ static void check_clean_worktree(struct
 			  original_path);
 	ret = xread(cp.out, buf, sizeof(buf));
 	if (ret)
-		die(_("'%s' is dirty, use --force to delete it"),
+		die(_("'%s' contains modified or untracked files, use --force to delete it"),
 		    original_path);
 	close(cp.out);
 	ret = finish_command(&cp);
@@ -812,32 +902,18 @@ static int delete_git_work_tree(struct w
 	return ret;
 }
 
-static int delete_git_dir(struct worktree *wt)
-{
-	struct strbuf sb = STRBUF_INIT;
-	int ret = 0;
-
-	strbuf_addstr(&sb, git_common_path("worktrees/%s", wt->id));
-	if (remove_dir_recursively(&sb, 0)) {
-		error_errno(_("failed to delete '%s'"), sb.buf);
-		ret = -1;
-	}
-	strbuf_release(&sb);
-	return ret;
-}
-
 static int remove_worktree(int ac, const char **av, const char *prefix)
 {
 	int force = 0;
 	struct option options[] = {
 		OPT__FORCE(&force,
-			 N_("force removing even if the worktree is dirty"),
+			 N_("force removal even if worktree is dirty or locked"),
 			 PARSE_OPT_NOCOMPLETE),
 		OPT_END()
 	};
 	struct worktree **worktrees, *wt;
 	struct strbuf errmsg = STRBUF_INIT;
-	const char *reason;
+	const char *reason = NULL;
 	int ret = 0;
 
 	ac = parse_options(ac, av, prefix, options, worktree_usage, 0);
@@ -850,12 +926,13 @@ static int remove_worktree(int ac, const
 		die(_("'%s' is not a working tree"), av[0]);
 	if (is_main_worktree(wt))
 		die(_("'%s' is a main working tree"), av[0]);
-	reason = is_worktree_locked(wt);
+	if (force < 2)
+		reason = worktree_lock_reason(wt);
 	if (reason) {
 		if (*reason)
-			die(_("cannot remove a locked working tree, lock reason: %s"),
+			die(_("cannot remove a locked working tree, lock reason: %s\nuse 'remove -f -f' to override or unlock first"),
 			    reason);
-		die(_("cannot remove a locked working tree"));
+		die(_("cannot remove a locked working tree;\nuse 'remove -f -f' to override or unlock first"));
 	}
 	if (validate_worktree(wt, &errmsg, WT_VALIDATE_WORKTREE_MISSING_OK))
 		die(_("validation failed, cannot remove working tree: %s"),
@@ -872,7 +949,8 @@ static int remove_worktree(int ac, const
 	 * continue on even if ret is non-zero, there's no going back
 	 * from here.
 	 */
-	ret |= delete_git_dir(wt);
+	ret |= delete_git_dir(wt->id);
+	delete_worktrees_dir_if_empty();
 
 	free_worktrees(worktrees);
 	return ret;
diff -pruN 1.2.1+git2.18.0-1/git/builtin/write-tree.c 1.2.3+git2.25.1-1/git/builtin/write-tree.c
--- 1.2.1+git2.18.0-1/git/builtin/write-tree.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/builtin/write-tree.c	2020-02-17 04:47:35.000000000 +0000
@@ -3,6 +3,7 @@
  *
  * Copyright (C) Linus Torvalds, 2005
  */
+#define USE_THE_INDEX_COMPATIBILITY_MACROS
 #include "builtin.h"
 #include "cache.h"
 #include "config.h"
@@ -15,18 +16,17 @@ static const char * const write_tree_usa
 	NULL
 };
 
-int cmd_write_tree(int argc, const char **argv, const char *unused_prefix)
+int cmd_write_tree(int argc, const char **argv, const char *cmd_prefix)
 {
 	int flags = 0, ret;
-	const char *prefix = NULL;
+	const char *tree_prefix = NULL;
 	struct object_id oid;
 	const char *me = "git-write-tree";
 	struct option write_tree_options[] = {
 		OPT_BIT(0, "missing-ok", &flags, N_("allow missing objects"),
 			WRITE_TREE_MISSING_OK),
-		{ OPTION_STRING, 0, "prefix", &prefix, N_("<prefix>/"),
-		  N_("write tree object for a subdirectory <prefix>") ,
-		  PARSE_OPT_LITERAL_ARGHELP },
+		OPT_STRING(0, "prefix", &tree_prefix, N_("<prefix>/"),
+			   N_("write tree object for a subdirectory <prefix>")),
 		{ OPTION_BIT, 0, "ignore-cache-tree", &flags, NULL,
 		  N_("only useful for debugging"),
 		  PARSE_OPT_HIDDEN | PARSE_OPT_NOARG, NULL,
@@ -35,10 +35,10 @@ int cmd_write_tree(int argc, const char
 	};
 
 	git_config(git_default_config, NULL);
-	argc = parse_options(argc, argv, unused_prefix, write_tree_options,
+	argc = parse_options(argc, argv, cmd_prefix, write_tree_options,
 			     write_tree_usage, 0);
 
-	ret = write_cache_as_tree(&oid, flags, prefix);
+	ret = write_cache_as_tree(&oid, flags, tree_prefix);
 	switch (ret) {
 	case 0:
 		printf("%s\n", oid_to_hex(&oid));
@@ -50,7 +50,7 @@ int cmd_write_tree(int argc, const char
 		die("%s: error building trees", me);
 		break;
 	case WRITE_TREE_PREFIX_ERROR:
-		die("%s: prefix %s not found", me, prefix);
+		die("%s: prefix %s not found", me, tree_prefix);
 		break;
 	}
 	return ret;
diff -pruN 1.2.1+git2.18.0-1/git/builtin.h 1.2.3+git2.25.1-1/git/builtin.h
--- 1.2.1+git2.18.0-1/git/builtin.h	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/builtin.h	2020-02-17 04:47:35.000000000 +0000
@@ -102,7 +102,7 @@ extern const char git_more_info_string[]
 #define PRUNE_PACKED_DRY_RUN 01
 #define PRUNE_PACKED_VERBOSE 02
 
-extern void prune_packed_objects(int);
+void prune_packed_objects(int);
 
 struct fmt_merge_msg_opts {
 	unsigned add_title:1,
@@ -110,8 +110,8 @@ struct fmt_merge_msg_opts {
 	int shortlog_len;
 };
 
-extern int fmt_merge_msg(struct strbuf *in, struct strbuf *out,
-			 struct fmt_merge_msg_opts *);
+int fmt_merge_msg(struct strbuf *in, struct strbuf *out,
+		  struct fmt_merge_msg_opts *);
 
 /**
  * If a built-in has DELAY_PAGER_CONFIG set, the built-in should call this early
@@ -123,127 +123,135 @@ extern int fmt_merge_msg(struct strbuf *
  * You should most likely use a default of 0 or 1. "Punt" (-1) could be useful
  * to be able to fall back to some historical compatibility name.
  */
-extern void setup_auto_pager(const char *cmd, int def);
+void setup_auto_pager(const char *cmd, int def);
 
-extern int is_builtin(const char *s);
+int is_builtin(const char *s);
 
-extern int cmd_add(int argc, const char **argv, const char *prefix);
-extern int cmd_am(int argc, const char **argv, const char *prefix);
-extern int cmd_annotate(int argc, const char **argv, const char *prefix);
-extern int cmd_apply(int argc, const char **argv, const char *prefix);
-extern int cmd_archive(int argc, const char **argv, const char *prefix);
-extern int cmd_bisect__helper(int argc, const char **argv, const char *prefix);
-extern int cmd_blame(int argc, const char **argv, const char *prefix);
-extern int cmd_branch(int argc, const char **argv, const char *prefix);
-extern int cmd_bundle(int argc, const char **argv, const char *prefix);
-extern int cmd_cat_file(int argc, const char **argv, const char *prefix);
-extern int cmd_checkout(int argc, const char **argv, const char *prefix);
-extern int cmd_checkout_index(int argc, const char **argv, const char *prefix);
-extern int cmd_check_attr(int argc, const char **argv, const char *prefix);
-extern int cmd_check_ignore(int argc, const char **argv, const char *prefix);
-extern int cmd_check_mailmap(int argc, const char **argv, const char *prefix);
-extern int cmd_check_ref_format(int argc, const char **argv, const char *prefix);
-extern int cmd_cherry(int argc, const char **argv, const char *prefix);
-extern int cmd_cherry_pick(int argc, const char **argv, const char *prefix);
-extern int cmd_clone(int argc, const char **argv, const char *prefix);
-extern int cmd_clean(int argc, const char **argv, const char *prefix);
-extern int cmd_column(int argc, const char **argv, const char *prefix);
-extern int cmd_commit(int argc, const char **argv, const char *prefix);
-extern int cmd_commit_graph(int argc, const char **argv, const char *prefix);
-extern int cmd_commit_tree(int argc, const char **argv, const char *prefix);
-extern int cmd_config(int argc, const char **argv, const char *prefix);
-extern int cmd_count_objects(int argc, const char **argv, const char *prefix);
-extern int cmd_credential(int argc, const char **argv, const char *prefix);
-extern int cmd_describe(int argc, const char **argv, const char *prefix);
-extern int cmd_diff_files(int argc, const char **argv, const char *prefix);
-extern int cmd_diff_index(int argc, const char **argv, const char *prefix);
-extern int cmd_diff(int argc, const char **argv, const char *prefix);
-extern int cmd_diff_tree(int argc, const char **argv, const char *prefix);
-extern int cmd_difftool(int argc, const char **argv, const char *prefix);
-extern int cmd_fast_export(int argc, const char **argv, const char *prefix);
-extern int cmd_fetch(int argc, const char **argv, const char *prefix);
-extern int cmd_fetch_pack(int argc, const char **argv, const char *prefix);
-extern int cmd_fmt_merge_msg(int argc, const char **argv, const char *prefix);
-extern int cmd_for_each_ref(int argc, const char **argv, const char *prefix);
-extern int cmd_format_patch(int argc, const char **argv, const char *prefix);
-extern int cmd_fsck(int argc, const char **argv, const char *prefix);
-extern int cmd_gc(int argc, const char **argv, const char *prefix);
-extern int cmd_get_tar_commit_id(int argc, const char **argv, const char *prefix);
-extern int cmd_grep(int argc, const char **argv, const char *prefix);
-extern int cmd_hash_object(int argc, const char **argv, const char *prefix);
-extern int cmd_help(int argc, const char **argv, const char *prefix);
-extern int cmd_index_pack(int argc, const char **argv, const char *prefix);
-extern int cmd_init_db(int argc, const char **argv, const char *prefix);
-extern int cmd_interpret_trailers(int argc, const char **argv, const char *prefix);
-extern int cmd_log(int argc, const char **argv, const char *prefix);
-extern int cmd_log_reflog(int argc, const char **argv, const char *prefix);
-extern int cmd_ls_files(int argc, const char **argv, const char *prefix);
-extern int cmd_ls_tree(int argc, const char **argv, const char *prefix);
-extern int cmd_ls_remote(int argc, const char **argv, const char *prefix);
-extern int cmd_mailinfo(int argc, const char **argv, const char *prefix);
-extern int cmd_mailsplit(int argc, const char **argv, const char *prefix);
-extern int cmd_merge(int argc, const char **argv, const char *prefix);
-extern int cmd_merge_base(int argc, const char **argv, const char *prefix);
-extern int cmd_merge_index(int argc, const char **argv, const char *prefix);
-extern int cmd_merge_ours(int argc, const char **argv, const char *prefix);
-extern int cmd_merge_file(int argc, const char **argv, const char *prefix);
-extern int cmd_merge_recursive(int argc, const char **argv, const char *prefix);
-extern int cmd_merge_tree(int argc, const char **argv, const char *prefix);
-extern int cmd_mktag(int argc, const char **argv, const char *prefix);
-extern int cmd_mktree(int argc, const char **argv, const char *prefix);
-extern int cmd_mv(int argc, const char **argv, const char *prefix);
-extern int cmd_name_rev(int argc, const char **argv, const char *prefix);
-extern int cmd_notes(int argc, const char **argv, const char *prefix);
-extern int cmd_pack_objects(int argc, const char **argv, const char *prefix);
-extern int cmd_pack_redundant(int argc, const char **argv, const char *prefix);
-extern int cmd_patch_id(int argc, const char **argv, const char *prefix);
-extern int cmd_prune(int argc, const char **argv, const char *prefix);
-extern int cmd_prune_packed(int argc, const char **argv, const char *prefix);
-extern int cmd_pull(int argc, const char **argv, const char *prefix);
-extern int cmd_push(int argc, const char **argv, const char *prefix);
-extern int cmd_read_tree(int argc, const char **argv, const char *prefix);
-extern int cmd_rebase__helper(int argc, const char **argv, const char *prefix);
-extern int cmd_receive_pack(int argc, const char **argv, const char *prefix);
-extern int cmd_reflog(int argc, const char **argv, const char *prefix);
-extern int cmd_remote(int argc, const char **argv, const char *prefix);
-extern int cmd_remote_ext(int argc, const char **argv, const char *prefix);
-extern int cmd_remote_fd(int argc, const char **argv, const char *prefix);
-extern int cmd_repack(int argc, const char **argv, const char *prefix);
-extern int cmd_rerere(int argc, const char **argv, const char *prefix);
-extern int cmd_reset(int argc, const char **argv, const char *prefix);
-extern int cmd_rev_list(int argc, const char **argv, const char *prefix);
-extern int cmd_rev_parse(int argc, const char **argv, const char *prefix);
-extern int cmd_revert(int argc, const char **argv, const char *prefix);
-extern int cmd_rm(int argc, const char **argv, const char *prefix);
-extern int cmd_send_pack(int argc, const char **argv, const char *prefix);
-extern int cmd_serve(int argc, const char **argv, const char *prefix);
-extern int cmd_shortlog(int argc, const char **argv, const char *prefix);
-extern int cmd_show(int argc, const char **argv, const char *prefix);
-extern int cmd_show_branch(int argc, const char **argv, const char *prefix);
-extern int cmd_status(int argc, const char **argv, const char *prefix);
-extern int cmd_stripspace(int argc, const char **argv, const char *prefix);
-extern int cmd_submodule__helper(int argc, const char **argv, const char *prefix);
-extern int cmd_symbolic_ref(int argc, const char **argv, const char *prefix);
-extern int cmd_tag(int argc, const char **argv, const char *prefix);
-extern int cmd_tar_tree(int argc, const char **argv, const char *prefix);
-extern int cmd_unpack_file(int argc, const char **argv, const char *prefix);
-extern int cmd_unpack_objects(int argc, const char **argv, const char *prefix);
-extern int cmd_update_index(int argc, const char **argv, const char *prefix);
-extern int cmd_update_ref(int argc, const char **argv, const char *prefix);
-extern int cmd_update_server_info(int argc, const char **argv, const char *prefix);
-extern int cmd_upload_archive(int argc, const char **argv, const char *prefix);
-extern int cmd_upload_archive_writer(int argc, const char **argv, const char *prefix);
-extern int cmd_upload_pack(int argc, const char **argv, const char *prefix);
-extern int cmd_var(int argc, const char **argv, const char *prefix);
-extern int cmd_verify_commit(int argc, const char **argv, const char *prefix);
-extern int cmd_verify_tag(int argc, const char **argv, const char *prefix);
-extern int cmd_version(int argc, const char **argv, const char *prefix);
-extern int cmd_whatchanged(int argc, const char **argv, const char *prefix);
-extern int cmd_worktree(int argc, const char **argv, const char *prefix);
-extern int cmd_write_tree(int argc, const char **argv, const char *prefix);
-extern int cmd_verify_pack(int argc, const char **argv, const char *prefix);
-extern int cmd_show_ref(int argc, const char **argv, const char *prefix);
-extern int cmd_pack_refs(int argc, const char **argv, const char *prefix);
-extern int cmd_replace(int argc, const char **argv, const char *prefix);
+int cmd_add(int argc, const char **argv, const char *prefix);
+int cmd_am(int argc, const char **argv, const char *prefix);
+int cmd_annotate(int argc, const char **argv, const char *prefix);
+int cmd_apply(int argc, const char **argv, const char *prefix);
+int cmd_archive(int argc, const char **argv, const char *prefix);
+int cmd_bisect__helper(int argc, const char **argv, const char *prefix);
+int cmd_blame(int argc, const char **argv, const char *prefix);
+int cmd_branch(int argc, const char **argv, const char *prefix);
+int cmd_bundle(int argc, const char **argv, const char *prefix);
+int cmd_cat_file(int argc, const char **argv, const char *prefix);
+int cmd_checkout(int argc, const char **argv, const char *prefix);
+int cmd_checkout_index(int argc, const char **argv, const char *prefix);
+int cmd_check_attr(int argc, const char **argv, const char *prefix);
+int cmd_check_ignore(int argc, const char **argv, const char *prefix);
+int cmd_check_mailmap(int argc, const char **argv, const char *prefix);
+int cmd_check_ref_format(int argc, const char **argv, const char *prefix);
+int cmd_cherry(int argc, const char **argv, const char *prefix);
+int cmd_cherry_pick(int argc, const char **argv, const char *prefix);
+int cmd_clone(int argc, const char **argv, const char *prefix);
+int cmd_clean(int argc, const char **argv, const char *prefix);
+int cmd_column(int argc, const char **argv, const char *prefix);
+int cmd_commit(int argc, const char **argv, const char *prefix);
+int cmd_commit_graph(int argc, const char **argv, const char *prefix);
+int cmd_commit_tree(int argc, const char **argv, const char *prefix);
+int cmd_config(int argc, const char **argv, const char *prefix);
+int cmd_count_objects(int argc, const char **argv, const char *prefix);
+int cmd_credential(int argc, const char **argv, const char *prefix);
+int cmd_describe(int argc, const char **argv, const char *prefix);
+int cmd_diff_files(int argc, const char **argv, const char *prefix);
+int cmd_diff_index(int argc, const char **argv, const char *prefix);
+int cmd_diff(int argc, const char **argv, const char *prefix);
+int cmd_diff_tree(int argc, const char **argv, const char *prefix);
+int cmd_difftool(int argc, const char **argv, const char *prefix);
+int cmd_env__helper(int argc, const char **argv, const char *prefix);
+int cmd_fast_export(int argc, const char **argv, const char *prefix);
+int cmd_fetch(int argc, const char **argv, const char *prefix);
+int cmd_fetch_pack(int argc, const char **argv, const char *prefix);
+int cmd_fmt_merge_msg(int argc, const char **argv, const char *prefix);
+int cmd_for_each_ref(int argc, const char **argv, const char *prefix);
+int cmd_format_patch(int argc, const char **argv, const char *prefix);
+int cmd_fsck(int argc, const char **argv, const char *prefix);
+int cmd_gc(int argc, const char **argv, const char *prefix);
+int cmd_get_tar_commit_id(int argc, const char **argv, const char *prefix);
+int cmd_grep(int argc, const char **argv, const char *prefix);
+int cmd_hash_object(int argc, const char **argv, const char *prefix);
+int cmd_help(int argc, const char **argv, const char *prefix);
+int cmd_index_pack(int argc, const char **argv, const char *prefix);
+int cmd_init_db(int argc, const char **argv, const char *prefix);
+int cmd_interpret_trailers(int argc, const char **argv, const char *prefix);
+int cmd_log(int argc, const char **argv, const char *prefix);
+int cmd_log_reflog(int argc, const char **argv, const char *prefix);
+int cmd_ls_files(int argc, const char **argv, const char *prefix);
+int cmd_ls_tree(int argc, const char **argv, const char *prefix);
+int cmd_ls_remote(int argc, const char **argv, const char *prefix);
+int cmd_mailinfo(int argc, const char **argv, const char *prefix);
+int cmd_mailsplit(int argc, const char **argv, const char *prefix);
+int cmd_merge(int argc, const char **argv, const char *prefix);
+int cmd_merge_base(int argc, const char **argv, const char *prefix);
+int cmd_merge_index(int argc, const char **argv, const char *prefix);
+int cmd_merge_ours(int argc, const char **argv, const char *prefix);
+int cmd_merge_file(int argc, const char **argv, const char *prefix);
+int cmd_merge_recursive(int argc, const char **argv, const char *prefix);
+int cmd_merge_tree(int argc, const char **argv, const char *prefix);
+int cmd_mktag(int argc, const char **argv, const char *prefix);
+int cmd_mktree(int argc, const char **argv, const char *prefix);
+int cmd_multi_pack_index(int argc, const char **argv, const char *prefix);
+int cmd_mv(int argc, const char **argv, const char *prefix);
+int cmd_name_rev(int argc, const char **argv, const char *prefix);
+int cmd_notes(int argc, const char **argv, const char *prefix);
+int cmd_pack_objects(int argc, const char **argv, const char *prefix);
+int cmd_pack_redundant(int argc, const char **argv, const char *prefix);
+int cmd_patch_id(int argc, const char **argv, const char *prefix);
+int cmd_prune(int argc, const char **argv, const char *prefix);
+int cmd_prune_packed(int argc, const char **argv, const char *prefix);
+int cmd_pull(int argc, const char **argv, const char *prefix);
+int cmd_push(int argc, const char **argv, const char *prefix);
+int cmd_range_diff(int argc, const char **argv, const char *prefix);
+int cmd_read_tree(int argc, const char **argv, const char *prefix);
+int cmd_rebase(int argc, const char **argv, const char *prefix);
+int cmd_rebase__interactive(int argc, const char **argv, const char *prefix);
+int cmd_receive_pack(int argc, const char **argv, const char *prefix);
+int cmd_reflog(int argc, const char **argv, const char *prefix);
+int cmd_remote(int argc, const char **argv, const char *prefix);
+int cmd_remote_ext(int argc, const char **argv, const char *prefix);
+int cmd_remote_fd(int argc, const char **argv, const char *prefix);
+int cmd_repack(int argc, const char **argv, const char *prefix);
+int cmd_rerere(int argc, const char **argv, const char *prefix);
+int cmd_reset(int argc, const char **argv, const char *prefix);
+int cmd_restore(int argc, const char **argv, const char *prefix);
+int cmd_rev_list(int argc, const char **argv, const char *prefix);
+int cmd_rev_parse(int argc, const char **argv, const char *prefix);
+int cmd_revert(int argc, const char **argv, const char *prefix);
+int cmd_rm(int argc, const char **argv, const char *prefix);
+int cmd_send_pack(int argc, const char **argv, const char *prefix);
+int cmd_shortlog(int argc, const char **argv, const char *prefix);
+int cmd_show(int argc, const char **argv, const char *prefix);
+int cmd_show_branch(int argc, const char **argv, const char *prefix);
+int cmd_show_index(int argc, const char **argv, const char *prefix);
+int cmd_sparse_checkout(int argc, const char **argv, const char *prefix);
+int cmd_status(int argc, const char **argv, const char *prefix);
+int cmd_stash(int argc, const char **argv, const char *prefix);
+int cmd_stripspace(int argc, const char **argv, const char *prefix);
+int cmd_submodule__helper(int argc, const char **argv, const char *prefix);
+int cmd_switch(int argc, const char **argv, const char *prefix);
+int cmd_symbolic_ref(int argc, const char **argv, const char *prefix);
+int cmd_tag(int argc, const char **argv, const char *prefix);
+int cmd_tar_tree(int argc, const char **argv, const char *prefix);
+int cmd_unpack_file(int argc, const char **argv, const char *prefix);
+int cmd_unpack_objects(int argc, const char **argv, const char *prefix);
+int cmd_update_index(int argc, const char **argv, const char *prefix);
+int cmd_update_ref(int argc, const char **argv, const char *prefix);
+int cmd_update_server_info(int argc, const char **argv, const char *prefix);
+int cmd_upload_archive(int argc, const char **argv, const char *prefix);
+int cmd_upload_archive_writer(int argc, const char **argv, const char *prefix);
+int cmd_upload_pack(int argc, const char **argv, const char *prefix);
+int cmd_var(int argc, const char **argv, const char *prefix);
+int cmd_verify_commit(int argc, const char **argv, const char *prefix);
+int cmd_verify_tag(int argc, const char **argv, const char *prefix);
+int cmd_version(int argc, const char **argv, const char *prefix);
+int cmd_whatchanged(int argc, const char **argv, const char *prefix);
+int cmd_worktree(int argc, const char **argv, const char *prefix);
+int cmd_write_tree(int argc, const char **argv, const char *prefix);
+int cmd_verify_pack(int argc, const char **argv, const char *prefix);
+int cmd_show_ref(int argc, const char **argv, const char *prefix);
+int cmd_pack_refs(int argc, const char **argv, const char *prefix);
+int cmd_replace(int argc, const char **argv, const char *prefix);
 
 #endif
diff -pruN 1.2.1+git2.18.0-1/git/bulk-checkin.c 1.2.3+git2.25.1-1/git/bulk-checkin.c
--- 1.2.1+git2.18.0-1/git/bulk-checkin.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/bulk-checkin.c	2020-02-17 04:47:35.000000000 +0000
@@ -8,6 +8,7 @@
 #include "pack.h"
 #include "strbuf.h"
 #include "packfile.h"
+#include "object-store.h"
 
 static struct bulk_checkin_state {
 	unsigned plugged:1;
@@ -66,12 +67,12 @@ static int already_written(struct bulk_c
 	int i;
 
 	/* The object may already exist in the repository */
-	if (has_sha1_file(oid->hash))
+	if (has_object_file(oid))
 		return 1;
 
 	/* Might want to keep the list sorted */
 	for (i = 0; i < state->nr_written; i++)
-		if (!oidcmp(&state->written[i]->oid, oid))
+		if (oideq(&state->written[i]->oid, oid))
 			return 1;
 
 	/* This is a new object we need to keep */
@@ -196,7 +197,7 @@ static int deflate_to_pack(struct bulk_c
 	git_hash_ctx ctx;
 	unsigned char obuf[16384];
 	unsigned header_len;
-	struct hashfile_checkpoint checkpoint;
+	struct hashfile_checkpoint checkpoint = {0};
 	struct pack_idx_entry *idx = NULL;
 
 	seekback = lseek(fd, 0, SEEK_CUR);
diff -pruN 1.2.1+git2.18.0-1/git/bulk-checkin.h 1.2.3+git2.25.1-1/git/bulk-checkin.h
--- 1.2.1+git2.18.0-1/git/bulk-checkin.h	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/bulk-checkin.h	2020-02-17 04:47:35.000000000 +0000
@@ -4,11 +4,13 @@
 #ifndef BULK_CHECKIN_H
 #define BULK_CHECKIN_H
 
-extern int index_bulk_checkin(struct object_id *oid,
-			      int fd, size_t size, enum object_type type,
-			      const char *path, unsigned flags);
+#include "cache.h"
 
-extern void plug_bulk_checkin(void);
-extern void unplug_bulk_checkin(void);
+int index_bulk_checkin(struct object_id *oid,
+		       int fd, size_t size, enum object_type type,
+		       const char *path, unsigned flags);
+
+void plug_bulk_checkin(void);
+void unplug_bulk_checkin(void);
 
 #endif
diff -pruN 1.2.1+git2.18.0-1/git/bundle.c 1.2.3+git2.25.1-1/git/bundle.c
--- 1.2.1+git2.18.0-1/git/bundle.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/bundle.c	2020-02-17 04:47:35.000000000 +0000
@@ -1,6 +1,8 @@
 #include "cache.h"
 #include "lockfile.h"
 #include "bundle.h"
+#include "object-store.h"
+#include "repository.h"
 #include "object.h"
 #include "commit.h"
 #include "diff.h"
@@ -125,7 +127,9 @@ static int list_refs(struct ref_list *r,
 /* Remember to update object flag allocation in object.h */
 #define PREREQ_MARK (1u<<16)
 
-int verify_bundle(struct bundle_header *header, int verbose)
+int verify_bundle(struct repository *r,
+		  struct bundle_header *header,
+		  int verbose)
 {
 	/*
 	 * Do fast check, then if any prereqs are missing then go line by line
@@ -138,10 +142,13 @@ int verify_bundle(struct bundle_header *
 	int i, ret = 0, req_nr;
 	const char *message = _("Repository lacks these prerequisite commits:");
 
-	init_revisions(&revs, NULL);
+	if (!r || !r->objects || !r->objects->odb)
+		return error(_("need a repository to verify a bundle"));
+
+	repo_init_revisions(r, &revs, NULL);
 	for (i = 0; i < p->nr; i++) {
 		struct ref_list_entry *e = p->list + i;
-		struct object *o = parse_object(&e->oid);
+		struct object *o = parse_object(r, &e->oid);
 		if (o) {
 			o->flags |= PREREQ_MARK;
 			add_pending_object(&revs, o, e->name);
@@ -166,7 +173,7 @@ int verify_bundle(struct bundle_header *
 
 	for (i = 0; i < p->nr; i++) {
 		struct ref_list_entry *e = p->list + i;
-		struct object *o = parse_object(&e->oid);
+		struct object *o = parse_object(r, &e->oid);
 		assert(o); /* otherwise we'd have returned early */
 		if (o->flags & SHOWN)
 			continue;
@@ -178,7 +185,7 @@ int verify_bundle(struct bundle_header *
 	/* Clean up objects used, as they will be reused. */
 	for (i = 0; i < p->nr; i++) {
 		struct ref_list_entry *e = p->list + i;
-		commit = lookup_commit_reference_gently(&e->oid, 1);
+		commit = lookup_commit_reference_gently(r, &e->oid, 1);
 		if (commit)
 			clear_commit_marks(commit, ALL_REV_FLAGS);
 	}
@@ -241,19 +248,34 @@ out:
 }
 
 
-/* Write the pack data to bundle_fd, then close it if it is > 1. */
-static int write_pack_data(int bundle_fd, struct rev_info *revs)
+/* Write the pack data to bundle_fd */
+static int write_pack_data(int bundle_fd, struct rev_info *revs, struct argv_array *pack_options)
 {
 	struct child_process pack_objects = CHILD_PROCESS_INIT;
 	int i;
 
 	argv_array_pushl(&pack_objects.args,
-			 "pack-objects", "--all-progress-implied",
+			 "pack-objects",
 			 "--stdout", "--thin", "--delta-base-offset",
 			 NULL);
+	argv_array_pushv(&pack_objects.args, pack_options->argv);
 	pack_objects.in = -1;
 	pack_objects.out = bundle_fd;
 	pack_objects.git_cmd = 1;
+
+	/*
+	 * start_command() will close our descriptor if it's >1. Duplicate it
+	 * to avoid surprising the caller.
+	 */
+	if (pack_objects.out > 1) {
+		pack_objects.out = dup(pack_objects.out);
+		if (pack_objects.out < 0) {
+			error_errno(_("unable to dup bundle descriptor"));
+			child_process_clear(&pack_objects);
+			return -1;
+		}
+	}
+
 	if (start_command(&pack_objects))
 		return error(_("Could not spawn pack-objects"));
 
@@ -261,7 +283,7 @@ static int write_pack_data(int bundle_fd
 		struct object *object = revs->pending.objects[i].item;
 		if (object->flags & UNINTERESTING)
 			write_or_die(pack_objects.in, "^", 1);
-		write_or_die(pack_objects.in, oid_to_hex(&object->oid), GIT_SHA1_HEXSZ);
+		write_or_die(pack_objects.in, oid_to_hex(&object->oid), the_hash_algo->hexsz);
 		write_or_die(pack_objects.in, "\n", 1);
 	}
 	close(pack_objects.in);
@@ -367,13 +389,13 @@ static int write_bundle_refs(int bundle_
 		 * commit that is referenced by the tag, and not the tag
 		 * itself.
 		 */
-		if (oidcmp(&oid, &e->item->oid)) {
+		if (!oideq(&oid, &e->item->oid)) {
 			/*
 			 * Is this the positive end of a range expressed
 			 * in terms of a tag (e.g. v2.0 from the range
 			 * "v1.0..v2.0")?
 			 */
-			struct commit *one = lookup_commit_reference(&oid);
+			struct commit *one = lookup_commit_reference(revs->repo, &oid);
 			struct object *obj;
 
 			if (e->item == &(one->object)) {
@@ -393,7 +415,7 @@ static int write_bundle_refs(int bundle_
 		}
 
 		ref_count++;
-		write_or_die(bundle_fd, oid_to_hex(&e->item->oid), 40);
+		write_or_die(bundle_fd, oid_to_hex(&e->item->oid), the_hash_algo->hexsz);
 		write_or_die(bundle_fd, " ", 1);
 		write_or_die(bundle_fd, display_ref, strlen(display_ref));
 		write_or_die(bundle_fd, "\n", 1);
@@ -406,8 +428,8 @@ static int write_bundle_refs(int bundle_
 	return ref_count;
 }
 
-int create_bundle(struct bundle_header *header, const char *path,
-		  int argc, const char **argv)
+int create_bundle(struct repository *r, const char *path,
+		  int argc, const char **argv, struct argv_array *pack_options)
 {
 	struct lock_file lock = LOCK_INIT;
 	int bundle_fd = -1;
@@ -418,27 +440,16 @@ int create_bundle(struct bundle_header *
 	bundle_to_stdout = !strcmp(path, "-");
 	if (bundle_to_stdout)
 		bundle_fd = 1;
-	else {
+	else
 		bundle_fd = hold_lock_file_for_update(&lock, path,
 						      LOCK_DIE_ON_ERROR);
 
-		/*
-		 * write_pack_data() will close the fd passed to it,
-		 * but commit_lock_file() will also try to close the
-		 * lockfile's fd. So make a copy of the file
-		 * descriptor to avoid trying to close it twice.
-		 */
-		bundle_fd = dup(bundle_fd);
-		if (bundle_fd < 0)
-			die_errno("unable to dup file descriptor");
-	}
-
 	/* write signature */
 	write_or_die(bundle_fd, bundle_signature, strlen(bundle_signature));
 
 	/* init revs to list objects for pack-objects later */
 	save_commit_buffer = 0;
-	init_revisions(&revs, NULL);
+	repo_init_revisions(r, &revs, NULL);
 
 	/* write prerequisites */
 	if (compute_and_write_prerequisites(bundle_fd, &revs, argc, argv))
@@ -460,10 +471,8 @@ int create_bundle(struct bundle_header *
 		goto err;
 
 	/* write pack */
-	if (write_pack_data(bundle_fd, &revs)) {
-		bundle_fd = -1; /* already closed by the above call */
+	if (write_pack_data(bundle_fd, &revs, pack_options))
 		goto err;
-	}
 
 	if (!bundle_to_stdout) {
 		if (commit_lock_file(&lock))
@@ -471,15 +480,12 @@ int create_bundle(struct bundle_header *
 	}
 	return 0;
 err:
-	if (!bundle_to_stdout) {
-		if (0 <= bundle_fd)
-			close(bundle_fd);
-		rollback_lock_file(&lock);
-	}
+	rollback_lock_file(&lock);
 	return -1;
 }
 
-int unbundle(struct bundle_header *header, int bundle_fd, int flags)
+int unbundle(struct repository *r, struct bundle_header *header,
+	     int bundle_fd, int flags)
 {
 	const char *argv_index_pack[] = {"index-pack",
 					 "--fix-thin", "--stdin", NULL, NULL};
@@ -488,7 +494,7 @@ int unbundle(struct bundle_header *heade
 	if (flags & BUNDLE_VERBOSE)
 		argv_index_pack[3] = "-v";
 
-	if (verify_bundle(header, 0))
+	if (verify_bundle(r, header, 0))
 		return -1;
 	ip.argv = argv_index_pack;
 	ip.in = bundle_fd;
diff -pruN 1.2.1+git2.18.0-1/git/bundle.h 1.2.3+git2.25.1-1/git/bundle.h
--- 1.2.1+git2.18.0-1/git/bundle.h	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/bundle.h	2020-02-17 04:47:35.000000000 +0000
@@ -1,6 +1,7 @@
 #ifndef BUNDLE_H
 #define BUNDLE_H
 
+#include "argv-array.h"
 #include "cache.h"
 
 struct ref_list {
@@ -18,11 +19,12 @@ struct bundle_header {
 
 int is_bundle(const char *path, int quiet);
 int read_bundle_header(const char *path, struct bundle_header *header);
-int create_bundle(struct bundle_header *header, const char *path,
-		int argc, const char **argv);
-int verify_bundle(struct bundle_header *header, int verbose);
+int create_bundle(struct repository *r, const char *path,
+		  int argc, const char **argv, struct argv_array *pack_options);
+int verify_bundle(struct repository *r, struct bundle_header *header, int verbose);
 #define BUNDLE_VERBOSE 1
-int unbundle(struct bundle_header *header, int bundle_fd, int flags);
+int unbundle(struct repository *r, struct bundle_header *header,
+	     int bundle_fd, int flags);
 int list_bundle_refs(struct bundle_header *header,
 		int argc, const char **argv);
 
diff -pruN 1.2.1+git2.18.0-1/git/cache.h 1.2.3+git2.25.1-1/git/cache.h
--- 1.2.1+git2.18.0-1/git/cache.h	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/cache.h	2020-02-17 04:47:35.000000000 +0000
@@ -9,12 +9,14 @@
 #include "gettext.h"
 #include "convert.h"
 #include "trace.h"
+#include "trace2.h"
 #include "string-list.h"
 #include "pack-revindex.h"
 #include "hash.h"
 #include "path.h"
 #include "sha1-array.h"
 #include "repository.h"
+#include "mem-pool.h"
 
 #include <zlib.h>
 typedef struct git_zstream {
@@ -41,20 +43,6 @@ int git_deflate_end_gently(git_zstream *
 int git_deflate(git_zstream *, int flush);
 unsigned long git_deflate_bound(git_zstream *, unsigned long);
 
-/* The length in bytes and in hex digits of an object name (SHA-1 value). */
-#define GIT_SHA1_RAWSZ 20
-#define GIT_SHA1_HEXSZ (2 * GIT_SHA1_RAWSZ)
-
-/* The length in byte and in hex digits of the largest possible hash value. */
-#define GIT_MAX_RAWSZ GIT_SHA1_RAWSZ
-#define GIT_MAX_HEXSZ GIT_SHA1_HEXSZ
-
-struct object_id {
-	unsigned char hash[GIT_MAX_RAWSZ];
-};
-
-#define the_hash_algo the_repository->hash_algo
-
 #if defined(DT_UNKNOWN) && !defined(NO_D_TYPE_IN_DIRENT)
 #define DTYPE(de)	((de)->d_type)
 #else
@@ -156,6 +144,7 @@ struct cache_entry {
 	struct stat_data ce_stat_data;
 	unsigned int ce_mode;
 	unsigned int ce_flags;
+	unsigned int mem_pool_allocated;
 	unsigned int ce_namelen;
 	unsigned int index;	/* for link extension */
 	struct object_id oid;
@@ -218,6 +207,7 @@ struct cache_entry {
 /* Forward structure decls */
 struct pathspec;
 struct child_process;
+struct tree;
 
 /*
  * Copy the sha1 and stat state of a cache entry from one to
@@ -227,6 +217,7 @@ static inline void copy_cache_entry(stru
 				    const struct cache_entry *src)
 {
 	unsigned int state = dst->ce_flags & CE_HASHED;
+	int mem_pool_allocated = dst->mem_pool_allocated;
 
 	/* Don't copy hash chain and name */
 	memcpy(&dst->ce_stat_data, &src->ce_stat_data,
@@ -235,6 +226,9 @@ static inline void copy_cache_entry(stru
 
 	/* Restore the hash state */
 	dst->ce_flags = (dst->ce_flags & ~CE_HASHED) | state;
+
+	/* Restore the mem_pool_allocated flag */
+	dst->mem_pool_allocated = mem_pool_allocated;
 }
 
 static inline unsigned create_ce_flags(unsigned stage)
@@ -310,6 +304,7 @@ static inline unsigned int canon_mode(un
 
 struct split_index;
 struct untracked_cache;
+struct progress;
 
 struct index_state {
 	struct cache_entry **cache;
@@ -321,36 +316,95 @@ struct index_state {
 	struct cache_time timestamp;
 	unsigned name_hash_initialized : 1,
 		 initialized : 1,
-		 drop_cache_tree : 1;
+		 drop_cache_tree : 1,
+		 updated_workdir : 1,
+		 updated_skipworktree : 1,
+		 fsmonitor_has_run_once : 1;
 	struct hashmap name_hash;
 	struct hashmap dir_hash;
 	struct object_id oid;
 	struct untracked_cache *untracked;
 	uint64_t fsmonitor_last_update;
 	struct ewah_bitmap *fsmonitor_dirty;
+	struct mem_pool *ce_mem_pool;
+	struct progress *progress;
 };
 
-extern struct index_state the_index;
-
 /* Name hashing */
-extern int test_lazy_init_name_hash(struct index_state *istate, int try_threaded);
-extern void add_name_hash(struct index_state *istate, struct cache_entry *ce);
-extern void remove_name_hash(struct index_state *istate, struct cache_entry *ce);
-extern void free_name_hash(struct index_state *istate);
+int test_lazy_init_name_hash(struct index_state *istate, int try_threaded);
+void add_name_hash(struct index_state *istate, struct cache_entry *ce);
+void remove_name_hash(struct index_state *istate, struct cache_entry *ce);
+void free_name_hash(struct index_state *istate);
 
 
-#ifndef NO_THE_INDEX_COMPATIBILITY_MACROS
+/* Cache entry creation and cleanup */
+
+/*
+ * Create cache_entry intended for use in the specified index. Caller
+ * is responsible for discarding the cache_entry with
+ * `discard_cache_entry`.
+ */
+struct cache_entry *make_cache_entry(struct index_state *istate,
+				     unsigned int mode,
+				     const struct object_id *oid,
+				     const char *path,
+				     int stage,
+				     unsigned int refresh_options);
+
+struct cache_entry *make_empty_cache_entry(struct index_state *istate,
+					   size_t name_len);
+
+/*
+ * Create a cache_entry that is not intended to be added to an index.
+ * Caller is responsible for discarding the cache_entry
+ * with `discard_cache_entry`.
+ */
+struct cache_entry *make_transient_cache_entry(unsigned int mode,
+					       const struct object_id *oid,
+					       const char *path,
+					       int stage);
+
+struct cache_entry *make_empty_transient_cache_entry(size_t name_len);
+
+/*
+ * Discard cache entry.
+ */
+void discard_cache_entry(struct cache_entry *ce);
+
+/*
+ * Check configuration if we should perform extra validation on cache
+ * entries.
+ */
+int should_validate_cache_entries(void);
+
+/*
+ * Duplicate a cache_entry. Allocate memory for the new entry from a
+ * memory_pool. Takes into account cache_entry fields that are meant
+ * for managing the underlying memory allocation of the cache_entry.
+ */
+struct cache_entry *dup_cache_entry(const struct cache_entry *ce, struct index_state *istate);
+
+/*
+ * Validate the cache entries in the index.  This is an internal
+ * consistency check that the cache_entry structs are allocated from
+ * the expected memory pool.
+ */
+void validate_cache_entries(const struct index_state *istate);
+
+#ifdef USE_THE_INDEX_COMPATIBILITY_MACROS
+extern struct index_state the_index;
+
 #define active_cache (the_index.cache)
 #define active_nr (the_index.cache_nr)
 #define active_alloc (the_index.cache_alloc)
 #define active_cache_changed (the_index.cache_changed)
 #define active_cache_tree (the_index.cache_tree)
 
-#define read_cache() read_index(&the_index)
+#define read_cache() repo_read_index(the_repository)
 #define read_cache_from(path) read_index_from(&the_index, (path), (get_git_dir()))
-#define read_cache_preload(pathspec) read_index_preload(&the_index, (pathspec))
+#define read_cache_preload(pathspec) repo_read_index_preload(the_repository, (pathspec), 0)
 #define is_cache_unborn() is_index_unborn(&the_index)
-#define read_cache_unmerged() read_index_unmerged(&the_index)
+#define read_cache_unmerged() repo_read_index_unmerged(the_repository)
 #define discard_cache() discard_index(&the_index)
 #define unmerged_cache() unmerged_index(&the_index)
 #define cache_name_pos(name, namelen) index_name_pos(&the_index,(name),(namelen))
@@ -362,6 +416,7 @@ extern void free_name_hash(struct index_
 #define add_file_to_cache(path, flags) add_file_to_index(&the_index, (path), (flags))
 #define chmod_cache_entry(ce, flip) chmod_index_entry(&the_index, (ce), (flip))
 #define refresh_cache(flags) refresh_index(&the_index, (flags), NULL, NULL, NULL)
+#define refresh_and_write_cache(refresh_flags, write_flags, gentle) repo_refresh_and_write_index(the_repository, (refresh_flags), (write_flags), (gentle), NULL, NULL, NULL)
 #define ce_match_stat(ce, st, options) ie_match_stat(&the_index, (ce), (st), (options))
 #define ce_modified(ce, st, options) ie_modified(&the_index, (ce), (st), (options))
 #define cache_dir_exists(name, namelen) index_dir_exists(&the_index, (name), (namelen))
@@ -371,6 +426,7 @@ extern void free_name_hash(struct index_
 #define unmerge_cache_entry_at(at) unmerge_index_entry_at(&the_index, at)
 #define unmerge_cache(pathspec) unmerge_index(&the_index, pathspec)
 #define read_blob_data_from_cache(path, sz) read_blob_data_from_index(&the_index, (path), (sz))
+#define hold_locked_index(lock_file, flags) repo_hold_locked_index(the_repository, (lock_file), (flags))
 #endif
 
 #define TYPE_BITS 3
@@ -424,6 +480,8 @@ static inline enum object_type object_ty
 #define INFOATTRIBUTES_FILE "info/attributes"
 #define ATTRIBUTE_MACRO_PREFIX "[attr]"
 #define GITMODULES_FILE ".gitmodules"
+#define GITMODULES_INDEX ":.gitmodules"
+#define GITMODULES_HEAD "HEAD:.gitmodules"
 #define GIT_NOTES_REF_ENVIRONMENT "GIT_NOTES_REF"
 #define GIT_NOTES_DEFAULT_REF "refs/notes/commits"
 #define GIT_NOTES_DISPLAY_REF_ENVIRONMENT "GIT_NOTES_DISPLAY_REF"
@@ -467,7 +525,7 @@ static inline enum object_type object_ty
  */
 extern const char * const local_repo_env[];
 
-extern void setup_git_env(const char *git_dir);
+void setup_git_env(const char *git_dir);
 
 /*
  * Returns true iff we have a configured git repository (either via
@@ -476,29 +534,29 @@ extern void setup_git_env(const char *gi
 int have_git_dir(void);
 
 extern int is_bare_repository_cfg;
-extern int is_bare_repository(void);
-extern int is_inside_git_dir(void);
+int is_bare_repository(void);
+int is_inside_git_dir(void);
 extern char *git_work_tree_cfg;
-extern int is_inside_work_tree(void);
-extern const char *get_git_dir(void);
-extern const char *get_git_common_dir(void);
-extern char *get_object_directory(void);
-extern char *get_index_file(void);
-extern char *get_graft_file(void);
-extern void set_git_dir(const char *path);
-extern int get_common_dir_noenv(struct strbuf *sb, const char *gitdir);
-extern int get_common_dir(struct strbuf *sb, const char *gitdir);
-extern const char *get_git_namespace(void);
-extern const char *strip_namespace(const char *namespaced_ref);
-extern const char *get_super_prefix(void);
-extern const char *get_git_work_tree(void);
+int is_inside_work_tree(void);
+const char *get_git_dir(void);
+const char *get_git_common_dir(void);
+char *get_object_directory(void);
+char *get_index_file(void);
+char *get_graft_file(struct repository *r);
+void set_git_dir(const char *path);
+int get_common_dir_noenv(struct strbuf *sb, const char *gitdir);
+int get_common_dir(struct strbuf *sb, const char *gitdir);
+const char *get_git_namespace(void);
+const char *strip_namespace(const char *namespaced_ref);
+const char *get_super_prefix(void);
+const char *get_git_work_tree(void);
 
 /*
  * Return true if the given path is a git directory; note that this _just_
  * looks at the directory itself. If you want to know whether "foo/.git"
  * is a repository, you must feed that path, not just "foo".
  */
-extern int is_git_directory(const char *path);
+int is_git_directory(const char *path);
 
 /*
  * Return 1 if the given path is the root of a git repository or
@@ -510,7 +568,7 @@ extern int is_git_directory(const char *
  * as we usually consider sub-repos precious, and would prefer to err on the
  * side of not disrupting or deleting them.
  */
-extern int is_nonbare_repository_dir(struct strbuf *path);
+int is_nonbare_repository_dir(struct strbuf *path);
 
 #define READ_GITFILE_ERR_STAT_FAILED 1
 #define READ_GITFILE_ERR_NOT_A_FILE 2
@@ -520,17 +578,17 @@ extern int is_nonbare_repository_dir(str
 #define READ_GITFILE_ERR_NO_PATH 6
 #define READ_GITFILE_ERR_NOT_A_REPO 7
 #define READ_GITFILE_ERR_TOO_LARGE 8
-extern void read_gitfile_error_die(int error_code, const char *path, const char *dir);
-extern const char *read_gitfile_gently(const char *path, int *return_error_code);
+void read_gitfile_error_die(int error_code, const char *path, const char *dir);
+const char *read_gitfile_gently(const char *path, int *return_error_code);
 #define read_gitfile(path) read_gitfile_gently((path), NULL)
-extern const char *resolve_gitdir_gently(const char *suspect, int *return_error_code);
+const char *resolve_gitdir_gently(const char *suspect, int *return_error_code);
 #define resolve_gitdir(path) resolve_gitdir_gently((path), NULL)
 
-extern void set_git_work_tree(const char *tree);
+void set_git_work_tree(const char *tree);
 
 #define ALTERNATE_DB_ENVIRONMENT "GIT_ALTERNATE_OBJECT_DIRECTORIES"
 
-extern void setup_work_tree(void);
+void setup_work_tree(void);
 /*
  * Find the commondir and gitdir of the repository that contains the current
  * working directory, without changing the working directory or other global
@@ -539,12 +597,12 @@ extern void setup_work_tree(void);
  * both have the same result appended to the buffer.  The return value is
  * either 0 upon success and non-zero if no repository was found.
  */
-extern int discover_git_directory(struct strbuf *commondir,
-				  struct strbuf *gitdir);
-extern const char *setup_git_directory_gently(int *);
-extern const char *setup_git_directory(void);
-extern char *prefix_path(const char *prefix, int len, const char *path);
-extern char *prefix_path_gently(const char *prefix, int len, int *remaining, const char *path);
+int discover_git_directory(struct strbuf *commondir,
+			   struct strbuf *gitdir);
+const char *setup_git_directory_gently(int *);
+const char *setup_git_directory(void);
+char *prefix_path(const char *prefix, int len, const char *path);
+char *prefix_path_gently(const char *prefix, int len, int *remaining, const char *path);
 
 /*
  * Concatenate "prefix" (if len is non-zero) and "path", with no
@@ -556,30 +614,66 @@ extern char *prefix_path_gently(const ch
  * The return value is always a newly allocated string (even if the
  * prefix was empty).
  */
-extern char *prefix_filename(const char *prefix, const char *path);
+char *prefix_filename(const char *prefix, const char *path);
 
-extern int check_filename(const char *prefix, const char *name);
-extern void verify_filename(const char *prefix,
-			    const char *name,
-			    int diagnose_misspelt_rev);
-extern void verify_non_filename(const char *prefix, const char *name);
-extern int path_inside_repo(const char *prefix, const char *path);
+int check_filename(const char *prefix, const char *name);
+void verify_filename(const char *prefix,
+		     const char *name,
+		     int diagnose_misspelt_rev);
+void verify_non_filename(const char *prefix, const char *name);
+int path_inside_repo(const char *prefix, const char *path);
 
 #define INIT_DB_QUIET 0x0001
 #define INIT_DB_EXIST_OK 0x0002
 
-extern int init_db(const char *git_dir, const char *real_git_dir,
-		   const char *template_dir, unsigned int flags);
+int init_db(const char *git_dir, const char *real_git_dir,
+	    const char *template_dir, unsigned int flags);
 
-extern void sanitize_stdfds(void);
-extern int daemonize(void);
+void sanitize_stdfds(void);
+int daemonize(void);
 
 #define alloc_nr(x) (((x)+16)*3/2)
 
-/*
- * Realloc the buffer pointed at by variable 'x' so that it can hold
- * at least 'nr' entries; the number of entries currently allocated
- * is 'alloc', using the standard growing factor alloc_nr() macro.
+/**
+ * Dynamically growing an array using realloc() is error prone and boring.
+ *
+ * Define your array with:
+ *
+ * - a pointer (`item`) that points at the array, initialized to `NULL`
+ *   (although please name the variable based on its contents, not on its
+ *   type);
+ *
+ * - an integer variable (`alloc`) that keeps track of how big the current
+ *   allocation is, initialized to `0`;
+ *
+ * - another integer variable (`nr`) to keep track of how many elements the
+ *   array currently has, initialized to `0`.
+ *
+ * Then before adding `n`th element to the item, call `ALLOC_GROW(item, n,
+ * alloc)`.  This ensures that the array can hold at least `n` elements by
+ * calling `realloc(3)` and adjusting `alloc` variable.
+ *
+ * ------------
+ * sometype *item;
+ * size_t nr;
+ * size_t alloc
+ *
+ * for (i = 0; i < nr; i++)
+ * 	if (we like item[i] already)
+ * 		return;
+ *
+ * // we did not like any existing one, so add one
+ * ALLOC_GROW(item, nr + 1, alloc);
+ * item[nr++] = value you like;
+ * ------------
+ *
+ * You are responsible for updating the `nr` variable.
+ *
+ * If you need to specify the number of elements to allocate explicitly
+ * then use the macro `REALLOC_ARRAY(item, alloc)` instead of `ALLOC_GROW`.
+ *
+ * Consider using ALLOC_GROW_BY instead of ALLOC_GROW as it has some
+ * added niceties.
  *
  * DO NOT USE any expression with side-effect for 'x', 'nr', or 'alloc'.
  */
@@ -594,16 +688,35 @@ extern int daemonize(void);
 		} \
 	} while (0)
 
+/*
+ * Similar to ALLOC_GROW but handles updating of the nr value and
+ * zeroing the bytes of the newly-grown array elements.
+ *
+ * DO NOT USE any expression with side-effect for any of the
+ * arguments.
+ */
+#define ALLOC_GROW_BY(x, nr, increase, alloc) \
+	do { \
+		if (increase) { \
+			size_t new_nr = nr + (increase); \
+			if (new_nr < nr) \
+				BUG("negative growth in ALLOC_GROW_BY"); \
+			ALLOC_GROW(x, new_nr, alloc); \
+			memset((x) + nr, 0, sizeof(*(x)) * (increase)); \
+			nr = new_nr; \
+		} \
+	} while (0)
+
 /* Initialize and use the cache information */
 struct lock_file;
-extern int read_index(struct index_state *);
-extern int read_index_preload(struct index_state *, const struct pathspec *pathspec);
-extern int do_read_index(struct index_state *istate, const char *path,
-			 int must_exist); /* for testting only! */
-extern int read_index_from(struct index_state *, const char *path,
-			   const char *gitdir);
-extern int is_index_unborn(struct index_state *);
-extern int read_index_unmerged(struct index_state *);
+void preload_index(struct index_state *index,
+		   const struct pathspec *pathspec,
+		   unsigned int refresh_flags);
+int do_read_index(struct index_state *istate, const char *path,
+		  int must_exist); /* for testting only! */
+int read_index_from(struct index_state *, const char *path,
+		    const char *gitdir);
+int is_index_unborn(struct index_state *);
 
 /* For use with `write_locked_index()`. */
 #define COMMIT_LOCK		(1 << 0)
@@ -628,25 +741,28 @@ extern int read_index_unmerged(struct in
  * If `SKIP_IF_UNCHANGED` is given and the index is unchanged, nothing
  * is written (and the lock is rolled back if `COMMIT_LOCK` is given).
  */
-extern int write_locked_index(struct index_state *, struct lock_file *lock, unsigned flags);
+int write_locked_index(struct index_state *, struct lock_file *lock, unsigned flags);
 
-extern int discard_index(struct index_state *);
-extern void move_index_extensions(struct index_state *dst, struct index_state *src);
-extern int unmerged_index(const struct index_state *);
+int discard_index(struct index_state *);
+void move_index_extensions(struct index_state *dst, struct index_state *src);
+int unmerged_index(const struct index_state *);
 
 /**
- * Returns 1 if the index differs from HEAD, 0 otherwise. When on an unborn
- * branch, returns 1 if there are entries in the index, 0 otherwise. If an
- * strbuf is provided, the space-separated list of files that differ will be
- * appended to it.
- */
-extern int index_has_changes(struct strbuf *sb);
-
-extern int verify_path(const char *path, unsigned mode);
-extern int strcmp_offset(const char *s1, const char *s2, size_t *first_change);
-extern int index_dir_exists(struct index_state *istate, const char *name, int namelen);
-extern void adjust_dirname_case(struct index_state *istate, char *name);
-extern struct cache_entry *index_file_exists(struct index_state *istate, const char *name, int namelen, int igncase);
+ * Returns 1 if istate differs from tree, 0 otherwise.  If tree is NULL,
+ * compares istate to HEAD.  If tree is NULL and on an unborn branch,
+ * returns 1 if there are entries in istate, 0 otherwise.  If an strbuf is
+ * provided, the space-separated list of files that differ will be appended
+ * to it.
+ */
+int repo_index_has_changes(struct repository *repo,
+			   struct tree *tree,
+			   struct strbuf *sb);
+
+int verify_path(const char *path, unsigned mode);
+int strcmp_offset(const char *s1, const char *s2, size_t *first_change);
+int index_dir_exists(struct index_state *istate, const char *name, int namelen);
+void adjust_dirname_case(struct index_state *istate, char *name);
+struct cache_entry *index_file_exists(struct index_state *istate, const char *name, int namelen, int igncase);
 
 /*
  * Searches for an entry defined by name and namelen in the given index.
@@ -665,7 +781,20 @@ extern struct cache_entry *index_file_ex
  * index_name_pos(&index, "f", 1) -> -3
  * index_name_pos(&index, "g", 1) -> -5
  */
-extern int index_name_pos(const struct index_state *, const char *name, int namelen);
+int index_name_pos(const struct index_state *, const char *name, int namelen);
+
+/*
+ * Some functions return the negative complement of an insert position when a
+ * precise match was not found but a position was found where the entry would
+ * need to be inserted. This helper protects that logic from any integer
+ * underflow.
+ */
+static inline int index_pos_to_insert_pos(uintmax_t pos)
+{
+	if (pos > INT_MAX)
+		die("overflow: -1 - %"PRIuMAX, pos);
+	return -1 - (int)pos;
+}
 
 #define ADD_CACHE_OK_TO_ADD 1		/* Ok to add */
 #define ADD_CACHE_OK_TO_REPLACE 2	/* Ok to replace file/directory */
@@ -673,14 +802,15 @@ extern int index_name_pos(const struct i
 #define ADD_CACHE_JUST_APPEND 8		/* Append only; tree.c::read_tree() */
 #define ADD_CACHE_NEW_ONLY 16		/* Do not replace existing ones */
 #define ADD_CACHE_KEEP_CACHE_TREE 32	/* Do not invalidate cache-tree */
-extern int add_index_entry(struct index_state *, struct cache_entry *ce, int option);
-extern void rename_index_entry_at(struct index_state *, int pos, const char *new_name);
+#define ADD_CACHE_RENORMALIZE 64        /* Pass along HASH_RENORMALIZE */
+int add_index_entry(struct index_state *, struct cache_entry *ce, int option);
+void rename_index_entry_at(struct index_state *, int pos, const char *new_name);
 
 /* Remove entry, return true if there are more entries to go. */
-extern int remove_index_entry_at(struct index_state *, int pos);
+int remove_index_entry_at(struct index_state *, int pos);
 
-extern void remove_marked_cache_entries(struct index_state *istate);
-extern int remove_file_from_index(struct index_state *, const char *path);
+void remove_marked_cache_entries(struct index_state *istate, int invalidate);
+int remove_file_from_index(struct index_state *, const char *path);
 #define ADD_CACHE_VERBOSE 1
 #define ADD_CACHE_PRETEND 2
 #define ADD_CACHE_IGNORE_ERRORS	4
@@ -695,15 +825,14 @@ extern int remove_file_from_index(struct
  * the latter will do necessary lstat(2) internally before
  * calling the former.
  */
-extern int add_to_index(struct index_state *, const char *path, struct stat *, int flags);
-extern int add_file_to_index(struct index_state *, const char *path, int flags);
+int add_to_index(struct index_state *, const char *path, struct stat *, int flags);
+int add_file_to_index(struct index_state *, const char *path, int flags);
 
-extern struct cache_entry *make_cache_entry(unsigned int mode, const unsigned char *sha1, const char *path, int stage, unsigned int refresh_options);
-extern int chmod_index_entry(struct index_state *, struct cache_entry *ce, char flip);
-extern int ce_same_name(const struct cache_entry *a, const struct cache_entry *b);
-extern void set_object_name_for_intent_to_add_entry(struct cache_entry *ce);
-extern int index_name_is_other(const struct index_state *, const char *, int);
-extern void *read_blob_data_from_index(const struct index_state *, const char *, unsigned long *);
+int chmod_index_entry(struct index_state *, struct cache_entry *ce, char flip);
+int ce_same_name(const struct cache_entry *a, const struct cache_entry *b);
+void set_object_name_for_intent_to_add_entry(struct cache_entry *ce);
+int index_name_is_other(const struct index_state *, const char *, int);
+void *read_blob_data_from_index(const struct index_state *, const char *, unsigned long *);
 
 /* do stat comparison even if CE_VALID is true */
 #define CE_MATCH_IGNORE_VALID		01
@@ -717,20 +846,22 @@ extern void *read_blob_data_from_index(c
 #define CE_MATCH_REFRESH		0x10
 /* don't refresh_fsmonitor state or do stat comparison even if CE_FSMONITOR_VALID is true */
 #define CE_MATCH_IGNORE_FSMONITOR 0X20
-extern int ie_match_stat(struct index_state *, const struct cache_entry *, struct stat *, unsigned int);
-extern int ie_modified(struct index_state *, const struct cache_entry *, struct stat *, unsigned int);
+int is_racy_timestamp(const struct index_state *istate,
+		      const struct cache_entry *ce);
+int ie_match_stat(struct index_state *, const struct cache_entry *, struct stat *, unsigned int);
+int ie_modified(struct index_state *, const struct cache_entry *, struct stat *, unsigned int);
 
 #define HASH_WRITE_OBJECT 1
 #define HASH_FORMAT_CHECK 2
 #define HASH_RENORMALIZE  4
-extern int index_fd(struct object_id *oid, int fd, struct stat *st, enum object_type type, const char *path, unsigned flags);
-extern int index_path(struct object_id *oid, const char *path, struct stat *st, unsigned flags);
+int index_fd(struct index_state *istate, struct object_id *oid, int fd, struct stat *st, enum object_type type, const char *path, unsigned flags);
+int index_path(struct index_state *istate, struct object_id *oid, const char *path, struct stat *st, unsigned flags);
 
 /*
  * Record to sd the data from st that we use to check whether a file
  * might have changed.
  */
-extern void fill_stat_data(struct stat_data *sd, struct stat *st);
+void fill_stat_data(struct stat_data *sd, struct stat *st);
 
 /*
  * Return 0 if st is consistent with a file not having been changed
@@ -738,11 +869,11 @@ extern void fill_stat_data(struct stat_d
  * combination of MTIME_CHANGED, CTIME_CHANGED, OWNER_CHANGED,
  * INODE_CHANGED, and DATA_CHANGED.
  */
-extern int match_stat_data(const struct stat_data *sd, struct stat *st);
-extern int match_stat_data_racy(const struct index_state *istate,
-				const struct stat_data *sd, struct stat *st);
+int match_stat_data(const struct stat_data *sd, struct stat *st);
+int match_stat_data_racy(const struct index_state *istate,
+			 const struct stat_data *sd, struct stat *st);
 
-extern void fill_stat_cache_info(struct cache_entry *ce, struct stat *st);
+void fill_stat_cache_info(struct index_state *istate, struct cache_entry *ce, struct stat *st);
 
 #define REFRESH_REALLY		0x0001	/* ignore_valid */
 #define REFRESH_UNMERGED	0x0002	/* allow unmerged */
@@ -750,17 +881,28 @@ extern void fill_stat_cache_info(struct
 #define REFRESH_IGNORE_MISSING	0x0008	/* ignore non-existent */
 #define REFRESH_IGNORE_SUBMODULES	0x0010	/* ignore submodules */
 #define REFRESH_IN_PORCELAIN	0x0020	/* user friendly output, not "needs update" */
-extern int refresh_index(struct index_state *, unsigned int flags, const struct pathspec *pathspec, char *seen, const char *header_msg);
-extern struct cache_entry *refresh_cache_entry(struct cache_entry *, unsigned int);
-
+#define REFRESH_PROGRESS	0x0040  /* show progress bar if stderr is tty */
+int refresh_index(struct index_state *, unsigned int flags, const struct pathspec *pathspec, char *seen, const char *header_msg);
 /*
- * Opportunistically update the index but do not complain if we can't.
- * The lockfile is always committed or rolled back.
+ * Refresh the index and write it to disk.
+ *
+ * 'refresh_flags' is passed directly to 'refresh_index()', while
+ * 'COMMIT_LOCK | write_flags' is passed to 'write_locked_index()', so
+ * the lockfile is always either committed or rolled back.
+ *
+ * If 'gentle' is passed, errors locking the index are ignored.
+ *
+ * Return 1 if refreshing the index returns an error, -1 if writing
+ * the index to disk fails, 0 on success.
+ *
+ * Note that if refreshing the index returns an error, we still write
+ * out the index (unless locking fails).
  */
-extern void update_index_if_able(struct index_state *, struct lock_file *);
+int repo_refresh_and_write_index(struct repository*, unsigned int refresh_flags, unsigned int write_flags, int gentle, const struct pathspec *, char *seen, const char *header_msg);
 
-extern int hold_locked_index(struct lock_file *, int);
-extern void set_alternate_index_output(const char *);
+struct cache_entry *refresh_cache_entry(struct index_state *, struct cache_entry *, unsigned int);
+
+void set_alternate_index_output(const char *);
 
 extern int verify_index_checksum;
 extern int verify_ce_order;
@@ -804,22 +946,21 @@ void reset_shared_repository(void);
  * Do replace refs need to be checked this run?  This variable is
  * initialized to true unless --no-replace-object is used or
  * $GIT_NO_REPLACE_OBJECTS is set, but is set to false by some
- * commands that do not want replace references to be active.  As an
- * optimization it is also set to false if replace references have
- * been sought but there were none.
+ * commands that do not want replace references to be active.
  */
-extern int check_replace_refs;
+extern int read_replace_refs;
 extern char *git_replace_ref_base;
 
 extern int fsync_object_files;
 extern int core_preload_index;
-extern int core_commit_graph;
-extern int core_apply_sparse_checkout;
 extern int precomposed_unicode;
 extern int protect_hfs;
 extern int protect_ntfs;
 extern const char *core_fsmonitor;
 
+extern int core_apply_sparse_checkout;
+extern int core_sparse_checkout_cone;
+
 /*
  * Include broken refs in all ref iterations, which will
  * generally choke dangerous operations rather than letting
@@ -840,14 +981,6 @@ int use_optional_locks(void);
 extern char comment_line_char;
 extern int auto_comment_line_char;
 
-/* Windows only */
-enum hide_dotfiles_type {
-	HIDE_DOTFILES_FALSE = 0,
-	HIDE_DOTFILES_TRUE,
-	HIDE_DOTFILES_DOTGITONLY
-};
-extern enum hide_dotfiles_type hide_dotfiles;
-
 enum log_refs_config {
 	LOG_REFS_UNSET = -1,
 	LOG_REFS_NONE = 0,
@@ -856,15 +989,6 @@ enum log_refs_config {
 };
 extern enum log_refs_config log_all_ref_updates;
 
-enum branch_track {
-	BRANCH_TRACK_UNSPECIFIED = -1,
-	BRANCH_TRACK_NEVER = 0,
-	BRANCH_TRACK_REMOTE,
-	BRANCH_TRACK_ALWAYS,
-	BRANCH_TRACK_EXPLICIT,
-	BRANCH_TRACK_OVERRIDE
-};
-
 enum rebase_setup_type {
 	AUTOREBASE_NEVER = 0,
 	AUTOREBASE_LOCAL,
@@ -881,7 +1005,6 @@ enum push_default_type {
 	PUSH_DEFAULT_UNSPECIFIED
 };
 
-extern enum branch_track git_branch_track;
 extern enum rebase_setup_type autorebase;
 extern enum push_default_type push_default;
 
@@ -904,13 +1027,17 @@ extern int grafts_replace_parents;
 #define GIT_REPO_VERSION 0
 #define GIT_REPO_VERSION_READ 1
 extern int repository_format_precious_objects;
-extern char *repository_format_partial_clone;
-extern const char *core_partial_clone_filter_default;
+extern int repository_format_worktree_config;
 
+/*
+ * You _have_ to initialize a `struct repository_format` using
+ * `= REPOSITORY_FORMAT_INIT` before calling `read_repository_format()`.
+ */
 struct repository_format {
 	int version;
 	int precious_objects;
 	char *partial_clone; /* value of extensions.partialclone */
+	int worktree_config;
 	int is_bare;
 	int hash_algo;
 	char *work_tree;
@@ -918,14 +1045,35 @@ struct repository_format {
 };
 
 /*
+ * Always use this to initialize a `struct repository_format`
+ * to a well-defined, default state before calling
+ * `read_repository()`.
+ */
+#define REPOSITORY_FORMAT_INIT \
+{ \
+	.version = -1, \
+	.is_bare = -1, \
+	.hash_algo = GIT_HASH_SHA1, \
+	.unknown_extensions = STRING_LIST_INIT_DUP, \
+}
+
+/*
  * Read the repository format characteristics from the config file "path" into
- * "format" struct. Returns the numeric version. On error, -1 is returned,
- * format->version is set to -1, and all other fields in the struct are
- * undefined.
+ * "format" struct. Returns the numeric version. On error, or if no version is
+ * found in the configuration, -1 is returned, format->version is set to -1,
+ * and all other fields in the struct are set to the default configuration
+ * (REPOSITORY_FORMAT_INIT). Always initialize the struct using
+ * REPOSITORY_FORMAT_INIT before calling this function.
  */
 int read_repository_format(struct repository_format *format, const char *path);
 
 /*
+ * Free the memory held onto by `format`, but not the struct itself.
+ * (No need to use this after `read_repository_format()` fails.)
+ */
+void clear_repository_format(struct repository_format *format);
+
+/*
  * Verify that the repository described by repository_format is something we
  * can read. If it is, return 0. Otherwise, return -1, and "err" will describe
  * any errors encountered.
@@ -939,7 +1087,7 @@ int verify_repository_format(const struc
  * set_git_dir() before calling this, and use it only for "are we in a valid
  * repo?".
  */
-extern void check_repository_format(void);
+void check_repository_format(void);
 
 #define MTIME_CHANGED	0x0001
 #define CTIME_CHANGED	0x0002
@@ -964,14 +1112,21 @@ extern void check_repository_format(void
  * Note that while this version avoids the static buffer, it is not fully
  * reentrant, as it calls into other non-reentrant git code.
  */
-extern const char *find_unique_abbrev(const struct object_id *oid, int len);
-extern int find_unique_abbrev_r(char *hex, const struct object_id *oid, int len);
+const char *repo_find_unique_abbrev(struct repository *r, const struct object_id *oid, int len);
+#define find_unique_abbrev(oid, len) repo_find_unique_abbrev(the_repository, oid, len)
+int repo_find_unique_abbrev_r(struct repository *r, char *hex, const struct object_id *oid, int len);
+#define find_unique_abbrev_r(hex, oid, len) repo_find_unique_abbrev_r(the_repository, hex, oid, len)
 
-extern const unsigned char null_sha1[GIT_MAX_RAWSZ];
 extern const struct object_id null_oid;
 
 static inline int hashcmp(const unsigned char *sha1, const unsigned char *sha2)
 {
+	/*
+	 * Teach the compiler that there are only two possibilities of hash size
+	 * here, so that it can optimize for this case as much as possible.
+	 */
+	if (the_hash_algo->rawsz == GIT_MAX_RAWSZ)
+		return memcmp(sha1, sha2, GIT_MAX_RAWSZ);
 	return memcmp(sha1, sha2, GIT_SHA1_RAWSZ);
 }
 
@@ -980,24 +1135,35 @@ static inline int oidcmp(const struct ob
 	return hashcmp(oid1->hash, oid2->hash);
 }
 
-static inline int is_null_sha1(const unsigned char *sha1)
+static inline int hasheq(const unsigned char *sha1, const unsigned char *sha2)
+{
+	/*
+	 * We write this here instead of deferring to hashcmp so that the
+	 * compiler can properly inline it and avoid calling memcmp.
+	 */
+	if (the_hash_algo->rawsz == GIT_MAX_RAWSZ)
+		return !memcmp(sha1, sha2, GIT_MAX_RAWSZ);
+	return !memcmp(sha1, sha2, GIT_SHA1_RAWSZ);
+}
+
+static inline int oideq(const struct object_id *oid1, const struct object_id *oid2)
 {
-	return !hashcmp(sha1, null_sha1);
+	return hasheq(oid1->hash, oid2->hash);
 }
 
 static inline int is_null_oid(const struct object_id *oid)
 {
-	return !hashcmp(oid->hash, null_sha1);
+	return oideq(oid, &null_oid);
 }
 
 static inline void hashcpy(unsigned char *sha_dst, const unsigned char *sha_src)
 {
-	memcpy(sha_dst, sha_src, GIT_SHA1_RAWSZ);
+	memcpy(sha_dst, sha_src, the_hash_algo->rawsz);
 }
 
 static inline void oidcpy(struct object_id *dst, const struct object_id *src)
 {
-	hashcpy(dst->hash, src->hash);
+	memcpy(dst->hash, src->hash, GIT_MAX_RAWSZ);
 }
 
 static inline struct object_id *oiddup(const struct object_id *src)
@@ -1009,7 +1175,7 @@ static inline struct object_id *oiddup(c
 
 static inline void hashclr(unsigned char *hash)
 {
-	memset(hash, 0, GIT_SHA1_RAWSZ);
+	memset(hash, 0, the_hash_algo->rawsz);
 }
 
 static inline void oidclr(struct object_id *oid)
@@ -1024,22 +1190,22 @@ static inline void oidread(struct object
 
 static inline int is_empty_blob_sha1(const unsigned char *sha1)
 {
-	return !hashcmp(sha1, the_hash_algo->empty_blob->hash);
+	return hasheq(sha1, the_hash_algo->empty_blob->hash);
 }
 
 static inline int is_empty_blob_oid(const struct object_id *oid)
 {
-	return !oidcmp(oid, the_hash_algo->empty_blob);
+	return oideq(oid, the_hash_algo->empty_blob);
 }
 
 static inline int is_empty_tree_sha1(const unsigned char *sha1)
 {
-	return !hashcmp(sha1, the_hash_algo->empty_tree->hash);
+	return hasheq(sha1, the_hash_algo->empty_tree->hash);
 }
 
 static inline int is_empty_tree_oid(const struct object_id *oid)
 {
-	return !oidcmp(oid, the_hash_algo->empty_tree);
+	return oideq(oid, the_hash_algo->empty_tree);
 }
 
 const char *empty_tree_oid_hex(void);
@@ -1139,7 +1305,7 @@ typedef int create_file_fn(const char *p
 int raceproof_create_file(const char *path, create_file_fn fn, void *cb);
 
 int mkdir_in_gitdir(const char *path);
-extern char *expand_user_path(const char *path, int real_home);
+char *expand_user_path(const char *path, int real_home);
 const char *enter_repo(const char *path, int strict);
 static inline int is_absolute_path(const char *path)
 {
@@ -1183,89 +1349,26 @@ int looks_like_command_line_option(const
  * "$XDG_CONFIG_HOME/git/$filename" if $XDG_CONFIG_HOME is non-empty, otherwise
  * "$HOME/.config/git/$filename". Return NULL upon error.
  */
-extern char *xdg_config_home(const char *filename);
+char *xdg_config_home(const char *filename);
 
 /**
  * Return a newly allocated string with the evaluation of
  * "$XDG_CACHE_HOME/git/$filename" if $XDG_CACHE_HOME is non-empty, otherwise
  * "$HOME/.cache/git/$filename". Return NULL upon error.
  */
-extern char *xdg_cache_home(const char *filename);
-
-extern void *read_object_file_extended(const struct object_id *oid,
-				       enum object_type *type,
-				       unsigned long *size, int lookup_replace);
-static inline void *read_object_file(const struct object_id *oid, enum object_type *type, unsigned long *size)
-{
-	return read_object_file_extended(oid, type, size, 1);
-}
-
-/* Read and unpack an object file into memory, write memory to an object file */
-int oid_object_info(struct repository *r, const struct object_id *, unsigned long *);
-
-extern int hash_object_file(const void *buf, unsigned long len,
-			    const char *type, struct object_id *oid);
-
-extern int write_object_file(const void *buf, unsigned long len,
-			     const char *type, struct object_id *oid);
-
-extern int hash_object_file_literally(const void *buf, unsigned long len,
-				      const char *type, struct object_id *oid,
-				      unsigned flags);
+char *xdg_cache_home(const char *filename);
 
-extern int pretend_object_file(void *, unsigned long, enum object_type,
-			       struct object_id *oid);
-
-extern int force_object_loose(const struct object_id *oid, time_t mtime);
-
-extern int git_open_cloexec(const char *name, int flags);
+int git_open_cloexec(const char *name, int flags);
 #define git_open(name) git_open_cloexec(name, O_RDONLY)
-extern int unpack_sha1_header(git_zstream *stream, unsigned char *map, unsigned long mapsize, void *buffer, unsigned long bufsiz);
-extern int parse_sha1_header(const char *hdr, unsigned long *sizep);
-
-extern int check_object_signature(const struct object_id *oid, void *buf, unsigned long size, const char *type);
-
-extern int finalize_object_file(const char *tmpfile, const char *filename);
-
-/*
- * Open the loose object at path, check its hash, and return the contents,
- * type, and size. If the object is a blob, then "contents" may return NULL,
- * to allow streaming of large blobs.
- *
- * Returns 0 on success, negative on error (details may be written to stderr).
- */
-int read_loose_object(const char *path,
-		      const struct object_id *expected_oid,
-		      enum object_type *type,
-		      unsigned long *size,
-		      void **contents);
+int unpack_loose_header(git_zstream *stream, unsigned char *map, unsigned long mapsize, void *buffer, unsigned long bufsiz);
+int parse_loose_header(const char *hdr, unsigned long *sizep);
 
-/*
- * Convenience for sha1_object_info_extended() with a NULL struct
- * object_info. OBJECT_INFO_SKIP_CACHED is automatically set; pass
- * nonzero flags to also set other flags.
- */
-extern int has_sha1_file_with_flags(const unsigned char *sha1, int flags);
-static inline int has_sha1_file(const unsigned char *sha1)
-{
-	return has_sha1_file_with_flags(sha1, 0);
-}
-
-/* Same as the above, except for struct object_id. */
-extern int has_object_file(const struct object_id *oid);
-extern int has_object_file_with_flags(const struct object_id *oid, int flags);
-
-/*
- * Return true iff an alternate object database has a loose object
- * with the specified name.  This function does not respect replace
- * references.
- */
-extern int has_loose_object_nonlocal(const struct object_id *oid);
+int check_object_signature(const struct object_id *oid, void *buf, unsigned long size, const char *type);
 
-extern void assert_oid_type(const struct object_id *oid, enum object_type expect);
+int finalize_object_file(const char *tmpfile, const char *filename);
 
 /* Helper to check and "touch" a file */
-extern int check_and_freshen_file(const char *fn, int freshen);
+int check_and_freshen_file(const char *fn, int freshen);
 
 extern const signed char hexval_table[256];
 static inline unsigned int hexval(unsigned char c)
@@ -1291,7 +1394,7 @@ static inline int hex2chr(const char *s)
 #define FALLBACK_DEFAULT_ABBREV 7
 
 struct object_context {
-	unsigned mode;
+	unsigned short mode;
 	/*
 	 * symlink_path is only used by get_tree_entry_follow_symlinks,
 	 * and only for symlinks that point outside the repository.
@@ -1320,20 +1423,52 @@ struct object_context {
 	GET_OID_TREE | GET_OID_TREEISH | \
 	GET_OID_BLOB)
 
-extern int get_oid(const char *str, struct object_id *oid);
-extern int get_oid_commit(const char *str, struct object_id *oid);
-extern int get_oid_committish(const char *str, struct object_id *oid);
-extern int get_oid_tree(const char *str, struct object_id *oid);
-extern int get_oid_treeish(const char *str, struct object_id *oid);
-extern int get_oid_blob(const char *str, struct object_id *oid);
-extern void maybe_die_on_misspelt_object_name(const char *name, const char *prefix);
-extern int get_oid_with_context(const char *str, unsigned flags, struct object_id *oid, struct object_context *oc);
-
+enum get_oid_result {
+	FOUND = 0,
+	MISSING_OBJECT = -1, /* The requested object is missing */
+	SHORT_NAME_AMBIGUOUS = -2,
+	/* The following only apply when symlinks are followed */
+	DANGLING_SYMLINK = -4, /*
+				* The initial symlink is there, but
+				* (transitively) points to a missing
+				* in-tree file
+				*/
+	SYMLINK_LOOP = -5,
+	NOT_DIR = -6, /*
+		       * Somewhere along the symlink chain, a path is
+		       * requested which contains a file as a
+		       * non-final element.
+		       */
+};
+
+int repo_get_oid(struct repository *r, const char *str, struct object_id *oid);
+int get_oidf(struct object_id *oid, const char *fmt, ...);
+int repo_get_oid_commit(struct repository *r, const char *str, struct object_id *oid);
+int repo_get_oid_committish(struct repository *r, const char *str, struct object_id *oid);
+int repo_get_oid_tree(struct repository *r, const char *str, struct object_id *oid);
+int repo_get_oid_treeish(struct repository *r, const char *str, struct object_id *oid);
+int repo_get_oid_blob(struct repository *r, const char *str, struct object_id *oid);
+int repo_get_oid_mb(struct repository *r, const char *str, struct object_id *oid);
+void maybe_die_on_misspelt_object_name(struct repository *repo,
+				       const char *name,
+				       const char *prefix);
+enum get_oid_result get_oid_with_context(struct repository *repo, const char *str,
+					 unsigned flags, struct object_id *oid,
+					 struct object_context *oc);
+
+#define get_oid(str, oid)		repo_get_oid(the_repository, str, oid)
+#define get_oid_commit(str, oid)	repo_get_oid_commit(the_repository, str, oid)
+#define get_oid_committish(str, oid)	repo_get_oid_committish(the_repository, str, oid)
+#define get_oid_tree(str, oid)		repo_get_oid_tree(the_repository, str, oid)
+#define get_oid_treeish(str, oid)	repo_get_oid_treeish(the_repository, str, oid)
+#define get_oid_blob(str, oid)		repo_get_oid_blob(the_repository, str, oid)
+#define get_oid_mb(str, oid) 		repo_get_oid_mb(the_repository, str, oid)
 
 typedef int each_abbrev_fn(const struct object_id *oid, void *);
-extern int for_each_abbrev(const char *prefix, each_abbrev_fn, void *);
+int repo_for_each_abbrev(struct repository *r, const char *prefix, each_abbrev_fn, void *);
+#define for_each_abbrev(prefix, fn, data) repo_for_each_abbrev(the_repository, prefix, fn, data)
 
-extern int set_disambiguate_hint_config(const char *var, const char *value);
+int set_disambiguate_hint_config(const char *var, const char *value);
 
 /*
  * Try to read a SHA1 in hexadecimal format from the 40 characters
@@ -1342,31 +1477,34 @@ extern int set_disambiguate_hint_config(
  * input, so it is safe to pass this function an arbitrary
  * null-terminated string.
  */
-extern int get_sha1_hex(const char *hex, unsigned char *sha1);
-extern int get_oid_hex(const char *hex, struct object_id *sha1);
+int get_sha1_hex(const char *hex, unsigned char *sha1);
+int get_oid_hex(const char *hex, struct object_id *sha1);
 
 /*
  * Read `len` pairs of hexadecimal digits from `hex` and write the
  * values to `binary` as `len` bytes. Return 0 on success, or -1 if
  * the input does not consist of hex digits).
  */
-extern int hex_to_bytes(unsigned char *binary, const char *hex, size_t len);
+int hex_to_bytes(unsigned char *binary, const char *hex, size_t len);
 
 /*
- * Convert a binary sha1 to its hex equivalent. The `_r` variant is reentrant,
+ * Convert a binary hash in "unsigned char []" or an object name in
+ * "struct object_id *" to its hex equivalent. The `_r` variant is reentrant,
  * and writes the NUL-terminated output to the buffer `out`, which must be at
- * least `GIT_SHA1_HEXSZ + 1` bytes, and returns a pointer to out for
+ * least `GIT_MAX_HEXSZ + 1` bytes, and returns a pointer to out for
  * convenience.
  *
  * The non-`_r` variant returns a static buffer, but uses a ring of 4
  * buffers, making it safe to make multiple calls for a single statement, like:
  *
- *   printf("%s -> %s", sha1_to_hex(one), sha1_to_hex(two));
+ *   printf("%s -> %s", hash_to_hex(one), hash_to_hex(two));
+ *   printf("%s -> %s", oid_to_hex(one), oid_to_hex(two));
  */
-extern char *sha1_to_hex_r(char *out, const unsigned char *sha1);
-extern char *oid_to_hex_r(char *out, const struct object_id *oid);
-extern char *sha1_to_hex(const unsigned char *sha1);	/* static buffer result! */
-extern char *oid_to_hex(const struct object_id *oid);	/* same static buffer as sha1_to_hex */
+char *hash_to_hex_algop_r(char *buffer, const unsigned char *hash, const struct git_hash_algo *);
+char *oid_to_hex_r(char *out, const struct object_id *oid);
+char *hash_to_hex_algop(const unsigned char *hash, const struct git_hash_algo *);	/* static buffer result! */
+char *hash_to_hex(const unsigned char *hash);						/* same static buffer */
+char *oid_to_hex(const struct object_id *oid);						/* same static buffer */
 
 /*
  * Parse a 40-character hexadecimal object ID starting from hex, updating the
@@ -1375,7 +1513,7 @@ extern char *oid_to_hex(const struct obj
  * other invalid character.  end is only updated on success; otherwise, it is
  * unmodified.
  */
-extern int parse_oid_hex(const char *hex, struct object_id *oid, const char **end);
+int parse_oid_hex(const char *hex, struct object_id *oid, const char **end);
 
 /*
  * This reads short-hand syntax that not only evaluates to a commit
@@ -1406,37 +1544,47 @@ extern int parse_oid_hex(const char *hex
 #define INTERPRET_BRANCH_LOCAL (1<<0)
 #define INTERPRET_BRANCH_REMOTE (1<<1)
 #define INTERPRET_BRANCH_HEAD (1<<2)
-extern int interpret_branch_name(const char *str, int len, struct strbuf *,
-				 unsigned allowed);
-extern int get_oid_mb(const char *str, struct object_id *oid);
-
-extern int validate_headref(const char *ref);
-
-extern int base_name_compare(const char *name1, int len1, int mode1, const char *name2, int len2, int mode2);
-extern int df_name_compare(const char *name1, int len1, int mode1, const char *name2, int len2, int mode2);
-extern int name_compare(const char *name1, size_t len1, const char *name2, size_t len2);
-extern int cache_name_stage_compare(const char *name1, int len1, int stage1, const char *name2, int len2, int stage2);
-
-extern void *read_object_with_reference(const struct object_id *oid,
-					const char *required_type,
-					unsigned long *size,
-					struct object_id *oid_ret);
-
-extern struct object *peel_to_type(const char *name, int namelen,
-				   struct object *o, enum object_type);
+int repo_interpret_branch_name(struct repository *r,
+			       const char *str, int len,
+			       struct strbuf *buf,
+			       unsigned allowed);
+#define interpret_branch_name(str, len, buf, allowed) \
+	repo_interpret_branch_name(the_repository, str, len, buf, allowed)
+
+int validate_headref(const char *ref);
+
+int base_name_compare(const char *name1, int len1, int mode1, const char *name2, int len2, int mode2);
+int df_name_compare(const char *name1, int len1, int mode1, const char *name2, int len2, int mode2);
+int name_compare(const char *name1, size_t len1, const char *name2, size_t len2);
+int cache_name_stage_compare(const char *name1, int len1, int stage1, const char *name2, int len2, int stage2);
+
+void *read_object_with_reference(struct repository *r,
+				 const struct object_id *oid,
+				 const char *required_type,
+				 unsigned long *size,
+				 struct object_id *oid_ret);
+
+struct object *repo_peel_to_type(struct repository *r,
+				 const char *name, int namelen,
+				 struct object *o, enum object_type);
+#define peel_to_type(name, namelen, obj, type) \
+	repo_peel_to_type(the_repository, name, namelen, obj, type)
+
+enum date_mode_type {
+	DATE_NORMAL = 0,
+	DATE_HUMAN,
+	DATE_RELATIVE,
+	DATE_SHORT,
+	DATE_ISO8601,
+	DATE_ISO8601_STRICT,
+	DATE_RFC2822,
+	DATE_STRFTIME,
+	DATE_RAW,
+	DATE_UNIX
+};
 
 struct date_mode {
-	enum date_mode_type {
-		DATE_NORMAL = 0,
-		DATE_RELATIVE,
-		DATE_SHORT,
-		DATE_ISO8601,
-		DATE_ISO8601_STRICT,
-		DATE_RFC2822,
-		DATE_STRFTIME,
-		DATE_RAW,
-		DATE_UNIX
-	} type;
+	enum date_mode_type type;
 	const char *strftime_fmt;
 	int local;
 };
@@ -1450,7 +1598,8 @@ struct date_mode {
 struct date_mode *date_mode_from_type(enum date_mode_type type);
 
 const char *show_date(timestamp_t time, int timezone, const struct date_mode *mode);
-void show_date_relative(timestamp_t time, int tz, const struct timeval *now,
+void show_date_relative(timestamp_t time, struct strbuf *timebuf);
+void show_date_human(timestamp_t time, int tz, const struct timeval *now,
 			struct strbuf *timebuf);
 int parse_date(const char *date, struct strbuf *out);
 int parse_date_basic(const char *date, timestamp_t *timestamp, int *offset);
@@ -1458,24 +1607,38 @@ int parse_expiry_date(const char *date,
 void datestamp(struct strbuf *out);
 #define approxidate(s) approxidate_careful((s), NULL)
 timestamp_t approxidate_careful(const char *, int *);
-timestamp_t approxidate_relative(const char *date, const struct timeval *now);
+timestamp_t approxidate_relative(const char *date);
 void parse_date_format(const char *format, struct date_mode *mode);
 int date_overflows(timestamp_t date);
 
 #define IDENT_STRICT	       1
 #define IDENT_NO_DATE	       2
 #define IDENT_NO_NAME	       4
-extern const char *git_author_info(int);
-extern const char *git_committer_info(int);
-extern const char *fmt_ident(const char *name, const char *email, const char *date_str, int);
-extern const char *fmt_name(const char *name, const char *email);
-extern const char *ident_default_name(void);
-extern const char *ident_default_email(void);
-extern const char *git_editor(void);
-extern const char *git_pager(int stdout_is_tty);
-extern int is_terminal_dumb(void);
-extern int git_ident_config(const char *, const char *, void *);
-extern void reset_ident_date(void);
+
+enum want_ident {
+	WANT_BLANK_IDENT,
+	WANT_AUTHOR_IDENT,
+	WANT_COMMITTER_IDENT
+};
+
+const char *git_author_info(int);
+const char *git_committer_info(int);
+const char *fmt_ident(const char *name, const char *email,
+		      enum want_ident whose_ident,
+		      const char *date_str, int);
+const char *fmt_name(enum want_ident);
+const char *ident_default_name(void);
+const char *ident_default_email(void);
+const char *git_editor(void);
+const char *git_sequence_editor(void);
+const char *git_pager(int stdout_is_tty);
+int is_terminal_dumb(void);
+int git_ident_config(const char *, const char *, void *);
+/*
+ * Prepare an ident to fall back on if the user didn't configure it.
+ */
+void prepare_fallback_ident(const char *name, const char *email);
+void reset_ident_date(void);
 
 struct ident_split {
 	const char *name_begin;
@@ -1491,7 +1654,7 @@ struct ident_split {
  * Signals an success with 0, but time part of the result may be NULL
  * if the input lacks timestamp and zone
  */
-extern int split_ident_line(struct ident_split *, const char *, int);
+int split_ident_line(struct ident_split *, const char *, int);
 
 /*
  * Like show_date, but pull the timestamp and tz parameters from
@@ -1508,7 +1671,7 @@ const char *show_ident_date(const struct
  * Because there are two fields, we must choose one as the primary key; we
  * currently arbitrarily pick the email.
  */
-extern int ident_cmp(const struct ident_split *, const struct ident_split *);
+int ident_cmp(const struct ident_split *, const struct ident_split *);
 
 struct checkout {
 	struct index_state *istate;
@@ -1518,14 +1681,20 @@ struct checkout {
 	unsigned force:1,
 		 quiet:1,
 		 not_new:1,
+		 clone:1,
 		 refresh_cache:1;
 };
 #define CHECKOUT_INIT { NULL, "" }
 
 #define TEMPORARY_FILENAME_LENGTH 25
-extern int checkout_entry(struct cache_entry *ce, const struct checkout *state, char *topath);
-extern void enable_delayed_checkout(struct checkout *state);
-extern int finish_delayed_checkout(struct checkout *state);
+int checkout_entry(struct cache_entry *ce, const struct checkout *state, char *topath, int *nr_checkouts);
+void enable_delayed_checkout(struct checkout *state);
+int finish_delayed_checkout(struct checkout *state, int *nr_checkouts);
+/*
+ * Unlink the last component and schedule the leading directories for
+ * removal, such that empty directories get removed.
+ */
+void unlink_entry(const struct cache_entry *ce);
 
 struct cache_def {
 	struct strbuf path;
@@ -1539,12 +1708,12 @@ static inline void cache_def_clear(struc
 	strbuf_release(&cache->path);
 }
 
-extern int has_symlink_leading_path(const char *name, int len);
-extern int threaded_has_symlink_leading_path(struct cache_def *, const char *, int);
-extern int check_leading_path(const char *name, int len);
-extern int has_dirs_only_path(const char *name, int len, int prefix_len);
-extern void schedule_dir_for_removal(const char *name, int len);
-extern void remove_scheduled_dirs(void);
+int has_symlink_leading_path(const char *name, int len);
+int threaded_has_symlink_leading_path(struct cache_def *, const char *, int);
+int check_leading_path(const char *name, int len);
+int has_dirs_only_path(const char *name, int len, int prefix_len);
+void schedule_dir_for_removal(const char *name, int len);
+void remove_scheduled_dirs(void);
 
 struct pack_window {
 	struct pack_window *next;
@@ -1566,127 +1735,17 @@ struct pack_entry {
  * usual "XXXXXX" trailer, and the resulting filename is written into the
  * "template" buffer. Returns the open descriptor.
  */
-extern int odb_mkstemp(struct strbuf *temp_filename, const char *pattern);
+int odb_mkstemp(struct strbuf *temp_filename, const char *pattern);
 
 /*
  * Create a pack .keep file named "name" (which should generally be the output
  * of odb_pack_name). Returns a file descriptor opened for writing, or -1 on
  * error.
  */
-extern int odb_pack_keep(const char *name);
+int odb_pack_keep(const char *name);
 
 /*
- * Iterate over the files in the loose-object parts of the object
- * directory "path", triggering the following callbacks:
- *
- *  - loose_object is called for each loose object we find.
- *
- *  - loose_cruft is called for any files that do not appear to be
- *    loose objects. Note that we only look in the loose object
- *    directories "objects/[0-9a-f]{2}/", so we will not report
- *    "objects/foobar" as cruft.
- *
- *  - loose_subdir is called for each top-level hashed subdirectory
- *    of the object directory (e.g., "$OBJDIR/f0"). It is called
- *    after the objects in the directory are processed.
- *
- * Any callback that is NULL will be ignored. Callbacks returning non-zero
- * will end the iteration.
- *
- * In the "buf" variant, "path" is a strbuf which will also be used as a
- * scratch buffer, but restored to its original contents before
- * the function returns.
- */
-typedef int each_loose_object_fn(const struct object_id *oid,
-				 const char *path,
-				 void *data);
-typedef int each_loose_cruft_fn(const char *basename,
-				const char *path,
-				void *data);
-typedef int each_loose_subdir_fn(unsigned int nr,
-				 const char *path,
-				 void *data);
-int for_each_file_in_obj_subdir(unsigned int subdir_nr,
-				struct strbuf *path,
-				each_loose_object_fn obj_cb,
-				each_loose_cruft_fn cruft_cb,
-				each_loose_subdir_fn subdir_cb,
-				void *data);
-int for_each_loose_file_in_objdir(const char *path,
-				  each_loose_object_fn obj_cb,
-				  each_loose_cruft_fn cruft_cb,
-				  each_loose_subdir_fn subdir_cb,
-				  void *data);
-int for_each_loose_file_in_objdir_buf(struct strbuf *path,
-				      each_loose_object_fn obj_cb,
-				      each_loose_cruft_fn cruft_cb,
-				      each_loose_subdir_fn subdir_cb,
-				      void *data);
-
-/*
- * Iterate over loose objects in both the local
- * repository and any alternates repositories (unless the
- * LOCAL_ONLY flag is set).
- */
-#define FOR_EACH_OBJECT_LOCAL_ONLY 0x1
-extern int for_each_loose_object(each_loose_object_fn, void *, unsigned flags);
-
-struct object_info {
-	/* Request */
-	enum object_type *typep;
-	unsigned long *sizep;
-	off_t *disk_sizep;
-	unsigned char *delta_base_sha1;
-	struct strbuf *type_name;
-	void **contentp;
-
-	/* Response */
-	enum {
-		OI_CACHED,
-		OI_LOOSE,
-		OI_PACKED,
-		OI_DBCACHED
-	} whence;
-	union {
-		/*
-		 * struct {
-		 * 	... Nothing to expose in this case
-		 * } cached;
-		 * struct {
-		 * 	... Nothing to expose in this case
-		 * } loose;
-		 */
-		struct {
-			struct packed_git *pack;
-			off_t offset;
-			unsigned int is_delta;
-		} packed;
-	} u;
-};
-
-/*
- * Initializer for a "struct object_info" that wants no items. You may
- * also memset() the memory to all-zeroes.
- */
-#define OBJECT_INFO_INIT {NULL}
-
-/* Invoke lookup_replace_object() on the given hash */
-#define OBJECT_INFO_LOOKUP_REPLACE 1
-/* Allow reading from a loose object file of unknown/bogus type */
-#define OBJECT_INFO_ALLOW_UNKNOWN_TYPE 2
-/* Do not check cached storage */
-#define OBJECT_INFO_SKIP_CACHED 4
-/* Do not retry packed storage after checking packed and loose storage */
-#define OBJECT_INFO_QUICK 8
-/* Do not check loose object */
-#define OBJECT_INFO_IGNORE_LOOSE 16
-
-int oid_object_info_extended(struct repository *r,
-			     const struct object_id *,
-			     struct object_info *, unsigned flags);
-
-/*
- * Set this to 0 to prevent sha1_object_info_extended() from fetching missing
+ * Set this to 0 to prevent oid_object_info_extended() from fetching missing
  * blobs. This has a difference only if extensions.partialClone is set.
  *
  * Its default value is 1.
@@ -1694,10 +1753,10 @@ int oid_object_info_extended(struct repo
 extern int fetch_if_missing;
 
 /* Dumb servers support */
-extern int update_server_info(int);
+int update_server_info(int);
 
-extern const char *get_log_output_encoding(void);
-extern const char *get_commit_output_encoding(void);
+const char *get_log_output_encoding(void);
+const char *get_commit_output_encoding(void);
 
 /*
  * This is a hack for test programs like test-dump-untracked-cache to
@@ -1706,8 +1765,8 @@ extern const char *get_commit_output_enc
  */
 extern int ignore_untracked_cache_config;
 
-extern int committer_ident_sufficiently_given(void);
-extern int author_ident_sufficiently_given(void);
+int committer_ident_sufficiently_given(void);
+int author_ident_sufficiently_given(void);
 
 extern const char *git_commit_encoding;
 extern const char *git_log_output_encoding;
@@ -1715,22 +1774,22 @@ extern const char *git_mailmap_file;
 extern const char *git_mailmap_blob;
 
 /* IO helper functions */
-extern void maybe_flush_or_die(FILE *, const char *);
+void maybe_flush_or_die(FILE *, const char *);
 __attribute__((format (printf, 2, 3)))
-extern void fprintf_or_die(FILE *, const char *fmt, ...);
+void fprintf_or_die(FILE *, const char *fmt, ...);
 
 #define COPY_READ_ERROR (-2)
 #define COPY_WRITE_ERROR (-3)
-extern int copy_fd(int ifd, int ofd);
-extern int copy_file(const char *dst, const char *src, int mode);
-extern int copy_file_with_time(const char *dst, const char *src, int mode);
-
-extern void write_or_die(int fd, const void *buf, size_t count);
-extern void fsync_or_die(int fd, const char *);
-
-extern ssize_t read_in_full(int fd, void *buf, size_t count);
-extern ssize_t write_in_full(int fd, const void *buf, size_t count);
-extern ssize_t pread_in_full(int fd, void *buf, size_t count, off_t offset);
+int copy_fd(int ifd, int ofd);
+int copy_file(const char *dst, const char *src, int mode);
+int copy_file_with_time(const char *dst, const char *src, int mode);
+
+void write_or_die(int fd, const void *buf, size_t count);
+void fsync_or_die(int fd, const char *);
+
+ssize_t read_in_full(int fd, void *buf, size_t count);
+ssize_t write_in_full(int fd, const void *buf, size_t count);
+ssize_t pread_in_full(int fd, void *buf, size_t count, off_t offset);
 
 static inline ssize_t write_str_in_full(int fd, const char *str)
 {
@@ -1741,7 +1800,7 @@ static inline ssize_t write_str_in_full(
  * Open (and truncate) the file at path, write the contents of buf to it,
  * and close it. Dies if any errors are encountered.
  */
-extern void write_file_buf(const char *path, const char *buf, size_t len);
+void write_file_buf(const char *path, const char *buf, size_t len);
 
 /**
  * Like write_file_buf(), but format the contents into a buffer first.
@@ -1751,16 +1810,17 @@ extern void write_file_buf(const char *p
  *   write_file(path, "counter: %d", ctr);
  */
 __attribute__((format (printf, 2, 3)))
-extern void write_file(const char *path, const char *fmt, ...);
+void write_file(const char *path, const char *fmt, ...);
 
 /* pager.c */
-extern void setup_pager(void);
-extern int pager_in_use(void);
+void setup_pager(void);
+int pager_in_use(void);
 extern int pager_use_color;
-extern int term_columns(void);
-extern int decimal_width(uintmax_t);
-extern int check_pager_config(const char *cmd);
-extern void prepare_pager_args(struct child_process *, const char *pager);
+int term_columns(void);
+void term_clear_line(void);
+int decimal_width(uintmax_t);
+int check_pager_config(const char *cmd);
+void prepare_pager_args(struct child_process *, const char *pager);
 
 extern const char *editor_program;
 extern const char *askpass_program;
@@ -1770,15 +1830,6 @@ extern const char *excludes_file;
 int decode_85(char *dst, const char *line, int linelen);
 void encode_85(char *buf, const unsigned char *data, int bytes);
 
-/* alloc.c */
-extern void *alloc_blob_node(void);
-extern void *alloc_tree_node(void);
-extern void *alloc_commit_node(void);
-extern void *alloc_tag_node(void);
-extern void *alloc_object_node(void);
-extern void alloc_report(void);
-extern unsigned int alloc_commit_index(void);
-
 /* pkt-line.c */
 void packet_trace_identity(const char *prog);
 
@@ -1793,8 +1844,8 @@ int add_files_to_cache(const char *prefi
 extern int diff_auto_refresh_index;
 
 /* match-trees.c */
-void shift_tree(const struct object_id *, const struct object_id *, struct object_id *, int);
-void shift_tree_by(const struct object_id *, const struct object_id *, struct object_id *, const char *);
+void shift_tree(struct repository *, const struct object_id *, const struct object_id *, struct object_id *, int);
+void shift_tree_by(struct repository *, const struct object_id *, const struct object_id *, struct object_id *, const char *);
 
 /*
  * whitespace rules.
@@ -1813,13 +1864,13 @@ void shift_tree_by(const struct object_i
 /* All WS_* -- when extended, adapt diff.c emit_symbol */
 #define WS_RULE_MASK           07777
 extern unsigned whitespace_rule_cfg;
-extern unsigned whitespace_rule(const char *);
-extern unsigned parse_whitespace_rule(const char *);
-extern unsigned ws_check(const char *line, int len, unsigned ws_rule);
-extern void ws_check_emit(const char *line, int len, unsigned ws_rule, FILE *stream, const char *set, const char *reset, const char *ws);
-extern char *whitespace_error_string(unsigned ws);
-extern void ws_fix_copy(struct strbuf *, const char *, int, unsigned, int *);
-extern int ws_blank_line(const char *line, int len, unsigned ws_rule);
+unsigned whitespace_rule(struct index_state *, const char *);
+unsigned parse_whitespace_rule(const char *);
+unsigned ws_check(const char *line, int len, unsigned ws_rule);
+void ws_check_emit(const char *line, int len, unsigned ws_rule, FILE *stream, const char *set, const char *reset, const char *ws);
+char *whitespace_error_string(unsigned ws);
+void ws_fix_copy(struct strbuf *, const char *, int, unsigned, int *);
+int ws_blank_line(const char *line, int len, unsigned ws_rule);
 #define ws_tab_width(rule)     ((rule) & WS_TAB_WIDTH_MASK)
 
 /* ls-files */
@@ -1835,10 +1886,12 @@ extern struct startup_info *startup_info
 
 /* merge.c */
 struct commit_list;
-int try_merge_command(const char *strategy, size_t xopts_nr,
+int try_merge_command(struct repository *r,
+		const char *strategy, size_t xopts_nr,
 		const char **xopts, struct commit_list *common,
 		const char *head_arg, struct commit_list *remotes);
-int checkout_fast_forward(const struct object_id *from,
+int checkout_fast_forward(struct repository *r,
+			  const struct object_id *from,
 			  const struct object_id *to,
 			  int overwrite_ignore);
 
@@ -1887,6 +1940,9 @@ void safe_create_dir(const char *dir, in
  * Should we print an ellipsis after an abbreviated SHA-1 value
  * when doing diff-raw output or indicating a detached HEAD?
  */
-extern int print_sha1_ellipsis(void);
+int print_sha1_ellipsis(void);
+
+/* Return 1 if the file is empty or does not exists, 0 otherwise. */
+int is_empty_or_missing_file(const char *filename);
 
 #endif /* CACHE_H */
diff -pruN 1.2.1+git2.18.0-1/git/cache-tree.c 1.2.3+git2.25.1-1/git/cache-tree.c
--- 1.2.1+git2.18.0-1/git/cache-tree.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/cache-tree.c	2020-02-17 04:47:35.000000000 +0000
@@ -3,9 +3,12 @@
 #include "tree.h"
 #include "tree-walk.h"
 #include "cache-tree.h"
+#include "object-store.h"
+#include "replace-object.h"
+#include "promisor-remote.h"
 
-#ifndef DEBUG
-#define DEBUG 0
+#ifndef DEBUG_CACHE_TREE
+#define DEBUG_CACHE_TREE 0
 #endif
 
 struct cache_tree *cache_tree(void)
@@ -109,7 +112,7 @@ static int do_invalidate_path(struct cac
 	int namelen;
 	struct cache_tree_sub *down;
 
-#if DEBUG
+#if DEBUG_CACHE_TREE
 	fprintf(stderr, "cache-tree invalidate <%s>\n", path);
 #endif
 
@@ -223,7 +226,7 @@ int cache_tree_fully_valid(struct cache_
 	int i;
 	if (!it)
 		return 0;
-	if (it->entry_count < 0 || !has_sha1_file(it->oid.hash))
+	if (it->entry_count < 0 || !has_object_file(&it->oid))
 		return 0;
 	for (i = 0; i < it->subtree_nr; i++) {
 		if (!cache_tree_fully_valid(it->down[i]->cache_tree))
@@ -251,7 +254,7 @@ static int update_one(struct cache_tree
 
 	*skip_count = 0;
 
-	if (0 <= it->entry_count && has_sha1_file(it->oid.hash))
+	if (0 <= it->entry_count && has_object_file(&it->oid))
 		return it->entry_count;
 
 	/*
@@ -324,6 +327,7 @@ static int update_one(struct cache_tree
 		unsigned mode;
 		int expected_missing = 0;
 		int contains_ita = 0;
+		int ce_missing_ok;
 
 		path = ce->name;
 		pathlen = ce_namelen(ce);
@@ -353,8 +357,11 @@ static int update_one(struct cache_tree
 			i++;
 		}
 
+		ce_missing_ok = mode == S_IFGITLINK || missing_ok ||
+			(has_promisor_remote() &&
+			 ce_skip_worktree(ce));
 		if (is_null_oid(oid) ||
-		    (mode != S_IFGITLINK && !missing_ok && !has_object_file(oid))) {
+		    (!ce_missing_ok && !has_object_file(oid))) {
 			strbuf_release(&buffer);
 			if (expected_missing)
 				return -1;
@@ -392,7 +399,7 @@ static int update_one(struct cache_tree
 		strbuf_addf(&buffer, "%o %.*s%c", mode, entlen, path + baselen, '\0');
 		strbuf_add(&buffer, oid->hash, the_hash_algo->rawsz);
 
-#if DEBUG
+#if DEBUG_CACHE_TREE
 		fprintf(stderr, "cache-tree update-one %o %.*s\n",
 			mode, entlen, path + baselen);
 #endif
@@ -401,7 +408,7 @@ static int update_one(struct cache_tree
 	if (repair) {
 		struct object_id oid;
 		hash_object_file(buffer.buf, buffer.len, tree_type, &oid);
-		if (has_object_file(&oid))
+		if (has_object_file_with_flags(&oid, OBJECT_INFO_SKIP_FETCH_OBJECT))
 			oidcpy(&it->oid, &oid);
 		else
 			to_invalidate = 1;
@@ -415,7 +422,7 @@ static int update_one(struct cache_tree
 
 	strbuf_release(&buffer);
 	it->entry_count = to_invalidate ? -1 : i - *skip_count;
-#if DEBUG
+#if DEBUG_CACHE_TREE
 	fprintf(stderr, "cache-tree update-one (%d ent, %d subtree) %s\n",
 		it->entry_count, it->subtree_nr,
 		oid_to_hex(&it->oid));
@@ -432,7 +439,9 @@ int cache_tree_update(struct index_state
 
 	if (i)
 		return i;
+	trace_performance_enter();
 	i = update_one(it, cache, entries, "", 0, &skip, flags);
+	trace_performance_leave("cache_tree_update");
 	if (i < 0)
 		return i;
 	istate->cache_changed |= CACHE_TREE_CHANGED;
@@ -440,7 +449,7 @@ int cache_tree_update(struct index_state
 }
 
 static void write_one(struct strbuf *buffer, struct cache_tree *it,
-                      const char *path, int pathlen)
+		      const char *path, int pathlen)
 {
 	int i;
 
@@ -454,7 +463,7 @@ static void write_one(struct strbuf *buf
 	strbuf_add(buffer, path, pathlen);
 	strbuf_addf(buffer, "%c%d %d\n", 0, it->entry_count, it->subtree_nr);
 
-#if DEBUG
+#if DEBUG_CACHE_TREE
 	if (0 <= it->entry_count)
 		fprintf(stderr, "cache-tree <%.*s> (%d ent, %d subtree) %s\n",
 			pathlen, path, it->entry_count, it->subtree_nr,
@@ -528,7 +537,7 @@ static struct cache_tree *read_one(const
 		size -= rawsz;
 	}
 
-#if DEBUG
+#if DEBUG_CACHE_TREE
 	if (0 <= it->entry_count)
 		fprintf(stderr, "cache-tree <%s> (%d ent, %d subtree) %s\n",
 			*buffer, it->entry_count, subtree_nr,
@@ -600,11 +609,66 @@ static struct cache_tree *cache_tree_fin
 	return it;
 }
 
+static int write_index_as_tree_internal(struct object_id *oid,
+					struct index_state *index_state,
+					int cache_tree_valid,
+					int flags,
+					const char *prefix)
+{
+	if (flags & WRITE_TREE_IGNORE_CACHE_TREE) {
+		cache_tree_free(&index_state->cache_tree);
+		cache_tree_valid = 0;
+	}
+
+	if (!index_state->cache_tree)
+		index_state->cache_tree = cache_tree();
+
+	if (!cache_tree_valid && cache_tree_update(index_state, flags) < 0)
+		return WRITE_TREE_UNMERGED_INDEX;
+
+	if (prefix) {
+		struct cache_tree *subtree;
+		subtree = cache_tree_find(index_state->cache_tree, prefix);
+		if (!subtree)
+			return WRITE_TREE_PREFIX_ERROR;
+		oidcpy(oid, &subtree->oid);
+	}
+	else
+		oidcpy(oid, &index_state->cache_tree->oid);
+
+	return 0;
+}
+
+struct tree* write_in_core_index_as_tree(struct repository *repo) {
+	struct object_id o;
+	int was_valid, ret;
+
+	struct index_state *index_state	= repo->index;
+	was_valid = index_state->cache_tree &&
+		    cache_tree_fully_valid(index_state->cache_tree);
+
+	ret = write_index_as_tree_internal(&o, index_state, was_valid, 0, NULL);
+	if (ret == WRITE_TREE_UNMERGED_INDEX) {
+		int i;
+		fprintf(stderr, "BUG: There are unmerged index entries:\n");
+		for (i = 0; i < index_state->cache_nr; i++) {
+			const struct cache_entry *ce = index_state->cache[i];
+			if (ce_stage(ce))
+				fprintf(stderr, "BUG: %d %.*s\n", ce_stage(ce),
+					(int)ce_namelen(ce), ce->name);
+		}
+		BUG("unmerged index entries when writing inmemory index");
+	}
+
+	return lookup_tree(repo, &index_state->cache_tree->oid);
+}
+
+
 int write_index_as_tree(struct object_id *oid, struct index_state *index_state, const char *index_path, int flags, const char *prefix)
 {
 	int entries, was_valid;
 	struct lock_file lock_file = LOCK_INIT;
-	int ret = 0;
+	int ret;
 
 	hold_lock_file_for_update(&lock_file, index_path, LOCK_DIE_ON_ERROR);
 
@@ -613,18 +677,14 @@ int write_index_as_tree(struct object_id
 		ret = WRITE_TREE_UNREADABLE_INDEX;
 		goto out;
 	}
-	if (flags & WRITE_TREE_IGNORE_CACHE_TREE)
-		cache_tree_free(&index_state->cache_tree);
 
-	if (!index_state->cache_tree)
-		index_state->cache_tree = cache_tree();
-
-	was_valid = cache_tree_fully_valid(index_state->cache_tree);
-	if (!was_valid) {
-		if (cache_tree_update(index_state, flags) < 0) {
-			ret = WRITE_TREE_UNMERGED_INDEX;
-			goto out;
-		}
+	was_valid = !(flags & WRITE_TREE_IGNORE_CACHE_TREE) &&
+		    index_state->cache_tree &&
+		    cache_tree_fully_valid(index_state->cache_tree);
+
+	ret = write_index_as_tree_internal(oid, index_state, was_valid, flags,
+					   prefix);
+	if (!ret && !was_valid) {
 		write_locked_index(index_state, &lock_file, COMMIT_LOCK);
 		/* Not being able to write is fine -- we are only interested
 		 * in updating the cache-tree part, and if the next caller
@@ -634,29 +694,14 @@ int write_index_as_tree(struct object_id
 		 */
 	}
 
-	if (prefix) {
-		struct cache_tree *subtree;
-		subtree = cache_tree_find(index_state->cache_tree, prefix);
-		if (!subtree) {
-			ret = WRITE_TREE_PREFIX_ERROR;
-			goto out;
-		}
-		oidcpy(oid, &subtree->oid);
-	}
-	else
-		oidcpy(oid, &index_state->cache_tree->oid);
-
 out:
 	rollback_lock_file(&lock_file);
 	return ret;
 }
 
-int write_cache_as_tree(struct object_id *oid, int flags, const char *prefix)
-{
-	return write_index_as_tree(oid, &the_index, get_index_file(), flags, prefix);
-}
-
-static void prime_cache_tree_rec(struct cache_tree *it, struct tree *tree)
+static void prime_cache_tree_rec(struct repository *r,
+				 struct cache_tree *it,
+				 struct tree *tree)
 {
 	struct tree_desc desc;
 	struct name_entry entry;
@@ -670,23 +715,25 @@ static void prime_cache_tree_rec(struct
 			cnt++;
 		else {
 			struct cache_tree_sub *sub;
-			struct tree *subtree = lookup_tree(entry.oid);
+			struct tree *subtree = lookup_tree(r, &entry.oid);
 			if (!subtree->object.parsed)
 				parse_tree(subtree);
 			sub = cache_tree_sub(it, entry.path);
 			sub->cache_tree = cache_tree();
-			prime_cache_tree_rec(sub->cache_tree, subtree);
+			prime_cache_tree_rec(r, sub->cache_tree, subtree);
 			cnt += sub->cache_tree->entry_count;
 		}
 	}
 	it->entry_count = cnt;
 }
 
-void prime_cache_tree(struct index_state *istate, struct tree *tree)
+void prime_cache_tree(struct repository *r,
+		      struct index_state *istate,
+		      struct tree *tree)
 {
 	cache_tree_free(&istate->cache_tree);
 	istate->cache_tree = cache_tree();
-	prime_cache_tree_rec(istate->cache_tree, tree);
+	prime_cache_tree_rec(r, istate->cache_tree, tree);
 	istate->cache_changed |= CACHE_TREE_CHANGED;
 }
 
@@ -706,7 +753,7 @@ static struct cache_tree *find_cache_tre
 	if (!info->prev)
 		return root;
 	our_parent = find_cache_tree_from_traversal(root, info->prev);
-	return cache_tree_find(our_parent, info->name.path);
+	return cache_tree_find(our_parent, info->name);
 }
 
 int cache_tree_matches_traversal(struct cache_tree *root,
@@ -717,14 +764,85 @@ int cache_tree_matches_traversal(struct
 
 	it = find_cache_tree_from_traversal(root, info);
 	it = cache_tree_find(it, ent->path);
-	if (it && it->entry_count > 0 && !oidcmp(ent->oid, &it->oid))
+	if (it && it->entry_count > 0 && oideq(&ent->oid, &it->oid))
 		return it->entry_count;
 	return 0;
 }
 
-int update_main_cache_tree(int flags)
+static void verify_one(struct repository *r,
+		       struct index_state *istate,
+		       struct cache_tree *it,
+		       struct strbuf *path)
+{
+	int i, pos, len = path->len;
+	struct strbuf tree_buf = STRBUF_INIT;
+	struct object_id new_oid;
+
+	for (i = 0; i < it->subtree_nr; i++) {
+		strbuf_addf(path, "%s/", it->down[i]->name);
+		verify_one(r, istate, it->down[i]->cache_tree, path);
+		strbuf_setlen(path, len);
+	}
+
+	if (it->entry_count < 0 ||
+	    /* no verification on tests (t7003) that replace trees */
+	    lookup_replace_object(r, &it->oid) != &it->oid)
+		return;
+
+	if (path->len) {
+		pos = index_name_pos(istate, path->buf, path->len);
+		pos = -pos - 1;
+	} else {
+		pos = 0;
+	}
+
+	i = 0;
+	while (i < it->entry_count) {
+		struct cache_entry *ce = istate->cache[pos + i];
+		const char *slash;
+		struct cache_tree_sub *sub = NULL;
+		const struct object_id *oid;
+		const char *name;
+		unsigned mode;
+		int entlen;
+
+		if (ce->ce_flags & (CE_STAGEMASK | CE_INTENT_TO_ADD | CE_REMOVE))
+			BUG("%s with flags 0x%x should not be in cache-tree",
+			    ce->name, ce->ce_flags);
+		name = ce->name + path->len;
+		slash = strchr(name, '/');
+		if (slash) {
+			entlen = slash - name;
+			sub = find_subtree(it, ce->name + path->len, entlen, 0);
+			if (!sub || sub->cache_tree->entry_count < 0)
+				BUG("bad subtree '%.*s'", entlen, name);
+			oid = &sub->cache_tree->oid;
+			mode = S_IFDIR;
+			i += sub->cache_tree->entry_count;
+		} else {
+			oid = &ce->oid;
+			mode = ce->ce_mode;
+			entlen = ce_namelen(ce) - path->len;
+			i++;
+		}
+		strbuf_addf(&tree_buf, "%o %.*s%c", mode, entlen, name, '\0');
+		strbuf_add(&tree_buf, oid->hash, the_hash_algo->rawsz);
+	}
+	hash_object_file(tree_buf.buf, tree_buf.len, tree_type, &new_oid);
+	if (!oideq(&new_oid, &it->oid))
+		BUG("cache-tree for path %.*s does not match. "
+		    "Expected %s got %s", len, path->buf,
+		    oid_to_hex(&new_oid), oid_to_hex(&it->oid));
+	strbuf_setlen(path, len);
+	strbuf_release(&tree_buf);
+}
+
+void cache_tree_verify(struct repository *r, struct index_state *istate)
 {
-	if (!the_index.cache_tree)
-		the_index.cache_tree = cache_tree();
-	return cache_tree_update(&the_index, flags);
+	struct strbuf path = STRBUF_INIT;
+
+	if (!istate->cache_tree)
+		return;
+	verify_one(r, istate, istate->cache_tree, &path);
+	strbuf_release(&path);
 }
diff -pruN 1.2.1+git2.18.0-1/git/cache-tree.h 1.2.3+git2.25.1-1/git/cache-tree.h
--- 1.2.1+git2.18.0-1/git/cache-tree.h	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/cache-tree.h	2020-02-17 04:47:35.000000000 +0000
@@ -32,10 +32,9 @@ struct cache_tree *cache_tree_read(const
 
 int cache_tree_fully_valid(struct cache_tree *);
 int cache_tree_update(struct index_state *, int);
+void cache_tree_verify(struct repository *, struct index_state *);
 
-int update_main_cache_tree(int);
-
-/* bitmasks to write_cache_as_tree flags */
+/* bitmasks to write_index_as_tree flags */
 #define WRITE_TREE_MISSING_OK 1
 #define WRITE_TREE_IGNORE_CACHE_TREE 2
 #define WRITE_TREE_DRY_RUN 4
@@ -47,10 +46,24 @@ int update_main_cache_tree(int);
 #define WRITE_TREE_UNMERGED_INDEX (-2)
 #define WRITE_TREE_PREFIX_ERROR (-3)
 
+struct tree* write_in_core_index_as_tree(struct repository *repo);
 int write_index_as_tree(struct object_id *oid, struct index_state *index_state, const char *index_path, int flags, const char *prefix);
-int write_cache_as_tree(struct object_id *oid, int flags, const char *prefix);
-void prime_cache_tree(struct index_state *, struct tree *);
+void prime_cache_tree(struct repository *, struct index_state *, struct tree *);
+
+int cache_tree_matches_traversal(struct cache_tree *, struct name_entry *ent, struct traverse_info *info);
 
-extern int cache_tree_matches_traversal(struct cache_tree *, struct name_entry *ent, struct traverse_info *info);
+#ifdef USE_THE_INDEX_COMPATIBILITY_MACROS
+static inline int write_cache_as_tree(struct object_id *oid, int flags, const char *prefix)
+{
+	return write_index_as_tree(oid, &the_index, get_index_file(), flags, prefix);
+}
+
+static inline int update_main_cache_tree(int flags)
+{
+	if (!the_index.cache_tree)
+		the_index.cache_tree = cache_tree();
+	return cache_tree_update(&the_index, flags);
+}
+#endif
 
 #endif
diff -pruN 1.2.1+git2.18.0-1/git/checkout.c 1.2.3+git2.25.1-1/git/checkout.c
--- 1.2.1+git2.18.0-1/git/checkout.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/checkout.c	2020-02-17 04:47:35.000000000 +0000
@@ -2,14 +2,20 @@
 #include "remote.h"
 #include "refspec.h"
 #include "checkout.h"
+#include "config.h"
 
 struct tracking_name_data {
 	/* const */ char *src_ref;
 	char *dst_ref;
 	struct object_id *dst_oid;
-	int unique;
+	int num_matches;
+	const char *default_remote;
+	char *default_dst_ref;
+	struct object_id *default_dst_oid;
 };
 
+#define TRACKING_NAME_DATA_INIT { NULL, NULL, NULL, 0, NULL, NULL, NULL }
+
 static int check_tracking_name(struct remote *remote, void *cb_data)
 {
 	struct tracking_name_data *cb = cb_data;
@@ -21,24 +27,45 @@ static int check_tracking_name(struct re
 		free(query.dst);
 		return 0;
 	}
+	cb->num_matches++;
+	if (cb->default_remote && !strcmp(remote->name, cb->default_remote)) {
+		struct object_id *dst = xmalloc(sizeof(*cb->default_dst_oid));
+		cb->default_dst_ref = xstrdup(query.dst);
+		oidcpy(dst, cb->dst_oid);
+		cb->default_dst_oid = dst;
+	}
 	if (cb->dst_ref) {
 		free(query.dst);
-		cb->unique = 0;
 		return 0;
 	}
 	cb->dst_ref = query.dst;
 	return 0;
 }
 
-const char *unique_tracking_name(const char *name, struct object_id *oid)
+const char *unique_tracking_name(const char *name, struct object_id *oid,
+				 int *dwim_remotes_matched)
 {
-	struct tracking_name_data cb_data = { NULL, NULL, NULL, 1 };
+	struct tracking_name_data cb_data = TRACKING_NAME_DATA_INIT;
+	const char *default_remote = NULL;
+	if (!git_config_get_string_const("checkout.defaultremote", &default_remote))
+		cb_data.default_remote = default_remote;
 	cb_data.src_ref = xstrfmt("refs/heads/%s", name);
 	cb_data.dst_oid = oid;
 	for_each_remote(check_tracking_name, &cb_data);
+	if (dwim_remotes_matched)
+		*dwim_remotes_matched = cb_data.num_matches;
 	free(cb_data.src_ref);
-	if (cb_data.unique)
+	free((char *)default_remote);
+	if (cb_data.num_matches == 1) {
+		free(cb_data.default_dst_ref);
+		free(cb_data.default_dst_oid);
 		return cb_data.dst_ref;
+	}
 	free(cb_data.dst_ref);
+	if (cb_data.default_dst_ref) {
+		oidcpy(oid, cb_data.default_dst_oid);
+		free(cb_data.default_dst_oid);
+		return cb_data.default_dst_ref;
+	}
 	return NULL;
 }
diff -pruN 1.2.1+git2.18.0-1/git/checkout.h 1.2.3+git2.25.1-1/git/checkout.h
--- 1.2.1+git2.18.0-1/git/checkout.h	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/checkout.h	2020-02-17 04:47:35.000000000 +0000
@@ -8,6 +8,8 @@
  * tracking branch.  Return the name of the remote if such a branch
  * exists, NULL otherwise.
  */
-extern const char *unique_tracking_name(const char *name, struct object_id *oid);
+const char *unique_tracking_name(const char *name,
+				 struct object_id *oid,
+				 int *dwim_remotes_matched);
 
 #endif /* CHECKOUT_H */
diff -pruN 1.2.1+git2.18.0-1/git/check-racy.c 1.2.3+git2.25.1-1/git/check-racy.c
--- 1.2.1+git2.18.0-1/git/check-racy.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/check-racy.c	1970-01-01 00:00:00.000000000 +0000
@@ -1,28 +0,0 @@
-#include "cache.h"
-
-int main(int ac, char **av)
-{
-	int i;
-	int dirty, clean, racy;
-
-	dirty = clean = racy = 0;
-	read_cache();
-	for (i = 0; i < active_nr; i++) {
-		struct cache_entry *ce = active_cache[i];
-		struct stat st;
-
-		if (lstat(ce->name, &st)) {
-			error_errno("lstat(%s)", ce->name);
-			continue;
-		}
-
-		if (ce_match_stat(ce, &st, 0))
-			dirty++;
-		else if (ce_match_stat(ce, &st, CE_MATCH_RACY_IS_DIRTY))
-			racy++;
-		else
-			clean++;
-	}
-	printf("dirty %d, clean %d, racy %d\n", dirty, clean, racy);
-	return 0;
-}
diff -pruN 1.2.1+git2.18.0-1/git/ci/install-dependencies.sh 1.2.3+git2.25.1-1/git/ci/install-dependencies.sh
--- 1.2.1+git2.18.0-1/git/ci/install-dependencies.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/ci/install-dependencies.sh	2020-02-17 04:47:35.000000000 +0000
@@ -3,13 +3,22 @@
 # Install dependencies required to build and test Git on Linux and macOS
 #
 
-. ${0%/*}/lib-travisci.sh
+. ${0%/*}/lib.sh
 
 P4WHENCE=http://filehost.perforce.com/perforce/r$LINUX_P4_VERSION
 LFSWHENCE=https://github.com/github/git-lfs/releases/download/v$LINUX_GIT_LFS_VERSION
 
 case "$jobname" in
 linux-clang|linux-gcc)
+	sudo apt-add-repository -y "ppa:ubuntu-toolchain-r/test"
+	sudo apt-get -q update
+	sudo apt-get -q -y install language-pack-is libsvn-perl apache2
+	case "$jobname" in
+	linux-gcc)
+		sudo apt-get -q -y install gcc-8
+		;;
+	esac
+
 	mkdir --parents "$P4_PATH"
 	pushd "$P4_PATH"
 		wget --quiet "$P4WHENCE/bin.linux26x86_64/p4d"
@@ -25,18 +34,51 @@ linux-clang|linux-gcc)
 	popd
 	;;
 osx-clang|osx-gcc)
-	brew update --quiet
+	export HOMEBREW_NO_AUTO_UPDATE=1 HOMEBREW_NO_INSTALL_CLEANUP=1
 	# Uncomment this if you want to run perf tests:
 	# brew install gnu-time
-	brew install git-lfs gettext
+	test -z "$BREW_INSTALL_PACKAGES" ||
+	brew install $BREW_INSTALL_PACKAGES
 	brew link --force gettext
+	brew cask install perforce || {
+		# Update the definitions and try again
+		cask_repo="$(brew --repository)"/Library/Taps/homebrew/homebrew-cask &&
+		git -C "$cask_repo" pull --no-stat &&
+		brew cask install perforce
+	} ||
 	brew install caskroom/cask/perforce
+	case "$jobname" in
+	osx-gcc)
+		brew install gcc@9
+		# Just in case the image is updated to contain gcc@9
+		# pre-installed but not linked.
+		brew link gcc@9
+		;;
+	esac
+	;;
+StaticAnalysis)
+	sudo apt-get -q update
+	sudo apt-get -q -y install coccinelle libcurl4-openssl-dev libssl-dev \
+		libexpat-dev gettext
+	;;
+Documentation)
+	sudo apt-get -q update
+	sudo apt-get -q -y install asciidoc xmlto docbook-xsl-ns
+
+	test -n "$ALREADY_HAVE_ASCIIDOCTOR" ||
+	gem install --version 1.5.8 asciidoctor
 	;;
 esac
 
-echo "$(tput setaf 6)Perforce Server Version$(tput sgr0)"
-p4d -V | grep Rev.
-echo "$(tput setaf 6)Perforce Client Version$(tput sgr0)"
-p4 -V | grep Rev.
-echo "$(tput setaf 6)Git-LFS Version$(tput sgr0)"
-git-lfs version
+if type p4d >/dev/null && type p4 >/dev/null
+then
+	echo "$(tput setaf 6)Perforce Server Version$(tput sgr0)"
+	p4d -V | grep Rev.
+	echo "$(tput setaf 6)Perforce Client Version$(tput sgr0)"
+	p4 -V | grep Rev.
+fi
+if type git-lfs >/dev/null
+then
+	echo "$(tput setaf 6)Git-LFS Version$(tput sgr0)"
+	git-lfs version
+fi
diff -pruN 1.2.1+git2.18.0-1/git/ci/lib.sh 1.2.3+git2.25.1-1/git/ci/lib.sh
--- 1.2.1+git2.18.0-1/git/ci/lib.sh	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/ci/lib.sh	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,197 @@
+# Library of functions shared by all CI scripts
+
+skip_branch_tip_with_tag () {
+	# Sometimes, a branch is pushed at the same time the tag that points
+	# at the same commit as the tip of the branch is pushed, and building
+	# both at the same time is a waste.
+	#
+	# When the build is triggered by a push to a tag, $CI_BRANCH will
+	# have that tagname, e.g. v2.14.0.  Let's see if $CI_BRANCH is
+	# exactly at a tag, and if so, if it is different from $CI_BRANCH.
+	# That way, we can tell if we are building the tip of a branch that
+	# is tagged and we can skip the build because we won't be skipping a
+	# build of a tag.
+
+	if TAG=$(git describe --exact-match "$CI_BRANCH" 2>/dev/null) &&
+		test "$TAG" != "$CI_BRANCH"
+	then
+		echo "$(tput setaf 2)Tip of $CI_BRANCH is exactly at $TAG$(tput sgr0)"
+		exit 0
+	fi
+}
+
+# Save some info about the current commit's tree, so we can skip the build
+# job if we encounter the same tree again and can provide a useful info
+# message.
+save_good_tree () {
+	echo "$(git rev-parse $CI_COMMIT^{tree}) $CI_COMMIT $CI_JOB_NUMBER $CI_JOB_ID" >>"$good_trees_file"
+	# limit the file size
+	tail -1000 "$good_trees_file" >"$good_trees_file".tmp
+	mv "$good_trees_file".tmp "$good_trees_file"
+}
+
+# Skip the build job if the same tree has already been built and tested
+# successfully before (e.g. because the branch got rebased, changing only
+# the commit messages).
+skip_good_tree () {
+	if test "$TRAVIS_DEBUG_MODE" = true
+	then
+		return
+	fi
+
+	if ! good_tree_info="$(grep "^$(git rev-parse $CI_COMMIT^{tree}) " "$good_trees_file")"
+	then
+		# Haven't seen this tree yet, or no cached good trees file yet.
+		# Continue the build job.
+		return
+	fi
+
+	echo "$good_tree_info" | {
+		read tree prev_good_commit prev_good_job_number prev_good_job_id
+
+		if test "$CI_JOB_ID" = "$prev_good_job_id"
+		then
+			cat <<-EOF
+			$(tput setaf 2)Skipping build job for commit $CI_COMMIT.$(tput sgr0)
+			This commit has already been built and tested successfully by this build job.
+			To force a re-build delete the branch's cache and then hit 'Restart job'.
+			EOF
+		else
+			cat <<-EOF
+			$(tput setaf 2)Skipping build job for commit $CI_COMMIT.$(tput sgr0)
+			This commit's tree has already been built and tested successfully in build job $prev_good_job_number for commit $prev_good_commit.
+			The log of that build job is available at $(url_for_job_id $prev_good_job_id)
+			To force a re-build delete the branch's cache and then hit 'Restart job'.
+			EOF
+		fi
+	}
+
+	exit 0
+}
+
+check_unignored_build_artifacts ()
+{
+	! git ls-files --other --exclude-standard --error-unmatch \
+		-- ':/*' 2>/dev/null ||
+	{
+		echo "$(tput setaf 1)error: found unignored build artifacts$(tput sgr0)"
+		false
+	}
+}
+
+# Clear MAKEFLAGS that may come from the outside world.
+export MAKEFLAGS=
+
+# Set 'exit on error' for all CI scripts to let the caller know that
+# something went wrong.
+# Set tracing executed commands, primarily setting environment variables
+# and installing dependencies.
+set -ex
+
+if test true = "$TRAVIS"
+then
+	CI_TYPE=travis
+	# When building a PR, TRAVIS_BRANCH refers to the *target* branch. Not
+	# what we want here. We want the source branch instead.
+	CI_BRANCH="${TRAVIS_PULL_REQUEST_BRANCH:-$TRAVIS_BRANCH}"
+	CI_COMMIT="$TRAVIS_COMMIT"
+	CI_JOB_ID="$TRAVIS_JOB_ID"
+	CI_JOB_NUMBER="$TRAVIS_JOB_NUMBER"
+	CI_OS_NAME="$TRAVIS_OS_NAME"
+	CI_REPO_SLUG="$TRAVIS_REPO_SLUG"
+
+	cache_dir="$HOME/travis-cache"
+
+	url_for_job_id () {
+		echo "https://travis-ci.org/$CI_REPO_SLUG/jobs/$1"
+	}
+
+	BREW_INSTALL_PACKAGES="git-lfs gettext"
+	export GIT_PROVE_OPTS="--timer --jobs 3 --state=failed,slow,save"
+	export GIT_TEST_OPTS="--verbose-log -x --immediate"
+	MAKEFLAGS="$MAKEFLAGS --jobs=2"
+elif test -n "$SYSTEM_COLLECTIONURI" || test -n "$SYSTEM_TASKDEFINITIONSURI"
+then
+	CI_TYPE=azure-pipelines
+	# We are running in Azure Pipelines
+	CI_BRANCH="$BUILD_SOURCEBRANCH"
+	CI_COMMIT="$BUILD_SOURCEVERSION"
+	CI_JOB_ID="$BUILD_BUILDID"
+	CI_JOB_NUMBER="$BUILD_BUILDNUMBER"
+	CI_OS_NAME="$(echo "$AGENT_OS" | tr A-Z a-z)"
+	test darwin != "$CI_OS_NAME" || CI_OS_NAME=osx
+	CI_REPO_SLUG="$(expr "$BUILD_REPOSITORY_URI" : '.*/\([^/]*/[^/]*\)$')"
+	CC="${CC:-gcc}"
+
+	# use a subdirectory of the cache dir (because the file share is shared
+	# among *all* phases)
+	cache_dir="$HOME/test-cache/$SYSTEM_PHASENAME"
+
+	url_for_job_id () {
+		echo "$SYSTEM_TASKDEFINITIONSURI$SYSTEM_TEAMPROJECT/_build/results?buildId=$1"
+	}
+
+	export GIT_PROVE_OPTS="--timer --jobs 10 --state=failed,slow,save"
+	export GIT_TEST_OPTS="--verbose-log -x --write-junit-xml"
+	MAKEFLAGS="$MAKEFLAGS --jobs=10"
+	test windows_nt != "$CI_OS_NAME" ||
+	GIT_TEST_OPTS="--no-chain-lint --no-bin-wrappers $GIT_TEST_OPTS"
+else
+	echo "Could not identify CI type" >&2
+	exit 1
+fi
+
+good_trees_file="$cache_dir/good-trees"
+
+mkdir -p "$cache_dir"
+
+skip_branch_tip_with_tag
+skip_good_tree
+
+if test -z "$jobname"
+then
+	jobname="$CI_OS_NAME-$CC"
+fi
+
+export DEVELOPER=1
+export DEFAULT_TEST_TARGET=prove
+export GIT_TEST_CLONE_2GB=true
+
+case "$jobname" in
+linux-clang|linux-gcc)
+	if [ "$jobname" = linux-gcc ]
+	then
+		export CC=gcc-8
+	fi
+
+	export GIT_TEST_HTTPD=true
+
+	# The Linux build installs the defined dependency versions below.
+	# The OS X build installs much more recent versions, whichever
+	# were recorded in the Homebrew database upon creating the OS X
+	# image.
+	# Keep that in mind when you encounter a broken OS X build!
+	export LINUX_P4_VERSION="16.2"
+	export LINUX_GIT_LFS_VERSION="1.5.2"
+
+	P4_PATH="$HOME/custom/p4"
+	GIT_LFS_PATH="$HOME/custom/git-lfs"
+	export PATH="$GIT_LFS_PATH:$P4_PATH:$PATH"
+	;;
+osx-clang|osx-gcc)
+	if [ "$jobname" = osx-gcc ]
+	then
+		export CC=gcc-9
+	fi
+
+	# t9810 occasionally fails on Travis CI OS X
+	# t9816 occasionally fails with "TAP out of sequence errors" on
+	# Travis CI OS X
+	export GIT_SKIP_TESTS="t9810 t9816"
+	;;
+GIT_TEST_GETTEXT_POISON)
+	export GIT_TEST_GETTEXT_POISON=true
+	;;
+esac
+
+MAKEFLAGS="$MAKEFLAGS CC=${CC:-cc}"
diff -pruN 1.2.1+git2.18.0-1/git/ci/lib-travisci.sh 1.2.3+git2.25.1-1/git/ci/lib-travisci.sh
--- 1.2.1+git2.18.0-1/git/ci/lib-travisci.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/ci/lib-travisci.sh	1970-01-01 00:00:00.000000000 +0000
@@ -1,129 +0,0 @@
-# Library of functions shared by all CI scripts
-
-skip_branch_tip_with_tag () {
-	# Sometimes, a branch is pushed at the same time the tag that points
-	# at the same commit as the tip of the branch is pushed, and building
-	# both at the same time is a waste.
-	#
-	# Travis gives a tagname e.g. v2.14.0 in $TRAVIS_BRANCH when
-	# the build is triggered by a push to a tag.  Let's see if
-	# $TRAVIS_BRANCH is exactly at a tag, and if so, if it is
-	# different from $TRAVIS_BRANCH.  That way, we can tell if
-	# we are building the tip of a branch that is tagged and
-	# we can skip the build because we won't be skipping a build
-	# of a tag.
-
-	if TAG=$(git describe --exact-match "$TRAVIS_BRANCH" 2>/dev/null) &&
-		test "$TAG" != "$TRAVIS_BRANCH"
-	then
-		echo "$(tput setaf 2)Tip of $TRAVIS_BRANCH is exactly at $TAG$(tput sgr0)"
-		exit 0
-	fi
-}
-
-# Save some info about the current commit's tree, so we can skip the build
-# job if we encounter the same tree again and can provide a useful info
-# message.
-save_good_tree () {
-	echo "$(git rev-parse $TRAVIS_COMMIT^{tree}) $TRAVIS_COMMIT $TRAVIS_JOB_NUMBER $TRAVIS_JOB_ID" >>"$good_trees_file"
-	# limit the file size
-	tail -1000 "$good_trees_file" >"$good_trees_file".tmp
-	mv "$good_trees_file".tmp "$good_trees_file"
-}
-
-# Skip the build job if the same tree has already been built and tested
-# successfully before (e.g. because the branch got rebased, changing only
-# the commit messages).
-skip_good_tree () {
-	if ! good_tree_info="$(grep "^$(git rev-parse $TRAVIS_COMMIT^{tree}) " "$good_trees_file")"
-	then
-		# Haven't seen this tree yet, or no cached good trees file yet.
-		# Continue the build job.
-		return
-	fi
-
-	echo "$good_tree_info" | {
-		read tree prev_good_commit prev_good_job_number prev_good_job_id
-
-		if test "$TRAVIS_JOB_ID" = "$prev_good_job_id"
-		then
-			cat <<-EOF
-			$(tput setaf 2)Skipping build job for commit $TRAVIS_COMMIT.$(tput sgr0)
-			This commit has already been built and tested successfully by this build job.
-			To force a re-build delete the branch's cache and then hit 'Restart job'.
-			EOF
-		else
-			cat <<-EOF
-			$(tput setaf 2)Skipping build job for commit $TRAVIS_COMMIT.$(tput sgr0)
-			This commit's tree has already been built and tested successfully in build job $prev_good_job_number for commit $prev_good_commit.
-			The log of that build job is available at https://travis-ci.org/$TRAVIS_REPO_SLUG/jobs/$prev_good_job_id
-			To force a re-build delete the branch's cache and then hit 'Restart job'.
-			EOF
-		fi
-	}
-
-	exit 0
-}
-
-check_unignored_build_artifacts ()
-{
-	! git ls-files --other --exclude-standard --error-unmatch \
-		-- ':/*' 2>/dev/null ||
-	{
-		echo "$(tput setaf 1)error: found unignored build artifacts$(tput sgr0)"
-		false
-	}
-}
-
-# Set 'exit on error' for all CI scripts to let the caller know that
-# something went wrong.
-# Set tracing executed commands, primarily setting environment variables
-# and installing dependencies.
-set -ex
-
-cache_dir="$HOME/travis-cache"
-good_trees_file="$cache_dir/good-trees"
-
-mkdir -p "$cache_dir"
-
-skip_branch_tip_with_tag
-skip_good_tree
-
-if test -z "$jobname"
-then
-	jobname="$TRAVIS_OS_NAME-$CC"
-fi
-
-export DEVELOPER=1
-export DEFAULT_TEST_TARGET=prove
-export GIT_PROVE_OPTS="--timer --jobs 3 --state=failed,slow,save"
-export GIT_TEST_OPTS="--verbose-log -x"
-export GIT_TEST_CLONE_2GB=YesPlease
-if [ "$jobname" = linux-gcc ]; then
-	export CC=gcc-8
-fi
-
-case "$jobname" in
-linux-clang|linux-gcc)
-	export GIT_TEST_HTTPD=YesPlease
-
-	# The Linux build installs the defined dependency versions below.
-	# The OS X build installs the latest available versions. Keep that
-	# in mind when you encounter a broken OS X build!
-	export LINUX_P4_VERSION="16.2"
-	export LINUX_GIT_LFS_VERSION="1.5.2"
-
-	P4_PATH="$HOME/custom/p4"
-	GIT_LFS_PATH="$HOME/custom/git-lfs"
-	export PATH="$GIT_LFS_PATH:$P4_PATH:$PATH"
-	;;
-osx-clang|osx-gcc)
-	# t9810 occasionally fails on Travis CI OS X
-	# t9816 occasionally fails with "TAP out of sequence errors" on
-	# Travis CI OS X
-	export GIT_SKIP_TESTS="t9810 t9816"
-	;;
-GETTEXT_POISON)
-	export GETTEXT_POISON=YesPlease
-	;;
-esac
diff -pruN 1.2.1+git2.18.0-1/git/ci/make-test-artifacts.sh 1.2.3+git2.25.1-1/git/ci/make-test-artifacts.sh
--- 1.2.1+git2.18.0-1/git/ci/make-test-artifacts.sh	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/ci/make-test-artifacts.sh	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,12 @@
+#!/bin/sh
+#
+# Build Git and store artifacts for testing
+#
+
+mkdir -p "$1" # in case ci/lib.sh decides to quit early
+
+. ${0%/*}/lib.sh
+
+make artifacts-tar ARTIFACTS_DIRECTORY="$1"
+
+check_unignored_build_artifacts
diff -pruN 1.2.1+git2.18.0-1/git/ci/mount-fileshare.sh 1.2.3+git2.25.1-1/git/ci/mount-fileshare.sh
--- 1.2.1+git2.18.0-1/git/ci/mount-fileshare.sh	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/ci/mount-fileshare.sh	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,25 @@
+#!/bin/sh
+
+die () {
+	echo "$*" >&2
+	exit 1
+}
+
+test $# = 4 ||
+die "Usage: $0 <share> <username> <password> <mountpoint>"
+
+mkdir -p "$4" || die "Could not create $4"
+
+case "$(uname -s)" in
+Linux)
+	sudo mount -t cifs -o vers=3.0,username="$2",password="$3",dir_mode=0777,file_mode=0777,serverino "$1" "$4"
+	;;
+Darwin)
+	pass="$(echo "$3" | sed -e 's/\//%2F/g' -e 's/+/%2B/g')" &&
+	mount -t smbfs,soft "smb://$2:$pass@${1#//}" "$4"
+	;;
+*)
+	die "No support for $(uname -s)"
+	;;
+esac ||
+die "Could not mount $4"
diff -pruN 1.2.1+git2.18.0-1/git/ci/print-test-failures.sh 1.2.3+git2.25.1-1/git/ci/print-test-failures.sh
--- 1.2.1+git2.18.0-1/git/ci/print-test-failures.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/ci/print-test-failures.sh	2020-02-17 04:47:35.000000000 +0000
@@ -3,18 +3,29 @@
 # Print output of failing tests
 #
 
-. ${0%/*}/lib-travisci.sh
+. ${0%/*}/lib.sh
 
 # Tracing executed commands would produce too much noise in the loop below.
 set +x
 
-if ! ls t/test-results/*.exit >/dev/null 2>/dev/null
+cd t/
+
+if ! ls test-results/*.exit >/dev/null 2>/dev/null
 then
 	echo "Build job failed before the tests could have been run"
 	exit
 fi
 
-for TEST_EXIT in t/test-results/*.exit
+case "$jobname" in
+osx-clang|osx-gcc)
+	# base64 in OSX doesn't wrap its output at 76 columns by
+	# default, but prints a single, very long line.
+	base64_opts="-b 76"
+	;;
+esac
+
+combined_trash_size=0
+for TEST_EXIT in test-results/*.exit
 do
 	if [ "$(cat "$TEST_EXIT")" != "0" ]
 	then
@@ -23,5 +34,58 @@ do
 		echo "$(tput setaf 1)${TEST_OUT}...$(tput sgr0)"
 		echo "------------------------------------------------------------------------"
 		cat "${TEST_OUT}"
+
+		test_name="${TEST_EXIT%.exit}"
+		test_name="${test_name##*/}"
+		trash_dir="trash directory.$test_name"
+		case "$CI_TYPE" in
+		travis)
+			;;
+		azure-pipelines)
+			mkdir -p failed-test-artifacts
+			mv "$trash_dir" failed-test-artifacts
+			continue
+			;;
+		*)
+			echo "Unhandled CI type: $CI_TYPE" >&2
+			exit 1
+			;;
+		esac
+		trash_tgz_b64="trash.$test_name.base64"
+		if [ -d "$trash_dir" ]
+		then
+			tar czp "$trash_dir" |base64 $base64_opts >"$trash_tgz_b64"
+
+			trash_size=$(wc -c <"$trash_tgz_b64")
+			if [ $trash_size -gt 1048576 ]
+			then
+				# larger than 1MB
+				echo "$(tput setaf 1)Didn't include the trash directory of '$test_name' in the trace log, it's too big$(tput sgr0)"
+				continue
+			fi
+
+			new_combined_trash_size=$(($combined_trash_size + $trash_size))
+			if [ $new_combined_trash_size -gt 1048576 ]
+			then
+				echo "$(tput setaf 1)Didn't include the trash directory of '$test_name' in the trace log, there is plenty of trash in there already.$(tput sgr0)"
+				continue
+			fi
+			combined_trash_size=$new_combined_trash_size
+
+			# DO NOT modify these two 'echo'-ed strings below
+			# without updating 'ci/util/extract-trash-dirs.sh'
+			# as well.
+			echo "$(tput setaf 1)Start of trash directory of '$test_name':$(tput sgr0)"
+			cat "$trash_tgz_b64"
+			echo "$(tput setaf 1)End of trash directory of '$test_name'$(tput sgr0)"
+		fi
 	fi
 done
+
+if [ $combined_trash_size -gt 0 ]
+then
+	echo "------------------------------------------------------------------------"
+	echo "Trash directories embedded in this log can be extracted by running:"
+	echo
+	echo "  curl https://api.travis-ci.org/v3/job/$TRAVIS_JOB_ID/log.txt |./ci/util/extract-trash-dirs.sh"
+fi
diff -pruN 1.2.1+git2.18.0-1/git/ci/run-build-and-tests.sh 1.2.3+git2.25.1-1/git/ci/run-build-and-tests.sh
--- 1.2.1+git2.18.0-1/git/ci/run-build-and-tests.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/ci/run-build-and-tests.sh	2020-02-17 04:47:35.000000000 +0000
@@ -3,19 +3,34 @@
 # Build and test Git
 #
 
-. ${0%/*}/lib-travisci.sh
+. ${0%/*}/lib.sh
 
-ln -s "$cache_dir/.prove" t/.prove
+case "$CI_OS_NAME" in
+windows*) cmd //c mklink //j t\\.prove "$(cygpath -aw "$cache_dir/.prove")";;
+*) ln -s "$cache_dir/.prove" t/.prove;;
+esac
 
-make --jobs=2
-make --quiet test
-if test "$jobname" = "linux-gcc"
-then
+make
+case "$jobname" in
+linux-gcc)
+	make test
 	export GIT_TEST_SPLIT_INDEX=yes
 	export GIT_TEST_FULL_IN_PACK_ARRAY=true
 	export GIT_TEST_OE_SIZE=10
-	make --quiet test
-fi
+	export GIT_TEST_OE_DELTA_SIZE=5
+	export GIT_TEST_COMMIT_GRAPH=1
+	export GIT_TEST_MULTI_PACK_INDEX=1
+	make test
+	;;
+linux-gcc-4.8)
+	# Don't run the tests; we only care about whether Git can be
+	# built with GCC 4.8, as it errors out on some undesired (C99)
+	# constructs that newer compilers seem to quietly accept.
+	;;
+*)
+	make test
+	;;
+esac
 
 check_unignored_build_artifacts
 
diff -pruN 1.2.1+git2.18.0-1/git/ci/run-linux32-build.sh 1.2.3+git2.25.1-1/git/ci/run-linux32-build.sh
--- 1.2.1+git2.18.0-1/git/ci/run-linux32-build.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/ci/run-linux32-build.sh	2020-02-17 04:47:35.000000000 +0000
@@ -55,6 +55,6 @@ linux32 --32bit i386 su -m -l $CI_USER -
 	set -ex
 	cd /usr/src/git
 	test -n "$cache_dir" && ln -s "$cache_dir/.prove" t/.prove
-	make --jobs=2
-	make --quiet test
+	make
+	make test
 '
diff -pruN 1.2.1+git2.18.0-1/git/ci/run-linux32-docker.sh 1.2.3+git2.25.1-1/git/ci/run-linux32-docker.sh
--- 1.2.1+git2.18.0-1/git/ci/run-linux32-docker.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/ci/run-linux32-docker.sh	2020-02-17 04:47:35.000000000 +0000
@@ -3,7 +3,7 @@
 # Download and run Docker image to build and test 32-bit Git
 #
 
-. ${0%/*}/lib-travisci.sh
+. ${0%/*}/lib.sh
 
 docker pull daald/ubuntu32:xenial
 
diff -pruN 1.2.1+git2.18.0-1/git/ci/run-static-analysis.sh 1.2.3+git2.25.1-1/git/ci/run-static-analysis.sh
--- 1.2.1+git2.18.0-1/git/ci/run-static-analysis.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/ci/run-static-analysis.sh	2020-02-17 04:47:35.000000000 +0000
@@ -3,8 +3,30 @@
 # Perform various static code analysis checks
 #
 
-. ${0%/*}/lib-travisci.sh
+. ${0%/*}/lib.sh
 
 make coccicheck
 
+set +x
+
+fail=
+for cocci_patch in contrib/coccinelle/*.patch
+do
+	if test -s "$cocci_patch"
+	then
+		echo "$(tput setaf 1)Coccinelle suggests the following changes in '$cocci_patch':$(tput sgr0)"
+		cat "$cocci_patch"
+		fail=UnfortunatelyYes
+	fi
+done
+
+if test -n "$fail"
+then
+	echo "$(tput setaf 1)error: Coccinelle suggested some changes$(tput sgr0)"
+	exit 1
+fi
+
+make hdr-check ||
+exit 1
+
 save_good_tree
diff -pruN 1.2.1+git2.18.0-1/git/ci/run-test-slice.sh 1.2.3+git2.25.1-1/git/ci/run-test-slice.sh
--- 1.2.1+git2.18.0-1/git/ci/run-test-slice.sh	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/ci/run-test-slice.sh	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,17 @@
+#!/bin/sh
+#
+# Test Git in parallel
+#
+
+. ${0%/*}/lib.sh
+
+case "$CI_OS_NAME" in
+windows*) cmd //c mklink //j t\\.prove "$(cygpath -aw "$cache_dir/.prove")";;
+*) ln -s "$cache_dir/.prove" t/.prove;;
+esac
+
+make --quiet -C t T="$(cd t &&
+	./helper/test-tool path-utils slice-tests "$1" "$2" t[0-9]*.sh |
+	tr '\n' ' ')"
+
+check_unignored_build_artifacts
diff -pruN 1.2.1+git2.18.0-1/git/ci/run-windows-build.sh 1.2.3+git2.25.1-1/git/ci/run-windows-build.sh
--- 1.2.1+git2.18.0-1/git/ci/run-windows-build.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/ci/run-windows-build.sh	1970-01-01 00:00:00.000000000 +0000
@@ -1,103 +0,0 @@
-#!/usr/bin/env bash
-#
-# Script to trigger the Git for Windows build and test run.
-# Set the $GFW_CI_TOKEN as environment variable.
-# Pass the branch (only branches on https://github.com/git/git are
-# supported) and a commit hash.
-#
-
-. ${0%/*}/lib-travisci.sh
-
-test $# -ne 2 && echo "Unexpected number of parameters" && exit 1
-test -z "$GFW_CI_TOKEN" && echo "GFW_CI_TOKEN not defined" && exit
-
-BRANCH=$1
-COMMIT=$2
-
-gfwci () {
-	local CURL_ERROR_CODE HTTP_CODE
-	CONTENT_FILE=$(mktemp -t "git-windows-ci-XXXXXX")
-	while test -z $HTTP_CODE
-	do
-	HTTP_CODE=$(curl \
-		-H "Authentication: Bearer $GFW_CI_TOKEN" \
-		--silent --retry 5 --write-out '%{HTTP_CODE}' \
-		--output >(sed "$(printf '1s/^\xef\xbb\xbf//')" >$CONTENT_FILE) \
-		"https://git-for-windows-ci.azurewebsites.net/api/TestNow?$1" \
-	)
-	CURL_ERROR_CODE=$?
-		# The GfW CI web app sometimes returns HTTP errors of
-		# "502 bad gateway" or "503 service unavailable".
-		# We also need to check the HTTP content because the GfW web
-		# app seems to pass through (error) results from other Azure
-		# calls with HTTP code 200.
-		# Wait a little and retry if we detect this error. More info:
-		# https://docs.microsoft.com/en-in/azure/app-service-web/app-service-web-troubleshoot-http-502-http-503
-		if test $HTTP_CODE -eq 502 ||
-		   test $HTTP_CODE -eq 503 ||
-		   grep "502 - Web server received an invalid response" $CONTENT_FILE >/dev/null
-		then
-			sleep 10
-			HTTP_CODE=
-		fi
-	done
-	cat $CONTENT_FILE
-	rm $CONTENT_FILE
-	if test $CURL_ERROR_CODE -ne 0
-	then
-		return $CURL_ERROR_CODE
-	fi
-	if test "$HTTP_CODE" -ge 400 && test "$HTTP_CODE" -lt 600
-	then
-		return 127
-	fi
-}
-
-# Trigger build job
-BUILD_ID=$(gfwci "action=trigger&branch=$BRANCH&commit=$COMMIT&skipTests=false")
-if test $? -ne 0
-then
-	echo "Unable to trigger Visual Studio Team Services Build"
-	echo "$BUILD_ID"
-	exit 1
-fi
-
-# Check if the $BUILD_ID contains a number
-case $BUILD_ID in
-''|*[!0-9]*) echo "Unexpected build number: $BUILD_ID" && exit 1
-esac
-
-echo "Visual Studio Team Services Build #${BUILD_ID}"
-
-# Tracing execued commands would produce too much noise in the waiting
-# loop below.
-set +x
-
-# Wait until build job finished
-STATUS=
-RESULT=
-while true
-do
-	LAST_STATUS=$STATUS
-	STATUS=$(gfwci "action=status&buildId=$BUILD_ID")
-	test "$STATUS" = "$LAST_STATUS" || printf "\nStatus: %s " "$STATUS"
-	printf "."
-
-	case "$STATUS" in
-	inProgress|postponed|notStarted) sleep 10               ;; # continue
-		 "completed: succeeded") RESULT="success"; break;; # success
-		    "completed: failed")                   break;; # failure
-	*) echo "Unhandled status: $STATUS";               break;; # unknown
-	esac
-done
-
-# Print log
-echo ""
-echo ""
-set -x
-gfwci "action=log&buildId=$BUILD_ID" | cut -c 30-
-
-# Set exit code for TravisCI
-test "$RESULT" = "success"
-
-save_good_tree
diff -pruN 1.2.1+git2.18.0-1/git/ci/test-documentation.sh 1.2.3+git2.25.1-1/git/ci/test-documentation.sh
--- 1.2.1+git2.18.0-1/git/ci/test-documentation.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/ci/test-documentation.sh	2020-02-17 04:47:35.000000000 +0000
@@ -3,33 +3,43 @@
 # Perform sanity checks on documentation and build it.
 #
 
-. ${0%/*}/lib-travisci.sh
+. ${0%/*}/lib.sh
 
-gem install asciidoctor
+filter_log () {
+	sed -e '/^GIT_VERSION = /d' \
+	    -e "/constant Gem::ConfigMap is deprecated/d" \
+	    -e '/^    \* new asciidoc flags$/d' \
+	    -e '/stripped namespace before processing/d' \
+	    -e '/Attributed.*IDs for element/d' \
+	    "$1"
+}
 
 make check-builtins
 make check-docs
 
 # Build docs with AsciiDoc
-make --jobs=2 doc > >(tee stdout.log) 2> >(tee stderr.log >&2)
-! test -s stderr.log
+make doc > >(tee stdout.log) 2> >(tee stderr.raw >&2)
+cat stderr.raw
+filter_log stderr.raw >stderr.log
+test ! -s stderr.log
 test -s Documentation/git.html
 test -s Documentation/git.xml
 test -s Documentation/git.1
 grep '<meta name="generator" content="AsciiDoc ' Documentation/git.html
 
-rm -f stdout.log stderr.log
+rm -f stdout.log stderr.log stderr.raw
 check_unignored_build_artifacts
 
 # Build docs with AsciiDoctor
 make clean
-make --jobs=2 USE_ASCIIDOCTOR=1 doc > >(tee stdout.log) 2> >(tee stderr.log >&2)
-sed '/^GIT_VERSION = / d' stderr.log
-! test -s stderr.log
+make USE_ASCIIDOCTOR=1 doc > >(tee stdout.log) 2> >(tee stderr.raw >&2)
+cat stderr.raw
+filter_log stderr.raw >stderr.log
+test ! -s stderr.log
 test -s Documentation/git.html
 grep '<meta name="generator" content="Asciidoctor ' Documentation/git.html
 
-rm -f stdout.log stderr.log
+rm -f stdout.log stderr.log stderr.raw
 check_unignored_build_artifacts
 
 save_good_tree
diff -pruN 1.2.1+git2.18.0-1/git/ci/util/extract-trash-dirs.sh 1.2.3+git2.25.1-1/git/ci/util/extract-trash-dirs.sh
--- 1.2.1+git2.18.0-1/git/ci/util/extract-trash-dirs.sh	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/ci/util/extract-trash-dirs.sh	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,50 @@
+#!/bin/sh
+
+error () {
+	echo >&2 "error: $@"
+	exit 1
+}
+
+find_embedded_trash () {
+	while read -r line
+	do
+		case "$line" in
+		*Start\ of\ trash\ directory\ of\ \'t[0-9][0-9][0-9][0-9]-*\':*)
+			test_name="${line#*\'}"
+			test_name="${test_name%\'*}"
+
+			return 0
+		esac
+	done
+
+	return 1
+}
+
+extract_embedded_trash () {
+	while read -r line
+	do
+		case "$line" in
+		*End\ of\ trash\ directory\ of\ \'$test_name\'*)
+			return
+			;;
+		*)
+			printf '%s\n' "$line"
+			;;
+		esac
+	done
+
+	error "unexpected end of input"
+}
+
+# Raw logs from Linux build jobs have CRLF line endings, while OSX
+# build jobs mostly have CRCRLF, except an odd line every now and
+# then that has CRCRCRLF.  'base64 -d' from 'coreutils' doesn't like
+# CRs and complains about "invalid input", so remove all CRs at the
+# end of lines.
+sed -e 's/\r*$//' | \
+while find_embedded_trash
+do
+	echo "Extracting trash directory of '$test_name'"
+
+	extract_embedded_trash |base64 -d |tar xzp
+done
diff -pruN 1.2.1+git2.18.0-1/git/.cirrus.yml 1.2.3+git2.25.1-1/git/.cirrus.yml
--- 1.2.1+git2.18.0-1/git/.cirrus.yml	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/.cirrus.yml	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,15 @@
+env:
+  CIRRUS_CLONE_DEPTH: 1
+
+freebsd_12_task:
+  freebsd_instance:
+    image: freebsd-12-1-release-amd64
+  install_script:
+    pkg install -y gettext gmake perl5
+  create_user_script:
+    - pw useradd git
+    - chown -R git:git .
+  build_script:
+    - su git -c gmake
+  test_script:
+    - su git -c 'gmake test'
diff -pruN 1.2.1+git2.18.0-1/git/.clang-format 1.2.3+git2.25.1-1/git/.clang-format
--- 1.2.1+git2.18.0-1/git/.clang-format	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/.clang-format	2020-02-17 04:47:35.000000000 +0000
@@ -6,6 +6,8 @@
 
 # Use tabs whenever we need to fill whitespace that spans at least from one tab
 # stop to the next one.
+#
+# These settings are mirrored in .editorconfig.  Keep them in sync.
 UseTab: Always
 TabWidth: 8
 IndentWidth: 8
@@ -146,8 +148,21 @@ SpacesInSquareBrackets: false
 Cpp11BracedListStyle: false
 
 # A list of macros that should be interpreted as foreach loops instead of as
-# function calls.
-ForEachMacros: ['for_each_string_list_item']
+# function calls. Taken from:
+#   git grep -h '^#define [^[:space:]]*for_each[^[:space:]]*(' \
+#   | sed "s,^#define \([^[:space:]]*for_each[^[:space:]]*\)(.*$,  - '\1'," \
+#   | sort | uniq
+ForEachMacros:
+  - 'for_each_abbrev'
+  - 'for_each_builtin'
+  - 'for_each_string_list_item'
+  - 'for_each_ut'
+  - 'for_each_wanted_builtin'
+  - 'list_for_each'
+  - 'list_for_each_dir'
+  - 'list_for_each_prev'
+  - 'list_for_each_prev_safe'
+  - 'list_for_each_safe'
 
 # The maximum number of consecutive empty lines to keep.
 MaxEmptyLinesToKeep: 1
diff -pruN 1.2.1+git2.18.0-1/git/CODE_OF_CONDUCT.md 1.2.3+git2.25.1-1/git/CODE_OF_CONDUCT.md
--- 1.2.1+git2.18.0-1/git/CODE_OF_CONDUCT.md	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/CODE_OF_CONDUCT.md	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,93 @@
+# Git Code of Conduct
+
+This code of conduct outlines our expectations for participants within
+the Git community, as well as steps for reporting unacceptable behavior.
+We are committed to providing a welcoming and inspiring community for
+all and expect our code of conduct to be honored. Anyone who violates
+this code of conduct may be banned from the community.
+
+## Our Pledge
+
+In the interest of fostering an open and welcoming environment, we as
+contributors and maintainers pledge to make participation in our project and
+our community a harassment-free experience for everyone, regardless of age,
+body size, disability, ethnicity, sex characteristics, gender identity and
+expression, level of experience, education, socio-economic status,
+nationality, personal appearance, race, religion, or sexual identity and
+orientation.
+
+## Our Standards
+
+Examples of behavior that contributes to creating a positive environment
+include:
+
+* Using welcoming and inclusive language
+* Being respectful of differing viewpoints and experiences
+* Gracefully accepting constructive criticism
+* Focusing on what is best for the community
+* Showing empathy towards other community members
+
+Examples of unacceptable behavior by participants include:
+
+* The use of sexualized language or imagery and unwelcome sexual attention or
+  advances
+* Trolling, insulting/derogatory comments, and personal or political attacks
+* Public or private harassment
+* Publishing others' private information, such as a physical or electronic
+  address, without explicit permission
+* Other conduct which could reasonably be considered inappropriate in a
+  professional setting
+
+## Our Responsibilities
+
+Project maintainers are responsible for clarifying the standards of acceptable
+behavior and are expected to take appropriate and fair corrective action in
+response to any instances of unacceptable behavior.
+
+Project maintainers have the right and responsibility to remove, edit, or
+reject comments, commits, code, wiki edits, issues, and other contributions
+that are not aligned to this Code of Conduct, or to ban temporarily or
+permanently any contributor for other behaviors that they deem inappropriate,
+threatening, offensive, or harmful.
+
+## Scope
+
+This Code of Conduct applies within all project spaces, and it also applies
+when an individual is representing the project or its community in public
+spaces. Examples of representing a project or community include using an
+official project e-mail address, posting via an official social media account,
+or acting as an appointed representative at an online or offline event.
+Representation of a project may be further defined and clarified by project
+maintainers.
+
+## Enforcement
+
+Instances of abusive, harassing, or otherwise unacceptable behavior may be
+reported by contacting the project team at git@sfconservancy.org. All
+complaints will be reviewed and investigated and will result in a response
+that is deemed necessary and appropriate to the circumstances. The project
+team is obligated to maintain confidentiality with regard to the reporter of
+an incident. Further details of specific enforcement policies may be posted
+separately.
+
+Project maintainers who do not follow or enforce the Code of Conduct in good
+faith may face temporary or permanent repercussions as determined by other
+members of the project's leadership.
+
+The project leadership team can be contacted by email as a whole at
+git@sfconservancy.org, or individually:
+
+  - Ævar Arnfjörð Bjarmason <avarab@gmail.com>
+  - Christian Couder <christian.couder@gmail.com>
+  - Jeff King <peff@peff.net>
+  - Junio C Hamano <gitster@pobox.com>
+
+## Attribution
+
+This Code of Conduct is adapted from the [Contributor Covenant][homepage],
+version 1.4, available at https://www.contributor-covenant.org/version/1/4/code-of-conduct.html
+
+[homepage]: https://www.contributor-covenant.org
+
+For answers to common questions about this code of conduct, see
+https://www.contributor-covenant.org/faq
diff -pruN 1.2.1+git2.18.0-1/git/color.c 1.2.3+git2.25.1-1/git/color.c
--- 1.2.1+git2.18.0-1/git/color.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/color.c	2020-02-17 04:47:35.000000000 +0000
@@ -343,6 +343,9 @@ int want_color_fd(int fd, int var)
 
 	static int want_auto[3] = { -1, -1, -1 };
 
+	if (fd < 1 || fd >= ARRAY_SIZE(want_auto))
+		BUG("file descriptor out of range: %d", fd);
+
 	if (var < 0)
 		var = git_use_color_default;
 
diff -pruN 1.2.1+git2.18.0-1/git/color.h 1.2.3+git2.25.1-1/git/color.h
--- 1.2.1+git2.18.0-1/git/color.h	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/color.h	2020-02-17 04:47:35.000000000 +0000
@@ -36,6 +36,12 @@ struct strbuf;
 #define GIT_COLOR_BOLD_BLUE	"\033[1;34m"
 #define GIT_COLOR_BOLD_MAGENTA	"\033[1;35m"
 #define GIT_COLOR_BOLD_CYAN	"\033[1;36m"
+#define GIT_COLOR_FAINT_RED	"\033[2;31m"
+#define GIT_COLOR_FAINT_GREEN	"\033[2;32m"
+#define GIT_COLOR_FAINT_YELLOW	"\033[2;33m"
+#define GIT_COLOR_FAINT_BLUE	"\033[2;34m"
+#define GIT_COLOR_FAINT_MAGENTA	"\033[2;35m"
+#define GIT_COLOR_FAINT_CYAN	"\033[2;36m"
 #define GIT_COLOR_BG_RED	"\033[41m"
 #define GIT_COLOR_BG_GREEN	"\033[42m"
 #define GIT_COLOR_BG_YELLOW	"\033[43m"
@@ -44,6 +50,7 @@ struct strbuf;
 #define GIT_COLOR_BG_CYAN	"\033[46m"
 #define GIT_COLOR_FAINT		"\033[2m"
 #define GIT_COLOR_FAINT_ITALIC	"\033[2;3m"
+#define GIT_COLOR_REVERSE	"\033[7m"
 
 /* A special value meaning "no color selected" */
 #define GIT_COLOR_NIL "NIL"
diff -pruN 1.2.1+git2.18.0-1/git/column.c 1.2.3+git2.25.1-1/git/column.c
--- 1.2.1+git2.18.0-1/git/column.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/column.c	2020-02-17 04:47:35.000000000 +0000
@@ -21,20 +21,9 @@ struct column_data {
 };
 
 /* return length of 's' in letters, ANSI escapes stripped */
-static int item_length(unsigned int colopts, const char *s)
+static int item_length(const char *s)
 {
-	int len, i = 0;
-	struct strbuf str = STRBUF_INIT;
-
-	strbuf_addstr(&str, s);
-	while ((s = strstr(str.buf + i, "\033[")) != NULL) {
-		int len = strspn(s + 2, "0123456789;");
-		i = s - str.buf;
-		strbuf_remove(&str, i, len + 3); /* \033[<len><func char> */
-	}
-	len = utf8_strwidth(str.buf);
-	strbuf_release(&str);
-	return len;
+	return utf8_strnwidth(s, -1, 1);
 }
 
 /*
@@ -167,7 +156,7 @@ static void display_table(const struct s
 
 	ALLOC_ARRAY(data.len, list->nr);
 	for (i = 0; i < list->nr; i++)
-		data.len[i] = item_length(colopts, list->items[i].string);
+		data.len[i] = item_length(list->items[i].string);
 
 	layout(&data, &initial_width);
 
diff -pruN 1.2.1+git2.18.0-1/git/column.h 1.2.3+git2.25.1-1/git/column.h
--- 1.2.1+git2.18.0-1/git/column.h	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/column.h	2020-02-17 04:47:35.000000000 +0000
@@ -27,19 +27,20 @@ struct column_options {
 };
 
 struct option;
-extern int parseopt_column_callback(const struct option *, const char *, int);
-extern int git_column_config(const char *var, const char *value,
-			     const char *command, unsigned int *colopts);
-extern int finalize_colopts(unsigned int *colopts, int stdout_is_tty);
+int parseopt_column_callback(const struct option *, const char *, int);
+int git_column_config(const char *var, const char *value,
+		      const char *command, unsigned int *colopts);
+int finalize_colopts(unsigned int *colopts, int stdout_is_tty);
 static inline int column_active(unsigned int colopts)
 {
 	return (colopts & COL_ENABLE_MASK) == COL_ENABLED;
 }
 
-extern void print_columns(const struct string_list *list, unsigned int colopts,
-			  const struct column_options *opts);
+struct string_list;
+void print_columns(const struct string_list *list, unsigned int colopts,
+		   const struct column_options *opts);
 
-extern int run_column_filter(int colopts, const struct column_options *);
-extern int stop_column_filter(void);
+int run_column_filter(int colopts, const struct column_options *);
+int stop_column_filter(void);
 
 #endif
diff -pruN 1.2.1+git2.18.0-1/git/combine-diff.c 1.2.3+git2.25.1-1/git/combine-diff.c
--- 1.2.1+git2.18.0-1/git/combine-diff.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/combine-diff.c	2020-02-17 04:47:35.000000000 +0000
@@ -1,4 +1,5 @@
 #include "cache.h"
+#include "object-store.h"
 #include "commit.h"
 #include "blob.h"
 #include "diff.h"
@@ -22,11 +23,20 @@ static int compare_paths(const struct co
 				 two->path, strlen(two->path), two->mode);
 }
 
-static struct combine_diff_path *intersect_paths(struct combine_diff_path *curr, int n, int num_parent)
+static int filename_changed(char status)
+{
+	return status == 'R' || status == 'C';
+}
+
+static struct combine_diff_path *intersect_paths(
+	struct combine_diff_path *curr,
+	int n,
+	int num_parent,
+	int combined_all_paths)
 {
 	struct diff_queue_struct *q = &diff_queued_diff;
 	struct combine_diff_path *p, **tail = &curr;
-	int i, cmp;
+	int i, j, cmp;
 
 	if (!n) {
 		for (i = 0; i < q->nr; i++) {
@@ -49,6 +59,13 @@ static struct combine_diff_path *interse
 			oidcpy(&p->parent[n].oid, &q->queue[i]->one->oid);
 			p->parent[n].mode = q->queue[i]->one->mode;
 			p->parent[n].status = q->queue[i]->status;
+
+			if (combined_all_paths &&
+			    filename_changed(p->parent[n].status)) {
+				strbuf_init(&p->parent[n].path, 0);
+				strbuf_addstr(&p->parent[n].path,
+					      q->queue[i]->one->path);
+			}
 			*tail = p;
 			tail = &p->next;
 		}
@@ -67,6 +84,10 @@ static struct combine_diff_path *interse
 		if (cmp < 0) {
 			/* p->path not in q->queue[]; drop it */
 			*tail = p->next;
+			for (j = 0; j < num_parent; j++)
+				if (combined_all_paths &&
+				    filename_changed(p->parent[j].status))
+					strbuf_release(&p->parent[j].path);
 			free(p);
 			continue;
 		}
@@ -80,6 +101,10 @@ static struct combine_diff_path *interse
 		oidcpy(&p->parent[n].oid, &q->queue[i]->one->oid);
 		p->parent[n].mode = q->queue[i]->one->mode;
 		p->parent[n].status = q->queue[i]->status;
+		if (combined_all_paths &&
+		    filename_changed(p->parent[n].status))
+			strbuf_addstr(&p->parent[n].path,
+				      q->queue[i]->one->path);
 
 		tail = &p->next;
 		i++;
@@ -284,7 +309,8 @@ static struct lline *coalesce_lines(stru
 	return base;
 }
 
-static char *grab_blob(const struct object_id *oid, unsigned int mode,
+static char *grab_blob(struct repository *r,
+		       const struct object_id *oid, unsigned int mode,
 		       unsigned long *size, struct userdiff_driver *textconv,
 		       const char *path)
 {
@@ -303,7 +329,7 @@ static char *grab_blob(const struct obje
 	} else if (textconv) {
 		struct diff_filespec *df = alloc_filespec(path);
 		fill_filespec(df, oid, 1, mode);
-		*size = fill_textconv(textconv, df, &blob);
+		*size = fill_textconv(r, textconv, df, &blob);
 		free_filespec(df);
 	} else {
 		blob = read_object_file(oid, &type, size);
@@ -343,38 +369,43 @@ struct combine_diff_state {
 	struct sline *lost_bucket;
 };
 
-static void consume_line(void *state_, char *line, unsigned long len)
+static void consume_hunk(void *state_,
+			 long ob, long on,
+			 long nb, long nn,
+			 const char *funcline, long funclen)
 {
 	struct combine_diff_state *state = state_;
-	if (5 < len && !memcmp("@@ -", line, 4)) {
-		if (parse_hunk_header(line, len,
-				      &state->ob, &state->on,
-				      &state->nb, &state->nn))
-			return;
-		state->lno = state->nb;
-		if (state->nn == 0) {
-			/* @@ -X,Y +N,0 @@ removed Y lines
-			 * that would have come *after* line N
-			 * in the result.  Our lost buckets hang
-			 * to the line after the removed lines,
-			 *
-			 * Note that this is correct even when N == 0,
-			 * in which case the hunk removes the first
-			 * line in the file.
-			 */
-			state->lost_bucket = &state->sline[state->nb];
-			if (!state->nb)
-				state->nb = 1;
-		} else {
-			state->lost_bucket = &state->sline[state->nb-1];
-		}
-		if (!state->sline[state->nb-1].p_lno)
-			state->sline[state->nb-1].p_lno =
-				xcalloc(state->num_parent,
-					sizeof(unsigned long));
-		state->sline[state->nb-1].p_lno[state->n] = state->ob;
-		return;
+
+	state->ob = ob;
+	state->on = on;
+	state->nb = nb;
+	state->nn = nn;
+	state->lno = state->nb;
+	if (state->nn == 0) {
+		/* @@ -X,Y +N,0 @@ removed Y lines
+		 * that would have come *after* line N
+		 * in the result.  Our lost buckets hang
+		 * to the line after the removed lines,
+		 *
+		 * Note that this is correct even when N == 0,
+		 * in which case the hunk removes the first
+		 * line in the file.
+		 */
+		state->lost_bucket = &state->sline[state->nb];
+		if (!state->nb)
+			state->nb = 1;
+	} else {
+		state->lost_bucket = &state->sline[state->nb-1];
 	}
+	if (!state->sline[state->nb-1].p_lno)
+		state->sline[state->nb-1].p_lno =
+			xcalloc(state->num_parent, sizeof(unsigned long));
+	state->sline[state->nb-1].p_lno[state->n] = state->ob;
+}
+
+static void consume_line(void *state_, char *line, unsigned long len)
+{
+	struct combine_diff_state *state = state_;
 	if (!state->lost_bucket)
 		return; /* not in any hunk yet */
 	switch (line[0]) {
@@ -388,7 +419,8 @@ static void consume_line(void *state_, c
 	}
 }
 
-static void combine_diff(const struct object_id *parent, unsigned int mode,
+static void combine_diff(struct repository *r,
+			 const struct object_id *parent, unsigned int mode,
 			 mmfile_t *result_file,
 			 struct sline *sline, unsigned int cnt, int n,
 			 int num_parent, int result_deleted,
@@ -406,7 +438,7 @@ static void combine_diff(const struct ob
 	if (result_deleted)
 		return; /* result deleted */
 
-	parent_file.ptr = grab_blob(parent, mode, &sz, textconv, path);
+	parent_file.ptr = grab_blob(r, parent, mode, &sz, textconv, path);
 	parent_file.size = sz;
 	memset(&xpp, 0, sizeof(xpp));
 	xpp.flags = flags;
@@ -418,8 +450,8 @@ static void combine_diff(const struct ob
 	state.num_parent = num_parent;
 	state.n = n;
 
-	if (xdi_diff_outf(&parent_file, result_file, consume_line, &state,
-			  &xpp, &xecfg))
+	if (xdi_diff_outf(&parent_file, result_file, consume_hunk,
+			  consume_line, &state, &xpp, &xecfg))
 		die("unable to generate combined diff for %s",
 		    oid_to_hex(parent));
 	free(parent_file.ptr);
@@ -898,7 +930,7 @@ static void show_combined_header(struct
 				 int show_file_header)
 {
 	struct diff_options *opt = &rev->diffopt;
-	int abbrev = opt->flags.full_index ? GIT_SHA1_HEXSZ : DEFAULT_ABBREV;
+	int abbrev = opt->flags.full_index ? the_hash_algo->hexsz : DEFAULT_ABBREV;
 	const char *a_prefix = opt->a_prefix ? opt->a_prefix : "a/";
 	const char *b_prefix = opt->b_prefix ? opt->b_prefix : "b/";
 	const char *c_meta = diff_get_color_opt(opt, DIFF_METAINFO);
@@ -952,12 +984,25 @@ static void show_combined_header(struct
 	if (!show_file_header)
 		return;
 
-	if (added)
-		dump_quoted_path("--- ", "", "/dev/null",
-				 line_prefix, c_meta, c_reset);
-	else
-		dump_quoted_path("--- ", a_prefix, elem->path,
-				 line_prefix, c_meta, c_reset);
+	if (rev->combined_all_paths) {
+		for (i = 0; i < num_parent; i++) {
+			char *path = filename_changed(elem->parent[i].status)
+				? elem->parent[i].path.buf : elem->path;
+			if (elem->parent[i].status == DIFF_STATUS_ADDED)
+				dump_quoted_path("--- ", "", "/dev/null",
+						 line_prefix, c_meta, c_reset);
+			else
+				dump_quoted_path("--- ", a_prefix, path,
+						 line_prefix, c_meta, c_reset);
+		}
+	} else {
+		if (added)
+			dump_quoted_path("--- ", "", "/dev/null",
+					 line_prefix, c_meta, c_reset);
+		else
+			dump_quoted_path("--- ", a_prefix, elem->path,
+					 line_prefix, c_meta, c_reset);
+	}
 	if (deleted)
 		dump_quoted_path("+++ ", "", "/dev/null",
 				 line_prefix, c_meta, c_reset);
@@ -984,15 +1029,15 @@ static void show_patch_diff(struct combi
 	const char *line_prefix = diff_line_prefix(opt);
 
 	context = opt->context;
-	userdiff = userdiff_find_by_path(elem->path);
+	userdiff = userdiff_find_by_path(opt->repo->index, elem->path);
 	if (!userdiff)
 		userdiff = userdiff_find_by_name("default");
 	if (opt->flags.allow_textconv)
-		textconv = userdiff_get_textconv(userdiff);
+		textconv = userdiff_get_textconv(opt->repo, userdiff);
 
 	/* Read the result of merge first */
 	if (!working_tree_file)
-		result = grab_blob(&elem->oid, elem->mode, &result_size,
+		result = grab_blob(opt->repo, &elem->oid, elem->mode, &result_size,
 				   textconv, elem->path);
 	else {
 		/* Used by diff-tree to read from the working tree */
@@ -1015,15 +1060,16 @@ static void show_patch_diff(struct combi
 		} else if (S_ISDIR(st.st_mode)) {
 			struct object_id oid;
 			if (resolve_gitlink_ref(elem->path, "HEAD", &oid) < 0)
-				result = grab_blob(&elem->oid, elem->mode,
-						   &result_size, NULL, NULL);
+				result = grab_blob(opt->repo, &elem->oid,
+						   elem->mode, &result_size,
+						   NULL, NULL);
 			else
-				result = grab_blob(&oid, elem->mode,
+				result = grab_blob(opt->repo, &oid, elem->mode,
 						   &result_size, NULL, NULL);
 		} else if (textconv) {
 			struct diff_filespec *df = alloc_filespec(elem->path);
 			fill_filespec(df, &null_oid, 0, st.st_mode);
-			result_size = fill_textconv(textconv, df, &result);
+			result_size = fill_textconv(opt->repo, textconv, df, &result);
 			free_filespec(df);
 		} else if (0 <= (fd = open(elem->path, O_RDONLY))) {
 			size_t len = xsize_t(st.st_size);
@@ -1053,7 +1099,8 @@ static void show_patch_diff(struct combi
 			if (is_file) {
 				struct strbuf buf = STRBUF_INIT;
 
-				if (convert_to_git(&the_index, elem->path, result, len, &buf, global_conv_flags_eol)) {
+				if (convert_to_git(rev->diffopt.repo->index,
+						   elem->path, result, len, &buf, global_conv_flags_eol)) {
 					free(result);
 					result = strbuf_detach(&buf, &len);
 					result_size = len;
@@ -1088,7 +1135,8 @@ static void show_patch_diff(struct combi
 		for (i = 0; !is_binary && i < num_parent; i++) {
 			char *buf;
 			unsigned long size;
-			buf = grab_blob(&elem->parent[i].oid,
+			buf = grab_blob(opt->repo,
+					&elem->parent[i].oid,
 					elem->parent[i].mode,
 					&size, NULL, NULL);
 			if (buffer_is_binary(buf, size))
@@ -1137,14 +1185,15 @@ static void show_patch_diff(struct combi
 	for (i = 0; i < num_parent; i++) {
 		int j;
 		for (j = 0; j < i; j++) {
-			if (!oidcmp(&elem->parent[i].oid,
-				     &elem->parent[j].oid)) {
+			if (oideq(&elem->parent[i].oid,
+				  &elem->parent[j].oid)) {
 				reuse_combine_diff(sline, cnt, i, j);
 				break;
 			}
 		}
 		if (i <= j)
-			combine_diff(&elem->parent[i].oid,
+			combine_diff(opt->repo,
+				     &elem->parent[i].oid,
 				     elem->parent[i].mode,
 				     &result_file, sline,
 				     cnt, i, num_parent, result_deleted,
@@ -1215,6 +1264,15 @@ static void show_raw_diff(struct combine
 		putchar(inter_name_termination);
 	}
 
+	for (i = 0; i < num_parent; i++)
+		if (rev->combined_all_paths) {
+			if (filename_changed(p->parent[i].status))
+				write_name_quoted(p->parent[i].path.buf, stdout,
+						  inter_name_termination);
+			else
+				write_name_quoted(p->path, stdout,
+						  inter_name_termination);
+		}
 	write_name_quoted(p->path, stdout, line_termination);
 }
 
@@ -1309,10 +1367,20 @@ static const char *path_path(void *obj)
 	return path->path;
 }
 
+/*
+ * Diff stat formats which we always compute solely against the first parent.
+ */
+#define STAT_FORMAT_MASK (DIFF_FORMAT_NUMSTAT \
+			  | DIFF_FORMAT_SHORTSTAT \
+			  | DIFF_FORMAT_SUMMARY \
+			  | DIFF_FORMAT_DIRSTAT \
+			  | DIFF_FORMAT_DIFFSTAT)
 
 /* find set of paths that every parent touches */
 static struct combine_diff_path *find_paths_generic(const struct object_id *oid,
-	const struct oid_array *parents, struct diff_options *opt)
+	const struct oid_array *parents,
+	struct diff_options *opt,
+	int combined_all_paths)
 {
 	struct combine_diff_path *paths = NULL;
 	int i, num_parent = parents->nr;
@@ -1330,15 +1398,15 @@ static struct combine_diff_path *find_pa
 		 * show stat against the first parent even when doing
 		 * combined diff.
 		 */
-		int stat_opt = (output_format &
-				(DIFF_FORMAT_NUMSTAT|DIFF_FORMAT_DIFFSTAT));
+		int stat_opt = output_format & STAT_FORMAT_MASK;
 		if (i == 0 && stat_opt)
 			opt->output_format = stat_opt;
 		else
 			opt->output_format = DIFF_FORMAT_NO_OUTPUT;
 		diff_tree_oid(&parents->oid[i], oid, "", opt);
 		diffcore_std(opt);
-		paths = intersect_paths(paths, i, num_parent);
+		paths = intersect_paths(paths, i, num_parent,
+					combined_all_paths);
 
 		/* if showing diff, show it in requested order */
 		if (opt->output_format != DIFF_FORMAT_NO_OUTPUT &&
@@ -1448,7 +1516,8 @@ void diff_tree_combined(const struct obj
 		 * diff(sha1,parent_i) for all i to do the job, specifically
 		 * for parent0.
 		 */
-		paths = find_paths_generic(oid, parents, &diffopts);
+		paths = find_paths_generic(oid, parents, &diffopts,
+					   rev->combined_all_paths);
 	}
 	else {
 		int stat_opt;
@@ -1458,8 +1527,7 @@ void diff_tree_combined(const struct obj
 		 * show stat against the first parent even
 		 * when doing combined diff.
 		 */
-		stat_opt = (opt->output_format &
-				(DIFF_FORMAT_NUMSTAT|DIFF_FORMAT_DIFFSTAT));
+		stat_opt = opt->output_format & STAT_FORMAT_MASK;
 		if (stat_opt) {
 			diffopts.output_format = stat_opt;
 
@@ -1503,8 +1571,7 @@ void diff_tree_combined(const struct obj
 				show_raw_diff(p, num_parent, rev);
 			needsep = 1;
 		}
-		else if (opt->output_format &
-			 (DIFF_FORMAT_NUMSTAT|DIFF_FORMAT_DIFFSTAT))
+		else if (opt->output_format & STAT_FORMAT_MASK)
 			needsep = 1;
 		else if (opt->output_format & DIFF_FORMAT_CALLBACK)
 			handle_combined_callback(opt, paths, num_parent, num_paths);
@@ -1523,6 +1590,10 @@ void diff_tree_combined(const struct obj
 	while (paths) {
 		struct combine_diff_path *tmp = paths;
 		paths = paths->next;
+		for (i = 0; i < num_parent; i++)
+			if (rev->combined_all_paths &&
+			    filename_changed(tmp->parent[i].status))
+				strbuf_release(&tmp->parent[i].path);
 		free(tmp);
 	}
 
diff -pruN 1.2.1+git2.18.0-1/git/command-list.txt 1.2.3+git2.25.1-1/git/command-list.txt
--- 1.2.1+git2.18.0-1/git/command-list.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/command-list.txt	2020-02-17 04:47:35.000000000 +0000
@@ -59,10 +59,10 @@ git-cat-file
 git-check-attr                          purehelpers
 git-check-ignore                        purehelpers
 git-check-mailmap                       purehelpers
-git-checkout                            mainporcelain           history
+git-checkout                            mainporcelain
 git-checkout-index                      plumbingmanipulators
 git-check-ref-format                    purehelpers
-git-cherry                              ancillaryinterrogators          complete
+git-cherry                              plumbinginterrogators          complete
 git-cherry-pick                         mainporcelain
 git-citool                              mainporcelain
 git-clean                               mainporcelain
@@ -81,7 +81,7 @@ git-cvsimport
 git-cvsserver                           foreignscminterface
 git-daemon                              synchingrepositories
 git-describe                            mainporcelain
-git-diff                                mainporcelain           history
+git-diff                                mainporcelain           info
 git-diff-files                          plumbinginterrogators
 git-diff-index                          plumbinginterrogators
 git-diff-tree                           plumbinginterrogators
@@ -96,7 +96,7 @@ git-for-each-ref
 git-format-patch                        mainporcelain
 git-fsck                                ancillaryinterrogators          complete
 git-gc                                  mainporcelain
-git-get-tar-commit-id                   ancillaryinterrogators
+git-get-tar-commit-id                   plumbinginterrogators
 git-grep                                mainporcelain           info
 git-gui                                 mainporcelain
 git-hash-object                         plumbingmanipulators
@@ -123,6 +123,7 @@ git-merge-index
 git-merge-one-file                      purehelpers
 git-mergetool                           ancillarymanipulators           complete
 git-merge-tree                          ancillaryinterrogators
+git-multi-pack-index                    plumbingmanipulators
 git-mktag                               plumbingmanipulators
 git-mktree                              plumbingmanipulators
 git-mv                                  mainporcelain           worktree
@@ -139,6 +140,7 @@ git-prune-packed
 git-pull                                mainporcelain           remote
 git-push                                mainporcelain           remote
 git-quiltimport                         foreignscminterface
+git-range-diff                          mainporcelain
 git-read-tree                           plumbingmanipulators
 git-rebase                              mainporcelain           history
 git-receive-pack                        synchelpers
@@ -148,10 +150,11 @@ git-repack
 git-replace                             ancillarymanipulators           complete
 git-request-pull                        foreignscminterface             complete
 git-rerere                              ancillaryinterrogators
-git-reset                               mainporcelain           worktree
+git-reset                               mainporcelain           history
+git-restore                             mainporcelain           worktree
 git-revert                              mainporcelain
 git-rev-list                            plumbinginterrogators
-git-rev-parse                           ancillaryinterrogators
+git-rev-parse                           plumbinginterrogators
 git-rm                                  mainporcelain           worktree
 git-send-email                          foreignscminterface             complete
 git-send-pack                           synchingrepositories
@@ -163,12 +166,14 @@ git-show-index
 git-show-ref                            plumbinginterrogators
 git-sh-i18n                             purehelpers
 git-sh-setup                            purehelpers
+git-sparse-checkout                     mainporcelain           worktree
 git-stash                               mainporcelain
 git-stage                                                               complete
 git-status                              mainporcelain           info
 git-stripspace                          purehelpers
 git-submodule                           mainporcelain
 git-svn                                 foreignscminterface
+git-switch                              mainporcelain           history
 git-symbolic-ref                        plumbingmanipulators
 git-tag                                 mainporcelain           history
 git-unpack-file                         plumbinginterrogators
@@ -199,6 +204,7 @@ gitmodules
 gitnamespaces                           guide
 gitrepository-layout                    guide
 gitrevisions                            guide
+gitsubmodules                           guide
 gittutorial-2                           guide
 gittutorial                             guide
 gitworkflows                            guide
diff -pruN 1.2.1+git2.18.0-1/git/commit.c 1.2.3+git2.25.1-1/git/commit.c
--- 1.2.1+git2.18.0-1/git/commit.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/commit.c	2020-02-17 04:47:35.000000000 +0000
@@ -2,11 +2,14 @@
 #include "tag.h"
 #include "commit.h"
 #include "commit-graph.h"
+#include "repository.h"
+#include "object-store.h"
 #include "pkt-line.h"
 #include "utf8.h"
 #include "diff.h"
 #include "revision.h"
 #include "notes.h"
+#include "alloc.h"
 #include "gpg-interface.h"
 #include "mergesort.h"
 #include "commit-slab.h"
@@ -14,6 +17,9 @@
 #include "sha1-lookup.h"
 #include "wt-status.h"
 #include "advice.h"
+#include "refs.h"
+#include "commit-reach.h"
+#include "run-command.h"
 
 static struct commit_extra_header *read_commit_extra_header_lines(const char *buf, size_t len, const char **);
 
@@ -21,39 +27,41 @@ int save_commit_buffer = 1;
 
 const char *commit_type = "commit";
 
-struct commit *lookup_commit_reference_gently(const struct object_id *oid,
-					      int quiet)
+struct commit *lookup_commit_reference_gently(struct repository *r,
+		const struct object_id *oid, int quiet)
 {
-	struct object *obj = deref_tag(parse_object(oid), NULL, 0);
+	struct object *obj = deref_tag(r,
+				       parse_object(r, oid),
+				       NULL, 0);
 
 	if (!obj)
 		return NULL;
-	return object_as_type(obj, OBJ_COMMIT, quiet);
+	return object_as_type(r, obj, OBJ_COMMIT, quiet);
 }
 
-struct commit *lookup_commit_reference(const struct object_id *oid)
+struct commit *lookup_commit_reference(struct repository *r, const struct object_id *oid)
 {
-	return lookup_commit_reference_gently(oid, 0);
+	return lookup_commit_reference_gently(r, oid, 0);
 }
 
 struct commit *lookup_commit_or_die(const struct object_id *oid, const char *ref_name)
 {
-	struct commit *c = lookup_commit_reference(oid);
+	struct commit *c = lookup_commit_reference(the_repository, oid);
 	if (!c)
 		die(_("could not parse %s"), ref_name);
-	if (oidcmp(oid, &c->object.oid)) {
+	if (!oideq(oid, &c->object.oid)) {
 		warning(_("%s %s is not a commit!"),
 			ref_name, oid_to_hex(oid));
 	}
 	return c;
 }
 
-struct commit *lookup_commit(const struct object_id *oid)
+struct commit *lookup_commit(struct repository *r, const struct object_id *oid)
 {
-	struct object *obj = lookup_object(oid->hash);
+	struct object *obj = lookup_object(r, oid);
 	if (!obj)
-		return create_object(oid->hash, alloc_commit_node());
-	return object_as_type(obj, OBJ_COMMIT, 0);
+		return create_object(r, oid, alloc_commit_node(r));
+	return object_as_type(r, obj, OBJ_COMMIT, 0);
 }
 
 struct commit *lookup_commit_reference_by_name(const char *name)
@@ -63,7 +71,7 @@ struct commit *lookup_commit_reference_b
 
 	if (get_oid_committish(name, &oid))
 		return NULL;
-	commit = lookup_commit_reference(&oid);
+	commit = lookup_commit_reference(the_repository, &oid);
 	if (parse_commit(commit))
 		return NULL;
 	return commit;
@@ -96,41 +104,44 @@ static timestamp_t parse_commit_date(con
 	return parse_timestamp(dateptr, NULL, 10);
 }
 
-static struct commit_graft **commit_graft;
-static int commit_graft_alloc, commit_graft_nr;
-
 static const unsigned char *commit_graft_sha1_access(size_t index, void *table)
 {
 	struct commit_graft **commit_graft_table = table;
 	return commit_graft_table[index]->oid.hash;
 }
 
-static int commit_graft_pos(const unsigned char *sha1)
+static int commit_graft_pos(struct repository *r, const unsigned char *sha1)
 {
-	return sha1_pos(sha1, commit_graft, commit_graft_nr,
+	return sha1_pos(sha1, r->parsed_objects->grafts,
+			r->parsed_objects->grafts_nr,
 			commit_graft_sha1_access);
 }
 
-int register_commit_graft(struct commit_graft *graft, int ignore_dups)
+int register_commit_graft(struct repository *r, struct commit_graft *graft,
+			  int ignore_dups)
 {
-	int pos = commit_graft_pos(graft->oid.hash);
+	int pos = commit_graft_pos(r, graft->oid.hash);
 
 	if (0 <= pos) {
 		if (ignore_dups)
 			free(graft);
 		else {
-			free(commit_graft[pos]);
-			commit_graft[pos] = graft;
+			free(r->parsed_objects->grafts[pos]);
+			r->parsed_objects->grafts[pos] = graft;
 		}
 		return 1;
 	}
 	pos = -pos - 1;
-	ALLOC_GROW(commit_graft, commit_graft_nr + 1, commit_graft_alloc);
-	commit_graft_nr++;
-	if (pos < commit_graft_nr)
-		MOVE_ARRAY(commit_graft + pos + 1, commit_graft + pos,
-			   commit_graft_nr - pos - 1);
-	commit_graft[pos] = graft;
+	ALLOC_GROW(r->parsed_objects->grafts,
+		   r->parsed_objects->grafts_nr + 1,
+		   r->parsed_objects->grafts_alloc);
+	r->parsed_objects->grafts_nr++;
+	if (pos < r->parsed_objects->grafts_nr)
+		memmove(r->parsed_objects->grafts + pos + 1,
+			r->parsed_objects->grafts + pos,
+			(r->parsed_objects->grafts_nr - pos - 1) *
+			sizeof(*r->parsed_objects->grafts));
+	r->parsed_objects->grafts[pos] = graft;
 	return 0;
 }
 
@@ -172,7 +183,7 @@ bad_graft_data:
 	return NULL;
 }
 
-static int read_graft_file(const char *graft_file)
+static int read_graft_file(struct repository *r, const char *graft_file)
 {
 	FILE *fp = fopen_or_warn(graft_file, "r");
 	struct strbuf buf = STRBUF_INIT;
@@ -192,7 +203,7 @@ static int read_graft_file(const char *g
 		struct commit_graft *graft = read_graft_line(&buf);
 		if (!graft)
 			continue;
-		if (register_commit_graft(graft, 1))
+		if (register_commit_graft(r, graft, 1))
 			error("duplicate graft data: %s", buf.buf);
 	}
 	fclose(fp);
@@ -200,50 +211,50 @@ static int read_graft_file(const char *g
 	return 0;
 }
 
-static void prepare_commit_graft(void)
+void prepare_commit_graft(struct repository *r)
 {
-	static int commit_graft_prepared;
 	char *graft_file;
 
-	if (commit_graft_prepared)
+	if (r->parsed_objects->commit_graft_prepared)
 		return;
 	if (!startup_info->have_repository)
 		return;
 
-	graft_file = get_graft_file();
-	read_graft_file(graft_file);
+	graft_file = get_graft_file(r);
+	read_graft_file(r, graft_file);
 	/* make sure shallows are read */
-	is_repository_shallow();
-	commit_graft_prepared = 1;
+	is_repository_shallow(r);
+	r->parsed_objects->commit_graft_prepared = 1;
 }
 
-struct commit_graft *lookup_commit_graft(const struct object_id *oid)
+struct commit_graft *lookup_commit_graft(struct repository *r, const struct object_id *oid)
 {
 	int pos;
-	prepare_commit_graft();
-	pos = commit_graft_pos(oid->hash);
+	prepare_commit_graft(r);
+	pos = commit_graft_pos(r, oid->hash);
 	if (pos < 0)
 		return NULL;
-	return commit_graft[pos];
+	return r->parsed_objects->grafts[pos];
 }
 
 int for_each_commit_graft(each_commit_graft_fn fn, void *cb_data)
 {
 	int i, ret;
-	for (i = ret = 0; i < commit_graft_nr && !ret; i++)
-		ret = fn(commit_graft[i], cb_data);
+	for (i = ret = 0; i < the_repository->parsed_objects->grafts_nr && !ret; i++)
+		ret = fn(the_repository->parsed_objects->grafts[i], cb_data);
 	return ret;
 }
 
 int unregister_shallow(const struct object_id *oid)
 {
-	int pos = commit_graft_pos(oid->hash);
+	int pos = commit_graft_pos(the_repository, oid->hash);
 	if (pos < 0)
 		return -1;
-	if (pos + 1 < commit_graft_nr)
-		MOVE_ARRAY(commit_graft + pos, commit_graft + pos + 1,
-			   commit_graft_nr - pos - 1);
-	commit_graft_nr--;
+	if (pos + 1 < the_repository->parsed_objects->grafts_nr)
+		MOVE_ARRAY(the_repository->parsed_objects->grafts + pos,
+			   the_repository->parsed_objects->grafts + pos + 1,
+			   the_repository->parsed_objects->grafts_nr - pos - 1);
+	the_repository->parsed_objects->grafts_nr--;
 	return 0;
 }
 
@@ -252,18 +263,32 @@ struct commit_buffer {
 	unsigned long size;
 };
 define_commit_slab(buffer_slab, struct commit_buffer);
-static struct buffer_slab buffer_slab = COMMIT_SLAB_INIT(1, buffer_slab);
 
-void set_commit_buffer(struct commit *commit, void *buffer, unsigned long size)
+struct buffer_slab *allocate_commit_buffer_slab(void)
+{
+	struct buffer_slab *bs = xmalloc(sizeof(*bs));
+	init_buffer_slab(bs);
+	return bs;
+}
+
+void free_commit_buffer_slab(struct buffer_slab *bs)
 {
-	struct commit_buffer *v = buffer_slab_at(&buffer_slab, commit);
+	clear_buffer_slab(bs);
+	free(bs);
+}
+
+void set_commit_buffer(struct repository *r, struct commit *commit, void *buffer, unsigned long size)
+{
+	struct commit_buffer *v = buffer_slab_at(
+		r->parsed_objects->buffer_slab, commit);
 	v->buffer = buffer;
 	v->size = size;
 }
 
-const void *get_cached_commit_buffer(const struct commit *commit, unsigned long *sizep)
+const void *get_cached_commit_buffer(struct repository *r, const struct commit *commit, unsigned long *sizep)
 {
-	struct commit_buffer *v = buffer_slab_peek(&buffer_slab, commit);
+	struct commit_buffer *v = buffer_slab_peek(
+		r->parsed_objects->buffer_slab, commit);
 	if (!v) {
 		if (sizep)
 			*sizep = 0;
@@ -274,13 +299,15 @@ const void *get_cached_commit_buffer(con
 	return v->buffer;
 }
 
-const void *get_commit_buffer(const struct commit *commit, unsigned long *sizep)
+const void *repo_get_commit_buffer(struct repository *r,
+				   const struct commit *commit,
+				   unsigned long *sizep)
 {
-	const void *ret = get_cached_commit_buffer(commit, sizep);
+	const void *ret = get_cached_commit_buffer(r, commit, sizep);
 	if (!ret) {
 		enum object_type type;
 		unsigned long size;
-		ret = read_object_file(&commit->object.oid, &type, &size);
+		ret = repo_read_object_file(r, &commit->object.oid, &type, &size);
 		if (!ret)
 			die("cannot read commit object %s",
 			    oid_to_hex(&commit->object.oid));
@@ -293,41 +320,63 @@ const void *get_commit_buffer(const stru
 	return ret;
 }
 
-void unuse_commit_buffer(const struct commit *commit, const void *buffer)
+void repo_unuse_commit_buffer(struct repository *r,
+			      const struct commit *commit,
+			      const void *buffer)
 {
-	struct commit_buffer *v = buffer_slab_peek(&buffer_slab, commit);
+	struct commit_buffer *v = buffer_slab_peek(
+		r->parsed_objects->buffer_slab, commit);
 	if (!(v && v->buffer == buffer))
 		free((void *)buffer);
 }
 
-void free_commit_buffer(struct commit *commit)
+void free_commit_buffer(struct parsed_object_pool *pool, struct commit *commit)
 {
-	struct commit_buffer *v = buffer_slab_peek(&buffer_slab, commit);
+	struct commit_buffer *v = buffer_slab_peek(
+		pool->buffer_slab, commit);
 	if (v) {
 		FREE_AND_NULL(v->buffer);
 		v->size = 0;
 	}
 }
 
-struct tree *get_commit_tree(const struct commit *commit)
+static inline void set_commit_tree(struct commit *c, struct tree *t)
+{
+	c->maybe_tree = t;
+}
+
+struct tree *repo_get_commit_tree(struct repository *r,
+				  const struct commit *commit)
 {
 	if (commit->maybe_tree || !commit->object.parsed)
 		return commit->maybe_tree;
 
-	if (commit->graph_pos == COMMIT_NOT_FROM_GRAPH)
-		BUG("commit has NULL tree, but was not loaded from commit-graph");
+	if (commit->graph_pos != COMMIT_NOT_FROM_GRAPH)
+		return get_commit_tree_in_graph(r, commit);
 
-	return get_commit_tree_in_graph(commit);
+	return NULL;
 }
 
 struct object_id *get_commit_tree_oid(const struct commit *commit)
 {
-	return &get_commit_tree(commit)->object.oid;
+	struct tree *tree = get_commit_tree(commit);
+	return tree ? &tree->object.oid : NULL;
+}
+
+void release_commit_memory(struct parsed_object_pool *pool, struct commit *c)
+{
+	set_commit_tree(c, NULL);
+	free_commit_buffer(pool, c);
+	c->index = 0;
+	free_commit_list(c->parents);
+
+	c->object.parsed = 0;
 }
 
 const void *detach_commit_buffer(struct commit *commit, unsigned long *sizep)
 {
-	struct commit_buffer *v = buffer_slab_peek(&buffer_slab, commit);
+	struct commit_buffer *v = buffer_slab_peek(
+		the_repository->parsed_objects->buffer_slab, commit);
 	void *ret;
 
 	if (!v) {
@@ -344,19 +393,31 @@ const void *detach_commit_buffer(struct
 	return ret;
 }
 
-int parse_commit_buffer(struct commit *item, const void *buffer, unsigned long size)
+int parse_commit_buffer(struct repository *r, struct commit *item, const void *buffer, unsigned long size, int check_graph)
 {
 	const char *tail = buffer;
 	const char *bufptr = buffer;
 	struct object_id parent;
 	struct commit_list **pptr;
 	struct commit_graft *graft;
-	const int tree_entry_len = GIT_SHA1_HEXSZ + 5;
-	const int parent_entry_len = GIT_SHA1_HEXSZ + 7;
+	const int tree_entry_len = the_hash_algo->hexsz + 5;
+	const int parent_entry_len = the_hash_algo->hexsz + 7;
+	struct tree *tree;
 
 	if (item->object.parsed)
 		return 0;
-	item->object.parsed = 1;
+
+	if (item->parents) {
+		/*
+		 * Presumably this is leftover from an earlier failed parse;
+		 * clear it out in preparation for us re-parsing (we'll hit the
+		 * same error, but that's good, since it lets our caller know
+		 * the result cannot be trusted.
+		 */
+		free_commit_list(item->parents);
+		item->parents = NULL;
+	}
+
 	tail += size;
 	if (tail <= bufptr + tree_entry_len + 1 || memcmp(bufptr, "tree ", 5) ||
 			bufptr[tree_entry_len] != '\n')
@@ -364,11 +425,16 @@ int parse_commit_buffer(struct commit *i
 	if (get_oid_hex(bufptr + 5, &parent) < 0)
 		return error("bad tree pointer in commit %s",
 			     oid_to_hex(&item->object.oid));
-	item->maybe_tree = lookup_tree(&parent);
+	tree = lookup_tree(r, &parent);
+	if (!tree)
+		return error("bad tree pointer %s in commit %s",
+			     oid_to_hex(&parent),
+			     oid_to_hex(&item->object.oid));
+	set_commit_tree(item, tree);
 	bufptr += tree_entry_len + 1; /* "tree " + "hex sha1" + "\n" */
 	pptr = &item->parents;
 
-	graft = lookup_commit_graft(&item->object.oid);
+	graft = lookup_commit_graft(r, &item->object.oid);
 	while (bufptr + parent_entry_len < tail && !memcmp(bufptr, "parent ", 7)) {
 		struct commit *new_parent;
 
@@ -383,26 +449,39 @@ int parse_commit_buffer(struct commit *i
 		 */
 		if (graft && (graft->nr_parent < 0 || grafts_replace_parents))
 			continue;
-		new_parent = lookup_commit(&parent);
-		if (new_parent)
-			pptr = &commit_list_insert(new_parent, pptr)->next;
+		new_parent = lookup_commit(r, &parent);
+		if (!new_parent)
+			return error("bad parent %s in commit %s",
+				     oid_to_hex(&parent),
+				     oid_to_hex(&item->object.oid));
+		pptr = &commit_list_insert(new_parent, pptr)->next;
 	}
 	if (graft) {
 		int i;
 		struct commit *new_parent;
 		for (i = 0; i < graft->nr_parent; i++) {
-			new_parent = lookup_commit(&graft->parent[i]);
+			new_parent = lookup_commit(r,
+						   &graft->parent[i]);
 			if (!new_parent)
-				continue;
+				return error("bad graft parent %s in commit %s",
+					     oid_to_hex(&graft->parent[i]),
+					     oid_to_hex(&item->object.oid));
 			pptr = &commit_list_insert(new_parent, pptr)->next;
 		}
 	}
 	item->date = parse_commit_date(bufptr, tail);
 
+	if (check_graph)
+		load_commit_graph_info(r, item);
+
+	item->object.parsed = 1;
 	return 0;
 }
 
-int parse_commit_gently(struct commit *item, int quiet_on_missing)
+int repo_parse_commit_internal(struct repository *r,
+			       struct commit *item,
+			       int quiet_on_missing,
+			       int use_commit_graph)
 {
 	enum object_type type;
 	void *buffer;
@@ -413,9 +492,9 @@ int parse_commit_gently(struct commit *i
 		return -1;
 	if (item->object.parsed)
 		return 0;
-	if (parse_commit_in_graph(item))
+	if (use_commit_graph && parse_commit_in_graph(r, item))
 		return 0;
-	buffer = read_object_file(&item->object.oid, &type, &size);
+	buffer = repo_read_object_file(r, &item->object.oid, &type, &size);
 	if (!buffer)
 		return quiet_on_missing ? -1 :
 			error("Could not read %s",
@@ -425,15 +504,22 @@ int parse_commit_gently(struct commit *i
 		return error("Object %s not a commit",
 			     oid_to_hex(&item->object.oid));
 	}
-	ret = parse_commit_buffer(item, buffer, size);
+
+	ret = parse_commit_buffer(r, item, buffer, size, 0);
 	if (save_commit_buffer && !ret) {
-		set_commit_buffer(item, buffer, size);
+		set_commit_buffer(r, item, buffer, size);
 		return 0;
 	}
 	free(buffer);
 	return ret;
 }
 
+int repo_parse_commit_gently(struct repository *r,
+			     struct commit *item, int quiet_on_missing)
+{
+	return repo_parse_commit_internal(r, item, quiet_on_missing, 1);
+}
+
 void parse_commit_or_die(struct commit *item)
 {
 	if (parse_commit(item))
@@ -608,11 +694,10 @@ struct commit *pop_commit(struct commit_
 /* count number of children that have not been emitted */
 define_commit_slab(indegree_slab, int);
 
-/* record author-date for each commit object */
-define_commit_slab(author_date_slab, unsigned long);
+define_commit_slab(author_date_slab, timestamp_t);
 
-static void record_author_date(struct author_date_slab *author_date,
-			       struct commit *commit)
+void record_author_date(struct author_date_slab *author_date,
+			struct commit *commit)
 {
 	const char *buffer = get_commit_buffer(commit, NULL);
 	struct ident_split ident;
@@ -637,8 +722,8 @@ fail_exit:
 	unuse_commit_buffer(commit, buffer);
 }
 
-static int compare_commits_by_author_date(const void *a_, const void *b_,
-					  void *cb_data)
+int compare_commits_by_author_date(const void *a_, const void *b_,
+				   void *cb_data)
 {
 	const struct commit *a = a_, *b = b_;
 	struct author_date_slab *author_date = cb_data;
@@ -653,6 +738,24 @@ static int compare_commits_by_author_dat
 	return 0;
 }
 
+int compare_commits_by_gen_then_commit_date(const void *a_, const void *b_, void *unused)
+{
+	const struct commit *a = a_, *b = b_;
+
+	/* newer commits first */
+	if (a->generation < b->generation)
+		return 1;
+	else if (a->generation > b->generation)
+		return -1;
+
+	/* use date as a heuristic when generations are equal */
+	if (a->date < b->date)
+		return 1;
+	else if (a->date > b->date)
+		return -1;
+	return 0;
+}
+
 int compare_commits_by_commit_date(const void *a_, const void *b_, void *unused)
 {
 	const struct commit *a = a_, *b = b_;
@@ -778,340 +881,86 @@ void sort_in_topological_order(struct co
 		clear_author_date_slab(&author_date);
 }
 
-/* merge-base stuff */
-
-/* Remember to update object flag allocation in object.h */
-#define PARENT1		(1u<<16)
-#define PARENT2		(1u<<17)
-#define STALE		(1u<<18)
-#define RESULT		(1u<<19)
-
-static const unsigned all_flags = (PARENT1 | PARENT2 | STALE | RESULT);
-
-static int queue_has_nonstale(struct prio_queue *queue)
-{
-	int i;
-	for (i = 0; i < queue->nr; i++) {
-		struct commit *commit = queue->array[i].data;
-		if (!(commit->object.flags & STALE))
-			return 1;
-	}
-	return 0;
-}
+struct rev_collect {
+	struct commit **commit;
+	int nr;
+	int alloc;
+	unsigned int initial : 1;
+};
 
-/* all input commits in one and twos[] must have been parsed! */
-static struct commit_list *paint_down_to_common(struct commit *one, int n, struct commit **twos)
+static void add_one_commit(struct object_id *oid, struct rev_collect *revs)
 {
-	struct prio_queue queue = { compare_commits_by_commit_date };
-	struct commit_list *result = NULL;
-	int i;
-
-	one->object.flags |= PARENT1;
-	if (!n) {
-		commit_list_append(one, &result);
-		return result;
-	}
-	prio_queue_put(&queue, one);
-
-	for (i = 0; i < n; i++) {
-		twos[i]->object.flags |= PARENT2;
-		prio_queue_put(&queue, twos[i]);
-	}
+	struct commit *commit;
 
-	while (queue_has_nonstale(&queue)) {
-		struct commit *commit = prio_queue_get(&queue);
-		struct commit_list *parents;
-		int flags;
+	if (is_null_oid(oid))
+		return;
 
-		flags = commit->object.flags & (PARENT1 | PARENT2 | STALE);
-		if (flags == (PARENT1 | PARENT2)) {
-			if (!(commit->object.flags & RESULT)) {
-				commit->object.flags |= RESULT;
-				commit_list_insert_by_date(commit, &result);
-			}
-			/* Mark parents of a found merge stale */
-			flags |= STALE;
-		}
-		parents = commit->parents;
-		while (parents) {
-			struct commit *p = parents->item;
-			parents = parents->next;
-			if ((p->object.flags & flags) == flags)
-				continue;
-			if (parse_commit(p))
-				return NULL;
-			p->object.flags |= flags;
-			prio_queue_put(&queue, p);
-		}
-	}
+	commit = lookup_commit(the_repository, oid);
+	if (!commit ||
+	    (commit->object.flags & TMP_MARK) ||
+	    parse_commit(commit))
+		return;
 
-	clear_prio_queue(&queue);
-	return result;
+	ALLOC_GROW(revs->commit, revs->nr + 1, revs->alloc);
+	revs->commit[revs->nr++] = commit;
+	commit->object.flags |= TMP_MARK;
 }
 
-static struct commit_list *merge_bases_many(struct commit *one, int n, struct commit **twos)
+static int collect_one_reflog_ent(struct object_id *ooid, struct object_id *noid,
+				  const char *ident, timestamp_t timestamp,
+				  int tz, const char *message, void *cbdata)
 {
-	struct commit_list *list = NULL;
-	struct commit_list *result = NULL;
-	int i;
+	struct rev_collect *revs = cbdata;
 
-	for (i = 0; i < n; i++) {
-		if (one == twos[i])
-			/*
-			 * We do not mark this even with RESULT so we do not
-			 * have to clean it up.
-			 */
-			return commit_list_insert(one, &result);
-	}
-
-	if (parse_commit(one))
-		return NULL;
-	for (i = 0; i < n; i++) {
-		if (parse_commit(twos[i]))
-			return NULL;
-	}
-
-	list = paint_down_to_common(one, n, twos);
-
-	while (list) {
-		struct commit *commit = pop_commit(&list);
-		if (!(commit->object.flags & STALE))
-			commit_list_insert_by_date(commit, &result);
+	if (revs->initial) {
+		revs->initial = 0;
+		add_one_commit(ooid, revs);
 	}
-	return result;
+	add_one_commit(noid, revs);
+	return 0;
 }
 
-struct commit_list *get_octopus_merge_bases(struct commit_list *in)
+struct commit *get_fork_point(const char *refname, struct commit *commit)
 {
-	struct commit_list *i, *j, *k, *ret = NULL;
+	struct object_id oid;
+	struct rev_collect revs;
+	struct commit_list *bases;
+	int i;
+	struct commit *ret = NULL;
 
-	if (!in)
-		return ret;
+	memset(&revs, 0, sizeof(revs));
+	revs.initial = 1;
+	for_each_reflog_ent(refname, collect_one_reflog_ent, &revs);
 
-	commit_list_insert(in->item, &ret);
+	if (!revs.nr && !get_oid(refname, &oid))
+		add_one_commit(&oid, &revs);
 
-	for (i = in->next; i; i = i->next) {
-		struct commit_list *new_commits = NULL, *end = NULL;
-
-		for (j = ret; j; j = j->next) {
-			struct commit_list *bases;
-			bases = get_merge_bases(i->item, j->item);
-			if (!new_commits)
-				new_commits = bases;
-			else
-				end->next = bases;
-			for (k = bases; k; k = k->next)
-				end = k;
-		}
-		ret = new_commits;
-	}
-	return ret;
-}
+	for (i = 0; i < revs.nr; i++)
+		revs.commit[i]->object.flags &= ~TMP_MARK;
+
+	bases = get_merge_bases_many(commit, revs.nr, revs.commit);
 
-static int remove_redundant(struct commit **array, int cnt)
-{
 	/*
-	 * Some commit in the array may be an ancestor of
-	 * another commit.  Move such commit to the end of
-	 * the array, and return the number of commits that
-	 * are independent from each other.
+	 * There should be one and only one merge base, when we found
+	 * a common ancestor among reflog entries.
 	 */
-	struct commit **work;
-	unsigned char *redundant;
-	int *filled_index;
-	int i, j, filled;
-
-	work = xcalloc(cnt, sizeof(*work));
-	redundant = xcalloc(cnt, 1);
-	ALLOC_ARRAY(filled_index, cnt - 1);
-
-	for (i = 0; i < cnt; i++)
-		parse_commit(array[i]);
-	for (i = 0; i < cnt; i++) {
-		struct commit_list *common;
-
-		if (redundant[i])
-			continue;
-		for (j = filled = 0; j < cnt; j++) {
-			if (i == j || redundant[j])
-				continue;
-			filled_index[filled] = j;
-			work[filled++] = array[j];
-		}
-		common = paint_down_to_common(array[i], filled, work);
-		if (array[i]->object.flags & PARENT2)
-			redundant[i] = 1;
-		for (j = 0; j < filled; j++)
-			if (work[j]->object.flags & PARENT1)
-				redundant[filled_index[j]] = 1;
-		clear_commit_marks(array[i], all_flags);
-		clear_commit_marks_many(filled, work, all_flags);
-		free_commit_list(common);
-	}
-
-	/* Now collect the result */
-	COPY_ARRAY(work, array, cnt);
-	for (i = filled = 0; i < cnt; i++)
-		if (!redundant[i])
-			array[filled++] = work[i];
-	for (j = filled, i = 0; i < cnt; i++)
-		if (redundant[i])
-			array[j++] = work[i];
-	free(work);
-	free(redundant);
-	free(filled_index);
-	return filled;
-}
-
-static struct commit_list *get_merge_bases_many_0(struct commit *one,
-						  int n,
-						  struct commit **twos,
-						  int cleanup)
-{
-	struct commit_list *list;
-	struct commit **rslt;
-	struct commit_list *result;
-	int cnt, i;
-
-	result = merge_bases_many(one, n, twos);
-	for (i = 0; i < n; i++) {
-		if (one == twos[i])
-			return result;
-	}
-	if (!result || !result->next) {
-		if (cleanup) {
-			clear_commit_marks(one, all_flags);
-			clear_commit_marks_many(n, twos, all_flags);
-		}
-		return result;
-	}
-
-	/* There are more than one */
-	cnt = commit_list_count(result);
-	rslt = xcalloc(cnt, sizeof(*rslt));
-	for (list = result, i = 0; list; list = list->next)
-		rslt[i++] = list->item;
-	free_commit_list(result);
-
-	clear_commit_marks(one, all_flags);
-	clear_commit_marks_many(n, twos, all_flags);
-
-	cnt = remove_redundant(rslt, cnt);
-	result = NULL;
-	for (i = 0; i < cnt; i++)
-		commit_list_insert_by_date(rslt[i], &result);
-	free(rslt);
-	return result;
-}
-
-struct commit_list *get_merge_bases_many(struct commit *one,
-					 int n,
-					 struct commit **twos)
-{
-	return get_merge_bases_many_0(one, n, twos, 1);
-}
+	if (!bases || bases->next)
+		goto cleanup_return;
 
-struct commit_list *get_merge_bases_many_dirty(struct commit *one,
-					       int n,
-					       struct commit **twos)
-{
-	return get_merge_bases_many_0(one, n, twos, 0);
-}
+	/* And the found one must be one of the reflog entries */
+	for (i = 0; i < revs.nr; i++)
+		if (&bases->item->object == &revs.commit[i]->object)
+			break; /* found */
+	if (revs.nr <= i)
+		goto cleanup_return;
 
-struct commit_list *get_merge_bases(struct commit *one, struct commit *two)
-{
-	return get_merge_bases_many_0(one, 1, &two, 1);
-}
-
-/*
- * Is "commit" a descendant of one of the elements on the "with_commit" list?
- */
-int is_descendant_of(struct commit *commit, struct commit_list *with_commit)
-{
-	if (!with_commit)
-		return 1;
-	while (with_commit) {
-		struct commit *other;
-
-		other = with_commit->item;
-		with_commit = with_commit->next;
-		if (in_merge_bases(other, commit))
-			return 1;
-	}
-	return 0;
-}
-
-/*
- * Is "commit" an ancestor of one of the "references"?
- */
-int in_merge_bases_many(struct commit *commit, int nr_reference, struct commit **reference)
-{
-	struct commit_list *bases;
-	int ret = 0, i;
+	ret = bases->item;
 
-	if (parse_commit(commit))
-		return ret;
-	for (i = 0; i < nr_reference; i++)
-		if (parse_commit(reference[i]))
-			return ret;
-
-	bases = paint_down_to_common(commit, nr_reference, reference);
-	if (commit->object.flags & PARENT2)
-		ret = 1;
-	clear_commit_marks(commit, all_flags);
-	clear_commit_marks_many(nr_reference, reference, all_flags);
+cleanup_return:
 	free_commit_list(bases);
 	return ret;
 }
 
-/*
- * Is "commit" an ancestor of (i.e. reachable from) the "reference"?
- */
-int in_merge_bases(struct commit *commit, struct commit *reference)
-{
-	return in_merge_bases_many(commit, 1, &reference);
-}
-
-struct commit_list *reduce_heads(struct commit_list *heads)
-{
-	struct commit_list *p;
-	struct commit_list *result = NULL, **tail = &result;
-	struct commit **array;
-	int num_head, i;
-
-	if (!heads)
-		return NULL;
-
-	/* Uniquify */
-	for (p = heads; p; p = p->next)
-		p->item->object.flags &= ~STALE;
-	for (p = heads, num_head = 0; p; p = p->next) {
-		if (p->item->object.flags & STALE)
-			continue;
-		p->item->object.flags |= STALE;
-		num_head++;
-	}
-	array = xcalloc(num_head, sizeof(*array));
-	for (p = heads, i = 0; p; p = p->next) {
-		if (p->item->object.flags & STALE) {
-			array[i++] = p->item;
-			p->item->object.flags &= ~STALE;
-		}
-	}
-	num_head = remove_redundant(array, num_head);
-	for (i = 0; i < num_head; i++)
-		tail = &commit_list_insert(array[i], tail)->next;
-	free(array);
-	return result;
-}
-
-void reduce_heads_replace(struct commit_list **heads)
-{
-	struct commit_list *result = reduce_heads(*heads);
-	free_commit_list(*heads);
-	*heads = result;
-}
-
 static const char gpg_sig_header[] = "gpgsig";
 static const int gpg_sig_header_len = sizeof(gpg_sig_header) - 1;
 
@@ -1287,7 +1136,33 @@ int check_commit_signature(const struct
 	return ret;
 }
 
+void verify_merge_signature(struct commit *commit, int verbosity)
+{
+	char hex[GIT_MAX_HEXSZ + 1];
+	struct signature_check signature_check;
+	memset(&signature_check, 0, sizeof(signature_check));
+
+	check_commit_signature(commit, &signature_check);
 
+	find_unique_abbrev_r(hex, &commit->object.oid, DEFAULT_ABBREV);
+	switch (signature_check.result) {
+	case 'G':
+		break;
+	case 'U':
+		die(_("Commit %s has an untrusted GPG signature, "
+		      "allegedly by %s."), hex, signature_check.signer);
+	case 'B':
+		die(_("Commit %s has a bad GPG signature "
+		      "allegedly by %s."), hex, signature_check.signer);
+	default: /* 'N' */
+		die(_("Commit %s does not have a GPG signature."), hex);
+	}
+	if (verbosity >= 0 && signature_check.result == 'G')
+		printf(_("Commit %s has a good GPG signature by %s\n"),
+		       hex, signature_check.signer);
+
+	signature_check_clear(&signature_check);
+}
 
 void append_merge_tag_headers(struct commit_list *parents,
 			      struct commit_extra_header ***tail)
@@ -1605,13 +1480,21 @@ out:
 	return result;
 }
 
+define_commit_slab(merge_desc_slab, struct merge_remote_desc *);
+static struct merge_desc_slab merge_desc_slab = COMMIT_SLAB_INIT(1, merge_desc_slab);
+
+struct merge_remote_desc *merge_remote_util(struct commit *commit)
+{
+	return *merge_desc_slab_at(&merge_desc_slab, commit);
+}
+
 void set_merge_remote_desc(struct commit *commit,
 			   const char *name, struct object *obj)
 {
 	struct merge_remote_desc *desc;
 	FLEX_ALLOC_STR(desc, name, name);
 	desc->obj = obj;
-	commit->util = desc;
+	*merge_desc_slab_at(&merge_desc_slab, commit) = desc;
 }
 
 struct commit *get_merge_parent(const char *name)
@@ -1621,9 +1504,9 @@ struct commit *get_merge_parent(const ch
 	struct object_id oid;
 	if (get_oid(name, &oid))
 		return NULL;
-	obj = parse_object(&oid);
+	obj = parse_object(the_repository, &oid);
 	commit = (struct commit *)peel_to_type(name, 0, obj, OBJ_COMMIT);
-	if (commit && !commit->util)
+	if (commit && !merge_remote_util(commit))
 		set_merge_remote_desc(commit, name, obj);
 	return commit;
 }
@@ -1687,10 +1570,10 @@ const char *find_commit_header(const cha
  * Returns the number of bytes from the tail to ignore, to be fed as
  * the second parameter to append_signoff().
  */
-int ignore_non_trailer(const char *buf, size_t len)
+size_t ignore_non_trailer(const char *buf, size_t len)
 {
-	int boc = 0;
-	int bol = 0;
+	size_t boc = 0;
+	size_t bol = 0;
 	int in_old_conflicts_block = 0;
 	size_t cutoff = wt_status_locate_end(buf, len);
 
@@ -1722,3 +1605,26 @@ int ignore_non_trailer(const char *buf,
 	}
 	return boc ? len - boc : len - cutoff;
 }
+
+int run_commit_hook(int editor_is_used, const char *index_file,
+		    const char *name, ...)
+{
+	struct argv_array hook_env = ARGV_ARRAY_INIT;
+	va_list args;
+	int ret;
+
+	argv_array_pushf(&hook_env, "GIT_INDEX_FILE=%s", index_file);
+
+	/*
+	 * Let the hook know that no editor will be launched.
+	 */
+	if (!editor_is_used)
+		argv_array_push(&hook_env, "GIT_EDITOR=:");
+
+	va_start(args, name);
+	ret = run_hook_ve(hook_env.argv,name, args);
+	va_end(args);
+	argv_array_clear(&hook_env);
+
+	return ret;
+}
diff -pruN 1.2.1+git2.18.0-1/git/commit-graph.c 1.2.3+git2.25.1-1/git/commit-graph.c
--- 1.2.1+git2.18.0-1/git/commit-graph.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/commit-graph.c	2020-02-17 04:47:35.000000000 +0000
@@ -1,47 +1,78 @@
 #include "cache.h"
 #include "config.h"
+#include "dir.h"
 #include "git-compat-util.h"
 #include "lockfile.h"
 #include "pack.h"
 #include "packfile.h"
 #include "commit.h"
 #include "object.h"
+#include "refs.h"
 #include "revision.h"
 #include "sha1-lookup.h"
 #include "commit-graph.h"
 #include "object-store.h"
+#include "alloc.h"
+#include "hashmap.h"
+#include "replace-object.h"
+#include "progress.h"
 
 #define GRAPH_SIGNATURE 0x43475048 /* "CGPH" */
 #define GRAPH_CHUNKID_OIDFANOUT 0x4f494446 /* "OIDF" */
 #define GRAPH_CHUNKID_OIDLOOKUP 0x4f49444c /* "OIDL" */
 #define GRAPH_CHUNKID_DATA 0x43444154 /* "CDAT" */
-#define GRAPH_CHUNKID_LARGEEDGES 0x45444745 /* "EDGE" */
+#define GRAPH_CHUNKID_EXTRAEDGES 0x45444745 /* "EDGE" */
+#define GRAPH_CHUNKID_BASE 0x42415345 /* "BASE" */
 
-#define GRAPH_DATA_WIDTH 36
+#define GRAPH_DATA_WIDTH (the_hash_algo->rawsz + 16)
 
 #define GRAPH_VERSION_1 0x1
 #define GRAPH_VERSION GRAPH_VERSION_1
 
-#define GRAPH_OID_VERSION_SHA1 1
-#define GRAPH_OID_LEN_SHA1 GIT_SHA1_RAWSZ
-#define GRAPH_OID_VERSION GRAPH_OID_VERSION_SHA1
-#define GRAPH_OID_LEN GRAPH_OID_LEN_SHA1
-
-#define GRAPH_OCTOPUS_EDGES_NEEDED 0x80000000
-#define GRAPH_PARENT_MISSING 0x7fffffff
+#define GRAPH_EXTRA_EDGES_NEEDED 0x80000000
 #define GRAPH_EDGE_LAST_MASK 0x7fffffff
 #define GRAPH_PARENT_NONE 0x70000000
 
 #define GRAPH_LAST_EDGE 0x80000000
 
+#define GRAPH_HEADER_SIZE 8
 #define GRAPH_FANOUT_SIZE (4 * 256)
 #define GRAPH_CHUNKLOOKUP_WIDTH 12
-#define GRAPH_MIN_SIZE (5 * GRAPH_CHUNKLOOKUP_WIDTH + GRAPH_FANOUT_SIZE + \
-			GRAPH_OID_LEN + 8)
+#define GRAPH_MIN_SIZE (GRAPH_HEADER_SIZE + 4 * GRAPH_CHUNKLOOKUP_WIDTH \
+			+ GRAPH_FANOUT_SIZE + the_hash_algo->rawsz)
+
+/* Remember to update object flag allocation in object.h */
+#define REACHABLE       (1u<<15)
 
 char *get_commit_graph_filename(const char *obj_dir)
 {
-	return xstrfmt("%s/info/commit-graph", obj_dir);
+	char *filename = xstrfmt("%s/info/commit-graph", obj_dir);
+	char *normalized = xmalloc(strlen(filename) + 1);
+	normalize_path_copy(normalized, filename);
+	free(filename);
+	return normalized;
+}
+
+static char *get_split_graph_filename(const char *obj_dir,
+				      const char *oid_hex)
+{
+	char *filename = xstrfmt("%s/info/commit-graphs/graph-%s.graph",
+				 obj_dir,
+				 oid_hex);
+	char *normalized = xmalloc(strlen(filename) + 1);
+	normalize_path_copy(normalized, filename);
+	free(filename);
+	return normalized;
+}
+
+static char *get_chain_filename(const char *obj_dir)
+{
+	return xstrfmt("%s/info/commit-graphs/commit-graph-chain", obj_dir);
+}
+
+static uint8_t oid_version(void)
+{
+	return 1;
 }
 
 static struct commit_graph *alloc_commit_graph(void)
@@ -52,59 +83,137 @@ static struct commit_graph *alloc_commit
 	return g;
 }
 
-struct commit_graph *load_commit_graph_one(const char *graph_file)
+extern int read_replace_refs;
+
+static int commit_graph_compatible(struct repository *r)
+{
+	if (!r->gitdir)
+		return 0;
+
+	if (read_replace_refs) {
+		prepare_replace_object(r);
+		if (hashmap_get_size(&r->objects->replace_map->map))
+			return 0;
+	}
+
+	prepare_commit_graft(r);
+	if (r->parsed_objects && r->parsed_objects->grafts_nr)
+		return 0;
+	if (is_repository_shallow(r))
+		return 0;
+
+	return 1;
+}
+
+int open_commit_graph(const char *graph_file, int *fd, struct stat *st)
+{
+	*fd = git_open(graph_file);
+	if (*fd < 0)
+		return 0;
+	if (fstat(*fd, st)) {
+		close(*fd);
+		return 0;
+	}
+	return 1;
+}
+
+struct commit_graph *load_commit_graph_one_fd_st(int fd, struct stat *st)
 {
 	void *graph_map;
-	const unsigned char *data, *chunk_lookup;
 	size_t graph_size;
-	struct stat st;
+	struct commit_graph *ret;
+
+	graph_size = xsize_t(st->st_size);
+
+	if (graph_size < GRAPH_MIN_SIZE) {
+		close(fd);
+		error(_("commit-graph file is too small"));
+		return NULL;
+	}
+	graph_map = xmmap(NULL, graph_size, PROT_READ, MAP_PRIVATE, fd, 0);
+	ret = parse_commit_graph(graph_map, fd, graph_size);
+
+	if (!ret) {
+		munmap(graph_map, graph_size);
+		close(fd);
+	}
+
+	return ret;
+}
+
+static int verify_commit_graph_lite(struct commit_graph *g)
+{
+	/*
+	 * Basic validation shared between parse_commit_graph()
+	 * which'll be called every time the graph is used, and the
+	 * much more expensive verify_commit_graph() used by
+	 * "commit-graph verify".
+	 *
+	 * There should only be very basic checks here to ensure that
+	 * we don't e.g. segfault in fill_commit_in_graph(), but
+	 * because this is a very hot codepath nothing that e.g. loops
+	 * over g->num_commits, or runs a checksum on the commit-graph
+	 * itself.
+	 */
+	if (!g->chunk_oid_fanout) {
+		error("commit-graph is missing the OID Fanout chunk");
+		return 1;
+	}
+	if (!g->chunk_oid_lookup) {
+		error("commit-graph is missing the OID Lookup chunk");
+		return 1;
+	}
+	if (!g->chunk_commit_data) {
+		error("commit-graph is missing the Commit Data chunk");
+		return 1;
+	}
+
+	return 0;
+}
+
+struct commit_graph *parse_commit_graph(void *graph_map, int fd,
+					size_t graph_size)
+{
+	const unsigned char *data, *chunk_lookup;
 	uint32_t i;
 	struct commit_graph *graph;
-	int fd = git_open(graph_file);
 	uint64_t last_chunk_offset;
 	uint32_t last_chunk_id;
 	uint32_t graph_signature;
 	unsigned char graph_version, hash_version;
 
-	if (fd < 0)
+	if (!graph_map)
 		return NULL;
-	if (fstat(fd, &st)) {
-		close(fd);
+
+	if (graph_size < GRAPH_MIN_SIZE)
 		return NULL;
-	}
-	graph_size = xsize_t(st.st_size);
 
-	if (graph_size < GRAPH_MIN_SIZE) {
-		close(fd);
-		die("graph file %s is too small", graph_file);
-	}
-	graph_map = xmmap(NULL, graph_size, PROT_READ, MAP_PRIVATE, fd, 0);
 	data = (const unsigned char *)graph_map;
 
 	graph_signature = get_be32(data);
 	if (graph_signature != GRAPH_SIGNATURE) {
-		error("graph signature %X does not match signature %X",
+		error(_("commit-graph signature %X does not match signature %X"),
 		      graph_signature, GRAPH_SIGNATURE);
-		goto cleanup_fail;
+		return NULL;
 	}
 
 	graph_version = *(unsigned char*)(data + 4);
 	if (graph_version != GRAPH_VERSION) {
-		error("graph version %X does not match version %X",
+		error(_("commit-graph version %X does not match version %X"),
 		      graph_version, GRAPH_VERSION);
-		goto cleanup_fail;
+		return NULL;
 	}
 
 	hash_version = *(unsigned char*)(data + 5);
-	if (hash_version != GRAPH_OID_VERSION) {
-		error("hash version %X does not match version %X",
-		      hash_version, GRAPH_OID_VERSION);
-		goto cleanup_fail;
+	if (hash_version != oid_version()) {
+		error(_("commit-graph hash version %X does not match version %X"),
+		      hash_version, oid_version());
+		return NULL;
 	}
 
 	graph = alloc_commit_graph();
 
-	graph->hash_len = GRAPH_OID_LEN;
+	graph->hash_len = the_hash_algo->rawsz;
 	graph->num_chunks = *(unsigned char*)(data + 6);
 	graph->graph_fd = fd;
 	graph->data = graph_map;
@@ -114,16 +223,27 @@ struct commit_graph *load_commit_graph_o
 	last_chunk_offset = 8;
 	chunk_lookup = data + 8;
 	for (i = 0; i < graph->num_chunks; i++) {
-		uint32_t chunk_id = get_be32(chunk_lookup + 0);
-		uint64_t chunk_offset = get_be64(chunk_lookup + 4);
+		uint32_t chunk_id;
+		uint64_t chunk_offset;
 		int chunk_repeated = 0;
 
+		if (data + graph_size - chunk_lookup <
+		    GRAPH_CHUNKLOOKUP_WIDTH) {
+			error(_("commit-graph chunk lookup table entry missing; file may be incomplete"));
+			free(graph);
+			return NULL;
+		}
+
+		chunk_id = get_be32(chunk_lookup + 0);
+		chunk_offset = get_be64(chunk_lookup + 4);
+
 		chunk_lookup += GRAPH_CHUNKLOOKUP_WIDTH;
 
-		if (chunk_offset > graph_size - GIT_MAX_RAWSZ) {
-			error("improper chunk offset %08x%08x", (uint32_t)(chunk_offset >> 32),
+		if (chunk_offset > graph_size - the_hash_algo->rawsz) {
+			error(_("commit-graph improper chunk offset %08x%08x"), (uint32_t)(chunk_offset >> 32),
 			      (uint32_t)chunk_offset);
-			goto cleanup_fail;
+			free(graph);
+			return NULL;
 		}
 
 		switch (chunk_id) {
@@ -148,17 +268,24 @@ struct commit_graph *load_commit_graph_o
 				graph->chunk_commit_data = data + chunk_offset;
 			break;
 
-		case GRAPH_CHUNKID_LARGEEDGES:
-			if (graph->chunk_large_edges)
+		case GRAPH_CHUNKID_EXTRAEDGES:
+			if (graph->chunk_extra_edges)
 				chunk_repeated = 1;
 			else
-				graph->chunk_large_edges = data + chunk_offset;
+				graph->chunk_extra_edges = data + chunk_offset;
 			break;
+
+		case GRAPH_CHUNKID_BASE:
+			if (graph->chunk_base_graphs)
+				chunk_repeated = 1;
+			else
+				graph->chunk_base_graphs = data + chunk_offset;
 		}
 
 		if (chunk_repeated) {
-			error("chunk id %08x appears multiple times", chunk_id);
-			goto cleanup_fail;
+			error(_("commit-graph chunk id %08x appears multiple times"), chunk_id);
+			free(graph);
+			return NULL;
 		}
 
 		if (last_chunk_id == GRAPH_CHUNKID_OIDLOOKUP)
@@ -171,61 +298,248 @@ struct commit_graph *load_commit_graph_o
 		last_chunk_offset = chunk_offset;
 	}
 
+	hashcpy(graph->oid.hash, graph->data + graph->data_len - graph->hash_len);
+
+	if (verify_commit_graph_lite(graph)) {
+		free(graph);
+		return NULL;
+	}
+
 	return graph;
+}
+
+static struct commit_graph *load_commit_graph_one(const char *graph_file)
+{
+
+	struct stat st;
+	int fd;
+	struct commit_graph *g;
+	int open_ok = open_commit_graph(graph_file, &fd, &st);
+
+	if (!open_ok)
+		return NULL;
+
+	g = load_commit_graph_one_fd_st(fd, &st);
 
-cleanup_fail:
-	munmap(graph_map, graph_size);
-	close(fd);
-	exit(1);
+	if (g)
+		g->filename = xstrdup(graph_file);
+
+	return g;
 }
 
-/* global storage */
-static struct commit_graph *commit_graph = NULL;
+static struct commit_graph *load_commit_graph_v1(struct repository *r, const char *obj_dir)
+{
+	char *graph_name = get_commit_graph_filename(obj_dir);
+	struct commit_graph *g = load_commit_graph_one(graph_name);
+	free(graph_name);
+
+	if (g)
+		g->obj_dir = obj_dir;
+
+	return g;
+}
 
-static void prepare_commit_graph_one(const char *obj_dir)
+static int add_graph_to_chain(struct commit_graph *g,
+			      struct commit_graph *chain,
+			      struct object_id *oids,
+			      int n)
 {
-	char *graph_name;
+	struct commit_graph *cur_g = chain;
 
-	if (commit_graph)
-		return;
+	if (n && !g->chunk_base_graphs) {
+		warning(_("commit-graph has no base graphs chunk"));
+		return 0;
+	}
+
+	while (n) {
+		n--;
+
+		if (!cur_g ||
+		    !oideq(&oids[n], &cur_g->oid) ||
+		    !hasheq(oids[n].hash, g->chunk_base_graphs + g->hash_len * n)) {
+			warning(_("commit-graph chain does not match"));
+			return 0;
+		}
 
-	graph_name = get_commit_graph_filename(obj_dir);
-	commit_graph = load_commit_graph_one(graph_name);
+		cur_g = cur_g->base_graph;
+	}
+
+	g->base_graph = chain;
 
-	FREE_AND_NULL(graph_name);
+	if (chain)
+		g->num_commits_in_base = chain->num_commits + chain->num_commits_in_base;
+
+	return 1;
 }
 
-static int prepare_commit_graph_run_once = 0;
-static void prepare_commit_graph(void)
+static struct commit_graph *load_commit_graph_chain(struct repository *r, const char *obj_dir)
 {
-	struct alternate_object_database *alt;
-	char *obj_dir;
+	struct commit_graph *graph_chain = NULL;
+	struct strbuf line = STRBUF_INIT;
+	struct stat st;
+	struct object_id *oids;
+	int i = 0, valid = 1, count;
+	char *chain_name = get_chain_filename(obj_dir);
+	FILE *fp;
+	int stat_res;
+
+	fp = fopen(chain_name, "r");
+	stat_res = stat(chain_name, &st);
+	free(chain_name);
+
+	if (!fp ||
+	    stat_res ||
+	    st.st_size <= the_hash_algo->hexsz)
+		return NULL;
+
+	count = st.st_size / (the_hash_algo->hexsz + 1);
+	oids = xcalloc(count, sizeof(struct object_id));
+
+	prepare_alt_odb(r);
+
+	for (i = 0; i < count; i++) {
+		struct object_directory *odb;
+
+		if (strbuf_getline_lf(&line, fp) == EOF)
+			break;
+
+		if (get_oid_hex(line.buf, &oids[i])) {
+			warning(_("invalid commit-graph chain: line '%s' not a hash"),
+				line.buf);
+			valid = 0;
+			break;
+		}
+
+		valid = 0;
+		for (odb = r->objects->odb; odb; odb = odb->next) {
+			char *graph_name = get_split_graph_filename(odb->path, line.buf);
+			struct commit_graph *g = load_commit_graph_one(graph_name);
+
+			free(graph_name);
+
+			if (g) {
+				g->obj_dir = odb->path;
+
+				if (add_graph_to_chain(g, graph_chain, oids, i)) {
+					graph_chain = g;
+					valid = 1;
+				}
+
+				break;
+			}
+		}
+
+		if (!valid) {
+			warning(_("unable to find all commit-graph files"));
+			break;
+		}
+	}
 
-	if (prepare_commit_graph_run_once)
+	free(oids);
+	fclose(fp);
+	strbuf_release(&line);
+
+	return graph_chain;
+}
+
+struct commit_graph *read_commit_graph_one(struct repository *r, const char *obj_dir)
+{
+	struct commit_graph *g = load_commit_graph_v1(r, obj_dir);
+
+	if (!g)
+		g = load_commit_graph_chain(r, obj_dir);
+
+	return g;
+}
+
+static void prepare_commit_graph_one(struct repository *r, const char *obj_dir)
+{
+
+	if (r->objects->commit_graph)
 		return;
-	prepare_commit_graph_run_once = 1;
 
-	obj_dir = get_object_directory();
-	prepare_commit_graph_one(obj_dir);
-	prepare_alt_odb(the_repository);
-	for (alt = the_repository->objects->alt_odb_list;
-	     !commit_graph && alt;
-	     alt = alt->next)
-		prepare_commit_graph_one(alt->path);
+	r->objects->commit_graph = read_commit_graph_one(r, obj_dir);
+}
+
+/*
+ * Return 1 if commit_graph is non-NULL, and 0 otherwise.
+ *
+ * On the first invocation, this function attempts to load the commit
+ * graph if the_repository is configured to have one.
+ */
+static int prepare_commit_graph(struct repository *r)
+{
+	struct object_directory *odb;
+
+	/*
+	 * This must come before the "already attempted?" check below, because
+	 * we want to disable even an already-loaded graph file.
+	 */
+	if (r->commit_graph_disabled)
+		return 0;
+
+	if (r->objects->commit_graph_attempted)
+		return !!r->objects->commit_graph;
+	r->objects->commit_graph_attempted = 1;
+
+	if (git_env_bool(GIT_TEST_COMMIT_GRAPH_DIE_ON_LOAD, 0))
+		die("dying as requested by the '%s' variable on commit-graph load!",
+		    GIT_TEST_COMMIT_GRAPH_DIE_ON_LOAD);
+
+	prepare_repo_settings(r);
+
+	if (!git_env_bool(GIT_TEST_COMMIT_GRAPH, 0) &&
+	    r->settings.core_commit_graph != 1)
+		/*
+		 * This repository is not configured to use commit graphs, so
+		 * do not load one. (But report commit_graph_attempted anyway
+		 * so that commit graph loading is not attempted again for this
+		 * repository.)
+		 */
+		return 0;
+
+	if (!commit_graph_compatible(r))
+		return 0;
+
+	prepare_alt_odb(r);
+	for (odb = r->objects->odb;
+	     !r->objects->commit_graph && odb;
+	     odb = odb->next)
+		prepare_commit_graph_one(r, odb->path);
+	return !!r->objects->commit_graph;
+}
+
+int generation_numbers_enabled(struct repository *r)
+{
+	uint32_t first_generation;
+	struct commit_graph *g;
+	if (!prepare_commit_graph(r))
+	       return 0;
+
+	g = r->objects->commit_graph;
+
+	if (!g->num_commits)
+		return 0;
+
+	first_generation = get_be32(g->chunk_commit_data +
+				    g->hash_len + 8) >> 2;
+
+	return !!first_generation;
 }
 
-static void close_commit_graph(void)
+static void close_commit_graph_one(struct commit_graph *g)
 {
-	if (!commit_graph)
+	if (!g)
 		return;
 
-	if (commit_graph->graph_fd >= 0) {
-		munmap((void *)commit_graph->data, commit_graph->data_len);
-		commit_graph->data = NULL;
-		close(commit_graph->graph_fd);
-	}
+	close_commit_graph_one(g->base_graph);
+	free_commit_graph(g);
+}
 
-	FREE_AND_NULL(commit_graph);
+void close_commit_graph(struct raw_object_store *o)
+{
+	close_commit_graph_one(o->commit_graph);
+	o->commit_graph = NULL;
 }
 
 static int bsearch_graph(struct commit_graph *g, struct object_id *oid, uint32_t *pos)
@@ -234,57 +548,120 @@ static int bsearch_graph(struct commit_g
 			    g->chunk_oid_lookup, g->hash_len, pos);
 }
 
-static struct commit_list **insert_parent_or_die(struct commit_graph *g,
-						 uint64_t pos,
+static void load_oid_from_graph(struct commit_graph *g,
+				uint32_t pos,
+				struct object_id *oid)
+{
+	uint32_t lex_index;
+
+	while (g && pos < g->num_commits_in_base)
+		g = g->base_graph;
+
+	if (!g)
+		BUG("NULL commit-graph");
+
+	if (pos >= g->num_commits + g->num_commits_in_base)
+		die(_("invalid commit position. commit-graph is likely corrupt"));
+
+	lex_index = pos - g->num_commits_in_base;
+
+	hashcpy(oid->hash, g->chunk_oid_lookup + g->hash_len * lex_index);
+}
+
+static struct commit_list **insert_parent_or_die(struct repository *r,
+						 struct commit_graph *g,
+						 uint32_t pos,
 						 struct commit_list **pptr)
 {
 	struct commit *c;
 	struct object_id oid;
-	hashcpy(oid.hash, g->chunk_oid_lookup + g->hash_len * pos);
-	c = lookup_commit(&oid);
+
+	if (pos >= g->num_commits + g->num_commits_in_base)
+		die("invalid parent position %"PRIu32, pos);
+
+	load_oid_from_graph(g, pos, &oid);
+	c = lookup_commit(r, &oid);
 	if (!c)
-		die("could not find commit %s", oid_to_hex(&oid));
+		die(_("could not find commit %s"), oid_to_hex(&oid));
 	c->graph_pos = pos;
 	return &commit_list_insert(c, pptr)->next;
 }
 
-static int fill_commit_in_graph(struct commit *item, struct commit_graph *g, uint32_t pos)
+static void fill_commit_graph_info(struct commit *item, struct commit_graph *g, uint32_t pos)
+{
+	const unsigned char *commit_data;
+	uint32_t lex_index;
+
+	while (pos < g->num_commits_in_base)
+		g = g->base_graph;
+
+	lex_index = pos - g->num_commits_in_base;
+	commit_data = g->chunk_commit_data + GRAPH_DATA_WIDTH * lex_index;
+	item->graph_pos = pos;
+	item->generation = get_be32(commit_data + g->hash_len + 8) >> 2;
+}
+
+static inline void set_commit_tree(struct commit *c, struct tree *t)
+{
+	c->maybe_tree = t;
+}
+
+static int fill_commit_in_graph(struct repository *r,
+				struct commit *item,
+				struct commit_graph *g, uint32_t pos)
 {
 	uint32_t edge_value;
 	uint32_t *parent_data_ptr;
 	uint64_t date_low, date_high;
 	struct commit_list **pptr;
-	const unsigned char *commit_data = g->chunk_commit_data + (g->hash_len + 16) * pos;
+	const unsigned char *commit_data;
+	uint32_t lex_index;
 
-	item->object.parsed = 1;
+	while (pos < g->num_commits_in_base)
+		g = g->base_graph;
+
+	if (pos >= g->num_commits + g->num_commits_in_base)
+		die(_("invalid commit position. commit-graph is likely corrupt"));
+
+	/*
+	 * Store the "full" position, but then use the
+	 * "local" position for the rest of the calculation.
+	 */
 	item->graph_pos = pos;
+	lex_index = pos - g->num_commits_in_base;
+
+	commit_data = g->chunk_commit_data + (g->hash_len + 16) * lex_index;
+
+	item->object.parsed = 1;
 
-	item->maybe_tree = NULL;
+	set_commit_tree(item, NULL);
 
 	date_high = get_be32(commit_data + g->hash_len + 8) & 0x3;
 	date_low = get_be32(commit_data + g->hash_len + 12);
 	item->date = (timestamp_t)((date_high << 32) | date_low);
 
+	item->generation = get_be32(commit_data + g->hash_len + 8) >> 2;
+
 	pptr = &item->parents;
 
 	edge_value = get_be32(commit_data + g->hash_len);
 	if (edge_value == GRAPH_PARENT_NONE)
 		return 1;
-	pptr = insert_parent_or_die(g, edge_value, pptr);
+	pptr = insert_parent_or_die(r, g, edge_value, pptr);
 
 	edge_value = get_be32(commit_data + g->hash_len + 4);
 	if (edge_value == GRAPH_PARENT_NONE)
 		return 1;
-	if (!(edge_value & GRAPH_OCTOPUS_EDGES_NEEDED)) {
-		pptr = insert_parent_or_die(g, edge_value, pptr);
+	if (!(edge_value & GRAPH_EXTRA_EDGES_NEEDED)) {
+		pptr = insert_parent_or_die(r, g, edge_value, pptr);
 		return 1;
 	}
 
-	parent_data_ptr = (uint32_t*)(g->chunk_large_edges +
+	parent_data_ptr = (uint32_t*)(g->chunk_extra_edges +
 			  4 * (uint64_t)(edge_value & GRAPH_EDGE_LAST_MASK));
 	do {
 		edge_value = get_be32(parent_data_ptr);
-		pptr = insert_parent_or_die(g,
+		pptr = insert_parent_or_die(r, g,
 					    edge_value & GRAPH_EDGE_LAST_MASK,
 					    pptr);
 		parent_data_ptr++;
@@ -293,59 +670,140 @@ static int fill_commit_in_graph(struct c
 	return 1;
 }
 
-int parse_commit_in_graph(struct commit *item)
+static int find_commit_in_graph(struct commit *item, struct commit_graph *g, uint32_t *pos)
 {
-	if (!core_commit_graph)
-		return 0;
-	if (item->object.parsed)
+	if (item->graph_pos != COMMIT_NOT_FROM_GRAPH) {
+		*pos = item->graph_pos;
 		return 1;
-
-	prepare_commit_graph();
-	if (commit_graph) {
-		uint32_t pos;
-		int found;
-		if (item->graph_pos != COMMIT_NOT_FROM_GRAPH) {
-			pos = item->graph_pos;
-			found = 1;
-		} else {
-			found = bsearch_graph(commit_graph, &(item->object.oid), &pos);
+	} else {
+		struct commit_graph *cur_g = g;
+		uint32_t lex_index;
+
+		while (cur_g && !bsearch_graph(cur_g, &(item->object.oid), &lex_index))
+			cur_g = cur_g->base_graph;
+
+		if (cur_g) {
+			*pos = lex_index + cur_g->num_commits_in_base;
+			return 1;
 		}
 
-		if (found)
-			return fill_commit_in_graph(item, commit_graph, pos);
+		return 0;
 	}
+}
+
+static int parse_commit_in_graph_one(struct repository *r,
+				     struct commit_graph *g,
+				     struct commit *item)
+{
+	uint32_t pos;
+
+	if (item->object.parsed)
+		return 1;
+
+	if (find_commit_in_graph(item, g, &pos))
+		return fill_commit_in_graph(r, item, g, pos);
 
 	return 0;
 }
 
-static struct tree *load_tree_for_commit(struct commit_graph *g, struct commit *c)
+int parse_commit_in_graph(struct repository *r, struct commit *item)
+{
+	if (!prepare_commit_graph(r))
+		return 0;
+	return parse_commit_in_graph_one(r, r->objects->commit_graph, item);
+}
+
+void load_commit_graph_info(struct repository *r, struct commit *item)
+{
+	uint32_t pos;
+	if (!prepare_commit_graph(r))
+		return;
+	if (find_commit_in_graph(item, r->objects->commit_graph, &pos))
+		fill_commit_graph_info(item, r->objects->commit_graph, pos);
+}
+
+static struct tree *load_tree_for_commit(struct repository *r,
+					 struct commit_graph *g,
+					 struct commit *c)
 {
 	struct object_id oid;
-	const unsigned char *commit_data = g->chunk_commit_data +
-					   GRAPH_DATA_WIDTH * (c->graph_pos);
+	const unsigned char *commit_data;
+
+	while (c->graph_pos < g->num_commits_in_base)
+		g = g->base_graph;
+
+	commit_data = g->chunk_commit_data +
+			GRAPH_DATA_WIDTH * (c->graph_pos - g->num_commits_in_base);
 
 	hashcpy(oid.hash, commit_data);
-	c->maybe_tree = lookup_tree(&oid);
+	set_commit_tree(c, lookup_tree(r, &oid));
 
 	return c->maybe_tree;
 }
 
-struct tree *get_commit_tree_in_graph(const struct commit *c)
+static struct tree *get_commit_tree_in_graph_one(struct repository *r,
+						 struct commit_graph *g,
+						 const struct commit *c)
 {
 	if (c->maybe_tree)
 		return c->maybe_tree;
 	if (c->graph_pos == COMMIT_NOT_FROM_GRAPH)
-		BUG("get_commit_tree_in_graph called from non-commit-graph commit");
+		BUG("get_commit_tree_in_graph_one called from non-commit-graph commit");
 
-	return load_tree_for_commit(commit_graph, (struct commit *)c);
+	return load_tree_for_commit(r, g, (struct commit *)c);
 }
 
+struct tree *get_commit_tree_in_graph(struct repository *r, const struct commit *c)
+{
+	return get_commit_tree_in_graph_one(r, r->objects->commit_graph, c);
+}
+
+struct packed_commit_list {
+	struct commit **list;
+	int nr;
+	int alloc;
+};
+
+struct packed_oid_list {
+	struct object_id *list;
+	int nr;
+	int alloc;
+};
+
+struct write_commit_graph_context {
+	struct repository *r;
+	char *obj_dir;
+	char *graph_name;
+	struct packed_oid_list oids;
+	struct packed_commit_list commits;
+	int num_extra_edges;
+	unsigned long approx_nr_objects;
+	struct progress *progress;
+	int progress_done;
+	uint64_t progress_cnt;
+
+	char *base_graph_name;
+	int num_commit_graphs_before;
+	int num_commit_graphs_after;
+	char **commit_graph_filenames_before;
+	char **commit_graph_filenames_after;
+	char **commit_graph_hash_after;
+	uint32_t new_num_commits_in_base;
+	struct commit_graph *new_base_graph;
+
+	unsigned append:1,
+		 report_progress:1,
+		 split:1,
+		 check_oids:1;
+
+	const struct split_commit_graph_opts *split_opts;
+};
+
 static void write_graph_chunk_fanout(struct hashfile *f,
-				     struct commit **commits,
-				     int nr_commits)
+				     struct write_commit_graph_context *ctx)
 {
 	int i, count = 0;
-	struct commit **list = commits;
+	struct commit **list = ctx->commits.list;
 
 	/*
 	 * Write the first-level table (the list is sorted,
@@ -353,9 +811,10 @@ static void write_graph_chunk_fanout(str
 	 * having to do eight extra binary search iterations).
 	 */
 	for (i = 0; i < 256; i++) {
-		while (count < nr_commits) {
+		while (count < ctx->commits.nr) {
 			if ((*list)->object.oid.hash[0] != i)
 				break;
+			display_progress(ctx->progress, ++ctx->progress_cnt);
 			count++;
 			list++;
 		}
@@ -365,12 +824,14 @@ static void write_graph_chunk_fanout(str
 }
 
 static void write_graph_chunk_oids(struct hashfile *f, int hash_len,
-				   struct commit **commits, int nr_commits)
+				   struct write_commit_graph_context *ctx)
 {
-	struct commit **list = commits;
+	struct commit **list = ctx->commits.list;
 	int count;
-	for (count = 0; count < nr_commits; count++, list++)
+	for (count = 0; count < ctx->commits.nr; count++, list++) {
+		display_progress(ctx->progress, ++ctx->progress_cnt);
 		hashwrite(f, (*list)->object.oid.hash, (int)hash_len);
+	}
 }
 
 static const unsigned char *commit_to_sha1(size_t index, void *table)
@@ -380,19 +841,24 @@ static const unsigned char *commit_to_sh
 }
 
 static void write_graph_chunk_data(struct hashfile *f, int hash_len,
-				   struct commit **commits, int nr_commits)
+				   struct write_commit_graph_context *ctx)
 {
-	struct commit **list = commits;
-	struct commit **last = commits + nr_commits;
+	struct commit **list = ctx->commits.list;
+	struct commit **last = ctx->commits.list + ctx->commits.nr;
 	uint32_t num_extra_edges = 0;
 
 	while (list < last) {
 		struct commit_list *parent;
+		struct object_id *tree;
 		int edge_value;
 		uint32_t packedDate[2];
+		display_progress(ctx->progress, ++ctx->progress_cnt);
 
-		parse_commit(*list);
-		hashwrite(f, get_commit_tree_oid(*list)->hash, hash_len);
+		if (parse_commit_no_graph(*list))
+			die(_("unable to parse commit %s"),
+				oid_to_hex(&(*list)->object.oid));
+		tree = get_commit_tree_oid(*list);
+		hashwrite(f, tree->hash, hash_len);
 
 		parent = (*list)->parents;
 
@@ -400,12 +866,24 @@ static void write_graph_chunk_data(struc
 			edge_value = GRAPH_PARENT_NONE;
 		else {
 			edge_value = sha1_pos(parent->item->object.oid.hash,
-					      commits,
-					      nr_commits,
+					      ctx->commits.list,
+					      ctx->commits.nr,
 					      commit_to_sha1);
 
+			if (edge_value >= 0)
+				edge_value += ctx->new_num_commits_in_base;
+			else {
+				uint32_t pos;
+				if (find_commit_in_graph(parent->item,
+							 ctx->new_base_graph,
+							 &pos))
+					edge_value = pos;
+			}
+
 			if (edge_value < 0)
-				edge_value = GRAPH_PARENT_MISSING;
+				BUG("missing parent %s for commit %s",
+				    oid_to_hex(&parent->item->object.oid),
+				    oid_to_hex(&(*list)->object.oid));
 		}
 
 		hashwrite_be32(f, edge_value);
@@ -416,19 +894,32 @@ static void write_graph_chunk_data(struc
 		if (!parent)
 			edge_value = GRAPH_PARENT_NONE;
 		else if (parent->next)
-			edge_value = GRAPH_OCTOPUS_EDGES_NEEDED | num_extra_edges;
+			edge_value = GRAPH_EXTRA_EDGES_NEEDED | num_extra_edges;
 		else {
 			edge_value = sha1_pos(parent->item->object.oid.hash,
-					      commits,
-					      nr_commits,
+					      ctx->commits.list,
+					      ctx->commits.nr,
 					      commit_to_sha1);
+
+			if (edge_value >= 0)
+				edge_value += ctx->new_num_commits_in_base;
+			else {
+				uint32_t pos;
+				if (find_commit_in_graph(parent->item,
+							 ctx->new_base_graph,
+							 &pos))
+					edge_value = pos;
+			}
+
 			if (edge_value < 0)
-				edge_value = GRAPH_PARENT_MISSING;
+				BUG("missing parent %s for commit %s",
+				    oid_to_hex(&parent->item->object.oid),
+				    oid_to_hex(&(*list)->object.oid));
 		}
 
 		hashwrite_be32(f, edge_value);
 
-		if (edge_value & GRAPH_OCTOPUS_EDGES_NEEDED) {
+		if (edge_value & GRAPH_EXTRA_EDGES_NEEDED) {
 			do {
 				num_extra_edges++;
 				parent = parent->next;
@@ -440,6 +931,8 @@ static void write_graph_chunk_data(struc
 		else
 			packedDate[0] = 0;
 
+		packedDate[0] |= htonl((*list)->generation << 2);
+
 		packedDate[1] = htonl((*list)->date);
 		hashwrite(f, packedDate, 8);
 
@@ -447,16 +940,18 @@ static void write_graph_chunk_data(struc
 	}
 }
 
-static void write_graph_chunk_large_edges(struct hashfile *f,
-					  struct commit **commits,
-					  int nr_commits)
+static void write_graph_chunk_extra_edges(struct hashfile *f,
+					  struct write_commit_graph_context *ctx)
 {
-	struct commit **list = commits;
-	struct commit **last = commits + nr_commits;
+	struct commit **list = ctx->commits.list;
+	struct commit **last = ctx->commits.list + ctx->commits.nr;
 	struct commit_list *parent;
 
 	while (list < last) {
 		int num_parents = 0;
+
+		display_progress(ctx->progress, ++ctx->progress_cnt);
+
 		for (parent = (*list)->parents; num_parents < 3 && parent;
 		     parent = parent->next)
 			num_parents++;
@@ -469,12 +964,24 @@ static void write_graph_chunk_large_edge
 		/* Since num_parents > 2, this initializer is safe. */
 		for (parent = (*list)->parents->next; parent; parent = parent->next) {
 			int edge_value = sha1_pos(parent->item->object.oid.hash,
-						  commits,
-						  nr_commits,
+						  ctx->commits.list,
+						  ctx->commits.nr,
 						  commit_to_sha1);
 
+			if (edge_value >= 0)
+				edge_value += ctx->new_num_commits_in_base;
+			else {
+				uint32_t pos;
+				if (find_commit_in_graph(parent->item,
+							 ctx->new_base_graph,
+							 &pos))
+					edge_value = pos;
+			}
+
 			if (edge_value < 0)
-				edge_value = GRAPH_PARENT_MISSING;
+				BUG("missing parent %s for commit %s",
+				    oid_to_hex(&parent->item->object.oid),
+				    oid_to_hex(&(*list)->object.oid));
 			else if (!parent->next)
 				edge_value |= GRAPH_LAST_EDGE;
 
@@ -485,257 +992,450 @@ static void write_graph_chunk_large_edge
 	}
 }
 
-static int commit_compare(const void *_a, const void *_b)
+static int oid_compare(const void *_a, const void *_b)
 {
 	const struct object_id *a = (const struct object_id *)_a;
 	const struct object_id *b = (const struct object_id *)_b;
 	return oidcmp(a, b);
 }
 
-struct packed_commit_list {
-	struct commit **list;
-	int nr;
-	int alloc;
-};
-
-struct packed_oid_list {
-	struct object_id *list;
-	int nr;
-	int alloc;
-};
-
 static int add_packed_commits(const struct object_id *oid,
 			      struct packed_git *pack,
 			      uint32_t pos,
 			      void *data)
 {
-	struct packed_oid_list *list = (struct packed_oid_list*)data;
+	struct write_commit_graph_context *ctx = (struct write_commit_graph_context*)data;
 	enum object_type type;
 	off_t offset = nth_packed_object_offset(pack, pos);
 	struct object_info oi = OBJECT_INFO_INIT;
 
+	if (ctx->progress)
+		display_progress(ctx->progress, ++ctx->progress_done);
+
 	oi.typep = &type;
-	if (packed_object_info(the_repository, pack, offset, &oi) < 0)
-		die("unable to get type of object %s", oid_to_hex(oid));
+	if (packed_object_info(ctx->r, pack, offset, &oi) < 0)
+		die(_("unable to get type of object %s"), oid_to_hex(oid));
 
 	if (type != OBJ_COMMIT)
 		return 0;
 
-	ALLOC_GROW(list->list, list->nr + 1, list->alloc);
-	oidcpy(&(list->list[list->nr]), oid);
-	list->nr++;
+	ALLOC_GROW(ctx->oids.list, ctx->oids.nr + 1, ctx->oids.alloc);
+	oidcpy(&(ctx->oids.list[ctx->oids.nr]), oid);
+	ctx->oids.nr++;
 
 	return 0;
 }
 
-static void add_missing_parents(struct packed_oid_list *oids, struct commit *commit)
+static void add_missing_parents(struct write_commit_graph_context *ctx, struct commit *commit)
 {
 	struct commit_list *parent;
 	for (parent = commit->parents; parent; parent = parent->next) {
-		if (!(parent->item->object.flags & UNINTERESTING)) {
-			ALLOC_GROW(oids->list, oids->nr + 1, oids->alloc);
-			oidcpy(&oids->list[oids->nr], &(parent->item->object.oid));
-			oids->nr++;
-			parent->item->object.flags |= UNINTERESTING;
+		if (!(parent->item->object.flags & REACHABLE)) {
+			ALLOC_GROW(ctx->oids.list, ctx->oids.nr + 1, ctx->oids.alloc);
+			oidcpy(&ctx->oids.list[ctx->oids.nr], &(parent->item->object.oid));
+			ctx->oids.nr++;
+			parent->item->object.flags |= REACHABLE;
 		}
 	}
 }
 
-static void close_reachable(struct packed_oid_list *oids)
+static void close_reachable(struct write_commit_graph_context *ctx)
 {
 	int i;
 	struct commit *commit;
 
-	for (i = 0; i < oids->nr; i++) {
-		commit = lookup_commit(&oids->list[i]);
+	if (ctx->report_progress)
+		ctx->progress = start_delayed_progress(
+					_("Loading known commits in commit graph"),
+					ctx->oids.nr);
+	for (i = 0; i < ctx->oids.nr; i++) {
+		display_progress(ctx->progress, i + 1);
+		commit = lookup_commit(ctx->r, &ctx->oids.list[i]);
 		if (commit)
-			commit->object.flags |= UNINTERESTING;
+			commit->object.flags |= REACHABLE;
 	}
+	stop_progress(&ctx->progress);
 
 	/*
-	 * As this loop runs, oids->nr may grow, but not more
+	 * As this loop runs, ctx->oids.nr may grow, but not more
 	 * than the number of missing commits in the reachable
 	 * closure.
 	 */
-	for (i = 0; i < oids->nr; i++) {
-		commit = lookup_commit(&oids->list[i]);
-
-		if (commit && !parse_commit(commit))
-			add_missing_parents(oids, commit);
-	}
+	if (ctx->report_progress)
+		ctx->progress = start_delayed_progress(
+					_("Expanding reachable commits in commit graph"),
+					0);
+	for (i = 0; i < ctx->oids.nr; i++) {
+		display_progress(ctx->progress, i + 1);
+		commit = lookup_commit(ctx->r, &ctx->oids.list[i]);
 
-	for (i = 0; i < oids->nr; i++) {
-		commit = lookup_commit(&oids->list[i]);
+		if (!commit)
+			continue;
+		if (ctx->split) {
+			if (!parse_commit(commit) &&
+			    commit->graph_pos == COMMIT_NOT_FROM_GRAPH)
+				add_missing_parents(ctx, commit);
+		} else if (!parse_commit_no_graph(commit))
+			add_missing_parents(ctx, commit);
+	}
+	stop_progress(&ctx->progress);
+
+	if (ctx->report_progress)
+		ctx->progress = start_delayed_progress(
+					_("Clearing commit marks in commit graph"),
+					ctx->oids.nr);
+	for (i = 0; i < ctx->oids.nr; i++) {
+		display_progress(ctx->progress, i + 1);
+		commit = lookup_commit(ctx->r, &ctx->oids.list[i]);
 
 		if (commit)
-			commit->object.flags &= ~UNINTERESTING;
+			commit->object.flags &= ~REACHABLE;
 	}
+	stop_progress(&ctx->progress);
 }
 
-void write_commit_graph(const char *obj_dir,
-			const char **pack_indexes,
-			int nr_packs,
-			const char **commit_hex,
-			int nr_commits,
-			int append)
+static void compute_generation_numbers(struct write_commit_graph_context *ctx)
 {
-	struct packed_oid_list oids;
-	struct packed_commit_list commits;
-	struct hashfile *f;
-	uint32_t i, count_distinct = 0;
-	char *graph_name;
-	int fd;
-	struct lock_file lk = LOCK_INIT;
-	uint32_t chunk_ids[5];
-	uint64_t chunk_offsets[5];
-	int num_chunks;
-	int num_extra_edges;
-	struct commit_list *parent;
+	int i;
+	struct commit_list *list = NULL;
 
-	oids.nr = 0;
-	oids.alloc = approximate_object_count() / 4;
+	if (ctx->report_progress)
+		ctx->progress = start_delayed_progress(
+					_("Computing commit graph generation numbers"),
+					ctx->commits.nr);
+	for (i = 0; i < ctx->commits.nr; i++) {
+		display_progress(ctx->progress, i + 1);
+		if (ctx->commits.list[i]->generation != GENERATION_NUMBER_INFINITY &&
+		    ctx->commits.list[i]->generation != GENERATION_NUMBER_ZERO)
+			continue;
 
-	if (append) {
-		prepare_commit_graph_one(obj_dir);
-		if (commit_graph)
-			oids.alloc += commit_graph->num_commits;
-	}
-
-	if (oids.alloc < 1024)
-		oids.alloc = 1024;
-	ALLOC_ARRAY(oids.list, oids.alloc);
-
-	if (append && commit_graph) {
-		for (i = 0; i < commit_graph->num_commits; i++) {
-			const unsigned char *hash = commit_graph->chunk_oid_lookup +
-				commit_graph->hash_len * i;
-			hashcpy(oids.list[oids.nr++].hash, hash);
+		commit_list_insert(ctx->commits.list[i], &list);
+		while (list) {
+			struct commit *current = list->item;
+			struct commit_list *parent;
+			int all_parents_computed = 1;
+			uint32_t max_generation = 0;
+
+			for (parent = current->parents; parent; parent = parent->next) {
+				if (parent->item->generation == GENERATION_NUMBER_INFINITY ||
+				    parent->item->generation == GENERATION_NUMBER_ZERO) {
+					all_parents_computed = 0;
+					commit_list_insert(parent->item, &list);
+					break;
+				} else if (parent->item->generation > max_generation) {
+					max_generation = parent->item->generation;
+				}
+			}
+
+			if (all_parents_computed) {
+				current->generation = max_generation + 1;
+				pop_commit(&list);
+
+				if (current->generation > GENERATION_NUMBER_MAX)
+					current->generation = GENERATION_NUMBER_MAX;
+			}
 		}
 	}
+	stop_progress(&ctx->progress);
+}
 
-	if (pack_indexes) {
-		struct strbuf packname = STRBUF_INIT;
-		int dirlen;
-		strbuf_addf(&packname, "%s/pack/", obj_dir);
-		dirlen = packname.len;
-		for (i = 0; i < nr_packs; i++) {
-			struct packed_git *p;
-			strbuf_setlen(&packname, dirlen);
-			strbuf_addstr(&packname, pack_indexes[i]);
-			p = add_packed_git(packname.buf, packname.len, 1);
-			if (!p)
-				die("error adding pack %s", packname.buf);
-			if (open_pack_index(p))
-				die("error opening index for %s", packname.buf);
-			for_each_object_in_pack(p, add_packed_commits, &oids);
-			close_pack(p);
+static int add_ref_to_list(const char *refname,
+			   const struct object_id *oid,
+			   int flags, void *cb_data)
+{
+	struct string_list *list = (struct string_list *)cb_data;
+
+	string_list_append(list, oid_to_hex(oid));
+	return 0;
+}
+
+int write_commit_graph_reachable(const char *obj_dir,
+				 enum commit_graph_write_flags flags,
+				 const struct split_commit_graph_opts *split_opts)
+{
+	struct string_list list = STRING_LIST_INIT_DUP;
+	int result;
+
+	for_each_ref(add_ref_to_list, &list);
+	result = write_commit_graph(obj_dir, NULL, &list,
+				    flags, split_opts);
+
+	string_list_clear(&list, 0);
+	return result;
+}
+
+static int fill_oids_from_packs(struct write_commit_graph_context *ctx,
+				struct string_list *pack_indexes)
+{
+	uint32_t i;
+	struct strbuf progress_title = STRBUF_INIT;
+	struct strbuf packname = STRBUF_INIT;
+	int dirlen;
+
+	strbuf_addf(&packname, "%s/pack/", ctx->obj_dir);
+	dirlen = packname.len;
+	if (ctx->report_progress) {
+		strbuf_addf(&progress_title,
+			    Q_("Finding commits for commit graph in %d pack",
+			       "Finding commits for commit graph in %d packs",
+			       pack_indexes->nr),
+			    pack_indexes->nr);
+		ctx->progress = start_delayed_progress(progress_title.buf, 0);
+		ctx->progress_done = 0;
+	}
+	for (i = 0; i < pack_indexes->nr; i++) {
+		struct packed_git *p;
+		strbuf_setlen(&packname, dirlen);
+		strbuf_addstr(&packname, pack_indexes->items[i].string);
+		p = add_packed_git(packname.buf, packname.len, 1);
+		if (!p) {
+			error(_("error adding pack %s"), packname.buf);
+			return -1;
+		}
+		if (open_pack_index(p)) {
+			error(_("error opening index for %s"), packname.buf);
+			return -1;
 		}
-		strbuf_release(&packname);
+		for_each_object_in_pack(p, add_packed_commits, ctx,
+					FOR_EACH_OBJECT_PACK_ORDER);
+		close_pack(p);
+		free(p);
 	}
 
-	if (commit_hex) {
-		for (i = 0; i < nr_commits; i++) {
-			const char *end;
-			struct object_id oid;
-			struct commit *result;
-
-			if (commit_hex[i] && parse_oid_hex(commit_hex[i], &oid, &end))
-				continue;
-
-			result = lookup_commit_reference_gently(&oid, 1);
-
-			if (result) {
-				ALLOC_GROW(oids.list, oids.nr + 1, oids.alloc);
-				oidcpy(&oids.list[oids.nr], &(result->object.oid));
-				oids.nr++;
-			}
+	stop_progress(&ctx->progress);
+	strbuf_release(&progress_title);
+	strbuf_release(&packname);
+
+	return 0;
+}
+
+static int fill_oids_from_commit_hex(struct write_commit_graph_context *ctx,
+				     struct string_list *commit_hex)
+{
+	uint32_t i;
+	struct strbuf progress_title = STRBUF_INIT;
+
+	if (ctx->report_progress) {
+		strbuf_addf(&progress_title,
+			    Q_("Finding commits for commit graph from %d ref",
+			       "Finding commits for commit graph from %d refs",
+			       commit_hex->nr),
+			    commit_hex->nr);
+		ctx->progress = start_delayed_progress(
+					progress_title.buf,
+					commit_hex->nr);
+	}
+	for (i = 0; i < commit_hex->nr; i++) {
+		const char *end;
+		struct object_id oid;
+		struct commit *result;
+
+		display_progress(ctx->progress, i + 1);
+		if (!parse_oid_hex(commit_hex->items[i].string, &oid, &end) &&
+		    (result = lookup_commit_reference_gently(ctx->r, &oid, 1))) {
+			ALLOC_GROW(ctx->oids.list, ctx->oids.nr + 1, ctx->oids.alloc);
+			oidcpy(&ctx->oids.list[ctx->oids.nr], &(result->object.oid));
+			ctx->oids.nr++;
+		} else if (ctx->check_oids) {
+			error(_("invalid commit object id: %s"),
+			    commit_hex->items[i].string);
+			return -1;
 		}
 	}
+	stop_progress(&ctx->progress);
+	strbuf_release(&progress_title);
 
-	if (!pack_indexes && !commit_hex)
-		for_each_packed_object(add_packed_commits, &oids, 0);
+	return 0;
+}
 
-	close_reachable(&oids);
+static void fill_oids_from_all_packs(struct write_commit_graph_context *ctx)
+{
+	if (ctx->report_progress)
+		ctx->progress = start_delayed_progress(
+			_("Finding commits for commit graph among packed objects"),
+			ctx->approx_nr_objects);
+	for_each_packed_object(add_packed_commits, ctx,
+			       FOR_EACH_OBJECT_PACK_ORDER);
+	if (ctx->progress_done < ctx->approx_nr_objects)
+		display_progress(ctx->progress, ctx->approx_nr_objects);
+	stop_progress(&ctx->progress);
+}
+
+static uint32_t count_distinct_commits(struct write_commit_graph_context *ctx)
+{
+	uint32_t i, count_distinct = 1;
+
+	if (ctx->report_progress)
+		ctx->progress = start_delayed_progress(
+			_("Counting distinct commits in commit graph"),
+			ctx->oids.nr);
+	display_progress(ctx->progress, 0); /* TODO: Measure QSORT() progress */
+	QSORT(ctx->oids.list, ctx->oids.nr, oid_compare);
+
+	for (i = 1; i < ctx->oids.nr; i++) {
+		display_progress(ctx->progress, i + 1);
+		if (!oideq(&ctx->oids.list[i - 1], &ctx->oids.list[i])) {
+			if (ctx->split) {
+				struct commit *c = lookup_commit(ctx->r, &ctx->oids.list[i]);
 
-	QSORT(oids.list, oids.nr, commit_compare);
+				if (!c || c->graph_pos != COMMIT_NOT_FROM_GRAPH)
+					continue;
+			}
 
-	count_distinct = 1;
-	for (i = 1; i < oids.nr; i++) {
-		if (oidcmp(&oids.list[i-1], &oids.list[i]))
 			count_distinct++;
+		}
 	}
+	stop_progress(&ctx->progress);
 
-	if (count_distinct >= GRAPH_PARENT_MISSING)
-		die(_("the commit graph format cannot write %d commits"), count_distinct);
+	return count_distinct;
+}
 
-	commits.nr = 0;
-	commits.alloc = count_distinct;
-	ALLOC_ARRAY(commits.list, commits.alloc);
+static void copy_oids_to_commits(struct write_commit_graph_context *ctx)
+{
+	uint32_t i;
 
-	num_extra_edges = 0;
-	for (i = 0; i < oids.nr; i++) {
-		int num_parents = 0;
-		if (i > 0 && !oidcmp(&oids.list[i-1], &oids.list[i]))
+	ctx->num_extra_edges = 0;
+	if (ctx->report_progress)
+		ctx->progress = start_delayed_progress(
+			_("Finding extra edges in commit graph"),
+			ctx->oids.nr);
+	for (i = 0; i < ctx->oids.nr; i++) {
+		unsigned int num_parents;
+
+		display_progress(ctx->progress, i + 1);
+		if (i > 0 && oideq(&ctx->oids.list[i - 1], &ctx->oids.list[i]))
 			continue;
 
-		commits.list[commits.nr] = lookup_commit(&oids.list[i]);
-		parse_commit(commits.list[commits.nr]);
+		ALLOC_GROW(ctx->commits.list, ctx->commits.nr + 1, ctx->commits.alloc);
+		ctx->commits.list[ctx->commits.nr] = lookup_commit(ctx->r, &ctx->oids.list[i]);
 
-		for (parent = commits.list[commits.nr]->parents;
-		     parent; parent = parent->next)
-			num_parents++;
+		if (ctx->split &&
+		    ctx->commits.list[ctx->commits.nr]->graph_pos != COMMIT_NOT_FROM_GRAPH)
+			continue;
 
+		parse_commit_no_graph(ctx->commits.list[ctx->commits.nr]);
+
+		num_parents = commit_list_count(ctx->commits.list[ctx->commits.nr]->parents);
 		if (num_parents > 2)
-			num_extra_edges += num_parents - 1;
+			ctx->num_extra_edges += num_parents - 1;
 
-		commits.nr++;
+		ctx->commits.nr++;
 	}
-	num_chunks = num_extra_edges ? 4 : 3;
-
-	if (commits.nr >= GRAPH_PARENT_MISSING)
-		die(_("too many commits to write graph"));
+	stop_progress(&ctx->progress);
+}
 
-	graph_name = get_commit_graph_filename(obj_dir);
-	fd = hold_lock_file_for_update(&lk, graph_name, 0);
+static int write_graph_chunk_base_1(struct hashfile *f,
+				    struct commit_graph *g)
+{
+	int num = 0;
 
-	if (fd < 0) {
-		struct strbuf folder = STRBUF_INIT;
-		strbuf_addstr(&folder, graph_name);
-		strbuf_setlen(&folder, strrchr(folder.buf, '/') - folder.buf);
+	if (!g)
+		return 0;
 
-		if (mkdir(folder.buf, 0777) < 0)
-			die_errno(_("cannot mkdir %s"), folder.buf);
-		strbuf_release(&folder);
+	num = write_graph_chunk_base_1(f, g->base_graph);
+	hashwrite(f, g->oid.hash, the_hash_algo->rawsz);
+	return num + 1;
+}
 
-		fd = hold_lock_file_for_update(&lk, graph_name, LOCK_DIE_ON_ERROR);
+static int write_graph_chunk_base(struct hashfile *f,
+				  struct write_commit_graph_context *ctx)
+{
+	int num = write_graph_chunk_base_1(f, ctx->new_base_graph);
 
-		if (fd < 0)
-			die_errno("unable to create '%s'", graph_name);
+	if (num != ctx->num_commit_graphs_after - 1) {
+		error(_("failed to write correct number of base graph ids"));
+		return -1;
 	}
 
-	f = hashfd(lk.tempfile->fd, lk.tempfile->filename.buf);
+	return 0;
+}
 
-	hashwrite_be32(f, GRAPH_SIGNATURE);
+static int write_commit_graph_file(struct write_commit_graph_context *ctx)
+{
+	uint32_t i;
+	int fd;
+	struct hashfile *f;
+	struct lock_file lk = LOCK_INIT;
+	uint32_t chunk_ids[6];
+	uint64_t chunk_offsets[6];
+	const unsigned hashsz = the_hash_algo->rawsz;
+	struct strbuf progress_title = STRBUF_INIT;
+	int num_chunks = 3;
+	struct object_id file_hash;
+
+	if (ctx->split) {
+		struct strbuf tmp_file = STRBUF_INIT;
+
+		strbuf_addf(&tmp_file,
+			    "%s/info/commit-graphs/tmp_graph_XXXXXX",
+			    ctx->obj_dir);
+		ctx->graph_name = strbuf_detach(&tmp_file, NULL);
+	} else {
+		ctx->graph_name = get_commit_graph_filename(ctx->obj_dir);
+	}
+
+	if (safe_create_leading_directories(ctx->graph_name)) {
+		UNLEAK(ctx->graph_name);
+		error(_("unable to create leading directories of %s"),
+			ctx->graph_name);
+		return -1;
+	}
+
+	if (ctx->split) {
+		char *lock_name = get_chain_filename(ctx->obj_dir);
+
+		hold_lock_file_for_update(&lk, lock_name, LOCK_DIE_ON_ERROR);
+
+		fd = git_mkstemp_mode(ctx->graph_name, 0444);
+		if (fd < 0) {
+			error(_("unable to create '%s'"), ctx->graph_name);
+			return -1;
+		}
 
-	hashwrite_u8(f, GRAPH_VERSION);
-	hashwrite_u8(f, GRAPH_OID_VERSION);
-	hashwrite_u8(f, num_chunks);
-	hashwrite_u8(f, 0); /* unused padding byte */
+		f = hashfd(fd, ctx->graph_name);
+	} else {
+		hold_lock_file_for_update(&lk, ctx->graph_name, LOCK_DIE_ON_ERROR);
+		fd = lk.tempfile->fd;
+		f = hashfd(lk.tempfile->fd, lk.tempfile->filename.buf);
+	}
 
 	chunk_ids[0] = GRAPH_CHUNKID_OIDFANOUT;
 	chunk_ids[1] = GRAPH_CHUNKID_OIDLOOKUP;
 	chunk_ids[2] = GRAPH_CHUNKID_DATA;
-	if (num_extra_edges)
-		chunk_ids[3] = GRAPH_CHUNKID_LARGEEDGES;
-	else
-		chunk_ids[3] = 0;
-	chunk_ids[4] = 0;
+	if (ctx->num_extra_edges) {
+		chunk_ids[num_chunks] = GRAPH_CHUNKID_EXTRAEDGES;
+		num_chunks++;
+	}
+	if (ctx->num_commit_graphs_after > 1) {
+		chunk_ids[num_chunks] = GRAPH_CHUNKID_BASE;
+		num_chunks++;
+	}
+
+	chunk_ids[num_chunks] = 0;
 
 	chunk_offsets[0] = 8 + (num_chunks + 1) * GRAPH_CHUNKLOOKUP_WIDTH;
 	chunk_offsets[1] = chunk_offsets[0] + GRAPH_FANOUT_SIZE;
-	chunk_offsets[2] = chunk_offsets[1] + GRAPH_OID_LEN * commits.nr;
-	chunk_offsets[3] = chunk_offsets[2] + (GRAPH_OID_LEN + 16) * commits.nr;
-	chunk_offsets[4] = chunk_offsets[3] + 4 * num_extra_edges;
+	chunk_offsets[2] = chunk_offsets[1] + hashsz * ctx->commits.nr;
+	chunk_offsets[3] = chunk_offsets[2] + (hashsz + 16) * ctx->commits.nr;
+
+	num_chunks = 3;
+	if (ctx->num_extra_edges) {
+		chunk_offsets[num_chunks + 1] = chunk_offsets[num_chunks] +
+						4 * ctx->num_extra_edges;
+		num_chunks++;
+	}
+	if (ctx->num_commit_graphs_after > 1) {
+		chunk_offsets[num_chunks + 1] = chunk_offsets[num_chunks] +
+						hashsz * (ctx->num_commit_graphs_after - 1);
+		num_chunks++;
+	}
+
+	hashwrite_be32(f, GRAPH_SIGNATURE);
+
+	hashwrite_u8(f, GRAPH_VERSION);
+	hashwrite_u8(f, oid_version());
+	hashwrite_u8(f, num_chunks);
+	hashwrite_u8(f, ctx->num_commit_graphs_after - 1);
 
 	for (i = 0; i <= num_chunks; i++) {
 		uint32_t chunk_write[3];
@@ -746,16 +1446,677 @@ void write_commit_graph(const char *obj_
 		hashwrite(f, chunk_write, 12);
 	}
 
-	write_graph_chunk_fanout(f, commits.list, commits.nr);
-	write_graph_chunk_oids(f, GRAPH_OID_LEN, commits.list, commits.nr);
-	write_graph_chunk_data(f, GRAPH_OID_LEN, commits.list, commits.nr);
-	write_graph_chunk_large_edges(f, commits.list, commits.nr);
+	if (ctx->report_progress) {
+		strbuf_addf(&progress_title,
+			    Q_("Writing out commit graph in %d pass",
+			       "Writing out commit graph in %d passes",
+			       num_chunks),
+			    num_chunks);
+		ctx->progress = start_delayed_progress(
+			progress_title.buf,
+			num_chunks * ctx->commits.nr);
+	}
+	write_graph_chunk_fanout(f, ctx);
+	write_graph_chunk_oids(f, hashsz, ctx);
+	write_graph_chunk_data(f, hashsz, ctx);
+	if (ctx->num_extra_edges)
+		write_graph_chunk_extra_edges(f, ctx);
+	if (ctx->num_commit_graphs_after > 1 &&
+	    write_graph_chunk_base(f, ctx)) {
+		return -1;
+	}
+	stop_progress(&ctx->progress);
+	strbuf_release(&progress_title);
+
+	if (ctx->split && ctx->base_graph_name && ctx->num_commit_graphs_after > 1) {
+		char *new_base_hash = xstrdup(oid_to_hex(&ctx->new_base_graph->oid));
+		char *new_base_name = get_split_graph_filename(ctx->new_base_graph->obj_dir, new_base_hash);
+
+		free(ctx->commit_graph_filenames_after[ctx->num_commit_graphs_after - 2]);
+		free(ctx->commit_graph_hash_after[ctx->num_commit_graphs_after - 2]);
+		ctx->commit_graph_filenames_after[ctx->num_commit_graphs_after - 2] = new_base_name;
+		ctx->commit_graph_hash_after[ctx->num_commit_graphs_after - 2] = new_base_hash;
+	}
+
+	close_commit_graph(ctx->r->objects);
+	finalize_hashfile(f, file_hash.hash, CSUM_HASH_IN_STREAM | CSUM_FSYNC);
+
+	if (ctx->split) {
+		FILE *chainf = fdopen_lock_file(&lk, "w");
+		char *final_graph_name;
+		int result;
+
+		close(fd);
+
+		if (!chainf) {
+			error(_("unable to open commit-graph chain file"));
+			return -1;
+		}
+
+		if (ctx->base_graph_name) {
+			const char *dest = ctx->commit_graph_filenames_after[
+						ctx->num_commit_graphs_after - 2];
+
+			if (strcmp(ctx->base_graph_name, dest)) {
+				result = rename(ctx->base_graph_name, dest);
+
+				if (result) {
+					error(_("failed to rename base commit-graph file"));
+					return -1;
+				}
+			}
+		} else {
+			char *graph_name = get_commit_graph_filename(ctx->obj_dir);
+			unlink(graph_name);
+		}
+
+		ctx->commit_graph_hash_after[ctx->num_commit_graphs_after - 1] = xstrdup(oid_to_hex(&file_hash));
+		final_graph_name = get_split_graph_filename(ctx->obj_dir,
+					ctx->commit_graph_hash_after[ctx->num_commit_graphs_after - 1]);
+		ctx->commit_graph_filenames_after[ctx->num_commit_graphs_after - 1] = final_graph_name;
+
+		result = rename(ctx->graph_name, final_graph_name);
+
+		for (i = 0; i < ctx->num_commit_graphs_after; i++)
+			fprintf(lk.tempfile->fp, "%s\n", ctx->commit_graph_hash_after[i]);
+
+		if (result) {
+			error(_("failed to rename temporary commit-graph file"));
+			return -1;
+		}
+	}
 
-	close_commit_graph();
-	finalize_hashfile(f, NULL, CSUM_HASH_IN_STREAM | CSUM_FSYNC);
 	commit_lock_file(&lk);
 
-	free(oids.list);
-	oids.alloc = 0;
-	oids.nr = 0;
+	return 0;
+}
+
+static void split_graph_merge_strategy(struct write_commit_graph_context *ctx)
+{
+	struct commit_graph *g;
+	uint32_t num_commits;
+	uint32_t i;
+
+	int max_commits = 0;
+	int size_mult = 2;
+
+	if (ctx->split_opts) {
+		max_commits = ctx->split_opts->max_commits;
+
+		if (ctx->split_opts->size_multiple)
+			size_mult = ctx->split_opts->size_multiple;
+	}
+
+	g = ctx->r->objects->commit_graph;
+	num_commits = ctx->commits.nr;
+	ctx->num_commit_graphs_after = ctx->num_commit_graphs_before + 1;
+
+	while (g && (g->num_commits <= size_mult * num_commits ||
+		    (max_commits && num_commits > max_commits))) {
+		if (strcmp(g->obj_dir, ctx->obj_dir))
+			break;
+
+		num_commits += g->num_commits;
+		g = g->base_graph;
+
+		ctx->num_commit_graphs_after--;
+	}
+
+	ctx->new_base_graph = g;
+
+	if (ctx->num_commit_graphs_after == 2) {
+		char *old_graph_name = get_commit_graph_filename(g->obj_dir);
+
+		if (!strcmp(g->filename, old_graph_name) &&
+		    strcmp(g->obj_dir, ctx->obj_dir)) {
+			ctx->num_commit_graphs_after = 1;
+			ctx->new_base_graph = NULL;
+		}
+
+		free(old_graph_name);
+	}
+
+	ALLOC_ARRAY(ctx->commit_graph_filenames_after, ctx->num_commit_graphs_after);
+	ALLOC_ARRAY(ctx->commit_graph_hash_after, ctx->num_commit_graphs_after);
+
+	for (i = 0; i < ctx->num_commit_graphs_after &&
+		    i < ctx->num_commit_graphs_before; i++)
+		ctx->commit_graph_filenames_after[i] = xstrdup(ctx->commit_graph_filenames_before[i]);
+
+	i = ctx->num_commit_graphs_before - 1;
+	g = ctx->r->objects->commit_graph;
+
+	while (g) {
+		if (i < ctx->num_commit_graphs_after)
+			ctx->commit_graph_hash_after[i] = xstrdup(oid_to_hex(&g->oid));
+
+		i--;
+		g = g->base_graph;
+	}
+}
+
+static void merge_commit_graph(struct write_commit_graph_context *ctx,
+			       struct commit_graph *g)
+{
+	uint32_t i;
+	uint32_t offset = g->num_commits_in_base;
+
+	ALLOC_GROW(ctx->commits.list, ctx->commits.nr + g->num_commits, ctx->commits.alloc);
+
+	for (i = 0; i < g->num_commits; i++) {
+		struct object_id oid;
+		struct commit *result;
+
+		display_progress(ctx->progress, i + 1);
+
+		load_oid_from_graph(g, i + offset, &oid);
+
+		/* only add commits if they still exist in the repo */
+		result = lookup_commit_reference_gently(ctx->r, &oid, 1);
+
+		if (result) {
+			ctx->commits.list[ctx->commits.nr] = result;
+			ctx->commits.nr++;
+		}
+	}
+}
+
+static int commit_compare(const void *_a, const void *_b)
+{
+	const struct commit *a = *(const struct commit **)_a;
+	const struct commit *b = *(const struct commit **)_b;
+	return oidcmp(&a->object.oid, &b->object.oid);
+}
+
+static void sort_and_scan_merged_commits(struct write_commit_graph_context *ctx)
+{
+	uint32_t i;
+
+	if (ctx->report_progress)
+		ctx->progress = start_delayed_progress(
+					_("Scanning merged commits"),
+					ctx->commits.nr);
+
+	QSORT(ctx->commits.list, ctx->commits.nr, commit_compare);
+
+	ctx->num_extra_edges = 0;
+	for (i = 0; i < ctx->commits.nr; i++) {
+		display_progress(ctx->progress, i);
+
+		if (i && oideq(&ctx->commits.list[i - 1]->object.oid,
+			  &ctx->commits.list[i]->object.oid)) {
+			die(_("unexpected duplicate commit id %s"),
+			    oid_to_hex(&ctx->commits.list[i]->object.oid));
+		} else {
+			unsigned int num_parents;
+
+			num_parents = commit_list_count(ctx->commits.list[i]->parents);
+			if (num_parents > 2)
+				ctx->num_extra_edges += num_parents - 1;
+		}
+	}
+
+	stop_progress(&ctx->progress);
+}
+
+static void merge_commit_graphs(struct write_commit_graph_context *ctx)
+{
+	struct commit_graph *g = ctx->r->objects->commit_graph;
+	uint32_t current_graph_number = ctx->num_commit_graphs_before;
+	struct strbuf progress_title = STRBUF_INIT;
+
+	while (g && current_graph_number >= ctx->num_commit_graphs_after) {
+		current_graph_number--;
+
+		if (ctx->report_progress) {
+			strbuf_addstr(&progress_title, _("Merging commit-graph"));
+			ctx->progress = start_delayed_progress(progress_title.buf, 0);
+		}
+
+		merge_commit_graph(ctx, g);
+		stop_progress(&ctx->progress);
+		strbuf_release(&progress_title);
+
+		g = g->base_graph;
+	}
+
+	if (g) {
+		ctx->new_base_graph = g;
+		ctx->new_num_commits_in_base = g->num_commits + g->num_commits_in_base;
+	}
+
+	if (ctx->new_base_graph)
+		ctx->base_graph_name = xstrdup(ctx->new_base_graph->filename);
+
+	sort_and_scan_merged_commits(ctx);
+}
+
+static void mark_commit_graphs(struct write_commit_graph_context *ctx)
+{
+	uint32_t i;
+	time_t now = time(NULL);
+
+	for (i = ctx->num_commit_graphs_after - 1; i < ctx->num_commit_graphs_before; i++) {
+		struct stat st;
+		struct utimbuf updated_time;
+
+		stat(ctx->commit_graph_filenames_before[i], &st);
+
+		updated_time.actime = st.st_atime;
+		updated_time.modtime = now;
+		utime(ctx->commit_graph_filenames_before[i], &updated_time);
+	}
+}
+
+static void expire_commit_graphs(struct write_commit_graph_context *ctx)
+{
+	struct strbuf path = STRBUF_INIT;
+	DIR *dir;
+	struct dirent *de;
+	size_t dirnamelen;
+	timestamp_t expire_time = time(NULL);
+
+	if (ctx->split_opts && ctx->split_opts->expire_time)
+		expire_time -= ctx->split_opts->expire_time;
+	if (!ctx->split) {
+		char *chain_file_name = get_chain_filename(ctx->obj_dir);
+		unlink(chain_file_name);
+		free(chain_file_name);
+		ctx->num_commit_graphs_after = 0;
+	}
+
+	strbuf_addstr(&path, ctx->obj_dir);
+	strbuf_addstr(&path, "/info/commit-graphs");
+	dir = opendir(path.buf);
+
+	if (!dir)
+		goto out;
+
+	strbuf_addch(&path, '/');
+	dirnamelen = path.len;
+	while ((de = readdir(dir)) != NULL) {
+		struct stat st;
+		uint32_t i, found = 0;
+
+		strbuf_setlen(&path, dirnamelen);
+		strbuf_addstr(&path, de->d_name);
+
+		stat(path.buf, &st);
+
+		if (st.st_mtime > expire_time)
+			continue;
+		if (path.len < 6 || strcmp(path.buf + path.len - 6, ".graph"))
+			continue;
+
+		for (i = 0; i < ctx->num_commit_graphs_after; i++) {
+			if (!strcmp(ctx->commit_graph_filenames_after[i],
+				    path.buf)) {
+				found = 1;
+				break;
+			}
+		}
+
+		if (!found)
+			unlink(path.buf);
+	}
+
+out:
+	strbuf_release(&path);
+}
+
+int write_commit_graph(const char *obj_dir,
+		       struct string_list *pack_indexes,
+		       struct string_list *commit_hex,
+		       enum commit_graph_write_flags flags,
+		       const struct split_commit_graph_opts *split_opts)
+{
+	struct write_commit_graph_context *ctx;
+	uint32_t i, count_distinct = 0;
+	size_t len;
+	int res = 0;
+
+	if (!commit_graph_compatible(the_repository))
+		return 0;
+
+	ctx = xcalloc(1, sizeof(struct write_commit_graph_context));
+	ctx->r = the_repository;
+
+	/* normalize object dir with no trailing slash */
+	ctx->obj_dir = xmallocz(strlen(obj_dir) + 1);
+	normalize_path_copy(ctx->obj_dir, obj_dir);
+	len = strlen(ctx->obj_dir);
+	if (len && ctx->obj_dir[len - 1] == '/')
+		ctx->obj_dir[len - 1] = 0;
+
+	ctx->append = flags & COMMIT_GRAPH_WRITE_APPEND ? 1 : 0;
+	ctx->report_progress = flags & COMMIT_GRAPH_WRITE_PROGRESS ? 1 : 0;
+	ctx->split = flags & COMMIT_GRAPH_WRITE_SPLIT ? 1 : 0;
+	ctx->check_oids = flags & COMMIT_GRAPH_WRITE_CHECK_OIDS ? 1 : 0;
+	ctx->split_opts = split_opts;
+
+	if (ctx->split) {
+		struct commit_graph *g;
+		prepare_commit_graph(ctx->r);
+
+		g = ctx->r->objects->commit_graph;
+
+		while (g) {
+			ctx->num_commit_graphs_before++;
+			g = g->base_graph;
+		}
+
+		if (ctx->num_commit_graphs_before) {
+			ALLOC_ARRAY(ctx->commit_graph_filenames_before, ctx->num_commit_graphs_before);
+			i = ctx->num_commit_graphs_before;
+			g = ctx->r->objects->commit_graph;
+
+			while (g) {
+				ctx->commit_graph_filenames_before[--i] = xstrdup(g->filename);
+				g = g->base_graph;
+			}
+		}
+	}
+
+	ctx->approx_nr_objects = approximate_object_count();
+	ctx->oids.alloc = ctx->approx_nr_objects / 32;
+
+	if (ctx->split && split_opts && ctx->oids.alloc > split_opts->max_commits)
+		ctx->oids.alloc = split_opts->max_commits;
+
+	if (ctx->append) {
+		prepare_commit_graph_one(ctx->r, ctx->obj_dir);
+		if (ctx->r->objects->commit_graph)
+			ctx->oids.alloc += ctx->r->objects->commit_graph->num_commits;
+	}
+
+	if (ctx->oids.alloc < 1024)
+		ctx->oids.alloc = 1024;
+	ALLOC_ARRAY(ctx->oids.list, ctx->oids.alloc);
+
+	if (ctx->append && ctx->r->objects->commit_graph) {
+		struct commit_graph *g = ctx->r->objects->commit_graph;
+		for (i = 0; i < g->num_commits; i++) {
+			const unsigned char *hash = g->chunk_oid_lookup + g->hash_len * i;
+			hashcpy(ctx->oids.list[ctx->oids.nr++].hash, hash);
+		}
+	}
+
+	if (pack_indexes) {
+		if ((res = fill_oids_from_packs(ctx, pack_indexes)))
+			goto cleanup;
+	}
+
+	if (commit_hex) {
+		if ((res = fill_oids_from_commit_hex(ctx, commit_hex)))
+			goto cleanup;
+	}
+
+	if (!pack_indexes && !commit_hex)
+		fill_oids_from_all_packs(ctx);
+
+	close_reachable(ctx);
+
+	count_distinct = count_distinct_commits(ctx);
+
+	if (count_distinct >= GRAPH_EDGE_LAST_MASK) {
+		error(_("the commit graph format cannot write %d commits"), count_distinct);
+		res = -1;
+		goto cleanup;
+	}
+
+	ctx->commits.alloc = count_distinct;
+	ALLOC_ARRAY(ctx->commits.list, ctx->commits.alloc);
+
+	copy_oids_to_commits(ctx);
+
+	if (ctx->commits.nr >= GRAPH_EDGE_LAST_MASK) {
+		error(_("too many commits to write graph"));
+		res = -1;
+		goto cleanup;
+	}
+
+	if (!ctx->commits.nr)
+		goto cleanup;
+
+	if (ctx->split) {
+		split_graph_merge_strategy(ctx);
+
+		merge_commit_graphs(ctx);
+	} else
+		ctx->num_commit_graphs_after = 1;
+
+	compute_generation_numbers(ctx);
+
+	res = write_commit_graph_file(ctx);
+
+	if (ctx->split)
+		mark_commit_graphs(ctx);
+
+	expire_commit_graphs(ctx);
+
+cleanup:
+	free(ctx->graph_name);
+	free(ctx->commits.list);
+	free(ctx->oids.list);
+	free(ctx->obj_dir);
+
+	if (ctx->commit_graph_filenames_after) {
+		for (i = 0; i < ctx->num_commit_graphs_after; i++) {
+			free(ctx->commit_graph_filenames_after[i]);
+			free(ctx->commit_graph_hash_after[i]);
+		}
+
+		for (i = 0; i < ctx->num_commit_graphs_before; i++)
+			free(ctx->commit_graph_filenames_before[i]);
+
+		free(ctx->commit_graph_filenames_after);
+		free(ctx->commit_graph_filenames_before);
+		free(ctx->commit_graph_hash_after);
+	}
+
+	free(ctx);
+
+	return res;
+}
+
+#define VERIFY_COMMIT_GRAPH_ERROR_HASH 2
+static int verify_commit_graph_error;
+
+static void graph_report(const char *fmt, ...)
+{
+	va_list ap;
+
+	verify_commit_graph_error = 1;
+	va_start(ap, fmt);
+	vfprintf(stderr, fmt, ap);
+	fprintf(stderr, "\n");
+	va_end(ap);
+}
+
+#define GENERATION_ZERO_EXISTS 1
+#define GENERATION_NUMBER_EXISTS 2
+
+int verify_commit_graph(struct repository *r, struct commit_graph *g, int flags)
+{
+	uint32_t i, cur_fanout_pos = 0;
+	struct object_id prev_oid, cur_oid, checksum;
+	int generation_zero = 0;
+	struct hashfile *f;
+	int devnull;
+	struct progress *progress = NULL;
+	int local_error = 0;
+
+	if (!g) {
+		graph_report("no commit-graph file loaded");
+		return 1;
+	}
+
+	verify_commit_graph_error = verify_commit_graph_lite(g);
+	if (verify_commit_graph_error)
+		return verify_commit_graph_error;
+
+	devnull = open("/dev/null", O_WRONLY);
+	f = hashfd(devnull, NULL);
+	hashwrite(f, g->data, g->data_len - g->hash_len);
+	finalize_hashfile(f, checksum.hash, CSUM_CLOSE);
+	if (!hasheq(checksum.hash, g->data + g->data_len - g->hash_len)) {
+		graph_report(_("the commit-graph file has incorrect checksum and is likely corrupt"));
+		verify_commit_graph_error = VERIFY_COMMIT_GRAPH_ERROR_HASH;
+	}
+
+	for (i = 0; i < g->num_commits; i++) {
+		struct commit *graph_commit;
+
+		hashcpy(cur_oid.hash, g->chunk_oid_lookup + g->hash_len * i);
+
+		if (i && oidcmp(&prev_oid, &cur_oid) >= 0)
+			graph_report(_("commit-graph has incorrect OID order: %s then %s"),
+				     oid_to_hex(&prev_oid),
+				     oid_to_hex(&cur_oid));
+
+		oidcpy(&prev_oid, &cur_oid);
+
+		while (cur_oid.hash[0] > cur_fanout_pos) {
+			uint32_t fanout_value = get_be32(g->chunk_oid_fanout + cur_fanout_pos);
+
+			if (i != fanout_value)
+				graph_report(_("commit-graph has incorrect fanout value: fanout[%d] = %u != %u"),
+					     cur_fanout_pos, fanout_value, i);
+			cur_fanout_pos++;
+		}
+
+		graph_commit = lookup_commit(r, &cur_oid);
+		if (!parse_commit_in_graph_one(r, g, graph_commit))
+			graph_report(_("failed to parse commit %s from commit-graph"),
+				     oid_to_hex(&cur_oid));
+	}
+
+	while (cur_fanout_pos < 256) {
+		uint32_t fanout_value = get_be32(g->chunk_oid_fanout + cur_fanout_pos);
+
+		if (g->num_commits != fanout_value)
+			graph_report(_("commit-graph has incorrect fanout value: fanout[%d] = %u != %u"),
+				     cur_fanout_pos, fanout_value, i);
+
+		cur_fanout_pos++;
+	}
+
+	if (verify_commit_graph_error & ~VERIFY_COMMIT_GRAPH_ERROR_HASH)
+		return verify_commit_graph_error;
+
+	if (flags & COMMIT_GRAPH_WRITE_PROGRESS)
+		progress = start_progress(_("Verifying commits in commit graph"),
+					g->num_commits);
+
+	for (i = 0; i < g->num_commits; i++) {
+		struct commit *graph_commit, *odb_commit;
+		struct commit_list *graph_parents, *odb_parents;
+		uint32_t max_generation = 0;
+
+		display_progress(progress, i + 1);
+		hashcpy(cur_oid.hash, g->chunk_oid_lookup + g->hash_len * i);
+
+		graph_commit = lookup_commit(r, &cur_oid);
+		odb_commit = (struct commit *)create_object(r, &cur_oid, alloc_commit_node(r));
+		if (parse_commit_internal(odb_commit, 0, 0)) {
+			graph_report(_("failed to parse commit %s from object database for commit-graph"),
+				     oid_to_hex(&cur_oid));
+			continue;
+		}
+
+		if (!oideq(&get_commit_tree_in_graph_one(r, g, graph_commit)->object.oid,
+			   get_commit_tree_oid(odb_commit)))
+			graph_report(_("root tree OID for commit %s in commit-graph is %s != %s"),
+				     oid_to_hex(&cur_oid),
+				     oid_to_hex(get_commit_tree_oid(graph_commit)),
+				     oid_to_hex(get_commit_tree_oid(odb_commit)));
+
+		graph_parents = graph_commit->parents;
+		odb_parents = odb_commit->parents;
+
+		while (graph_parents) {
+			if (odb_parents == NULL) {
+				graph_report(_("commit-graph parent list for commit %s is too long"),
+					     oid_to_hex(&cur_oid));
+				break;
+			}
+
+			/* parse parent in case it is in a base graph */
+			parse_commit_in_graph_one(r, g, graph_parents->item);
+
+			if (!oideq(&graph_parents->item->object.oid, &odb_parents->item->object.oid))
+				graph_report(_("commit-graph parent for %s is %s != %s"),
+					     oid_to_hex(&cur_oid),
+					     oid_to_hex(&graph_parents->item->object.oid),
+					     oid_to_hex(&odb_parents->item->object.oid));
+
+			if (graph_parents->item->generation > max_generation)
+				max_generation = graph_parents->item->generation;
+
+			graph_parents = graph_parents->next;
+			odb_parents = odb_parents->next;
+		}
+
+		if (odb_parents != NULL)
+			graph_report(_("commit-graph parent list for commit %s terminates early"),
+				     oid_to_hex(&cur_oid));
+
+		if (!graph_commit->generation) {
+			if (generation_zero == GENERATION_NUMBER_EXISTS)
+				graph_report(_("commit-graph has generation number zero for commit %s, but non-zero elsewhere"),
+					     oid_to_hex(&cur_oid));
+			generation_zero = GENERATION_ZERO_EXISTS;
+		} else if (generation_zero == GENERATION_ZERO_EXISTS)
+			graph_report(_("commit-graph has non-zero generation number for commit %s, but zero elsewhere"),
+				     oid_to_hex(&cur_oid));
+
+		if (generation_zero == GENERATION_ZERO_EXISTS)
+			continue;
+
+		/*
+		 * If one of our parents has generation GENERATION_NUMBER_MAX, then
+		 * our generation is also GENERATION_NUMBER_MAX. Decrement to avoid
+		 * extra logic in the following condition.
+		 */
+		if (max_generation == GENERATION_NUMBER_MAX)
+			max_generation--;
+
+		if (graph_commit->generation != max_generation + 1)
+			graph_report(_("commit-graph generation for commit %s is %u != %u"),
+				     oid_to_hex(&cur_oid),
+				     graph_commit->generation,
+				     max_generation + 1);
+
+		if (graph_commit->date != odb_commit->date)
+			graph_report(_("commit date for commit %s in commit-graph is %"PRItime" != %"PRItime),
+				     oid_to_hex(&cur_oid),
+				     graph_commit->date,
+				     odb_commit->date);
+	}
+	stop_progress(&progress);
+
+	local_error = verify_commit_graph_error;
+
+	if (!(flags & COMMIT_GRAPH_VERIFY_SHALLOW) && g->base_graph)
+		local_error |= verify_commit_graph(r, g->base_graph, flags);
+
+	return local_error;
+}
+
+void free_commit_graph(struct commit_graph *g)
+{
+	if (!g)
+		return;
+	if (g->graph_fd >= 0) {
+		munmap((void *)g->data, g->data_len);
+		g->data = NULL;
+		close(g->graph_fd);
+	}
+	free(g->filename);
+	free(g);
+}
+
+void disable_commit_graph(struct repository *r)
+{
+	r->commit_graph_disabled = 1;
 }
diff -pruN 1.2.1+git2.18.0-1/git/commit-graph.h 1.2.3+git2.25.1-1/git/commit-graph.h
--- 1.2.1+git2.18.0-1/git/commit-graph.h	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/commit-graph.h	2020-02-17 04:47:35.000000000 +0000
@@ -2,8 +2,17 @@
 #define COMMIT_GRAPH_H
 
 #include "git-compat-util.h"
+#include "repository.h"
+#include "string-list.h"
+#include "cache.h"
+
+#define GIT_TEST_COMMIT_GRAPH "GIT_TEST_COMMIT_GRAPH"
+#define GIT_TEST_COMMIT_GRAPH_DIE_ON_LOAD "GIT_TEST_COMMIT_GRAPH_DIE_ON_LOAD"
+
+struct commit;
 
 char *get_commit_graph_filename(const char *obj_dir);
+int open_commit_graph(const char *graph_file, int *fd, struct stat *st);
 
 /*
  * Given a commit struct, try to fill the commit struct info, including:
@@ -15,9 +24,18 @@ char *get_commit_graph_filename(const ch
  *
  * See parse_commit_buffer() for the fallback after this call.
  */
-int parse_commit_in_graph(struct commit *item);
+int parse_commit_in_graph(struct repository *r, struct commit *item);
+
+/*
+ * It is possible that we loaded commit contents from the commit buffer,
+ * but we also want to ensure the commit-graph content is correctly
+ * checked and filled. Fill the graph_pos and generation members of
+ * the given commit.
+ */
+void load_commit_graph_info(struct repository *r, struct commit *item);
 
-struct tree *get_commit_tree_in_graph(const struct commit *c);
+struct tree *get_commit_tree_in_graph(struct repository *r,
+				      const struct commit *c);
 
 struct commit_graph {
 	int graph_fd;
@@ -29,20 +47,70 @@ struct commit_graph {
 	unsigned char num_chunks;
 	uint32_t num_commits;
 	struct object_id oid;
+	char *filename;
+	const char *obj_dir;
+
+	uint32_t num_commits_in_base;
+	struct commit_graph *base_graph;
 
 	const uint32_t *chunk_oid_fanout;
 	const unsigned char *chunk_oid_lookup;
 	const unsigned char *chunk_commit_data;
-	const unsigned char *chunk_large_edges;
+	const unsigned char *chunk_extra_edges;
+	const unsigned char *chunk_base_graphs;
 };
 
-struct commit_graph *load_commit_graph_one(const char *graph_file);
+struct commit_graph *load_commit_graph_one_fd_st(int fd, struct stat *st);
+struct commit_graph *read_commit_graph_one(struct repository *r, const char *obj_dir);
+struct commit_graph *parse_commit_graph(void *graph_map, int fd,
+					size_t graph_size);
+
+/*
+ * Return 1 if and only if the repository has a commit-graph
+ * file and generation numbers are computed in that file.
+ */
+int generation_numbers_enabled(struct repository *r);
+
+enum commit_graph_write_flags {
+	COMMIT_GRAPH_WRITE_APPEND     = (1 << 0),
+	COMMIT_GRAPH_WRITE_PROGRESS   = (1 << 1),
+	COMMIT_GRAPH_WRITE_SPLIT      = (1 << 2),
+	/* Make sure that each OID in the input is a valid commit OID. */
+	COMMIT_GRAPH_WRITE_CHECK_OIDS = (1 << 3)
+};
 
-void write_commit_graph(const char *obj_dir,
-			const char **pack_indexes,
-			int nr_packs,
-			const char **commit_hex,
-			int nr_commits,
-			int append);
+struct split_commit_graph_opts {
+	int size_multiple;
+	int max_commits;
+	timestamp_t expire_time;
+};
+
+/*
+ * The write_commit_graph* methods return zero on success
+ * and a negative value on failure. Note that if the repository
+ * is not compatible with the commit-graph feature, then the
+ * methods will return 0 without writing a commit-graph.
+ */
+int write_commit_graph_reachable(const char *obj_dir,
+				 enum commit_graph_write_flags flags,
+				 const struct split_commit_graph_opts *split_opts);
+int write_commit_graph(const char *obj_dir,
+		       struct string_list *pack_indexes,
+		       struct string_list *commit_hex,
+		       enum commit_graph_write_flags flags,
+		       const struct split_commit_graph_opts *split_opts);
+
+#define COMMIT_GRAPH_VERIFY_SHALLOW	(1 << 0)
+
+int verify_commit_graph(struct repository *r, struct commit_graph *g, int flags);
+
+void close_commit_graph(struct raw_object_store *);
+void free_commit_graph(struct commit_graph *);
+
+/*
+ * Disable further use of the commit graph in this process when parsing a
+ * "struct commit".
+ */
+void disable_commit_graph(struct repository *r);
 
 #endif
diff -pruN 1.2.1+git2.18.0-1/git/commit.h 1.2.3+git2.25.1-1/git/commit.h
--- 1.2.1+git2.18.0-1/git/commit.h	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/commit.h	2020-02-17 04:47:35.000000000 +0000
@@ -8,27 +8,36 @@
 #include "gpg-interface.h"
 #include "string-list.h"
 #include "pretty.h"
+#include "commit-slab.h"
 
 #define COMMIT_NOT_FROM_GRAPH 0xFFFFFFFF
+#define GENERATION_NUMBER_INFINITY 0xFFFFFFFF
+#define GENERATION_NUMBER_MAX 0x3FFFFFFF
+#define GENERATION_NUMBER_ZERO 0
 
 struct commit_list {
 	struct commit *item;
 	struct commit_list *next;
 };
 
+/*
+ * The size of this struct matters in full repo walk operations like
+ * 'git clone' or 'git gc'. Consider using commit-slab to attach data
+ * to a commit instead of adding new fields here.
+ */
 struct commit {
 	struct object object;
-	void *util;
 	timestamp_t date;
 	struct commit_list *parents;
 
 	/*
 	 * If the commit is loaded from the commit-graph file, then this
-	 * member may be NULL. Only access it through get_commit_tree()
+	 * member may be NULL. Only access it through repo_get_commit_tree()
 	 * or get_commit_tree_oid().
 	 */
 	struct tree *maybe_tree;
 	uint32_t graph_pos;
+	uint32_t generation;
 	unsigned int index;
 };
 
@@ -55,9 +64,11 @@ enum decoration_type {
 void add_name_decoration(enum decoration_type type, const char *name, struct object *obj);
 const struct name_decoration *get_name_decoration(const struct object *obj);
 
-struct commit *lookup_commit(const struct object_id *oid);
-struct commit *lookup_commit_reference(const struct object_id *oid);
-struct commit *lookup_commit_reference_gently(const struct object_id *oid,
+struct commit *lookup_commit(struct repository *r, const struct object_id *oid);
+struct commit *lookup_commit_reference(struct repository *r,
+				       const struct object_id *oid);
+struct commit *lookup_commit_reference_gently(struct repository *r,
+					      const struct object_id *oid,
 					      int quiet);
 struct commit *lookup_commit_reference_by_name(const char *name);
 
@@ -68,50 +79,87 @@ struct commit *lookup_commit_reference_b
  */
 struct commit *lookup_commit_or_die(const struct object_id *oid, const char *ref_name);
 
-int parse_commit_buffer(struct commit *item, const void *buffer, unsigned long size);
-int parse_commit_gently(struct commit *item, int quiet_on_missing);
-static inline int parse_commit(struct commit *item)
+int parse_commit_buffer(struct repository *r, struct commit *item, const void *buffer, unsigned long size, int check_graph);
+int repo_parse_commit_internal(struct repository *r, struct commit *item,
+			       int quiet_on_missing, int use_commit_graph);
+int repo_parse_commit_gently(struct repository *r,
+			     struct commit *item,
+			     int quiet_on_missing);
+static inline int repo_parse_commit(struct repository *r, struct commit *item)
 {
-	return parse_commit_gently(item, 0);
+	return repo_parse_commit_gently(r, item, 0);
 }
+
+static inline int parse_commit_no_graph(struct commit *commit)
+{
+	return repo_parse_commit_internal(the_repository, commit, 0, 0);
+}
+
+#ifndef NO_THE_REPOSITORY_COMPATIBILITY_MACROS
+#define parse_commit_internal(item, quiet, use) repo_parse_commit_internal(the_repository, item, quiet, use)
+#define parse_commit_gently(item, quiet) repo_parse_commit_gently(the_repository, item, quiet)
+#define parse_commit(item) repo_parse_commit(the_repository, item)
+#endif
+
 void parse_commit_or_die(struct commit *item);
 
+struct buffer_slab;
+struct buffer_slab *allocate_commit_buffer_slab(void);
+void free_commit_buffer_slab(struct buffer_slab *bs);
+
 /*
  * Associate an object buffer with the commit. The ownership of the
  * memory is handed over to the commit, and must be free()-able.
  */
-void set_commit_buffer(struct commit *, void *buffer, unsigned long size);
+void set_commit_buffer(struct repository *r, struct commit *, void *buffer, unsigned long size);
 
 /*
  * Get any cached object buffer associated with the commit. Returns NULL
  * if none. The resulting memory should not be freed.
  */
-const void *get_cached_commit_buffer(const struct commit *, unsigned long *size);
+const void *get_cached_commit_buffer(struct repository *, const struct commit *, unsigned long *size);
 
 /*
  * Get the commit's object contents, either from cache or by reading the object
  * from disk. The resulting memory should not be modified, and must be given
  * to unuse_commit_buffer when the caller is done.
  */
-const void *get_commit_buffer(const struct commit *, unsigned long *size);
+const void *repo_get_commit_buffer(struct repository *r,
+				   const struct commit *,
+				   unsigned long *size);
+#ifndef NO_THE_REPOSITORY_COMPATIBILITY_MACROS
+#define get_commit_buffer(c, s) repo_get_commit_buffer(the_repository, c, s)
+#endif
 
 /*
- * Tell the commit subsytem that we are done with a particular commit buffer.
+ * Tell the commit subsystem that we are done with a particular commit buffer.
  * The commit and buffer should be the input and return value, respectively,
  * from an earlier call to get_commit_buffer.  The buffer may or may not be
  * freed by this call; callers should not access the memory afterwards.
  */
-void unuse_commit_buffer(const struct commit *, const void *buffer);
+void repo_unuse_commit_buffer(struct repository *r,
+			      const struct commit *,
+			      const void *buffer);
+#ifndef NO_THE_REPOSITORY_COMPATIBILITY_MACROS
+#define unuse_commit_buffer(c, b) repo_unuse_commit_buffer(the_repository, c, b)
+#endif
 
 /*
  * Free any cached object buffer associated with the commit.
  */
-void free_commit_buffer(struct commit *);
+void free_commit_buffer(struct parsed_object_pool *pool, struct commit *);
 
-struct tree *get_commit_tree(const struct commit *);
+struct tree *repo_get_commit_tree(struct repository *, const struct commit *);
+#define get_commit_tree(c) repo_get_commit_tree(the_repository, c)
 struct object_id *get_commit_tree_oid(const struct commit *);
 
 /*
+ * Release memory related to a commit, including the parent list and
+ * any cached object buffer.
+ */
+void release_commit_memory(struct parsed_object_pool *pool, struct commit *c);
+
+/*
  * Disassociate any cached object buffer from the commit, but do not free it.
  * The buffer (or NULL, if none) is returned.
  */
@@ -136,11 +184,19 @@ void free_commit_list(struct commit_list
 
 struct rev_info; /* in revision.h, it circularly uses enum cmit_fmt */
 
-extern int has_non_ascii(const char *text);
-extern const char *logmsg_reencode(const struct commit *commit,
-				   char **commit_encoding,
-				   const char *output_encoding);
-extern const char *skip_blank_lines(const char *msg);
+int has_non_ascii(const char *text);
+const char *logmsg_reencode(const struct commit *commit,
+			    char **commit_encoding,
+			    const char *output_encoding);
+const char *repo_logmsg_reencode(struct repository *r,
+				 const struct commit *commit,
+				 char **commit_encoding,
+				 const char *output_encoding);
+#ifndef NO_THE_REPOSITORY_COMPATIBILITY_MACROS
+#define logmsg_reencode(c, enc, out) repo_logmsg_reencode(the_repository, c, enc, out)
+#endif
+
+const char *skip_blank_lines(const char *msg);
 
 /** Removes the first commit from a list sorted by date, and adds all
  * of its parents.
@@ -180,38 +236,38 @@ struct commit_graft {
 typedef int (*each_commit_graft_fn)(const struct commit_graft *, void *);
 
 struct commit_graft *read_graft_line(struct strbuf *line);
-int register_commit_graft(struct commit_graft *, int);
-struct commit_graft *lookup_commit_graft(const struct object_id *oid);
-
-extern struct commit_list *get_merge_bases(struct commit *rev1, struct commit *rev2);
-extern struct commit_list *get_merge_bases_many(struct commit *one, int n, struct commit **twos);
-extern struct commit_list *get_octopus_merge_bases(struct commit_list *in);
+int register_commit_graft(struct repository *r, struct commit_graft *, int);
+void prepare_commit_graft(struct repository *r);
+struct commit_graft *lookup_commit_graft(struct repository *r, const struct object_id *oid);
 
-/* To be used only when object flags after this call no longer matter */
-extern struct commit_list *get_merge_bases_many_dirty(struct commit *one, int n, struct commit **twos);
+struct commit *get_fork_point(const char *refname, struct commit *commit);
 
 /* largest positive number a signed 32-bit integer can contain */
 #define INFINITE_DEPTH 0x7fffffff
 
 struct oid_array;
 struct ref;
-extern int register_shallow(const struct object_id *oid);
-extern int unregister_shallow(const struct object_id *oid);
-extern int for_each_commit_graft(each_commit_graft_fn, void *);
-extern int is_repository_shallow(void);
-extern struct commit_list *get_shallow_commits(struct object_array *heads,
-		int depth, int shallow_flag, int not_shallow_flag);
-extern struct commit_list *get_shallow_commits_by_rev_list(
+int register_shallow(struct repository *r, const struct object_id *oid);
+int unregister_shallow(const struct object_id *oid);
+int for_each_commit_graft(each_commit_graft_fn, void *);
+int is_repository_shallow(struct repository *r);
+struct commit_list *get_shallow_commits(struct object_array *heads,
+					int depth, int shallow_flag, int not_shallow_flag);
+struct commit_list *get_shallow_commits_by_rev_list(
 		int ac, const char **av, int shallow_flag, int not_shallow_flag);
-extern void set_alternate_shallow_file(const char *path, int override);
-extern int write_shallow_commits(struct strbuf *out, int use_pack_protocol,
-				 const struct oid_array *extra);
-extern void setup_alternate_shallow(struct lock_file *shallow_lock,
-				    const char **alternate_shallow_file,
-				    const struct oid_array *extra);
-extern const char *setup_temporary_shallow(const struct oid_array *extra);
-extern void advertise_shallow_grafts(int);
+void set_alternate_shallow_file(struct repository *r, const char *path, int override);
+int write_shallow_commits(struct strbuf *out, int use_pack_protocol,
+			  const struct oid_array *extra);
+void setup_alternate_shallow(struct lock_file *shallow_lock,
+			     const char **alternate_shallow_file,
+			     const struct oid_array *extra);
+const char *setup_temporary_shallow(const struct oid_array *extra);
+void advertise_shallow_grafts(int);
 
+/*
+ * Initialize with prepare_shallow_info() or zero-initialize (equivalent to
+ * prepare_shallow_info with a NULL oid_array).
+ */
 struct shallow_info {
 	struct oid_array *shallow;
 	int *ours, nr_ours;
@@ -227,41 +283,21 @@ struct shallow_info {
 	int nr_commits;
 };
 
-extern void prepare_shallow_info(struct shallow_info *, struct oid_array *);
-extern void clear_shallow_info(struct shallow_info *);
-extern void remove_nonexistent_theirs_shallow(struct shallow_info *);
-extern void assign_shallow_commits_to_refs(struct shallow_info *info,
-					   uint32_t **used,
-					   int *ref_status);
-extern int delayed_reachability_test(struct shallow_info *si, int c);
-extern void prune_shallow(int show_only);
+void prepare_shallow_info(struct shallow_info *, struct oid_array *);
+void clear_shallow_info(struct shallow_info *);
+void remove_nonexistent_theirs_shallow(struct shallow_info *);
+void assign_shallow_commits_to_refs(struct shallow_info *info,
+				    uint32_t **used,
+				    int *ref_status);
+int delayed_reachability_test(struct shallow_info *si, int c);
+#define PRUNE_SHOW_ONLY 1
+#define PRUNE_QUICK 2
+void prune_shallow(unsigned options);
 extern struct trace_key trace_shallow;
 
-int is_descendant_of(struct commit *, struct commit_list *);
-int in_merge_bases(struct commit *, struct commit *);
-int in_merge_bases_many(struct commit *, int, struct commit **);
-
-extern int interactive_add(int argc, const char **argv, const char *prefix, int patch);
-extern int run_add_interactive(const char *revision, const char *patch_mode,
-			       const struct pathspec *pathspec);
-
-/*
- * Takes a list of commits and returns a new list where those
- * have been removed that can be reached from other commits in
- * the list. It is useful for, e.g., reducing the commits
- * randomly thrown at the git-merge command and removing
- * redundant commits that the user shouldn't have given to it.
- *
- * This function destroys the STALE bit of the commit objects'
- * flags.
- */
-extern struct commit_list *reduce_heads(struct commit_list *heads);
-
-/*
- * Like `reduce_heads()`, except it replaces the list. Use this
- * instead of `foo = reduce_heads(foo);` to avoid memory leaks.
- */
-extern void reduce_heads_replace(struct commit_list **heads);
+int interactive_add(int argc, const char **argv, const char *prefix, int patch);
+int run_add_interactive(const char *revision, const char *patch_mode,
+			const struct pathspec *pathspec);
 
 struct commit_extra_header {
 	struct commit_extra_header *next;
@@ -270,24 +306,24 @@ struct commit_extra_header {
 	size_t len;
 };
 
-extern void append_merge_tag_headers(struct commit_list *parents,
-				     struct commit_extra_header ***tail);
+void append_merge_tag_headers(struct commit_list *parents,
+			      struct commit_extra_header ***tail);
 
-extern int commit_tree(const char *msg, size_t msg_len,
-		       const struct object_id *tree,
-		       struct commit_list *parents, struct object_id *ret,
-		       const char *author, const char *sign_commit);
-
-extern int commit_tree_extended(const char *msg, size_t msg_len,
-				const struct object_id *tree,
-				struct commit_list *parents,
-				struct object_id *ret, const char *author,
-				const char *sign_commit,
-				struct commit_extra_header *);
+int commit_tree(const char *msg, size_t msg_len,
+		const struct object_id *tree,
+		struct commit_list *parents, struct object_id *ret,
+		const char *author, const char *sign_commit);
+
+int commit_tree_extended(const char *msg, size_t msg_len,
+			 const struct object_id *tree,
+			 struct commit_list *parents,
+			 struct object_id *ret, const char *author,
+			 const char *sign_commit,
+			 struct commit_extra_header *);
 
-extern struct commit_extra_header *read_commit_extra_headers(struct commit *, const char **);
+struct commit_extra_header *read_commit_extra_headers(struct commit *, const char **);
 
-extern void free_commit_extra_headers(struct commit_extra_header *extra);
+void free_commit_extra_headers(struct commit_extra_header *extra);
 
 /*
  * Search the commit object contents given by "msg" for the header "key".
@@ -297,24 +333,24 @@ extern void free_commit_extra_headers(st
  * Note that some headers (like mergetag) may be multi-line. It is the caller's
  * responsibility to parse further in this case!
  */
-extern const char *find_commit_header(const char *msg, const char *key,
-				      size_t *out_len);
+const char *find_commit_header(const char *msg, const char *key,
+			       size_t *out_len);
 
 /* Find the end of the log message, the right place for a new trailer. */
-extern int ignore_non_trailer(const char *buf, size_t len);
+size_t ignore_non_trailer(const char *buf, size_t len);
 
 typedef int (*each_mergetag_fn)(struct commit *commit, struct commit_extra_header *extra,
-				 void *cb_data);
+				void *cb_data);
 
-extern int for_each_mergetag(each_mergetag_fn fn, struct commit *commit, void *data);
+int for_each_mergetag(each_mergetag_fn fn, struct commit *commit, void *data);
 
 struct merge_remote_desc {
 	struct object *obj; /* the named object, could be a tag */
 	char name[FLEX_ARRAY];
 };
-#define merge_remote_util(commit) ((struct merge_remote_desc *)((commit)->util))
-extern void set_merge_remote_desc(struct commit *commit,
-				  const char *name, struct object *obj);
+struct merge_remote_desc *merge_remote_util(struct commit *);
+void set_merge_remote_desc(struct commit *commit,
+			   const char *name, struct object *obj);
 
 /*
  * Given "name" from the command line to merge, find the commit object
@@ -323,9 +359,9 @@ extern void set_merge_remote_desc(struct
  */
 struct commit *get_merge_parent(const char *name);
 
-extern int parse_signed_commit(const struct commit *commit,
-			       struct strbuf *message, struct strbuf *signature);
-extern int remove_signature(struct strbuf *buf);
+int parse_signed_commit(const struct commit *commit,
+			struct strbuf *message, struct strbuf *signature);
+int remove_signature(struct strbuf *buf);
 
 /*
  * Check the signature of the given commit. The result of the check is stored
@@ -334,11 +370,26 @@ extern int remove_signature(struct strbu
  * at all.  This may allocate memory for sig->gpg_output, sig->gpg_status,
  * sig->signer and sig->key.
  */
-extern int check_commit_signature(const struct commit *commit, struct signature_check *sigc);
+int check_commit_signature(const struct commit *commit, struct signature_check *sigc);
+
+/* record author-date for each commit object */
+struct author_date_slab;
+void record_author_date(struct author_date_slab *author_date,
+			struct commit *commit);
+
+int compare_commits_by_author_date(const void *a_, const void *b_, void *unused);
+
+/*
+ * Verify a single commit with check_commit_signature() and die() if it is not
+ * a good signature. This isn't really suitable for general use, but is a
+ * helper to implement consistent logic for pull/merge --verify-signatures.
+ */
+void verify_merge_signature(struct commit *commit, int verbose);
 
 int compare_commits_by_commit_date(const void *a_, const void *b_, void *unused);
+int compare_commits_by_gen_then_commit_date(const void *a_, const void *b_, void *unused);
 
 LAST_ARG_MUST_BE_NULL
-extern int run_commit_hook(int editor_is_used, const char *index_file, const char *name, ...);
+int run_commit_hook(int editor_is_used, const char *index_file, const char *name, ...);
 
 #endif /* COMMIT_H */
diff -pruN 1.2.1+git2.18.0-1/git/commit-reach.c 1.2.3+git2.25.1-1/git/commit-reach.c
--- 1.2.1+git2.18.0-1/git/commit-reach.c	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/commit-reach.c	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,773 @@
+#include "cache.h"
+#include "commit.h"
+#include "commit-graph.h"
+#include "decorate.h"
+#include "prio-queue.h"
+#include "tree.h"
+#include "ref-filter.h"
+#include "revision.h"
+#include "tag.h"
+#include "commit-reach.h"
+
+/* Remember to update object flag allocation in object.h */
+#define PARENT1		(1u<<16)
+#define PARENT2		(1u<<17)
+#define STALE		(1u<<18)
+#define RESULT		(1u<<19)
+
+static const unsigned all_flags = (PARENT1 | PARENT2 | STALE | RESULT);
+
+static int queue_has_nonstale(struct prio_queue *queue)
+{
+	int i;
+	for (i = 0; i < queue->nr; i++) {
+		struct commit *commit = queue->array[i].data;
+		if (!(commit->object.flags & STALE))
+			return 1;
+	}
+	return 0;
+}
+
+/* all input commits in one and twos[] must have been parsed! */
+static struct commit_list *paint_down_to_common(struct repository *r,
+						struct commit *one, int n,
+						struct commit **twos,
+						int min_generation)
+{
+	struct prio_queue queue = { compare_commits_by_gen_then_commit_date };
+	struct commit_list *result = NULL;
+	int i;
+	uint32_t last_gen = GENERATION_NUMBER_INFINITY;
+
+	if (!min_generation)
+		queue.compare = compare_commits_by_commit_date;
+
+	one->object.flags |= PARENT1;
+	if (!n) {
+		commit_list_append(one, &result);
+		return result;
+	}
+	prio_queue_put(&queue, one);
+
+	for (i = 0; i < n; i++) {
+		twos[i]->object.flags |= PARENT2;
+		prio_queue_put(&queue, twos[i]);
+	}
+
+	while (queue_has_nonstale(&queue)) {
+		struct commit *commit = prio_queue_get(&queue);
+		struct commit_list *parents;
+		int flags;
+
+		if (min_generation && commit->generation > last_gen)
+			BUG("bad generation skip %8x > %8x at %s",
+			    commit->generation, last_gen,
+			    oid_to_hex(&commit->object.oid));
+		last_gen = commit->generation;
+
+		if (commit->generation < min_generation)
+			break;
+
+		flags = commit->object.flags & (PARENT1 | PARENT2 | STALE);
+		if (flags == (PARENT1 | PARENT2)) {
+			if (!(commit->object.flags & RESULT)) {
+				commit->object.flags |= RESULT;
+				commit_list_insert_by_date(commit, &result);
+			}
+			/* Mark parents of a found merge stale */
+			flags |= STALE;
+		}
+		parents = commit->parents;
+		while (parents) {
+			struct commit *p = parents->item;
+			parents = parents->next;
+			if ((p->object.flags & flags) == flags)
+				continue;
+			if (repo_parse_commit(r, p))
+				return NULL;
+			p->object.flags |= flags;
+			prio_queue_put(&queue, p);
+		}
+	}
+
+	clear_prio_queue(&queue);
+	return result;
+}
+
+static struct commit_list *merge_bases_many(struct repository *r,
+					    struct commit *one, int n,
+					    struct commit **twos)
+{
+	struct commit_list *list = NULL;
+	struct commit_list *result = NULL;
+	int i;
+
+	for (i = 0; i < n; i++) {
+		if (one == twos[i])
+			/*
+			 * We do not mark this even with RESULT so we do not
+			 * have to clean it up.
+			 */
+			return commit_list_insert(one, &result);
+	}
+
+	if (repo_parse_commit(r, one))
+		return NULL;
+	for (i = 0; i < n; i++) {
+		if (repo_parse_commit(r, twos[i]))
+			return NULL;
+	}
+
+	list = paint_down_to_common(r, one, n, twos, 0);
+
+	while (list) {
+		struct commit *commit = pop_commit(&list);
+		if (!(commit->object.flags & STALE))
+			commit_list_insert_by_date(commit, &result);
+	}
+	return result;
+}
+
+struct commit_list *get_octopus_merge_bases(struct commit_list *in)
+{
+	struct commit_list *i, *j, *k, *ret = NULL;
+
+	if (!in)
+		return ret;
+
+	commit_list_insert(in->item, &ret);
+
+	for (i = in->next; i; i = i->next) {
+		struct commit_list *new_commits = NULL, *end = NULL;
+
+		for (j = ret; j; j = j->next) {
+			struct commit_list *bases;
+			bases = get_merge_bases(i->item, j->item);
+			if (!new_commits)
+				new_commits = bases;
+			else
+				end->next = bases;
+			for (k = bases; k; k = k->next)
+				end = k;
+		}
+		ret = new_commits;
+	}
+	return ret;
+}
+
+static int remove_redundant(struct repository *r, struct commit **array, int cnt)
+{
+	/*
+	 * Some commit in the array may be an ancestor of
+	 * another commit.  Move such commit to the end of
+	 * the array, and return the number of commits that
+	 * are independent from each other.
+	 */
+	struct commit **work;
+	unsigned char *redundant;
+	int *filled_index;
+	int i, j, filled;
+
+	work = xcalloc(cnt, sizeof(*work));
+	redundant = xcalloc(cnt, 1);
+	ALLOC_ARRAY(filled_index, cnt - 1);
+
+	for (i = 0; i < cnt; i++)
+		repo_parse_commit(r, array[i]);
+	for (i = 0; i < cnt; i++) {
+		struct commit_list *common;
+		uint32_t min_generation = array[i]->generation;
+
+		if (redundant[i])
+			continue;
+		for (j = filled = 0; j < cnt; j++) {
+			if (i == j || redundant[j])
+				continue;
+			filled_index[filled] = j;
+			work[filled++] = array[j];
+
+			if (array[j]->generation < min_generation)
+				min_generation = array[j]->generation;
+		}
+		common = paint_down_to_common(r, array[i], filled,
+					      work, min_generation);
+		if (array[i]->object.flags & PARENT2)
+			redundant[i] = 1;
+		for (j = 0; j < filled; j++)
+			if (work[j]->object.flags & PARENT1)
+				redundant[filled_index[j]] = 1;
+		clear_commit_marks(array[i], all_flags);
+		clear_commit_marks_many(filled, work, all_flags);
+		free_commit_list(common);
+	}
+
+	/* Now collect the result */
+	COPY_ARRAY(work, array, cnt);
+	for (i = filled = 0; i < cnt; i++)
+		if (!redundant[i])
+			array[filled++] = work[i];
+	for (j = filled, i = 0; i < cnt; i++)
+		if (redundant[i])
+			array[j++] = work[i];
+	free(work);
+	free(redundant);
+	free(filled_index);
+	return filled;
+}
+
+static struct commit_list *get_merge_bases_many_0(struct repository *r,
+						  struct commit *one,
+						  int n,
+						  struct commit **twos,
+						  int cleanup)
+{
+	struct commit_list *list;
+	struct commit **rslt;
+	struct commit_list *result;
+	int cnt, i;
+
+	result = merge_bases_many(r, one, n, twos);
+	for (i = 0; i < n; i++) {
+		if (one == twos[i])
+			return result;
+	}
+	if (!result || !result->next) {
+		if (cleanup) {
+			clear_commit_marks(one, all_flags);
+			clear_commit_marks_many(n, twos, all_flags);
+		}
+		return result;
+	}
+
+	/* There are more than one */
+	cnt = commit_list_count(result);
+	rslt = xcalloc(cnt, sizeof(*rslt));
+	for (list = result, i = 0; list; list = list->next)
+		rslt[i++] = list->item;
+	free_commit_list(result);
+
+	clear_commit_marks(one, all_flags);
+	clear_commit_marks_many(n, twos, all_flags);
+
+	cnt = remove_redundant(r, rslt, cnt);
+	result = NULL;
+	for (i = 0; i < cnt; i++)
+		commit_list_insert_by_date(rslt[i], &result);
+	free(rslt);
+	return result;
+}
+
+struct commit_list *repo_get_merge_bases_many(struct repository *r,
+					      struct commit *one,
+					      int n,
+					      struct commit **twos)
+{
+	return get_merge_bases_many_0(r, one, n, twos, 1);
+}
+
+struct commit_list *repo_get_merge_bases_many_dirty(struct repository *r,
+						    struct commit *one,
+						    int n,
+						    struct commit **twos)
+{
+	return get_merge_bases_many_0(r, one, n, twos, 0);
+}
+
+struct commit_list *repo_get_merge_bases(struct repository *r,
+					 struct commit *one,
+					 struct commit *two)
+{
+	return get_merge_bases_many_0(r, one, 1, &two, 1);
+}
+
+/*
+ * Is "commit" a descendant of one of the elements on the "with_commit" list?
+ */
+int is_descendant_of(struct commit *commit, struct commit_list *with_commit)
+{
+	if (!with_commit)
+		return 1;
+
+	if (generation_numbers_enabled(the_repository)) {
+		struct commit_list *from_list = NULL;
+		int result;
+		commit_list_insert(commit, &from_list);
+		result = can_all_from_reach(from_list, with_commit, 0);
+		free_commit_list(from_list);
+		return result;
+	} else {
+		while (with_commit) {
+			struct commit *other;
+
+			other = with_commit->item;
+			with_commit = with_commit->next;
+			if (in_merge_bases(other, commit))
+				return 1;
+		}
+		return 0;
+	}
+}
+
+/*
+ * Is "commit" an ancestor of one of the "references"?
+ */
+int repo_in_merge_bases_many(struct repository *r, struct commit *commit,
+			     int nr_reference, struct commit **reference)
+{
+	struct commit_list *bases;
+	int ret = 0, i;
+	uint32_t min_generation = GENERATION_NUMBER_INFINITY;
+
+	if (repo_parse_commit(r, commit))
+		return ret;
+	for (i = 0; i < nr_reference; i++) {
+		if (repo_parse_commit(r, reference[i]))
+			return ret;
+		if (reference[i]->generation < min_generation)
+			min_generation = reference[i]->generation;
+	}
+
+	if (commit->generation > min_generation)
+		return ret;
+
+	bases = paint_down_to_common(r, commit,
+				     nr_reference, reference,
+				     commit->generation);
+	if (commit->object.flags & PARENT2)
+		ret = 1;
+	clear_commit_marks(commit, all_flags);
+	clear_commit_marks_many(nr_reference, reference, all_flags);
+	free_commit_list(bases);
+	return ret;
+}
+
+/*
+ * Is "commit" an ancestor of (i.e. reachable from) the "reference"?
+ */
+int repo_in_merge_bases(struct repository *r,
+			struct commit *commit,
+			struct commit *reference)
+{
+	return repo_in_merge_bases_many(r, commit, 1, &reference);
+}
+
+struct commit_list *reduce_heads(struct commit_list *heads)
+{
+	struct commit_list *p;
+	struct commit_list *result = NULL, **tail = &result;
+	struct commit **array;
+	int num_head, i;
+
+	if (!heads)
+		return NULL;
+
+	/* Uniquify */
+	for (p = heads; p; p = p->next)
+		p->item->object.flags &= ~STALE;
+	for (p = heads, num_head = 0; p; p = p->next) {
+		if (p->item->object.flags & STALE)
+			continue;
+		p->item->object.flags |= STALE;
+		num_head++;
+	}
+	array = xcalloc(num_head, sizeof(*array));
+	for (p = heads, i = 0; p; p = p->next) {
+		if (p->item->object.flags & STALE) {
+			array[i++] = p->item;
+			p->item->object.flags &= ~STALE;
+		}
+	}
+	num_head = remove_redundant(the_repository, array, num_head);
+	for (i = 0; i < num_head; i++)
+		tail = &commit_list_insert(array[i], tail)->next;
+	free(array);
+	return result;
+}
+
+void reduce_heads_replace(struct commit_list **heads)
+{
+	struct commit_list *result = reduce_heads(*heads);
+	free_commit_list(*heads);
+	*heads = result;
+}
+
+int ref_newer(const struct object_id *new_oid, const struct object_id *old_oid)
+{
+	struct object *o;
+	struct commit *old_commit, *new_commit;
+	struct commit_list *old_commit_list = NULL;
+
+	/*
+	 * Both new_commit and old_commit must be commit-ish and new_commit is descendant of
+	 * old_commit.  Otherwise we require --force.
+	 */
+	o = deref_tag(the_repository, parse_object(the_repository, old_oid),
+		      NULL, 0);
+	if (!o || o->type != OBJ_COMMIT)
+		return 0;
+	old_commit = (struct commit *) o;
+
+	o = deref_tag(the_repository, parse_object(the_repository, new_oid),
+		      NULL, 0);
+	if (!o || o->type != OBJ_COMMIT)
+		return 0;
+	new_commit = (struct commit *) o;
+
+	if (parse_commit(new_commit) < 0)
+		return 0;
+
+	commit_list_insert(old_commit, &old_commit_list);
+	return is_descendant_of(new_commit, old_commit_list);
+}
+
+/*
+ * Mimicking the real stack, this stack lives on the heap, avoiding stack
+ * overflows.
+ *
+ * At each recursion step, the stack items points to the commits whose
+ * ancestors are to be inspected.
+ */
+struct contains_stack {
+	int nr, alloc;
+	struct contains_stack_entry {
+		struct commit *commit;
+		struct commit_list *parents;
+	} *contains_stack;
+};
+
+static int in_commit_list(const struct commit_list *want, struct commit *c)
+{
+	for (; want; want = want->next)
+		if (oideq(&want->item->object.oid, &c->object.oid))
+			return 1;
+	return 0;
+}
+
+/*
+ * Test whether the candidate is contained in the list.
+ * Do not recurse to find out, though, but return -1 if inconclusive.
+ */
+static enum contains_result contains_test(struct commit *candidate,
+					  const struct commit_list *want,
+					  struct contains_cache *cache,
+					  uint32_t cutoff)
+{
+	enum contains_result *cached = contains_cache_at(cache, candidate);
+
+	/* If we already have the answer cached, return that. */
+	if (*cached)
+		return *cached;
+
+	/* or are we it? */
+	if (in_commit_list(want, candidate)) {
+		*cached = CONTAINS_YES;
+		return CONTAINS_YES;
+	}
+
+	/* Otherwise, we don't know; prepare to recurse */
+	parse_commit_or_die(candidate);
+
+	if (candidate->generation < cutoff)
+		return CONTAINS_NO;
+
+	return CONTAINS_UNKNOWN;
+}
+
+static void push_to_contains_stack(struct commit *candidate, struct contains_stack *contains_stack)
+{
+	ALLOC_GROW(contains_stack->contains_stack, contains_stack->nr + 1, contains_stack->alloc);
+	contains_stack->contains_stack[contains_stack->nr].commit = candidate;
+	contains_stack->contains_stack[contains_stack->nr++].parents = candidate->parents;
+}
+
+static enum contains_result contains_tag_algo(struct commit *candidate,
+					      const struct commit_list *want,
+					      struct contains_cache *cache)
+{
+	struct contains_stack contains_stack = { 0, 0, NULL };
+	enum contains_result result;
+	uint32_t cutoff = GENERATION_NUMBER_INFINITY;
+	const struct commit_list *p;
+
+	for (p = want; p; p = p->next) {
+		struct commit *c = p->item;
+		load_commit_graph_info(the_repository, c);
+		if (c->generation < cutoff)
+			cutoff = c->generation;
+	}
+
+	result = contains_test(candidate, want, cache, cutoff);
+	if (result != CONTAINS_UNKNOWN)
+		return result;
+
+	push_to_contains_stack(candidate, &contains_stack);
+	while (contains_stack.nr) {
+		struct contains_stack_entry *entry = &contains_stack.contains_stack[contains_stack.nr - 1];
+		struct commit *commit = entry->commit;
+		struct commit_list *parents = entry->parents;
+
+		if (!parents) {
+			*contains_cache_at(cache, commit) = CONTAINS_NO;
+			contains_stack.nr--;
+		}
+		/*
+		 * If we just popped the stack, parents->item has been marked,
+		 * therefore contains_test will return a meaningful yes/no.
+		 */
+		else switch (contains_test(parents->item, want, cache, cutoff)) {
+		case CONTAINS_YES:
+			*contains_cache_at(cache, commit) = CONTAINS_YES;
+			contains_stack.nr--;
+			break;
+		case CONTAINS_NO:
+			entry->parents = parents->next;
+			break;
+		case CONTAINS_UNKNOWN:
+			push_to_contains_stack(parents->item, &contains_stack);
+			break;
+		}
+	}
+	free(contains_stack.contains_stack);
+	return contains_test(candidate, want, cache, cutoff);
+}
+
+int commit_contains(struct ref_filter *filter, struct commit *commit,
+		    struct commit_list *list, struct contains_cache *cache)
+{
+	if (filter->with_commit_tag_algo)
+		return contains_tag_algo(commit, list, cache) == CONTAINS_YES;
+	return is_descendant_of(commit, list);
+}
+
+static int compare_commits_by_gen(const void *_a, const void *_b)
+{
+	const struct commit *a = *(const struct commit * const *)_a;
+	const struct commit *b = *(const struct commit * const *)_b;
+
+	if (a->generation < b->generation)
+		return -1;
+	if (a->generation > b->generation)
+		return 1;
+	return 0;
+}
+
+int can_all_from_reach_with_flag(struct object_array *from,
+				 unsigned int with_flag,
+				 unsigned int assign_flag,
+				 time_t min_commit_date,
+				 uint32_t min_generation)
+{
+	struct commit **list = NULL;
+	int i;
+	int nr_commits;
+	int result = 1;
+
+	ALLOC_ARRAY(list, from->nr);
+	nr_commits = 0;
+	for (i = 0; i < from->nr; i++) {
+		struct object *from_one = from->objects[i].item;
+
+		if (!from_one || from_one->flags & assign_flag)
+			continue;
+
+		from_one = deref_tag(the_repository, from_one,
+				     "a from object", 0);
+		if (!from_one || from_one->type != OBJ_COMMIT) {
+			/*
+			 * no way to tell if this is reachable by
+			 * looking at the ancestry chain alone, so
+			 * leave a note to ourselves not to worry about
+			 * this object anymore.
+			 */
+			from->objects[i].item->flags |= assign_flag;
+			continue;
+		}
+
+		list[nr_commits] = (struct commit *)from_one;
+		if (parse_commit(list[nr_commits]) ||
+		    list[nr_commits]->generation < min_generation) {
+			result = 0;
+			goto cleanup;
+		}
+
+		nr_commits++;
+	}
+
+	QSORT(list, nr_commits, compare_commits_by_gen);
+
+	for (i = 0; i < nr_commits; i++) {
+		/* DFS from list[i] */
+		struct commit_list *stack = NULL;
+
+		list[i]->object.flags |= assign_flag;
+		commit_list_insert(list[i], &stack);
+
+		while (stack) {
+			struct commit_list *parent;
+
+			if (stack->item->object.flags & (with_flag | RESULT)) {
+				pop_commit(&stack);
+				if (stack)
+					stack->item->object.flags |= RESULT;
+				continue;
+			}
+
+			for (parent = stack->item->parents; parent; parent = parent->next) {
+				if (parent->item->object.flags & (with_flag | RESULT))
+					stack->item->object.flags |= RESULT;
+
+				if (!(parent->item->object.flags & assign_flag)) {
+					parent->item->object.flags |= assign_flag;
+
+					if (parse_commit(parent->item) ||
+					    parent->item->date < min_commit_date ||
+					    parent->item->generation < min_generation)
+						continue;
+
+					commit_list_insert(parent->item, &stack);
+					break;
+				}
+			}
+
+			if (!parent)
+				pop_commit(&stack);
+		}
+
+		if (!(list[i]->object.flags & (with_flag | RESULT))) {
+			result = 0;
+			goto cleanup;
+		}
+	}
+
+cleanup:
+	clear_commit_marks_many(nr_commits, list, RESULT | assign_flag);
+	free(list);
+
+	for (i = 0; i < from->nr; i++)
+		from->objects[i].item->flags &= ~assign_flag;
+
+	return result;
+}
+
+int can_all_from_reach(struct commit_list *from, struct commit_list *to,
+		       int cutoff_by_min_date)
+{
+	struct object_array from_objs = OBJECT_ARRAY_INIT;
+	time_t min_commit_date = cutoff_by_min_date ? from->item->date : 0;
+	struct commit_list *from_iter = from, *to_iter = to;
+	int result;
+	uint32_t min_generation = GENERATION_NUMBER_INFINITY;
+
+	while (from_iter) {
+		add_object_array(&from_iter->item->object, NULL, &from_objs);
+
+		if (!parse_commit(from_iter->item)) {
+			if (from_iter->item->date < min_commit_date)
+				min_commit_date = from_iter->item->date;
+
+			if (from_iter->item->generation < min_generation)
+				min_generation = from_iter->item->generation;
+		}
+
+		from_iter = from_iter->next;
+	}
+
+	while (to_iter) {
+		if (!parse_commit(to_iter->item)) {
+			if (to_iter->item->date < min_commit_date)
+				min_commit_date = to_iter->item->date;
+
+			if (to_iter->item->generation < min_generation)
+				min_generation = to_iter->item->generation;
+		}
+
+		to_iter->item->object.flags |= PARENT2;
+
+		to_iter = to_iter->next;
+	}
+
+	result = can_all_from_reach_with_flag(&from_objs, PARENT2, PARENT1,
+					      min_commit_date, min_generation);
+
+	while (from) {
+		clear_commit_marks(from->item, PARENT1);
+		from = from->next;
+	}
+
+	while (to) {
+		clear_commit_marks(to->item, PARENT2);
+		to = to->next;
+	}
+
+	object_array_clear(&from_objs);
+	return result;
+}
+
+struct commit_list *get_reachable_subset(struct commit **from, int nr_from,
+					 struct commit **to, int nr_to,
+					 unsigned int reachable_flag)
+{
+	struct commit **item;
+	struct commit *current;
+	struct commit_list *found_commits = NULL;
+	struct commit **to_last = to + nr_to;
+	struct commit **from_last = from + nr_from;
+	uint32_t min_generation = GENERATION_NUMBER_INFINITY;
+	int num_to_find = 0;
+
+	struct prio_queue queue = { compare_commits_by_gen_then_commit_date };
+
+	for (item = to; item < to_last; item++) {
+		struct commit *c = *item;
+
+		parse_commit(c);
+		if (c->generation < min_generation)
+			min_generation = c->generation;
+
+		if (!(c->object.flags & PARENT1)) {
+			c->object.flags |= PARENT1;
+			num_to_find++;
+		}
+	}
+
+	for (item = from; item < from_last; item++) {
+		struct commit *c = *item;
+		if (!(c->object.flags & PARENT2)) {
+			c->object.flags |= PARENT2;
+			parse_commit(c);
+
+			prio_queue_put(&queue, *item);
+		}
+	}
+
+	while (num_to_find && (current = prio_queue_get(&queue)) != NULL) {
+		struct commit_list *parents;
+
+		if (current->object.flags & PARENT1) {
+			current->object.flags &= ~PARENT1;
+			current->object.flags |= reachable_flag;
+			commit_list_insert(current, &found_commits);
+			num_to_find--;
+		}
+
+		for (parents = current->parents; parents; parents = parents->next) {
+			struct commit *p = parents->item;
+
+			parse_commit(p);
+
+			if (p->generation < min_generation)
+				continue;
+
+			if (p->object.flags & PARENT2)
+				continue;
+
+			p->object.flags |= PARENT2;
+			prio_queue_put(&queue, p);
+		}
+	}
+
+	clear_commit_marks_many(nr_to, to, PARENT1);
+	clear_commit_marks_many(nr_from, from, PARENT2);
+
+	return found_commits;
+}
diff -pruN 1.2.1+git2.18.0-1/git/commit-reach.h 1.2.3+git2.25.1-1/git/commit-reach.h
--- 1.2.1+git2.18.0-1/git/commit-reach.h	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/commit-reach.h	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,105 @@
+#ifndef COMMIT_REACH_H
+#define COMMIT_REACH_H
+
+#include "commit.h"
+#include "commit-slab.h"
+
+struct commit_list;
+struct ref_filter;
+struct object_id;
+struct object_array;
+
+struct commit_list *repo_get_merge_bases(struct repository *r,
+					 struct commit *rev1,
+					 struct commit *rev2);
+struct commit_list *repo_get_merge_bases_many(struct repository *r,
+					      struct commit *one, int n,
+					      struct commit **twos);
+/* To be used only when object flags after this call no longer matter */
+struct commit_list *repo_get_merge_bases_many_dirty(struct repository *r,
+						    struct commit *one, int n,
+						    struct commit **twos);
+#ifndef NO_THE_REPOSITORY_COMPATIBILITY_MACROS
+#define get_merge_bases(r1, r2)           repo_get_merge_bases(the_repository, r1, r2)
+#define get_merge_bases_many(one, n, two) repo_get_merge_bases_many(the_repository, one, n, two)
+#define get_merge_bases_many_dirty(one, n, twos) repo_get_merge_bases_many_dirty(the_repository, one, n, twos)
+#endif
+
+struct commit_list *get_octopus_merge_bases(struct commit_list *in);
+
+int is_descendant_of(struct commit *commit, struct commit_list *with_commit);
+int repo_in_merge_bases(struct repository *r,
+			struct commit *commit,
+			struct commit *reference);
+int repo_in_merge_bases_many(struct repository *r,
+			     struct commit *commit,
+			     int nr_reference, struct commit **reference);
+#ifndef NO_THE_REPOSITORY_COMPATIBILITY_MACROS
+#define in_merge_bases(c1, c2) repo_in_merge_bases(the_repository, c1, c2)
+#define in_merge_bases_many(c1, n, cs) repo_in_merge_bases_many(the_repository, c1, n, cs)
+#endif
+
+/*
+ * Takes a list of commits and returns a new list where those
+ * have been removed that can be reached from other commits in
+ * the list. It is useful for, e.g., reducing the commits
+ * randomly thrown at the git-merge command and removing
+ * redundant commits that the user shouldn't have given to it.
+ *
+ * This function destroys the STALE bit of the commit objects'
+ * flags.
+ */
+struct commit_list *reduce_heads(struct commit_list *heads);
+
+/*
+ * Like `reduce_heads()`, except it replaces the list. Use this
+ * instead of `foo = reduce_heads(foo);` to avoid memory leaks.
+ */
+void reduce_heads_replace(struct commit_list **heads);
+
+int ref_newer(const struct object_id *new_oid, const struct object_id *old_oid);
+
+/*
+ * Unknown has to be "0" here, because that's the default value for
+ * contains_cache slab entries that have not yet been assigned.
+ */
+enum contains_result {
+	CONTAINS_UNKNOWN = 0,
+	CONTAINS_NO,
+	CONTAINS_YES
+};
+
+define_commit_slab(contains_cache, enum contains_result);
+
+int commit_contains(struct ref_filter *filter, struct commit *commit,
+		    struct commit_list *list, struct contains_cache *cache);
+
+/*
+ * Determine if every commit in 'from' can reach at least one commit
+ * that is marked with 'with_flag'. As we traverse, use 'assign_flag'
+ * as a marker for commits that are already visited. Do not walk
+ * commits with date below 'min_commit_date' or generation below
+ * 'min_generation'.
+ */
+int can_all_from_reach_with_flag(struct object_array *from,
+				 unsigned int with_flag,
+				 unsigned int assign_flag,
+				 time_t min_commit_date,
+				 uint32_t min_generation);
+int can_all_from_reach(struct commit_list *from, struct commit_list *to,
+		       int commit_date_cutoff);
+
+
+/*
+ * Return a list of commits containing the commits in the 'to' array
+ * that are reachable from at least one commit in the 'from' array.
+ * Also add the given 'flag' to each of the commits in the returned list.
+ *
+ * This method uses the PARENT1 and PARENT2 flags during its operation,
+ * so be sure these flags are not set before calling the method.
+ */
+struct commit_list *get_reachable_subset(struct commit **from, int nr_from,
+					 struct commit **to, int nr_to,
+					 unsigned int reachable_flag);
+
+#endif
diff -pruN 1.2.1+git2.18.0-1/git/commit-slab-decl.h 1.2.3+git2.25.1-1/git/commit-slab-decl.h
--- 1.2.1+git2.18.0-1/git/commit-slab-decl.h	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/commit-slab-decl.h	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,43 @@
+#ifndef COMMIT_SLAB_HDR_H
+#define COMMIT_SLAB_HDR_H
+
+/* allocate ~512kB at once, allowing for malloc overhead */
+#ifndef COMMIT_SLAB_SIZE
+#define COMMIT_SLAB_SIZE (512*1024-32)
+#endif
+
+#define declare_commit_slab(slabname, elemtype) 			\
+									\
+struct slabname {							\
+	unsigned slab_size;						\
+	unsigned stride;						\
+	unsigned slab_count;						\
+	elemtype **slab;						\
+}
+
+/*
+ * Statically initialize a commit slab named "var". Note that this
+ * evaluates "stride" multiple times! Example:
+ *
+ *   struct indegree indegrees = COMMIT_SLAB_INIT(1, indegrees);
+ *
+ */
+#define COMMIT_SLAB_INIT(stride, var) { \
+	COMMIT_SLAB_SIZE / sizeof(**((var).slab)) / (stride), \
+	(stride), 0, NULL \
+}
+
+#define declare_commit_slab_prototypes(slabname, elemtype)		\
+									\
+void init_ ##slabname## _with_stride(struct slabname *s, unsigned stride); \
+void init_ ##slabname(struct slabname *s);				\
+void clear_ ##slabname(struct slabname *s);				\
+elemtype *slabname## _at_peek(struct slabname *s, const struct commit *c, int add_if_missing); \
+elemtype *slabname## _at(struct slabname *s, const struct commit *c);	\
+elemtype *slabname## _peek(struct slabname *s, const struct commit *c)
+
+#define define_shared_commit_slab(slabname, elemtype) \
+	declare_commit_slab(slabname, elemtype); \
+	declare_commit_slab_prototypes(slabname, elemtype)
+
+#endif /* COMMIT_SLAB_HDR_H */
diff -pruN 1.2.1+git2.18.0-1/git/commit-slab.h 1.2.3+git2.25.1-1/git/commit-slab.h
--- 1.2.1+git2.18.0-1/git/commit-slab.h	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/commit-slab.h	2020-02-17 04:47:35.000000000 +0000
@@ -1,6 +1,9 @@
 #ifndef COMMIT_SLAB_H
 #define COMMIT_SLAB_H
 
+#include "commit-slab-decl.h"
+#include "commit-slab-impl.h"
+
 /*
  * define_commit_slab(slabname, elemtype) creates boilerplate code to define
  * a new struct (struct slabname) that is used to associate a piece of data
@@ -41,114 +44,8 @@
  *   leaking memory.
  */
 
-/* allocate ~512kB at once, allowing for malloc overhead */
-#ifndef COMMIT_SLAB_SIZE
-#define COMMIT_SLAB_SIZE (512*1024-32)
-#endif
-
-#define MAYBE_UNUSED __attribute__((__unused__))
-
-#define define_commit_slab(slabname, elemtype) 				\
-									\
-struct slabname {							\
-	unsigned slab_size;						\
-	unsigned stride;						\
-	unsigned slab_count;						\
-	elemtype **slab;						\
-};									\
-static int stat_ ##slabname## realloc;					\
-									\
-static MAYBE_UNUSED void init_ ##slabname## _with_stride(struct slabname *s, \
-						   unsigned stride)	\
-{									\
-	unsigned int elem_size;						\
-	if (!stride)							\
-		stride = 1;						\
-	s->stride = stride;						\
-	elem_size = sizeof(elemtype) * stride;				\
-	s->slab_size = COMMIT_SLAB_SIZE / elem_size;			\
-	s->slab_count = 0;						\
-	s->slab = NULL;							\
-}									\
-									\
-static MAYBE_UNUSED void init_ ##slabname(struct slabname *s)		\
-{									\
-	init_ ##slabname## _with_stride(s, 1);				\
-}									\
-									\
-static MAYBE_UNUSED void clear_ ##slabname(struct slabname *s)		\
-{									\
-	unsigned int i;							\
-	for (i = 0; i < s->slab_count; i++)				\
-		free(s->slab[i]);					\
-	s->slab_count = 0;						\
-	FREE_AND_NULL(s->slab);						\
-}									\
-									\
-static MAYBE_UNUSED elemtype *slabname## _at_peek(struct slabname *s,	\
-						  const struct commit *c, \
-						  int add_if_missing)   \
-{									\
-	unsigned int nth_slab, nth_slot;				\
-									\
-	nth_slab = c->index / s->slab_size;				\
-	nth_slot = c->index % s->slab_size;				\
-									\
-	if (s->slab_count <= nth_slab) {				\
-		unsigned int i;						\
-		if (!add_if_missing)					\
-			return NULL;					\
-		REALLOC_ARRAY(s->slab, nth_slab + 1);			\
-		stat_ ##slabname## realloc++;				\
-		for (i = s->slab_count; i <= nth_slab; i++)		\
-			s->slab[i] = NULL;				\
-		s->slab_count = nth_slab + 1;				\
-	}								\
-	if (!s->slab[nth_slab]) {					\
-		if (!add_if_missing)					\
-			return NULL;					\
-		s->slab[nth_slab] = xcalloc(s->slab_size,		\
-					    sizeof(**s->slab) * s->stride);		\
-	}								\
-	return &s->slab[nth_slab][nth_slot * s->stride];		\
-}									\
-									\
-static MAYBE_UNUSED elemtype *slabname## _at(struct slabname *s,	\
-					     const struct commit *c)	\
-{									\
-	return slabname##_at_peek(s, c, 1);				\
-}									\
-									\
-static MAYBE_UNUSED elemtype *slabname## _peek(struct slabname *s,	\
-					     const struct commit *c)	\
-{									\
-	return slabname##_at_peek(s, c, 0);				\
-}									\
-									\
-struct slabname
-
-/*
- * Note that this redundant forward declaration is required
- * to allow a terminating semicolon, which makes instantiations look
- * like function declarations.  I.e., the expansion of
- *
- *    define_commit_slab(indegree, int);
- *
- * ends in 'struct indegree;'.  This would otherwise
- * be a syntax error according (at least) to ISO C.  It's hard to
- * catch because GCC silently parses it by default.
- */
-
-/*
- * Statically initialize a commit slab named "var". Note that this
- * evaluates "stride" multiple times! Example:
- *
- *   struct indegree indegrees = COMMIT_SLAB_INIT(1, indegrees);
- *
- */
-#define COMMIT_SLAB_INIT(stride, var) { \
-	COMMIT_SLAB_SIZE / sizeof(**((var).slab)) / (stride), \
-	(stride), 0, NULL \
-}
+#define define_commit_slab(slabname, elemtype) \
+	declare_commit_slab(slabname, elemtype); \
+	implement_static_commit_slab(slabname, elemtype)
 
 #endif /* COMMIT_SLAB_H */
diff -pruN 1.2.1+git2.18.0-1/git/commit-slab-impl.h 1.2.3+git2.25.1-1/git/commit-slab-impl.h
--- 1.2.1+git2.18.0-1/git/commit-slab-impl.h	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/commit-slab-impl.h	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,94 @@
+#ifndef COMMIT_SLAB_IMPL_H
+#define COMMIT_SLAB_IMPL_H
+
+#include "git-compat-util.h"
+
+#define implement_static_commit_slab(slabname, elemtype) \
+	implement_commit_slab(slabname, elemtype, MAYBE_UNUSED static)
+
+#define implement_shared_commit_slab(slabname, elemtype) \
+	implement_commit_slab(slabname, elemtype, )
+
+#define implement_commit_slab(slabname, elemtype, scope)		\
+									\
+scope void init_ ##slabname## _with_stride(struct slabname *s,		\
+						   unsigned stride)	\
+{									\
+	unsigned int elem_size;						\
+	if (!stride)							\
+		stride = 1;						\
+	s->stride = stride;						\
+	elem_size = sizeof(elemtype) * stride;				\
+	s->slab_size = COMMIT_SLAB_SIZE / elem_size;			\
+	s->slab_count = 0;						\
+	s->slab = NULL;							\
+}									\
+									\
+scope void init_ ##slabname(struct slabname *s)				\
+{									\
+	init_ ##slabname## _with_stride(s, 1);				\
+}									\
+									\
+scope void clear_ ##slabname(struct slabname *s)			\
+{									\
+	unsigned int i;							\
+	for (i = 0; i < s->slab_count; i++)				\
+		free(s->slab[i]);					\
+	s->slab_count = 0;						\
+	FREE_AND_NULL(s->slab);						\
+}									\
+									\
+scope elemtype *slabname## _at_peek(struct slabname *s,			\
+						  const struct commit *c, \
+						  int add_if_missing)   \
+{									\
+	unsigned int nth_slab, nth_slot;				\
+									\
+	nth_slab = c->index / s->slab_size;				\
+	nth_slot = c->index % s->slab_size;				\
+									\
+	if (s->slab_count <= nth_slab) {				\
+		unsigned int i;						\
+		if (!add_if_missing)					\
+			return NULL;					\
+		REALLOC_ARRAY(s->slab, nth_slab + 1);			\
+		for (i = s->slab_count; i <= nth_slab; i++)		\
+			s->slab[i] = NULL;				\
+		s->slab_count = nth_slab + 1;				\
+	}								\
+	if (!s->slab[nth_slab]) {					\
+		if (!add_if_missing)					\
+			return NULL;					\
+		s->slab[nth_slab] = xcalloc(s->slab_size,		\
+					    sizeof(**s->slab) * s->stride);		\
+	}								\
+	return &s->slab[nth_slab][nth_slot * s->stride];		\
+}									\
+									\
+scope elemtype *slabname## _at(struct slabname *s,			\
+					     const struct commit *c)	\
+{									\
+	return slabname##_at_peek(s, c, 1);				\
+}									\
+									\
+scope elemtype *slabname## _peek(struct slabname *s,			\
+					     const struct commit *c)	\
+{									\
+	return slabname##_at_peek(s, c, 0);				\
+}									\
+									\
+struct slabname
+
+/*
+ * Note that this redundant forward declaration is required
+ * to allow a terminating semicolon, which makes instantiations look
+ * like function declarations.  I.e., the expansion of
+ *
+ *    implement_commit_slab(indegree, int, static);
+ *
+ * ends in 'struct indegree;'.  This would otherwise
+ * be a syntax error according (at least) to ISO C.  It's hard to
+ * catch because GCC silently parses it by default.
+ */
+
+#endif	/* COMMIT_SLAB_IMPL_H */
diff -pruN 1.2.1+git2.18.0-1/git/common-main.c 1.2.3+git2.25.1-1/git/common-main.c
--- 1.2.1+git2.18.0-1/git/common-main.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/common-main.c	2020-02-17 04:47:35.000000000 +0000
@@ -25,12 +25,17 @@ static void restore_sigpipe_to_default(v
 
 int main(int argc, const char **argv)
 {
+	int result;
+
+	trace2_initialize_clock();
+
 	/*
 	 * Always open file descriptors 0/1/2 to avoid clobbering files
 	 * in die().  It also avoids messing up when the pipes are dup'ed
 	 * onto stdin/stdout/stderr in the child processes we spawn.
 	 */
 	sanitize_stdfds();
+	restore_sigpipe_to_default();
 
 	git_resolve_executable_dir(argv[0]);
 
@@ -40,7 +45,13 @@ int main(int argc, const char **argv)
 
 	attr_start();
 
-	restore_sigpipe_to_default();
+	trace2_initialize();
+	trace2_cmd_start(argv);
+	trace2_collect_process_info(TRACE2_PROCESS_INFO_STARTUP);
+
+	result = cmd_main(argc, argv);
+
+	trace2_cmd_exit(result);
 
-	return cmd_main(argc, argv);
+	return result;
 }
diff -pruN 1.2.1+git2.18.0-1/git/compat/access.c 1.2.3+git2.25.1-1/git/compat/access.c
--- 1.2.1+git2.18.0-1/git/compat/access.c	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/compat/access.c	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,31 @@
+#define COMPAT_CODE_ACCESS
+#include "../git-compat-util.h"
+
+/* Do the same thing access(2) does, but use the effective uid,
+ * and don't make the mistake of telling root that any file is
+ * executable.  This version uses stat(2).
+ */
+int git_access(const char *path, int mode)
+{
+	struct stat st;
+
+	/* do not interfere a normal user */
+	if (geteuid())
+		return access(path, mode);
+
+	if (stat(path, &st) < 0)
+		return -1;
+
+	/* Root can read or write any file. */
+	if (!(mode & X_OK))
+		return 0;
+
+	/* Root can execute any file that has any one of the execute
+	 * bits set.
+	 */
+	if (st.st_mode & (S_IXUSR | S_IXGRP | S_IXOTH))
+		return 0;
+
+	errno = EACCES;
+	return -1;
+}
diff -pruN 1.2.1+git2.18.0-1/git/compat/bswap.h 1.2.3+git2.25.1-1/git/compat/bswap.h
--- 1.2.1+git2.18.0-1/git/compat/bswap.h	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/compat/bswap.h	2020-02-17 04:47:35.000000000 +0000
@@ -1,3 +1,6 @@
+#ifndef COMPAT_BSWAP_H
+#define COMPAT_BSWAP_H
+
 /*
  * Let's make sure we always have a sane definition for ntohl()/htonl().
  * Some libraries define those as a function call, just to perform byte
@@ -210,3 +213,5 @@ static inline void put_be64(void *ptr, u
 }
 
 #endif
+
+#endif /* COMPAT_BSWAP_H */
diff -pruN 1.2.1+git2.18.0-1/git/compat/cygwin.c 1.2.3+git2.25.1-1/git/compat/cygwin.c
--- 1.2.1+git2.18.0-1/git/compat/cygwin.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/compat/cygwin.c	1970-01-01 00:00:00.000000000 +0000
@@ -1,19 +0,0 @@
-#include "../git-compat-util.h"
-#include "../cache.h"
-
-int cygwin_offset_1st_component(const char *path)
-{
-	const char *pos = path;
-	/* unc paths */
-	if (is_dir_sep(pos[0]) && is_dir_sep(pos[1])) {
-		/* skip server name */
-		pos = strchr(pos + 2, '/');
-		if (!pos)
-			return 0; /* Error: malformed unc path */
-
-		do {
-			pos++;
-		} while (*pos && pos[0] != '/');
-	}
-	return pos + is_dir_sep(*pos) - path;
-}
diff -pruN 1.2.1+git2.18.0-1/git/compat/cygwin.h 1.2.3+git2.25.1-1/git/compat/cygwin.h
--- 1.2.1+git2.18.0-1/git/compat/cygwin.h	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/compat/cygwin.h	1970-01-01 00:00:00.000000000 +0000
@@ -1,2 +0,0 @@
-int cygwin_offset_1st_component(const char *path);
-#define offset_1st_component cygwin_offset_1st_component
diff -pruN 1.2.1+git2.18.0-1/git/compat/fileno.c 1.2.3+git2.25.1-1/git/compat/fileno.c
--- 1.2.1+git2.18.0-1/git/compat/fileno.c	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/compat/fileno.c	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,7 @@
+#define COMPAT_CODE_FILENO
+#include "../git-compat-util.h"
+
+int git_fileno(FILE *stream)
+{
+	return fileno(stream);
+}
diff -pruN 1.2.1+git2.18.0-1/git/compat/mingw.c 1.2.3+git2.25.1-1/git/compat/mingw.c
--- 1.2.1+git2.18.0-1/git/compat/mingw.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/compat/mingw.c	2020-02-17 04:47:35.000000000 +0000
@@ -5,6 +5,9 @@
 #include "../strbuf.h"
 #include "../run-command.h"
 #include "../cache.h"
+#include "win32/lazyload.h"
+#include "../config.h"
+#include "dir.h"
 
 #define HCAST(type, handle) ((type)(intptr_t)handle)
 
@@ -111,6 +114,7 @@ int err_win_to_posix(DWORD winerr)
 	case ERROR_SHARING_BUFFER_EXCEEDED: error = ENFILE; break;
 	case ERROR_SHARING_VIOLATION: error = EACCES; break;
 	case ERROR_STACK_OVERFLOW: error = ENOMEM; break;
+	case ERROR_SUCCESS: BUG("err_win_to_posix() called without an error!");
 	case ERROR_SWAPERROR: error = ENOENT; break;
 	case ERROR_TOO_MANY_MODULES: error = EMFILE; break;
 	case ERROR_TOO_MANY_OPEN_FILES: error = EMFILE; break;
@@ -202,6 +206,70 @@ static int ask_yes_no_if_possible(const
 	}
 }
 
+/* Windows only */
+enum hide_dotfiles_type {
+	HIDE_DOTFILES_FALSE = 0,
+	HIDE_DOTFILES_TRUE,
+	HIDE_DOTFILES_DOTGITONLY
+};
+
+static int core_restrict_inherited_handles = -1;
+static enum hide_dotfiles_type hide_dotfiles = HIDE_DOTFILES_DOTGITONLY;
+static char *unset_environment_variables;
+
+int mingw_core_config(const char *var, const char *value, void *cb)
+{
+	if (!strcmp(var, "core.hidedotfiles")) {
+		if (value && !strcasecmp(value, "dotgitonly"))
+			hide_dotfiles = HIDE_DOTFILES_DOTGITONLY;
+		else
+			hide_dotfiles = git_config_bool(var, value);
+		return 0;
+	}
+
+	if (!strcmp(var, "core.unsetenvvars")) {
+		free(unset_environment_variables);
+		unset_environment_variables = xstrdup(value);
+		return 0;
+	}
+
+	if (!strcmp(var, "core.restrictinheritedhandles")) {
+		if (value && !strcasecmp(value, "auto"))
+			core_restrict_inherited_handles = -1;
+		else
+			core_restrict_inherited_handles =
+				git_config_bool(var, value);
+		return 0;
+	}
+
+	return 0;
+}
+
+/* Normalizes NT paths as returned by some low-level APIs. */
+static wchar_t *normalize_ntpath(wchar_t *wbuf)
+{
+	int i;
+	/* fix absolute path prefixes */
+	if (wbuf[0] == '\\') {
+		/* strip NT namespace prefixes */
+		if (!wcsncmp(wbuf, L"\\??\\", 4) ||
+		    !wcsncmp(wbuf, L"\\\\?\\", 4))
+			wbuf += 4;
+		else if (!wcsnicmp(wbuf, L"\\DosDevices\\", 12))
+			wbuf += 12;
+		/* replace remaining '...UNC\' with '\\' */
+		if (!wcsnicmp(wbuf, L"UNC\\", 4)) {
+			wbuf += 2;
+			*wbuf = '\\';
+		}
+	}
+	/* convert backslashes to slashes */
+	for (i = 0; wbuf[i]; i++)
+		if (wbuf[i] == '\\')
+			wbuf[i] = '/';
+	return wbuf;
+}
+
 int mingw_unlink(const char *pathname)
 {
 	int ret, tries = 0;
@@ -294,7 +362,7 @@ static inline int needs_hiding(const cha
 		return 0;
 
 	/* We cannot use basename(), as it would remove trailing slashes */
-	mingw_skip_dos_drive_prefix((char **)&path);
+	win32_skip_dos_drive_prefix((char **)&path);
 	if (!*path)
 		return 0;
 
@@ -306,6 +374,8 @@ static inline int needs_hiding(const cha
 			/* ignore trailing slashes */
 			if (*path)
 				basename = path;
+			else
+				break;
 		}
 
 	if (hide_dotfiles == HIDE_DOTFILES_TRUE)
@@ -333,6 +403,12 @@ int mingw_mkdir(const char *path, int mo
 {
 	int ret;
 	wchar_t wpath[MAX_PATH];
+
+	if (!is_valid_win32_path(path, 0)) {
+		errno = EINVAL;
+		return -1;
+	}
+
 	if (xutftowcs_path(wpath, path) < 0)
 		return -1;
 	ret = _wmkdir(wpath);
@@ -341,23 +417,95 @@ int mingw_mkdir(const char *path, int mo
 	return ret;
 }
 
+/*
+ * Calling CreateFile() using FILE_APPEND_DATA and without FILE_WRITE_DATA
+ * is documented in [1] as opening a writable file handle in append mode.
+ * (It is believed that) this is atomic since it is maintained by the
+ * kernel unlike the O_APPEND flag which is racily maintained by the CRT.
+ *
+ * [1] https://docs.microsoft.com/en-us/windows/desktop/fileio/file-access-rights-constants
+ *
+ * This trick does not appear to work for named pipes.  Instead it creates
+ * a named pipe client handle that cannot be written to.  Callers should
+ * just use the regular _wopen() for them.  (And since client handle gets
+ * bound to a unique server handle, it isn't really an issue.)
+ */
+static int mingw_open_append(wchar_t const *wfilename, int oflags, ...)
+{
+	HANDLE handle;
+	int fd;
+	DWORD create = (oflags & O_CREAT) ? OPEN_ALWAYS : OPEN_EXISTING;
+
+	/* only these flags are supported */
+	if ((oflags & ~O_CREAT) != (O_WRONLY | O_APPEND))
+		return errno = ENOSYS, -1;
+
+	/*
+	 * FILE_SHARE_WRITE is required to permit child processes
+	 * to append to the file.
+	 */
+	handle = CreateFileW(wfilename, FILE_APPEND_DATA,
+			FILE_SHARE_WRITE | FILE_SHARE_READ,
+			NULL, create, FILE_ATTRIBUTE_NORMAL, NULL);
+	if (handle == INVALID_HANDLE_VALUE)
+		return errno = err_win_to_posix(GetLastError()), -1;
+
+	/*
+	 * No O_APPEND here, because the CRT uses it only to reset the
+	 * file pointer to EOF before each write(); but that is not
+	 * necessary (and may lead to races) for a file created with
+	 * FILE_APPEND_DATA.
+	 */
+	fd = _open_osfhandle((intptr_t)handle, O_BINARY);
+	if (fd < 0)
+		CloseHandle(handle);
+	return fd;
+}
+
+/*
+ * Does the pathname map to the local named pipe filesystem?
+ * That is, does it have a "//./pipe/" prefix?
+ */
+static int is_local_named_pipe_path(const char *filename)
+{
+	return (is_dir_sep(filename[0]) &&
+		is_dir_sep(filename[1]) &&
+		filename[2] == '.'  &&
+		is_dir_sep(filename[3]) &&
+		!strncasecmp(filename+4, "pipe", 4) &&
+		is_dir_sep(filename[8]) &&
+		filename[9]);
+}
+
 int mingw_open (const char *filename, int oflags, ...)
 {
+	typedef int (*open_fn_t)(wchar_t const *wfilename, int oflags, ...);
 	va_list args;
 	unsigned mode;
-	int fd;
+	int fd, create = (oflags & (O_CREAT | O_EXCL)) == (O_CREAT | O_EXCL);
 	wchar_t wfilename[MAX_PATH];
+	open_fn_t open_fn;
 
 	va_start(args, oflags);
 	mode = va_arg(args, int);
 	va_end(args);
 
-	if (filename && !strcmp(filename, "/dev/null"))
-		filename = "nul";
+	if (!is_valid_win32_path(filename, !create)) {
+		errno = create ? EINVAL : ENOENT;
+		return -1;
+	}
 
-	if (xutftowcs_path(wfilename, filename) < 0)
+	if ((oflags & O_APPEND) && !is_local_named_pipe_path(filename))
+		open_fn = mingw_open_append;
+	else
+		open_fn = _wopen;
+
+	if (filename && !strcmp(filename, "/dev/null"))
+		wcscpy(wfilename, L"nul");
+	else if (xutftowcs_path(wfilename, filename) < 0)
 		return -1;
-	fd = _wopen(wfilename, oflags, mode);
+
+	fd = open_fn(wfilename, oflags, mode);
 
 	if (fd < 0 && (oflags & O_ACCMODE) != O_RDONLY && errno == EACCES) {
 		DWORD attrs = GetFileAttributesW(wfilename);
@@ -375,7 +523,7 @@ int mingw_open (const char *filename, in
 		 * CREATE_ALWAYS flag of CreateFile()).
 		 */
 		if (fd < 0 && errno == EACCES)
-			fd = _wopen(wfilename, oflags & ~O_CREAT, mode);
+			fd = open_fn(wfilename, oflags & ~O_CREAT, mode);
 		if (fd >= 0 && set_hidden_flag(wfilename, 1))
 			warning("could not mark '%s' as hidden.", filename);
 	}
@@ -414,10 +562,17 @@ FILE *mingw_fopen (const char *filename,
 	FILE *file;
 	wchar_t wfilename[MAX_PATH], wotype[4];
 	if (filename && !strcmp(filename, "/dev/null"))
-		filename = "nul";
-	if (xutftowcs_path(wfilename, filename) < 0 ||
-		xutftowcs(wotype, otype, ARRAY_SIZE(wotype)) < 0)
+		wcscpy(wfilename, L"nul");
+	else if (!is_valid_win32_path(filename, 1)) {
+		int create = otype && strchr(otype, 'w');
+		errno = create ? EINVAL : ENOENT;
+		return NULL;
+	} else if (xutftowcs_path(wfilename, filename) < 0)
+		return NULL;
+
+	if (xutftowcs(wotype, otype, ARRAY_SIZE(wotype)) < 0)
 		return NULL;
+
 	if (hide && !access(filename, F_OK) && set_hidden_flag(wfilename, 0)) {
 		error("could not unhide %s", filename);
 		return NULL;
@@ -436,10 +591,17 @@ FILE *mingw_freopen (const char *filenam
 	FILE *file;
 	wchar_t wfilename[MAX_PATH], wotype[4];
 	if (filename && !strcmp(filename, "/dev/null"))
-		filename = "nul";
-	if (xutftowcs_path(wfilename, filename) < 0 ||
-		xutftowcs(wotype, otype, ARRAY_SIZE(wotype)) < 0)
+		wcscpy(wfilename, L"nul");
+	else if (!is_valid_win32_path(filename, 1)) {
+		int create = otype && strchr(otype, 'w');
+		errno = create ? EINVAL : ENOENT;
+		return NULL;
+	} else if (xutftowcs_path(wfilename, filename) < 0)
 		return NULL;
+
+	if (xutftowcs(wotype, otype, ARRAY_SIZE(wotype)) < 0)
+		return NULL;
+
 	if (hide && !access(filename, F_OK) && set_hidden_flag(wfilename, 0)) {
 		error("could not unhide %s", filename);
 		return NULL;
@@ -525,9 +687,11 @@ static inline long long filetime_to_hnse
 	return winTime - 116444736000000000LL;
 }
 
-static inline time_t filetime_to_time_t(const FILETIME *ft)
+static inline void filetime_to_timespec(const FILETIME *ft, struct timespec *ts)
 {
-	return (time_t)(filetime_to_hnsec(ft) / 10000000);
+	long long hnsec = filetime_to_hnsec(ft);
+	ts->tv_sec = (time_t)(hnsec / 10000000);
+	ts->tv_nsec = (hnsec % 10000000) * 100;
 }
 
 /**
@@ -586,9 +750,9 @@ static int do_lstat(int follow, const ch
 		buf->st_size = fdata.nFileSizeLow |
 			(((off_t)fdata.nFileSizeHigh)<<32);
 		buf->st_dev = buf->st_rdev = 0; /* not used by Git */
-		buf->st_atime = filetime_to_time_t(&(fdata.ftLastAccessTime));
-		buf->st_mtime = filetime_to_time_t(&(fdata.ftLastWriteTime));
-		buf->st_ctime = filetime_to_time_t(&(fdata.ftCreationTime));
+		filetime_to_timespec(&(fdata.ftLastAccessTime), &(buf->st_atim));
+		filetime_to_timespec(&(fdata.ftLastWriteTime), &(buf->st_mtim));
+		filetime_to_timespec(&(fdata.ftCreationTime), &(buf->st_ctim));
 		if (fdata.dwFileAttributes & FILE_ATTRIBUTE_REPARSE_POINT) {
 			WIN32_FIND_DATAW findbuf;
 			HANDLE handle = FindFirstFileW(wfilename, &findbuf);
@@ -669,6 +833,29 @@ static int do_stat_internal(int follow,
 	return do_lstat(follow, alt_name, buf);
 }
 
+static int get_file_info_by_handle(HANDLE hnd, struct stat *buf)
+{
+	BY_HANDLE_FILE_INFORMATION fdata;
+
+	if (!GetFileInformationByHandle(hnd, &fdata)) {
+		errno = err_win_to_posix(GetLastError());
+		return -1;
+	}
+
+	buf->st_ino = 0;
+	buf->st_gid = 0;
+	buf->st_uid = 0;
+	buf->st_nlink = 1;
+	buf->st_mode = file_attr_to_st_mode(fdata.dwFileAttributes);
+	buf->st_size = fdata.nFileSizeLow |
+		(((off_t)fdata.nFileSizeHigh)<<32);
+	buf->st_dev = buf->st_rdev = 0; /* not used by Git */
+	filetime_to_timespec(&(fdata.ftLastAccessTime), &(buf->st_atim));
+	filetime_to_timespec(&(fdata.ftLastWriteTime), &(buf->st_mtim));
+	filetime_to_timespec(&(fdata.ftCreationTime), &(buf->st_ctim));
+	return 0;
+}
+
 int mingw_lstat(const char *file_name, struct stat *buf)
 {
 	return do_stat_internal(0, file_name, buf);
@@ -681,32 +868,31 @@ int mingw_stat(const char *file_name, st
 int mingw_fstat(int fd, struct stat *buf)
 {
 	HANDLE fh = (HANDLE)_get_osfhandle(fd);
-	BY_HANDLE_FILE_INFORMATION fdata;
-
-	if (fh == INVALID_HANDLE_VALUE) {
-		errno = EBADF;
-		return -1;
-	}
-	/* direct non-file handles to MS's fstat() */
-	if (GetFileType(fh) != FILE_TYPE_DISK)
-		return _fstati64(fd, buf);
+	DWORD avail, type = GetFileType(fh) & ~FILE_TYPE_REMOTE;
 
-	if (GetFileInformationByHandle(fh, &fdata)) {
-		buf->st_ino = 0;
-		buf->st_gid = 0;
-		buf->st_uid = 0;
+	switch (type) {
+	case FILE_TYPE_DISK:
+		return get_file_info_by_handle(fh, buf);
+
+	case FILE_TYPE_CHAR:
+	case FILE_TYPE_PIPE:
+		/* initialize stat fields */
+		memset(buf, 0, sizeof(*buf));
 		buf->st_nlink = 1;
-		buf->st_mode = file_attr_to_st_mode(fdata.dwFileAttributes);
-		buf->st_size = fdata.nFileSizeLow |
-			(((off_t)fdata.nFileSizeHigh)<<32);
-		buf->st_dev = buf->st_rdev = 0; /* not used by Git */
-		buf->st_atime = filetime_to_time_t(&(fdata.ftLastAccessTime));
-		buf->st_mtime = filetime_to_time_t(&(fdata.ftLastWriteTime));
-		buf->st_ctime = filetime_to_time_t(&(fdata.ftCreationTime));
+
+		if (type == FILE_TYPE_CHAR) {
+			buf->st_mode = _S_IFCHR;
+		} else {
+			buf->st_mode = _S_IFIFO;
+			if (PeekNamedPipe(fh, NULL, 0, NULL, &avail, NULL))
+				buf->st_size = avail;
+		}
 		return 0;
+
+	default:
+		errno = EBADF;
+		return -1;
 	}
-	errno = EBADF;
-	return -1;
 }
 
 static inline void time_t_to_filetime(time_t t, FILETIME *ft)
@@ -836,22 +1022,43 @@ int pipe(int filedes[2])
 
 struct tm *gmtime_r(const time_t *timep, struct tm *result)
 {
-	/* gmtime() in MSVCRT.DLL is thread-safe, but not reentrant */
-	memcpy(result, gmtime(timep), sizeof(struct tm));
-	return result;
+	if (gmtime_s(result, timep) == 0)
+		return result;
+	return NULL;
 }
 
 struct tm *localtime_r(const time_t *timep, struct tm *result)
 {
-	/* localtime() in MSVCRT.DLL is thread-safe, but not reentrant */
-	memcpy(result, localtime(timep), sizeof(struct tm));
-	return result;
+	if (localtime_s(result, timep) == 0)
+		return result;
+	return NULL;
 }
 
 char *mingw_getcwd(char *pointer, int len)
 {
-	wchar_t wpointer[MAX_PATH];
-	if (!_wgetcwd(wpointer, ARRAY_SIZE(wpointer)))
+	wchar_t cwd[MAX_PATH], wpointer[MAX_PATH];
+	DWORD ret = GetCurrentDirectoryW(ARRAY_SIZE(cwd), cwd);
+
+	if (!ret || ret >= ARRAY_SIZE(cwd)) {
+		errno = ret ? ENAMETOOLONG : err_win_to_posix(GetLastError());
+		return NULL;
+	}
+	ret = GetLongPathNameW(cwd, wpointer, ARRAY_SIZE(wpointer));
+	if (!ret && GetLastError() == ERROR_ACCESS_DENIED) {
+		HANDLE hnd = CreateFileW(cwd, 0,
+			FILE_SHARE_READ | FILE_SHARE_WRITE | FILE_SHARE_DELETE, NULL,
+			OPEN_EXISTING, FILE_FLAG_BACKUP_SEMANTICS, NULL);
+		if (hnd == INVALID_HANDLE_VALUE)
+			return NULL;
+		ret = GetFinalPathNameByHandleW(hnd, wpointer, ARRAY_SIZE(wpointer), 0);
+		CloseHandle(hnd);
+		if (!ret || ret >= ARRAY_SIZE(wpointer))
+			return NULL;
+		if (xwcstoutf(pointer, normalize_ntpath(wpointer), len) < 0)
+			return NULL;
+		return pointer;
+	}
+	if (!ret || ret >= ARRAY_SIZE(wpointer))
 		return NULL;
 	if (xwcstoutf(pointer, wpointer, len) < 0)
 		return NULL;
@@ -860,10 +1067,10 @@ char *mingw_getcwd(char *pointer, int le
 }
 
 /*
- * See http://msdn2.microsoft.com/en-us/library/17w5ykft(vs.71).aspx
- * (Parsing C++ Command-Line Arguments)
+ * See "Parsing C++ Command-Line Arguments" at Microsoft's Docs:
+ * https://docs.microsoft.com/en-us/cpp/cpp/parsing-cpp-command-line-arguments
  */
-static const char *quote_arg(const char *arg)
+static const char *quote_arg_msvc(const char *arg)
 {
 	/* count chars to quote */
 	int len = 0, n = 0;
@@ -883,7 +1090,7 @@ static const char *quote_arg(const char
 				p++;
 				len++;
 			}
-			if (*p == '"')
+			if (*p == '"' || !*p)
 				n += count*2 + 1;
 			continue;
 		}
@@ -905,19 +1112,54 @@ static const char *quote_arg(const char
 				count++;
 				*d++ = *arg++;
 			}
-			if (*arg == '"') {
+			if (*arg == '"' || !*arg) {
 				while (count-- > 0)
 					*d++ = '\\';
+				/* don't escape the surrounding end quote */
+				if (!*arg)
+					break;
 				*d++ = '\\';
 			}
 		}
 		*d++ = *arg++;
 	}
 	*d++ = '"';
-	*d++ = 0;
+	*d++ = '\0';
 	return q;
 }
 
+#include "quote.h"
+
+static const char *quote_arg_msys2(const char *arg)
+{
+	struct strbuf buf = STRBUF_INIT;
+	const char *p2 = arg, *p;
+
+	for (p = arg; *p; p++) {
+		int ws = isspace(*p);
+		if (!ws && *p != '\\' && *p != '"' && *p != '{' && *p != '\'' &&
+		    *p != '?' && *p != '*' && *p != '~')
+			continue;
+		if (!buf.len)
+			strbuf_addch(&buf, '"');
+		if (p != p2)
+			strbuf_add(&buf, p2, p - p2);
+		if (*p == '\\' || *p == '"')
+			strbuf_addch(&buf, '\\');
+		p2 = p;
+	}
+
+	if (p == arg)
+		strbuf_addch(&buf, '"');
+	else if (!buf.len)
+		return arg;
+	else
+		strbuf_add(&buf, p2, p - p2);
+
+	strbuf_addch(&buf, '"');
+	return strbuf_detach(&buf, 0);
+}
+
 static const char *parse_interpreter(const char *cmd)
 {
 	static char buf[100];
@@ -961,14 +1203,21 @@ static char *lookup_prog(const char *dir
 			 int isexe, int exe_only)
 {
 	char path[MAX_PATH];
+	wchar_t wpath[MAX_PATH];
 	snprintf(path, sizeof(path), "%.*s\\%s.exe", dirlen, dir, cmd);
 
-	if (!isexe && access(path, F_OK) == 0)
+	if (xutftowcs_path(wpath, path) < 0)
+		return NULL;
+
+	if (!isexe && _waccess(wpath, F_OK) == 0)
 		return xstrdup(path);
-	path[strlen(path)-4] = '\0';
-	if ((!exe_only || isexe) && access(path, F_OK) == 0)
-		if (!(GetFileAttributes(path) & FILE_ATTRIBUTE_DIRECTORY))
+	wpath[wcslen(wpath)-4] = '\0';
+	if ((!exe_only || isexe) && _waccess(wpath, F_OK) == 0) {
+		if (!(GetFileAttributesW(wpath) & FILE_ATTRIBUTE_DIRECTORY)) {
+			path[strlen(path)-4] = '\0';
 			return xstrdup(path);
+		}
+	}
 	return NULL;
 }
 
@@ -1003,44 +1252,137 @@ static char *path_lookup(const char *cmd
 	return prog;
 }
 
-static int do_putenv(char **env, const char *name, int size, int free_old);
+static const wchar_t *wcschrnul(const wchar_t *s, wchar_t c)
+{
+	while (*s && *s != c)
+		s++;
+	return s;
+}
+
+/* Compare only keys */
+static int wenvcmp(const void *a, const void *b)
+{
+	wchar_t *p = *(wchar_t **)a, *q = *(wchar_t **)b;
+	size_t p_len, q_len;
+
+	/* Find the keys */
+	p_len = wcschrnul(p, L'=') - p;
+	q_len = wcschrnul(q, L'=') - q;
+
+	/* If the length differs, include the shorter key's NUL */
+	if (p_len < q_len)
+		p_len++;
+	else if (p_len > q_len)
+		p_len = q_len + 1;
 
-/* used number of elements of environ array, including terminating NULL */
-static int environ_size = 0;
-/* allocated size of environ array, in bytes */
-static int environ_alloc = 0;
+	return _wcsnicmp(p, q, p_len);
+}
 
 /*
- * Create environment block suitable for CreateProcess. Merges current
- * process environment and the supplied environment changes.
+ * Build an environment block combining the inherited environment
+ * merged with the given list of settings.
+ *
+ * Values of the form "KEY=VALUE" in deltaenv override inherited values.
+ * Values of the form "KEY" in deltaenv delete inherited values.
+ *
+ * Multiple entries in deltaenv for the same key are explicitly allowed.
+ *
+ * We return a contiguous block of UNICODE strings with a final trailing
+ * zero word.
  */
 static wchar_t *make_environment_block(char **deltaenv)
 {
-	wchar_t *wenvblk = NULL;
-	char **tmpenv;
-	int i = 0, size = environ_size, wenvsz = 0, wenvpos = 0;
+	wchar_t *wenv = GetEnvironmentStringsW(), *wdeltaenv, *result, *p;
+	size_t wlen, s, delta_size, size;
 
-	while (deltaenv && deltaenv[i])
-		i++;
+	wchar_t **array = NULL;
+	size_t alloc = 0, nr = 0, i;
+
+	size = 1; /* for extra NUL at the end */
+
+	/* If there is no deltaenv to apply, simply return a copy. */
+	if (!deltaenv || !*deltaenv) {
+		for (p = wenv; p && *p; ) {
+			size_t s = wcslen(p) + 1;
+			size += s;
+			p += s;
+		}
+
+		ALLOC_ARRAY(result, size);
+		COPY_ARRAY(result, wenv, size);
+		FreeEnvironmentStringsW(wenv);
+		return result;
+	}
 
-	/* copy the environment, leaving space for changes */
-	ALLOC_ARRAY(tmpenv, size + i);
-	memcpy(tmpenv, environ, size * sizeof(char*));
-
-	/* merge supplied environment changes into the temporary environment */
-	for (i = 0; deltaenv && deltaenv[i]; i++)
-		size = do_putenv(tmpenv, deltaenv[i], size, 0);
-
-	/* create environment block from temporary environment */
-	for (i = 0; tmpenv[i]; i++) {
-		size = 2 * strlen(tmpenv[i]) + 2; /* +2 for final \0 */
-		ALLOC_GROW(wenvblk, (wenvpos + size) * sizeof(wchar_t), wenvsz);
-		wenvpos += xutftowcs(&wenvblk[wenvpos], tmpenv[i], size) + 1;
-	}
-	/* add final \0 terminator */
-	wenvblk[wenvpos] = 0;
-	free(tmpenv);
-	return wenvblk;
+	/*
+	 * If there is a deltaenv, let's accumulate all keys into `array`,
+	 * sort them using the stable git_stable_qsort() and then copy,
+	 * skipping duplicate keys
+	 */
+	for (p = wenv; p && *p; ) {
+		ALLOC_GROW(array, nr + 1, alloc);
+		s = wcslen(p) + 1;
+		array[nr++] = p;
+		p += s;
+		size += s;
+	}
+
+	/* (over-)assess size needed for wchar version of deltaenv */
+	for (delta_size = 0, i = 0; deltaenv[i]; i++)
+		delta_size += strlen(deltaenv[i]) * 2 + 1;
+	ALLOC_ARRAY(wdeltaenv, delta_size);
+
+	/* convert the deltaenv, appending to array */
+	for (i = 0, p = wdeltaenv; deltaenv[i]; i++) {
+		ALLOC_GROW(array, nr + 1, alloc);
+		wlen = xutftowcs(p, deltaenv[i], wdeltaenv + delta_size - p);
+		array[nr++] = p;
+		p += wlen + 1;
+	}
+
+	git_stable_qsort(array, nr, sizeof(*array), wenvcmp);
+	ALLOC_ARRAY(result, size + delta_size);
+
+	for (p = result, i = 0; i < nr; i++) {
+		/* Skip any duplicate keys; last one wins */
+		while (i + 1 < nr && !wenvcmp(array + i, array + i + 1))
+		       i++;
+
+		/* Skip "to delete" entry */
+		if (!wcschr(array[i], L'='))
+			continue;
+
+		size = wcslen(array[i]) + 1;
+		COPY_ARRAY(p, array[i], size);
+		p += size;
+	}
+	*p = L'\0';
+
+	free(array);
+	free(wdeltaenv);
+	FreeEnvironmentStringsW(wenv);
+	return result;
+}
+
+static void do_unset_environment_variables(void)
+{
+	static int done;
+	char *p = unset_environment_variables;
+
+	if (done || !p)
+		return;
+	done = 1;
+
+	for (;;) {
+		char *comma = strchr(p, ',');
+
+		if (comma)
+			*comma = '\0';
+		unsetenv(p);
+		if (!comma)
+			break;
+		p = comma + 1;
+	}
 }
 
 struct pinfo_t {
@@ -1051,19 +1393,97 @@ struct pinfo_t {
 static struct pinfo_t *pinfo = NULL;
 CRITICAL_SECTION pinfo_cs;
 
+/* Used to match and chomp off path components */
+static inline int match_last_path_component(const char *path, size_t *len,
+					    const char *component)
+{
+	size_t component_len = strlen(component);
+	if (*len < component_len + 1 ||
+	    !is_dir_sep(path[*len - component_len - 1]) ||
+	    fspathncmp(path + *len - component_len, component, component_len))
+		return 0;
+	*len -= component_len + 1;
+	/* chomp off repeated dir separators */
+	while (*len > 0 && is_dir_sep(path[*len - 1]))
+		(*len)--;
+	return 1;
+}
+
+static int is_msys2_sh(const char *cmd)
+{
+	if (!cmd)
+		return 0;
+
+	if (!strcmp(cmd, "sh")) {
+		static int ret = -1;
+		char *p;
+
+		if (ret >= 0)
+			return ret;
+
+		p = path_lookup(cmd, 0);
+		if (!p)
+			ret = 0;
+		else {
+			size_t len = strlen(p);
+
+			ret = match_last_path_component(p, &len, "sh.exe") &&
+				match_last_path_component(p, &len, "bin") &&
+				match_last_path_component(p, &len, "usr");
+			free(p);
+		}
+		return ret;
+	}
+
+	if (ends_with(cmd, "\\sh.exe")) {
+		static char *sh;
+
+		if (!sh)
+			sh = path_lookup("sh", 0);
+
+		return !fspathcmp(cmd, sh);
+	}
+
+	return 0;
+}
+
 static pid_t mingw_spawnve_fd(const char *cmd, const char **argv, char **deltaenv,
 			      const char *dir,
 			      int prepend_cmd, int fhin, int fhout, int fherr)
 {
-	STARTUPINFOW si;
+	static int restrict_handle_inheritance = -1;
+	STARTUPINFOEXW si;
 	PROCESS_INFORMATION pi;
+	LPPROC_THREAD_ATTRIBUTE_LIST attr_list = NULL;
+	HANDLE stdhandles[3];
+	DWORD stdhandles_count = 0;
+	SIZE_T size;
 	struct strbuf args;
 	wchar_t wcmd[MAX_PATH], wdir[MAX_PATH], *wargs, *wenvblk = NULL;
 	unsigned flags = CREATE_UNICODE_ENVIRONMENT;
 	BOOL ret;
+	HANDLE cons;
+	const char *(*quote_arg)(const char *arg) =
+		is_msys2_sh(cmd ? cmd : *argv) ?
+		quote_arg_msys2 : quote_arg_msvc;
+
+	/* Make sure to override previous errors, if any */
+	errno = 0;
+
+	if (restrict_handle_inheritance < 0)
+		restrict_handle_inheritance = core_restrict_inherited_handles;
+	/*
+	 * The following code to restrict which handles are inherited seems
+	 * to work properly only on Windows 7 and later, so let's disable it
+	 * on Windows Vista and 2008.
+	 */
+	if (restrict_handle_inheritance < 0)
+		restrict_handle_inheritance = GetVersion() >> 16 >= 7601;
+
+	do_unset_environment_variables();
 
 	/* Determine whether or not we are associated to a console */
-	HANDLE cons = CreateFile("CONOUT$", GENERIC_WRITE,
+	cons = CreateFileW(L"CONOUT$", GENERIC_WRITE,
 			FILE_SHARE_WRITE, NULL, OPEN_EXISTING,
 			FILE_ATTRIBUTE_NORMAL, NULL);
 	if (cons == INVALID_HANDLE_VALUE) {
@@ -1087,13 +1507,27 @@ static pid_t mingw_spawnve_fd(const char
 		CloseHandle(cons);
 	}
 	memset(&si, 0, sizeof(si));
-	si.cb = sizeof(si);
-	si.dwFlags = STARTF_USESTDHANDLES;
-	si.hStdInput = winansi_get_osfhandle(fhin);
-	si.hStdOutput = winansi_get_osfhandle(fhout);
-	si.hStdError = winansi_get_osfhandle(fherr);
-
-	if (xutftowcs_path(wcmd, cmd) < 0)
+	si.StartupInfo.cb = sizeof(si);
+	si.StartupInfo.hStdInput = winansi_get_osfhandle(fhin);
+	si.StartupInfo.hStdOutput = winansi_get_osfhandle(fhout);
+	si.StartupInfo.hStdError = winansi_get_osfhandle(fherr);
+
+	/* The list of handles cannot contain duplicates */
+	if (si.StartupInfo.hStdInput != INVALID_HANDLE_VALUE)
+		stdhandles[stdhandles_count++] = si.StartupInfo.hStdInput;
+	if (si.StartupInfo.hStdOutput != INVALID_HANDLE_VALUE &&
+	    si.StartupInfo.hStdOutput != si.StartupInfo.hStdInput)
+		stdhandles[stdhandles_count++] = si.StartupInfo.hStdOutput;
+	if (si.StartupInfo.hStdError != INVALID_HANDLE_VALUE &&
+	    si.StartupInfo.hStdError != si.StartupInfo.hStdInput &&
+	    si.StartupInfo.hStdError != si.StartupInfo.hStdOutput)
+		stdhandles[stdhandles_count++] = si.StartupInfo.hStdError;
+	if (stdhandles_count)
+		si.StartupInfo.dwFlags |= STARTF_USESTDHANDLES;
+
+	if (*argv && !strcmp(cmd, *argv))
+		wcmd[0] = L'\0';
+	else if (xutftowcs_path(wcmd, cmd) < 0)
 		return -1;
 	if (dir && xutftowcs_path(wdir, dir) < 0)
 		return -1;
@@ -1122,16 +1556,98 @@ static pid_t mingw_spawnve_fd(const char
 	wenvblk = make_environment_block(deltaenv);
 
 	memset(&pi, 0, sizeof(pi));
-	ret = CreateProcessW(wcmd, wargs, NULL, NULL, TRUE, flags,
-		wenvblk, dir ? wdir : NULL, &si, &pi);
+	if (restrict_handle_inheritance && stdhandles_count &&
+	    (InitializeProcThreadAttributeList(NULL, 1, 0, &size) ||
+	     GetLastError() == ERROR_INSUFFICIENT_BUFFER) &&
+	    (attr_list = (LPPROC_THREAD_ATTRIBUTE_LIST)
+			(HeapAlloc(GetProcessHeap(), 0, size))) &&
+	    InitializeProcThreadAttributeList(attr_list, 1, 0, &size) &&
+	    UpdateProcThreadAttribute(attr_list, 0,
+				      PROC_THREAD_ATTRIBUTE_HANDLE_LIST,
+				      stdhandles,
+				      stdhandles_count * sizeof(HANDLE),
+				      NULL, NULL)) {
+		si.lpAttributeList = attr_list;
+		flags |= EXTENDED_STARTUPINFO_PRESENT;
+	}
+
+	ret = CreateProcessW(*wcmd ? wcmd : NULL, wargs, NULL, NULL,
+			     stdhandles_count ? TRUE : FALSE,
+			     flags, wenvblk, dir ? wdir : NULL,
+			     &si.StartupInfo, &pi);
+
+	/*
+	 * On Windows 2008 R2, it seems that specifying certain types of handles
+	 * (such as FILE_TYPE_CHAR or FILE_TYPE_PIPE) will always produce an
+	 * error. Rather than playing finicky and fragile games, let's just try
+	 * to detect this situation and simply try again without restricting any
+	 * handle inheritance. This is still better than failing to create
+	 * processes.
+	 */
+	if (!ret && restrict_handle_inheritance && stdhandles_count) {
+		DWORD err = GetLastError();
+		struct strbuf buf = STRBUF_INIT;
+
+		if (err != ERROR_NO_SYSTEM_RESOURCES &&
+		    /*
+		     * On Windows 7 and earlier, handles on pipes and character
+		     * devices are inherited automatically, and cannot be
+		     * specified in the thread handle list. Rather than trying
+		     * to catch each and every corner case (and running the
+		     * chance of *still* forgetting a few), let's just fall
+		     * back to creating the process without trying to limit the
+		     * handle inheritance.
+		     */
+		    !(err == ERROR_INVALID_PARAMETER &&
+		      GetVersion() >> 16 < 9200) &&
+		    !getenv("SUPPRESS_HANDLE_INHERITANCE_WARNING")) {
+			DWORD fl = 0;
+			int i;
+
+			setenv("SUPPRESS_HANDLE_INHERITANCE_WARNING", "1", 1);
+
+			for (i = 0; i < stdhandles_count; i++) {
+				HANDLE h = stdhandles[i];
+				strbuf_addf(&buf, "handle #%d: %p (type %lx, "
+					    "handle info (%d) %lx\n", i, h,
+					    GetFileType(h),
+					    GetHandleInformation(h, &fl),
+					    fl);
+			}
+			strbuf_addstr(&buf, "\nThis is a bug; please report it "
+				      "at\nhttps://github.com/git-for-windows/"
+				      "git/issues/new\n\n"
+				      "To suppress this warning, please set "
+				      "the environment variable\n\n"
+				      "\tSUPPRESS_HANDLE_INHERITANCE_WARNING=1"
+				      "\n");
+		}
+		restrict_handle_inheritance = 0;
+		flags &= ~EXTENDED_STARTUPINFO_PRESENT;
+		ret = CreateProcessW(*wcmd ? wcmd : NULL, wargs, NULL, NULL,
+				     TRUE, flags, wenvblk, dir ? wdir : NULL,
+				     &si.StartupInfo, &pi);
+		if (!ret)
+			errno = err_win_to_posix(GetLastError());
+		if (ret && buf.len) {
+			warning("failed to restrict file handles (%ld)\n\n%s",
+				err, buf.buf);
+		}
+		strbuf_release(&buf);
+	} else if (!ret)
+		errno = err_win_to_posix(GetLastError());
+
+	if (si.lpAttributeList)
+		DeleteProcThreadAttributeList(si.lpAttributeList);
+	if (attr_list)
+		HeapFree(GetProcessHeap(), 0, attr_list);
 
 	free(wenvblk);
 	free(wargs);
 
-	if (!ret) {
-		errno = ENOENT;
+	if (!ret)
 		return -1;
-	}
+
 	CloseHandle(pi.hThread);
 
 	/*
@@ -1207,19 +1723,26 @@ static int try_shell_exec(const char *cm
 		return 0;
 	prog = path_lookup(interpr, 1);
 	if (prog) {
+		int exec_id;
 		int argc = 0;
-		const char **argv2;
+#ifndef _MSC_VER
+		const
+#endif
+		char **argv2;
 		while (argv[argc]) argc++;
 		ALLOC_ARRAY(argv2, argc + 1);
 		argv2[0] = (char *)cmd;	/* full path to the script file */
-		memcpy(&argv2[1], &argv[1], sizeof(*argv) * argc);
+		COPY_ARRAY(&argv2[1], &argv[1], argc);
+		exec_id = trace2_exec(prog, argv2);
 		pid = mingw_spawnv(prog, argv2, 1);
 		if (pid >= 0) {
 			int status;
 			if (waitpid(pid, &status, 0) < 0)
 				status = 255;
+			trace2_exec_result(exec_id, status);
 			exit(status);
 		}
+		trace2_exec_result(exec_id, -1);
 		pid = 1;	/* indicate that we tried but failed */
 		free(prog);
 		free(argv2);
@@ -1232,12 +1755,17 @@ int mingw_execv(const char *cmd, char *c
 	/* check if git_command is a shell script */
 	if (!try_shell_exec(cmd, argv)) {
 		int pid, status;
+		int exec_id;
 
+		exec_id = trace2_exec(cmd, (const char **)argv);
 		pid = mingw_spawnv(cmd, (const char **)argv, 0);
-		if (pid < 0)
+		if (pid < 0) {
+			trace2_exec_result(exec_id, -1);
 			return -1;
+		}
 		if (waitpid(pid, &status, 0) < 0)
 			status = 255;
+		trace2_exec_result(exec_id, status);
 		exit(status);
 	}
 	return -1;
@@ -1282,225 +1810,91 @@ int mingw_kill(pid_t pid, int sig)
 }
 
 /*
- * Compare environment entries by key (i.e. stopping at '=' or '\0').
+ * UTF-8 versions of getenv(), putenv() and unsetenv().
+ * Internally, they use the CRT's stock UNICODE routines
+ * to avoid data loss.
  */
-static int compareenv(const void *v1, const void *v2)
+char *mingw_getenv(const char *name)
 {
-	const char *e1 = *(const char**)v1;
-	const char *e2 = *(const char**)v2;
+#define GETENV_MAX_RETAIN 64
+	static char *values[GETENV_MAX_RETAIN];
+	static int value_counter;
+	int len_key, len_value;
+	wchar_t *w_key;
+	char *value;
+	wchar_t w_value[32768];
 
-	for (;;) {
-		int c1 = *e1++;
-		int c2 = *e2++;
-		c1 = (c1 == '=') ? 0 : tolower(c1);
-		c2 = (c2 == '=') ? 0 : tolower(c2);
-		if (c1 > c2)
-			return 1;
-		if (c1 < c2)
-			return -1;
-		if (c1 == 0)
-			return 0;
-	}
-}
+	if (!name || !*name)
+		return NULL;
 
-static int bsearchenv(char **env, const char *name, size_t size)
-{
-	unsigned low = 0, high = size;
-	while (low < high) {
-		unsigned mid = low + ((high - low) >> 1);
-		int cmp = compareenv(&env[mid], &name);
-		if (cmp < 0)
-			low = mid + 1;
-		else if (cmp > 0)
-			high = mid;
-		else
-			return mid;
+	len_key = strlen(name) + 1;
+	/* We cannot use xcalloc() here because that uses getenv() itself */
+	w_key = calloc(len_key, sizeof(wchar_t));
+	if (!w_key)
+		die("Out of memory, (tried to allocate %u wchar_t's)", len_key);
+	xutftowcs(w_key, name, len_key);
+	/* GetEnvironmentVariableW() only sets the last error upon failure */
+	SetLastError(ERROR_SUCCESS);
+	len_value = GetEnvironmentVariableW(w_key, w_value, ARRAY_SIZE(w_value));
+	if (!len_value && GetLastError() == ERROR_ENVVAR_NOT_FOUND) {
+		free(w_key);
+		return NULL;
 	}
-	return ~low; /* not found, return 1's complement of insert position */
-}
+	free(w_key);
 
-/*
- * If name contains '=', then sets the variable, otherwise it unsets it
- * Size includes the terminating NULL. Env must have room for size + 1 entries
- * (in case of insert). Returns the new size. Optionally frees removed entries.
- */
-static int do_putenv(char **env, const char *name, int size, int free_old)
-{
-	int i = bsearchenv(env, name, size - 1);
+	len_value = len_value * 3 + 1;
+	/* We cannot use xcalloc() here because that uses getenv() itself */
+	value = calloc(len_value, sizeof(char));
+	if (!value)
+		die("Out of memory, (tried to allocate %u bytes)", len_value);
+	xwcstoutf(value, w_value, len_value);
 
-	/* optionally free removed / replaced entry */
-	if (i >= 0 && free_old)
-		free(env[i]);
-
-	if (strchr(name, '=')) {
-		/* if new value ('key=value') is specified, insert or replace entry */
-		if (i < 0) {
-			i = ~i;
-			memmove(&env[i + 1], &env[i], (size - i) * sizeof(char*));
-			size++;
-		}
-		env[i] = (char*) name;
-	} else if (i >= 0) {
-		/* otherwise ('key') remove existing entry */
-		size--;
-		memmove(&env[i], &env[i + 1], (size - i) * sizeof(char*));
-	}
-	return size;
-}
+	/*
+	 * We return `value` which is an allocated value and the caller is NOT
+	 * expecting to have to free it, so we keep a round-robin array,
+	 * invalidating the buffer after GETENV_MAX_RETAIN getenv() calls.
+	 */
+	free(values[value_counter]);
+	values[value_counter++] = value;
+	if (value_counter >= ARRAY_SIZE(values))
+		value_counter = 0;
 
-char *mingw_getenv(const char *name)
-{
-	char *value;
-	int pos = bsearchenv(environ, name, environ_size - 1);
-	if (pos < 0)
-		return NULL;
-	value = strchr(environ[pos], '=');
-	return value ? &value[1] : NULL;
+	return value;
 }
 
 int mingw_putenv(const char *namevalue)
 {
-	ALLOC_GROW(environ, (environ_size + 1) * sizeof(char*), environ_alloc);
-	environ_size = do_putenv(environ, namevalue, environ_size, 1);
-	return 0;
-}
-
-/*
- * Note, this isn't a complete replacement for getaddrinfo. It assumes
- * that service contains a numerical port, or that it is null. It
- * does a simple search using gethostbyname, and returns one IPv4 host
- * if one was found.
- */
-static int WSAAPI getaddrinfo_stub(const char *node, const char *service,
-				   const struct addrinfo *hints,
-				   struct addrinfo **res)
-{
-	struct hostent *h = NULL;
-	struct addrinfo *ai;
-	struct sockaddr_in *sin;
-
-	if (node) {
-		h = gethostbyname(node);
-		if (!h)
-			return WSAGetLastError();
-	}
-
-	ai = xmalloc(sizeof(struct addrinfo));
-	*res = ai;
-	ai->ai_flags = 0;
-	ai->ai_family = AF_INET;
-	ai->ai_socktype = hints ? hints->ai_socktype : 0;
-	switch (ai->ai_socktype) {
-	case SOCK_STREAM:
-		ai->ai_protocol = IPPROTO_TCP;
-		break;
-	case SOCK_DGRAM:
-		ai->ai_protocol = IPPROTO_UDP;
-		break;
-	default:
-		ai->ai_protocol = 0;
-		break;
-	}
-	ai->ai_addrlen = sizeof(struct sockaddr_in);
-	if (hints && (hints->ai_flags & AI_CANONNAME))
-		ai->ai_canonname = h ? xstrdup(h->h_name) : NULL;
-	else
-		ai->ai_canonname = NULL;
-
-	sin = xcalloc(1, ai->ai_addrlen);
-	sin->sin_family = AF_INET;
-	/* Note: getaddrinfo is supposed to allow service to be a string,
-	 * which should be looked up using getservbyname. This is
-	 * currently not implemented */
-	if (service)
-		sin->sin_port = htons(atoi(service));
-	if (h)
-		sin->sin_addr = *(struct in_addr *)h->h_addr;
-	else if (hints && (hints->ai_flags & AI_PASSIVE))
-		sin->sin_addr.s_addr = INADDR_ANY;
-	else
-		sin->sin_addr.s_addr = INADDR_LOOPBACK;
-	ai->ai_addr = (struct sockaddr *)sin;
-	ai->ai_next = NULL;
-	return 0;
-}
-
-static void WSAAPI freeaddrinfo_stub(struct addrinfo *res)
-{
-	free(res->ai_canonname);
-	free(res->ai_addr);
-	free(res);
-}
-
-static int WSAAPI getnameinfo_stub(const struct sockaddr *sa, socklen_t salen,
-				   char *host, DWORD hostlen,
-				   char *serv, DWORD servlen, int flags)
-{
-	const struct sockaddr_in *sin = (const struct sockaddr_in *)sa;
-	if (sa->sa_family != AF_INET)
-		return EAI_FAMILY;
-	if (!host && !serv)
-		return EAI_NONAME;
-
-	if (host && hostlen > 0) {
-		struct hostent *ent = NULL;
-		if (!(flags & NI_NUMERICHOST))
-			ent = gethostbyaddr((const char *)&sin->sin_addr,
-					    sizeof(sin->sin_addr), AF_INET);
-
-		if (ent)
-			snprintf(host, hostlen, "%s", ent->h_name);
-		else if (flags & NI_NAMEREQD)
-			return EAI_NONAME;
-		else
-			snprintf(host, hostlen, "%s", inet_ntoa(sin->sin_addr));
-	}
+	int size;
+	wchar_t *wide, *equal;
+	BOOL result;
 
-	if (serv && servlen > 0) {
-		struct servent *ent = NULL;
-		if (!(flags & NI_NUMERICSERV))
-			ent = getservbyport(sin->sin_port,
-					    flags & NI_DGRAM ? "udp" : "tcp");
+	if (!namevalue || !*namevalue)
+		return 0;
 
-		if (ent)
-			snprintf(serv, servlen, "%s", ent->s_name);
-		else
-			snprintf(serv, servlen, "%d", ntohs(sin->sin_port));
+	size = strlen(namevalue) * 2 + 1;
+	wide = calloc(size, sizeof(wchar_t));
+	if (!wide)
+		die("Out of memory, (tried to allocate %u wchar_t's)", size);
+	xutftowcs(wide, namevalue, size);
+	equal = wcschr(wide, L'=');
+	if (!equal)
+		result = SetEnvironmentVariableW(wide, NULL);
+	else {
+		*equal = L'\0';
+		result = SetEnvironmentVariableW(wide, equal + 1);
 	}
+	free(wide);
 
-	return 0;
-}
-
-static HMODULE ipv6_dll = NULL;
-static void (WSAAPI *ipv6_freeaddrinfo)(struct addrinfo *res);
-static int (WSAAPI *ipv6_getaddrinfo)(const char *node, const char *service,
-				      const struct addrinfo *hints,
-				      struct addrinfo **res);
-static int (WSAAPI *ipv6_getnameinfo)(const struct sockaddr *sa, socklen_t salen,
-				      char *host, DWORD hostlen,
-				      char *serv, DWORD servlen, int flags);
-/*
- * gai_strerror is an inline function in the ws2tcpip.h header, so we
- * don't need to try to load that one dynamically.
- */
+	if (!result)
+		errno = err_win_to_posix(GetLastError());
 
-static void socket_cleanup(void)
-{
-	WSACleanup();
-	if (ipv6_dll)
-		FreeLibrary(ipv6_dll);
-	ipv6_dll = NULL;
-	ipv6_freeaddrinfo = freeaddrinfo_stub;
-	ipv6_getaddrinfo = getaddrinfo_stub;
-	ipv6_getnameinfo = getnameinfo_stub;
+	return result ? 0 : -1;
 }
 
 static void ensure_socket_initialization(void)
 {
 	WSADATA wsa;
 	static int initialized = 0;
-	const char *libraries[] = { "ws2_32.dll", "wship6.dll", NULL };
-	const char **name;
 
 	if (initialized)
 		return;
@@ -1509,34 +1903,7 @@ static void ensure_socket_initialization
 		die("unable to initialize winsock subsystem, error %d",
 			WSAGetLastError());
 
-	for (name = libraries; *name; name++) {
-		ipv6_dll = LoadLibrary(*name);
-		if (!ipv6_dll)
-			continue;
-
-		ipv6_freeaddrinfo = (void (WSAAPI *)(struct addrinfo *))
-			GetProcAddress(ipv6_dll, "freeaddrinfo");
-		ipv6_getaddrinfo = (int (WSAAPI *)(const char *, const char *,
-						   const struct addrinfo *,
-						   struct addrinfo **))
-			GetProcAddress(ipv6_dll, "getaddrinfo");
-		ipv6_getnameinfo = (int (WSAAPI *)(const struct sockaddr *,
-						   socklen_t, char *, DWORD,
-						   char *, DWORD, int))
-			GetProcAddress(ipv6_dll, "getnameinfo");
-		if (!ipv6_freeaddrinfo || !ipv6_getaddrinfo || !ipv6_getnameinfo) {
-			FreeLibrary(ipv6_dll);
-			ipv6_dll = NULL;
-		} else
-			break;
-	}
-	if (!ipv6_freeaddrinfo || !ipv6_getaddrinfo || !ipv6_getnameinfo) {
-		ipv6_freeaddrinfo = freeaddrinfo_stub;
-		ipv6_getaddrinfo = getaddrinfo_stub;
-		ipv6_getnameinfo = getnameinfo_stub;
-	}
-
-	atexit(socket_cleanup);
+	atexit((void(*)(void)) WSACleanup);
 	initialized = 1;
 }
 
@@ -1554,24 +1921,12 @@ struct hostent *mingw_gethostbyname(cons
 	return gethostbyname(host);
 }
 
-void mingw_freeaddrinfo(struct addrinfo *res)
-{
-	ipv6_freeaddrinfo(res);
-}
-
+#undef getaddrinfo
 int mingw_getaddrinfo(const char *node, const char *service,
 		      const struct addrinfo *hints, struct addrinfo **res)
 {
 	ensure_socket_initialization();
-	return ipv6_getaddrinfo(node, service, hints, res);
-}
-
-int mingw_getnameinfo(const struct sockaddr *sa, socklen_t salen,
-		      char *host, DWORD hostlen, char *serv, DWORD servlen,
-		      int flags)
-{
-	ensure_socket_initialization();
-	return ipv6_getnameinfo(sa, salen, host, hostlen, serv, servlen, flags);
+	return getaddrinfo(node, service, hints, res);
 }
 
 int mingw_socket(int domain, int type, int protocol)
@@ -1731,18 +2086,69 @@ int mingw_getpagesize(void)
 	return si.dwAllocationGranularity;
 }
 
+/* See https://msdn.microsoft.com/en-us/library/windows/desktop/ms724435.aspx */
+enum EXTENDED_NAME_FORMAT {
+	NameDisplay = 3,
+	NameUserPrincipal = 8
+};
+
+static char *get_extended_user_info(enum EXTENDED_NAME_FORMAT type)
+{
+	DECLARE_PROC_ADDR(secur32.dll, BOOL, GetUserNameExW,
+		enum EXTENDED_NAME_FORMAT, LPCWSTR, PULONG);
+	static wchar_t wbuffer[1024];
+	DWORD len;
+
+	if (!INIT_PROC_ADDR(GetUserNameExW))
+		return NULL;
+
+	len = ARRAY_SIZE(wbuffer);
+	if (GetUserNameExW(type, wbuffer, &len)) {
+		char *converted = xmalloc((len *= 3));
+		if (xwcstoutf(converted, wbuffer, len) >= 0)
+			return converted;
+		free(converted);
+	}
+
+	return NULL;
+}
+
+char *mingw_query_user_email(void)
+{
+	return get_extended_user_info(NameUserPrincipal);
+}
+
 struct passwd *getpwuid(int uid)
 {
+	static unsigned initialized;
 	static char user_name[100];
-	static struct passwd p;
+	static struct passwd *p;
+	wchar_t buf[100];
+	DWORD len;
 
-	DWORD len = sizeof(user_name);
-	if (!GetUserName(user_name, &len))
+	if (initialized)
+		return p;
+
+	len = ARRAY_SIZE(buf);
+	if (!GetUserNameW(buf, &len)) {
+		initialized = 1;
+		return NULL;
+	}
+
+	if (xwcstoutf(user_name, buf, sizeof(user_name)) < 0) {
+		initialized = 1;
 		return NULL;
-	p.pw_name = user_name;
-	p.pw_gecos = "unknown";
-	p.pw_dir = NULL;
-	return &p;
+	}
+
+	p = xmalloc(sizeof(*p));
+	p->pw_name = user_name;
+	p->pw_gecos = get_extended_user_info(NameDisplay);
+	if (!p->pw_gecos)
+		p->pw_gecos = "unknown";
+	p->pw_dir = NULL;
+
+	initialized = 1;
+	return p;
 }
 
 static HANDLE timer_event;
@@ -1789,7 +2195,7 @@ static void stop_timer_thread(void)
 	if (timer_event)
 		SetEvent(timer_event);	/* tell thread to terminate */
 	if (timer_thread) {
-		int rc = WaitForSingleObject(timer_thread, 1000);
+		int rc = WaitForSingleObject(timer_thread, 10000);
 		if (rc == WAIT_TIMEOUT)
 			error("timer thread did not terminate timely");
 		else if (rc != WAIT_OBJECT_0)
@@ -1893,31 +2299,44 @@ int mingw_raise(int sig)
 			sigint_fn(SIGINT);
 		return 0;
 
+#if defined(_MSC_VER)
+	case SIGILL:
+	case SIGFPE:
+	case SIGSEGV:
+	case SIGTERM:
+	case SIGBREAK:
+	case SIGABRT:
+	case SIGABRT_COMPAT:
+		/*
+		 * The <signal.h> header in the MS C Runtime defines 8 signals
+		 * as being supported on the platform. Anything else causes an
+		 * "Invalid signal or error" (which in DEBUG builds causes the
+		 * Abort/Retry/Ignore dialog). We by-pass the CRT for things we
+		 * already know will fail.
+		 */
+		return raise(sig);
+	default:
+		errno = EINVAL;
+		return -1;
+
+#else
+
 	default:
 		return raise(sig);
+
+#endif
+
 	}
 }
 
 int link(const char *oldpath, const char *newpath)
 {
-	typedef BOOL (WINAPI *T)(LPCWSTR, LPCWSTR, LPSECURITY_ATTRIBUTES);
-	static T create_hard_link = NULL;
 	wchar_t woldpath[MAX_PATH], wnewpath[MAX_PATH];
 	if (xutftowcs_path(woldpath, oldpath) < 0 ||
 		xutftowcs_path(wnewpath, newpath) < 0)
 		return -1;
 
-	if (!create_hard_link) {
-		create_hard_link = (T) GetProcAddress(
-			GetModuleHandle("kernel32.dll"), "CreateHardLinkW");
-		if (!create_hard_link)
-			create_hard_link = (T)-1;
-	}
-	if (create_hard_link == (T)-1) {
-		errno = ENOSYS;
-		return -1;
-	}
-	if (!create_hard_link(wnewpath, woldpath, NULL)) {
+	if (!CreateHardLinkW(wnewpath, woldpath, NULL)) {
 		errno = err_win_to_posix(GetLastError());
 		return -1;
 	}
@@ -1976,33 +2395,6 @@ pid_t waitpid(pid_t pid, int *status, in
 	return -1;
 }
 
-int mingw_skip_dos_drive_prefix(char **path)
-{
-	int ret = has_dos_drive_prefix(*path);
-	*path += ret;
-	return ret;
-}
-
-int mingw_offset_1st_component(const char *path)
-{
-	char *pos = (char *)path;
-
-	/* unc paths */
-	if (!skip_dos_drive_prefix(&pos) &&
-			is_dir_sep(pos[0]) && is_dir_sep(pos[1])) {
-		/* skip server name */
-		pos = strpbrk(pos + 2, "\\/");
-		if (!pos)
-			return 0; /* Error: malformed unc path */
-
-		do {
-			pos++;
-		} while (*pos && !is_dir_sep(*pos));
-	}
-
-	return pos + is_dir_sep(*pos) - path;
-}
-
 int xutftowcsn(wchar_t *wcs, const char *utfs, size_t wcslen, int utflen)
 {
 	int upos = 0, wpos = 0;
@@ -2115,20 +2507,161 @@ static void setup_windows_environment(vo
 	/* simulate TERM to enable auto-color (see color.c) */
 	if (!getenv("TERM"))
 		setenv("TERM", "cygwin", 1);
+
+	/* calculate HOME if not set */
+	if (!getenv("HOME")) {
+		/*
+		 * try $HOMEDRIVE$HOMEPATH - the home share may be a network
+		 * location, thus also check if the path exists (i.e. is not
+		 * disconnected)
+		 */
+		if ((tmp = getenv("HOMEDRIVE"))) {
+			struct strbuf buf = STRBUF_INIT;
+			strbuf_addstr(&buf, tmp);
+			if ((tmp = getenv("HOMEPATH"))) {
+				strbuf_addstr(&buf, tmp);
+				if (is_directory(buf.buf))
+					setenv("HOME", buf.buf, 1);
+				else
+					tmp = NULL; /* use $USERPROFILE */
+			}
+			strbuf_release(&buf);
+		}
+		/* use $USERPROFILE if the home share is not available */
+		if (!tmp && (tmp = getenv("USERPROFILE")))
+			setenv("HOME", tmp, 1);
+	}
 }
 
+int is_valid_win32_path(const char *path, int allow_literal_nul)
+{
+	const char *p = path;
+	int preceding_space_or_period = 0, i = 0, periods = 0;
+
+	if (!protect_ntfs)
+		return 1;
+
+	skip_dos_drive_prefix((char **)&path);
+	goto segment_start;
+
+	for (;;) {
+		char c = *(path++);
+		switch (c) {
+		case '\0':
+		case '/': case '\\':
+			/* cannot end in ` ` or `.`, except for `.` and `..` */
+			if (preceding_space_or_period &&
+			    (i != periods || periods > 2))
+				return 0;
+			if (!c)
+				return 1;
+
+			i = periods = preceding_space_or_period = 0;
+
+segment_start:
+			switch (*path) {
+			case 'a': case 'A': /* AUX */
+				if (((c = path[++i]) != 'u' && c != 'U') ||
+				    ((c = path[++i]) != 'x' && c != 'X')) {
+not_a_reserved_name:
+					path += i;
+					continue;
+				}
+				break;
+			case 'c': case 'C': /* COM<N>, CON, CONIN$, CONOUT$ */
+				if ((c = path[++i]) != 'o' && c != 'O')
+					goto not_a_reserved_name;
+				c = path[++i];
+				if (c == 'm' || c == 'M') { /* COM<N> */
+					if (!isdigit(path[++i]))
+						goto not_a_reserved_name;
+				} else if (c == 'n' || c == 'N') { /* CON */
+					c = path[i + 1];
+					if ((c == 'i' || c == 'I') &&
+					    ((c = path[i + 2]) == 'n' ||
+					     c == 'N') &&
+					    path[i + 3] == '$')
+						i += 3; /* CONIN$ */
+					else if ((c == 'o' || c == 'O') &&
+						 ((c = path[i + 2]) == 'u' ||
+						  c == 'U') &&
+						 ((c = path[i + 3]) == 't' ||
+						  c == 'T') &&
+						 path[i + 4] == '$')
+						i += 4; /* CONOUT$ */
+				} else
+					goto not_a_reserved_name;
+				break;
+			case 'l': case 'L': /* LPT<N> */
+				if (((c = path[++i]) != 'p' && c != 'P') ||
+				    ((c = path[++i]) != 't' && c != 'T') ||
+				    !isdigit(path[++i]))
+					goto not_a_reserved_name;
+				break;
+			case 'n': case 'N': /* NUL */
+				if (((c = path[++i]) != 'u' && c != 'U') ||
+				    ((c = path[++i]) != 'l' && c != 'L') ||
+				    (allow_literal_nul &&
+				     !path[i + 1] && p == path))
+					goto not_a_reserved_name;
+				break;
+			case 'p': case 'P': /* PRN */
+				if (((c = path[++i]) != 'r' && c != 'R') ||
+				    ((c = path[++i]) != 'n' && c != 'N'))
+					goto not_a_reserved_name;
+				break;
+			default:
+				continue;
+			}
+
+			/*
+			 * So far, this looks like a reserved name. Let's see
+			 * whether it actually is one: trailing spaces, a file
+			 * extension, or an NTFS Alternate Data Stream do not
+			 * matter, the name is still reserved if any of those
+			 * follow immediately after the actual name.
+			 */
+			i++;
+			if (path[i] == ' ') {
+				preceding_space_or_period = 1;
+				while (path[++i] == ' ')
+					; /* skip all spaces */
+			}
+
+			c = path[i];
+			if (c && c != '.' && c != ':' && c != '/' && c != '\\')
+				goto not_a_reserved_name;
+
+			/* contains reserved name */
+			return 0;
+		case '.':
+			periods++;
+			/* fallthru */
+		case ' ':
+			preceding_space_or_period = 1;
+			i++;
+			continue;
+		case ':': /* DOS drive prefix was already skipped */
+		case '<': case '>': case '"': case '|': case '?': case '*':
+			/* illegal character */
+			return 0;
+		default:
+			if (c > '\0' && c < '\x20')
+				/* illegal character */
+				return 0;
+		}
+		preceding_space_or_period = 0;
+		i++;
+	}
+}
+
+#if !defined(_MSC_VER)
 /*
  * Disable MSVCRT command line wildcard expansion (__getmainargs called from
  * mingw startup code, see init.c in mingw runtime).
  */
 int _CRT_glob = 0;
-
-typedef struct {
-	int newmode;
-} _startupinfo;
-
-extern int __wgetmainargs(int *argc, wchar_t ***argv, wchar_t ***env, int glob,
-		_startupinfo *si);
+#endif
 
 static NORETURN void die_startup(void)
 {
@@ -2206,54 +2739,67 @@ static void maybe_redirect_std_handles(v
 				  GENERIC_WRITE, FILE_FLAG_NO_BUFFERING);
 }
 
-void mingw_startup(void)
+#ifdef _MSC_VER
+#ifdef _DEBUG
+#include <crtdbg.h>
+#endif
+#endif
+
+/*
+ * We implement wmain() and compile with -municode, which would
+ * normally ignore main(), but we call the latter from the former
+ * so that we can handle non-ASCII command-line parameters
+ * appropriately.
+ *
+ * To be more compatible with the core git code, we convert
+ * argv into UTF8 and pass them directly to main().
+ */
+int wmain(int argc, const wchar_t **wargv)
 {
-	int i, maxlen, argc;
-	char *buffer;
-	wchar_t **wenv, **wargv;
-	_startupinfo si;
+	int i, maxlen, exit_status;
+	char *buffer, **save;
+	const char **argv;
+
+	trace2_initialize_clock();
+
+#ifdef _MSC_VER
+#ifdef _DEBUG
+	_CrtSetReportMode(_CRT_ASSERT, _CRTDBG_MODE_DEBUG);
+#endif
+
+#ifdef USE_MSVC_CRTDBG
+	_CrtSetDbgFlag(_CRTDBG_ALLOC_MEM_DF | _CRTDBG_LEAK_CHECK_DF);
+#endif
+#endif
 
 	maybe_redirect_std_handles();
 
-	/* get wide char arguments and environment */
-	si.newmode = 0;
-	if (__wgetmainargs(&argc, &wargv, &wenv, _CRT_glob, &si) < 0)
-		die_startup();
-
 	/* determine size of argv and environ conversion buffer */
 	maxlen = wcslen(wargv[0]);
 	for (i = 1; i < argc; i++)
 		maxlen = max(maxlen, wcslen(wargv[i]));
-	for (i = 0; wenv[i]; i++)
-		maxlen = max(maxlen, wcslen(wenv[i]));
-
-	/*
-	 * nedmalloc can't free CRT memory, allocate resizable environment
-	 * list. Note that xmalloc / xmemdupz etc. call getenv, so we cannot
-	 * use it while initializing the environment itself.
-	 */
-	environ_size = i + 1;
-	environ_alloc = alloc_nr(environ_size * sizeof(char*));
-	environ = malloc_startup(environ_alloc);
 
 	/* allocate buffer (wchar_t encodes to max 3 UTF-8 bytes) */
 	maxlen = 3 * maxlen + 1;
 	buffer = malloc_startup(maxlen);
 
-	/* convert command line arguments and environment to UTF-8 */
+	/*
+	 * Create a UTF-8 version of w_argv. Also create a "save" copy
+	 * to remember all the string pointers because parse_options()
+	 * will remove claimed items from the argv that we pass down.
+	 */
+	ALLOC_ARRAY(argv, argc + 1);
+	ALLOC_ARRAY(save, argc + 1);
 	for (i = 0; i < argc; i++)
-		__argv[i] = wcstoutfdup_startup(buffer, wargv[i], maxlen);
-	for (i = 0; wenv[i]; i++)
-		environ[i] = wcstoutfdup_startup(buffer, wenv[i], maxlen);
-	environ[i] = NULL;
+		argv[i] = save[i] = wcstoutfdup_startup(buffer, wargv[i], maxlen);
+	argv[i] = save[i] = NULL;
 	free(buffer);
 
-	/* sort environment for O(log n) getenv / putenv */
-	qsort(environ, i, sizeof(char*), compareenv);
-
 	/* fix Windows specific environment settings */
 	setup_windows_environment();
 
+	unset_environment_variables = xstrdup("PERL5LIB");
+
 	/* initialize critical section for waitpid pinfo_t list */
 	InitializeCriticalSection(&pinfo_cs);
 
@@ -2265,6 +2811,16 @@ void mingw_startup(void)
 
 	/* initialize Unicode console */
 	winansi_init();
+
+	/* invoke the real main() using our utf8 version of argv. */
+	exit_status = main(argc, argv);
+
+	for (i = 0; i < argc; i++)
+		free(save[i]);
+	free(save);
+	free(argv);
+
+	return exit_status;
 }
 
 int uname(struct utsname *buf)
diff -pruN 1.2.1+git2.18.0-1/git/compat/mingw.h 1.2.3+git2.25.1-1/git/compat/mingw.h
--- 1.2.1+git2.18.0-1/git/compat/mingw.h	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/compat/mingw.h	2020-02-17 04:47:35.000000000 +0000
@@ -11,6 +11,9 @@ typedef _sigset_t sigset_t;
 #undef _POSIX_THREAD_SAFE_FUNCTIONS
 #endif
 
+int mingw_core_config(const char *var, const char *value, void *cb);
+#define platform_core_config mingw_core_config
+
 /*
  * things that are not available in header files
  */
@@ -144,8 +147,7 @@ static inline int fcntl(int fd, int cmd,
 	errno = EINVAL;
 	return -1;
 }
-/* bash cannot reliably detect negative return codes as failure */
-#define exit(code) exit((code) & 0xff)
+
 #define sigemptyset(x) (void)0
 static inline int sigaddset(sigset_t *set, int signum)
 { return 0; }
@@ -257,11 +259,35 @@ char *mingw_mktemp(char *template);
 char *mingw_getcwd(char *pointer, int len);
 #define getcwd mingw_getcwd
 
+#ifdef NO_UNSETENV
+#error "NO_UNSETENV is incompatible with the Windows-specific startup code!"
+#endif
+
+/*
+ * We bind *env() routines (even the mingw_ ones) to private mingw_ versions.
+ * These talk to the CRT using UNICODE/wchar_t, but maintain the original
+ * narrow-char API.
+ *
+ * Note that the MSCRT maintains both ANSI (getenv()) and UNICODE (_wgetenv())
+ * routines and stores both versions of each environment variable in parallel
+ * (and secretly updates both when you set one or the other), but it uses CP_ACP
+ * to do the conversion rather than CP_UTF8.
+ *
+ * Since everything in the git code base is UTF8, we define the mingw_ routines
+ * to access the CRT using the UNICODE routines and manually convert them to
+ * UTF8.  This also avoids round-trip problems.
+ *
+ * This also helps with our linkage, since "_wenviron" is publicly exported
+ * from the CRT.  But to access "_environ" we would have to statically link
+ * to the CRT (/MT).
+ *
+ * We require NO_SETENV (and let gitsetenv() call our mingw_putenv).
+ */
+#define getenv       mingw_getenv
+#define putenv       mingw_putenv
+#define unsetenv     mingw_putenv
 char *mingw_getenv(const char *name);
-#define getenv mingw_getenv
-int mingw_putenv(const char *namevalue);
-#define putenv mingw_putenv
-#define unsetenv mingw_putenv
+int   mingw_putenv(const char *name);
 
 int mingw_gethostname(char *host, int namelen);
 #define gethostname mingw_gethostname
@@ -269,18 +295,10 @@ int mingw_gethostname(char *host, int na
 struct hostent *mingw_gethostbyname(const char *host);
 #define gethostbyname mingw_gethostbyname
 
-void mingw_freeaddrinfo(struct addrinfo *res);
-#define freeaddrinfo mingw_freeaddrinfo
-
 int mingw_getaddrinfo(const char *node, const char *service,
 		      const struct addrinfo *hints, struct addrinfo **res);
 #define getaddrinfo mingw_getaddrinfo
 
-int mingw_getnameinfo(const struct sockaddr *sa, socklen_t salen,
-		      char *host, DWORD hostlen, char *serv, DWORD servlen,
-		      int flags);
-#define getnameinfo mingw_getnameinfo
-
 int mingw_socket(int domain, int type, int protocol);
 #define socket mingw_socket
 
@@ -327,18 +345,43 @@ static inline int getrlimit(int resource
 }
 
 /*
- * Use mingw specific stat()/lstat()/fstat() implementations on Windows.
+ * Use mingw specific stat()/lstat()/fstat() implementations on Windows,
+ * including our own struct stat with 64 bit st_size and nanosecond-precision
+ * file times.
  */
 #ifndef __MINGW64_VERSION_MAJOR
 #define off_t off64_t
 #define lseek _lseeki64
+#ifndef _MSC_VER
+struct timespec {
+	time_t tv_sec;
+	long tv_nsec;
+};
 #endif
+#endif
+
+struct mingw_stat {
+    _dev_t st_dev;
+    _ino_t st_ino;
+    _mode_t st_mode;
+    short st_nlink;
+    short st_uid;
+    short st_gid;
+    _dev_t st_rdev;
+    off64_t st_size;
+    struct timespec st_atim;
+    struct timespec st_mtim;
+    struct timespec st_ctim;
+};
+
+#define st_atime st_atim.tv_sec
+#define st_mtime st_mtim.tv_sec
+#define st_ctime st_ctim.tv_sec
 
-/* use struct stat with 64 bit st_size */
 #ifdef stat
 #undef stat
 #endif
-#define stat _stati64
+#define stat mingw_stat
 int mingw_lstat(const char *file_name, struct stat *buf);
 int mingw_stat(const char *file_name, struct stat *buf);
 int mingw_fstat(int fd, struct stat *buf);
@@ -351,13 +394,6 @@ int mingw_fstat(int fd, struct stat *buf
 #endif
 #define lstat mingw_lstat
 
-#ifndef _stati64
-# define _stati64(x,y) mingw_stat(x,y)
-#elif defined (_USE_32BIT_TIME_T)
-# define _stat32i64(x,y) mingw_stat(x,y)
-#else
-# define _stat64(x,y) mingw_stat(x,y)
-#endif
 
 int mingw_utime(const char *file_name, const struct utimbuf *times);
 #define utime mingw_utime
@@ -390,6 +426,9 @@ int mingw_raise(int sig);
 int winansi_isatty(int fd);
 #define isatty winansi_isatty
 
+int winansi_dup2(int oldfd, int newfd);
+#define dup2 winansi_dup2
+
 void winansi_init(void);
 HANDLE winansi_get_osfhandle(int fd);
 
@@ -397,33 +436,15 @@ HANDLE winansi_get_osfhandle(int fd);
  * git specific compatibility
  */
 
-#define has_dos_drive_prefix(path) \
-	(isalpha(*(path)) && (path)[1] == ':' ? 2 : 0)
-int mingw_skip_dos_drive_prefix(char **path);
-#define skip_dos_drive_prefix mingw_skip_dos_drive_prefix
-static inline int mingw_is_dir_sep(int c)
-{
-	return c == '/' || c == '\\';
-}
-#define is_dir_sep mingw_is_dir_sep
-static inline char *mingw_find_last_dir_sep(const char *path)
-{
-	char *ret = NULL;
-	for (; *path; ++path)
-		if (is_dir_sep(*path))
-			ret = (char *)path;
-	return ret;
-}
 static inline void convert_slashes(char *path)
 {
 	for (; *path; path++)
 		if (*path == '\\')
 			*path = '/';
 }
-#define find_last_dir_sep mingw_find_last_dir_sep
-int mingw_offset_1st_component(const char *path);
-#define offset_1st_component mingw_offset_1st_component
 #define PATH_SEP ';'
+char *mingw_query_user_email(void);
+#define query_user_email mingw_query_user_email
 #if !defined(__MINGW64_VERSION_MAJOR) && (!defined(_MSC_VER) || _MSC_VER < 1800)
 #define PRIuMAX "I64u"
 #define PRId64 "I64d"
@@ -432,6 +453,27 @@ int mingw_offset_1st_component(const cha
 #endif
 
 /**
+ * Verifies that the given path is a valid one on Windows.
+ *
+ * In particular, path segments are disallowed which
+ *
+ * - end in a period or a space (except the special directories `.` and `..`).
+ *
+ * - contain any of the reserved characters, e.g. `:`, `;`, `*`, etc
+ *
+ * - correspond to reserved names (such as `AUX`, `PRN`, etc)
+ *
+ * The `allow_literal_nul` parameter controls whether the path `NUL` should
+ * be considered valid (this makes sense e.g. before opening files, as it is
+ * perfectly legitimate to open `NUL` on Windows, just as it is to open
+ * `/dev/null` on Unix/Linux).
+ *
+ * Returns 1 upon success, otherwise 0.
+ */
+int is_valid_win32_path(const char *path, int allow_literal_nul);
+#define is_valid_path(path) is_valid_win32_path(path, 0)
+
+/**
  * Converts UTF-8 encoded string to UTF-16LE.
  *
  * To support repositories with legacy-encoded file names, invalid UTF-8 bytes
@@ -537,26 +579,26 @@ int xwcstoutf(char *utf, const wchar_t *
 
 /*
  * A critical section used in the implementation of the spawn
- * functions (mingw_spawnv[p]e()) and waitpid(). Intialised in
+ * functions (mingw_spawnv[p]e()) and waitpid(). Initialised in
  * the replacement main() macro below.
  */
 extern CRITICAL_SECTION pinfo_cs;
 
 /*
- * A replacement of main() that adds win32 specific initialization.
+ * Git, like most portable C applications, implements a main() function. On
+ * Windows, this main() function would receive parameters encoded in the
+ * current locale, but Git for Windows would prefer UTF-8 encoded  parameters.
+ *
+ * To make that happen, we still declare main() here, and then declare and
+ * implement wmain() (which is the Unicode variant of main()) and compile with
+ * -municode. This wmain() function reencodes the parameters from UTF-16 to
+ * UTF-8 format, sets up a couple of other things as required on Windows, and
+ * then hands off to the main() function.
  */
-
-void mingw_startup(void);
-#define main(c,v) dummy_decl_mingw_main(void); \
-static int mingw_main(c,v); \
-int main(int argc, const char **argv) \
-{ \
-	mingw_startup(); \
-	return mingw_main(__argc, (void *)__argv); \
-} \
-static int mingw_main(c,v)
+int wmain(int argc, const wchar_t **w_argv);
+int main(int argc, const char **argv);
 
 /*
  * Used by Pthread API implementation for Windows
  */
-extern int err_win_to_posix(DWORD winerr);
+int err_win_to_posix(DWORD winerr);
diff -pruN 1.2.1+git2.18.0-1/git/compat/mmap.c 1.2.3+git2.25.1-1/git/compat/mmap.c
--- 1.2.1+git2.18.0-1/git/compat/mmap.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/compat/mmap.c	2020-02-17 04:47:35.000000000 +0000
@@ -4,7 +4,7 @@ void *git_mmap(void *start, size_t lengt
 {
 	size_t n = 0;
 
-	if (start != NULL || !(flags & MAP_PRIVATE))
+	if (start != NULL || flags != MAP_PRIVATE || prot != PROT_READ)
 		die("Invalid usage of mmap when built with NO_MMAP");
 
 	start = xmalloc(length);
diff -pruN 1.2.1+git2.18.0-1/git/compat/msvc.h 1.2.3+git2.25.1-1/git/compat/msvc.h
--- 1.2.1+git2.18.0-1/git/compat/msvc.h	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/compat/msvc.h	2020-02-17 04:47:35.000000000 +0000
@@ -6,24 +6,28 @@
 #include <malloc.h>
 #include <io.h>
 
+#pragma warning(disable: 4018) /* signed/unsigned comparison */
+#pragma warning(disable: 4244) /* type conversion, possible loss of data */
+#pragma warning(disable: 4090) /* 'function' : different 'const' qualifiers (ALLOC_GROW etc.)*/
+
 /* porting function */
 #define inline __inline
 #define __inline__ __inline
 #define __attribute__(x)
+#define strcasecmp   _stricmp
 #define strncasecmp  _strnicmp
 #define ftruncate    _chsize
 #define strtoull     _strtoui64
 #define strtoll      _strtoi64
 
-static __inline int strcasecmp (const char *s1, const char *s2)
-{
-	int size1 = strlen(s1);
-	int sisz2 = strlen(s2);
-	return _strnicmp(s1, s2, sisz2 > size1 ? sisz2 : size1);
-}
-
 #undef ERROR
 
+#define ftello _ftelli64
+
+typedef int sigset_t;
+/* open for reading, writing, or both (not in fcntl.h) */
+#define O_ACCMODE     (_O_RDONLY | _O_WRONLY | _O_RDWR)
+
 #include "compat/mingw.h"
 
 #endif
diff -pruN 1.2.1+git2.18.0-1/git/compat/nedmalloc/malloc.c.h 1.2.3+git2.25.1-1/git/compat/nedmalloc/malloc.c.h
--- 1.2.1+git2.18.0-1/git/compat/nedmalloc/malloc.c.h	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/compat/nedmalloc/malloc.c.h	2020-02-17 04:47:35.000000000 +0000
@@ -1564,7 +1564,7 @@ static FORCEINLINE void* win32direct_mma
   return (ptr != 0)? ptr: MFAIL;
 }
 
-/* This function supports releasing coalesed segments */
+/* This function supports releasing coalesced segments */
 static FORCEINLINE int win32munmap(void* ptr, size_t size) {
   MEMORY_BASIC_INFORMATION minfo;
   char* cptr = (char*)ptr;
@@ -1655,7 +1655,7 @@ static FORCEINLINE int win32munmap(void*
     #define CALL_MREMAP(addr, osz, nsz, mv)     MFAIL
 #endif /* HAVE_MMAP && HAVE_MREMAP */
 
-/* mstate bit set if continguous morecore disabled or failed */
+/* mstate bit set if contiguous morecore disabled or failed */
 #define USE_NONCONTIGUOUS_BIT (4U)
 
 /* segment bit set in create_mspace_with_base */
@@ -1755,10 +1755,10 @@ static FORCEINLINE void pthread_release_
   assert(sl->l != 0);
   assert(sl->threadid == CURRENT_THREAD);
   if (--sl->c == 0) {
-    sl->threadid = 0;
     volatile unsigned int* lp = &sl->l;
     int prev = 0;
     int ret;
+    sl->threadid = 0;
     __asm__ __volatile__ ("lock; xchgl %0, %1"
 			  : "=r" (ret)
 			  : "m" (*(lp)), "0"(prev)
@@ -2485,7 +2485,7 @@ typedef struct malloc_segment* msegmentp
 
   Trim support
     Fields holding the amount of unused topmost memory that should trigger
-    timming, and a counter to force periodic scanning to release unused
+    timing, and a counter to force periodic scanning to release unused
     non-topmost segments.
 
   Locking
@@ -3066,7 +3066,7 @@ static int init_mparams(void) {
 #if !ONLY_MSPACES
     /* Set up lock for main malloc area */
     gm->mflags = mparams.default_mflags;
-    INITIAL_LOCK(&gm->mutex);
+    (void)INITIAL_LOCK(&gm->mutex);
 #endif
 
 #if (FOOTERS && !INSECURE)
@@ -5017,7 +5017,7 @@ static mstate init_user_mstate(char* tba
   mchunkptr msp = align_as_chunk(tbase);
   mstate m = (mstate)(chunk2mem(msp));
   memset(m, 0, msize);
-  INITIAL_LOCK(&m->mutex);
+  (void)INITIAL_LOCK(&m->mutex);
   msp->head = (msize|PINUSE_BIT|CINUSE_BIT);
   m->seg.base = m->least_addr = tbase;
   m->seg.size = m->footprint = m->max_footprint = tsize;
diff -pruN 1.2.1+git2.18.0-1/git/compat/obstack.c 1.2.3+git2.25.1-1/git/compat/obstack.c
--- 1.2.1+git2.18.0-1/git/compat/obstack.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/compat/obstack.c	2020-02-17 04:47:35.000000000 +0000
@@ -112,15 +112,15 @@ compat_symbol (libc, _obstack_compat, _o
 
 # define CALL_CHUNKFUN(h, size) \
   (((h) -> use_extra_arg) \
-   ? (*(h)->chunkfun) ((h)->extra_arg, (size)) \
-   : (*(struct _obstack_chunk *(*) (long)) (h)->chunkfun) ((size)))
+   ? (*(h)->chunkfun.extra) ((h)->extra_arg, (size)) \
+   : (*(h)->chunkfun.plain) ((size)))
 
 # define CALL_FREEFUN(h, old_chunk) \
   do { \
     if ((h) -> use_extra_arg) \
-      (*(h)->freefun) ((h)->extra_arg, (old_chunk)); \
+      (*(h)->freefun.extra) ((h)->extra_arg, (old_chunk)); \
     else \
-      (*(void (*) (void *)) (h)->freefun) ((old_chunk)); \
+      (*(h)->freefun.plain) ((old_chunk)); \
   } while (0)
 
 
@@ -159,8 +159,8 @@ _obstack_begin (struct obstack *h,
       size = 4096 - extra;
     }
 
-  h->chunkfun = (struct _obstack_chunk * (*)(void *, long)) chunkfun;
-  h->freefun = (void (*) (void *, struct _obstack_chunk *)) freefun;
+  h->chunkfun.plain = chunkfun;
+  h->freefun.plain = freefun;
   h->chunk_size = size;
   h->alignment_mask = alignment - 1;
   h->use_extra_arg = 0;
@@ -206,8 +206,9 @@ _obstack_begin_1 (struct obstack *h, int
       size = 4096 - extra;
     }
 
-  h->chunkfun = (struct _obstack_chunk * (*)(void *,long)) chunkfun;
-  h->freefun = (void (*) (void *, struct _obstack_chunk *)) freefun;
+  h->chunkfun.extra = (struct _obstack_chunk * (*)(void *,long)) chunkfun;
+  h->freefun.extra = (void (*) (void *, struct _obstack_chunk *)) freefun;
+
   h->chunk_size = size;
   h->alignment_mask = alignment - 1;
   h->extra_arg = arg;
diff -pruN 1.2.1+git2.18.0-1/git/compat/obstack.h 1.2.3+git2.25.1-1/git/compat/obstack.h
--- 1.2.1+git2.18.0-1/git/compat/obstack.h	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/compat/obstack.h	2020-02-17 04:47:35.000000000 +0000
@@ -79,7 +79,7 @@ change its address during its lifetime.
 When the chars burst over a chunk boundary, we allocate a larger
 chunk, and then copy the partly formed object from the end of the old
 chunk to the beginning of the new larger chunk.  We then carry on
-accreting characters to the end of the object as we normally would.
+accrediting characters to the end of the object as we normally would.
 
 A special macro is provided to add a single char at a time to a
 growing object.  This allows the use of register variables, which
@@ -160,11 +160,15 @@ struct obstack		/* control current objec
     void *tempptr;
   } temp;			/* Temporary for some macros.  */
   int   alignment_mask;		/* Mask of alignment for each object. */
-  /* These prototypes vary based on `use_extra_arg', and we use
-     casts to the prototypeless function type in all assignments,
-     but having prototypes here quiets -Wstrict-prototypes.  */
-  struct _obstack_chunk *(*chunkfun) (void *, long);
-  void (*freefun) (void *, struct _obstack_chunk *);
+  /* These prototypes vary based on `use_extra_arg'. */
+  union {
+    void *(*plain) (long);
+    struct _obstack_chunk *(*extra) (void *, long);
+  } chunkfun;
+  union {
+    void (*plain) (void *);
+    void (*extra) (void *, struct _obstack_chunk *);
+  } freefun;
   void *extra_arg;		/* first arg for chunk alloc/dealloc funcs */
   unsigned use_extra_arg:1;	/* chunk alloc/dealloc funcs take extra arg */
   unsigned maybe_empty_object:1;/* There is a possibility that the current
@@ -235,10 +239,10 @@ extern void (*obstack_alloc_failed_handl
 		    (void (*) (void *, void *)) (freefun), (arg))
 
 #define obstack_chunkfun(h, newchunkfun) \
-  ((h) -> chunkfun = (struct _obstack_chunk *(*)(void *, long)) (newchunkfun))
+  ((h)->chunkfun.extra = (struct _obstack_chunk *(*)(void *, long)) (newchunkfun))
 
 #define obstack_freefun(h, newfreefun) \
-  ((h) -> freefun = (void (*)(void *, struct _obstack_chunk *)) (newfreefun))
+  ((h)->freefun.extra = (void (*)(void *, struct _obstack_chunk *)) (newfreefun))
 
 #define obstack_1grow_fast(h,achar) (*((h)->next_free)++ = (achar))
 
@@ -492,7 +496,7 @@ __extension__								\
 ( (h)->temp.tempint = (char *) (obj) - (char *) (h)->chunk,		\
   ((((h)->temp.tempint > 0						\
     && (h)->temp.tempint < (h)->chunk_limit - (char *) (h)->chunk))	\
-   ? (int) ((h)->next_free = (h)->object_base				\
+   ? (ptrdiff_t) ((h)->next_free = (h)->object_base				\
 	    = (h)->temp.tempint + (char *) (h)->chunk)			\
    : (((obstack_free) ((h), (h)->temp.tempint + (char *) (h)->chunk), 0), 0)))
 
diff -pruN 1.2.1+git2.18.0-1/git/compat/poll/poll.c 1.2.3+git2.25.1-1/git/compat/poll/poll.c
--- 1.2.1+git2.18.0-1/git/compat/poll/poll.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/compat/poll/poll.c	2020-02-17 04:47:35.000000000 +0000
@@ -18,6 +18,9 @@
    You should have received a copy of the GNU General Public License along
    with this program; if not, see <http://www.gnu.org/licenses/>.  */
 
+/* To bump the minimum Windows version to Windows Vista */
+#include "git-compat-util.h"
+
 /* Tell gcc not to warn about the (nfd < 0) tests, below.  */
 #if (__GNUC__ == 4 && 3 <= __GNUC_MINOR__) || 4 < __GNUC__
 # pragma GCC diagnostic ignored "-Wtype-limits"
@@ -29,9 +32,6 @@
 
 #include <sys/types.h>
 
-/* Specification.  */
-#include <poll.h>
-
 #include <errno.h>
 #include <limits.h>
 #include <assert.h>
@@ -55,6 +55,9 @@
 # include <unistd.h>
 #endif
 
+/* Specification.  */
+#include "poll.h"
+
 #ifdef HAVE_SYS_IOCTL_H
 # include <sys/ioctl.h>
 #endif
@@ -146,8 +149,8 @@ win32_compute_revents (HANDLE h, int *p_
     case FILE_TYPE_PIPE:
       if (!once_only)
 	{
-	  NtQueryInformationFile = (PNtQueryInformationFile)
-	    GetProcAddress (GetModuleHandle ("ntdll.dll"),
+	  NtQueryInformationFile = (PNtQueryInformationFile)(void (*)(void))
+	    GetProcAddress (GetModuleHandleW (L"ntdll.dll"),
 			    "NtQueryInformationFile");
 	  once_only = TRUE;
 	}
@@ -449,7 +452,8 @@ poll (struct pollfd *pfd, nfds_t nfd, in
   static HANDLE hEvent;
   WSANETWORKEVENTS ev;
   HANDLE h, handle_array[FD_SETSIZE + 2];
-  DWORD ret, wait_timeout, nhandles, start = 0, elapsed, orig_timeout = 0;
+  DWORD ret, wait_timeout, nhandles, orig_timeout = 0;
+  ULONGLONG start = 0;
   fd_set rfds, wfds, xfds;
   BOOL poll_again;
   MSG msg;
@@ -465,7 +469,7 @@ poll (struct pollfd *pfd, nfds_t nfd, in
   if (timeout != INFTIM)
     {
       orig_timeout = timeout;
-      start = GetTickCount();
+      start = GetTickCount64();
     }
 
   if (!hEvent)
@@ -614,8 +618,8 @@ restart:
 
   if (!rc && orig_timeout && timeout != INFTIM)
     {
-      elapsed = GetTickCount() - start;
-      timeout = elapsed >= orig_timeout ? 0 : orig_timeout - elapsed;
+      ULONGLONG elapsed = GetTickCount64() - start;
+      timeout = elapsed >= orig_timeout ? 0 : (int)(orig_timeout - elapsed);
     }
 
   if (!rc && timeout)
diff -pruN 1.2.1+git2.18.0-1/git/compat/poll/poll.h 1.2.3+git2.25.1-1/git/compat/poll/poll.h
--- 1.2.1+git2.18.0-1/git/compat/poll/poll.h	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/compat/poll/poll.h	2020-02-17 04:47:35.000000000 +0000
@@ -21,6 +21,21 @@
 #ifndef _GL_POLL_H
 #define _GL_POLL_H
 
+#if defined(_WIN32_WINNT) && _WIN32_WINNT >= 0x600
+/* Vista has its own, socket-only poll() */
+#undef POLLIN
+#undef POLLPRI
+#undef POLLOUT
+#undef POLLERR
+#undef POLLHUP
+#undef POLLNVAL
+#undef POLLRDNORM
+#undef POLLRDBAND
+#undef POLLWRNORM
+#undef POLLWRBAND
+#define pollfd compat_pollfd
+#endif
+
 /* fake a poll(2) environment */
 #define POLLIN      0x0001      /* any readable data available   */
 #define POLLPRI     0x0002      /* OOB/Urgent readable data      */
diff -pruN 1.2.1+git2.18.0-1/git/compat/precompose_utf8.c 1.2.3+git2.25.1-1/git/compat/precompose_utf8.c
--- 1.2.1+git2.18.0-1/git/compat/precompose_utf8.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/compat/precompose_utf8.c	2020-02-17 04:47:35.000000000 +0000
@@ -79,7 +79,7 @@ void precompose_argv(int argc, const cha
 		size_t namelen;
 		oldarg = argv[i];
 		if (has_non_ascii(oldarg, (size_t)-1, &namelen)) {
-			newarg = reencode_string_iconv(oldarg, namelen, ic_precompose, NULL);
+			newarg = reencode_string_iconv(oldarg, namelen, ic_precompose, 0, NULL);
 			if (newarg)
 				argv[i] = newarg;
 		}
diff -pruN 1.2.1+git2.18.0-1/git/compat/precompose_utf8.h 1.2.3+git2.25.1-1/git/compat/precompose_utf8.h
--- 1.2.1+git2.18.0-1/git/compat/precompose_utf8.h	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/compat/precompose_utf8.h	2020-02-17 04:47:35.000000000 +0000
@@ -1,4 +1,6 @@
 #ifndef PRECOMPOSE_UNICODE_H
+#define PRECOMPOSE_UNICODE_H
+
 #include <sys/stat.h>
 #include <sys/types.h>
 #include <dirent.h>
@@ -41,5 +43,4 @@ int precompose_utf8_closedir(PREC_DIR *d
 #define DIR PREC_DIR
 #endif /* PRECOMPOSE_UNICODE_C */
 
-#define  PRECOMPOSE_UNICODE_H
 #endif /* PRECOMPOSE_UNICODE_H */
diff -pruN 1.2.1+git2.18.0-1/git/compat/qsort.c 1.2.3+git2.25.1-1/git/compat/qsort.c
--- 1.2.1+git2.18.0-1/git/compat/qsort.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/compat/qsort.c	1970-01-01 00:00:00.000000000 +0000
@@ -1,62 +0,0 @@
-#include "../git-compat-util.h"
-
-/*
- * A merge sort implementation, simplified from the qsort implementation
- * by Mike Haertel, which is a part of the GNU C Library.
- */
-
-static void msort_with_tmp(void *b, size_t n, size_t s,
-			   int (*cmp)(const void *, const void *),
-			   char *t)
-{
-	char *tmp;
-	char *b1, *b2;
-	size_t n1, n2;
-
-	if (n <= 1)
-		return;
-
-	n1 = n / 2;
-	n2 = n - n1;
-	b1 = b;
-	b2 = (char *)b + (n1 * s);
-
-	msort_with_tmp(b1, n1, s, cmp, t);
-	msort_with_tmp(b2, n2, s, cmp, t);
-
-	tmp = t;
-
-	while (n1 > 0 && n2 > 0) {
-		if (cmp(b1, b2) <= 0) {
-			memcpy(tmp, b1, s);
-			tmp += s;
-			b1 += s;
-			--n1;
-		} else {
-			memcpy(tmp, b2, s);
-			tmp += s;
-			b2 += s;
-			--n2;
-		}
-	}
-	if (n1 > 0)
-		memcpy(tmp, b1, n1 * s);
-	memcpy(b, t, (n - n2) * s);
-}
-
-void git_qsort(void *b, size_t n, size_t s,
-	       int (*cmp)(const void *, const void *))
-{
-	const size_t size = st_mult(n, s);
-	char buf[1024];
-
-	if (size < sizeof(buf)) {
-		/* The temporary array fits on the small on-stack buffer. */
-		msort_with_tmp(b, n, s, cmp, buf);
-	} else {
-		/* It's somewhat large, so malloc it.  */
-		char *tmp = xmalloc(size);
-		msort_with_tmp(b, n, s, cmp, tmp);
-		free(tmp);
-	}
-}
diff -pruN 1.2.1+git2.18.0-1/git/compat/regex/regcomp.c 1.2.3+git2.25.1-1/git/compat/regex/regcomp.c
--- 1.2.1+git2.18.0-1/git/compat/regex/regcomp.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/compat/regex/regcomp.c	2020-02-17 04:47:35.000000000 +0000
@@ -17,6 +17,14 @@
    License along with the GNU C Library; if not, see
    <http://www.gnu.org/licenses/>.  */
 
+#if defined __TANDEM
+ /* This is currently duplicated from git-compat-utils.h */
+# ifdef NO_INTPTR_T
+ typedef long intptr_t;
+ typedef unsigned long uintptr_t;
+# endif
+#endif
+
 static reg_errcode_t re_compile_internal (regex_t *preg, const char * pattern,
 					  size_t length, reg_syntax_t syntax);
 static void re_compile_fastmap_iter (regex_t *bufp,
@@ -3454,7 +3462,7 @@ build_equiv_class (bitset_t sbcset, cons
 	/* This isn't a valid character.  */
 	return REG_ECOLLATE;
 
-      /* Build single byte matcing table for this equivalence class.  */
+      /* Build single byte matching table for this equivalence class.  */
       char_buf[1] = (unsigned char) '\0';
       len = weights[idx1 & 0xffffff];
       for (ch = 0; ch < SBC_MAX; ++ch)
diff -pruN 1.2.1+git2.18.0-1/git/compat/regex/regexec.c 1.2.3+git2.25.1-1/git/compat/regex/regexec.c
--- 1.2.1+git2.18.0-1/git/compat/regex/regexec.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/compat/regex/regexec.c	2020-02-17 04:47:35.000000000 +0000
@@ -2420,7 +2420,7 @@ find_recover_state (reg_errcode_t *err,
 /* From the node set CUR_NODES, pick up the nodes whose types are
    OP_OPEN_SUBEXP and which have corresponding back references in the regular
    expression. And register them to use them later for evaluating the
-   correspoding back references.  */
+   corresponding back references.  */
 
 static reg_errcode_t
 internal_function
@@ -3347,7 +3347,7 @@ build_trtable (const re_dfa_t *dfa, re_d
   dests_node = dests_alloc->dests_node;
   dests_ch = dests_alloc->dests_ch;
 
-  /* Initialize transiton table.  */
+  /* Initialize transition table.  */
   state->word_trtable = state->trtable = NULL;
 
   /* At first, group all nodes belonging to `state' into several
diff -pruN 1.2.1+git2.18.0-1/git/compat/regex/regex.h 1.2.3+git2.25.1-1/git/compat/regex/regex.h
--- 1.2.1+git2.18.0-1/git/compat/regex/regex.h	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/compat/regex/regex.h	2020-02-17 04:47:35.000000000 +0000
@@ -41,6 +41,11 @@
 extern "C" {
 #endif
 
+#define regcomp git_regcomp
+#define regexec git_regexec
+#define regerror git_regerror
+#define regfree git_regfree
+
 /* The following two types have to be signed and unsigned integer type
    wide enough to hold a value of a pointer.  For most ANSI compilers
    ptrdiff_t and size_t should be likely OK.  Still size of these two
@@ -322,7 +327,7 @@ typedef enum
   /* POSIX regcomp return error codes.  (In the order listed in the
      standard.)  */
   REG_BADPAT,		/* Invalid pattern.  */
-  REG_ECOLLATE,		/* Inalid collating element.  */
+  REG_ECOLLATE,		/* Invalid collating element.  */
   REG_ECTYPE,		/* Invalid character class name.  */
   REG_EESCAPE,		/* Trailing backslash.  */
   REG_ESUBREG,		/* Invalid back reference.  */
diff -pruN 1.2.1+git2.18.0-1/git/compat/regex/regex_internal.c 1.2.3+git2.25.1-1/git/compat/regex/regex_internal.c
--- 1.2.1+git2.18.0-1/git/compat/regex/regex_internal.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/compat/regex/regex_internal.c	2020-02-17 04:47:35.000000000 +0000
@@ -1616,7 +1616,7 @@ free_state (re_dfastate_t *state)
   re_free (state);
 }
 
-/* Create the new state which is independ of contexts.
+/* Create the new state which is independent of contexts.
    Return the new state if succeeded, otherwise return NULL.  */
 
 static re_dfastate_t *
diff -pruN 1.2.1+git2.18.0-1/git/compat/vcbuild/find_vs_env.bat 1.2.3+git2.25.1-1/git/compat/vcbuild/find_vs_env.bat
--- 1.2.1+git2.18.0-1/git/compat/vcbuild/find_vs_env.bat	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/compat/vcbuild/find_vs_env.bat	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,168 @@
+@ECHO OFF
+REM ================================================================
+REM You can use either GCC (the default) or MSVC to build git
+REM using the GIT-SDK command line tools.
+REM        $ make
+REM        $ make MSVC=1
+REM
+REM GIT-SDK BASH windows inherit environment variables with all of
+REM the bin/lib/include paths for GCC.  It DOES NOT inherit values
+REM for the corresponding MSVC tools.
+REM
+REM During normal (non-git) Windows development, you launch one
+REM of the provided "developer command prompts" to set environment
+REM variables for the MSVC tools.
+REM
+REM Therefore, to allow MSVC command line builds of git from BASH
+REM and MAKE, we must blend these two different worlds.  This script
+REM attempts to do that.
+REM ================================================================
+REM This BAT file starts in a plain (non-developer) command prompt,
+REM searches for the "best" command prompt setup script, installs
+REM it into the current CMD process, and exports the various MSVC
+REM environment variables for use by MAKE.
+REM
+REM The output of this script should be written to a make "include
+REM file" and referenced by the top-level Makefile.
+REM
+REM See "config.mak.uname" (look for compat/vcbuild/MSVC-DEFS-GEN).
+REM ================================================================
+REM The provided command prompts are custom to each VS release and
+REM filled with lots of internal knowledge (such as Registry settings);
+REM even their names vary by release, so it is not appropriate for us
+REM to look inside them.  Rather, just run them in a subordinate
+REM process and extract the settings we need.
+REM ================================================================
+REM
+REM Current (VS2017 and beyond)
+REM -------------------
+REM Visual Studio 2017 introduced a new installation layout and
+REM support for side-by-side installation of multiple versions of
+REM VS2017.  Furthermore, these can all coexist with installations
+REM of previous versions of VS (which have a completely different
+REM layout on disk).
+REM
+REM VS2017 Update 2 introduced a "vswhere.exe" command:
+REM https://github.com/Microsoft/vswhere
+REM https://blogs.msdn.microsoft.com/heaths/2017/02/25/vswhere-available/
+REM https://blogs.msdn.microsoft.com/vcblog/2017/03/06/finding-the-visual-c-compiler-tools-in-visual-studio-2017/
+REM
+REM VS2015
+REM ------
+REM Visual Studio 2015 uses the traditional VcVarsAll.
+REM
+REM Earlier Versions
+REM ----------------
+REM Currently unsupported.
+REM
+REM ================================================================
+REM Note: Throughout this script we use "dir <path> && <cmd>" rather
+REM than "if exist <path>" because of script problems with pathnames
+REM containing spaces.
+REM ================================================================
+
+REM Sanitize PATH to prevent git-sdk paths from confusing "wmic.exe"
+REM (called internally in some of the system BAT files).
+SET PATH=%SystemRoot%\system32;%SystemRoot%;%SystemRoot%\System32\Wbem;
+
+REM ================================================================
+
+:current
+   SET vs_where=C:\Program Files (x86)\Microsoft Visual Studio\Installer\vswhere.exe
+   dir "%vs_where%" >nul 2>nul && GOTO have_vs_where
+   GOTO not_2017
+
+:have_vs_where
+   REM Try to use VsWhere to get the location of VsDevCmd.
+
+   REM Keep VsDevCmd from cd'ing away.
+   SET VSCMD_START_DIR=.
+
+   REM Get the root of the VS product installation.
+   FOR /F "usebackq tokens=*" %%i IN (`"%vs_where%" -latest -requires Microsoft.VisualStudio.Workload.NativeDesktop -property installationPath`) DO @SET vs_ip=%%i
+
+   SET vs_devcmd=%vs_ip%\Common7\Tools\VsDevCmd.bat
+   dir "%vs_devcmd%" >nul 2>nul && GOTO have_vs_devcmd
+   GOTO not_2017
+
+:have_vs_devcmd
+   REM Use VsDevCmd to setup the environment of this process.
+   REM Setup CL for building 64-bit apps using 64-bit tools.
+   @call "%vs_devcmd%" -no_logo -arch=x64 -host_arch=x64
+
+   SET tgt=%VSCMD_ARG_TGT_ARCH%
+
+   SET mn=%VCToolsInstallDir%
+   SET msvc_includes=-I"%mn%INCLUDE"
+   SET msvc_libs=-L"%mn%lib\%tgt%"
+   SET msvc_bin_dir=%mn%bin\Host%VSCMD_ARG_HOST_ARCH%\%tgt%
+
+   SET sdk_dir=%WindowsSdkDir%
+   SET sdk_ver=%WindowsSDKVersion%
+   SET si=%sdk_dir%Include\%sdk_ver%
+   SET sdk_includes=-I"%si%ucrt" -I"%si%um" -I"%si%shared"
+   SET sl=%sdk_dir%lib\%sdk_ver%
+   SET sdk_libs=-L"%sl%ucrt\%tgt%" -L"%sl%um\%tgt%"
+
+   SET vs_ver=%VisualStudioVersion%
+
+   GOTO print_vars
+
+REM ================================================================
+
+:not_2017
+   REM See if VS2015 is installed.
+
+   SET vs_2015_bat=C:\Program Files (x86)\Microsoft Visual Studio 14.0\VC\vcvarsall.bat
+   dir "%vs_2015_bat%" >nul 2>nul && GOTO have_vs_2015
+   GOTO not_2015
+
+:have_vs_2015
+   REM Use VcVarsAll like the "x64 Native" command prompt.
+   REM Setup CL for building 64-bit apps using 64-bit tools.
+   @call "%vs_2015_bat%" amd64
+
+   REM Note that in VS2015 they use "x64" in some contexts and "amd64" in others.
+   SET mn=C:\Program Files (x86)\Microsoft Visual Studio 14.0\VC\
+   SET msvc_includes=-I"%mn%INCLUDE"
+   SET msvc_libs=-L"%mn%lib\amd64"
+   SET msvc_bin_dir=%mn%bin\amd64
+
+   SET sdk_dir=%WindowsSdkDir%
+   SET sdk_ver=%WindowsSDKVersion%
+   SET si=%sdk_dir%Include\%sdk_ver%
+   SET sdk_includes=-I"%si%ucrt" -I"%si%um" -I"%si%shared" -I"%si%winrt"
+   SET sl=%sdk_dir%lib\%sdk_ver%
+   SET sdk_libs=-L"%sl%ucrt\x64" -L"%sl%um\x64"
+
+   SET vs_ver=%VisualStudioVersion%
+
+   GOTO print_vars
+
+REM ================================================================
+
+:not_2015
+   echo "ERROR: unsupported VS version (older than VS2015)" >&2
+   EXIT /B 1
+
+REM ================================================================
+
+:print_vars
+   REM Dump the essential vars to stdout to allow the main
+   REM Makefile to include it.  See config.mak.uname.
+   REM Include DOS-style and BASH-style path for bin dir.
+
+   echo msvc_bin_dir=%msvc_bin_dir%
+   SET X1=%msvc_bin_dir:C:=/C%
+   SET X2=%X1:\=/%
+   echo msvc_bin_dir_msys=%X2%
+
+   echo msvc_includes=%msvc_includes%
+   echo msvc_libs=%msvc_libs%
+
+   echo sdk_includes=%sdk_includes%
+   echo sdk_libs=%sdk_libs%
+
+   echo vs_ver=%vs_ver%
+
+   EXIT /B 0
diff -pruN 1.2.1+git2.18.0-1/git/compat/vcbuild/.gitignore 1.2.3+git2.25.1-1/git/compat/vcbuild/.gitignore
--- 1.2.1+git2.18.0-1/git/compat/vcbuild/.gitignore	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/compat/vcbuild/.gitignore	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,3 @@
+/vcpkg/
+/MSVC-DEFS-GEN
+/VCPKG-DEFS
diff -pruN 1.2.1+git2.18.0-1/git/compat/vcbuild/README 1.2.3+git2.25.1-1/git/compat/vcbuild/README
--- 1.2.1+git2.18.0-1/git/compat/vcbuild/README	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/compat/vcbuild/README	2020-02-17 04:47:35.000000000 +0000
@@ -1,3 +1,65 @@
+The Steps to Build Git with VS2015 or VS2017 from the command line.
+
+1. Install the "vcpkg" open source package manager and build essential
+   third-party libraries.  The steps for this have been captured in a
+   set of convenience scripts.  These can be run from a stock Command
+   Prompt or from an SDK bash window:
+
+   $ cd <repo_root>
+   $ ./compat/vcbuild/vcpkg_install.bat
+
+   The vcpkg tools and all of the third-party sources will be installed
+   in this folder:
+      <repo_root>/compat/vcbuild/vcpkg/
+
+   A file will be created with a set of Makefile macros pointing to a
+   unified "include", "lib", and "bin" directory (release and debug) for
+   all of the required packages.  This file will be included by the main
+   Makefile:
+      <repo_root>/compat/vcbuild/MSVC-DEFS-GEN
+
+2. OPTIONALLY copy the third-party *.dll and *.pdb files into the repo
+   root to make it easier to run and debug git.exe without having to
+   manipulate your PATH.  This is especially true for debug sessions in
+   Visual Studio.
+
+   Use ONE of the following forms which should match how you want to
+   compile git.exe.
+
+   $ ./compat/vcbuild/vcpkg_copy_packages.bat debug
+   $ ./compat/vcbuild/vcpkg_copy_packages.bat release
+
+3. Build git using MSVC from an SDK bash window using one of the
+   following commands:
+
+   $ make MSVC=1
+   $ make MSVC=1 DEBUG=1
+
+================================================================
+
+Alternatively, run `make vcxproj` and then load the generated `git.sln` in
+Visual Studio. The initial build will install the vcpkg system and build the
+dependencies automatically. This will take a while.
+
+Instead of generating the `git.sln` file yourself (which requires a full Git
+for Windows SDK), you may want to consider fetching the `vs/master` branch of
+https://github.com/git-for-windows/git instead (which is updated automatically
+via CI running `make vcxproj`). The `vs/master` branch does not require a Git
+for Windows to build, but you can run the test scripts in a regular Git Bash.
+
+Note that `make vcxproj` will automatically add and commit the generated `.sln`
+and `.vcxproj` files to the repo. This is necessary to allow building a
+fully-testable Git in Visual Studio, where a regular Git Bash can be used to
+run the test scripts (as opposed to a full Git for Windows SDK): a number of
+build targets, such as Git commands implemented as Unix shell scripts (where
+`@@SHELL_PATH@@` and other placeholders are interpolated) require a full-blown
+Git for Windows SDK (which is about 10x the size of a regular Git for Windows
+installation).
+
+If your plan is to open a Pull Request with Git for Windows, it is a good idea
+to drop this commit before submitting.
+
+================================================================
 The Steps of Build Git with VS2008
 
 1. You need the build environment, which contains the Git dependencies
@@ -30,8 +92,8 @@ The Steps of Build Git with VS2008
    the git operations.
 
 3. Inside Git's directory run the command:
-       make common-cmds.h
-   to generate the common-cmds.h file needed to compile git.
+       make command-list.h
+   to generate the command-list.h file needed to compile git.
 
 4. Then either build Git with the GNU Make Makefile in the Git projects
    root
diff -pruN 1.2.1+git2.18.0-1/git/compat/vcbuild/scripts/clink.pl 1.2.3+git2.25.1-1/git/compat/vcbuild/scripts/clink.pl
--- 1.2.1+git2.18.0-1/git/compat/vcbuild/scripts/clink.pl	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/compat/vcbuild/scripts/clink.pl	2020-02-17 04:47:35.000000000 +0000
@@ -12,43 +12,120 @@
 use strict;
 my @args = ();
 my @cflags = ();
+my @lflags = ();
 my $is_linking = 0;
+my $is_debug = 0;
 while (@ARGV) {
 	my $arg = shift @ARGV;
-	if ("$arg" =~ /^-[DIMGO]/) {
+	if ("$arg" eq "-DDEBUG") {
+	    # Some vcpkg-based libraries have different names for release
+	    # and debug versions.  This hack assumes that -DDEBUG comes
+	    # before any "-l*" flags.
+	    $is_debug = 1;
+	}
+	if ("$arg" =~ /^-[DIMGOZ]/) {
 		push(@cflags, $arg);
 	} elsif ("$arg" eq "-o") {
 		my $file_out = shift @ARGV;
 		if ("$file_out" =~ /exe$/) {
 			$is_linking = 1;
+			# Create foo.exe and foo.pdb
 			push(@args, "-OUT:$file_out");
 		} else {
+			# Create foo.o and foo.o.pdb
 			push(@args, "-Fo$file_out");
+			push(@args, "-Fd$file_out.pdb");
 		}
 	} elsif ("$arg" eq "-lz") {
+	    if ($is_debug) {
+		push(@args, "zlibd.lib");
+	    } else{
 		push(@args, "zlib.lib");
+	    }
 	} elsif ("$arg" eq "-liconv") {
-		push(@args, "iconv.lib");
+		push(@args, "libiconv.lib");
 	} elsif ("$arg" eq "-lcrypto") {
-		push(@args, "libeay32.lib");
+		push(@args, "libcrypto.lib");
 	} elsif ("$arg" eq "-lssl") {
-		push(@args, "ssleay32.lib");
+		push(@args, "libssl.lib");
 	} elsif ("$arg" eq "-lcurl") {
-		push(@args, "libcurl.lib");
+		my $lib = "";
+		# Newer vcpkg definitions call this libcurl_imp.lib; Do we
+		# need to use that instead?
+		foreach my $flag (@lflags) {
+			if ($flag =~ /^-LIBPATH:(.*)/) {
+				foreach my $l ("libcurl_imp.lib", "libcurl.lib") {
+					if (-f "$1/$l") {
+						$lib = $l;
+						last;
+					}
+				}
+			}
+		}
+		push(@args, $lib);
+	} elsif ("$arg" eq "-lexpat") {
+		push(@args, "expat.lib");
 	} elsif ("$arg" =~ /^-L/ && "$arg" ne "-LTCG") {
 		$arg =~ s/^-L/-LIBPATH:/;
-		push(@args, $arg);
-	} elsif ("$arg" =~ /^-R/) {
+		push(@lflags, $arg);
+	} elsif ("$arg" =~ /^-[Rl]/) {
 		# eat
+	} elsif ("$arg" eq "-Werror") {
+		push(@cflags, "-WX");
+	} elsif ("$arg" eq "-Wall") {
+		# cl.exe understands -Wall, but it is really overzealous
+		push(@cflags, "-W4");
+		# disable the "signed/unsigned mismatch" warnings; our source code violates that
+		push(@cflags, "-wd4018");
+		push(@cflags, "-wd4245");
+		push(@cflags, "-wd4389");
+		# disable the "unreferenced formal parameter" warning; our source code violates that
+		push(@cflags, "-wd4100");
+		# disable the "conditional expression is constant" warning; our source code violates that
+		push(@cflags, "-wd4127");
+		# disable the "const object should be initialized" warning; these warnings affect only objects that are `static`
+		push(@cflags, "-wd4132");
+		# disable the "function/data pointer conversion in expression" warning; our source code violates that
+		push(@cflags, "-wd4152");
+		# disable the "non-constant aggregate initializer" warning; our source code violates that
+		push(@cflags, "-wd4204");
+		# disable the "cannot be initialized using address of automatic variable" warning; our source code violates that
+		push(@cflags, "-wd4221");
+		# disable the "possible loss of data" warnings; our source code violates that
+		push(@cflags, "-wd4244");
+		push(@cflags, "-wd4267");
+		# disable the "array is too small to include a terminating null character" warning; we ab-use strings to initialize OIDs
+		push(@cflags, "-wd4295");
+		# disable the "'<<': result of 32-bit shift implicitly converted to 64 bits" warning; our source code violates that
+		push(@cflags, "-wd4334");
+		# disable the "declaration hides previous local declaration" warning; our source code violates that
+		push(@cflags, "-wd4456");
+		# disable the "declaration hides function parameter" warning; our source code violates that
+		push(@cflags, "-wd4457");
+		# disable the "declaration hides global declaration" warning; our source code violates that
+		push(@cflags, "-wd4459");
+		# disable the "potentially uninitialized local variable '<name>' used" warning; our source code violates that
+		push(@cflags, "-wd4701");
+		# disable the "unreachable code" warning; our source code violates that
+		push(@cflags, "-wd4702");
+		# disable the "potentially uninitialized local pointer variable used" warning; our source code violates that
+		push(@cflags, "-wd4703");
+		# disable the "assignment within conditional expression" warning; our source code violates that
+		push(@cflags, "-wd4706");
+		# disable the "'inet_ntoa': Use inet_ntop() or InetNtop() instead" warning; our source code violates that
+		push(@cflags, "-wd4996");
+	} elsif ("$arg" =~ /^-W[a-z]/) {
+		# let's ignore those
 	} else {
 		push(@args, $arg);
 	}
 }
 if ($is_linking) {
+	push(@args, @lflags);
 	unshift(@args, "link.exe");
 } else {
 	unshift(@args, "cl.exe");
 	push(@args, @cflags);
 }
-#printf("**** @args\n");
+printf(STDERR "**** @args\n\n\n") if (!defined($ENV{'QUIET_GEN'}));
 exit (system(@args) != 0);
diff -pruN 1.2.1+git2.18.0-1/git/compat/vcbuild/vcpkg_copy_dlls.bat 1.2.3+git2.25.1-1/git/compat/vcbuild/vcpkg_copy_dlls.bat
--- 1.2.1+git2.18.0-1/git/compat/vcbuild/vcpkg_copy_dlls.bat	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/compat/vcbuild/vcpkg_copy_dlls.bat	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,39 @@
+@ECHO OFF
+REM ================================================================
+REM This script is an optional step. It copies the *.dll and *.pdb
+REM files (created by vcpkg_install.bat) into the top-level directory
+REM of the repo so that you can type "./git.exe" and find them without
+REM having to fixup your PATH.
+REM
+REM NOTE: Because the names of some DLL files change between DEBUG and
+REM NOTE: RELEASE builds when built using "vcpkg.exe", you will need
+REM NOTE: to copy up the corresponding version.
+REM ================================================================
+
+	SETLOCAL EnableDelayedExpansion
+
+	@FOR /F "delims=" %%D IN ("%~dp0") DO @SET cwd=%%~fD
+	cd %cwd%
+
+	SET arch=x64-windows
+	SET inst=%cwd%vcpkg\installed\%arch%
+
+	IF [%1]==[release] (
+		echo Copying RELEASE mode DLLs to repo root...
+	) ELSE IF [%1]==[debug] (
+		SET inst=%inst%\debug
+		echo Copying DEBUG mode DLLs to repo root...
+	) ELSE (
+		echo ERROR: Invalid argument.
+		echo Usage: %~0 release
+		echo Usage: %~0 debug
+		EXIT /B 1
+	)
+
+	xcopy /e/s/v/y %inst%\bin\*.dll ..\..\
+	xcopy /e/s/v/y %inst%\bin\*.pdb ..\..\
+
+	xcopy /e/s/v/y %inst%\bin\*.dll ..\..\t\helper\
+	xcopy /e/s/v/y %inst%\bin\*.pdb ..\..\t\helper\
+
+	EXIT /B 0
diff -pruN 1.2.1+git2.18.0-1/git/compat/vcbuild/vcpkg_install.bat 1.2.3+git2.25.1-1/git/compat/vcbuild/vcpkg_install.bat
--- 1.2.1+git2.18.0-1/git/compat/vcbuild/vcpkg_install.bat	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/compat/vcbuild/vcpkg_install.bat	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,80 @@
+@ECHO OFF
+REM ================================================================
+REM This script installs the "vcpkg" source package manager and uses
+REM it to build the third-party libraries that git requires when it
+REM is built using MSVC.
+REM
+REM [1] Install VCPKG.
+REM     [a] Create <root>/compat/vcbuild/vcpkg/
+REM     [b] Download "vcpkg".
+REM     [c] Compile using the currently installed version of VS.
+REM     [d] Create <root>/compat/vcbuild/vcpkg/vcpkg.exe
+REM
+REM [2] Install third-party libraries.
+REM     [a] Download each (which may also install CMAKE).
+REM     [b] Compile in RELEASE mode and install in:
+REM         vcpkg/installed/<arch>/{bin,lib}
+REM     [c] Compile in DEBUG mode and install in:
+REM         vcpkg/installed/<arch>/debug/{bin,lib}
+REM     [d] Install headers in:
+REM         vcpkg/installed/<arch>/include
+REM
+REM [3] Create a set of MAKE definitions for the top-level
+REM     Makefile to allow "make MSVC=1" to find the above
+REM     third-party libraries.
+REM     [a] Write vcpkg/VCPGK-DEFS
+REM
+REM https://blogs.msdn.microsoft.com/vcblog/2016/09/19/vcpkg-a-tool-to-acquire-and-build-c-open-source-libraries-on-windows/
+REM https://github.com/Microsoft/vcpkg
+REM https://vcpkg.readthedocs.io/en/latest/
+REM ================================================================
+
+	SETLOCAL EnableDelayedExpansion
+
+	@FOR /F "delims=" %%D IN ("%~dp0") DO @SET cwd=%%~fD
+	cd %cwd%
+
+	dir vcpkg\vcpkg.exe >nul 2>nul && GOTO :install_libraries
+
+	echo Fetching vcpkg in %cwd%vcpkg
+	git.exe clone https://github.com/Microsoft/vcpkg vcpkg
+	IF ERRORLEVEL 1 ( EXIT /B 1 )
+
+	cd vcpkg
+	echo Building vcpkg
+	powershell -exec bypass scripts\bootstrap.ps1
+	IF ERRORLEVEL 1 ( EXIT /B 1 )
+
+	echo Successfully installed %cwd%vcpkg\vcpkg.exe
+
+:install_libraries
+	SET arch=x64-windows
+
+	echo Installing third-party libraries...
+	FOR %%i IN (zlib expat libiconv openssl libssh2 curl) DO (
+	    cd %cwd%vcpkg
+	    IF NOT EXIST "packages\%%i_%arch%" CALL :sub__install_one %%i
+	    IF ERRORLEVEL 1 ( EXIT /B 1 )
+	)
+
+:install_defines
+	cd %cwd%
+	SET inst=%cwd%vcpkg\installed\%arch%
+
+	echo vcpkg_inc=-I"%inst%\include">VCPKG-DEFS
+	echo vcpkg_rel_lib=-L"%inst%\lib">>VCPKG-DEFS
+	echo vcpkg_rel_bin="%inst%\bin">>VCPKG-DEFS
+	echo vcpkg_dbg_lib=-L"%inst%\debug\lib">>VCPKG-DEFS
+	echo vcpkg_dbg_bin="%inst%\debug\bin">>VCPKG-DEFS
+
+	EXIT /B 0
+
+
+:sub__install_one
+	echo     Installing package %1...
+
+	.\vcpkg.exe install %1:%arch%
+	IF ERRORLEVEL 1 ( EXIT /B 1 )
+
+	echo     Finished %1
+	goto :EOF
diff -pruN 1.2.1+git2.18.0-1/git/compat/win32/git.manifest 1.2.3+git2.25.1-1/git/compat/win32/git.manifest
--- 1.2.1+git2.18.0-1/git/compat/win32/git.manifest	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/compat/win32/git.manifest	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,25 @@
+<?xml version="1.0" encoding="UTF-8" standalone="yes"?>
+<assembly xmlns="urn:schemas-microsoft-com:asm.v1" manifestVersion="1.0">
+	<assemblyIdentity type="win32" name="Git" version="0.0.0.1" />
+	<trustInfo xmlns="urn:schemas-microsoft-com:asm.v2">
+		<security>
+			<requestedPrivileges>
+				<requestedExecutionLevel level="asInvoker" uiAccess="false" />
+			</requestedPrivileges>
+		</security>
+	</trustInfo>
+	<compatibility xmlns="urn:schemas-microsoft-com:compatibility.v1">
+		<application>
+			<!-- Windows Vista -->
+			<supportedOS Id="{e2011457-1546-43c5-a5fe-008deee3d3f0}"/>
+			<!-- Windows 7 -->
+			<supportedOS Id="{35138b9a-5d96-4fbd-8e2d-a2440225f93a}"/>
+			<!-- Windows 8 -->
+			<supportedOS Id="{4a2f28e3-53b9-4441-ba9c-d69d4a4a6e38}"/>
+			<!-- Windows 8.1 -->
+			<supportedOS Id="{1f676c76-80e1-4239-95bb-83d0f6d0da78}"/>
+			<!-- Windows 10 -->
+			<supportedOS Id="{8e0f7a12-bfb3-4fe8-b9a5-48fd50a15a9a}"/>
+		</application>
+	</compatibility>
+</assembly>
diff -pruN 1.2.1+git2.18.0-1/git/compat/win32/path-utils.c 1.2.3+git2.25.1-1/git/compat/win32/path-utils.c
--- 1.2.1+git2.18.0-1/git/compat/win32/path-utils.c	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/compat/win32/path-utils.c	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,52 @@
+#include "../../git-compat-util.h"
+
+int win32_has_dos_drive_prefix(const char *path)
+{
+	int i;
+
+	/*
+	 * Does it start with an ASCII letter (i.e. highest bit not set),
+	 * followed by a colon?
+	 */
+	if (!(0x80 & (unsigned char)*path))
+		return *path && path[1] == ':' ? 2 : 0;
+
+	/*
+	 * While drive letters must be letters of the English alphabet, it is
+	 * possible to assign virtually _any_ Unicode character via `subst` as
+	 * a drive letter to "virtual drives". Even `1`, or `ä`. Or fun stuff
+	 * like this:
+	 *
+	 *      subst ֍: %USERPROFILE%\Desktop
+	 */
+	for (i = 1; i < 4 && (0x80 & (unsigned char)path[i]); i++)
+		; /* skip first UTF-8 character */
+	return path[i] == ':' ? i + 1 : 0;
+}
+
+int win32_skip_dos_drive_prefix(char **path)
+{
+	int ret = has_dos_drive_prefix(*path);
+	*path += ret;
+	return ret;
+}
+
+int win32_offset_1st_component(const char *path)
+{
+	char *pos = (char *)path;
+
+	/* unc paths */
+	if (!skip_dos_drive_prefix(&pos) &&
+			is_dir_sep(pos[0]) && is_dir_sep(pos[1])) {
+		/* skip server name */
+		pos = strpbrk(pos + 2, "\\/");
+		if (!pos)
+			return 0; /* Error: malformed unc path */
+
+		do {
+			pos++;
+		} while (*pos && !is_dir_sep(*pos));
+	}
+
+	return pos + is_dir_sep(*pos) - path;
+}
diff -pruN 1.2.1+git2.18.0-1/git/compat/win32/path-utils.h 1.2.3+git2.25.1-1/git/compat/win32/path-utils.h
--- 1.2.1+git2.18.0-1/git/compat/win32/path-utils.h	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/compat/win32/path-utils.h	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,26 @@
+#ifndef WIN32_PATH_UTILS_H
+#define WIN32_PATH_UTILS_H
+
+int win32_has_dos_drive_prefix(const char *path);
+#define has_dos_drive_prefix win32_has_dos_drive_prefix
+
+int win32_skip_dos_drive_prefix(char **path);
+#define skip_dos_drive_prefix win32_skip_dos_drive_prefix
+static inline int win32_is_dir_sep(int c)
+{
+	return c == '/' || c == '\\';
+}
+#define is_dir_sep win32_is_dir_sep
+static inline char *win32_find_last_dir_sep(const char *path)
+{
+	char *ret = NULL;
+	for (; *path; ++path)
+		if (is_dir_sep(*path))
+			ret = (char *)path;
+	return ret;
+}
+#define find_last_dir_sep win32_find_last_dir_sep
+int win32_offset_1st_component(const char *path);
+#define offset_1st_component win32_offset_1st_component
+
+#endif
diff -pruN 1.2.1+git2.18.0-1/git/compat/win32/pthread.c 1.2.3+git2.25.1-1/git/compat/win32/pthread.c
--- 1.2.1+git2.18.0-1/git/compat/win32/pthread.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/compat/win32/pthread.c	2020-02-17 04:47:35.000000000 +0000
@@ -56,141 +56,3 @@ pthread_t pthread_self(void)
 	t.tid = GetCurrentThreadId();
 	return t;
 }
-
-int pthread_cond_init(pthread_cond_t *cond, const void *unused)
-{
-	cond->waiters = 0;
-	cond->was_broadcast = 0;
-	InitializeCriticalSection(&cond->waiters_lock);
-
-	cond->sema = CreateSemaphore(NULL, 0, LONG_MAX, NULL);
-	if (!cond->sema)
-		die("CreateSemaphore() failed");
-
-	cond->continue_broadcast = CreateEvent(NULL,	/* security */
-				FALSE,			/* auto-reset */
-				FALSE,			/* not signaled */
-				NULL);			/* name */
-	if (!cond->continue_broadcast)
-		die("CreateEvent() failed");
-
-	return 0;
-}
-
-int pthread_cond_destroy(pthread_cond_t *cond)
-{
-	CloseHandle(cond->sema);
-	CloseHandle(cond->continue_broadcast);
-	DeleteCriticalSection(&cond->waiters_lock);
-	return 0;
-}
-
-int pthread_cond_wait(pthread_cond_t *cond, CRITICAL_SECTION *mutex)
-{
-	int last_waiter;
-
-	EnterCriticalSection(&cond->waiters_lock);
-	cond->waiters++;
-	LeaveCriticalSection(&cond->waiters_lock);
-
-	/*
-	 * Unlock external mutex and wait for signal.
-	 * NOTE: we've held mutex locked long enough to increment
-	 * waiters count above, so there's no problem with
-	 * leaving mutex unlocked before we wait on semaphore.
-	 */
-	LeaveCriticalSection(mutex);
-
-	/* let's wait - ignore return value */
-	WaitForSingleObject(cond->sema, INFINITE);
-
-	/*
-	 * Decrease waiters count. If we are the last waiter, then we must
-	 * notify the broadcasting thread that it can continue.
-	 * But if we continued due to cond_signal, we do not have to do that
-	 * because the signaling thread knows that only one waiter continued.
-	 */
-	EnterCriticalSection(&cond->waiters_lock);
-	cond->waiters--;
-	last_waiter = cond->was_broadcast && cond->waiters == 0;
-	LeaveCriticalSection(&cond->waiters_lock);
-
-	if (last_waiter) {
-		/*
-		 * cond_broadcast was issued while mutex was held. This means
-		 * that all other waiters have continued, but are contending
-		 * for the mutex at the end of this function because the
-		 * broadcasting thread did not leave cond_broadcast, yet.
-		 * (This is so that it can be sure that each waiter has
-		 * consumed exactly one slice of the semaphor.)
-		 * The last waiter must tell the broadcasting thread that it
-		 * can go on.
-		 */
-		SetEvent(cond->continue_broadcast);
-		/*
-		 * Now we go on to contend with all other waiters for
-		 * the mutex. Auf in den Kampf!
-		 */
-	}
-	/* lock external mutex again */
-	EnterCriticalSection(mutex);
-
-	return 0;
-}
-
-/*
- * IMPORTANT: This implementation requires that pthread_cond_signal
- * is called while the mutex is held that is used in the corresponding
- * pthread_cond_wait calls!
- */
-int pthread_cond_signal(pthread_cond_t *cond)
-{
-	int have_waiters;
-
-	EnterCriticalSection(&cond->waiters_lock);
-	have_waiters = cond->waiters > 0;
-	LeaveCriticalSection(&cond->waiters_lock);
-
-	/*
-	 * Signal only when there are waiters
-	 */
-	if (have_waiters)
-		return ReleaseSemaphore(cond->sema, 1, NULL) ?
-			0 : err_win_to_posix(GetLastError());
-	else
-		return 0;
-}
-
-/*
- * DOUBLY IMPORTANT: This implementation requires that pthread_cond_broadcast
- * is called while the mutex is held that is used in the corresponding
- * pthread_cond_wait calls!
- */
-int pthread_cond_broadcast(pthread_cond_t *cond)
-{
-	EnterCriticalSection(&cond->waiters_lock);
-
-	if ((cond->was_broadcast = cond->waiters > 0)) {
-		/* wake up all waiters */
-		ReleaseSemaphore(cond->sema, cond->waiters, NULL);
-		LeaveCriticalSection(&cond->waiters_lock);
-		/*
-		 * At this point all waiters continue. Each one takes its
-		 * slice of the semaphor. Now it's our turn to wait: Since
-		 * the external mutex is held, no thread can leave cond_wait,
-		 * yet. For this reason, we can be sure that no thread gets
-		 * a chance to eat *more* than one slice. OTOH, it means
-		 * that the last waiter must send us a wake-up.
-		 */
-		WaitForSingleObject(cond->continue_broadcast, INFINITE);
-		/*
-		 * Since the external mutex is held, no thread can enter
-		 * cond_wait, and, hence, it is safe to reset this flag
-		 * without cond->waiters_lock held.
-		 */
-		cond->was_broadcast = 0;
-	} else {
-		LeaveCriticalSection(&cond->waiters_lock);
-	}
-	return 0;
-}
diff -pruN 1.2.1+git2.18.0-1/git/compat/win32/pthread.h 1.2.3+git2.25.1-1/git/compat/win32/pthread.h
--- 1.2.1+git2.18.0-1/git/compat/win32/pthread.h	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/compat/win32/pthread.h	2020-02-17 04:47:35.000000000 +0000
@@ -32,27 +32,13 @@ typedef int pthread_mutexattr_t;
 #define pthread_mutexattr_settype(a, t) 0
 #define PTHREAD_MUTEX_RECURSIVE 0
 
-/*
- * Implement simple condition variable for Windows threads, based on ACE
- * implementation.
- *
- * See original implementation: http://bit.ly/1vkDjo
- * ACE homepage: http://www.cse.wustl.edu/~schmidt/ACE.html
- * See also: http://www.cse.wustl.edu/~schmidt/win32-cv-1.html
- */
-typedef struct {
-	LONG waiters;
-	int was_broadcast;
-	CRITICAL_SECTION waiters_lock;
-	HANDLE sema;
-	HANDLE continue_broadcast;
-} pthread_cond_t;
-
-extern int pthread_cond_init(pthread_cond_t *cond, const void *unused);
-extern int pthread_cond_destroy(pthread_cond_t *cond);
-extern int pthread_cond_wait(pthread_cond_t *cond, CRITICAL_SECTION *mutex);
-extern int pthread_cond_signal(pthread_cond_t *cond);
-extern int pthread_cond_broadcast(pthread_cond_t *cond);
+#define pthread_cond_t CONDITION_VARIABLE
+
+#define pthread_cond_init(a,b) InitializeConditionVariable((a))
+#define pthread_cond_destroy(a) do {} while (0)
+#define pthread_cond_wait(a,b) return_0(SleepConditionVariableCS((a), (b), INFINITE))
+#define pthread_cond_signal WakeConditionVariable
+#define pthread_cond_broadcast WakeAllConditionVariable
 
 /*
  * Simple thread creation implementation using pthread API
@@ -64,8 +50,8 @@ typedef struct {
 	DWORD tid;
 } pthread_t;
 
-extern int pthread_create(pthread_t *thread, const void *unused,
-			  void *(*start_routine)(void*), void *arg);
+int pthread_create(pthread_t *thread, const void *unused,
+		   void *(*start_routine)(void*), void *arg);
 
 /*
  * To avoid the need of copying a struct, we use small macro wrapper to pass
@@ -73,10 +59,10 @@ extern int pthread_create(pthread_t *thr
  */
 #define pthread_join(a, b) win32_pthread_join(&(a), (b))
 
-extern int win32_pthread_join(pthread_t *thread, void **value_ptr);
+int win32_pthread_join(pthread_t *thread, void **value_ptr);
 
 #define pthread_equal(t1, t2) ((t1).tid == (t2).tid)
-extern pthread_t pthread_self(void);
+pthread_t pthread_self(void);
 
 static inline void NORETURN pthread_exit(void *ret)
 {
diff -pruN 1.2.1+git2.18.0-1/git/compat/win32/trace2_win32_process_info.c 1.2.3+git2.25.1-1/git/compat/win32/trace2_win32_process_info.c
--- 1.2.1+git2.18.0-1/git/compat/win32/trace2_win32_process_info.c	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/compat/win32/trace2_win32_process_info.c	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,191 @@
+#include "../../cache.h"
+#include "../../json-writer.h"
+#include "lazyload.h"
+#include <Psapi.h>
+#include <tlHelp32.h>
+
+/*
+ * An arbitrarily chosen value to limit the size of the ancestor
+ * array built in git_processes().
+ */
+#define NR_PIDS_LIMIT 10
+
+/*
+ * Find the process data for the given PID in the given snapshot
+ * and update the PROCESSENTRY32 data.
+ */
+static int find_pid(DWORD pid, HANDLE hSnapshot, PROCESSENTRY32 *pe32)
+{
+	pe32->dwSize = sizeof(PROCESSENTRY32);
+
+	if (Process32First(hSnapshot, pe32)) {
+		do {
+			if (pe32->th32ProcessID == pid)
+				return 1;
+		} while (Process32Next(hSnapshot, pe32));
+	}
+	return 0;
+}
+
+/*
+ * Accumulate JSON array of our parent processes:
+ *     [
+ *         exe-name-parent,
+ *         exe-name-grand-parent,
+ *         ...
+ *     ]
+ *
+ * Note: we only report the filename of the process executable; the
+ *       only way to get its full pathname is to use OpenProcess()
+ *       and GetModuleFileNameEx() or QueryfullProcessImageName()
+ *       and that seems rather expensive (on top of the cost of
+ *       getting the snapshot).
+ *
+ * Note: we compute the set of parent processes by walking the PPID
+ *       link in each visited PROCESSENTRY32 record.  This search
+ *       stops when an ancestor process is not found in the snapshot
+ *       (because it exited before the current or intermediate parent
+ *       process exited).
+ *
+ *       This search may compute an incorrect result if the PPID link
+ *       refers to the PID of an exited parent and that PID has been
+ *       recycled and given to a new unrelated process.
+ *
+ *       Worse, it is possible for a child or descendant of the
+ *       current process to be given the recycled PID and cause a
+ *       PPID-cycle.  This would cause an infinite loop building our
+ *       parent process array.
+ *
+ * Note: for completeness, the "System Idle" process has PID=0 and
+ *       PPID=0 and could cause another PPID-cycle.  We don't expect
+ *       Git to be a descendant of the idle process, but because of
+ *       PID recycling, it might be possible to get a PPID link value
+ *       of 0.  This too would cause an infinite loop.
+ *
+ * Therefore, we keep an array of the visited PPIDs to guard against
+ * cycles.
+ *
+ * We use a fixed-size array rather than ALLOC_GROW to keep things
+ * simple and avoid the alloc/realloc overhead.  It is OK if we
+ * truncate the search and return a partial answer.
+ */
+static void get_processes(struct json_writer *jw, HANDLE hSnapshot)
+{
+	PROCESSENTRY32 pe32;
+	DWORD pid;
+	DWORD pid_list[NR_PIDS_LIMIT];
+	int k, nr_pids = 0;
+
+	pid = GetCurrentProcessId();
+	while (find_pid(pid, hSnapshot, &pe32)) {
+		/* Only report parents. Omit self from the JSON output. */
+		if (nr_pids)
+			jw_array_string(jw, pe32.szExeFile);
+
+		/* Check for cycle in snapshot. (Yes, it happened.) */
+		for (k = 0; k < nr_pids; k++)
+			if (pid == pid_list[k]) {
+				jw_array_string(jw, "(cycle)");
+				return;
+			}
+
+		if (nr_pids == NR_PIDS_LIMIT) {
+			jw_array_string(jw, "(truncated)");
+			return;
+		}
+
+		pid_list[nr_pids++] = pid;
+
+		pid = pe32.th32ParentProcessID;
+	}
+}
+
+/*
+ * Emit JSON data for the current and parent processes.  Individual
+ * trace2 targets can decide how to actually print it.
+ */
+static void get_ancestry(void)
+{
+	HANDLE hSnapshot = CreateToolhelp32Snapshot(TH32CS_SNAPPROCESS, 0);
+
+	if (hSnapshot != INVALID_HANDLE_VALUE) {
+		struct json_writer jw = JSON_WRITER_INIT;
+
+		jw_array_begin(&jw, 0);
+		get_processes(&jw, hSnapshot);
+		jw_end(&jw);
+
+		trace2_data_json("process", the_repository, "windows/ancestry",
+				 &jw);
+
+		jw_release(&jw);
+		CloseHandle(hSnapshot);
+	}
+}
+
+/*
+ * Is a debugger attached to the current process?
+ *
+ * This will catch debug runs (where the debugger started the process).
+ * This is the normal case.  Since this code is called during our startup,
+ * it will not report instances where a debugger is attached dynamically
+ * to a running git process, but that is relatively rare.
+ */
+static void get_is_being_debugged(void)
+{
+	if (IsDebuggerPresent())
+		trace2_data_intmax("process", the_repository,
+				   "windows/debugger_present", 1);
+}
+
+/*
+ * Emit JSON data with the peak memory usage of the current process.
+ */
+static void get_peak_memory_info(void)
+{
+	DECLARE_PROC_ADDR(psapi.dll, BOOL, GetProcessMemoryInfo, HANDLE,
+			  PPROCESS_MEMORY_COUNTERS, DWORD);
+
+	if (INIT_PROC_ADDR(GetProcessMemoryInfo)) {
+		PROCESS_MEMORY_COUNTERS pmc;
+
+		if (GetProcessMemoryInfo(GetCurrentProcess(), &pmc,
+					 sizeof(pmc))) {
+			struct json_writer jw = JSON_WRITER_INIT;
+
+			jw_object_begin(&jw, 0);
+
+#define KV(kv) #kv, (intmax_t)pmc.kv
+
+			jw_object_intmax(&jw, KV(PageFaultCount));
+			jw_object_intmax(&jw, KV(PeakWorkingSetSize));
+			jw_object_intmax(&jw, KV(PeakPagefileUsage));
+
+			jw_end(&jw);
+
+			trace2_data_json("process", the_repository,
+					 "windows/memory", &jw);
+			jw_release(&jw);
+		}
+	}
+}
+
+void trace2_collect_process_info(enum trace2_process_info_reason reason)
+{
+	if (!trace2_is_enabled())
+		return;
+
+	switch (reason) {
+	case TRACE2_PROCESS_INFO_STARTUP:
+		get_is_being_debugged();
+		get_ancestry();
+		return;
+
+	case TRACE2_PROCESS_INFO_EXIT:
+		get_peak_memory_info();
+		return;
+
+	default:
+		BUG("trace2_collect_process_info: unknown reason '%d'", reason);
+	}
+}
diff -pruN 1.2.1+git2.18.0-1/git/compat/winansi.c 1.2.3+git2.25.1-1/git/compat/winansi.c
--- 1.2.1+git2.18.0-1/git/compat/winansi.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/compat/winansi.c	2020-02-17 04:47:35.000000000 +0000
@@ -7,6 +7,7 @@
 #include <wingdi.h>
 #include <winreg.h>
 #include "win32.h"
+#include "win32/lazyload.h"
 
 static int fd_is_interactive[3] = { 0, 0, 0 };
 #define FD_CONSOLE 0x1
@@ -41,26 +42,21 @@ typedef struct _CONSOLE_FONT_INFOEX {
 #endif
 #endif
 
-typedef BOOL (WINAPI *PGETCURRENTCONSOLEFONTEX)(HANDLE, BOOL,
-		PCONSOLE_FONT_INFOEX);
-
 static void warn_if_raster_font(void)
 {
 	DWORD fontFamily = 0;
-	PGETCURRENTCONSOLEFONTEX pGetCurrentConsoleFontEx;
+	DECLARE_PROC_ADDR(kernel32.dll, BOOL, GetCurrentConsoleFontEx,
+			HANDLE, BOOL, PCONSOLE_FONT_INFOEX);
 
 	/* don't bother if output was ascii only */
 	if (!non_ascii_used)
 		return;
 
 	/* GetCurrentConsoleFontEx is available since Vista */
-	pGetCurrentConsoleFontEx = (PGETCURRENTCONSOLEFONTEX) GetProcAddress(
-			GetModuleHandle("kernel32.dll"),
-			"GetCurrentConsoleFontEx");
-	if (pGetCurrentConsoleFontEx) {
+	if (INIT_PROC_ADDR(GetCurrentConsoleFontEx)) {
 		CONSOLE_FONT_INFOEX cfi;
 		cfi.cbSize = sizeof(cfi);
-		if (pGetCurrentConsoleFontEx(console, 0, &cfi))
+		if (GetCurrentConsoleFontEx(console, 0, &cfi))
 			fontFamily = cfi.FontFamily;
 	} else {
 		/* pre-Vista: check default console font in registry */
@@ -474,6 +470,18 @@ static void die_lasterr(const char *fmt,
 	va_end(params);
 }
 
+#undef dup2
+int winansi_dup2(int oldfd, int newfd)
+{
+	int ret = dup2(oldfd, newfd);
+
+	if (!ret && newfd >= 0 && newfd <= 2)
+		fd_is_interactive[newfd] = oldfd < 0 || oldfd > 2 ?
+			0 : fd_is_interactive[oldfd];
+
+	return ret;
+}
+
 static HANDLE duplicate_handle(HANDLE hnd)
 {
 	HANDLE hresult, hproc = GetCurrentProcess();
@@ -532,7 +540,20 @@ static HANDLE swap_osfhnd(int fd, HANDLE
 #ifdef DETECT_MSYS_TTY
 
 #include <winternl.h>
+
+#if defined(_MSC_VER)
+
+typedef struct _OBJECT_NAME_INFORMATION
+{
+	UNICODE_STRING Name;
+	WCHAR NameBuffer[FLEX_ARRAY];
+} OBJECT_NAME_INFORMATION, *POBJECT_NAME_INFORMATION;
+
+#define ObjectNameInformation 1
+
+#else
 #include <ntstatus.h>
+#endif
 
 static void detect_msys_tty(int fd)
 {
@@ -587,7 +608,7 @@ int winansi_isatty(int fd)
 void winansi_init(void)
 {
 	int con1, con2;
-	char name[32];
+	wchar_t name[32];
 
 	/* check if either stdout or stderr is a console output screen buffer */
 	con1 = is_console(1);
@@ -607,13 +628,15 @@ void winansi_init(void)
 	}
 
 	/* create a named pipe to communicate with the console thread */
-	xsnprintf(name, sizeof(name), "\\\\.\\pipe\\winansi%lu", GetCurrentProcessId());
-	hwrite = CreateNamedPipe(name, PIPE_ACCESS_OUTBOUND,
+	if (swprintf(name, ARRAY_SIZE(name) - 1, L"\\\\.\\pipe\\winansi%lu",
+		     GetCurrentProcessId()) < 0)
+		die("Could not initialize winansi pipe name");
+	hwrite = CreateNamedPipeW(name, PIPE_ACCESS_OUTBOUND,
 		PIPE_TYPE_BYTE | PIPE_WAIT, 1, BUFFER_SIZE, 0, 0, NULL);
 	if (hwrite == INVALID_HANDLE_VALUE)
 		die_lasterr("CreateNamedPipe failed");
 
-	hread = CreateFile(name, GENERIC_READ, 0, NULL, OPEN_EXISTING, 0, NULL);
+	hread = CreateFileW(name, GENERIC_READ, 0, NULL, OPEN_EXISTING, 0, NULL);
 	if (hread == INVALID_HANDLE_VALUE)
 		die_lasterr("CreateFile for named pipe failed");
 
@@ -639,10 +662,20 @@ void winansi_init(void)
  */
 HANDLE winansi_get_osfhandle(int fd)
 {
+	HANDLE ret;
+
 	if (fd == 1 && (fd_is_interactive[1] & FD_SWAPPED))
 		return hconsole1;
 	if (fd == 2 && (fd_is_interactive[2] & FD_SWAPPED))
 		return hconsole2;
 
-	return (HANDLE)_get_osfhandle(fd);
+	ret = (HANDLE)_get_osfhandle(fd);
+
+	/*
+	 * There are obviously circumstances under which _get_osfhandle()
+	 * returns (HANDLE)-2. This is not documented anywhere, but that is so
+	 * clearly an invalid handle value that we can just work around this
+	 * and return the correct value for invalid handles.
+	 */
+	return ret == (HANDLE)-2 ? INVALID_HANDLE_VALUE : ret;
 }
diff -pruN 1.2.1+git2.18.0-1/git/config.c 1.2.3+git2.25.1-1/git/config.c
--- 1.2.1+git2.18.0-1/git/config.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/config.c	2020-02-17 04:47:35.000000000 +0000
@@ -6,6 +6,7 @@
  *
  */
 #include "cache.h"
+#include "branch.h"
 #include "config.h"
 #include "repository.h"
 #include "lockfile.h"
@@ -14,9 +15,11 @@
 #include "quote.h"
 #include "hashmap.h"
 #include "string-list.h"
+#include "object-store.h"
 #include "utf8.h"
 #include "dir.h"
 #include "color.h"
+#include "refs.h"
 
 struct config_source {
 	struct config_source *prev;
@@ -31,11 +34,12 @@ struct config_source {
 	enum config_origin_type origin_type;
 	const char *name;
 	const char *path;
-	int die_on_error;
+	enum config_error_action default_error_action;
 	int linenr;
 	int eof;
 	struct strbuf value;
 	struct strbuf var;
+	unsigned subsection_case_sensitive : 1;
 
 	int (*do_fgetc)(struct config_source *c);
 	int (*do_ungetc)(int c, struct config_source *conf);
@@ -116,12 +120,12 @@ static long config_buf_ftell(struct conf
 }
 
 #define MAX_INCLUDE_DEPTH 10
-static const char include_depth_advice[] =
+static const char include_depth_advice[] = N_(
 "exceeded maximum include depth (%d) while including\n"
 "	%s\n"
 "from\n"
 "	%s\n"
-"Do you have circular includes?";
+"This might be due to circular includes.");
 static int handle_path_include(const char *path, struct config_include_data *inc)
 {
 	int ret = 0;
@@ -133,7 +137,7 @@ static int handle_path_include(const cha
 
 	expanded = expand_user_path(path, 0);
 	if (!expanded)
-		return error("could not expand include path '%s'", path);
+		return error(_("could not expand include path '%s'"), path);
 	path = expanded;
 
 	/*
@@ -144,7 +148,7 @@ static int handle_path_include(const cha
 		char *slash;
 
 		if (!cf || !cf->path)
-			return error("relative config includes must come from files");
+			return error(_("relative config includes must come from files"));
 
 		slash = find_last_dir_sep(cf->path);
 		if (slash)
@@ -155,7 +159,7 @@ static int handle_path_include(const cha
 
 	if (!access_or_die(path, R_OK, 0)) {
 		if (++inc->depth > MAX_INCLUDE_DEPTH)
-			die(include_depth_advice, MAX_INCLUDE_DEPTH, path,
+			die(_(include_depth_advice), MAX_INCLUDE_DEPTH, path,
 			    !cf ? "<unknown>" :
 			    cf->name ? cf->name :
 			    "the command line");
@@ -167,6 +171,12 @@ static int handle_path_include(const cha
 	return ret;
 }
 
+static void add_trailing_starstar_for_dir(struct strbuf *pat)
+{
+	if (pat->len && is_dir_sep(pat->buf[pat->len - 1]))
+		strbuf_addstr(pat, "**");
+}
+
 static int prepare_include_condition_pattern(struct strbuf *pat)
 {
 	struct strbuf path = STRBUF_INIT;
@@ -196,8 +206,7 @@ static int prepare_include_condition_pat
 	} else if (!is_absolute_path(pat->buf))
 		strbuf_insert(pat, 0, "**/", 3);
 
-	if (pat->len && is_dir_sep(pat->buf[pat->len - 1]))
-		strbuf_addstr(pat, "**");
+	add_trailing_starstar_for_dir(pat);
 
 	strbuf_release(&path);
 	return prefix;
@@ -239,7 +248,7 @@ again:
 	}
 
 	ret = !wildmatch(pattern.buf + prefix, text.buf + prefix,
-			 icase ? WM_CASEFOLD : 0);
+			 WM_PATHNAME | (icase ? WM_CASEFOLD : 0));
 
 	if (!ret && !already_tried_absolute) {
 		/*
@@ -261,6 +270,26 @@ done:
 	return ret;
 }
 
+static int include_by_branch(const char *cond, size_t cond_len)
+{
+	int flags;
+	int ret;
+	struct strbuf pattern = STRBUF_INIT;
+	const char *refname = !the_repository->gitdir ?
+		NULL : resolve_ref_unsafe("HEAD", 0, NULL, &flags);
+	const char *shortname;
+
+	if (!refname || !(flags & REF_ISSYMREF)	||
+			!skip_prefix(refname, "refs/heads/", &shortname))
+		return 0;
+
+	strbuf_add(&pattern, cond, cond_len);
+	add_trailing_starstar_for_dir(&pattern);
+	ret = !wildmatch(pattern.buf, shortname, WM_PATHNAME);
+	strbuf_release(&pattern);
+	return ret;
+}
+
 static int include_condition_is_true(const struct config_options *opts,
 				     const char *cond, size_t cond_len)
 {
@@ -269,6 +298,8 @@ static int include_condition_is_true(con
 		return include_by_gitdir(opts, cond, cond_len, 0);
 	else if (skip_prefix_mem(cond, cond_len, "gitdir/i:", &cond, &cond_len))
 		return include_by_gitdir(opts, cond, cond_len, 1);
+	else if (skip_prefix_mem(cond, cond_len, "onbranch:", &cond, &cond_len))
+		return include_by_branch(cond, cond_len);
 
 	/* unknown conditionals are always false */
 	return 0;
@@ -342,13 +373,13 @@ static int git_config_parse_key_1(const
 
 	if (last_dot == NULL || last_dot == key) {
 		if (!quiet)
-			error("key does not contain a section: %s", key);
+			error(_("key does not contain a section: %s"), key);
 		return -CONFIG_NO_SECTION_OR_NAME;
 	}
 
 	if (!last_dot[1]) {
 		if (!quiet)
-			error("key does not contain variable name: %s", key);
+			error(_("key does not contain variable name: %s"), key);
 		return -CONFIG_NO_SECTION_OR_NAME;
 	}
 
@@ -372,13 +403,13 @@ static int git_config_parse_key_1(const
 			if (!iskeychar(c) ||
 			    (i == baselen + 1 && !isalpha(c))) {
 				if (!quiet)
-					error("invalid key: %s", key);
+					error(_("invalid key: %s"), key);
 				goto out_free_ret_1;
 			}
 			c = tolower(c);
 		} else if (c == '\n') {
 			if (!quiet)
-				error("invalid key (newline): %s", key);
+				error(_("invalid key (newline): %s"), key);
 			goto out_free_ret_1;
 		}
 		if (store_key)
@@ -414,7 +445,7 @@ int git_config_parse_parameter(const cha
 
 	pair = strbuf_split_str(text, '=', 2);
 	if (!pair[0])
-		return error("bogus config parameter: %s", text);
+		return error(_("bogus config parameter: %s"), text);
 
 	if (pair[0]->len && pair[0]->buf[pair[0]->len - 1] == '=') {
 		strbuf_setlen(pair[0], pair[0]->len - 1);
@@ -426,7 +457,7 @@ int git_config_parse_parameter(const cha
 	strbuf_trim(pair[0]);
 	if (!pair[0]->len) {
 		strbuf_list_free(pair);
-		return error("bogus config parameter: %s", text);
+		return error(_("bogus config parameter: %s"), text);
 	}
 
 	if (git_config_parse_key(pair[0]->buf, &canonical_name, NULL)) {
@@ -461,7 +492,7 @@ int git_config_from_parameters(config_fn
 	envw = xstrdup(env);
 
 	if (sq_dequote_to_argv(envw, &argv, &nr, &alloc) < 0) {
-		ret = error("bogus format in " CONFIG_DATA_ENVIRONMENT);
+		ret = error(_("bogus format in %s"), CONFIG_DATA_ENVIRONMENT);
 		goto out;
 	}
 
@@ -604,6 +635,7 @@ static int get_value(config_fn_t fn, voi
 
 static int get_extended_base_var(struct strbuf *name, int c)
 {
+	cf->subsection_case_sensitive = 0;
 	do {
 		if (c == '\n')
 			goto error_incomplete_line;
@@ -640,6 +672,7 @@ error_incomplete_line:
 
 static int get_base_var(struct strbuf *name)
 {
+	cf->subsection_case_sensitive = 1;
 	for (;;) {
 		int c = get_next_char();
 		if (cf->eof)
@@ -809,31 +842,36 @@ static int git_parse_source(config_fn_t
 				      cf->linenr, cf->name);
 	}
 
-	if (cf->die_on_error)
+	switch (opts && opts->error_action ?
+		opts->error_action :
+		cf->default_error_action) {
+	case CONFIG_ERROR_DIE:
 		die("%s", error_msg);
-	else
+		break;
+	case CONFIG_ERROR_ERROR:
 		error_return = error("%s", error_msg);
+		break;
+	case CONFIG_ERROR_SILENT:
+		error_return = -1;
+		break;
+	case CONFIG_ERROR_UNSET:
+		BUG("config error action unset");
+	}
 
 	free(error_msg);
 	return error_return;
 }
 
-static int parse_unit_factor(const char *end, uintmax_t *val)
+static uintmax_t get_unit_factor(const char *end)
 {
 	if (!*end)
 		return 1;
-	else if (!strcasecmp(end, "k")) {
-		*val *= 1024;
-		return 1;
-	}
-	else if (!strcasecmp(end, "m")) {
-		*val *= 1024 * 1024;
-		return 1;
-	}
-	else if (!strcasecmp(end, "g")) {
-		*val *= 1024 * 1024 * 1024;
-		return 1;
-	}
+	else if (!strcasecmp(end, "k"))
+		return 1024;
+	else if (!strcasecmp(end, "m"))
+		return 1024 * 1024;
+	else if (!strcasecmp(end, "g"))
+		return 1024 * 1024 * 1024;
 	return 0;
 }
 
@@ -843,19 +881,20 @@ static int git_parse_signed(const char *
 		char *end;
 		intmax_t val;
 		uintmax_t uval;
-		uintmax_t factor = 1;
+		uintmax_t factor;
 
 		errno = 0;
 		val = strtoimax(value, &end, 0);
 		if (errno == ERANGE)
 			return 0;
-		if (!parse_unit_factor(end, &factor)) {
+		factor = get_unit_factor(end);
+		if (!factor) {
 			errno = EINVAL;
 			return 0;
 		}
-		uval = labs(val);
-		uval *= factor;
-		if (uval > max || labs(val) > uval) {
+		uval = val < 0 ? -val : val;
+		if (unsigned_mult_overflows(factor, uval) ||
+		    factor * uval > max) {
 			errno = ERANGE;
 			return 0;
 		}
@@ -872,21 +911,23 @@ static int git_parse_unsigned(const char
 	if (value && *value) {
 		char *end;
 		uintmax_t val;
-		uintmax_t oldval;
+		uintmax_t factor;
 
 		errno = 0;
 		val = strtoumax(value, &end, 0);
 		if (errno == ERANGE)
 			return 0;
-		oldval = val;
-		if (!parse_unit_factor(end, &val)) {
+		factor = get_unit_factor(end);
+		if (!factor) {
 			errno = EINVAL;
 			return 0;
 		}
-		if (val > max || oldval > val) {
+		if (unsigned_mult_overflows(factor, val) ||
+		    factor * val > max) {
 			errno = ERANGE;
 			return 0;
 		}
+		val *= factor;
 		*ret = val;
 		return 1;
 	}
@@ -921,7 +962,7 @@ int git_parse_ulong(const char *value, u
 	return 1;
 }
 
-static int git_parse_ssize_t(const char *value, ssize_t *ret)
+int git_parse_ssize_t(const char *value, ssize_t *ret)
 {
 	intmax_t tmp;
 	if (!git_parse_signed(value, &tmp, maximum_signed_value_of_type(ssize_t)))
@@ -933,34 +974,44 @@ static int git_parse_ssize_t(const char
 NORETURN
 static void die_bad_number(const char *name, const char *value)
 {
-	const char * error_type = (errno == ERANGE)? _("out of range"):_("invalid unit");
+	const char *error_type = (errno == ERANGE) ?
+		N_("out of range") : N_("invalid unit");
+	const char *bad_numeric = N_("bad numeric config value '%s' for '%s': %s");
 
 	if (!value)
 		value = "";
 
+	if (!strcmp(name, "GIT_TEST_GETTEXT_POISON"))
+		/*
+		 * We explicitly *don't* use _() here since it would
+		 * cause an infinite loop with _() needing to call
+		 * use_gettext_poison(). This is why marked up
+		 * translations with N_() above.
+		 */
+		die(bad_numeric, value, name, error_type);
+
 	if (!(cf && cf->name))
-		die(_("bad numeric config value '%s' for '%s': %s"),
-		    value, name, error_type);
+		die(_(bad_numeric), value, name, _(error_type));
 
 	switch (cf->origin_type) {
 	case CONFIG_ORIGIN_BLOB:
 		die(_("bad numeric config value '%s' for '%s' in blob %s: %s"),
-		    value, name, cf->name, error_type);
+		    value, name, cf->name, _(error_type));
 	case CONFIG_ORIGIN_FILE:
 		die(_("bad numeric config value '%s' for '%s' in file %s: %s"),
-		    value, name, cf->name, error_type);
+		    value, name, cf->name, _(error_type));
 	case CONFIG_ORIGIN_STDIN:
 		die(_("bad numeric config value '%s' for '%s' in standard input: %s"),
-		    value, name, error_type);
+		    value, name, _(error_type));
 	case CONFIG_ORIGIN_SUBMODULE_BLOB:
 		die(_("bad numeric config value '%s' for '%s' in submodule-blob %s: %s"),
-		    value, name, cf->name, error_type);
+		    value, name, cf->name, _(error_type));
 	case CONFIG_ORIGIN_CMDLINE:
 		die(_("bad numeric config value '%s' for '%s' in command line %s: %s"),
-		    value, name, cf->name, error_type);
+		    value, name, cf->name, _(error_type));
 	default:
 		die(_("bad numeric config value '%s' for '%s' in %s: %s"),
-		    value, name, cf->name, error_type);
+		    value, name, cf->name, _(error_type));
 	}
 }
 
@@ -1077,7 +1128,7 @@ int git_config_color(char *dest, const c
 	return 0;
 }
 
-static int git_default_core_config(const char *var, const char *value)
+static int git_default_core_config(const char *var, const char *value, void *cb)
 {
 	/* This needs a better name */
 	if (!strcmp(var, "core.filemode")) {
@@ -1153,8 +1204,8 @@ static int git_default_core_config(const
 			default_abbrev = -1;
 		else {
 			int abbrev = git_config_int(var, value);
-			if (abbrev < minimum_abbrev || abbrev > 40)
-				return error("abbrev length out of range: %d", abbrev);
+			if (abbrev < minimum_abbrev || abbrev > the_hash_algo->hexsz)
+				return error(_("abbrev length out of range: %d"), abbrev);
 			default_abbrev = abbrev;
 		}
 		return 0;
@@ -1233,7 +1284,7 @@ static int git_default_core_config(const
 		}
 		eol_rndtrp_die = git_config_bool(var, value);
 		global_conv_flags_eol = eol_rndtrp_die ?
-			CONV_EOL_RNDTRP_DIE : CONV_EOL_RNDTRP_WARN;
+			CONV_EOL_RNDTRP_DIE : 0;
 		return 0;
 	}
 
@@ -1271,7 +1322,7 @@ static int git_default_core_config(const
 			comment_line_char = value[0];
 			auto_comment_line_char = 0;
 		} else
-			return error("core.commentChar should only be one character");
+			return error(_("core.commentChar should only be one character"));
 		return 0;
 	}
 
@@ -1308,13 +1359,13 @@ static int git_default_core_config(const
 		return 0;
 	}
 
-	if (!strcmp(var, "core.commitgraph")) {
-		core_commit_graph = git_config_bool(var, value);
+	if (!strcmp(var, "core.sparsecheckout")) {
+		core_apply_sparse_checkout = git_config_bool(var, value);
 		return 0;
 	}
 
-	if (!strcmp(var, "core.sparsecheckout")) {
-		core_apply_sparse_checkout = git_config_bool(var, value);
+	if (!strcmp(var, "core.sparsecheckoutcone")) {
+		core_sparse_checkout_cone = git_config_bool(var, value);
 		return 0;
 	}
 
@@ -1333,21 +1384,13 @@ static int git_default_core_config(const
 		return 0;
 	}
 
-	if (!strcmp(var, "core.hidedotfiles")) {
-		if (value && !strcasecmp(value, "dotgitonly"))
-			hide_dotfiles = HIDE_DOTFILES_DOTGITONLY;
-		else
-			hide_dotfiles = git_config_bool(var, value);
+	if (!strcmp(var, "core.usereplacerefs")) {
+		read_replace_refs = git_config_bool(var, value);
 		return 0;
 	}
 
-	if (!strcmp(var, "core.partialclonefilter")) {
-		return git_config_string(&core_partial_clone_filter_default,
-					 var, value);
-	}
-
 	/* Add other config variables here and to Documentation/config.txt. */
-	return 0;
+	return platform_core_config(var, value, cb);
 }
 
 static int git_default_i18n_config(const char *var, const char *value)
@@ -1384,7 +1427,7 @@ static int git_default_branch_config(con
 		else if (!strcmp(value, "always"))
 			autorebase = AUTOREBASE_ALWAYS;
 		else
-			return error("malformed value for %s", var);
+			return error(_("malformed value for %s"), var);
 		return 0;
 	}
 
@@ -1410,9 +1453,9 @@ static int git_default_push_config(const
 		else if (!strcmp(value, "current"))
 			push_default = PUSH_DEFAULT_CURRENT;
 		else {
-			error("malformed value for %s: %s", var, value);
-			return error("Must be one of nothing, matching, simple, "
-				     "upstream or current.");
+			error(_("malformed value for %s: %s"), var, value);
+			return error(_("must be one of nothing, matching, simple, "
+				       "upstream or current"));
 		}
 		return 0;
 	}
@@ -1432,13 +1475,15 @@ static int git_default_mailmap_config(co
 	return 0;
 }
 
-int git_default_config(const char *var, const char *value, void *dummy)
+int git_default_config(const char *var, const char *value, void *cb)
 {
 	if (starts_with(var, "core."))
-		return git_default_core_config(var, value);
+		return git_default_core_config(var, value, cb);
 
-	if (starts_with(var, "user."))
-		return git_ident_config(var, value, dummy);
+	if (starts_with(var, "user.") ||
+	    starts_with(var, "author.") ||
+	    starts_with(var, "committer."))
+		return git_ident_config(var, value, cb);
 
 	if (starts_with(var, "i18n."))
 		return git_default_i18n_config(var, value);
@@ -1520,7 +1565,7 @@ static int do_config_from_file(config_fn
 	top.origin_type = origin_type;
 	top.name = name;
 	top.path = path;
-	top.die_on_error = 1;
+	top.default_error_action = CONFIG_ERROR_DIE;
 	top.do_fgetc = config_file_fgetc;
 	top.do_ungetc = config_file_ungetc;
 	top.do_ftell = config_file_ftell;
@@ -1558,8 +1603,10 @@ int git_config_from_file(config_fn_t fn,
 	return git_config_from_file_with_options(fn, filename, data, NULL);
 }
 
-int git_config_from_mem(config_fn_t fn, const enum config_origin_type origin_type,
-			const char *name, const char *buf, size_t len, void *data)
+int git_config_from_mem(config_fn_t fn,
+			const enum config_origin_type origin_type,
+			const char *name, const char *buf, size_t len,
+			void *data, const struct config_options *opts)
 {
 	struct config_source top;
 
@@ -1569,12 +1616,12 @@ int git_config_from_mem(config_fn_t fn,
 	top.origin_type = origin_type;
 	top.name = name;
 	top.path = NULL;
-	top.die_on_error = 0;
+	top.default_error_action = CONFIG_ERROR_ERROR;
 	top.do_fgetc = config_buf_fgetc;
 	top.do_ungetc = config_buf_ungetc;
 	top.do_ftell = config_buf_ftell;
 
-	return do_config_from(&top, fn, data, NULL);
+	return do_config_from(&top, fn, data, opts);
 }
 
 int git_config_from_blob_oid(config_fn_t fn,
@@ -1589,13 +1636,14 @@ int git_config_from_blob_oid(config_fn_t
 
 	buf = read_object_file(oid, &type, &size);
 	if (!buf)
-		return error("unable to load config blob object '%s'", name);
+		return error(_("unable to load config blob object '%s'"), name);
 	if (type != OBJ_BLOB) {
 		free(buf);
-		return error("reference '%s' does not point to a blob", name);
+		return error(_("reference '%s' does not point to a blob"), name);
 	}
 
-	ret = git_config_from_mem(fn, CONFIG_ORIGIN_BLOB, name, buf, size, data);
+	ret = git_config_from_mem(fn, CONFIG_ORIGIN_BLOB, name, buf, size,
+				  data, NULL);
 	free(buf);
 
 	return ret;
@@ -1608,7 +1656,7 @@ static int git_config_from_blob_ref(conf
 	struct object_id oid;
 
 	if (get_oid(name, &oid) < 0)
-		return error("unable to resolve config blob '%s'", name);
+		return error(_("unable to resolve config blob '%s'"), name);
 	return git_config_from_blob_oid(fn, name, &oid, data);
 }
 
@@ -1638,7 +1686,7 @@ unsigned long git_env_ulong(const char *
 {
 	const char *v = getenv(k);
 	if (v && !git_parse_ulong(v, &val))
-		die("failed to parse %s", k);
+		die(_("failed to parse %s"), k);
 	return val;
 }
 
@@ -1657,11 +1705,15 @@ static int do_git_config_sequence(const
 
 	if (opts->commondir)
 		repo_config = mkpathdup("%s/config", opts->commondir);
+	else if (opts->git_dir)
+		BUG("git_dir without commondir");
 	else
 		repo_config = NULL;
 
 	current_parsing_scope = CONFIG_SCOPE_SYSTEM;
-	if (git_config_system() && !access_or_die(git_etc_gitconfig(), R_OK, 0))
+	if (git_config_system() && !access_or_die(git_etc_gitconfig(), R_OK,
+						  opts->system_gently ?
+						  ACCESS_EACCES_OK : 0))
 		ret += git_config_from_file(fn, git_etc_gitconfig(),
 					    data);
 
@@ -1673,11 +1725,23 @@ static int do_git_config_sequence(const
 		ret += git_config_from_file(fn, user_config, data);
 
 	current_parsing_scope = CONFIG_SCOPE_REPO;
-	if (repo_config && !access_or_die(repo_config, R_OK, 0))
+	if (!opts->ignore_repo && repo_config &&
+	    !access_or_die(repo_config, R_OK, 0))
 		ret += git_config_from_file(fn, repo_config, data);
 
+	/*
+	 * Note: this should have a new scope, CONFIG_SCOPE_WORKTREE.
+	 * But let's not complicate things before it's actually needed.
+	 */
+	if (!opts->ignore_worktree && repository_format_worktree_config) {
+		char *path = git_pathdup("config.worktree");
+		if (!access_or_die(path, R_OK, 0))
+			ret += git_config_from_file(fn, path, data);
+		free(path);
+	}
+
 	current_parsing_scope = CONFIG_SCOPE_CMDLINE;
-	if (git_config_from_parameters(fn, data) < 0)
+	if (!opts->ignore_cmdline && git_config_from_parameters(fn, data) < 0)
 		die(_("unable to parse command-line config"));
 
 	current_parsing_scope = CONFIG_SCOPE_UNKNOWN;
@@ -1768,6 +1832,23 @@ void read_early_config(config_fn_t cb, v
 	strbuf_release(&gitdir);
 }
 
+/*
+ * Read config but only enumerate system and global settings.
+ * Omit any repo-local, worktree-local, or command-line settings.
+ */
+void read_very_early_config(config_fn_t cb, void *data)
+{
+	struct config_options opts = { 0 };
+
+	opts.respect_includes = 1;
+	opts.ignore_repo = 1;
+	opts.ignore_worktree = 1;
+	opts.ignore_cmdline = 1;
+	opts.system_gently = 1;
+
+	config_with_options(cb, data, NULL, &opts);
+}
+
 static struct config_set_element *configset_find_element(struct config_set *cs, const char *key)
 {
 	struct config_set_element k;
@@ -1780,9 +1861,9 @@ static struct config_set_element *config
 	if (git_config_parse_key(key, &normalized_key, NULL))
 		return NULL;
 
-	hashmap_entry_init(&k, strhash(normalized_key));
+	hashmap_entry_init(&k.ent, strhash(normalized_key));
 	k.key = normalized_key;
-	found_entry = hashmap_get(&cs->config_hash, &k, NULL);
+	found_entry = hashmap_get_entry(&cs->config_hash, &k, ent, NULL);
 	free(normalized_key);
 	return found_entry;
 }
@@ -1801,10 +1882,10 @@ static int configset_add_value(struct co
 	 */
 	if (!e) {
 		e = xmalloc(sizeof(*e));
-		hashmap_entry_init(e, strhash(key));
+		hashmap_entry_init(&e->ent, strhash(key));
 		e->key = xstrdup(key);
 		string_list_init(&e->value_list, 1);
-		hashmap_add(&cs->config_hash, e);
+		hashmap_add(&cs->config_hash, &e->ent);
 	}
 	si = string_list_append_nodup(&e->value_list, xstrdup_or_null(value));
 
@@ -1832,12 +1913,14 @@ static int configset_add_value(struct co
 }
 
 static int config_set_element_cmp(const void *unused_cmp_data,
-				  const void *entry,
-				  const void *entry_or_key,
+				  const struct hashmap_entry *eptr,
+				  const struct hashmap_entry *entry_or_key,
 				  const void *unused_keydata)
 {
-	const struct config_set_element *e1 = entry;
-	const struct config_set_element *e2 = entry_or_key;
+	const struct config_set_element *e1, *e2;
+
+	e1 = container_of(eptr, const struct config_set_element, ent);
+	e2 = container_of(entry_or_key, const struct config_set_element, ent);
 
 	return strcmp(e1->key, e2->key);
 }
@@ -1858,12 +1941,12 @@ void git_configset_clear(struct config_s
 	if (!cs->hash_initialized)
 		return;
 
-	hashmap_iter_init(&cs->config_hash, &iter);
-	while ((entry = hashmap_iter_next(&iter))) {
+	hashmap_for_each_entry(&cs->config_hash, &iter, entry,
+				ent /* member name */) {
 		free(entry->key);
 		string_list_clear(&entry->value_list, 1);
 	}
-	hashmap_free(&cs->config_hash, 1);
+	hashmap_free_entries(&cs->config_hash, struct config_set_element, ent);
 	cs->hash_initialized = 0;
 	free(cs->list.items);
 	cs->list.nr = 0;
@@ -1985,7 +2068,7 @@ int git_configset_get_pathname(struct co
 /* Functions use to read configuration from a repository */
 static void repo_read_config(struct repository *repo)
 {
-	struct config_options opts;
+	struct config_options opts = { 0 };
 
 	opts.respect_includes = 1;
 	opts.commondir = repo->commondir;
@@ -2172,23 +2255,6 @@ int git_config_get_pathname(const char *
 	return repo_config_get_pathname(the_repository, key, dest);
 }
 
-/*
- * Note: This function exists solely to maintain backward compatibility with
- * 'fetch' and 'update_clone' storing configuration in '.gitmodules' and should
- * NOT be used anywhere else.
- *
- * Runs the provided config function on the '.gitmodules' file found in the
- * working directory.
- */
-void config_from_gitmodules(config_fn_t fn, void *data)
-{
-	if (the_repository->worktree) {
-		char *file = repo_worktree_path(the_repository, GITMODULES_FILE);
-		git_config_from_file(fn, file, data);
-		free(file);
-	}
-}
-
 int git_config_get_expiry(const char *key, const char **output)
 {
 	int ret = git_config_get_string_const(key, output);
@@ -2224,30 +2290,6 @@ int git_config_get_expiry_in_days(const
 	return -1; /* thing exists but cannot be parsed */
 }
 
-int git_config_get_untracked_cache(void)
-{
-	int val = -1;
-	const char *v;
-
-	/* Hack for test programs like test-dump-untracked-cache */
-	if (ignore_untracked_cache_config)
-		return -1;
-
-	if (!git_config_get_maybe_bool("core.untrackedcache", &val))
-		return val;
-
-	if (!git_config_get_value("core.untrackedcache", &v)) {
-		if (!strcasecmp(v, "keep"))
-			return -1;
-
-		error(_("unknown core.untrackedCache value '%s'; "
-			"using 'keep' default value"), v);
-		return -1;
-	}
-
-	return -1; /* default value */
-}
-
 int git_config_get_split_index(void)
 {
 	int val;
@@ -2276,7 +2318,7 @@ int git_config_get_max_percent_split_cha
 int git_config_get_fsmonitor(void)
 {
 	if (git_config_get_pathname("core.fsmonitor", &core_fsmonitor))
-		core_fsmonitor = getenv("GIT_FSMONITOR_TEST");
+		core_fsmonitor = getenv("GIT_TEST_FSMONITOR");
 
 	if (core_fsmonitor && !*core_fsmonitor)
 		core_fsmonitor = NULL;
@@ -2287,6 +2329,27 @@ int git_config_get_fsmonitor(void)
 	return 0;
 }
 
+int git_config_get_index_threads(int *dest)
+{
+	int is_bool, val;
+
+	val = git_env_ulong("GIT_TEST_INDEX_THREADS", 0);
+	if (val) {
+		*dest = val;
+		return 0;
+	}
+
+	if (!git_config_get_bool_or_int("index.threads", &is_bool, &val)) {
+		if (is_bool)
+			*dest = val ? 0 : 1;
+		else
+			*dest = val;
+		return 0;
+	}
+
+	return 1;
+}
+
 NORETURN
 void git_die_config_linenr(const char *key, const char *filename, int linenr)
 {
@@ -2371,14 +2434,21 @@ static int store_aux_event(enum config_e
 	store->parsed[store->parsed_nr].type = type;
 
 	if (type == CONFIG_EVENT_SECTION) {
+		int (*cmpfn)(const char *, const char *, size_t);
+
 		if (cf->var.len < 2 || cf->var.buf[cf->var.len - 1] != '.')
-			return error("invalid section name '%s'", cf->var.buf);
+			return error(_("invalid section name '%s'"), cf->var.buf);
+
+		if (cf->subsection_case_sensitive)
+			cmpfn = strncasecmp;
+		else
+			cmpfn = strncmp;
 
 		/* Is this the section we were looking for? */
 		store->is_keys_section =
 			store->parsed[store->parsed_nr].is_keys_section =
 			cf->var.len - 1 == store->baselen &&
-			!strncasecmp(cf->var.buf, store->key, store->baselen);
+			!cmpfn(cf->var.buf, store->key, store->baselen);
 		if (store->is_keys_section) {
 			store->section_seen = 1;
 			ALLOC_GROW(store->seen, store->seen_nr + 1,
@@ -2428,7 +2498,7 @@ static int store_aux(const char *key, co
 
 static int write_error(const char *filename)
 {
-	error("failed to write new configuration file %s", filename);
+	error(_("failed to write new configuration file %s"), filename);
 
 	/* Same error code as "failed to rename". */
 	return 4;
@@ -2530,7 +2600,6 @@ static ssize_t write_pair(int fd, const
  * entry (which all are to be removed).
  */
 static void maybe_remove_section(struct config_store_data *store,
-				 const char *contents,
 				 size_t *begin_offset, size_t *end_offset,
 				 int *seen_ptr)
 {
@@ -2621,6 +2690,8 @@ int git_config_set_gently(const char *ke
 void git_config_set(const char *key, const char *value)
 {
 	git_config_set_multivar(key, value, NULL, 0);
+
+	trace2_cmd_set_config(key, value);
 }
 
 /*
@@ -2679,7 +2750,7 @@ int git_config_set_multivar_in_file_gent
 	 */
 	fd = hold_lock_file_for_update(&lock, config_filename, 0);
 	if (fd < 0) {
-		error_errno("could not lock config file %s", config_filename);
+		error_errno(_("could not lock config file %s"), config_filename);
 		ret = CONFIG_NO_LOCK;
 		goto out_free;
 	}
@@ -2690,7 +2761,7 @@ int git_config_set_multivar_in_file_gent
 	in_fd = open(config_filename, O_RDONLY);
 	if ( in_fd < 0 ) {
 		if ( ENOENT != errno ) {
-			error_errno("opening %s", config_filename);
+			error_errno(_("opening %s"), config_filename);
 			ret = CONFIG_INVALID_FILE; /* same as "invalid config file" */
 			goto out_free;
 		}
@@ -2725,7 +2796,7 @@ int git_config_set_multivar_in_file_gent
 			store.value_regex = (regex_t*)xmalloc(sizeof(regex_t));
 			if (regcomp(store.value_regex, value_regex,
 					REG_EXTENDED)) {
-				error("invalid pattern: %s", value_regex);
+				error(_("invalid pattern: %s"), value_regex);
 				FREE_AND_NULL(store.value_regex);
 				ret = CONFIG_INVALID_PATTERN;
 				goto out_free;
@@ -2750,7 +2821,7 @@ int git_config_set_multivar_in_file_gent
 		if (git_config_from_file_with_options(store_aux,
 						      config_filename,
 						      &store, &opts)) {
-			error("invalid config file %s", config_filename);
+			error(_("invalid config file %s"), config_filename);
 			ret = CONFIG_INVALID_FILE;
 			goto out_free;
 		}
@@ -2774,7 +2845,7 @@ int git_config_set_multivar_in_file_gent
 		if (contents == MAP_FAILED) {
 			if (errno == ENODEV && S_ISDIR(st.st_mode))
 				errno = EISDIR;
-			error_errno("unable to mmap '%s'", config_filename);
+			error_errno(_("unable to mmap '%s'"), config_filename);
 			ret = CONFIG_INVALID_FILE;
 			contents = NULL;
 			goto out_free;
@@ -2783,7 +2854,7 @@ int git_config_set_multivar_in_file_gent
 		in_fd = -1;
 
 		if (chmod(get_lock_file_path(&lock), st.st_mode & 07777) < 0) {
-			error_errno("chmod on %s failed", get_lock_file_path(&lock));
+			error_errno(_("chmod on %s failed"), get_lock_file_path(&lock));
 			ret = CONFIG_NO_WRITE;
 			goto out_free;
 		}
@@ -2815,7 +2886,7 @@ int git_config_set_multivar_in_file_gent
 				replace_end = store.parsed[j].end;
 				copy_end = store.parsed[j].begin;
 				if (!value)
-					maybe_remove_section(&store, contents,
+					maybe_remove_section(&store,
 							     &copy_end,
 							     &replace_end, &i);
 				/*
@@ -2868,7 +2939,7 @@ int git_config_set_multivar_in_file_gent
 	}
 
 	if (commit_lock_file(&lock) < 0) {
-		error_errno("could not write config file %s", config_filename);
+		error_errno(_("could not write config file %s"), config_filename);
 		ret = CONFIG_NO_WRITE;
 		goto out_free;
 	}
@@ -2994,7 +3065,7 @@ static int git_config_copy_or_rename_sec
 	memset(&store, 0, sizeof(store));
 
 	if (new_name && !section_name_is_ok(new_name)) {
-		ret = error("invalid section name: %s", new_name);
+		ret = error(_("invalid section name: %s"), new_name);
 		goto out_no_rollback;
 	}
 
@@ -3003,7 +3074,7 @@ static int git_config_copy_or_rename_sec
 
 	out_fd = hold_lock_file_for_update(&lock, config_filename, 0);
 	if (out_fd < 0) {
-		ret = error("could not lock config file %s", config_filename);
+		ret = error(_("could not lock config file %s"), config_filename);
 		goto out;
 	}
 
@@ -3021,7 +3092,7 @@ static int git_config_copy_or_rename_sec
 	}
 
 	if (chmod(get_lock_file_path(&lock), st.st_mode & 07777) < 0) {
-		ret = error_errno("chmod on %s failed",
+		ret = error_errno(_("chmod on %s failed"),
 				  get_lock_file_path(&lock));
 		goto out;
 	}
@@ -3118,7 +3189,7 @@ static int git_config_copy_or_rename_sec
 	config_file = NULL;
 commit_and_out:
 	if (commit_lock_file(&lock) < 0)
-		ret = error_errno("could not write config file %s",
+		ret = error_errno(_("could not write config file %s"),
 				  config_filename);
 out:
 	if (config_file)
@@ -3161,7 +3232,7 @@ int git_config_copy_section(const char *
 #undef config_error_nonbool
 int config_error_nonbool(const char *var)
 {
-	return error("missing value for '%s'", var);
+	return error(_("missing value for '%s'"), var);
 }
 
 int parse_config_key(const char *var,
@@ -3245,3 +3316,16 @@ enum config_scope current_config_scope(v
 	else
 		return current_parsing_scope;
 }
+
+int lookup_config(const char **mapping, int nr_mapping, const char *var)
+{
+	int i;
+
+	for (i = 0; i < nr_mapping; i++) {
+		const char *name = mapping[i];
+
+		if (name && !strcasecmp(var, name))
+			return i;
+	}
+	return -1;
+}
diff -pruN 1.2.1+git2.18.0-1/git/config.h 1.2.3+git2.25.1-1/git/config.h
--- 1.2.1+git2.18.0-1/git/config.h	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/config.h	2020-02-17 04:47:35.000000000 +0000
@@ -1,6 +1,27 @@
 #ifndef CONFIG_H
 #define CONFIG_H
 
+#include "hashmap.h"
+#include "string-list.h"
+
+
+/**
+ * The config API gives callers a way to access Git configuration files
+ * (and files which have the same syntax).
+ *
+ * General Usage
+ * -------------
+ *
+ * Config files are parsed linearly, and each variable found is passed to a
+ * caller-provided callback function. The callback function is responsible
+ * for any actions to be taken on the config option, and is free to ignore
+ * some options. It is not uncommon for the configuration to be parsed
+ * several times during the run of a Git program, with different callbacks
+ * picking out different variables useful to themselves.
+ */
+
+struct object_id;
+
 /* git_config_parse_key() returns these negated: */
 #define CONFIG_INVALID_KEY 1
 #define CONFIG_NO_SECTION_OR_NAME 2
@@ -50,65 +71,228 @@ typedef int (*config_parser_event_fn_t)(
 
 struct config_options {
 	unsigned int respect_includes : 1;
+	unsigned int ignore_repo : 1;
+	unsigned int ignore_worktree : 1;
+	unsigned int ignore_cmdline : 1;
+	unsigned int system_gently : 1;
 	const char *commondir;
 	const char *git_dir;
 	config_parser_event_fn_t event_fn;
 	void *event_fn_data;
+	enum config_error_action {
+		CONFIG_ERROR_UNSET = 0, /* use source-specific default */
+		CONFIG_ERROR_DIE, /* die() on error */
+		CONFIG_ERROR_ERROR, /* error() on error, return -1 */
+		CONFIG_ERROR_SILENT, /* return -1 */
+	} error_action;
 };
 
+/**
+ * A config callback function takes three parameters:
+ *
+ * - the name of the parsed variable. This is in canonical "flat" form: the
+ *   section, subsection, and variable segments will be separated by dots,
+ *   and the section and variable segments will be all lowercase. E.g.,
+ *   `core.ignorecase`, `diff.SomeType.textconv`.
+ *
+ * - the value of the found variable, as a string. If the variable had no
+ *   value specified, the value will be NULL (typically this means it
+ *   should be interpreted as boolean true).
+ *
+ * - a void pointer passed in by the caller of the config API; this can
+ *   contain callback-specific data
+ *
+ * A config callback should return 0 for success, or -1 if the variable
+ * could not be parsed properly.
+ */
 typedef int (*config_fn_t)(const char *, const char *, void *);
-extern int git_default_config(const char *, const char *, void *);
-extern int git_config_from_file(config_fn_t fn, const char *, void *);
-extern int git_config_from_file_with_options(config_fn_t fn, const char *,
-					     void *,
-					     const struct config_options *);
-extern int git_config_from_mem(config_fn_t fn, const enum config_origin_type,
-					const char *name, const char *buf, size_t len, void *data);
-extern int git_config_from_blob_oid(config_fn_t fn, const char *name,
-				    const struct object_id *oid, void *data);
-extern void git_config_push_parameter(const char *text);
-extern int git_config_from_parameters(config_fn_t fn, void *data);
-extern void read_early_config(config_fn_t cb, void *data);
-extern void git_config(config_fn_t fn, void *);
-extern int config_with_options(config_fn_t fn, void *,
-			       struct git_config_source *config_source,
-			       const struct config_options *opts);
-extern int git_parse_ulong(const char *, unsigned long *);
-extern int git_parse_maybe_bool(const char *);
-extern int git_config_int(const char *, const char *);
-extern int64_t git_config_int64(const char *, const char *);
-extern unsigned long git_config_ulong(const char *, const char *);
-extern ssize_t git_config_ssize_t(const char *, const char *);
-extern int git_config_bool_or_int(const char *, const char *, int *);
-extern int git_config_bool(const char *, const char *);
-extern int git_config_string(const char **, const char *, const char *);
-extern int git_config_pathname(const char **, const char *, const char *);
-extern int git_config_expiry_date(timestamp_t *, const char *, const char *);
-extern int git_config_color(char *, const char *, const char *);
-extern int git_config_set_in_file_gently(const char *, const char *, const char *);
-extern void git_config_set_in_file(const char *, const char *, const char *);
-extern int git_config_set_gently(const char *, const char *);
-extern void git_config_set(const char *, const char *);
-extern int git_config_parse_key(const char *, char **, int *);
-extern int git_config_key_is_valid(const char *key);
-extern int git_config_set_multivar_gently(const char *, const char *, const char *, int);
-extern void git_config_set_multivar(const char *, const char *, const char *, int);
-extern int git_config_set_multivar_in_file_gently(const char *, const char *, const char *, const char *, int);
-extern void git_config_set_multivar_in_file(const char *, const char *, const char *, const char *, int);
-extern int git_config_rename_section(const char *, const char *);
-extern int git_config_rename_section_in_file(const char *, const char *, const char *);
-extern int git_config_copy_section(const char *, const char *);
-extern int git_config_copy_section_in_file(const char *, const char *, const char *);
-extern const char *git_etc_gitconfig(void);
-extern int git_env_bool(const char *, int);
-extern unsigned long git_env_ulong(const char *, unsigned long);
-extern int git_config_system(void);
-extern int config_error_nonbool(const char *);
+
+int git_default_config(const char *, const char *, void *);
+
+/**
+ * Read a specific file in git-config format.
+ * This function takes the same callback and data parameters as `git_config`.
+ */
+int git_config_from_file(config_fn_t fn, const char *, void *);
+
+int git_config_from_file_with_options(config_fn_t fn, const char *,
+				      void *,
+				      const struct config_options *);
+int git_config_from_mem(config_fn_t fn,
+			const enum config_origin_type,
+			const char *name,
+			const char *buf, size_t len,
+			void *data, const struct config_options *opts);
+int git_config_from_blob_oid(config_fn_t fn, const char *name,
+			     const struct object_id *oid, void *data);
+void git_config_push_parameter(const char *text);
+int git_config_from_parameters(config_fn_t fn, void *data);
+void read_early_config(config_fn_t cb, void *data);
+void read_very_early_config(config_fn_t cb, void *data);
+
+/**
+ * Most programs will simply want to look up variables in all config files
+ * that Git knows about, using the normal precedence rules. To do this,
+ * call `git_config` with a callback function and void data pointer.
+ *
+ * `git_config` will read all config sources in order of increasing
+ * priority. Thus a callback should typically overwrite previously-seen
+ * entries with new ones (e.g., if both the user-wide `~/.gitconfig` and
+ * repo-specific `.git/config` contain `color.ui`, the config machinery
+ * will first feed the user-wide one to the callback, and then the
+ * repo-specific one; by overwriting, the higher-priority repo-specific
+ * value is left at the end).
+ */
+void git_config(config_fn_t fn, void *);
+
+/**
+ * Lets the caller examine config while adjusting some of the default
+ * behavior of `git_config`. It should almost never be used by "regular"
+ * Git code that is looking up configuration variables.
+ * It is intended for advanced callers like `git-config`, which are
+ * intentionally tweaking the normal config-lookup process.
+ * It takes two extra parameters:
+ *
+ * - `config_source`
+ * If this parameter is non-NULL, it specifies the source to parse for
+ * configuration, rather than looking in the usual files. See `struct
+ * git_config_source` in `config.h` for details. Regular `git_config` defaults
+ * to `NULL`.
+ *
+ * - `opts`
+ * Specify options to adjust the behavior of parsing config files. See `struct
+ * config_options` in `config.h` for details. As an example: regular `git_config`
+ * sets `opts.respect_includes` to `1` by default.
+ */
+int config_with_options(config_fn_t fn, void *,
+			struct git_config_source *config_source,
+			const struct config_options *opts);
+
+/**
+ * Value Parsing Helpers
+ * ---------------------
+ *
+ * The following helper functions aid in parsing string values
+ */
+
+int git_parse_ssize_t(const char *, ssize_t *);
+int git_parse_ulong(const char *, unsigned long *);
+
+/**
+ * Same as `git_config_bool`, except that it returns -1 on error rather
+ * than dying.
+ */
+int git_parse_maybe_bool(const char *);
+
+/**
+ * Parse the string to an integer, including unit factors. Dies on error;
+ * otherwise, returns the parsed result.
+ */
+int git_config_int(const char *, const char *);
+
+int64_t git_config_int64(const char *, const char *);
+
+/**
+ * Identical to `git_config_int`, but for unsigned longs.
+ */
+unsigned long git_config_ulong(const char *, const char *);
+
+ssize_t git_config_ssize_t(const char *, const char *);
+
+/**
+ * Same as `git_config_bool`, except that integers are returned as-is, and
+ * an `is_bool` flag is unset.
+ */
+int git_config_bool_or_int(const char *, const char *, int *);
+
+/**
+ * Parse a string into a boolean value, respecting keywords like "true" and
+ * "false". Integer values are converted into true/false values (when they
+ * are non-zero or zero, respectively). Other values cause a die(). If
+ * parsing is successful, the return value is the result.
+ */
+int git_config_bool(const char *, const char *);
+
+/**
+ * Allocates and copies the value string into the `dest` parameter; if no
+ * string is given, prints an error message and returns -1.
+ */
+int git_config_string(const char **, const char *, const char *);
+
+/**
+ * Similar to `git_config_string`, but expands `~` or `~user` into the
+ * user's home directory when found at the beginning of the path.
+ */
+int git_config_pathname(const char **, const char *, const char *);
+
+int git_config_expiry_date(timestamp_t *, const char *, const char *);
+int git_config_color(char *, const char *, const char *);
+int git_config_set_in_file_gently(const char *, const char *, const char *);
+
+/**
+ * write config values to a specific config file, takes a key/value pair as
+ * parameter.
+ */
+void git_config_set_in_file(const char *, const char *, const char *);
+
+int git_config_set_gently(const char *, const char *);
+
+/**
+ * write config values to `.git/config`, takes a key/value pair as parameter.
+ */
+void git_config_set(const char *, const char *);
+
+int git_config_parse_key(const char *, char **, int *);
+int git_config_key_is_valid(const char *key);
+int git_config_set_multivar_gently(const char *, const char *, const char *, int);
+void git_config_set_multivar(const char *, const char *, const char *, int);
+int git_config_set_multivar_in_file_gently(const char *, const char *, const char *, const char *, int);
+
+/**
+ * takes four parameters:
+ *
+ * - the name of the file, as a string, to which key/value pairs will be written.
+ *
+ * - the name of key, as a string. This is in canonical "flat" form: the section,
+ *   subsection, and variable segments will be separated by dots, and the section
+ *   and variable segments will be all lowercase.
+ *   E.g., `core.ignorecase`, `diff.SomeType.textconv`.
+ *
+ * - the value of the variable, as a string. If value is equal to NULL, it will
+ *   remove the matching key from the config file.
+ *
+ * - the value regex, as a string. It will disregard key/value pairs where value
+ *   does not match.
+ *
+ * - a multi_replace value, as an int. If value is equal to zero, nothing or only
+ *   one matching key/value is replaced, else all matching key/values (regardless
+ *   how many) are removed, before the new pair is written.
+ *
+ * It returns 0 on success.
+ */
+void git_config_set_multivar_in_file(const char *, const char *, const char *, const char *, int);
+
+/**
+ * rename or remove sections in the config file
+ * parameters `old_name` and `new_name`
+ * If NULL is passed through `new_name` parameter,
+ * the section will be removed from the config file.
+ */
+int git_config_rename_section(const char *, const char *);
+
+int git_config_rename_section_in_file(const char *, const char *, const char *);
+int git_config_copy_section(const char *, const char *);
+int git_config_copy_section_in_file(const char *, const char *, const char *);
+const char *git_etc_gitconfig(void);
+int git_env_bool(const char *, int);
+unsigned long git_env_ulong(const char *, unsigned long);
+int git_config_system(void);
+int config_error_nonbool(const char *);
 #if defined(__GNUC__)
 #define config_error_nonbool(s) (config_error_nonbool(s), const_error())
 #endif
 
-extern int git_config_parse_parameter(const char *, config_fn_t fn, void *data);
+int git_config_parse_parameter(const char *, config_fn_t fn, void *data);
 
 enum config_scope {
 	CONFIG_SCOPE_UNKNOWN = 0,
@@ -118,10 +302,34 @@ enum config_scope {
 	CONFIG_SCOPE_CMDLINE,
 };
 
-extern enum config_scope current_config_scope(void);
-extern const char *current_config_origin_type(void);
-extern const char *current_config_name(void);
-
+enum config_scope current_config_scope(void);
+const char *current_config_origin_type(void);
+const char *current_config_name(void);
+
+/**
+ * Include Directives
+ * ------------------
+ *
+ * By default, the config parser does not respect include directives.
+ * However, a caller can use the special `git_config_include` wrapper
+ * callback to support them. To do so, you simply wrap your "real" callback
+ * function and data pointer in a `struct config_include_data`, and pass
+ * the wrapper to the regular config-reading functions. For example:
+ *
+ * -------------------------------------------
+ * int read_file_with_include(const char *file, config_fn_t fn, void *data)
+ * {
+ * struct config_include_data inc = CONFIG_INCLUDE_INIT;
+ * inc.fn = fn;
+ * inc.data = data;
+ * return git_config_from_file(git_config_include, file, &inc);
+ * }
+ * -------------------------------------------
+ *
+ * `git_config` respects includes automatically. The lower-level
+ * `git_config_from_file` does not.
+ *
+ */
 struct config_include_data {
 	int depth;
 	config_fn_t fn;
@@ -129,7 +337,7 @@ struct config_include_data {
 	const struct config_options *opts;
 };
 #define CONFIG_INCLUDE_INIT { 0 }
-extern int git_config_include(const char *name, const char *value, void *data);
+int git_config_include(const char *name, const char *value, void *data);
 
 /*
  * Match and parse a config key of the form:
@@ -144,10 +352,37 @@ extern int git_config_include(const char
  * If the subsection pointer-to-pointer passed in is NULL, returns 0 only if
  * there is no subsection at all.
  */
-extern int parse_config_key(const char *var,
-			    const char *section,
-			    const char **subsection, int *subsection_len,
-			    const char **key);
+int parse_config_key(const char *var,
+		     const char *section,
+		     const char **subsection, int *subsection_len,
+		     const char **key);
+
+/**
+ * Custom Configsets
+ * -----------------
+ *
+ * A `config_set` can be used to construct an in-memory cache for
+ * config-like files that the caller specifies (i.e., files like `.gitmodules`,
+ * `~/.gitconfig` etc.). For example,
+ *
+ * ----------------------------------------
+ * struct config_set gm_config;
+ * git_configset_init(&gm_config);
+ * int b;
+ * //we add config files to the config_set
+ * git_configset_add_file(&gm_config, ".gitmodules");
+ * git_configset_add_file(&gm_config, ".gitmodules_alt");
+ *
+ * if (!git_configset_get_bool(gm_config, "submodule.frotz.ignore", &b)) {
+ * //hack hack hack
+ * }
+ *
+ * when we are done with the configset:
+ * git_configset_clear(&gm_config);
+ * ----------------------------------------
+ *
+ * Configset API provides functions for the above mentioned work flow
+ */
 
 struct config_set_element {
 	struct hashmap_entry ent;
@@ -177,75 +412,179 @@ struct config_set {
 	struct configset_list list;
 };
 
-extern void git_configset_init(struct config_set *cs);
-extern int git_configset_add_file(struct config_set *cs, const char *filename);
-extern int git_configset_get_value(struct config_set *cs, const char *key, const char **value);
-extern const struct string_list *git_configset_get_value_multi(struct config_set *cs, const char *key);
-extern void git_configset_clear(struct config_set *cs);
-extern int git_configset_get_string_const(struct config_set *cs, const char *key, const char **dest);
-extern int git_configset_get_string(struct config_set *cs, const char *key, char **dest);
-extern int git_configset_get_int(struct config_set *cs, const char *key, int *dest);
-extern int git_configset_get_ulong(struct config_set *cs, const char *key, unsigned long *dest);
-extern int git_configset_get_bool(struct config_set *cs, const char *key, int *dest);
-extern int git_configset_get_bool_or_int(struct config_set *cs, const char *key, int *is_bool, int *dest);
-extern int git_configset_get_maybe_bool(struct config_set *cs, const char *key, int *dest);
-extern int git_configset_get_pathname(struct config_set *cs, const char *key, const char **dest);
+/**
+ * Initializes the config_set `cs`.
+ */
+void git_configset_init(struct config_set *cs);
+
+/**
+ * Parses the file and adds the variable-value pairs to the `config_set`,
+ * dies if there is an error in parsing the file. Returns 0 on success, or
+ * -1 if the file does not exist or is inaccessible. The user has to decide
+ * if he wants to free the incomplete configset or continue using it when
+ * the function returns -1.
+ */
+int git_configset_add_file(struct config_set *cs, const char *filename);
+
+/**
+ * Finds and returns the value list, sorted in order of increasing priority
+ * for the configuration variable `key` and config set `cs`. When the
+ * configuration variable `key` is not found, returns NULL. The caller
+ * should not free or modify the returned pointer, as it is owned by the cache.
+ */
+const struct string_list *git_configset_get_value_multi(struct config_set *cs, const char *key);
+
+/**
+ * Clears `config_set` structure, removes all saved variable-value pairs.
+ */
+void git_configset_clear(struct config_set *cs);
+
+/*
+ * These functions return 1 if not found, and 0 if found, leaving the found
+ * value in the 'dest' pointer.
+ */
+
+/*
+ * Finds the highest-priority value for the configuration variable `key`
+ * and config set `cs`, stores the pointer to it in `value` and returns 0.
+ * When the configuration variable `key` is not found, returns 1 without
+ * touching `value`. The caller should not free or modify `value`, as it
+ * is owned by the cache.
+ */
+int git_configset_get_value(struct config_set *cs, const char *key, const char **dest);
+
+int git_configset_get_string_const(struct config_set *cs, const char *key, const char **dest);
+int git_configset_get_string(struct config_set *cs, const char *key, char **dest);
+int git_configset_get_int(struct config_set *cs, const char *key, int *dest);
+int git_configset_get_ulong(struct config_set *cs, const char *key, unsigned long *dest);
+int git_configset_get_bool(struct config_set *cs, const char *key, int *dest);
+int git_configset_get_bool_or_int(struct config_set *cs, const char *key, int *is_bool, int *dest);
+int git_configset_get_maybe_bool(struct config_set *cs, const char *key, int *dest);
+int git_configset_get_pathname(struct config_set *cs, const char *key, const char **dest);
 
 /* Functions for reading a repository's config */
 struct repository;
-extern void repo_config(struct repository *repo, config_fn_t fn, void *data);
-extern int repo_config_get_value(struct repository *repo,
-				 const char *key, const char **value);
-extern const struct string_list *repo_config_get_value_multi(struct repository *repo,
-							     const char *key);
-extern int repo_config_get_string_const(struct repository *repo,
-					const char *key, const char **dest);
-extern int repo_config_get_string(struct repository *repo,
-				  const char *key, char **dest);
-extern int repo_config_get_int(struct repository *repo,
+void repo_config(struct repository *repo, config_fn_t fn, void *data);
+int repo_config_get_value(struct repository *repo,
+			  const char *key, const char **value);
+const struct string_list *repo_config_get_value_multi(struct repository *repo,
+						      const char *key);
+int repo_config_get_string_const(struct repository *repo,
+				 const char *key, const char **dest);
+int repo_config_get_string(struct repository *repo,
+			   const char *key, char **dest);
+int repo_config_get_int(struct repository *repo,
+			const char *key, int *dest);
+int repo_config_get_ulong(struct repository *repo,
+			  const char *key, unsigned long *dest);
+int repo_config_get_bool(struct repository *repo,
+			 const char *key, int *dest);
+int repo_config_get_bool_or_int(struct repository *repo,
+				const char *key, int *is_bool, int *dest);
+int repo_config_get_maybe_bool(struct repository *repo,
 			       const char *key, int *dest);
-extern int repo_config_get_ulong(struct repository *repo,
-				 const char *key, unsigned long *dest);
-extern int repo_config_get_bool(struct repository *repo,
-				const char *key, int *dest);
-extern int repo_config_get_bool_or_int(struct repository *repo,
-				       const char *key, int *is_bool, int *dest);
-extern int repo_config_get_maybe_bool(struct repository *repo,
-				      const char *key, int *dest);
-extern int repo_config_get_pathname(struct repository *repo,
-				    const char *key, const char **dest);
+int repo_config_get_pathname(struct repository *repo,
+			     const char *key, const char **dest);
 
-/*
- * Note: This function exists solely to maintain backward compatibility with
- * 'fetch' and 'update_clone' storing configuration in '.gitmodules' and should
- * NOT be used anywhere else.
- *
- * Runs the provided config function on the '.gitmodules' file found in the
- * working directory.
- */
-extern void config_from_gitmodules(config_fn_t fn, void *data);
-
-extern int git_config_get_value(const char *key, const char **value);
-extern const struct string_list *git_config_get_value_multi(const char *key);
-extern void git_config_clear(void);
-extern int git_config_get_string_const(const char *key, const char **dest);
-extern int git_config_get_string(const char *key, char **dest);
-extern int git_config_get_int(const char *key, int *dest);
-extern int git_config_get_ulong(const char *key, unsigned long *dest);
-extern int git_config_get_bool(const char *key, int *dest);
-extern int git_config_get_bool_or_int(const char *key, int *is_bool, int *dest);
-extern int git_config_get_maybe_bool(const char *key, int *dest);
-extern int git_config_get_pathname(const char *key, const char **dest);
-extern int git_config_get_untracked_cache(void);
-extern int git_config_get_split_index(void);
-extern int git_config_get_max_percent_split_change(void);
-extern int git_config_get_fsmonitor(void);
+/**
+ * Querying For Specific Variables
+ * -------------------------------
+ *
+ * For programs wanting to query for specific variables in a non-callback
+ * manner, the config API provides two functions `git_config_get_value`
+ * and `git_config_get_value_multi`. They both read values from an internal
+ * cache generated previously from reading the config files.
+ */
+
+/**
+ * Finds the highest-priority value for the configuration variable `key`,
+ * stores the pointer to it in `value` and returns 0. When the
+ * configuration variable `key` is not found, returns 1 without touching
+ * `value`. The caller should not free or modify `value`, as it is owned
+ * by the cache.
+ */
+int git_config_get_value(const char *key, const char **value);
+
+/**
+ * Finds and returns the value list, sorted in order of increasing priority
+ * for the configuration variable `key`. When the configuration variable
+ * `key` is not found, returns NULL. The caller should not free or modify
+ * the returned pointer, as it is owned by the cache.
+ */
+const struct string_list *git_config_get_value_multi(const char *key);
+
+/**
+ * Resets and invalidates the config cache.
+ */
+void git_config_clear(void);
+
+/**
+ * Allocates and copies the retrieved string into the `dest` parameter for
+ * the configuration variable `key`; if NULL string is given, prints an
+ * error message and returns -1. When the configuration variable `key` is
+ * not found, returns 1 without touching `dest`.
+ */
+int git_config_get_string_const(const char *key, const char **dest);
+
+/**
+ * Similar to `git_config_get_string_const`, except that retrieved value
+ * copied into the `dest` parameter is a mutable string.
+ */
+int git_config_get_string(const char *key, char **dest);
+
+/**
+ * Finds and parses the value to an integer for the configuration variable
+ * `key`. Dies on error; otherwise, stores the value of the parsed integer in
+ * `dest` and returns 0. When the configuration variable `key` is not found,
+ * returns 1 without touching `dest`.
+ */
+int git_config_get_int(const char *key, int *dest);
+
+/**
+ * Similar to `git_config_get_int` but for unsigned longs.
+ */
+int git_config_get_ulong(const char *key, unsigned long *dest);
+
+/**
+ * Finds and parses the value into a boolean value, for the configuration
+ * variable `key` respecting keywords like "true" and "false". Integer
+ * values are converted into true/false values (when they are non-zero or
+ * zero, respectively). Other values cause a die(). If parsing is successful,
+ * stores the value of the parsed result in `dest` and returns 0. When the
+ * configuration variable `key` is not found, returns 1 without touching
+ * `dest`.
+ */
+int git_config_get_bool(const char *key, int *dest);
+
+/**
+ * Similar to `git_config_get_bool`, except that integers are copied as-is,
+ * and `is_bool` flag is unset.
+ */
+int git_config_get_bool_or_int(const char *key, int *is_bool, int *dest);
+
+/**
+ * Similar to `git_config_get_bool`, except that it returns -1 on error
+ * rather than dying.
+ */
+int git_config_get_maybe_bool(const char *key, int *dest);
+
+/**
+ * Similar to `git_config_get_string`, but expands `~` or `~user` into
+ * the user's home directory when found at the beginning of the path.
+ */
+int git_config_get_pathname(const char *key, const char **dest);
+
+int git_config_get_index_threads(int *dest);
+int git_config_get_untracked_cache(void);
+int git_config_get_split_index(void);
+int git_config_get_max_percent_split_change(void);
+int git_config_get_fsmonitor(void);
 
 /* This dies if the configured or default date is in the future */
-extern int git_config_get_expiry(const char *key, const char **output);
+int git_config_get_expiry(const char *key, const char **output);
 
 /* parse either "this many days" integer, or "5.days.ago" approxidate */
-extern int git_config_get_expiry_in_days(const char *key, timestamp_t *, timestamp_t now);
+int git_config_get_expiry_in_days(const char *key, timestamp_t *, timestamp_t now);
 
 struct key_value_info {
 	const char *filename;
@@ -254,7 +593,23 @@ struct key_value_info {
 	enum config_scope scope;
 };
 
-extern NORETURN void git_die_config(const char *key, const char *err, ...) __attribute__((format(printf, 2, 3)));
-extern NORETURN void git_die_config_linenr(const char *key, const char *filename, int linenr);
+/**
+ * First prints the error message specified by the caller in `err` and then
+ * dies printing the line number and the file name of the highest priority
+ * value for the configuration variable `key`.
+ */
+NORETURN void git_die_config(const char *key, const char *err, ...) __attribute__((format(printf, 2, 3)));
+
+/**
+ * Helper function which formats the die error message according to the
+ * parameters entered. Used by `git_die_config()`. It can be used by callers
+ * handling `git_config_get_value_multi()` to print the correct error message
+ * for the desired value.
+ */
+NORETURN void git_die_config_linenr(const char *key, const char *filename, int linenr);
+
+#define LOOKUP_CONFIG(mapping, var) \
+	lookup_config(mapping, ARRAY_SIZE(mapping), var)
+int lookup_config(const char **mapping, int nr_mapping, const char *var);
 
 #endif /* CONFIG_H */
diff -pruN 1.2.1+git2.18.0-1/git/config.mak.dev 1.2.3+git2.25.1-1/git/config.mak.dev
--- 1.2.1+git2.18.0-1/git/config.mak.dev	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/config.mak.dev	2020-02-17 04:47:35.000000000 +0000
@@ -1,35 +1,41 @@
 ifeq ($(filter no-error,$(DEVOPTS)),)
-CFLAGS += -Werror
+DEVELOPER_CFLAGS += -Werror
 endif
-CFLAGS += -Wdeclaration-after-statement
-CFLAGS += -Wno-format-zero-length
-CFLAGS += -Wold-style-definition
-CFLAGS += -Woverflow
-CFLAGS += -Wpointer-arith
-CFLAGS += -Wstrict-prototypes
-CFLAGS += -Wunused
-CFLAGS += -Wvla
+ifneq ($(filter pedantic,$(DEVOPTS)),)
+DEVELOPER_CFLAGS += -pedantic
+# don't warn for each N_ use
+DEVELOPER_CFLAGS += -DUSE_PARENS_AROUND_GETTEXT_N=0
+endif
+DEVELOPER_CFLAGS += -Wall
+DEVELOPER_CFLAGS += -Wdeclaration-after-statement
+DEVELOPER_CFLAGS += -Wformat-security
+DEVELOPER_CFLAGS += -Wno-format-zero-length
+DEVELOPER_CFLAGS += -Wold-style-definition
+DEVELOPER_CFLAGS += -Woverflow
+DEVELOPER_CFLAGS += -Wpointer-arith
+DEVELOPER_CFLAGS += -Wstrict-prototypes
+DEVELOPER_CFLAGS += -Wunused
+DEVELOPER_CFLAGS += -Wvla
 
 ifndef COMPILER_FEATURES
 COMPILER_FEATURES := $(shell ./detect-compiler $(CC))
 endif
 
 ifneq ($(filter clang4,$(COMPILER_FEATURES)),)
-CFLAGS += -Wtautological-constant-out-of-range-compare
+DEVELOPER_CFLAGS += -Wtautological-constant-out-of-range-compare
 endif
 
 ifneq ($(or $(filter gcc6,$(COMPILER_FEATURES)),$(filter clang4,$(COMPILER_FEATURES))),)
-CFLAGS += -Wextra
+DEVELOPER_CFLAGS += -Wextra
 # if a function is public, there should be a prototype and the right
 # header file should be included. If not, it should be static.
-CFLAGS += -Wmissing-prototypes
+DEVELOPER_CFLAGS += -Wmissing-prototypes
 ifeq ($(filter extra-all,$(DEVOPTS)),)
 # These are disabled because we have these all over the place.
-CFLAGS += -Wno-empty-body
-CFLAGS += -Wno-missing-field-initializers
-CFLAGS += -Wno-sign-compare
-CFLAGS += -Wno-unused-function
-CFLAGS += -Wno-unused-parameter
+DEVELOPER_CFLAGS += -Wno-empty-body
+DEVELOPER_CFLAGS += -Wno-missing-field-initializers
+DEVELOPER_CFLAGS += -Wno-sign-compare
+DEVELOPER_CFLAGS += -Wno-unused-parameter
 endif
 endif
 
@@ -37,6 +43,6 @@ endif
 # not worth fixing since newer compilers correctly stop complaining
 ifneq ($(filter gcc4,$(COMPILER_FEATURES)),)
 ifeq ($(filter gcc5,$(COMPILER_FEATURES)),)
-CFLAGS += -Wno-uninitialized
+DEVELOPER_CFLAGS += -Wno-uninitialized
 endif
 endif
diff -pruN 1.2.1+git2.18.0-1/git/config.mak.uname 1.2.3+git2.25.1-1/git/config.mak.uname
--- 1.2.1+git2.18.0-1/git/config.mak.uname	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/config.mak.uname	2020-02-17 04:47:35.000000000 +0000
@@ -1,5 +1,9 @@
 # Platform specific Makefile tweaks based on uname detection
 
+# Define NO_SAFESEH if you need MSVC/Visual Studio to ignore the lack of
+# Microsoft's Safe Exception Handling in libraries (such as zlib).
+# Typically required for VS2013+/32-bit compilation on Vista+ versions.
+
 uname_S := $(shell sh -c 'uname -s 2>/dev/null || echo not')
 uname_M := $(shell sh -c 'uname -m 2>/dev/null || echo not')
 uname_O := $(shell sh -c 'uname -o 2>/dev/null || echo not')
@@ -11,6 +15,21 @@ ifdef MSVC
 	# avoid the MingW and Cygwin configuration sections
 	uname_S := Windows
 	uname_O := Windows
+
+	# Generate and include makefile variables that point to the
+	# currently installed set of MSVC command line tools.
+compat/vcbuild/MSVC-DEFS-GEN: compat/vcbuild/find_vs_env.bat
+	@"$<" | tr '\\' / >"$@"
+include compat/vcbuild/MSVC-DEFS-GEN
+
+	# See if vcpkg and the vcpkg-build versions of the third-party
+	# libraries that we use are installed.  We include the result
+	# to get $(vcpkg_*) variables defined for the Makefile.
+ifeq (,$(SKIP_VCPKG))
+compat/vcbuild/VCPKG-DEFS: compat/vcbuild/vcpkg_install.bat
+	@"$<"
+include compat/vcbuild/VCPKG-DEFS
+endif
 endif
 
 # We choose to avoid "if .. else if .. else .. endif endif"
@@ -114,6 +133,8 @@ ifeq ($(uname_S),Darwin)
 	HAVE_BSD_SYSCTL = YesPlease
 	FREAD_READS_DIRECTORIES = UnfortunatelyYes
 	HAVE_NS_GET_EXECUTABLE_PATH = YesPlease
+	BASIC_CFLAGS += -I/usr/local/include
+	BASIC_LDFLAGS += -L/usr/local/lib
 endif
 ifeq ($(uname_S),SunOS)
 	NEEDS_SOCKET = YesPlease
@@ -187,12 +208,22 @@ ifeq ($(uname_O),Cygwin)
 	UNRELIABLE_FSTAT = UnfortunatelyYes
 	OBJECT_CREATION_USES_RENAMES = UnfortunatelyNeedsTo
 	MMAP_PREVENTS_DELETE = UnfortunatelyYes
-	COMPAT_OBJS += compat/cygwin.o
+	COMPAT_OBJS += compat/win32/path-utils.o
 	FREAD_READS_DIRECTORIES = UnfortunatelyYes
 endif
 ifeq ($(uname_S),FreeBSD)
 	NEEDS_LIBICONV = YesPlease
-	OLD_ICONV = YesPlease
+	# Versions up to 10.1 require OLD_ICONV; 10.2 and beyond don't.
+	# A typical version string looks like "10.2-RELEASE".
+	ifeq ($(shell expr "$(uname_R)" : '[1-9]\.'),2)
+		OLD_ICONV = YesPlease
+	endif
+	ifeq ($(firstword $(subst -, ,$(uname_R))),10.0)
+		OLD_ICONV = YesPlease
+	endif
+	ifeq ($(firstword $(subst -, ,$(uname_R))),10.1)
+		OLD_ICONV = YesPlease
+	endif
 	NO_MEMMEM = YesPlease
 	BASIC_CFLAGS += -I/usr/local/include
 	BASIC_LDFLAGS += -L/usr/local/lib
@@ -211,6 +242,7 @@ ifeq ($(uname_S),FreeBSD)
 	HAVE_BSD_KERN_PROC_SYSCTL = YesPlease
 	PAGER_ENV = LESS=FRX LV=-c MORE=FRX
 	FREAD_READS_DIRECTORIES = UnfortunatelyYes
+	FILENO_IS_A_MACRO = UnfortunatelyYes
 endif
 ifeq ($(uname_S),OpenBSD)
 	NO_STRCASESTR = YesPlease
@@ -223,6 +255,8 @@ ifeq ($(uname_S),OpenBSD)
 	HAVE_BSD_SYSCTL = YesPlease
 	HAVE_BSD_KERN_PROC_SYSCTL = YesPlease
 	PROCFS_EXECUTABLE_PATH = /proc/curproc/file
+	FREAD_READS_DIRECTORIES = UnfortunatelyYes
+	FILENO_IS_A_MACRO = UnfortunatelyYes
 endif
 ifeq ($(uname_S),MirBSD)
 	NO_STRCASESTR = YesPlease
@@ -256,6 +290,8 @@ ifeq ($(uname_S),AIX)
 	INTERNAL_QSORT = UnfortunatelyYes
 	NEEDS_LIBICONV = YesPlease
 	BASIC_CFLAGS += -D_LARGE_FILES
+	FILENO_IS_A_MACRO = UnfortunatelyYes
+	NEED_ACCESS_ROOT_HANDLER = UnfortunatelyYes
 	ifeq ($(shell expr "$(uname_V)" : '[1234]'),1)
 		NO_PTHREADS = YesPlease
 	else
@@ -339,6 +375,19 @@ endif
 ifeq ($(uname_S),Windows)
 	GIT_VERSION := $(GIT_VERSION).MSVC
 	pathsep = ;
+	# Assume that this is built in Git for Windows' SDK
+	ifeq (MINGW32,$(MSYSTEM))
+		prefix = /mingw32
+	else
+		prefix = /mingw64
+	endif
+	# Prepend MSVC 64-bit tool-chain to PATH.
+	#
+	# A regular Git Bash *does not* have cl.exe in its $PATH. As there is a
+	# link.exe next to, and required by, cl.exe, we have to prepend this
+	# onto the existing $PATH.
+	#
+	SANE_TOOL_PATH ?= $(msvc_bin_dir_msys)
 	HAVE_ALLOCA_H = YesPlease
 	NO_PREAD = YesPlease
 	NEEDS_CRYPTO_WITH_SSL = YesPlease
@@ -351,16 +400,18 @@ ifeq ($(uname_S),Windows)
 	NO_STRCASESTR = YesPlease
 	NO_STRLCPY = YesPlease
 	NO_MEMMEM = YesPlease
-	# NEEDS_LIBICONV = YesPlease
-	NO_ICONV = YesPlease
+	NEEDS_LIBICONV = YesPlease
 	NO_STRTOUMAX = YesPlease
 	NO_MKDTEMP = YesPlease
-	SNPRINTF_RETURNS_BOGUS = YesPlease
+	NO_INTTYPES_H = YesPlease
+	# VS2015 with UCRT claims that snprintf and friends are C99 compliant,
+	# so we don't need this:
+	#
+	#   SNPRINTF_RETURNS_BOGUS = YesPlease
 	NO_SVN_TESTS = YesPlease
 	RUNTIME_PREFIX = YesPlease
 	HAVE_WPGMPTR = YesWeDo
 	NO_ST_BLOCKS_IN_STRUCT_STAT = YesPlease
-	NO_NSEC = YesPlease
 	USE_WIN32_MMAP = YesPlease
 	MMAP_PREVENTS_DELETE = UnfortunatelyYes
 	# USE_NED_ALLOCATOR = YesPlease
@@ -369,10 +420,7 @@ ifeq ($(uname_S),Windows)
 	NO_REGEX = YesPlease
 	NO_GETTEXT = YesPlease
 	NO_PYTHON = YesPlease
-	BLK_SHA1 = YesPlease
 	ETAGS_TARGET = ETAGS
-	NO_INET_PTON = YesPlease
-	NO_INET_NTOP = YesPlease
 	NO_POSIX_GOODIES = UnfortunatelyYes
 	NATIVE_CRLF = YesPlease
 	DEFAULT_HELP_FORMAT = html
@@ -380,24 +428,51 @@ ifeq ($(uname_S),Windows)
 	CC = compat/vcbuild/scripts/clink.pl
 	AR = compat/vcbuild/scripts/lib.pl
 	CFLAGS =
-	BASIC_CFLAGS = -nologo -I. -I../zlib -Icompat/vcbuild -Icompat/vcbuild/include -DWIN32 -D_CONSOLE -DHAVE_STRING_H -D_CRT_SECURE_NO_WARNINGS -D_CRT_NONSTDC_NO_DEPRECATE
+	BASIC_CFLAGS = -nologo -I. -Icompat/vcbuild/include -DWIN32 -D_CONSOLE -DHAVE_STRING_H -D_CRT_SECURE_NO_WARNINGS -D_CRT_NONSTDC_NO_DEPRECATE
 	COMPAT_OBJS = compat/msvc.o compat/winansi.o \
+		compat/win32/path-utils.o \
 		compat/win32/pthread.o compat/win32/syslog.o \
+		compat/win32/trace2_win32_process_info.o \
 		compat/win32/dirent.o
-	COMPAT_CFLAGS = -D__USE_MINGW_ACCESS -DNOGDI -DHAVE_STRING_H -Icompat -Icompat/regex -Icompat/win32 -DSTRIP_EXTENSION=\".exe\"
-	BASIC_LDFLAGS = -IGNORE:4217 -IGNORE:4049 -NOLOGO -SUBSYSTEM:CONSOLE
-	EXTLIBS = user32.lib advapi32.lib shell32.lib wininet.lib ws2_32.lib invalidcontinue.obj
+	COMPAT_CFLAGS = -D__USE_MINGW_ACCESS -DDETECT_MSYS_TTY -DNOGDI -DHAVE_STRING_H -Icompat -Icompat/regex -Icompat/win32 -DSTRIP_EXTENSION=\".exe\"
+	BASIC_LDFLAGS = -IGNORE:4217 -IGNORE:4049 -NOLOGO -ENTRY:wmainCRTStartup -SUBSYSTEM:CONSOLE
+	# invalidcontinue.obj allows Git's source code to close the same file
+	# handle twice, or to access the osfhandle of an already-closed stdout
+	# See https://msdn.microsoft.com/en-us/library/ms235330.aspx
+	EXTLIBS = user32.lib advapi32.lib shell32.lib wininet.lib ws2_32.lib invalidcontinue.obj kernel32.lib ntdll.lib
 	PTHREAD_LIBS =
 	lib =
-	BASIC_CFLAGS += -DPROTECT_NTFS_DEFAULT=1
+	BASIC_CFLAGS += $(vcpkg_inc) $(sdk_includes) $(msvc_includes)
+ifndef DEBUG
+	BASIC_CFLAGS += $(vcpkg_rel_lib)
+else
+	BASIC_CFLAGS += $(vcpkg_dbg_lib)
+endif
+	BASIC_CFLAGS += $(sdk_libs) $(msvc_libs)
+
+ifneq ($(USE_MSVC_CRTDBG),)
+	# Optionally enable memory leak reporting.
+	BASIC_CFLAGS += -DUSE_MSVC_CRTDBG
+endif
+	# Always give "-Zi" to the compiler and "-debug" to linker (even in
+	# release mode) to force a PDB to be generated (like RelWithDebInfo).
+	BASIC_CFLAGS += -Zi
+	BASIC_LDFLAGS += -debug -Zf
+
+ifdef NO_SAFESEH
+	LDFLAGS += -SAFESEH:NO
+endif
+
 ifndef DEBUG
-	BASIC_CFLAGS += -GL -Os -MD
-	BASIC_LDFLAGS += -LTCG
+	BASIC_CFLAGS += -GL -Gy -O2 -Oy- -MD -DNDEBUG
+	BASIC_LDFLAGS += -release -LTCG /OPT:REF /OPT:ICF /INCREMENTAL:NO /DEBUGTYPE:CV,FIXUP
 	AR += -LTCG
 else
-	BASIC_CFLAGS += -Zi -MDd
+	BASIC_CFLAGS += -MDd -DDEBUG -D_DEBUG
 endif
 	X = .exe
+
+compat/msvc.o: compat/msvc.c compat/mingw.c GIT-CFLAGS
 endif
 ifeq ($(uname_S),Interix)
 	NO_INITGROUPS = YesPlease
@@ -423,8 +498,6 @@ ifeq ($(uname_S),Minix)
 	NO_NSEC = YesPlease
 	NEEDS_LIBGEN =
 	NEEDS_CRYPTO_WITH_SSL = YesPlease
-	NEEDS_IDN_WITH_CURL = YesPlease
-	NEEDS_SSL_WITH_CURL = YesPlease
 	NEEDS_RESOLV =
 	NO_HSTRERROR = YesPlease
 	NO_MMAP = YesPlease
@@ -436,27 +509,43 @@ ifeq ($(uname_S),NONSTOP_KERNEL)
 	# INLINE='' would just replace one set of warnings with another and
 	# still not compile in c89 mode, due to non-const array initializations.
 	CC = cc -c99
+	# Build down-rev compatible objects that don't use our new getopt_long.
+	ifeq ($(uname_R).$(uname_V),J06.21)
+		CC += -WRVU=J06.20
+	endif
+	ifeq ($(uname_R).$(uname_V),L17.02)
+		CC += -WRVU=L16.05
+	endif
 	# Disable all optimization, seems to result in bad code, with -O or -O2
 	# or even -O1 (default), /usr/local/libexec/git-core/git-pack-objects
 	# abends on "git push". Needs more investigation.
-	CFLAGS = -g -O0
+	CFLAGS = -g -O0 -Winline
 	# We'd want it to be here.
 	prefix = /usr/local
-	# Our's are in ${prefix}/bin (perl might also be in /usr/bin/perl).
-	PERL_PATH = ${prefix}/bin/perl
-	PYTHON_PATH = ${prefix}/bin/python
-
+	# perl and python must be in /usr/bin on NonStop - supplied by HPE
+	# with operating system in that managed directory.
+	PERL_PATH = /usr/bin/perl
+	PYTHON_PATH = /usr/bin/python
+	# The current /usr/coreutils/rm at lowest support level does not work
+	# with the git test structure. Long paths as in
+	# 'trash directory...' cause rm to terminate prematurely without fully
+	# removing the directory at OS releases J06.21 and L17.02.
+	# Default to the older rm until those two releases are deprecated.
+	RM = /bin/rm -f
 	# As detected by './configure'.
 	# Missdetected, hence commented out, see below.
 	#NO_CURL = YesPlease
 	# Added manually, see above.
 	NEEDS_SSL_WITH_CURL = YesPlease
+	NEEDS_CRYPTO_WITH_SSL = YesPlease
+	HAVE_DEV_TTY = YesPlease
 	HAVE_LIBCHARSET_H = YesPlease
 	HAVE_STRINGS_H = YesPlease
 	NEEDS_LIBICONV = YesPlease
 	NEEDS_LIBINTL_BEFORE_LIBICONV = YesPlease
 	NO_SYS_SELECT_H = UnfortunatelyYes
 	NO_D_TYPE_IN_DIRENT = YesPlease
+	NO_GETTEXT = YesPlease
 	NO_HSTRERROR = YesPlease
 	NO_STRCASESTR = YesPlease
 	NO_MEMMEM = YesPlease
@@ -466,8 +555,9 @@ ifeq ($(uname_S),NONSTOP_KERNEL)
 	NO_MKDTEMP = YesPlease
 	# Currently libiconv-1.9.1.
 	OLD_ICONV = UnfortunatelyYes
-	NO_REGEX = YesPlease
+	NO_REGEX = NeedsStartEnd
 	NO_PTHREADS = UnfortunatelyYes
+	FREAD_READS_DIRECTORIES = UnfortunatelyYes
 
 	# Not detected (nor checked for) by './configure'.
 	# We don't have SA_RESTART on NonStop, unfortunalety.
@@ -485,9 +575,7 @@ ifeq ($(uname_S),NONSTOP_KERNEL)
 	# RFE 10-120912-4693 submitted to HP NonStop development.
 	NO_SETITIMER = UnfortunatelyYes
 	SANE_TOOL_PATH = /usr/coreutils/bin:/usr/local/bin
-	SHELL_PATH = /usr/local/bin/bash
-	# as of H06.25/J06.14, we might better use this
-	#SHELL_PATH = /usr/coreutils/bin/bash
+	SHELL_PATH = /usr/coreutils/bin/bash
 endif
 ifneq (,$(findstring MINGW,$(uname_S)))
 	pathsep = ;
@@ -506,11 +594,9 @@ ifneq (,$(findstring MINGW,$(uname_S)))
 	NO_STRTOUMAX = YesPlease
 	NO_MKDTEMP = YesPlease
 	NO_SVN_TESTS = YesPlease
-	NO_PERL_MAKEMAKER = YesPlease
 	RUNTIME_PREFIX = YesPlease
 	HAVE_WPGMPTR = YesWeDo
 	NO_ST_BLOCKS_IN_STRUCT_STAT = YesPlease
-	NO_NSEC = YesPlease
 	USE_WIN32_MMAP = YesPlease
 	MMAP_PREVENTS_DELETE = UnfortunatelyYes
 	USE_NED_ALLOCATOR = YesPlease
@@ -519,23 +605,23 @@ ifneq (,$(findstring MINGW,$(uname_S)))
 	NO_REGEX = YesPlease
 	NO_PYTHON = YesPlease
 	ETAGS_TARGET = ETAGS
-	NO_INET_PTON = YesPlease
-	NO_INET_NTOP = YesPlease
 	NO_POSIX_GOODIES = UnfortunatelyYes
 	DEFAULT_HELP_FORMAT = html
+	BASIC_LDFLAGS += -municode
 	COMPAT_CFLAGS += -DNOGDI -Icompat -Icompat/win32
 	COMPAT_CFLAGS += -DSTRIP_EXTENSION=\".exe\"
 	COMPAT_OBJS += compat/mingw.o compat/winansi.o \
+		compat/win32/trace2_win32_process_info.o \
+		compat/win32/path-utils.o \
 		compat/win32/pthread.o compat/win32/syslog.o \
 		compat/win32/dirent.o
-	BASIC_CFLAGS += -DPROTECT_NTFS_DEFAULT=1
+	BASIC_CFLAGS += -DWIN32
 	EXTLIBS += -lws2_32
 	GITLIBS += git.res
 	PTHREAD_LIBS =
 	RC = windres -O coff
 	NATIVE_CRLF = YesPlease
 	X = .exe
-	SPARSE_FLAGS = -Wno-one-bit-signed-bitfield
 ifneq (,$(wildcard ../THIS_IS_MSYSGIT))
 	htmldir = doc/git/html/
 	prefix =
@@ -545,22 +631,33 @@ ifneq (,$(wildcard ../THIS_IS_MSYSGIT))
 	INTERNAL_QSORT = YesPlease
 	HAVE_LIBCHARSET_H = YesPlease
 	NO_GETTEXT = YesPlease
-	COMPAT_CLFAGS += -D__USE_MINGW_ACCESS
+	COMPAT_CFLAGS += -D__USE_MINGW_ACCESS
 else
-	ifeq ($(shell expr "$(uname_R)" : '2\.'),2)
+	ifneq ($(shell expr "$(uname_R)" : '1\.'),2)
 		# MSys2
 		prefix = /usr/
+		# Enable DEP
+		BASIC_LDFLAGS += -Wl,--nxcompat
+		# Enable ASLR (unless debugging)
+		ifneq (,$(findstring -O,$(filter-out -O0 -Og,$(CFLAGS))))
+			BASIC_LDFLAGS += -Wl,--dynamicbase
+		endif
 		ifeq (MINGW32,$(MSYSTEM))
 			prefix = /mingw32
+			HOST_CPU = i686
+			BASIC_LDFLAGS += -Wl,--pic-executable,-e,_mainCRTStartup
 		endif
 		ifeq (MINGW64,$(MSYSTEM))
 			prefix = /mingw64
+			HOST_CPU = x86_64
+			BASIC_LDFLAGS += -Wl,--pic-executable,-e,mainCRTStartup
 		else
 			COMPAT_CFLAGS += -D_USE_32BIT_TIME_T
 			BASIC_LDFLAGS += -Wl,--large-address-aware
 		endif
 		CC = gcc
-		COMPAT_CFLAGS += -D__USE_MINGW_ANSI_STDIO=0 -DDETECT_MSYS_TTY
+		COMPAT_CFLAGS += -D__USE_MINGW_ANSI_STDIO=0 -DDETECT_MSYS_TTY \
+			-fstack-protector-strong
 		EXTLIBS += -lntdll
 		INSTALL = /bin/install
 		NO_R_TO_GCC_LINKER = YesPlease
@@ -593,3 +690,84 @@ ifeq ($(uname_S),QNX)
 	NO_STRCASESTR = YesPlease
 	NO_STRLCPY = YesPlease
 endif
+
+vcxproj:
+	# Require clean work tree
+	git update-index -q --refresh && \
+	git diff-files --quiet && \
+	git diff-index --cached --quiet HEAD --
+
+	# Make .vcxproj files and add them
+	unset QUIET_GEN QUIET_BUILT_IN; \
+	perl contrib/buildsystems/generate -g Vcxproj
+	git add -f git.sln {*,*/lib,t/helper/*}/*.vcxproj
+
+	# Generate the LinkOrCopyBuiltins.targets and LinkOrCopyRemoteHttp.targets file
+	(echo '<Project xmlns="http://schemas.microsoft.com/developer/msbuild/2003">' && \
+	 echo '  <Target Name="CopyBuiltins_AfterBuild" AfterTargets="AfterBuild">' && \
+	 for name in $(BUILT_INS);\
+	 do \
+	   echo '    <Copy SourceFiles="$$(OutDir)\git.exe" DestinationFiles="$$(OutDir)\'"$$name"'" SkipUnchangedFiles="true" UseHardlinksIfPossible="true" />'; \
+	 done && \
+	 echo '  </Target>' && \
+	 echo '</Project>') >git/LinkOrCopyBuiltins.targets
+	(echo '<Project xmlns="http://schemas.microsoft.com/developer/msbuild/2003">' && \
+	 echo '  <Target Name="CopyBuiltins_AfterBuild" AfterTargets="AfterBuild">' && \
+	 for name in $(REMOTE_CURL_ALIASES); \
+	 do \
+	   echo '    <Copy SourceFiles="$$(OutDir)\'"$(REMOTE_CURL_PRIMARY)"'" DestinationFiles="$$(OutDir)\'"$$name"'" SkipUnchangedFiles="true" UseHardlinksIfPossible="true" />'; \
+	 done && \
+	 echo '  </Target>' && \
+	 echo '</Project>') >git-remote-http/LinkOrCopyRemoteHttp.targets
+	git add -f git/LinkOrCopyBuiltins.targets git-remote-http/LinkOrCopyRemoteHttp.targets
+
+	# Add command-list.h
+	$(MAKE) MSVC=1 SKIP_VCPKG=1 prefix=/mingw64 command-list.h
+	git add -f command-list.h
+
+	# Add scripts
+	rm -f perl/perl.mak
+	$(MAKE) MSVC=1 SKIP_VCPKG=1 prefix=/mingw64 $(SCRIPT_LIB) $(SCRIPTS)
+	# Strip out the sane tool path, needed only for building
+	sed -i '/^git_broken_path_fix ".*/d' git-sh-setup
+	git add -f $(SCRIPT_LIB) $(SCRIPTS)
+
+	# Add Perl module
+	$(MAKE) $(LIB_PERL_GEN)
+	git add -f perl/build
+
+	# Add bin-wrappers, for testing
+	rm -rf bin-wrappers/
+	$(MAKE) MSVC=1 SKIP_VCPKG=1 prefix=/mingw64 $(test_bindir_programs)
+	# Ensure that the GIT_EXEC_PATH is a Unix-y one, and that the absolute
+	# path of the repository is not hard-coded (GIT_EXEC_PATH will be set
+	# by test-lib.sh according to the current setup)
+	sed -i -e 's/^\(GIT_EXEC_PATH\)=.*/test -n "$${\1##*:*}" ||\
+			\1="$$(cygpath -u "$$\1")"/' \
+		-e "s|'$$(pwd)|\"\$$GIT_EXEC_PATH\"'|g" bin-wrappers/*
+	# Ensure that test-* helpers find the .dll files copied to top-level
+	sed -i 's|^PATH=.*|&:"$$GIT_EXEC_PATH"|' bin-wrappers/test-*
+	# We do not want to force hard-linking builtins
+	sed -i 's|\(git\)-\([-a-z]*\)\.exe"|\1.exe" \2|g' \
+		bin-wrappers/git-{receive-pack,upload-archive}
+	git add -f $(test_bindir_programs)
+	# remote-ext is a builtin, but invoked as if it were external
+	sed 's|receive-pack|remote-ext|g' \
+		<bin-wrappers/git-receive-pack >bin-wrappers/git-remote-ext
+	git add -f bin-wrappers/git-remote-ext
+
+	# Add templates
+	$(MAKE) -C templates
+	git add -f templates/boilerplates.made templates/blt/
+
+	# Add the translated messages
+	make MSVC=1 SKIP_VCPKG=1 prefix=/mingw64 $(MOFILES)
+	git add -f $(MOFILES)
+
+	# Add build options
+	$(MAKE) MSVC=1 SKIP_VCPKG=1 prefix=/mingw64 GIT-BUILD-OPTIONS
+	git add -f GIT-BUILD-OPTIONS
+
+	# Commit the whole shebang
+	git commit -m "Generate Visual Studio solution" \
+		-m "Auto-generated by \`$(MAKE)$(MAKEFLAGS) $@\`"
diff -pruN 1.2.1+git2.18.0-1/git/configure 1.2.3+git2.25.1-1/git/configure
--- 1.2.1+git2.18.0-1/git/configure	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/configure	2020-02-17 04:47:36.000000000 +0000
@@ -1,6 +1,6 @@
 #! /bin/sh
 # Guess values for system-dependent variables and create Makefiles.
-# Generated by GNU Autoconf 2.69 for git 2.18.0.
+# Generated by GNU Autoconf 2.69 for git 2.25.1.
 #
 # Report bugs to <git@vger.kernel.org>.
 #
@@ -580,8 +580,8 @@ MAKEFLAGS=
 # Identity of this package.
 PACKAGE_NAME='git'
 PACKAGE_TARNAME='git'
-PACKAGE_VERSION='2.18.0'
-PACKAGE_STRING='git 2.18.0'
+PACKAGE_VERSION='2.25.1'
+PACKAGE_STRING='git 2.25.1'
 PACKAGE_BUGREPORT='git@vger.kernel.org'
 PACKAGE_URL=''
 
@@ -1265,7 +1265,7 @@ if test "$ac_init_help" = "long"; then
   # Omit some internal or obsolete options to make the list less imposing.
   # This message is too long to be a string in the A/UX 3.1 sh.
   cat <<_ACEOF
-\`configure' configures git 2.18.0 to adapt to many kinds of systems.
+\`configure' configures git 2.25.1 to adapt to many kinds of systems.
 
 Usage: $0 [OPTION]... [VAR=VALUE]...
 
@@ -1327,7 +1327,7 @@ fi
 
 if test -n "$ac_init_help"; then
   case $ac_init_help in
-     short | recursive ) echo "Configuration of git 2.18.0:";;
+     short | recursive ) echo "Configuration of git 2.25.1:";;
    esac
   cat <<\_ACEOF
 
@@ -1472,7 +1472,7 @@ fi
 test -n "$ac_init_help" && exit $ac_status
 if $ac_init_version; then
   cat <<\_ACEOF
-git configure 2.18.0
+git configure 2.25.1
 generated by GNU Autoconf 2.69
 
 Copyright (C) 2012 Free Software Foundation, Inc.
@@ -1952,7 +1952,7 @@ cat >config.log <<_ACEOF
 This file contains any messages produced by compilers while
 running configure, to aid debugging if configure makes a mistake.
 
-It was created by git $as_me 2.18.0, which was
+It was created by git $as_me 2.25.1, which was
 generated by GNU Autoconf 2.69.  Invocation command line was
 
   $ $0 $@
@@ -4739,9 +4739,44 @@ $as_echo "$git_cv_ld_rpath" >&6; }
       if test "$git_cv_ld_rpath" = "yes"; then
          CC_LD_DYNPATH=-rpath
       else
-         CC_LD_DYNPATH=
-         { $as_echo "$as_me:${as_lineno-$LINENO}: WARNING: linker does not support runtime path to dynamic libraries" >&5
+         { $as_echo "$as_me:${as_lineno-$LINENO}: checking if linker supports -Wl,+b," >&5
+$as_echo_n "checking if linker supports -Wl,+b,... " >&6; }
+if ${git_cv_ld_wl_b+:} false; then :
+  $as_echo_n "(cached) " >&6
+else
+
+            SAVE_LDFLAGS="${LDFLAGS}"
+            LDFLAGS="${SAVE_LDFLAGS} -Wl,+b,/"
+            cat confdefs.h - <<_ACEOF >conftest.$ac_ext
+/* end confdefs.h.  */
+
+int
+main ()
+{
+
+  ;
+  return 0;
+}
+_ACEOF
+if ac_fn_c_try_link "$LINENO"; then :
+  git_cv_ld_wl_b=yes
+else
+  git_cv_ld_wl_b=no
+fi
+rm -f core conftest.err conftest.$ac_objext \
+    conftest$ac_exeext conftest.$ac_ext
+            LDFLAGS="${SAVE_LDFLAGS}"
+
+fi
+{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $git_cv_ld_wl_b" >&5
+$as_echo "$git_cv_ld_wl_b" >&6; }
+         if test "$git_cv_ld_wl_b" = "yes"; then
+            CC_LD_DYNPATH=-Wl,+b,
+          else
+             CC_LD_DYNPATH=
+             { $as_echo "$as_me:${as_lineno-$LINENO}: WARNING: linker does not support runtime path to dynamic libraries" >&5
 $as_echo "$as_me: WARNING: linker does not support runtime path to dynamic libraries" >&2;}
+          fi
       fi
    fi
 fi
@@ -5421,21 +5456,16 @@ fi
 if test $CURL_CONFIG != no; then
 
 config_appended_defs="$config_appended_defs${newline}CURL_CONFIG=${CURL_CONFIG}"
-    if test -z "${NO_OPENSSL}"; then
-      { $as_echo "$as_me:${as_lineno-$LINENO}: checking if Curl supports SSL" >&5
-$as_echo_n "checking if Curl supports SSL... " >&6; }
-      if test $(curl-config --features|grep SSL) = SSL; then
-         NEEDS_SSL_WITH_CURL=YesPlease
-         { $as_echo "$as_me:${as_lineno-$LINENO}: result: yes" >&5
-$as_echo "yes" >&6; }
-      else
-         NEEDS_SSL_WITH_CURL=
-         { $as_echo "$as_me:${as_lineno-$LINENO}: result: no" >&5
-$as_echo "no" >&6; }
-      fi
 
-config_appended_defs="$config_appended_defs${newline}NEEDS_SSL_WITH_CURL=${NEEDS_SSL_WITH_CURL}"
+    if test -z "$CURL_CONFIG_OPTS"; then
+        CURL_CONFIG_OPTS="--libs"
     fi
+
+    CURL_LDFLAGS=$($CURL_CONFIG $CURL_CONFIG_OPTS)
+    { $as_echo "$as_me:${as_lineno-$LINENO}: Setting CURL_LDFLAGS to '$CURL_LDFLAGS'" >&5
+$as_echo "$as_me: Setting CURL_LDFLAGS to '$CURL_LDFLAGS'" >&6;}
+
+config_appended_defs="$config_appended_defs${newline}CURL_LDFLAGS=$CURL_LDFLAGS"
 fi
 
 fi
@@ -5914,48 +5944,37 @@ fi
 config_appended_defs="$config_appended_defs${newline}NEEDS_LIBGEN=${NEEDS_LIBGEN}"
 test -n "$NEEDS_LIBGEN" && LIBS="$LIBS -lgen"
 
-{ $as_echo "$as_me:${as_lineno-$LINENO}: checking for gettext in -lc" >&5
-$as_echo_n "checking for gettext in -lc... " >&6; }
-if ${ac_cv_lib_c_gettext+:} false; then :
-  $as_echo_n "(cached) " >&6
-else
-  ac_check_lib_save_LIBS=$LIBS
-LIBS="-lc  $LIBS"
+
+
+{ $as_echo "$as_me:${as_lineno-$LINENO}: checking if libc contains libintl" >&5
+$as_echo_n "checking if libc contains libintl... " >&6; }
 cat confdefs.h - <<_ACEOF >conftest.$ac_ext
 /* end confdefs.h.  */
 
-/* Override any GCC internal prototype to avoid an error.
-   Use char because int might match the return type of a GCC
-   builtin and then its argument prototype would still apply.  */
-#ifdef __cplusplus
-extern "C"
-#endif
-char gettext ();
+
+#include <libintl.h>
+
 int
 main ()
 {
-return gettext ();
+
+char *msg = gettext("test");
+
   ;
   return 0;
 }
 _ACEOF
 if ac_fn_c_try_link "$LINENO"; then :
-  ac_cv_lib_c_gettext=yes
+  { $as_echo "$as_me:${as_lineno-$LINENO}: result: yes" >&5
+$as_echo "yes" >&6; }
+	LIBC_CONTAINS_LIBINTL=YesPlease
 else
-  ac_cv_lib_c_gettext=no
+  { $as_echo "$as_me:${as_lineno-$LINENO}: result: no" >&5
+$as_echo "no" >&6; }
+	LIBC_CONTAINS_LIBINTL=
 fi
 rm -f core conftest.err conftest.$ac_objext \
     conftest$ac_exeext conftest.$ac_ext
-LIBS=$ac_check_lib_save_LIBS
-fi
-{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $ac_cv_lib_c_gettext" >&5
-$as_echo "$ac_cv_lib_c_gettext" >&6; }
-if test "x$ac_cv_lib_c_gettext" = xyes; then :
-  LIBC_CONTAINS_LIBINTL=YesPlease
-else
-  LIBC_CONTAINS_LIBINTL=
-fi
-
 
 config_appended_defs="$config_appended_defs${newline}LIBC_CONTAINS_LIBINTL=${LIBC_CONTAINS_LIBINTL}"
 
@@ -5993,6 +6012,18 @@ fi
 
 config_appended_defs="$config_appended_defs${newline}NO_SYS_SELECT_H=${NO_SYS_SELECT_H}"
 #
+# Define NO_POLL_H if you don't have poll.h
+ac_fn_c_check_header_mongrel "$LINENO" "poll.h" "ac_cv_header_poll_h" "$ac_includes_default"
+if test "x$ac_cv_header_poll_h" = xyes; then :
+  NO_POLL_H=
+else
+  NO_POLL_H=UnfortunatelyYes
+fi
+
+
+
+config_appended_defs="$config_appended_defs${newline}NO_POLL_H=${NO_POLL_H}"
+#
 # Define NO_SYS_POLL_H if you don't have sys/poll.h
 ac_fn_c_check_header_mongrel "$LINENO" "sys/poll.h" "ac_cv_header_sys_poll_h" "$ac_includes_default"
 if test "x$ac_cv_header_sys_poll_h" = xyes; then :
@@ -6056,6 +6087,8 @@ $as_echo "no" >&6; }
 else
   { $as_echo "$as_me:${as_lineno-$LINENO}: result: yes" >&5
 $as_echo "yes" >&6; }
+	$as_echo "#define HAVE_OLD_ICONV 1" >>confdefs.h
+
 	OLD_ICONV=UnfortunatelyYes
 fi
 rm -f core conftest.err conftest.$ac_objext conftest.$ac_ext
@@ -6070,6 +6103,82 @@ fi
 
 config_appended_defs="$config_appended_defs${newline}OLD_ICONV=${OLD_ICONV}"
 
+#
+# Define ICONV_OMITS_BOM if you are on a system which
+# iconv omits bom for utf-{16,32}
+if test -z "$NO_ICONV"; then
+{ $as_echo "$as_me:${as_lineno-$LINENO}: checking whether iconv omits bom for utf-16 and utf-32" >&5
+$as_echo_n "checking whether iconv omits bom for utf-16 and utf-32... " >&6; }
+if ${ac_cv_iconv_omits_bom+:} false; then :
+  $as_echo_n "(cached) " >&6
+else
+
+old_LIBS="$LIBS"
+if test -n "$NEEDS_LIBICONV"; then
+	LIBS="$LIBS -liconv"
+fi
+
+if test "$cross_compiling" = yes; then :
+  { { $as_echo "$as_me:${as_lineno-$LINENO}: error: in \`$ac_pwd':" >&5
+$as_echo "$as_me: error: in \`$ac_pwd':" >&2;}
+as_fn_error $? "cannot run test program while cross compiling
+See \`config.log' for more details" "$LINENO" 5; }
+else
+  cat confdefs.h - <<_ACEOF >conftest.$ac_ext
+/* end confdefs.h.  */
+$ac_includes_default
+	#include <iconv.h>
+	#ifdef HAVE_OLD_ICONV
+	typedef const char *iconv_ibp;
+	#else
+	typedef char *iconv_ibp;
+	#endif
+
+int
+main ()
+{
+
+	int v;
+	iconv_t conv;
+	char in[] = "a"; iconv_ibp pin = in;
+	char out[20] = ""; char *pout = out;
+	size_t isz = sizeof in;
+	size_t osz = sizeof out;
+
+	conv = iconv_open("UTF-16", "UTF-8");
+	iconv(conv, &pin, &isz, &pout, &osz);
+	iconv_close(conv);
+	v = (unsigned char)(out[0]) + (unsigned char)(out[1]);
+	return v != 0xfe + 0xff;
+
+  ;
+  return 0;
+}
+_ACEOF
+if ac_fn_c_try_run "$LINENO"; then :
+  ac_cv_iconv_omits_bom=no
+else
+  ac_cv_iconv_omits_bom=yes
+fi
+rm -f core *.core core.conftest.* gmon.out bb.out conftest$ac_exeext \
+  conftest.$ac_objext conftest.beam conftest.$ac_ext
+fi
+
+
+LIBS="$old_LIBS"
+
+fi
+{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $ac_cv_iconv_omits_bom" >&5
+$as_echo "$ac_cv_iconv_omits_bom" >&6; }
+if test "x$ac_cv_iconv_omits_bom" = xyes; then
+	ICONV_OMITS_BOM=Yes
+else
+	ICONV_OMITS_BOM=
+fi
+
+config_appended_defs="$config_appended_defs${newline}ICONV_OMITS_BOM=${ICONV_OMITS_BOM}"
+fi
+
 ## Checks for typedefs, structures, and compiler characteristics.
 { $as_echo "$as_me:${as_lineno-$LINENO}: CHECKS for typedefs, structures, and compiler characteristics" >&5
 $as_echo "$as_me: CHECKS for typedefs, structures, and compiler characteristics" >&6;}
@@ -8251,7 +8360,7 @@ cat >>$CONFIG_STATUS <<\_ACEOF || ac_wri
 # report actual input values of CONFIG_FILES etc. instead of their
 # values after options handling.
 ac_log="
-This file was extended by git $as_me 2.18.0, which was
+This file was extended by git $as_me 2.25.1, which was
 generated by GNU Autoconf 2.69.  Invocation command line was
 
   CONFIG_FILES    = $CONFIG_FILES
@@ -8308,7 +8417,7 @@ _ACEOF
 cat >>$CONFIG_STATUS <<_ACEOF || ac_write_fail=1
 ac_cs_config="`$as_echo "$ac_configure_args" | sed 's/^ //; s/[\\""\`\$]/\\\\&/g'`"
 ac_cs_version="\\
-git config.status 2.18.0
+git config.status 2.25.1
 configured by $0, generated by GNU Autoconf 2.69,
   with options \\"\$ac_cs_config\\"
 
diff -pruN 1.2.1+git2.18.0-1/git/configure.ac 1.2.3+git2.25.1-1/git/configure.ac
--- 1.2.1+git2.18.0-1/git/configure.ac	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/configure.ac	2020-02-17 04:47:35.000000000 +0000
@@ -85,7 +85,7 @@ AC_DEFUN([GIT_PARSE_WITH],
 
 # GIT_PARSE_WITH_SET_MAKE_VAR(WITHNAME, VAR, HELP_TEXT)
 # -----------------------------------------------------
-# Set VAR to the value specied by --with-WITHNAME.
+# Set VAR to the value specified by --with-WITHNAME.
 # No verification of arguments is performed, but warnings are issued
 # if either 'yes' or 'no' is specified.
 # HELP_TEXT is presented when --help is called.
@@ -475,8 +475,18 @@ else
       if test "$git_cv_ld_rpath" = "yes"; then
          CC_LD_DYNPATH=-rpath
       else
-         CC_LD_DYNPATH=
-         AC_MSG_WARN([linker does not support runtime path to dynamic libraries])
+         AC_CACHE_CHECK([if linker supports -Wl,+b,], git_cv_ld_wl_b, [
+            SAVE_LDFLAGS="${LDFLAGS}"
+            LDFLAGS="${SAVE_LDFLAGS} -Wl,+b,/"
+            AC_LINK_IFELSE([AC_LANG_PROGRAM([], [])], [git_cv_ld_wl_b=yes], [git_cv_ld_wl_b=no])
+            LDFLAGS="${SAVE_LDFLAGS}"
+         ])
+         if test "$git_cv_ld_wl_b" = "yes"; then
+            CC_LD_DYNPATH=-Wl,+b,
+          else
+             CC_LD_DYNPATH=
+             AC_MSG_WARN([linker does not support runtime path to dynamic libraries])
+          fi
       fi
    fi
 fi
@@ -600,17 +610,14 @@ AC_CHECK_PROG([CURL_CONFIG], [curl-confi
 
 if test $CURL_CONFIG != no; then
     GIT_CONF_SUBST([CURL_CONFIG])
-    if test -z "${NO_OPENSSL}"; then
-      AC_MSG_CHECKING([if Curl supports SSL])
-      if test $(curl-config --features|grep SSL) = SSL; then
-         NEEDS_SSL_WITH_CURL=YesPlease
-         AC_MSG_RESULT([yes])
-      else
-         NEEDS_SSL_WITH_CURL=
-         AC_MSG_RESULT([no])
-      fi
-      GIT_CONF_SUBST([NEEDS_SSL_WITH_CURL])
+
+    if test -z "$CURL_CONFIG_OPTS"; then
+        CURL_CONFIG_OPTS="--libs"
     fi
+
+    CURL_LDFLAGS=$($CURL_CONFIG $CURL_CONFIG_OPTS)
+    AC_MSG_NOTICE([Setting CURL_LDFLAGS to '$CURL_LDFLAGS'])
+    GIT_CONF_SUBST([CURL_LDFLAGS], [$CURL_LDFLAGS])
 fi
 
 fi
@@ -766,9 +773,19 @@ AC_CHECK_LIB([c], [basename],
 GIT_CONF_SUBST([NEEDS_LIBGEN])
 test -n "$NEEDS_LIBGEN" && LIBS="$LIBS -lgen"
 
-AC_CHECK_LIB([c], [gettext],
-[LIBC_CONTAINS_LIBINTL=YesPlease],
-[LIBC_CONTAINS_LIBINTL=])
+AC_DEFUN([LIBINTL_SRC], [
+AC_LANG_PROGRAM([[
+#include <libintl.h>
+]],[[
+char *msg = gettext("test");
+]])])
+
+AC_MSG_CHECKING([if libc contains libintl])
+AC_LINK_IFELSE([LIBINTL_SRC],
+	[AC_MSG_RESULT([yes])
+	LIBC_CONTAINS_LIBINTL=YesPlease],
+	[AC_MSG_RESULT([no])
+	LIBC_CONTAINS_LIBINTL=])
 GIT_CONF_SUBST([LIBC_CONTAINS_LIBINTL])
 
 #
@@ -792,6 +809,12 @@ AC_CHECK_HEADER([sys/select.h],
 [NO_SYS_SELECT_H=UnfortunatelyYes])
 GIT_CONF_SUBST([NO_SYS_SELECT_H])
 #
+# Define NO_POLL_H if you don't have poll.h
+AC_CHECK_HEADER([poll.h],
+[NO_POLL_H=],
+[NO_POLL_H=UnfortunatelyYes])
+GIT_CONF_SUBST([NO_POLL_H])
+#
 # Define NO_SYS_POLL_H if you don't have sys/poll.h
 AC_CHECK_HEADER([sys/poll.h],
 [NO_SYS_POLL_H=],
@@ -821,12 +844,61 @@ AC_MSG_CHECKING([for old iconv()])
 AC_COMPILE_IFELSE([OLDICONVTEST_SRC],
 	[AC_MSG_RESULT([no])],
 	[AC_MSG_RESULT([yes])
+	AC_DEFINE(HAVE_OLD_ICONV, 1)
 	OLD_ICONV=UnfortunatelyYes])
 
 GIT_UNSTASH_FLAGS($ICONVDIR)
 
 GIT_CONF_SUBST([OLD_ICONV])
 
+#
+# Define ICONV_OMITS_BOM if you are on a system which
+# iconv omits bom for utf-{16,32}
+if test -z "$NO_ICONV"; then
+AC_CACHE_CHECK([whether iconv omits bom for utf-16 and utf-32],
+ [ac_cv_iconv_omits_bom],
+[
+old_LIBS="$LIBS"
+if test -n "$NEEDS_LIBICONV"; then
+	LIBS="$LIBS -liconv"
+fi
+
+AC_RUN_IFELSE(
+	[AC_LANG_PROGRAM([AC_INCLUDES_DEFAULT
+	#include <iconv.h>
+	#ifdef HAVE_OLD_ICONV
+	typedef const char *iconv_ibp;
+	#else
+	typedef char *iconv_ibp;
+	#endif
+	],
+	[[
+	int v;
+	iconv_t conv;
+	char in[] = "a"; iconv_ibp pin = in;
+	char out[20] = ""; char *pout = out;
+	size_t isz = sizeof in;
+	size_t osz = sizeof out;
+
+	conv = iconv_open("UTF-16", "UTF-8");
+	iconv(conv, &pin, &isz, &pout, &osz);
+	iconv_close(conv);
+	v = (unsigned char)(out[0]) + (unsigned char)(out[1]);
+	return v != 0xfe + 0xff;
+	]])],
+	[ac_cv_iconv_omits_bom=no],
+	[ac_cv_iconv_omits_bom=yes])
+
+LIBS="$old_LIBS"
+])
+if test "x$ac_cv_iconv_omits_bom" = xyes; then
+	ICONV_OMITS_BOM=Yes
+else
+	ICONV_OMITS_BOM=
+fi
+GIT_CONF_SUBST([ICONV_OMITS_BOM])
+fi
+
 ## Checks for typedefs, structures, and compiler characteristics.
 AC_MSG_NOTICE([CHECKS for typedefs, structures, and compiler characteristics])
 #
diff -pruN 1.2.1+git2.18.0-1/git/connect.c 1.2.3+git2.25.1-1/git/connect.c
--- 1.2.1+git2.18.0-1/git/connect.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/connect.c	2020-02-17 04:47:35.000000000 +0000
@@ -58,7 +58,7 @@ static NORETURN void die_initial_contact
 	 * response does not necessarily mean an ACL problem, though.
 	 */
 	if (unexpected)
-		die(_("The remote end hung up upon initial contact"));
+		die(_("the remote end hung up upon initial contact"));
 	else
 		die(_("Could not read from remote repository.\n\n"
 		      "Please make sure you have the correct access rights\n"
@@ -78,7 +78,7 @@ int server_supports_v2(const char *c, in
 	}
 
 	if (die_on_error)
-		die("server doesn't support '%s'", c);
+		die(_("server doesn't support '%s'"), c);
 
 	return 0;
 }
@@ -100,7 +100,7 @@ int server_supports_feature(const char *
 	}
 
 	if (die_on_error)
-		die("server doesn't support feature '%s'", feature);
+		die(_("server doesn't support feature '%s'"), feature);
 
 	return 0;
 }
@@ -111,7 +111,7 @@ static void process_capabilities_v2(stru
 		argv_array_push(&server_capabilities_v2, reader->line);
 
 	if (reader->status != PACKET_READ_FLUSH)
-		die("expected flush after capabilities");
+		die(_("expected flush after capabilities"));
 }
 
 enum protocol_version discover_version(struct packet_reader *reader)
@@ -224,13 +224,13 @@ static int process_dummy_ref(const char
 		return 0;
 	name++;
 
-	return !oidcmp(&null_oid, &oid) && !strcmp(name, "capabilities^{}");
+	return oideq(&null_oid, &oid) && !strcmp(name, "capabilities^{}");
 }
 
 static void check_no_capabilities(const char *line, int len)
 {
 	if (strlen(line) != len)
-		warning("Ignoring capabilities after first line '%s'",
+		warning(_("ignoring capabilities after first line '%s'"),
 			line + strlen(line));
 }
 
@@ -249,7 +249,7 @@ static int process_ref(const char *line,
 	if (extra_have && !strcmp(name, ".have")) {
 		oid_array_append(extra_have, &old_oid);
 	} else if (!strcmp(name, "capabilities^{}")) {
-		die("protocol error: unexpected capabilities^{}");
+		die(_("protocol error: unexpected capabilities^{}"));
 	} else if (check_ref(name, flags)) {
 		struct ref *ref = alloc_ref(name);
 		oidcpy(&ref->old_oid, &old_oid);
@@ -270,9 +270,9 @@ static int process_shallow(const char *l
 		return 0;
 
 	if (get_oid_hex(arg, &old_oid))
-		die("protocol error: expected shallow sha-1, got '%s'", arg);
+		die(_("protocol error: expected shallow sha-1, got '%s'"), arg);
 	if (!shallow_points)
-		die("repository on the other end cannot be shallow");
+		die(_("repository on the other end cannot be shallow"));
 	oid_array_append(shallow_points, &old_oid);
 	check_no_capabilities(line, len);
 	return 1;
@@ -296,7 +296,6 @@ struct ref **get_remote_heads(struct pac
 	struct ref **orig_list = list;
 	int len = 0;
 	enum get_remote_heads_state state = EXPECTING_FIRST_REF;
-	const char *arg;
 
 	*list = NULL;
 
@@ -306,14 +305,12 @@ struct ref **get_remote_heads(struct pac
 			die_initial_contact(1);
 		case PACKET_READ_NORMAL:
 			len = reader->pktlen;
-			if (len > 4 && skip_prefix(reader->line, "ERR ", &arg))
-				die("remote error: %s", arg);
 			break;
 		case PACKET_READ_FLUSH:
 			state = EXPECTING_DONE;
 			break;
 		case PACKET_READ_DELIM:
-			die("invalid packet");
+			die(_("invalid packet"));
 		}
 
 		switch (state) {
@@ -333,7 +330,7 @@ struct ref **get_remote_heads(struct pac
 		case EXPECTING_SHALLOW:
 			if (process_shallow(reader->line, len, shallow_points))
 				break;
-			die("protocol error: unexpected '%s'", reader->line);
+			die(_("protocol error: unexpected '%s'"), reader->line);
 		case EXPECTING_DONE:
 			break;
 		}
@@ -441,11 +438,11 @@ struct ref **get_remote_refs(int fd_out,
 	/* Process response from server */
 	while (packet_reader_read(reader) == PACKET_READ_NORMAL) {
 		if (!process_ref_v2(reader->line, &list))
-			die("invalid ls-refs response: %s", reader->line);
+			die(_("invalid ls-refs response: %s"), reader->line);
 	}
 
 	if (reader->status != PACKET_READ_FLUSH)
-		die("expected flush after ref listing");
+		die(_("expected flush after ref listing"));
 
 	return list;
 }
@@ -514,7 +511,7 @@ int url_is_local_not_ssh(const char *url
 	const char *colon = strchr(url, ':');
 	const char *slash = strchr(url, '/');
 	return !colon || (slash && slash < colon) ||
-		has_dos_drive_prefix(url);
+		(has_dos_drive_prefix(url) && is_valid_path(url));
 }
 
 static const char *prot_name(enum protocol protocol)
@@ -544,7 +541,7 @@ static enum protocol get_protocol(const
 		return PROTO_SSH;
 	if (!strcmp(name, "file"))
 		return PROTO_FILE;
-	die("I don't handle protocol '%s'", name);
+	die(_("protocol '%s' is not supported"), name);
 }
 
 static char *host_end(char **hoststart, int removebrackets)
@@ -595,8 +592,7 @@ static void enable_keepalive(int sockfd)
 	int ka = 1;
 
 	if (setsockopt(sockfd, SOL_SOCKET, SO_KEEPALIVE, &ka, sizeof(ka)) < 0)
-		fprintf(stderr, "unable to set SO_KEEPALIVE on socket: %s\n",
-			strerror(errno));
+		error_errno(_("unable to set SO_KEEPALIVE on socket"));
 }
 
 #ifndef NO_IPV6
@@ -636,14 +632,15 @@ static int git_tcp_connect_sock(char *ho
 	hints.ai_protocol = IPPROTO_TCP;
 
 	if (flags & CONNECT_VERBOSE)
-		fprintf(stderr, "Looking up %s ... ", host);
+		fprintf(stderr, _("Looking up %s ... "), host);
 
 	gai = getaddrinfo(host, port, &hints, &ai);
 	if (gai)
-		die("Unable to look up %s (port %s) (%s)", host, port, gai_strerror(gai));
+		die(_("unable to look up %s (port %s) (%s)"), host, port, gai_strerror(gai));
 
 	if (flags & CONNECT_VERBOSE)
-		fprintf(stderr, "done.\nConnecting to %s (port %s) ... ", host, port);
+		/* TRANSLATORS: this is the end of "Looking up %s ... " */
+		fprintf(stderr, _("done.\nConnecting to %s (port %s) ... "), host, port);
 
 	for (ai0 = ai; ai; ai = ai->ai_next, cnt++) {
 		sockfd = socket(ai->ai_family,
@@ -665,12 +662,13 @@ static int git_tcp_connect_sock(char *ho
 	freeaddrinfo(ai0);
 
 	if (sockfd < 0)
-		die("unable to connect to %s:\n%s", host, error_message.buf);
+		die(_("unable to connect to %s:\n%s"), host, error_message.buf);
 
 	enable_keepalive(sockfd);
 
 	if (flags & CONNECT_VERBOSE)
-		fprintf(stderr, "done.\n");
+		/* TRANSLATORS: this is the end of "Connecting to %s (port %s) ... " */
+		fprintf_ln(stderr, _("done."));
 
 	strbuf_release(&error_message);
 
@@ -697,22 +695,23 @@ static int git_tcp_connect_sock(char *ho
 	get_host_and_port(&host, &port);
 
 	if (flags & CONNECT_VERBOSE)
-		fprintf(stderr, "Looking up %s ... ", host);
+		fprintf(stderr, _("Looking up %s ... "), host);
 
 	he = gethostbyname(host);
 	if (!he)
-		die("Unable to look up %s (%s)", host, hstrerror(h_errno));
+		die(_("unable to look up %s (%s)"), host, hstrerror(h_errno));
 	nport = strtoul(port, &ep, 10);
 	if ( ep == port || *ep ) {
 		/* Not numeric */
 		struct servent *se = getservbyname(port,"tcp");
 		if ( !se )
-			die("Unknown port %s", port);
+			die(_("unknown port %s"), port);
 		nport = se->s_port;
 	}
 
 	if (flags & CONNECT_VERBOSE)
-		fprintf(stderr, "done.\nConnecting to %s (port %s) ... ", host, port);
+		/* TRANSLATORS: this is the end of "Looking up %s ... " */
+		fprintf(stderr, _("done.\nConnecting to %s (port %s) ... "), host, port);
 
 	for (cnt = 0, ap = he->h_addr_list; *ap; ap++, cnt++) {
 		memset(&sa, 0, sizeof sa);
@@ -740,12 +739,13 @@ static int git_tcp_connect_sock(char *ho
 	}
 
 	if (sockfd < 0)
-		die("unable to connect to %s:\n%s", host, error_message.buf);
+		die(_("unable to connect to %s:\n%s"), host, error_message.buf);
 
 	enable_keepalive(sockfd);
 
 	if (flags & CONNECT_VERBOSE)
-		fprintf(stderr, "done.\n");
+		/* TRANSLATORS: this is the end of "Connecting to %s (port %s) ... " */
+		fprintf_ln(stderr, _("done."));
 
 	return sockfd;
 }
@@ -842,9 +842,9 @@ static struct child_process *git_proxy_c
 	get_host_and_port(&host, &port);
 
 	if (looks_like_command_line_option(host))
-		die("strange hostname '%s' blocked", host);
+		die(_("strange hostname '%s' blocked"), host);
 	if (looks_like_command_line_option(port))
-		die("strange port '%s' blocked", port);
+		die(_("strange port '%s' blocked"), port);
 
 	proxy = xmalloc(sizeof(*proxy));
 	child_process_init(proxy);
@@ -854,7 +854,7 @@ static struct child_process *git_proxy_c
 	proxy->in = -1;
 	proxy->out = -1;
 	if (start_command(proxy))
-		die("cannot start proxy %s", git_proxy_command);
+		die(_("cannot start proxy %s"), git_proxy_command);
 	fd[0] = proxy->out; /* read from proxy stdout */
 	fd[1] = proxy->in;  /* write to proxy stdin */
 	return proxy;
@@ -915,13 +915,17 @@ static enum protocol parse_connect_url(c
 
 	if (protocol == PROTO_LOCAL)
 		path = end;
+	else if (protocol == PROTO_FILE && *host != '/' &&
+		 !has_dos_drive_prefix(host) &&
+		 offset_1st_component(host - 2) > 1)
+		path = host - 2; /* include the leading "//" */
 	else if (protocol == PROTO_FILE && has_dos_drive_prefix(end))
 		path = end; /* "file://$(pwd)" may be "file://C:/projects/repo" */
 	else
 		path = strchr(end, separator);
 
 	if (!path || !*path)
-		die("No path specified. See 'man git-pull' for valid url syntax");
+		die(_("no path specified; see 'git help pull' for valid url syntax"));
 
 	/*
 	 * null-terminate hostname and point path to ~ for URL's like this:
@@ -1116,7 +1120,7 @@ static void push_ssh_options(struct argv
 		case VARIANT_AUTO:
 			BUG("VARIANT_AUTO passed to push_ssh_options");
 		case VARIANT_SIMPLE:
-			die("ssh variant 'simple' does not support -4");
+			die(_("ssh variant 'simple' does not support -4"));
 		case VARIANT_SSH:
 		case VARIANT_PLINK:
 		case VARIANT_PUTTY:
@@ -1128,7 +1132,7 @@ static void push_ssh_options(struct argv
 		case VARIANT_AUTO:
 			BUG("VARIANT_AUTO passed to push_ssh_options");
 		case VARIANT_SIMPLE:
-			die("ssh variant 'simple' does not support -6");
+			die(_("ssh variant 'simple' does not support -6"));
 		case VARIANT_SSH:
 		case VARIANT_PLINK:
 		case VARIANT_PUTTY:
@@ -1145,7 +1149,7 @@ static void push_ssh_options(struct argv
 		case VARIANT_AUTO:
 			BUG("VARIANT_AUTO passed to push_ssh_options");
 		case VARIANT_SIMPLE:
-			die("ssh variant 'simple' does not support setting port");
+			die(_("ssh variant 'simple' does not support setting port"));
 		case VARIANT_SSH:
 			argv_array_push(args, "-p");
 			break;
@@ -1168,7 +1172,7 @@ static void fill_ssh_args(struct child_p
 	enum ssh_variant variant;
 
 	if (looks_like_command_line_option(ssh_host))
-		die("strange hostname '%s' blocked", ssh_host);
+		die(_("strange hostname '%s' blocked"), ssh_host);
 
 	ssh = get_ssh_command();
 	if (ssh) {
@@ -1248,6 +1252,7 @@ struct child_process *git_connect(int fd
 		conn = NULL;
 	} else if (protocol == PROTO_GIT) {
 		conn = git_connect_git(fd, hostandport, path, prog, version, flags);
+		conn->trace2_child_class = "transport/git";
 	} else {
 		struct strbuf cmd = STRBUF_INIT;
 		const char *const *var;
@@ -1256,7 +1261,7 @@ struct child_process *git_connect(int fd
 		child_process_init(conn);
 
 		if (looks_like_command_line_option(path))
-			die("strange pathname '%s' blocked", path);
+			die(_("strange pathname '%s' blocked"), path);
 
 		strbuf_addstr(&cmd, prog);
 		strbuf_addch(&cmd, ' ');
@@ -1290,9 +1295,11 @@ struct child_process *git_connect(int fd
 				strbuf_release(&cmd);
 				return NULL;
 			}
+			conn->trace2_child_class = "transport/ssh";
 			fill_ssh_args(conn, ssh_host, port, version, flags);
 		} else {
 			transport_check_allowed("file");
+			conn->trace2_child_class = "transport/file";
 			if (version > 0) {
 				argv_array_pushf(&conn->env_array, GIT_PROTOCOL_ENVIRONMENT "=version=%d",
 						 version);
@@ -1301,7 +1308,7 @@ struct child_process *git_connect(int fd
 		argv_array_push(&conn->args, cmd.buf);
 
 		if (start_command(conn))
-			die("unable to fork");
+			die(_("unable to fork"));
 
 		fd[0] = conn->out; /* read from child's stdout */
 		fd[1] = conn->in;  /* write to child's stdin */
diff -pruN 1.2.1+git2.18.0-1/git/connected.c 1.2.3+git2.25.1-1/git/connected.c
--- 1.2.1+git2.18.0-1/git/connected.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/connected.c	2020-02-17 04:47:35.000000000 +0000
@@ -1,9 +1,11 @@
 #include "cache.h"
+#include "object-store.h"
 #include "run-command.h"
 #include "sigchain.h"
 #include "connected.h"
 #include "transport.h"
 #include "packfile.h"
+#include "promisor-remote.h"
 
 /*
  * If we feed all the commits we want to verify to this command
@@ -27,6 +29,7 @@ int check_connected(oid_iterate_fn fn, v
 	struct packed_git *new_pack = NULL;
 	struct transport *transport;
 	size_t base_len;
+	const unsigned hexsz = the_hash_algo->hexsz;
 
 	if (!opt)
 		opt = &defaults;
@@ -49,6 +52,23 @@ int check_connected(oid_iterate_fn fn, v
 		strbuf_release(&idx_file);
 	}
 
+	if (opt->check_refs_only) {
+		/*
+		 * For partial clones, we don't want to have to do a regular
+		 * connectivity check because we have to enumerate and exclude
+		 * all promisor objects (slow), and then the connectivity check
+		 * itself becomes a no-op because in a partial clone every
+		 * object is a promisor object. Instead, just make sure we
+		 * received the objects pointed to by each wanted ref.
+		 */
+		do {
+			if (!repo_has_object_file_with_flags(the_repository, &oid,
+							     OBJECT_INFO_SKIP_FETCH_OBJECT))
+				return 1;
+		} while (!fn(cb_data, &oid));
+		return 0;
+	}
+
 	if (opt->shallow_file) {
 		argv_array_push(&rev_list.args, "--shallow-file");
 		argv_array_push(&rev_list.args, opt->shallow_file);
@@ -56,11 +76,14 @@ int check_connected(oid_iterate_fn fn, v
 	argv_array_push(&rev_list.args,"rev-list");
 	argv_array_push(&rev_list.args, "--objects");
 	argv_array_push(&rev_list.args, "--stdin");
-	if (repository_format_partial_clone)
+	if (has_promisor_remote())
 		argv_array_push(&rev_list.args, "--exclude-promisor-objects");
-	argv_array_push(&rev_list.args, "--not");
-	argv_array_push(&rev_list.args, "--all");
+	if (!opt->is_deepening_fetch) {
+		argv_array_push(&rev_list.args, "--not");
+		argv_array_push(&rev_list.args, "--all");
+	}
 	argv_array_push(&rev_list.args, "--quiet");
+	argv_array_push(&rev_list.args, "--alternate-refs");
 	if (opt->progress)
 		argv_array_pushf(&rev_list.args, "--progress=%s",
 				 _("Checking connectivity"));
@@ -79,7 +102,7 @@ int check_connected(oid_iterate_fn fn, v
 
 	sigchain_push(SIGPIPE, SIG_IGN);
 
-	commit[GIT_SHA1_HEXSZ] = '\n';
+	commit[hexsz] = '\n';
 	do {
 		/*
 		 * If index-pack already checked that:
@@ -92,8 +115,8 @@ int check_connected(oid_iterate_fn fn, v
 		if (new_pack && find_pack_entry_one(oid.hash, new_pack))
 			continue;
 
-		memcpy(commit, oid_to_hex(&oid), GIT_SHA1_HEXSZ);
-		if (write_in_full(rev_list.in, commit, GIT_SHA1_HEXSZ + 1) < 0) {
+		memcpy(commit, oid_to_hex(&oid), hexsz);
+		if (write_in_full(rev_list.in, commit, hexsz + 1) < 0) {
 			if (errno != EPIPE && errno != EINVAL)
 				error_errno(_("failed write to rev-list"));
 			err = -1;
diff -pruN 1.2.1+git2.18.0-1/git/connected.h 1.2.3+git2.25.1-1/git/connected.h
--- 1.2.1+git2.18.0-1/git/connected.h	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/connected.h	2020-02-17 04:47:35.000000000 +0000
@@ -1,6 +1,7 @@
 #ifndef CONNECTED_H
 #define CONNECTED_H
 
+struct object_id;
 struct transport;
 
 /*
@@ -38,14 +39,29 @@ struct check_connected_options {
 	 * Insert these variables into the environment of the child process.
 	 */
 	const char **env;
+
+	/*
+	 * If non-zero, check the ancestry chain completely, not stopping at
+	 * any existing ref. This is necessary when deepening existing refs
+	 * during a fetch.
+	 */
+	unsigned is_deepening_fetch : 1;
+
+	/*
+	 * If non-zero, only check the top-level objects referenced by the
+	 * wanted refs (passed in as cb_data). This is useful for partial
+	 * clones, where enumerating and excluding all promisor objects is very
+	 * slow and the commit-walk itself becomes a no-op.
+	 */
+	unsigned check_refs_only : 1;
 };
 
 #define CHECK_CONNECTED_INIT { 0 }
 
 /*
- * Make sure that our object store has all the commits necessary to
- * connect the ancestry chain to some of our existing refs, and all
- * the trees and blobs that these commits use.
+ * Make sure that all given objects and all objects reachable from them
+ * either exist in our object store or (if the repository is a partial
+ * clone) are promised to be available.
  *
  * Return 0 if Ok, non zero otherwise (i.e. some missing objects)
  *
diff -pruN 1.2.1+git2.18.0-1/git/connect.h 1.2.3+git2.25.1-1/git/connect.h
--- 1.2.1+git2.18.0-1/git/connect.h	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/connect.h	2020-02-17 04:47:35.000000000 +0000
@@ -1,23 +1,25 @@
 #ifndef CONNECT_H
 #define CONNECT_H
 
+#include "protocol.h"
+
 #define CONNECT_VERBOSE       (1u << 0)
 #define CONNECT_DIAG_URL      (1u << 1)
 #define CONNECT_IPV4          (1u << 2)
 #define CONNECT_IPV6          (1u << 3)
-extern struct child_process *git_connect(int fd[2], const char *url, const char *prog, int flags);
-extern int finish_connect(struct child_process *conn);
-extern int git_connection_is_socket(struct child_process *conn);
-extern int server_supports(const char *feature);
-extern int parse_feature_request(const char *features, const char *feature);
-extern const char *server_feature_value(const char *feature, int *len_ret);
-extern int url_is_local_not_ssh(const char *url);
+struct child_process *git_connect(int fd[2], const char *url, const char *prog, int flags);
+int finish_connect(struct child_process *conn);
+int git_connection_is_socket(struct child_process *conn);
+int server_supports(const char *feature);
+int parse_feature_request(const char *features, const char *feature);
+const char *server_feature_value(const char *feature, int *len_ret);
+int url_is_local_not_ssh(const char *url);
 
 struct packet_reader;
-extern enum protocol_version discover_version(struct packet_reader *reader);
+enum protocol_version discover_version(struct packet_reader *reader);
 
-extern int server_supports_v2(const char *c, int die_on_error);
-extern int server_supports_feature(const char *c, const char *feature,
-				   int die_on_error);
+int server_supports_v2(const char *c, int die_on_error);
+int server_supports_feature(const char *c, const char *feature,
+			    int die_on_error);
 
 #endif
diff -pruN 1.2.1+git2.18.0-1/git/contrib/buildsystems/engine.pl 1.2.3+git2.25.1-1/git/contrib/buildsystems/engine.pl
--- 1.2.1+git2.18.0-1/git/contrib/buildsystems/engine.pl	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/contrib/buildsystems/engine.pl	2020-02-17 04:47:35.000000000 +0000
@@ -12,6 +12,7 @@ use File::Basename;
 use File::Spec;
 use Cwd;
 use Generators;
+use Text::ParseWords;
 
 my (%build_structure, %compile_options, @makedry);
 my $out_dir = getcwd();
@@ -31,6 +32,7 @@ generate usage:
   -g <GENERATOR>  --gen <GENERATOR> Specify the buildsystem generator    (default: $gen)
                                     Available: $genlist
   -o <PATH>       --out <PATH>      Specify output directory generation  (default: .)
+                  --make-out <PATH> Write the output of GNU Make into a file
   -i <FILE>       --in <FILE>       Specify input file, instead of running GNU Make
   -h,-?           --help            This help
 EOM
@@ -38,6 +40,7 @@ EOM
 }
 
 # Parse command-line options
+my $make_out;
 while (@ARGV) {
     my $arg = shift @ARGV;
     if ("$arg" eq "-h" || "$arg" eq "--help" || "$arg" eq "-?") {
@@ -45,6 +48,8 @@ while (@ARGV) {
 	exit(0);
     } elsif("$arg" eq "--out" || "$arg" eq "-o") {
 	$out_dir = shift @ARGV;
+    } elsif("$arg" eq "--make-out") {
+	$make_out = shift @ARGV;
     } elsif("$arg" eq "--gen" || "$arg" eq "-g") {
 	$gen = shift @ARGV;
     } elsif("$arg" eq "--in" || "$arg" eq "-i") {
@@ -52,6 +57,8 @@ while (@ARGV) {
         open(F, "<$infile") || die "Couldn't open file $infile";
         @makedry = <F>;
         close(F);
+    } else {
+        die "Unknown option: " . $arg;
     }
 }
 
@@ -72,7 +79,19 @@ Running GNU Make to figure out build str
 EOM
 
 # Pipe a make --dry-run into a variable, if not already loaded from file
-@makedry = `cd $git_dir && make -n MSVC=1 V=1 2>/dev/null` if !@makedry;
+# Capture the make dry stderr to file for review (will be empty for a release build).
+
+my $ErrsFile = "msvc-build-makedryerrors.txt";
+@makedry = `make -C $git_dir -n MSVC=1 SKIP_VCPKG=1 V=1 2>$ErrsFile`
+if !@makedry;
+# test for an empty Errors file and remove it
+unlink $ErrsFile if -f -z $ErrsFile;
+
+if (defined $make_out) {
+    open OUT, ">" . $make_out;
+    print OUT @makedry;
+    close OUT;
+}
 
 # Parse the make output into usable info
 parseMakeOutput();
@@ -140,6 +159,12 @@ sub parseMakeOutput
             next;
         }
 
+        if ($text =~ /^(mkdir|msgfmt) /) {
+            # options to the Portable Object translations
+            # the line "mkdir ... && msgfmt ..." contains no linker options
+            next;
+        }
+
         if($text =~ / -c /) {
             # compilation
             handleCompileLine($text, $line);
@@ -231,7 +256,7 @@ sub removeDuplicates
 sub handleCompileLine
 {
     my ($line, $lineno) = @_;
-    my @parts = split(' ', $line);
+    my @parts = shellwords($line);
     my $sourcefile;
     shift(@parts); # ignore cmd
     while (my $part = shift @parts) {
@@ -265,7 +290,7 @@ sub handleLibLine
     my (@objfiles, @lflags, $libout, $part);
     # kill cmd and rm 'prefix'
     $line =~ s/^rm -f .* && .* rcs //;
-    my @parts = split(' ', $line);
+    my @parts = shellwords($line);
     while ($part = shift @parts) {
         if ($part =~ /^-/) {
             push(@lflags, $part);
@@ -282,7 +307,7 @@ sub handleLibLine
 #    exit(1);
     foreach (@objfiles) {
         my $sourcefile = $_;
-        $sourcefile =~ s/\.o/.c/;
+        $sourcefile =~ s/\.o$/.c/;
         push(@sources, $sourcefile);
         push(@cflags, @{$compile_options{"${sourcefile}_CFLAGS"}});
         push(@defines, @{$compile_options{"${sourcefile}_DEFINES"}});
@@ -306,7 +331,7 @@ sub handleLinkLine
 {
     my ($line, $lineno) = @_;
     my (@objfiles, @lflags, @libs, $appout, $part);
-    my @parts = split(' ', $line);
+    my @parts = shellwords($line);
     shift(@parts); # ignore cmd
     while ($part = shift @parts) {
         if ($part =~ /^-IGNORE/) {
@@ -317,26 +342,36 @@ sub handleLinkLine
             $appout = shift @parts;
         } elsif ("$part" eq "-lz") {
             push(@libs, "zlib.lib");
-	} elsif ("$part" eq "-lcrypto") {
-            push(@libs, "libeay32.lib");
+        } elsif ("$part" eq "-lcrypto") {
+            push(@libs, "libcrypto.lib");
         } elsif ("$part" eq "-lssl") {
-            push(@libs, "ssleay32.lib");
-        } elsif ($part =~ /^-/) {
+            push(@libs, "libssl.lib");
+        } elsif ("$part" eq "-lcurl") {
+            push(@libs, "libcurl.lib");
+        } elsif ("$part" eq "-lexpat") {
+            push(@libs, "expat.lib");
+        } elsif ("$part" eq "-liconv") {
+            push(@libs, "libiconv.lib");
+        } elsif ($part =~ /^[-\/]/) {
             push(@lflags, $part);
         } elsif ($part =~ /\.(a|lib)$/) {
             $part =~ s/\.a$/.lib/;
             push(@libs, $part);
-        } elsif ($part =~ /\.(o|obj)$/) {
+        } elsif ($part eq 'invalidcontinue.obj') {
+            # ignore - known to MSVC
+        } elsif ($part =~ /\.o$/) {
             push(@objfiles, $part);
+        } elsif ($part =~ /\.obj$/) {
+            # do nothing, 'make' should not be producing .obj, only .o files
         } else {
-            die "Unhandled lib option @ line $lineno: $part";
+            die "Unhandled link option @ line $lineno: $part";
         }
     }
 #    print "AppOut: '$appout'\nLFlags: @lflags\nLibs  : @libs\nOfiles: @objfiles\n";
 #    exit(1);
     foreach (@objfiles) {
         my $sourcefile = $_;
-        $sourcefile =~ s/\.o/.c/;
+        $sourcefile =~ s/\.o$/.c/;
         push(@sources, $sourcefile);
         push(@cflags, @{$compile_options{"${sourcefile}_CFLAGS"}});
         push(@defines, @{$compile_options{"${sourcefile}_DEFINES"}});
diff -pruN 1.2.1+git2.18.0-1/git/contrib/buildsystems/Generators/Vcproj.pm 1.2.3+git2.25.1-1/git/contrib/buildsystems/Generators/Vcproj.pm
--- 1.2.1+git2.18.0-1/git/contrib/buildsystems/Generators/Vcproj.pm	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/contrib/buildsystems/Generators/Vcproj.pm	2020-02-17 04:47:35.000000000 +0000
@@ -3,6 +3,7 @@ require Exporter;
 
 use strict;
 use vars qw($VERSION);
+use Digest::SHA qw(sha256_hex);
 
 our $VERSION = '1.00';
 our(@ISA, @EXPORT, @EXPORT_OK, @AVAILABLE);
@@ -12,59 +13,12 @@ BEGIN {
     push @EXPORT_OK, qw(generate);
 }
 
-my $guid_index = 0;
-my @GUIDS = (
-    "{E07B9989-2BF7-4F21-8918-BE22BA467AC3}",
-    "{278FFB51-0296-4A44-A81A-22B87B7C3592}",
-    "{7346A2C4-F0FD-444F-9EBE-1AF23B2B5650}",
-    "{67F421AC-EB34-4D49-820B-3196807B423F}",
-    "{385DCFE1-CC8C-4211-A451-80FCFC31CA51}",
-    "{97CC46C5-D2CC-4D26-B634-E75792B79916}",
-    "{C7CE21FE-6EF8-4012-A5C7-A22BCEDFBA11}",
-    "{51575134-3FDF-42D1-BABD-3FB12669C6C9}",
-    "{0AE195E4-9823-4B87-8E6F-20C5614AF2FF}",
-    "{4B918255-67CA-43BB-A46C-26704B666E6B}",
-    "{18CCFEEF-C8EE-4CC1-A265-26F95C9F4649}",
-    "{5D5D90FA-01B7-4973-AFE5-CA88C53AC197}",
-    "{1F054320-036D-49E1-B384-FB5DF0BC8AC0}",
-    "{7CED65EE-F2D9-4171-825B-C7D561FE5786}",
-    "{8D341679-0F07-4664-9A56-3BA0DE88B9BC}",
-    "{C189FEDC-2957-4BD7-9FA4-7622241EA145}",
-    "{66844203-1B9F-4C53-9274-164FFF95B847}",
-    "{E4FEA145-DECC-440D-AEEA-598CF381FD43}",
-    "{73300A8E-C8AC-41B0-B555-4F596B681BA7}",
-    "{873FDEB1-D01D-40BF-A1BF-8BBC58EC0F51}",
-    "{7922C8BE-76C5-4AC6-8BF7-885C0F93B782}",
-    "{E245D370-308B-4A49-BFC1-1E527827975F}",
-    "{F6FA957B-66FC-4ED7-B260-E59BBE4FE813}",
-    "{E6055070-0198-431A-BC49-8DB6CEE770AE}",
-    "{54159234-C3EB-43DA-906B-CE5DA5C74654}",
-    "{594CFC35-0B60-46F6-B8EF-9983ACC1187D}",
-    "{D93FCAB7-1F01-48D2-B832-F761B83231A5}",
-    "{DBA5E6AC-E7BE-42D3-8703-4E787141526E}",
-    "{6171953F-DD26-44C7-A3BE-CC45F86FC11F}",
-    "{9E19DDBE-F5E4-4A26-A2FE-0616E04879B8}",
-    "{AE81A615-99E3-4885-9CE0-D9CAA193E867}",
-    "{FBF4067E-1855-4F6C-8BCD-4D62E801A04D}",
-    "{17007948-6593-4AEB-8106-F7884B4F2C19}",
-    "{199D4C8D-8639-4DA6-82EF-08668C35DEE0}",
-    "{E085E50E-C140-4CF3-BE4B-094B14F0DDD6}",
-    "{00785268-A9CC-4E40-AC29-BAC0019159CE}",
-    "{4C06F56A-DCDB-46A6-B67C-02339935CF12}",
-    "{3A62D3FD-519E-4EC9-8171-D2C1BFEA022F}",
-    "{3A62D3FD-519E-4EC9-8171-D2C1BFEA022F}",
-    "{9392EB58-D7BA-410B-B1F0-B2FAA6BC89A7}",
-    "{2ACAB2D5-E0CE-4027-BCA0-D78B2D7A6C66}",
-    "{86E216C3-43CE-481A-BCB2-BE5E62850635}",
-    "{FB631291-7923-4B91-9A57-7B18FDBB7A42}",
-    "{0A176EC9-E934-45B8-B87F-16C7F4C80039}",
-    "{DF55CA80-46E8-4C53-B65B-4990A23DD444}",
-    "{3A0F9895-55D2-4710-BE5E-AD7498B5BF44}",
-    "{294BDC5A-F448-48B6-8110-DD0A81820F8C}",
-    "{4B9F66E9-FAC9-47AB-B1EF-C16756FBFD06}",
-    "{72EA49C6-2806-48BD-B81B-D4905102E19C}",
-    "{5728EB7E-8929-486C-8CD5-3238D060E768}"
-);
+sub generate_guid ($) {
+    my $hex = sha256_hex($_[0]);
+    $hex =~ s/^(.{8})(.{4})(.{4})(.{4})(.{12}).*/{$1-$2-$3-$4-$5}/;
+    $hex =~ tr/a-z/A-Z/;
+    return $hex;
+}
 
 sub generate {
     my ($git_dir, $out_dir, $rel_dir, %build_structure) = @_;
@@ -92,9 +46,8 @@ sub createLibProject {
     $target =~ s/\//_/g;
     $target =~ s/\.a//;
 
-    my $uuid = $GUIDS[$guid_index];
+    my $uuid = generate_guid($libname);
     $$build_structure{"LIBS_${target}_GUID"} = $uuid;
-    $guid_index += 1;
 
     my @srcs = sort(map("$rel_dir\\$_", @{$$build_structure{"LIBS_${libname}_SOURCES"}}));
     my @sources;
@@ -106,6 +59,8 @@ sub createLibProject {
     my $includes= join(";", sort(map("&quot;$rel_dir\\$_&quot;", @{$$build_structure{"LIBS_${libname}_INCLUDES"}})));
     my $cflags  = join(" ", sort(@{$$build_structure{"LIBS_${libname}_CFLAGS"}}));
     $cflags =~ s/\"/&quot;/g;
+    $cflags =~ s/</&lt;/g;
+    $cflags =~ s/>/&gt;/g;
 
     my $cflags_debug = $cflags;
     $cflags_debug =~ s/-MT/-MTd/;
@@ -127,6 +82,8 @@ sub createLibProject {
 
     $defines =~ s/-D//g;
     $defines =~ s/\"/\\&quot;/g;
+    $defines =~ s/</&lt;/g;
+    $defines =~ s/>/&gt;/g;
     $defines =~ s/\'//g;
     $includes =~ s/-I//g;
     mkdir "$target" || die "Could not create the directory $target for lib project!\n";
@@ -163,9 +120,6 @@ sub createLibProject {
 				Name="VCXMLDataGeneratorTool"
 			/>
 			<Tool
-				Name="VCWebServiceProxyGeneratorTool"
-			/>
-			<Tool
 				Name="VCMIDLTool"
 			/>
 			<Tool
@@ -229,9 +183,6 @@ sub createLibProject {
 				Name="VCXMLDataGeneratorTool"
 			/>
 			<Tool
-				Name="VCWebServiceProxyGeneratorTool"
-			/>
-			<Tool
 				Name="VCMIDLTool"
 			/>
 			<Tool
@@ -311,9 +262,8 @@ sub createAppProject {
     $target =~ s/\//_/g;
     $target =~ s/\.exe//;
 
-    my $uuid = $GUIDS[$guid_index];
+    my $uuid = generate_guid($appname);
     $$build_structure{"APPS_${target}_GUID"} = $uuid;
-    $guid_index += 1;
 
     my @srcs = sort(map("$rel_dir\\$_", @{$$build_structure{"APPS_${appname}_SOURCES"}}));
     my @sources;
@@ -325,6 +275,8 @@ sub createAppProject {
     my $includes= join(";", sort(map("&quot;$rel_dir\\$_&quot;", @{$$build_structure{"APPS_${appname}_INCLUDES"}})));
     my $cflags  = join(" ", sort(@{$$build_structure{"APPS_${appname}_CFLAGS"}}));
     $cflags =~ s/\"/&quot;/g;
+    $cflags =~ s/</&lt;/g;
+    $cflags =~ s/>/&gt;/g;
 
     my $cflags_debug = $cflags;
     $cflags_debug =~ s/-MT/-MTd/;
@@ -351,6 +303,8 @@ sub createAppProject {
 
     $defines =~ s/-D//g;
     $defines =~ s/\"/\\&quot;/g;
+    $defines =~ s/</&lt;/g;
+    $defines =~ s/>/&gt;/g;
     $defines =~ s/\'//g;
     $defines =~ s/\\\\/\\/g;
     $includes =~ s/-I//g;
@@ -388,9 +342,6 @@ sub createAppProject {
 				Name="VCXMLDataGeneratorTool"
 			/>
 			<Tool
-				Name="VCWebServiceProxyGeneratorTool"
-			/>
-			<Tool
 				Name="VCMIDLTool"
 			/>
 			<Tool
@@ -459,9 +410,6 @@ sub createAppProject {
 				Name="VCXMLDataGeneratorTool"
 			/>
 			<Tool
-				Name="VCWebServiceProxyGeneratorTool"
-			/>
-			<Tool
 				Name="VCMIDLTool"
 			/>
 			<Tool
@@ -561,20 +509,18 @@ sub createGlueProject {
     foreach (@apps) {
         $_ =~ s/\//_/g;
         $_ =~ s/\.exe//;
-        push(@tmp, $_);
+        if ($_ eq "git" ) {
+            unshift(@tmp, $_);
+        } else {
+            push(@tmp, $_);
+        }
     }
     @apps = @tmp;
 
     open F, ">git.sln" || die "Could not open git.sln for writing!\n";
     binmode F, ":crlf";
     print F "$SLN_HEAD";
-    foreach (@libs) {
-        my $libname = $_;
-        my $uuid = $build_structure{"LIBS_${libname}_GUID"};
-        print F "$SLN_PRE";
-        print F "\"${libname}\", \"${libname}\\${libname}.vcproj\", \"${uuid}\"";
-        print F "$SLN_POST";
-    }
+
     my $uuid_libgit = $build_structure{"LIBS_libgit_GUID"};
     my $uuid_xdiff_lib = $build_structure{"LIBS_xdiff_lib_GUID"};
     foreach (@apps) {
@@ -588,6 +534,13 @@ sub createGlueProject {
         print F "	EndProjectSection";
         print F "$SLN_POST";
     }
+    foreach (@libs) {
+        my $libname = $_;
+        my $uuid = $build_structure{"LIBS_${libname}_GUID"};
+        print F "$SLN_PRE";
+        print F "\"${libname}\", \"${libname}\\${libname}.vcproj\", \"${uuid}\"";
+        print F "$SLN_POST";
+    }
 
     print F << "EOM";
 Global
@@ -599,17 +552,17 @@ EOM
     print F << "EOM";
 	GlobalSection(ProjectConfigurationPlatforms) = postSolution
 EOM
-    foreach (@libs) {
-        my $libname = $_;
-        my $uuid = $build_structure{"LIBS_${libname}_GUID"};
+    foreach (@apps) {
+        my $appname = $_;
+        my $uuid = $build_structure{"APPS_${appname}_GUID"};
         print F "\t\t${uuid}.Debug|Win32.ActiveCfg = Debug|Win32\n";
         print F "\t\t${uuid}.Debug|Win32.Build.0 = Debug|Win32\n";
         print F "\t\t${uuid}.Release|Win32.ActiveCfg = Release|Win32\n";
         print F "\t\t${uuid}.Release|Win32.Build.0 = Release|Win32\n";
     }
-    foreach (@apps) {
-        my $appname = $_;
-        my $uuid = $build_structure{"APPS_${appname}_GUID"};
+    foreach (@libs) {
+        my $libname = $_;
+        my $uuid = $build_structure{"LIBS_${libname}_GUID"};
         print F "\t\t${uuid}.Debug|Win32.ActiveCfg = Debug|Win32\n";
         print F "\t\t${uuid}.Debug|Win32.Build.0 = Debug|Win32\n";
         print F "\t\t${uuid}.Release|Win32.ActiveCfg = Release|Win32\n";
diff -pruN 1.2.1+git2.18.0-1/git/contrib/buildsystems/Generators/Vcxproj.pm 1.2.3+git2.25.1-1/git/contrib/buildsystems/Generators/Vcxproj.pm
--- 1.2.1+git2.18.0-1/git/contrib/buildsystems/Generators/Vcxproj.pm	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/contrib/buildsystems/Generators/Vcxproj.pm	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,392 @@
+package Generators::Vcxproj;
+require Exporter;
+
+use strict;
+use vars qw($VERSION);
+use Digest::SHA qw(sha256_hex);
+
+our $VERSION = '1.00';
+our(@ISA, @EXPORT, @EXPORT_OK, @AVAILABLE);
+@ISA = qw(Exporter);
+
+BEGIN {
+    push @EXPORT_OK, qw(generate);
+}
+
+sub generate_guid ($) {
+	my $hex = sha256_hex($_[0]);
+	$hex =~ s/^(.{8})(.{4})(.{4})(.{4})(.{12}).*/{$1-$2-$3-$4-$5}/;
+	$hex =~ tr/a-z/A-Z/;
+	return $hex;
+}
+
+sub generate {
+    my ($git_dir, $out_dir, $rel_dir, %build_structure) = @_;
+    my @libs = @{$build_structure{"LIBS"}};
+    foreach (@libs) {
+        createProject($_, $git_dir, $out_dir, $rel_dir, \%build_structure, 1);
+    }
+
+    my @apps = @{$build_structure{"APPS"}};
+    foreach (@apps) {
+        createProject($_, $git_dir, $out_dir, $rel_dir, \%build_structure, 0);
+    }
+
+    createGlueProject($git_dir, $out_dir, $rel_dir, %build_structure);
+    return 0;
+}
+
+sub createProject {
+    my ($name, $git_dir, $out_dir, $rel_dir, $build_structure, $static_library) = @_;
+    my $label = $static_library ? "lib" : "app";
+    my $prefix = $static_library ? "LIBS_" : "APPS_";
+    my $config_type = $static_library ? "StaticLibrary" : "Application";
+    print "Generate $name vcxproj $label project\n";
+    my $cdup = $name;
+    $cdup =~ s/[^\/]+/../g;
+    $cdup =~ s/\//\\/g;
+    $rel_dir = $rel_dir eq "." ? $cdup : "$cdup\\$rel_dir";
+    $rel_dir =~ s/\//\\/g;
+
+    my $target = $name;
+    if ($static_library) {
+      $target =~ s/\.a//;
+    } else {
+      $target =~ s/\.exe//;
+    }
+
+    my $uuid = generate_guid($name);
+    $$build_structure{"$prefix${target}_GUID"} = $uuid;
+    my $vcxproj = $target;
+    $vcxproj =~ s/(.*\/)?(.*)/$&\/$2.vcxproj/;
+    $vcxproj =~ s/([^\/]*)(\/lib)\/(lib.vcxproj)/$1$2\/$1_$3/;
+    $$build_structure{"$prefix${target}_VCXPROJ"} = $vcxproj;
+
+    my @srcs = sort(map("$rel_dir\\$_", @{$$build_structure{"$prefix${name}_SOURCES"}}));
+    my @sources;
+    foreach (@srcs) {
+        $_ =~ s/\//\\/g;
+        push(@sources, $_);
+    }
+    my $defines = join(";", sort(@{$$build_structure{"$prefix${name}_DEFINES"}}));
+    my $includes= join(";", sort(map { s/^-I//; s/\//\\/g; File::Spec->file_name_is_absolute($_) ? $_ : "$rel_dir\\$_" } @{$$build_structure{"$prefix${name}_INCLUDES"}}));
+    my $cflags = join(" ", sort(map { s/^-[GLMOWZ].*//; s/.* .*/"$&"/; $_; } @{$$build_structure{"$prefix${name}_CFLAGS"}}));
+    $cflags =~ s/</&lt;/g;
+    $cflags =~ s/>/&gt;/g;
+
+    my $libs_release = "\n    ";
+    my $libs_debug = "\n    ";
+    if (!$static_library) {
+      $libs_release = join(";", sort(grep /^(?!libgit\.lib|xdiff\/lib\.lib|vcs-svn\/lib\.lib)/, @{$$build_structure{"$prefix${name}_LIBS"}}));
+      $libs_debug = $libs_release;
+      $libs_debug =~ s/zlib\.lib/zlibd\.lib/g;
+      $libs_debug =~ s/libcurl\.lib/libcurl-d\.lib/g;
+    }
+
+    $defines =~ s/-D//g;
+    $defines =~ s/</&lt;/g;
+    $defines =~ s/>/&gt;/g;
+    $defines =~ s/\'//g;
+
+    die "Could not create the directory $target for $label project!\n" unless (-d "$target" || mkdir "$target");
+
+    open F, ">$vcxproj" or die "Could not open $vcxproj for writing!\n";
+    binmode F, ":crlf :utf8";
+    print F chr(0xFEFF);
+    print F << "EOM";
+<?xml version="1.0" encoding="utf-8"?>
+<Project DefaultTargets="Build" ToolsVersion="14.0" xmlns="http://schemas.microsoft.com/developer/msbuild/2003">
+  <ItemGroup Label="ProjectConfigurations">
+    <ProjectConfiguration Include="Debug|Win32">
+      <Configuration>Debug</Configuration>
+      <Platform>Win32</Platform>
+    </ProjectConfiguration>
+    <ProjectConfiguration Include="Release|Win32">
+      <Configuration>Release</Configuration>
+      <Platform>Win32</Platform>
+    </ProjectConfiguration>
+    <ProjectConfiguration Include="Debug|x64">
+      <Configuration>Debug</Configuration>
+      <Platform>x64</Platform>
+    </ProjectConfiguration>
+    <ProjectConfiguration Include="Release|x64">
+      <Configuration>Release</Configuration>
+      <Platform>x64</Platform>
+    </ProjectConfiguration>
+  </ItemGroup>
+  <PropertyGroup Label="Globals">
+    <ProjectGuid>$uuid</ProjectGuid>
+    <Keyword>Win32Proj</Keyword>
+    <VCPKGArch Condition="'\$(Platform)'=='Win32'">x86-windows</VCPKGArch>
+    <VCPKGArch Condition="'\$(Platform)'!='Win32'">x64-windows</VCPKGArch>
+    <VCPKGArchDirectory>$cdup\\compat\\vcbuild\\vcpkg\\installed\\\$(VCPKGArch)</VCPKGArchDirectory>
+    <VCPKGBinDirectory Condition="'\$(Configuration)'=='Debug'">\$(VCPKGArchDirectory)\\debug\\bin</VCPKGBinDirectory>
+    <VCPKGLibDirectory Condition="'\$(Configuration)'=='Debug'">\$(VCPKGArchDirectory)\\debug\\lib</VCPKGLibDirectory>
+    <VCPKGBinDirectory Condition="'\$(Configuration)'!='Debug'">\$(VCPKGArchDirectory)\\bin</VCPKGBinDirectory>
+    <VCPKGLibDirectory Condition="'\$(Configuration)'!='Debug'">\$(VCPKGArchDirectory)\\lib</VCPKGLibDirectory>
+    <VCPKGIncludeDirectory>\$(VCPKGArchDirectory)\\include</VCPKGIncludeDirectory>
+    <VCPKGLibs Condition="'\$(Configuration)'=='Debug'">$libs_debug</VCPKGLibs>
+    <VCPKGLibs Condition="'\$(Configuration)'!='Debug'">$libs_release</VCPKGLibs>
+  </PropertyGroup>
+  <Import Project="\$(VCTargetsPath)\\Microsoft.Cpp.Default.props" />
+  <PropertyGroup Condition="'\$(Configuration)'=='Debug'" Label="Configuration">
+    <UseDebugLibraries>true</UseDebugLibraries>
+    <LinkIncremental>true</LinkIncremental>
+  </PropertyGroup>
+  <PropertyGroup Condition="'\$(Configuration)'=='Release'" Label="Configuration">
+    <UseDebugLibraries>false</UseDebugLibraries>
+    <WholeProgramOptimization>true</WholeProgramOptimization>
+  </PropertyGroup>
+  <PropertyGroup>
+    <ConfigurationType>$config_type</ConfigurationType>
+    <PlatformToolset>v140</PlatformToolset>
+    <!-- <CharacterSet>UTF-8</CharacterSet> -->
+    <OutDir>..\\</OutDir>
+    <!-- <IntDir>\$(ProjectDir)\$(Configuration)\\</IntDir> -->
+  </PropertyGroup>
+  <Import Project="\$(VCTargetsPath)\\Microsoft.Cpp.props" />
+  <ImportGroup Label="ExtensionSettings">
+  </ImportGroup>
+  <ImportGroup Label="Shared">
+  </ImportGroup>
+  <ImportGroup Label="PropertySheets">
+    <Import Project="\$(UserRootDir)\\Microsoft.Cpp.\$(Platform).user.props" Condition="exists('\$(UserRootDir)\\Microsoft.Cpp.\$(Platform).user.props')" Label="LocalAppDataPlatform" />
+  </ImportGroup>
+  <PropertyGroup Label="UserMacros" />
+  <PropertyGroup>
+    <GenerateManifest>false</GenerateManifest>
+    <EnableManagedIncrementalBuild>true</EnableManagedIncrementalBuild>
+  </PropertyGroup>
+  <ItemDefinitionGroup>
+    <ClCompile>
+      <AdditionalOptions>$cflags %(AdditionalOptions)</AdditionalOptions>
+      <AdditionalIncludeDirectories>$cdup;$cdup\\compat;$cdup\\compat\\regex;$cdup\\compat\\win32;$cdup\\compat\\poll;$cdup\\compat\\vcbuild\\include;\$(VCPKGIncludeDirectory);%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
+      <EnableParallelCodeGeneration />
+      <InlineFunctionExpansion>OnlyExplicitInline</InlineFunctionExpansion>
+      <PrecompiledHeader />
+      <DebugInformationFormat>ProgramDatabase</DebugInformationFormat>
+    </ClCompile>
+    <Lib>
+      <SuppressStartupBanner>true</SuppressStartupBanner>
+    </Lib>
+    <Link>
+      <AdditionalLibraryDirectories>\$(VCPKGLibDirectory);%(AdditionalLibraryDirectories)</AdditionalLibraryDirectories>
+      <AdditionalDependencies>\$(VCPKGLibs);\$(AdditionalDependencies)</AdditionalDependencies>
+      <AdditionalOptions>invalidcontinue.obj %(AdditionalOptions)</AdditionalOptions>
+      <EntryPointSymbol>wmainCRTStartup</EntryPointSymbol>
+      <ManifestFile>$cdup\\compat\\win32\\git.manifest</ManifestFile>
+      <SubSystem>Console</SubSystem>
+    </Link>
+EOM
+    if ($target eq 'libgit') {
+        print F << "EOM";
+    <PreBuildEvent Condition="!Exists('$cdup\\compat\\vcbuild\\vcpkg\\installed\\\$(VCPKGArch)\\include\\openssl\\ssl.h')">
+      <Message>Initialize VCPKG</Message>
+      <Command>del "$cdup\\compat\\vcbuild\\vcpkg"</Command>
+      <Command>call "$cdup\\compat\\vcbuild\\vcpkg_install.bat"</Command>
+    </PreBuildEvent>
+EOM
+    }
+    print F << "EOM";
+  </ItemDefinitionGroup>
+  <ItemDefinitionGroup Condition="'\$(Platform)'=='Win32'">
+    <Link>
+      <TargetMachine>MachineX86</TargetMachine>
+    </Link>
+  </ItemDefinitionGroup>
+  <ItemDefinitionGroup Condition="'\$(Configuration)'=='Debug'">
+    <ClCompile>
+      <Optimization>Disabled</Optimization>
+      <PreprocessorDefinitions>WIN32;_DEBUG;$defines;%(PreprocessorDefinitions)</PreprocessorDefinitions>
+      <RuntimeLibrary>MultiThreadedDebugDLL</RuntimeLibrary>
+    </ClCompile>
+    <Link>
+      <GenerateDebugInformation>true</GenerateDebugInformation>
+    </Link>
+  </ItemDefinitionGroup>
+  <ItemDefinitionGroup Condition="'\$(Configuration)'=='Release'">
+    <ClCompile>
+      <Optimization>MaxSpeed</Optimization>
+      <IntrinsicFunctions>true</IntrinsicFunctions>
+      <PreprocessorDefinitions>WIN32;NDEBUG;$defines;%(PreprocessorDefinitions)</PreprocessorDefinitions>
+      <RuntimeLibrary>MultiThreadedDLL</RuntimeLibrary>
+      <FunctionLevelLinking>true</FunctionLevelLinking>
+      <FavorSizeOrSpeed>Speed</FavorSizeOrSpeed>
+    </ClCompile>
+    <Link>
+      <GenerateDebugInformation>true</GenerateDebugInformation>
+      <EnableCOMDATFolding>true</EnableCOMDATFolding>
+      <OptimizeReferences>true</OptimizeReferences>
+    </Link>
+  </ItemDefinitionGroup>
+  <ItemGroup>
+EOM
+    foreach(@sources) {
+        print F << "EOM";
+    <ClCompile Include="$_" />
+EOM
+    }
+    print F << "EOM";
+  </ItemGroup>
+EOM
+    if (!$static_library || $target =~ 'vcs-svn' || $target =~ 'xdiff') {
+      my $uuid_libgit = $$build_structure{"LIBS_libgit_GUID"};
+      my $uuid_xdiff_lib = $$build_structure{"LIBS_xdiff/lib_GUID"};
+
+      print F << "EOM";
+  <ItemGroup>
+    <ProjectReference Include="$cdup\\libgit\\libgit.vcxproj">
+      <Project>$uuid_libgit</Project>
+      <ReferenceOutputAssembly>false</ReferenceOutputAssembly>
+    </ProjectReference>
+EOM
+      if (!($name =~ 'xdiff')) {
+        print F << "EOM";
+    <ProjectReference Include="$cdup\\xdiff\\lib\\xdiff_lib.vcxproj">
+      <Project>$uuid_xdiff_lib</Project>
+      <ReferenceOutputAssembly>false</ReferenceOutputAssembly>
+    </ProjectReference>
+EOM
+      }
+      if ($name =~ /(test-(line-buffer|svn-fe)|^git-remote-testsvn)\.exe$/) {
+        my $uuid_vcs_svn_lib = $$build_structure{"LIBS_vcs-svn/lib_GUID"};
+        print F << "EOM";
+    <ProjectReference Include="$cdup\\vcs-svn\\lib\\vcs-svn_lib.vcxproj">
+      <Project>$uuid_vcs_svn_lib</Project>
+      <ReferenceOutputAssembly>false</ReferenceOutputAssembly>
+    </ProjectReference>
+EOM
+      }
+      print F << "EOM";
+  </ItemGroup>
+EOM
+    }
+    print F << "EOM";
+  <Import Project="\$(VCTargetsPath)\\Microsoft.Cpp.targets" />
+EOM
+    if (!$static_library) {
+      print F << "EOM";
+  <Target Name="${target}_AfterBuild" AfterTargets="AfterBuild">
+    <ItemGroup>
+      <DLLsAndPDBs Include="\$(VCPKGBinDirectory)\\*.dll;\$(VCPKGBinDirectory)\\*.pdb" />
+    </ItemGroup>
+    <Copy SourceFiles="@(DLLsAndPDBs)" DestinationFolder="\$(OutDir)" SkipUnchangedFiles="true" UseHardlinksIfPossible="true" />
+    <MakeDir Directories="..\\templates\\blt\\branches" />
+  </Target>
+EOM
+    }
+    if ($target eq 'git') {
+      print F "  <Import Project=\"LinkOrCopyBuiltins.targets\" />\n";
+    }
+    if ($target eq 'git-remote-http') {
+      print F "  <Import Project=\"LinkOrCopyRemoteHttp.targets\" />\n";
+    }
+    print F << "EOM";
+</Project>
+EOM
+    close F;
+}
+
+sub createGlueProject {
+    my ($git_dir, $out_dir, $rel_dir, %build_structure) = @_;
+    print "Generate solutions file\n";
+    $rel_dir = "..\\$rel_dir";
+    $rel_dir =~ s/\//\\/g;
+    my $SLN_HEAD = "Microsoft Visual Studio Solution File, Format Version 11.00\n# Visual Studio 2010\n";
+    my $SLN_PRE  = "Project(\"{8BC9CEB8-8B4A-11D0-8D11-00A0C91BC942}\") = ";
+    my $SLN_POST = "\nEndProject\n";
+
+    my @libs = @{$build_structure{"LIBS"}};
+    my @tmp;
+    foreach (@libs) {
+        $_ =~ s/\.a//;
+        push(@tmp, $_);
+    }
+    @libs = @tmp;
+
+    my @apps = @{$build_structure{"APPS"}};
+    @tmp = ();
+    foreach (@apps) {
+        $_ =~ s/\.exe//;
+        if ($_ eq "git" ) {
+            unshift(@tmp, $_);
+        } else {
+            push(@tmp, $_);
+        }
+    }
+    @apps = @tmp;
+
+    open F, ">git.sln" || die "Could not open git.sln for writing!\n";
+    binmode F, ":crlf :utf8";
+    print F chr(0xFEFF);
+    print F "$SLN_HEAD";
+
+    foreach (@apps) {
+        my $appname = $_;
+        my $uuid = $build_structure{"APPS_${appname}_GUID"};
+        print F "$SLN_PRE";
+	my $vcxproj = $build_structure{"APPS_${appname}_VCXPROJ"};
+	$vcxproj =~ s/\//\\/g;
+        $appname =~ s/.*\///;
+        print F "\"${appname}\", \"${vcxproj}\", \"${uuid}\"";
+        print F "$SLN_POST";
+    }
+    foreach (@libs) {
+        my $libname = $_;
+        my $uuid = $build_structure{"LIBS_${libname}_GUID"};
+        print F "$SLN_PRE";
+        my $vcxproj = $build_structure{"LIBS_${libname}_VCXPROJ"};
+	$vcxproj =~ s/\//\\/g;
+        $libname =~ s/\//_/g;
+        print F "\"${libname}\", \"${vcxproj}\", \"${uuid}\"";
+        print F "$SLN_POST";
+    }
+
+    print F << "EOM";
+Global
+	GlobalSection(SolutionConfigurationPlatforms) = preSolution
+		Debug|x64 = Debug|x64
+		Debug|x86 = Debug|x86
+		Release|x64 = Release|x64
+		Release|x86 = Release|x86
+	EndGlobalSection
+EOM
+    print F << "EOM";
+	GlobalSection(ProjectConfigurationPlatforms) = postSolution
+EOM
+    foreach (@apps) {
+        my $appname = $_;
+        my $uuid = $build_structure{"APPS_${appname}_GUID"};
+        print F "\t\t${uuid}.Debug|x64.ActiveCfg = Debug|x64\n";
+        print F "\t\t${uuid}.Debug|x64.Build.0 = Debug|x64\n";
+        print F "\t\t${uuid}.Debug|x86.ActiveCfg = Debug|Win32\n";
+        print F "\t\t${uuid}.Debug|x86.Build.0 = Debug|Win32\n";
+        print F "\t\t${uuid}.Release|x64.ActiveCfg = Release|x64\n";
+        print F "\t\t${uuid}.Release|x64.Build.0 = Release|x64\n";
+        print F "\t\t${uuid}.Release|x86.ActiveCfg = Release|Win32\n";
+        print F "\t\t${uuid}.Release|x86.Build.0 = Release|Win32\n";
+    }
+    foreach (@libs) {
+        my $libname = $_;
+        my $uuid = $build_structure{"LIBS_${libname}_GUID"};
+        print F "\t\t${uuid}.Debug|x64.ActiveCfg = Debug|x64\n";
+        print F "\t\t${uuid}.Debug|x64.Build.0 = Debug|x64\n";
+        print F "\t\t${uuid}.Debug|x86.ActiveCfg = Debug|Win32\n";
+        print F "\t\t${uuid}.Debug|x86.Build.0 = Debug|Win32\n";
+        print F "\t\t${uuid}.Release|x64.ActiveCfg = Release|x64\n";
+        print F "\t\t${uuid}.Release|x64.Build.0 = Release|x64\n";
+        print F "\t\t${uuid}.Release|x86.ActiveCfg = Release|Win32\n";
+        print F "\t\t${uuid}.Release|x86.Build.0 = Release|Win32\n";
+    }
+
+    print F << "EOM";
+	EndGlobalSection
+	GlobalSection(SolutionProperties) = preSolution
+		HideSolutionNode = FALSE
+	EndGlobalSection
+EndGlobal
+EOM
+    close F;
+}
+
+1;
diff -pruN 1.2.1+git2.18.0-1/git/contrib/buildsystems/Generators.pm 1.2.3+git2.25.1-1/git/contrib/buildsystems/Generators.pm
--- 1.2.1+git2.18.0-1/git/contrib/buildsystems/Generators.pm	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/contrib/buildsystems/Generators.pm	2020-02-17 04:47:35.000000000 +0000
@@ -17,7 +17,7 @@ BEGIN {
     $me = dirname($me);
     if (opendir(D,"$me/Generators")) {
         foreach my $gen (readdir(D)) {
-            next if ($gen  =~ /^\.\.?$/);
+            next unless ($gen  =~ /\.pm$/);
             require "${me}/Generators/$gen";
             $gen =~ s,\.pm,,;
             push(@AVAILABLE, $gen);
diff -pruN 1.2.1+git2.18.0-1/git/contrib/coccinelle/array.cocci 1.2.3+git2.25.1-1/git/contrib/coccinelle/array.cocci
--- 1.2.1+git2.18.0-1/git/contrib/coccinelle/array.cocci	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/contrib/coccinelle/array.cocci	2020-02-17 04:47:35.000000000 +0000
@@ -1,29 +1,60 @@
 @@
-type T;
-T *dst;
-T *src;
-expression n;
+expression dst, src, n, E;
 @@
-- memcpy(dst, src, (n) * sizeof(*dst));
-+ COPY_ARRAY(dst, src, n);
+  memcpy(dst, src, n * sizeof(
+- E[...]
++ *(E)
+  ))
 
 @@
 type T;
-T *dst;
-T *src;
-expression n;
-@@
-- memcpy(dst, src, (n) * sizeof(*src));
-+ COPY_ARRAY(dst, src, n);
+T *ptr;
+T[] arr;
+expression E, n;
+@@
+(
+  memcpy(ptr, E,
+- n * sizeof(*(ptr))
++ n * sizeof(T)
+  )
+|
+  memcpy(arr, E,
+- n * sizeof(*(arr))
++ n * sizeof(T)
+  )
+|
+  memcpy(E, ptr,
+- n * sizeof(*(ptr))
++ n * sizeof(T)
+  )
+|
+  memcpy(E, arr,
+- n * sizeof(*(arr))
++ n * sizeof(T)
+  )
+)
 
 @@
 type T;
-T *dst;
-T *src;
+T *dst_ptr;
+T *src_ptr;
+T[] dst_arr;
+T[] src_arr;
 expression n;
 @@
-- memcpy(dst, src, (n) * sizeof(T));
-+ COPY_ARRAY(dst, src, n);
+(
+- memcpy(dst_ptr, src_ptr, (n) * sizeof(T))
++ COPY_ARRAY(dst_ptr, src_ptr, n)
+|
+- memcpy(dst_ptr, src_arr, (n) * sizeof(T))
++ COPY_ARRAY(dst_ptr, src_arr, n)
+|
+- memcpy(dst_arr, src_ptr, (n) * sizeof(T))
++ COPY_ARRAY(dst_arr, src_ptr, n)
+|
+- memcpy(dst_arr, src_arr, (n) * sizeof(T))
++ COPY_ARRAY(dst_arr, src_arr, n)
+)
 
 @@
 type T;
diff -pruN 1.2.1+git2.18.0-1/git/contrib/coccinelle/commit.cocci 1.2.3+git2.25.1-1/git/contrib/coccinelle/commit.cocci
--- 1.2.1+git2.18.0-1/git/contrib/coccinelle/commit.cocci	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/contrib/coccinelle/commit.cocci	2020-02-17 04:47:35.000000000 +0000
@@ -10,19 +10,25 @@ expression c;
 - c->maybe_tree->object.oid.hash
 + get_commit_tree_oid(c)->hash
 
-// These excluded functions must access c->maybe_tree direcly.
 @@
-identifier f !~ "^(get_commit_tree|get_commit_tree_in_graph|load_tree_for_commit)$";
+identifier f !~ "^set_commit_tree$";
 expression c;
+expression s;
 @@
-  f(...) {...
-- c->maybe_tree
-+ get_commit_tree(c)
-  ...}
+  f(...) {<...
+- c->maybe_tree = s
++ set_commit_tree(c, s)
+  ...>}
 
+// These excluded functions must access c->maybe_tree directly.
+// Note that if c->maybe_tree is written somewhere outside of these
+// functions, then the recommended transformation will be bogus with
+// repo_get_commit_tree() on the LHS.
 @@
+identifier f !~ "^(repo_get_commit_tree|get_commit_tree_in_graph_one|load_tree_for_commit|set_commit_tree)$";
 expression c;
-expression s;
 @@
-- get_commit_tree(c) = s
-+ c->maybe_tree = s
+  f(...) {<...
+- c->maybe_tree
++ repo_get_commit_tree(specify_the_right_repo_here, c)
+  ...>}
diff -pruN 1.2.1+git2.18.0-1/git/contrib/coccinelle/flex_alloc.cocci 1.2.3+git2.25.1-1/git/contrib/coccinelle/flex_alloc.cocci
--- 1.2.1+git2.18.0-1/git/contrib/coccinelle/flex_alloc.cocci	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/contrib/coccinelle/flex_alloc.cocci	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,13 @@
+@@
+expression str;
+identifier x, flexname;
+@@
+- FLEX_ALLOC_MEM(x, flexname, str, strlen(str));
++ FLEX_ALLOC_STR(x, flexname, str);
+
+@@
+expression str;
+identifier x, ptrname;
+@@
+- FLEXPTR_ALLOC_MEM(x, ptrname, str, strlen(str));
++ FLEXPTR_ALLOC_STR(x, ptrname, str);
diff -pruN 1.2.1+git2.18.0-1/git/contrib/coccinelle/hashmap.cocci 1.2.3+git2.25.1-1/git/contrib/coccinelle/hashmap.cocci
--- 1.2.1+git2.18.0-1/git/contrib/coccinelle/hashmap.cocci	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/contrib/coccinelle/hashmap.cocci	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,16 @@
+@ hashmap_entry_init_usage @
+expression E;
+struct hashmap_entry HME;
+@@
+- HME.hash = E;
++ hashmap_entry_init(&HME, E);
+
+@@
+identifier f !~ "^hashmap_entry_init$";
+expression E;
+struct hashmap_entry *HMEP;
+@@
+  f(...) {<...
+- HMEP->hash = E;
++ hashmap_entry_init(HMEP, E);
+  ...>}
diff -pruN 1.2.1+git2.18.0-1/git/contrib/coccinelle/object_id.cocci 1.2.3+git2.25.1-1/git/contrib/coccinelle/object_id.cocci
--- 1.2.1+git2.18.0-1/git/contrib/coccinelle/object_id.cocci	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/contrib/coccinelle/object_id.cocci	2020-02-17 04:47:35.000000000 +0000
@@ -1,110 +1,87 @@
 @@
-expression E1;
+struct object_id OID;
 @@
-- is_null_sha1(E1.hash)
-+ is_null_oid(&E1)
+- is_null_sha1(OID.hash)
++ is_null_oid(&OID)
 
 @@
-expression E1;
+struct object_id *OIDPTR;
 @@
-- is_null_sha1(E1->hash)
-+ is_null_oid(E1)
+- is_null_sha1(OIDPTR->hash)
++ is_null_oid(OIDPTR)
 
 @@
-expression E1;
+struct object_id OID;
 @@
-- sha1_to_hex(E1.hash)
-+ oid_to_hex(&E1)
-
-@@
-identifier f != oid_to_hex;
-expression E1;
-@@
-  f(...) {...
-- sha1_to_hex(E1->hash)
-+ oid_to_hex(E1)
-  ...}
-
-@@
-expression E1, E2;
-@@
-- sha1_to_hex_r(E1, E2.hash)
-+ oid_to_hex_r(E1, &E2)
-
-@@
-identifier f != oid_to_hex_r;
-expression E1, E2;
-@@
-   f(...) {...
-- sha1_to_hex_r(E1, E2->hash)
-+ oid_to_hex_r(E1, E2)
-  ...}
-
-@@
-expression E1;
-@@
-- hashclr(E1.hash)
-+ oidclr(&E1)
+- hashclr(OID.hash)
++ oidclr(&OID)
 
 @@
 identifier f != oidclr;
-expression E1;
+struct object_id *OIDPTR;
 @@
-  f(...) {...
-- hashclr(E1->hash)
-+ oidclr(E1)
-  ...}
+  f(...) {<...
+- hashclr(OIDPTR->hash)
++ oidclr(OIDPTR)
+  ...>}
 
 @@
-expression E1, E2;
+struct object_id OID1, OID2;
 @@
-- hashcmp(E1.hash, E2.hash)
-+ oidcmp(&E1, &E2)
+- hashcmp(OID1.hash, OID2.hash)
++ oidcmp(&OID1, &OID2)
 
 @@
 identifier f != oidcmp;
-expression E1, E2;
+struct object_id *OIDPTR1, OIDPTR2;
 @@
-  f(...) {...
-- hashcmp(E1->hash, E2->hash)
-+ oidcmp(E1, E2)
-  ...}
+  f(...) {<...
+- hashcmp(OIDPTR1->hash, OIDPTR2->hash)
++ oidcmp(OIDPTR1, OIDPTR2)
+  ...>}
 
 @@
-expression E1, E2;
+struct object_id *OIDPTR;
+struct object_id OID;
 @@
-- hashcmp(E1->hash, E2.hash)
-+ oidcmp(E1, &E2)
+- hashcmp(OIDPTR->hash, OID.hash)
++ oidcmp(OIDPTR, &OID)
 
 @@
-expression E1, E2;
+struct object_id *OIDPTR;
+struct object_id OID;
 @@
-- hashcmp(E1.hash, E2->hash)
-+ oidcmp(&E1, E2)
+- hashcmp(OID.hash, OIDPTR->hash)
++ oidcmp(&OID, OIDPTR)
 
 @@
-expression E1, E2;
+struct object_id *OIDPTR1;
+struct object_id *OIDPTR2;
 @@
-- hashcpy(E1.hash, E2.hash)
-+ oidcpy(&E1, &E2)
+- oidcmp(OIDPTR1, OIDPTR2) == 0
++ oideq(OIDPTR1, OIDPTR2)
 
 @@
-identifier f != oidcpy;
+identifier f != hasheq;
 expression E1, E2;
 @@
-  f(...) {...
-- hashcpy(E1->hash, E2->hash)
-+ oidcpy(E1, E2)
-  ...}
+  f(...) {<...
+- hashcmp(E1, E2) == 0
++ hasheq(E1, E2)
+  ...>}
 
 @@
-expression E1, E2;
+struct object_id *OIDPTR1;
+struct object_id *OIDPTR2;
 @@
-- hashcpy(E1->hash, E2.hash)
-+ oidcpy(E1, &E2)
+- oidcmp(OIDPTR1, OIDPTR2) != 0
++ !oideq(OIDPTR1, OIDPTR2)
 
 @@
+identifier f != hasheq;
 expression E1, E2;
 @@
-- hashcpy(E1.hash, E2->hash)
-+ oidcpy(&E1, E2)
+  f(...) {<...
+- hashcmp(E1, E2) != 0
++ !hasheq(E1, E2)
+  ...>}
diff -pruN 1.2.1+git2.18.0-1/git/contrib/coccinelle/preincr.cocci 1.2.3+git2.25.1-1/git/contrib/coccinelle/preincr.cocci
--- 1.2.1+git2.18.0-1/git/contrib/coccinelle/preincr.cocci	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/contrib/coccinelle/preincr.cocci	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,5 @@
+@ preincrement @
+identifier i;
+@@
+- ++i > 1
++ i++
diff -pruN 1.2.1+git2.18.0-1/git/contrib/coccinelle/README 1.2.3+git2.25.1-1/git/contrib/coccinelle/README
--- 1.2.1+git2.18.0-1/git/contrib/coccinelle/README	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/contrib/coccinelle/README	2020-02-17 04:47:35.000000000 +0000
@@ -1,2 +1,43 @@
 This directory provides examples of Coccinelle (http://coccinelle.lip6.fr/)
 semantic patches that might be useful to developers.
+
+There are two types of semantic patches:
+
+ * Using the semantic transformation to check for bad patterns in the code;
+   The target 'make coccicheck' is designed to check for these patterns and
+   it is expected that any resulting patch indicates a regression.
+   The patches resulting from 'make coccicheck' are small and infrequent,
+   so once they are found, they can be sent to the mailing list as per usual.
+
+   Example for introducing new patterns:
+   67947c34ae (convert "hashcmp() != 0" to "!hasheq()", 2018-08-28)
+   b84c783882 (fsck: s/++i > 1/i++/, 2018-10-24)
+
+   Example of fixes using this approach:
+   248f66ed8e (run-command: use strbuf_addstr() for adding a string to
+               a strbuf, 2018-03-25)
+   f919ffebed (Use MOVE_ARRAY, 2018-01-22)
+
+   These types of semantic patches are usually part of testing, c.f.
+   0860a7641b (travis-ci: fail if Coccinelle static analysis found something
+               to transform, 2018-07-23)
+
+ * Using semantic transformations in large scale refactorings throughout
+   the code base.
+
+   When applying the semantic patch into a real patch, sending it to the
+   mailing list in the usual way, such a patch would be expected to have a
+   lot of textual and semantic conflicts as such large scale refactorings
+   change function signatures that are used widely in the code base.
+   A textual conflict would arise if surrounding code near any call of such
+   function changes. A semantic conflict arises when other patch series in
+   flight introduce calls to such functions.
+
+   So to aid these large scale refactorings, semantic patches can be used.
+   However we do not want to store them in the same place as the checks for
+   bad patterns, as then automated builds would fail.
+   That is why semantic patches 'contrib/coccinelle/*.pending.cocci'
+   are ignored for checks, and can be applied using 'make coccicheck-pending'.
+
+   This allows to expose plans of pending large scale refactorings without
+   impacting the bad pattern checks.
diff -pruN 1.2.1+git2.18.0-1/git/contrib/coccinelle/strbuf.cocci 1.2.3+git2.25.1-1/git/contrib/coccinelle/strbuf.cocci
--- 1.2.1+git2.18.0-1/git/contrib/coccinelle/strbuf.cocci	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/contrib/coccinelle/strbuf.cocci	2020-02-17 04:47:35.000000000 +0000
@@ -13,6 +13,36 @@ constant fmt !~ "%";
   );
 
 @@
+expression E;
+struct strbuf SB;
+format F =~ "s";
+@@
+- strbuf_addf(E, "%@F@", SB.buf);
++ strbuf_addbuf(E, &SB);
+
+@@
+expression E;
+struct strbuf *SBP;
+format F =~ "s";
+@@
+- strbuf_addf(E, "%@F@", SBP->buf);
++ strbuf_addbuf(E, SBP);
+
+@@
+expression E;
+struct strbuf SB;
+@@
+- strbuf_addstr(E, SB.buf);
++ strbuf_addbuf(E, &SB);
+
+@@
+expression E;
+struct strbuf *SBP;
+@@
+- strbuf_addstr(E, SBP->buf);
++ strbuf_addbuf(E, SBP);
+
+@@
 expression E1, E2;
 format F =~ "s";
 @@
diff -pruN 1.2.1+git2.18.0-1/git/contrib/coccinelle/the_repository.pending.cocci 1.2.3+git2.25.1-1/git/contrib/coccinelle/the_repository.pending.cocci
--- 1.2.1+git2.18.0-1/git/contrib/coccinelle/the_repository.pending.cocci	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/contrib/coccinelle/the_repository.pending.cocci	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,144 @@
+// This file is used for the ongoing refactoring of
+// bringing the index or repository struct in all of
+// our code base.
+
+@@
+expression E;
+expression F;
+expression G;
+@@
+- read_object_file(
++ repo_read_object_file(the_repository,
+  E, F, G)
+
+@@
+expression E;
+@@
+- has_sha1_file(
++ repo_has_sha1_file(the_repository,
+  E)
+
+@@
+expression E;
+expression F;
+@@
+- has_sha1_file_with_flags(
++ repo_has_sha1_file_with_flags(the_repository,
+  E)
+
+@@
+expression E;
+@@
+- has_object_file(
++ repo_has_object_file(the_repository,
+  E)
+
+@@
+expression E;
+expression F;
+@@
+- has_object_file_with_flags(
++ repo_has_object_file_with_flags(the_repository,
+  E)
+
+@@
+expression E;
+expression F;
+expression G;
+@@
+- parse_commit_internal(
++ repo_parse_commit_internal(the_repository,
+  E, F, G)
+
+@@
+expression E;
+expression F;
+@@
+- parse_commit_gently(
++ repo_parse_commit_gently(the_repository,
+  E, F)
+
+@@
+expression E;
+@@
+- parse_commit(
++ repo_parse_commit(the_repository,
+  E)
+
+@@
+expression E;
+expression F;
+@@
+- get_merge_bases(
++ repo_get_merge_bases(the_repository,
+  E, F);
+
+@@
+expression E;
+expression F;
+expression G;
+@@
+- get_merge_bases_many(
++ repo_get_merge_bases_many(the_repository,
+  E, F, G);
+
+@@
+expression E;
+expression F;
+expression G;
+@@
+- get_merge_bases_many_dirty(
++ repo_get_merge_bases_many_dirty(the_repository,
+  E, F, G);
+
+@@
+expression E;
+expression F;
+@@
+- in_merge_bases(
++ repo_in_merge_bases(the_repository,
+  E, F);
+
+@@
+expression E;
+expression F;
+expression G;
+@@
+- in_merge_bases_many(
++ repo_in_merge_bases_many(the_repository,
+  E, F, G);
+
+@@
+expression E;
+expression F;
+@@
+- get_commit_buffer(
++ repo_get_commit_buffer(the_repository,
+  E, F);
+
+@@
+expression E;
+expression F;
+@@
+- unuse_commit_buffer(
++ repo_unuse_commit_buffer(the_repository,
+  E, F);
+
+@@
+expression E;
+expression F;
+expression G;
+@@
+- logmsg_reencode(
++ repo_logmsg_reencode(the_repository,
+  E, F, G);
+
+@@
+expression E;
+expression F;
+expression G;
+expression H;
+@@
+- format_commit_message(
++ repo_format_commit_message(the_repository,
+  E, F, G, H);
diff -pruN 1.2.1+git2.18.0-1/git/contrib/completion/git-completion.bash 1.2.3+git2.25.1-1/git/contrib/completion/git-completion.bash
--- 1.2.1+git2.18.0-1/git/contrib/completion/git-completion.bash	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/contrib/completion/git-completion.bash	2020-02-17 04:47:35.000000000 +0000
@@ -37,7 +37,8 @@
 #   GIT_COMPLETION_CHECKOUT_NO_GUESS
 #
 #     When set to "1", do not include "DWIM" suggestions in git-checkout
-#     completion (e.g., completing "foo" when "origin/foo" exists).
+#     and git-switch completion (e.g., completing "foo" when "origin/foo"
+#     exists).
 
 case "$COMP_WORDBREAKS" in
 *:*) : great ;;
@@ -330,13 +331,36 @@ __gitcomp ()
 	case "$cur_" in
 	--*=)
 		;;
+	--no-*)
+		local c i=0 IFS=$' \t\n'
+		for c in $1; do
+			if [[ $c == "--" ]]; then
+				continue
+			fi
+			c="$c${4-}"
+			if [[ $c == "$cur_"* ]]; then
+				case $c in
+				--*=|*.) ;;
+				*) c="$c " ;;
+				esac
+				COMPREPLY[i++]="${2-}$c"
+			fi
+		done
+		;;
 	*)
 		local c i=0 IFS=$' \t\n'
 		for c in $1; do
+			if [[ $c == "--" ]]; then
+				c="--no-...${4-}"
+				if [[ $c == "$cur_"* ]]; then
+					COMPREPLY[i++]="${2-}$c "
+				fi
+				break
+			fi
 			c="$c${4-}"
 			if [[ $c == "$cur_"* ]]; then
 				case $c in
-				--*=*|*.) ;;
+				*=|*.) ;;
 				*) c="$c " ;;
 				esac
 				COMPREPLY[i++]="${2-}$c"
@@ -377,7 +401,8 @@ __gitcomp_builtin ()
 	if [ -z "$options" ]; then
 		# leading and trailing spaces are significant to make
 		# option removal work correctly.
-		options=" $(__git ${cmd/_/ } --git-completion-helper) $incl "
+		options=" $incl $(__git ${cmd/_/ } --git-completion-helper) " || return
+
 		for i in $excl; do
 			options="${options/ $i / }"
 		done
@@ -415,7 +440,7 @@ __gitcomp_nl ()
 # Callers must take care of providing only paths that match the current path
 # to be completed and adding any prefix path components, if necessary.
 # 1: List of newline-separated matching paths, complete with all prefix
-#    path componens.
+#    path components.
 __gitcomp_file_direct ()
 {
 	local IFS=$'\n'
@@ -499,7 +524,7 @@ __git_index_files ()
 			# Even when a directory name itself does not contain
 			# any special characters, it will still be quoted if
 			# any of its (stripped) trailing path components do.
-			# Because of this we may have seen the same direcory
+			# Because of this we may have seen the same directory
 			# both quoted and unquoted.
 			if (p in paths)
 				# We have seen the same directory unquoted,
@@ -525,7 +550,7 @@ __git_index_files ()
 						 esc_idx, 1)
 			} else if (esc == "n") {
 				# Uh-oh, a newline character.
-				# We cant reliably put a pathname
+				# We cannot reliably put a pathname
 				# containing a newline into COMPREPLY,
 				# and the newline would create a mess.
 				# Skip this path.
@@ -540,7 +565,7 @@ __git_index_files ()
 			}
 		}
 		# Drop closing double quote, if there is one.
-		# (There isnt any if this is a directory, as it was
+		# (There is not any if this is a directory, as it was
 		# already stripped with the trailing path components.)
 		if (substr(p, length(p), 1) == "\"")
 			out = out substr(p, 1, length(p) - 1)
@@ -830,9 +855,14 @@ __git_compute_merge_strategies ()
 	__git_merge_strategies=$(__git_list_merge_strategies)
 }
 
+__git_merge_strategy_options="ours theirs subtree subtree= patience
+	histogram diff-algorithm= ignore-space-change ignore-all-space
+	ignore-space-at-eol renormalize no-renormalize no-renames
+	find-renames find-renames= rename-threshold="
+
 __git_complete_revlist_file ()
 {
-	local pfx ls ref cur_="$cur"
+	local dequoted_word pfx ls ref cur_="$cur"
 	case "$cur_" in
 	*..?*:*)
 		return
@@ -840,14 +870,18 @@ __git_complete_revlist_file ()
 	?*:*)
 		ref="${cur_%%:*}"
 		cur_="${cur_#*:}"
-		case "$cur_" in
+
+		__git_dequote "$cur_"
+
+		case "$dequoted_word" in
 		?*/*)
-			pfx="${cur_%/*}"
-			cur_="${cur_##*/}"
+			pfx="${dequoted_word%/*}"
+			cur_="${dequoted_word##*/}"
 			ls="$ref:$pfx"
 			pfx="$pfx/"
 			;;
 		*)
+			cur_="$dequoted_word"
 			ls="$ref"
 			;;
 		esac
@@ -857,21 +891,10 @@ __git_complete_revlist_file ()
 		*)   pfx="$ref:$pfx" ;;
 		esac
 
-		__gitcomp_nl "$(__git ls-tree "$ls" \
-				| sed '/^100... blob /{
-				           s,^.*	,,
-				           s,$, ,
-				       }
-				       /^120000 blob /{
-				           s,^.*	,,
-				           s,$, ,
-				       }
-				       /^040000 tree /{
-				           s,^.*	,,
-				           s,$,/,
-				       }
-				       s/^.*	//')" \
-			"$pfx" "$cur_" ""
+		__gitcomp_file "$(__git ls-tree "$ls" \
+				| sed 's/^.*	//
+				       s/$//')" \
+			"$pfx" "$cur_"
 		;;
 	*...*)
 		pfx="${cur_%...*}..."
@@ -920,6 +943,7 @@ __git_complete_remote_or_refspec ()
 			*) ;;
 			esac
 			;;
+		--multiple) no_complete_refspec=1; break ;;
 		-*) ;;
 		*) remote="$i"; break ;;
 		esac
@@ -979,12 +1003,21 @@ __git_complete_strategy ()
 	-s|--strategy)
 		__gitcomp "$__git_merge_strategies"
 		return 0
+		;;
+	-X)
+		__gitcomp "$__git_merge_strategy_options"
+		return 0
+		;;
 	esac
 	case "$cur" in
 	--strategy=*)
 		__gitcomp "$__git_merge_strategies" "" "${cur##--strategy=}"
 		return 0
 		;;
+	--strategy-option=*)
+		__gitcomp "$__git_merge_strategy_options" "" "${cur##--strategy-option=}"
+		return 0
+		;;
 	esac
 	return 1
 }
@@ -993,7 +1026,7 @@ __git_all_commands=
 __git_compute_all_commands ()
 {
 	test -n "$__git_all_commands" ||
-	__git_all_commands=$(git --list-cmds=main,others,alias,nohelpers)
+	__git_all_commands=$(__git --list-cmds=main,others,alias,nohelpers)
 }
 
 # Lists all set config variables starting with the given section prefix,
@@ -1146,6 +1179,7 @@ __git_count_arguments ()
 }
 
 __git_whitespacelist="nowarn warn error error-all fix"
+__git_patchformat="mbox stgit stgit-series hg mboxrd"
 __git_am_inprogress_options="--skip --continue --resolved --abort --quit --show-current-patch"
 
 _git_am ()
@@ -1160,8 +1194,12 @@ _git_am ()
 		__gitcomp "$__git_whitespacelist" "" "${cur##--whitespace=}"
 		return
 		;;
+	--patch-format=*)
+		__gitcomp "$__git_patchformat" "" "${cur##--patch-format=}"
+		return
+		;;
 	--*)
-		__gitcomp_builtin am "--no-utf8" \
+		__gitcomp_builtin am "" \
 			"$__git_am_inprogress_options"
 		return
 	esac
@@ -1183,6 +1221,10 @@ _git_apply ()
 _git_add ()
 {
 	case "$cur" in
+	--chmod=*)
+		__gitcomp "+x -x" "" "${cur##--chmod=}"
+		return
+		;;
 	--*)
 		__gitcomp_builtin add
 		return
@@ -1208,10 +1250,7 @@ _git_archive ()
 		return
 		;;
 	--*)
-		__gitcomp "
-			--format= --list --verbose
-			--prefix= --remote= --exec= --output
-			"
+		__gitcomp_builtin archive "--format= --list --verbose --prefix= --worktree-attributes"
 		return
 		;;
 	esac
@@ -1243,6 +1282,8 @@ _git_bisect ()
 	esac
 }
 
+__git_ref_fieldlist="refname objecttype objectsize objectname upstream push HEAD symref"
+
 _git_branch ()
 {
 	local i c=1 only_local_ref="n" has_r="n"
@@ -1261,9 +1302,7 @@ _git_branch ()
 		__git_complete_refs --cur="${cur##--set-upstream-to=}"
 		;;
 	--*)
-		__gitcomp_builtin branch "--no-color --no-abbrev
-			--no-track --no-column
-			"
+		__gitcomp_builtin branch
 		;;
 	*)
 		if [ $only_local_ref = "y" -a $has_r = "n" ]; then
@@ -1304,7 +1343,7 @@ _git_checkout ()
 		__gitcomp "diff3 merge" "" "${cur##--conflict=}"
 		;;
 	--*)
-		__gitcomp_builtin checkout "--no-track --no-recurse-submodules"
+		__gitcomp_builtin checkout
 		;;
 	*)
 		# check if --track, --no-track, or --no-guess was specified
@@ -1319,18 +1358,9 @@ _git_checkout ()
 	esac
 }
 
-_git_cherry ()
-{
-	case "$cur" in
-	--*)
-		__gitcomp_builtin cherry
-		return
-	esac
-
-	__git_complete_refs
-}
+__git_sequencer_inprogress_options="--continue --quit --abort --skip"
 
-__git_cherry_pick_inprogress_options="--continue --quit --abort"
+__git_cherry_pick_inprogress_options=$__git_sequencer_inprogress_options
 
 _git_cherry_pick ()
 {
@@ -1339,6 +1369,9 @@ _git_cherry_pick ()
 		__gitcomp "$__git_cherry_pick_inprogress_options"
 		return
 	fi
+
+	__git_complete_strategy && return
+
 	case "$cur" in
 	--*)
 		__gitcomp_builtin cherry-pick "" \
@@ -1365,9 +1398,20 @@ _git_clean ()
 
 _git_clone ()
 {
+	case "$prev" in
+	-c|--config)
+		__git_complete_config_variable_name_and_value
+		return
+		;;
+	esac
 	case "$cur" in
+	--config=*)
+		__git_complete_config_variable_name_and_value \
+			--cur="${cur##--config=}"
+		return
+		;;
 	--*)
-		__gitcomp_builtin clone "--no-single-branch"
+		__gitcomp_builtin clone
 		return
 		;;
 	esac
@@ -1400,7 +1444,7 @@ _git_commit ()
 		return
 		;;
 	--*)
-		__gitcomp_builtin commit "--no-edit --verify"
+		__gitcomp_builtin commit
 		return
 	esac
 
@@ -1442,6 +1486,8 @@ __git_diff_common_options="--stat --nums
 			--dirstat-by-file= --cumulative
 			--diff-algorithm=
 			--submodule --submodule= --ignore-submodules
+			--indent-heuristic --no-indent-heuristic
+			--textconv --no-textconv
 "
 
 _git_diff ()
@@ -1469,7 +1515,8 @@ _git_diff ()
 }
 
 __git_mergetools_common="diffuse diffmerge ecmerge emerge kdiff3 meld opendiff
-			tkdiff vimdiff gvimdiff xxdiff araxis p4merge bc codecompare
+			tkdiff vimdiff gvimdiff xxdiff araxis p4merge bc
+			codecompare smerge
 "
 
 _git_difftool ()
@@ -1502,21 +1549,21 @@ _git_fetch ()
 		__gitcomp "$__git_fetch_recurse_submodules" "" "${cur##--recurse-submodules=}"
 		return
 		;;
+	--filter=*)
+		__gitcomp "blob:none blob:limit= sparse:oid=" "" "${cur##--filter=}"
+		return
+		;;
 	--*)
-		__gitcomp_builtin fetch "--no-tags"
+		__gitcomp_builtin fetch
 		return
 		;;
 	esac
 	__git_complete_remote_or_refspec
 }
 
-__git_format_patch_options="
-	--stdout --attach --no-attach --thread --thread= --no-thread
-	--numbered --start-number --numbered-files --keep-subject --signoff
-	--signature --no-signature --in-reply-to= --cc= --full-index --binary
-	--not --all --cover-letter --no-prefix --src-prefix= --dst-prefix=
-	--inline --suffix= --ignore-if-in-upstream --subject-prefix=
-	--output-directory --reroll-count --to= --quiet --notes
+__git_format_patch_extra_options="
+	--full-index --not --all --no-prefix --src-prefix=
+	--dst-prefix= --notes
 "
 
 _git_format_patch ()
@@ -1529,7 +1576,7 @@ _git_format_patch ()
 		return
 		;;
 	--*)
-		__gitcomp "$__git_format_patch_options"
+		__gitcomp_builtin format-patch "$__git_format_patch_extra_options"
 		return
 		;;
 	esac
@@ -1540,7 +1587,7 @@ _git_fsck ()
 {
 	case "$cur" in
 	--*)
-		__gitcomp_builtin fsck "--no-reflogs"
+		__gitcomp_builtin fsck
 		return
 		;;
 	esac
@@ -1620,9 +1667,9 @@ _git_help ()
 	esac
 	if test -n "$GIT_TESTING_ALL_COMMAND_LIST"
 	then
-		__gitcomp "$GIT_TESTING_ALL_COMMAND_LIST $(git --list-cmds=alias,list-guide) gitk"
+		__gitcomp "$GIT_TESTING_ALL_COMMAND_LIST $(__git --list-cmds=alias,list-guide) gitk"
 	else
-		__gitcomp "$(git --list-cmds=main,nohelpers,alias,list-guide) gitk"
+		__gitcomp "$(__git --list-cmds=main,nohelpers,alias,list-guide) gitk"
 	fi
 }
 
@@ -1646,7 +1693,7 @@ _git_ls_files ()
 {
 	case "$cur" in
 	--*)
-		__gitcomp_builtin ls-files "--no-empty-directory"
+		__gitcomp_builtin ls-files
 		return
 		;;
 	esac
@@ -1702,8 +1749,8 @@ __git_log_shortlog_options="
 	--all-match --invert-grep
 "
 
-__git_log_pretty_formats="oneline short medium full fuller email raw format:"
-__git_log_date_formats="relative iso8601 rfc2822 short local default raw"
+__git_log_pretty_formats="oneline short medium full fuller reference email raw format: tformat: mboxrd"
+__git_log_date_formats="relative iso8601 iso8601-strict rfc2822 short local default raw unix format:"
 
 _git_log ()
 {
@@ -1749,6 +1796,10 @@ _git_log ()
 		__gitcomp "$__git_diff_submodule_formats" "" "${cur##--submodule=}"
 		return
 		;;
+	--no-walk=*)
+		__gitcomp "sorted unsorted" "" "${cur##--no-walk=}"
+		return
+		;;
 	--*)
 		__gitcomp "
 			$__git_log_common_options
@@ -1756,16 +1807,19 @@ _git_log ()
 			$__git_log_gitk_options
 			--root --topo-order --date-order --reverse
 			--follow --full-diff
-			--abbrev-commit --abbrev=
+			--abbrev-commit --no-abbrev-commit --abbrev=
 			--relative-date --date=
 			--pretty= --format= --oneline
 			--show-signature
 			--cherry-mark
 			--cherry-pick
 			--graph
-			--decorate --decorate=
+			--decorate --decorate= --no-decorate
 			--walk-reflogs
+			--no-walk --no-walk= --do-walk
 			--parents --children
+			--expand-tabs --expand-tabs= --no-expand-tabs
+			--patch
 			$merge
 			$__git_diff_common_options
 			--pickaxe-all --pickaxe-regex
@@ -1797,12 +1851,7 @@ _git_merge ()
 
 	case "$cur" in
 	--*)
-		__gitcomp_builtin merge "--no-rerere-autoupdate
-				--no-commit --no-edit --no-ff
-				--no-log --no-progress
-				--no-squash --no-stat
-				--no-verify-signatures
-				"
+		__gitcomp_builtin merge
 		return
 	esac
 	__git_complete_refs
@@ -1816,7 +1865,7 @@ _git_mergetool ()
 		return
 		;;
 	--*)
-		__gitcomp "--tool= --prompt --no-prompt"
+		__gitcomp "--tool= --prompt --no-prompt --gui --no-gui"
 		return
 		;;
 	esac
@@ -1901,10 +1950,7 @@ _git_pull ()
 		return
 		;;
 	--*)
-		__gitcomp_builtin pull "--no-autostash --no-commit --no-edit
-					--no-ff --no-log --no-progress --no-rebase
-					--no-squash --no-stat --no-tags
-					--no-verify-signatures"
+		__gitcomp_builtin pull
 
 		return
 		;;
@@ -1963,15 +2009,32 @@ _git_push ()
 	__git_complete_remote_or_refspec
 }
 
+_git_range_diff ()
+{
+	case "$cur" in
+	--*)
+		__gitcomp "
+			--creation-factor= --no-dual-color
+			$__git_diff_common_options
+		"
+		return
+		;;
+	esac
+	__git_complete_revlist
+}
+
+__git_rebase_inprogress_options="--continue --skip --abort --quit --show-current-patch"
+__git_rebase_interactive_inprogress_options="$__git_rebase_inprogress_options --edit-todo"
+
 _git_rebase ()
 {
 	__git_find_repo_path
 	if [ -f "$__git_repo_path"/rebase-merge/interactive ]; then
-		__gitcomp "--continue --skip --abort --quit --edit-todo --show-current-patch"
+		__gitcomp "$__git_rebase_interactive_inprogress_options"
 		return
 	elif [ -d "$__git_repo_path"/rebase-apply ] || \
 	     [ -d "$__git_repo_path"/rebase-merge ]; then
-		__gitcomp "--continue --skip --abort --quit --show-current-patch"
+		__gitcomp "$__git_rebase_inprogress_options"
 		return
 	fi
 	__git_complete_strategy && return
@@ -1980,20 +2043,13 @@ _git_rebase ()
 		__gitcomp "$__git_whitespacelist" "" "${cur##--whitespace=}"
 		return
 		;;
+	--onto=*)
+		__git_complete_refs --cur="${cur##--onto=}"
+		return
+		;;
 	--*)
-		__gitcomp "
-			--onto --merge --strategy --interactive
-			--rebase-merges --preserve-merges --stat --no-stat
-			--committer-date-is-author-date --ignore-date
-			--ignore-whitespace --whitespace=
-			--autosquash --no-autosquash
-			--fork-point --no-fork-point
-			--autostash --no-autostash
-			--verify --no-verify
-			--keep-empty --root --force-rebase --no-ff
-			--rerere-autoupdate
-			--exec
-			"
+		__gitcomp_builtin rebase "" \
+			"$__git_rebase_interactive_inprogress_options"
 
 		return
 	esac
@@ -2053,7 +2109,7 @@ _git_send_email ()
 		return
 		;;
 	--*)
-		__gitcomp "--annotate --bcc --cc --cc-cmd --chain-reply-to
+		__gitcomp_builtin send-email "--annotate --bcc --cc --cc-cmd --chain-reply-to
 			--compose --confirm= --dry-run --envelope-sender
 			--from --identity
 			--in-reply-to --no-chain-reply-to --no-signed-off-by-cc
@@ -2062,7 +2118,7 @@ _git_send_email ()
 			--smtp-server-port --smtp-encryption= --smtp-user
 			--subject --suppress-cc= --suppress-from --thread --to
 			--validate --no-validate
-			$__git_format_patch_options"
+			$__git_format_patch_extra_options"
 		return
 		;;
 	esac
@@ -2095,7 +2151,7 @@ _git_status ()
 		return
 		;;
 	--*)
-		__gitcomp_builtin status "--no-column"
+		__gitcomp_builtin status
 		return
 		;;
 	esac
@@ -2120,6 +2176,44 @@ _git_status ()
 	__git_complete_index_file "$complete_opt"
 }
 
+_git_switch ()
+{
+	case "$cur" in
+	--conflict=*)
+		__gitcomp "diff3 merge" "" "${cur##--conflict=}"
+		;;
+	--*)
+		__gitcomp_builtin switch
+		;;
+	*)
+		# check if --track, --no-track, or --no-guess was specified
+		# if so, disable DWIM mode
+		local track_opt="--track" only_local_ref=n
+		if [ "$GIT_COMPLETION_CHECKOUT_NO_GUESS" = "1" ] ||
+		   [ -n "$(__git_find_on_cmdline "--track --no-track --no-guess")" ]; then
+			track_opt=''
+		fi
+		# explicit --guess enables DWIM mode regardless of
+		# $GIT_COMPLETION_CHECKOUT_NO_GUESS
+		if [ -n "$(__git_find_on_cmdline "--guess")" ]; then
+			track_opt='--track'
+		fi
+		if [ -z "$(__git_find_on_cmdline "-d --detach")" ]; then
+			only_local_ref=y
+		else
+			# --guess --detach is invalid combination, no
+			# dwim will be done when --detach is specified
+			track_opt=
+		fi
+		if [ $only_local_ref = y -a -z "$track_opt" ]; then
+			__gitcomp_direct "$(__git_heads "" "$cur" " ")"
+		else
+			__git_complete_refs $track_opt
+		fi
+		;;
+	esac
+}
+
 __git_config_get_set_variables ()
 {
 	local prevword word config_file= c=$cword
@@ -2142,490 +2236,287 @@ __git_config_get_set_variables ()
 	__git config $config_file --name-only --list
 }
 
-_git_config ()
+__git_config_vars=
+__git_compute_config_vars ()
 {
-	case "$prev" in
+	test -n "$__git_config_vars" ||
+	__git_config_vars="$(git help --config-for-completion | sort -u)"
+}
+
+# Completes possible values of various configuration variables.
+#
+# Usage: __git_complete_config_variable_value [<option>]...
+# --varname=<word>: The name of the configuration variable whose value is
+#                   to be completed.  Defaults to the previous word on the
+#                   command line.
+# --cur=<word>: The current value to be completed.  Defaults to the current
+#               word to be completed.
+__git_complete_config_variable_value ()
+{
+	local varname="$prev" cur_="$cur"
+
+	while test $# != 0; do
+		case "$1" in
+		--varname=*)	varname="${1##--varname=}" ;;
+		--cur=*)	cur_="${1##--cur=}" ;;
+		*)		return 1 ;;
+		esac
+		shift
+	done
+
+	if [ "${BASH_VERSINFO[0]:-0}" -ge 4 ]; then
+		varname="${varname,,}"
+	else
+		varname="$(echo "$varname" |tr A-Z a-z)"
+	fi
+
+	case "$varname" in
 	branch.*.remote|branch.*.pushremote)
-		__gitcomp_nl "$(__git_remotes)"
+		__gitcomp_nl "$(__git_remotes)" "" "$cur_"
 		return
 		;;
 	branch.*.merge)
-		__git_complete_refs
+		__git_complete_refs --cur="$cur_"
 		return
 		;;
 	branch.*.rebase)
-		__gitcomp "false true merges preserve interactive"
+		__gitcomp "false true merges preserve interactive" "" "$cur_"
 		return
 		;;
 	remote.pushdefault)
-		__gitcomp_nl "$(__git_remotes)"
+		__gitcomp_nl "$(__git_remotes)" "" "$cur_"
 		return
 		;;
 	remote.*.fetch)
-		local remote="${prev#remote.}"
+		local remote="${varname#remote.}"
 		remote="${remote%.fetch}"
-		if [ -z "$cur" ]; then
+		if [ -z "$cur_" ]; then
 			__gitcomp_nl "refs/heads/" "" "" ""
 			return
 		fi
-		__gitcomp_nl "$(__git_refs_remotes "$remote")"
+		__gitcomp_nl "$(__git_refs_remotes "$remote")" "" "$cur_"
 		return
 		;;
 	remote.*.push)
-		local remote="${prev#remote.}"
+		local remote="${varname#remote.}"
 		remote="${remote%.push}"
 		__gitcomp_nl "$(__git for-each-ref \
-			--format='%(refname):%(refname)' refs/heads)"
+			--format='%(refname):%(refname)' refs/heads)" "" "$cur_"
 		return
 		;;
 	pull.twohead|pull.octopus)
 		__git_compute_merge_strategies
-		__gitcomp "$__git_merge_strategies"
-		return
-		;;
-	color.branch|color.diff|color.interactive|\
-	color.showbranch|color.status|color.ui)
-		__gitcomp "always never auto"
+		__gitcomp "$__git_merge_strategies" "" "$cur_"
 		return
 		;;
 	color.pager)
-		__gitcomp "false true"
+		__gitcomp "false true" "" "$cur_"
 		return
 		;;
 	color.*.*)
 		__gitcomp "
 			normal black red green yellow blue magenta cyan white
 			bold dim ul blink reverse
-			"
+			" "" "$cur_"
+		return
+		;;
+	color.*)
+		__gitcomp "false true always never auto" "" "$cur_"
 		return
 		;;
 	diff.submodule)
-		__gitcomp "log short"
+		__gitcomp "$__git_diff_submodule_formats" "" "$cur_"
 		return
 		;;
 	help.format)
-		__gitcomp "man info web html"
+		__gitcomp "man info web html" "" "$cur_"
 		return
 		;;
 	log.date)
-		__gitcomp "$__git_log_date_formats"
+		__gitcomp "$__git_log_date_formats" "" "$cur_"
 		return
 		;;
 	sendemail.aliasfiletype)
-		__gitcomp "mutt mailrc pine elm gnus"
+		__gitcomp "mutt mailrc pine elm gnus" "" "$cur_"
 		return
 		;;
 	sendemail.confirm)
-		__gitcomp "$__git_send_email_confirm_options"
+		__gitcomp "$__git_send_email_confirm_options" "" "$cur_"
 		return
 		;;
 	sendemail.suppresscc)
-		__gitcomp "$__git_send_email_suppresscc_options"
+		__gitcomp "$__git_send_email_suppresscc_options" "" "$cur_"
 		return
 		;;
 	sendemail.transferencoding)
-		__gitcomp "7bit 8bit quoted-printable base64"
-		return
-		;;
-	--get|--get-all|--unset|--unset-all)
-		__gitcomp_nl "$(__git_config_get_set_variables)"
+		__gitcomp "7bit 8bit quoted-printable base64" "" "$cur_"
 		return
 		;;
 	*.*)
 		return
 		;;
 	esac
-	case "$cur" in
-	--*)
-		__gitcomp_builtin config
-		return
-		;;
+}
+
+# Completes configuration sections, subsections, variable names.
+#
+# Usage: __git_complete_config_variable_name [<option>]...
+# --cur=<word>: The current configuration section/variable name to be
+#               completed.  Defaults to the current word to be completed.
+# --sfx=<suffix>: A suffix to be appended to each fully completed
+#                 configuration variable name (but not to sections or
+#                 subsections) instead of the default space.
+__git_complete_config_variable_name ()
+{
+	local cur_="$cur" sfx
+
+	while test $# != 0; do
+		case "$1" in
+		--cur=*)	cur_="${1##--cur=}" ;;
+		--sfx=*)	sfx="${1##--sfx=}" ;;
+		*)		return 1 ;;
+		esac
+		shift
+	done
+
+	case "$cur_" in
 	branch.*.*)
-		local pfx="${cur%.*}." cur_="${cur##*.}"
-		__gitcomp "remote pushremote merge mergeoptions rebase" "$pfx" "$cur_"
+		local pfx="${cur_%.*}."
+		cur_="${cur_##*.}"
+		__gitcomp "remote pushRemote merge mergeOptions rebase" "$pfx" "$cur_" "$sfx"
 		return
 		;;
 	branch.*)
-		local pfx="${cur%.*}." cur_="${cur#*.}"
+		local pfx="${cur%.*}."
+		cur_="${cur#*.}"
 		__gitcomp_direct "$(__git_heads "$pfx" "$cur_" ".")"
-		__gitcomp_nl_append $'autosetupmerge\nautosetuprebase\n' "$pfx" "$cur_"
+		__gitcomp_nl_append $'autoSetupMerge\nautoSetupRebase\n' "$pfx" "$cur_" "$sfx"
 		return
 		;;
 	guitool.*.*)
-		local pfx="${cur%.*}." cur_="${cur##*.}"
+		local pfx="${cur_%.*}."
+		cur_="${cur_##*.}"
 		__gitcomp "
-			argprompt cmd confirm needsfile noconsole norescan
-			prompt revprompt revunmerged title
-			" "$pfx" "$cur_"
+			argPrompt cmd confirm needsFile noConsole noRescan
+			prompt revPrompt revUnmerged title
+			" "$pfx" "$cur_" "$sfx"
 		return
 		;;
 	difftool.*.*)
-		local pfx="${cur%.*}." cur_="${cur##*.}"
-		__gitcomp "cmd path" "$pfx" "$cur_"
+		local pfx="${cur_%.*}."
+		cur_="${cur_##*.}"
+		__gitcomp "cmd path" "$pfx" "$cur_" "$sfx"
 		return
 		;;
 	man.*.*)
-		local pfx="${cur%.*}." cur_="${cur##*.}"
-		__gitcomp "cmd path" "$pfx" "$cur_"
+		local pfx="${cur_%.*}."
+		cur_="${cur_##*.}"
+		__gitcomp "cmd path" "$pfx" "$cur_" "$sfx"
 		return
 		;;
 	mergetool.*.*)
-		local pfx="${cur%.*}." cur_="${cur##*.}"
-		__gitcomp "cmd path trustExitCode" "$pfx" "$cur_"
+		local pfx="${cur_%.*}."
+		cur_="${cur_##*.}"
+		__gitcomp "cmd path trustExitCode" "$pfx" "$cur_" "$sfx"
 		return
 		;;
 	pager.*)
-		local pfx="${cur%.*}." cur_="${cur#*.}"
+		local pfx="${cur_%.*}."
+		cur_="${cur_#*.}"
 		__git_compute_all_commands
-		__gitcomp_nl "$__git_all_commands" "$pfx" "$cur_"
+		__gitcomp_nl "$__git_all_commands" "$pfx" "$cur_" "$sfx"
 		return
 		;;
 	remote.*.*)
-		local pfx="${cur%.*}." cur_="${cur##*.}"
+		local pfx="${cur_%.*}."
+		cur_="${cur_##*.}"
 		__gitcomp "
 			url proxy fetch push mirror skipDefaultUpdate
-			receivepack uploadpack tagopt pushurl
-			" "$pfx" "$cur_"
+			receivepack uploadpack tagOpt pushurl
+			" "$pfx" "$cur_" "$sfx"
 		return
 		;;
 	remote.*)
-		local pfx="${cur%.*}." cur_="${cur#*.}"
+		local pfx="${cur_%.*}."
+		cur_="${cur_#*.}"
 		__gitcomp_nl "$(__git_remotes)" "$pfx" "$cur_" "."
-		__gitcomp_nl_append "pushdefault" "$pfx" "$cur_"
+		__gitcomp_nl_append "pushDefault" "$pfx" "$cur_" "$sfx"
 		return
 		;;
 	url.*.*)
-		local pfx="${cur%.*}." cur_="${cur##*.}"
-		__gitcomp "insteadOf pushInsteadOf" "$pfx" "$cur_"
+		local pfx="${cur_%.*}."
+		cur_="${cur_##*.}"
+		__gitcomp "insteadOf pushInsteadOf" "$pfx" "$cur_" "$sfx"
 		return
 		;;
+	*.*)
+		__git_compute_config_vars
+		__gitcomp "$__git_config_vars" "" "$cur_" "$sfx"
+		;;
+	*)
+		__git_compute_config_vars
+		__gitcomp "$(echo "$__git_config_vars" |
+				awk -F . '{
+					sections[$1] = 1
+				}
+				END {
+					for (s in sections)
+						print s "."
+				}
+				')" "" "$cur_"
+		;;
+	esac
+}
+
+# Completes '='-separated configuration sections/variable names and values
+# for 'git -c section.name=value'.
+#
+# Usage: __git_complete_config_variable_name_and_value [<option>]...
+# --cur=<word>: The current configuration section/variable name/value to be
+#               completed. Defaults to the current word to be completed.
+__git_complete_config_variable_name_and_value ()
+{
+	local cur_="$cur"
+
+	while test $# != 0; do
+		case "$1" in
+		--cur=*)	cur_="${1##--cur=}" ;;
+		*)		return 1 ;;
+		esac
+		shift
+	done
+
+	case "$cur_" in
+	*=*)
+		__git_complete_config_variable_value \
+			--varname="${cur_%%=*}" --cur="${cur_#*=}"
+		;;
+	*)
+		__git_complete_config_variable_name --cur="$cur_" --sfx='='
+		;;
+	esac
+}
+
+_git_config ()
+{
+	case "$prev" in
+	--get|--get-all|--unset|--unset-all)
+		__gitcomp_nl "$(__git_config_get_set_variables)"
+		return
+		;;
+	*.*)
+		__git_complete_config_variable_value
+		return
+		;;
+	esac
+	case "$cur" in
+	--*)
+		__gitcomp_builtin config
+		;;
+	*)
+		__git_complete_config_variable_name
+		;;
 	esac
-	__gitcomp "
-		add.ignoreErrors
-		advice.amWorkDir
-		advice.commitBeforeMerge
-		advice.detachedHead
-		advice.implicitIdentity
-		advice.pushAlreadyExists
-		advice.pushFetchFirst
-		advice.pushNeedsForce
-		advice.pushNonFFCurrent
-		advice.pushNonFFMatching
-		advice.pushUpdateRejected
-		advice.resolveConflict
-		advice.rmHints
-		advice.statusHints
-		advice.statusUoption
-		advice.ignoredHook
-		alias.
-		am.keepcr
-		am.threeWay
-		apply.ignorewhitespace
-		apply.whitespace
-		branch.autosetupmerge
-		branch.autosetuprebase
-		browser.
-		clean.requireForce
-		color.branch
-		color.branch.current
-		color.branch.local
-		color.branch.plain
-		color.branch.remote
-		color.decorate.HEAD
-		color.decorate.branch
-		color.decorate.remoteBranch
-		color.decorate.stash
-		color.decorate.tag
-		color.diff
-		color.diff.commit
-		color.diff.frag
-		color.diff.func
-		color.diff.meta
-		color.diff.new
-		color.diff.old
-		color.diff.plain
-		color.diff.whitespace
-		color.grep
-		color.grep.context
-		color.grep.filename
-		color.grep.function
-		color.grep.linenumber
-		color.grep.match
-		color.grep.selected
-		color.grep.separator
-		color.interactive
-		color.interactive.error
-		color.interactive.header
-		color.interactive.help
-		color.interactive.prompt
-		color.pager
-		color.showbranch
-		color.status
-		color.status.added
-		color.status.changed
-		color.status.header
-		color.status.localBranch
-		color.status.nobranch
-		color.status.remoteBranch
-		color.status.unmerged
-		color.status.untracked
-		color.status.updated
-		color.ui
-		commit.cleanup
-		commit.gpgSign
-		commit.status
-		commit.template
-		commit.verbose
-		core.abbrev
-		core.askpass
-		core.attributesfile
-		core.autocrlf
-		core.bare
-		core.bigFileThreshold
-		core.checkStat
-		core.commentChar
-		core.commitGraph
-		core.compression
-		core.createObject
-		core.deltaBaseCacheLimit
-		core.editor
-		core.eol
-		core.excludesfile
-		core.fileMode
-		core.fsyncobjectfiles
-		core.gitProxy
-		core.hideDotFiles
-		core.hooksPath
-		core.ignoreStat
-		core.ignorecase
-		core.logAllRefUpdates
-		core.loosecompression
-		core.notesRef
-		core.packedGitLimit
-		core.packedGitWindowSize
-		core.packedRefsTimeout
-		core.pager
-		core.precomposeUnicode
-		core.preferSymlinkRefs
-		core.preloadindex
-		core.protectHFS
-		core.protectNTFS
-		core.quotepath
-		core.repositoryFormatVersion
-		core.safecrlf
-		core.sharedRepository
-		core.sparseCheckout
-		core.splitIndex
-		core.sshCommand
-		core.symlinks
-		core.trustctime
-		core.untrackedCache
-		core.warnAmbiguousRefs
-		core.whitespace
-		core.worktree
-		credential.helper
-		credential.useHttpPath
-		credential.username
-		credentialCache.ignoreSIGHUP
-		diff.autorefreshindex
-		diff.external
-		diff.ignoreSubmodules
-		diff.mnemonicprefix
-		diff.noprefix
-		diff.renameLimit
-		diff.renames
-		diff.statGraphWidth
-		diff.submodule
-		diff.suppressBlankEmpty
-		diff.tool
-		diff.wordRegex
-		diff.algorithm
-		difftool.
-		difftool.prompt
-		fetch.recurseSubmodules
-		fetch.unpackLimit
-		format.attach
-		format.cc
-		format.coverLetter
-		format.from
-		format.headers
-		format.numbered
-		format.pretty
-		format.signature
-		format.signoff
-		format.subjectprefix
-		format.suffix
-		format.thread
-		format.to
-		gc.
-		gc.aggressiveDepth
-		gc.aggressiveWindow
-		gc.auto
-		gc.autoDetach
-		gc.autopacklimit
-		gc.logExpiry
-		gc.packrefs
-		gc.pruneexpire
-		gc.reflogexpire
-		gc.reflogexpireunreachable
-		gc.rerereresolved
-		gc.rerereunresolved
-		gc.worktreePruneExpire
-		gitcvs.allbinary
-		gitcvs.commitmsgannotation
-		gitcvs.dbTableNamePrefix
-		gitcvs.dbdriver
-		gitcvs.dbname
-		gitcvs.dbpass
-		gitcvs.dbuser
-		gitcvs.enabled
-		gitcvs.logfile
-		gitcvs.usecrlfattr
-		guitool.
-		gui.blamehistoryctx
-		gui.commitmsgwidth
-		gui.copyblamethreshold
-		gui.diffcontext
-		gui.encoding
-		gui.fastcopyblame
-		gui.matchtrackingbranch
-		gui.newbranchtemplate
-		gui.pruneduringfetch
-		gui.spellingdictionary
-		gui.trustmtime
-		help.autocorrect
-		help.browser
-		help.format
-		http.lowSpeedLimit
-		http.lowSpeedTime
-		http.maxRequests
-		http.minSessions
-		http.noEPSV
-		http.postBuffer
-		http.proxy
-		http.sslCipherList
-		http.sslVersion
-		http.sslCAInfo
-		http.sslCAPath
-		http.sslCert
-		http.sslCertPasswordProtected
-		http.sslKey
-		http.sslVerify
-		http.useragent
-		i18n.commitEncoding
-		i18n.logOutputEncoding
-		imap.authMethod
-		imap.folder
-		imap.host
-		imap.pass
-		imap.port
-		imap.preformattedHTML
-		imap.sslverify
-		imap.tunnel
-		imap.user
-		init.templatedir
-		instaweb.browser
-		instaweb.httpd
-		instaweb.local
-		instaweb.modulepath
-		instaweb.port
-		interactive.singlekey
-		log.date
-		log.decorate
-		log.showroot
-		mailmap.file
-		man.
-		man.viewer
-		merge.
-		merge.conflictstyle
-		merge.log
-		merge.renameLimit
-		merge.renormalize
-		merge.stat
-		merge.tool
-		merge.verbosity
-		mergetool.
-		mergetool.keepBackup
-		mergetool.keepTemporaries
-		mergetool.prompt
-		notes.displayRef
-		notes.rewrite.
-		notes.rewrite.amend
-		notes.rewrite.rebase
-		notes.rewriteMode
-		notes.rewriteRef
-		pack.compression
-		pack.deltaCacheLimit
-		pack.deltaCacheSize
-		pack.depth
-		pack.indexVersion
-		pack.packSizeLimit
-		pack.threads
-		pack.window
-		pack.windowMemory
-		pager.
-		pretty.
-		pull.octopus
-		pull.twohead
-		push.default
-		push.followTags
-		rebase.autosquash
-		rebase.stat
-		receive.autogc
-		receive.denyCurrentBranch
-		receive.denyDeleteCurrent
-		receive.denyDeletes
-		receive.denyNonFastForwards
-		receive.fsckObjects
-		receive.unpackLimit
-		receive.updateserverinfo
-		remote.pushdefault
-		remotes.
-		repack.usedeltabaseoffset
-		rerere.autoupdate
-		rerere.enabled
-		sendemail.
-		sendemail.aliasesfile
-		sendemail.aliasfiletype
-		sendemail.bcc
-		sendemail.cc
-		sendemail.cccmd
-		sendemail.chainreplyto
-		sendemail.confirm
-		sendemail.envelopesender
-		sendemail.from
-		sendemail.identity
-		sendemail.multiedit
-		sendemail.signedoffbycc
-		sendemail.smtpdomain
-		sendemail.smtpencryption
-		sendemail.smtppass
-		sendemail.smtpserver
-		sendemail.smtpserveroption
-		sendemail.smtpserverport
-		sendemail.smtpuser
-		sendemail.suppresscc
-		sendemail.suppressfrom
-		sendemail.thread
-		sendemail.to
-		sendemail.tocmd
-		sendemail.validate
-		sendemail.smtpbatchsize
-		sendemail.smtprelogindelay
-		showbranch.default
-		status.relativePaths
-		status.showUntrackedFiles
-		status.submodulesummary
-		submodule.
-		tar.umask
-		transfer.unpackLimit
-		url.
-		user.email
-		user.name
-		user.signingkey
-		web.browser
-		branch. remote.
-	"
 }
 
 _git_remote ()
@@ -2649,7 +2540,7 @@ _git_remote ()
 
 	case "$subcommand,$cur" in
 	add,--*)
-		__gitcomp_builtin remote_add "--no-tags"
+		__gitcomp_builtin remote_add
 		;;
 	add,*)
 		;;
@@ -2666,7 +2557,7 @@ _git_remote ()
 		__gitcomp_builtin remote_update
 		;;
 	update,*)
-		__gitcomp "$(__git_get_config_variables "remotes")"
+		__gitcomp "$(__git_remotes) $(__git_get_config_variables "remotes")"
 		;;
 	set-url,--*)
 		__gitcomp_builtin remote_set-url
@@ -2686,6 +2577,10 @@ _git_remote ()
 _git_replace ()
 {
 	case "$cur" in
+	--format=*)
+		__gitcomp "short medium long" "" "${cur##--format=}"
+		return
+		;;
 	--*)
 		__gitcomp_builtin replace
 		return
@@ -2718,7 +2613,22 @@ _git_reset ()
 	__git_complete_refs
 }
 
-__git_revert_inprogress_options="--continue --quit --abort"
+_git_restore ()
+{
+	case "$cur" in
+	--conflict=*)
+		__gitcomp "diff3 merge" "" "${cur##--conflict=}"
+		;;
+	--source=*)
+		__git_complete_refs --cur="${cur##--source=}"
+		;;
+	--*)
+		__gitcomp_builtin restore
+		;;
+	esac
+}
+
+__git_revert_inprogress_options=$__git_sequencer_inprogress_options
 
 _git_revert ()
 {
@@ -2727,9 +2637,10 @@ _git_revert ()
 		__gitcomp "$__git_revert_inprogress_options"
 		return
 	fi
+	__git_complete_strategy && return
 	case "$cur" in
 	--*)
-		__gitcomp_builtin revert "--no-edit" \
+		__gitcomp_builtin revert "" \
 			"$__git_revert_inprogress_options"
 		return
 		;;
@@ -2785,8 +2696,9 @@ _git_show ()
 		return
 		;;
 	--*)
-		__gitcomp "--pretty= --format= --abbrev-commit --oneline
-			--show-signature
+		__gitcomp "--pretty= --format= --abbrev-commit --no-abbrev-commit
+			--oneline --show-signature --patch
+			--expand-tabs --expand-tabs= --no-expand-tabs
 			$__git_diff_common_options
 			"
 		return
@@ -2799,7 +2711,7 @@ _git_show_branch ()
 {
 	case "$cur" in
 	--*)
-		__gitcomp_builtin show-branch "--no-color"
+		__gitcomp_builtin show-branch
 		return
 		;;
 	esac
@@ -2844,6 +2756,9 @@ _git_stash ()
 		drop,--*)
 			__gitcomp "--quiet"
 			;;
+		list,--*)
+			__gitcomp "--name-status --oneline --patch-with-stat"
+			;;
 		show,--*|branch,--*)
 			;;
 		branch,*)
@@ -2868,7 +2783,7 @@ _git_submodule ()
 {
 	__git_has_doubledash && return
 
-	local subcommands="add status init deinit update summary foreach sync"
+	local subcommands="add status init deinit update set-branch set-url summary foreach sync absorbgitdirs"
 	local subcommand="$(__git_find_on_cmdline "$subcommands")"
 	if [ -z "$subcommand" ]; then
 		case "$cur" in
@@ -2899,6 +2814,9 @@ _git_submodule ()
 			--force --rebase --merge --reference --depth --recursive --jobs
 		"
 		;;
+	set-branch,--*)
+		__gitcomp "--default --branch"
+		;;
 	summary,--*)
 		__gitcomp "--cached --files --summary-limit"
 		;;
@@ -2929,6 +2847,7 @@ _git_svn ()
 			--log-window-size= --no-checkout --quiet
 			--repack-flags --use-log-author --localtime
 			--add-author-from
+			--recursive
 			--ignore-paths= --include-paths= $remote_opts
 			"
 		local init_opts="
@@ -3155,7 +3074,11 @@ __git_main ()
 			# Bash filename completion
 			return
 			;;
-		-c|--namespace)
+		-c)
+			__git_complete_config_variable_name_and_value
+			return
+			;;
+		--namespace)
 			# we don't support completing these options' arguments
 			return
 			;;
@@ -3183,7 +3106,7 @@ __git_main ()
 			then
 				__gitcomp "$GIT_TESTING_PORCELAIN_COMMAND_LIST"
 			else
-				__gitcomp "$(git --list-cmds=list-mainporcelain,others,nohelpers,alias,list-complete,config)"
+				__gitcomp "$(__git --list-cmds=list-mainporcelain,others,nohelpers,alias,list-complete,config)"
 			fi
 			;;
 		esac
@@ -3281,7 +3204,7 @@ if [[ -n ${ZSH_VERSION-} ]] &&
 
 		local IFS=$'\n'
 		compset -P '*[=:]'
-		compadd -Q -f -- ${=1} && _ret=0
+		compadd -f -- ${=1} && _ret=0
 	}
 
 	__gitcomp_file ()
@@ -3290,7 +3213,7 @@ if [[ -n ${ZSH_VERSION-} ]] &&
 
 		local IFS=$'\n'
 		compset -P '*[=:]'
-		compadd -Q -p "${2-}" -f -- ${=1} && _ret=0
+		compadd -p "${2-}" -f -- ${=1} && _ret=0
 	}
 
 	_git ()
diff -pruN 1.2.1+git2.18.0-1/git/contrib/completion/git-completion.zsh 1.2.3+git2.25.1-1/git/contrib/completion/git-completion.zsh
--- 1.2.1+git2.18.0-1/git/contrib/completion/git-completion.zsh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/contrib/completion/git-completion.zsh	2020-02-17 04:47:35.000000000 +0000
@@ -11,8 +11,9 @@
 #
 #  zstyle ':completion:*:*:git:*' script ~/.git-completion.zsh
 #
-# The recommended way to install this script is to copy to '~/.zsh/_git', and
-# then add the following to your ~/.zshrc file:
+# The recommended way to install this script is to make a copy of it in
+# ~/.zsh/ directory as ~/.zsh/git-completion.zsh and then add the following
+# to your ~/.zshrc file:
 #
 #  fpath=(~/.zsh $fpath)
 
@@ -99,7 +100,7 @@ __gitcomp_file_direct ()
 
 	local IFS=$'\n'
 	compset -P '*[=:]'
-	compadd -Q -f -- ${=1} && _ret=0
+	compadd -f -- ${=1} && _ret=0
 }
 
 __gitcomp_file ()
@@ -108,7 +109,7 @@ __gitcomp_file ()
 
 	local IFS=$'\n'
 	compset -P '*[=:]'
-	compadd -Q -p "${2-}" -f -- ${=1} && _ret=0
+	compadd -p "${2-}" -f -- ${=1} && _ret=0
 }
 
 __git_zsh_bash_func ()
diff -pruN 1.2.1+git2.18.0-1/git/contrib/completion/git-prompt.sh 1.2.3+git2.25.1-1/git/contrib/completion/git-prompt.sh
--- 1.2.1+git2.18.0-1/git/contrib/completion/git-prompt.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/contrib/completion/git-prompt.sh	2020-02-17 04:47:35.000000000 +0000
@@ -286,6 +286,37 @@ __git_eread ()
 	test -r "$1" && IFS=$'\r\n' read "$2" <"$1"
 }
 
+# see if a cherry-pick or revert is in progress, if the user has committed a
+# conflict resolution with 'git commit' in the middle of a sequence of picks or
+# reverts then CHERRY_PICK_HEAD/REVERT_HEAD will not exist so we have to read
+# the todo file.
+__git_sequencer_status ()
+{
+	local todo
+	if test -f "$g/CHERRY_PICK_HEAD"
+	then
+		r="|CHERRY-PICKING"
+		return 0;
+	elif test -f "$g/REVERT_HEAD"
+	then
+		r="|REVERTING"
+		return 0;
+	elif __git_eread "$g/sequencer/todo" todo
+	then
+		case "$todo" in
+		p[\ \	]|pick[\ \	]*)
+			r="|CHERRY-PICKING"
+			return 0
+		;;
+		revert[\ \	]*)
+			r="|REVERTING"
+			return 0
+		;;
+		esac
+	fi
+	return 1
+}
+
 # __git_ps1 accepts 0 or 1 arguments (i.e., format string)
 # when called from PS1 using command substitution
 # in this mode it prints text to add to bash PS1 prompt (includes branch name)
@@ -417,10 +448,8 @@ __git_ps1 ()
 			fi
 		elif [ -f "$g/MERGE_HEAD" ]; then
 			r="|MERGING"
-		elif [ -f "$g/CHERRY_PICK_HEAD" ]; then
-			r="|CHERRY-PICKING"
-		elif [ -f "$g/REVERT_HEAD" ]; then
-			r="|REVERTING"
+		elif __git_sequencer_status; then
+			:
 		elif [ -f "$g/BISECT_LOG" ]; then
 			r="|BISECTING"
 		fi
diff -pruN 1.2.1+git2.18.0-1/git/contrib/coverage-diff.sh 1.2.3+git2.25.1-1/git/contrib/coverage-diff.sh
--- 1.2.1+git2.18.0-1/git/contrib/coverage-diff.sh	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/contrib/coverage-diff.sh	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,108 @@
+#!/bin/sh
+
+# Usage: Run 'contrib/coverage-diff.sh <version1> <version2>' from source-root
+# after running
+#
+#     make coverage-test
+#     make coverage-report
+#
+# while checked out at <version2>. This script combines the *.gcov files
+# generated by the 'make' commands above with 'git diff <version1> <version2>'
+# to report new lines that are not covered by the test suite.
+
+V1=$1
+V2=$2
+
+diff_lines () {
+	perl -e '
+		my $line_num;
+		while (<>) {
+			# Hunk header?  Grab the beginning in postimage.
+			if (/^@@ -\d+(?:,\d+)? \+(\d+)(?:,\d+)? @@/) {
+				$line_num = $1;
+				next;
+			}
+
+			# Have we seen a hunk?  Ignore "diff --git" etc.
+			next unless defined $line_num;
+
+			# Deleted line? Ignore.
+			if (/^-/) {
+				next;
+			}
+
+			# Show only the line number of added lines.
+			if (/^\+/) {
+				print "$line_num\n";
+			}
+			# Either common context or added line appear in
+			# the postimage.  Count it.
+			$line_num++;
+		}
+	'
+}
+
+files=$(git diff --name-only "$V1" "$V2" -- \*.c)
+
+# create empty file
+>coverage-data.txt
+
+for file in $files
+do
+	git diff "$V1" "$V2" -- "$file" |
+	diff_lines |
+	sort >new_lines.txt
+
+	if ! test -s new_lines.txt
+	then
+		continue
+	fi
+
+	hash_file=$(echo $file | sed "s/\//\#/")
+
+	if ! test -s "$hash_file.gcov"
+	then
+		continue
+	fi
+
+	sed -ne '/#####:/{
+			s/    #####://
+			s/:.*//
+			s/ //g
+			p
+		}' "$hash_file.gcov" |
+	sort >uncovered_lines.txt
+
+	comm -12 uncovered_lines.txt new_lines.txt |
+	sed -e 's/$/\)/' |
+	sed -e 's/^/ /' >uncovered_new_lines.txt
+
+	grep -q '[^[:space:]]' <uncovered_new_lines.txt &&
+	echo $file >>coverage-data.txt &&
+	git blame -s "$V2" -- "$file" |
+	sed 's/\t//g' |
+	grep -f uncovered_new_lines.txt >>coverage-data.txt &&
+	echo >>coverage-data.txt
+
+	rm -f new_lines.txt uncovered_lines.txt uncovered_new_lines.txt
+done
+
+cat coverage-data.txt
+
+echo "Commits introducing uncovered code:"
+
+commit_list=$(cat coverage-data.txt |
+	grep -E '^[0-9a-f]{7,} ' |
+	awk '{print $1;}' |
+	sort |
+	uniq)
+
+(
+	for commit in $commit_list
+	do
+		git log --no-decorate --pretty=format:'%an      %h: %s' -1 $commit
+		echo
+	done
+) | sort
+
+rm coverage-data.txt
diff -pruN 1.2.1+git2.18.0-1/git/contrib/credential/netrc/Makefile 1.2.3+git2.25.1-1/git/contrib/credential/netrc/Makefile
--- 1.2.1+git2.18.0-1/git/contrib/credential/netrc/Makefile	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/contrib/credential/netrc/Makefile	2020-02-17 04:47:35.000000000 +0000
@@ -1,3 +1,6 @@
+# The default target of this Makefile is...
+all::
+
 test:
 	./t-git-credential-netrc.sh
 
diff -pruN 1.2.1+git2.18.0-1/git/contrib/credential/netrc/test.pl 1.2.3+git2.25.1-1/git/contrib/credential/netrc/test.pl
--- 1.2.1+git2.18.0-1/git/contrib/credential/netrc/test.pl	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/contrib/credential/netrc/test.pl	2020-02-17 04:47:35.000000000 +0000
@@ -1,5 +1,4 @@
 #!/usr/bin/perl
-use lib (split(/:/, $ENV{GITPERLLIB}));
 
 use warnings;
 use strict;
@@ -12,7 +11,6 @@ BEGIN {
 	# t-git-credential-netrc.sh kicks off our testing, so we have to go
 	# from there.
 	Test::More->builder->current_test(1);
-	Test::More->builder->no_ending(1);
 }
 
 my @global_credential_args = @ARGV;
@@ -104,6 +102,9 @@ $cred = run_credential( ['-f', $netrcGpg
 
 ok(scalar keys %$cred == 2, 'Got keys decrypted by command option');
 
+my $is_passing = eval { Test::More->is_passing };
+exit($is_passing ? 0 : 1) unless $@ =~ /Can't locate object method/;
+
 sub run_credential
 {
 	my $args = shift @_;
diff -pruN 1.2.1+git2.18.0-1/git/contrib/credential/netrc/t-git-credential-netrc.sh 1.2.3+git2.25.1-1/git/contrib/credential/netrc/t-git-credential-netrc.sh
--- 1.2.1+git2.18.0-1/git/contrib/credential/netrc/t-git-credential-netrc.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/contrib/credential/netrc/t-git-credential-netrc.sh	2020-02-17 04:47:35.000000000 +0000
@@ -17,15 +17,16 @@
 	# set up test repository
 
 	test_expect_success \
-    'set up test repository' \
-    'git config --add gpg.program test.git-config-gpg'
+		'set up test repository' \
+		'git config --add gpg.program test.git-config-gpg'
 
 	# The external test will outputs its own plan
 	test_external_has_tap=1
 
+	export PERL5LIB="$GITPERLLIB"
 	test_external \
-    'git-credential-netrc' \
-    perl "$TEST_DIRECTORY"/../contrib/credential/netrc/test.pl
+		'git-credential-netrc' \
+		perl "$GIT_BUILD_DIR"/contrib/credential/netrc/test.pl
 
 	test_done
 )
diff -pruN 1.2.1+git2.18.0-1/git/contrib/credential/wincred/git-credential-wincred.c 1.2.3+git2.25.1-1/git/contrib/credential/wincred/git-credential-wincred.c
--- 1.2.1+git2.18.0-1/git/contrib/credential/wincred/git-credential-wincred.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/contrib/credential/wincred/git-credential-wincred.c	2020-02-17 04:47:35.000000000 +0000
@@ -75,7 +75,8 @@ static CredDeleteWT CredDeleteW;
 static void load_cred_funcs(void)
 {
 	/* load DLLs */
-	advapi = LoadLibrary("advapi32.dll");
+	advapi = LoadLibraryExA("advapi32.dll", NULL,
+				LOAD_LIBRARY_SEARCH_SYSTEM32);
 	if (!advapi)
 		die("failed to load advapi32.dll");
 
diff -pruN 1.2.1+git2.18.0-1/git/contrib/diff-highlight/DiffHighlight.pm 1.2.3+git2.25.1-1/git/contrib/diff-highlight/DiffHighlight.pm
--- 1.2.1+git2.18.0-1/git/contrib/diff-highlight/DiffHighlight.pm	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/contrib/diff-highlight/DiffHighlight.pm	2020-02-17 04:47:35.000000000 +0000
@@ -4,6 +4,11 @@ use 5.008;
 use warnings FATAL => 'all';
 use strict;
 
+# Use the correct value for both UNIX and Windows (/dev/null vs nul)
+use File::Spec;
+
+my $NULL = File::Spec->devnull();
+
 # Highlight by reversing foreground and background. You could do
 # other things like bold or underline if you prefer.
 my @OLD_HIGHLIGHT = (
@@ -67,7 +72,7 @@ sub handle_line {
 	      (?:$COLOR?\|$COLOR?[ ])* # zero or more trailing "|"
 	                         [ ]*  # trailing whitespace for merges
 	    /x) {
-	        my $graph_prefix = $&;
+		my $graph_prefix = $&;
 
 		# We must flush before setting graph indent, since the
 		# new commit may be indented differently from what we
@@ -134,7 +139,7 @@ sub highlight_stdin {
 # fallback, which means we will work even if git can't be run.
 sub color_config {
 	my ($key, $default) = @_;
-	my $s = `git config --get-color $key 2>/dev/null`;
+	my $s = `git config --get-color $key 2>$NULL`;
 	return length($s) ? $s : $default;
 }
 
diff -pruN 1.2.1+git2.18.0-1/git/contrib/git-jump/git-jump 1.2.3+git2.25.1-1/git/contrib/git-jump/git-jump
--- 1.2.1+git2.18.0-1/git/contrib/git-jump/git-jump	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/contrib/git-jump/git-jump	2020-02-17 04:47:35.000000000 +0000
@@ -52,7 +52,7 @@ mode_merge() {
 # editor shows them to us in the status bar.
 mode_grep() {
 	cmd=$(git config jump.grepCmd)
-	test -n "$cmd" || cmd="git grep -n"
+	test -n "$cmd" || cmd="git grep -n --column"
 	$cmd "$@" |
 	perl -pe '
 	s/[ \t]+/ /g;
diff -pruN 1.2.1+git2.18.0-1/git/contrib/git-jump/README 1.2.3+git2.25.1-1/git/contrib/git-jump/README
--- 1.2.1+git2.18.0-1/git/contrib/git-jump/README	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/contrib/git-jump/README	2020-02-17 04:47:35.000000000 +0000
@@ -25,6 +25,13 @@ git-jump will feed this to the editor:
 foo.c:2: printf("hello word!\n");
 -----------------------------------
 
+Or, when running 'git jump grep', column numbers will also be emitted,
+e.g. `git jump grep "hello"` would return:
+
+-----------------------------------
+foo.c:2:9: printf("hello word!\n");
+-----------------------------------
+
 Obviously this trivial case isn't that interesting; you could just open
 `foo.c` yourself. But when you have many changes scattered across a
 project, you can use the editor's support to "jump" from point to point.
@@ -35,7 +42,8 @@ Git-jump can generate four types of inte
 
   2. The beginning of any merge conflict markers.
 
-  3. Any grep matches.
+  3. Any grep matches, including the column of the first match on a
+     line.
 
   4. Any whitespace errors detected by `git diff --check`.
 
@@ -82,7 +90,7 @@ which does something similar to `git jum
 to positioning the cursor to the correct line in only the first file,
 leaving you to locate subsequent hits in that file or other files using
 the editor or pager. By contrast, git-jump provides the editor with a
-complete list of files and line numbers for each match.
+complete list of files, lines, and a column number for each match.
 
 
 Limitations
diff -pruN 1.2.1+git2.18.0-1/git/contrib/hg-to-git/hg-to-git.py 1.2.3+git2.25.1-1/git/contrib/hg-to-git/hg-to-git.py
--- 1.2.1+git2.18.0-1/git/contrib/hg-to-git/hg-to-git.py	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/contrib/hg-to-git/hg-to-git.py	2020-02-17 04:47:35.000000000 +0000
@@ -42,7 +42,7 @@ hgnewcsets = 0
 
 def usage():
 
-        print """\
+        print("""\
 %s: [OPTIONS] <hgprj>
 
 options:
@@ -54,7 +54,7 @@ options:
 
 required:
     hgprj:  name of the HG project to import (directory)
-""" % sys.argv[0]
+""" % sys.argv[0])
 
 #------------------------------------------------------------------------------
 
@@ -104,22 +104,22 @@ os.chdir(hgprj)
 if state:
     if os.path.exists(state):
         if verbose:
-            print 'State does exist, reading'
+            print('State does exist, reading')
         f = open(state, 'r')
         hgvers = pickle.load(f)
     else:
-        print 'State does not exist, first run'
+        print('State does not exist, first run')
 
 sock = os.popen('hg tip --template "{rev}"')
 tip = sock.read()
 if sock.close():
     sys.exit(1)
 if verbose:
-    print 'tip is', tip
+    print('tip is', tip)
 
 # Calculate the branches
 if verbose:
-    print 'analysing the branches...'
+    print('analysing the branches...')
 hgchildren["0"] = ()
 hgparents["0"] = (None, None)
 hgbranch["0"] = "master"
@@ -154,15 +154,15 @@ for cset in range(1, int(tip) + 1):
         else:
             hgbranch[str(cset)] = "branch-" + str(cset)
 
-if not hgvers.has_key("0"):
-    print 'creating repository'
+if "0" not in hgvers:
+    print('creating repository')
     os.system('git init')
 
 # loop through every hg changeset
 for cset in range(int(tip) + 1):
 
     # incremental, already seen
-    if hgvers.has_key(str(cset)):
+    if str(cset) in hgvers:
         continue
     hgnewcsets += 1
 
@@ -180,27 +180,27 @@ for cset in range(int(tip) + 1):
     os.write(fdcomment, csetcomment)
     os.close(fdcomment)
 
-    print '-----------------------------------------'
-    print 'cset:', cset
-    print 'branch:', hgbranch[str(cset)]
-    print 'user:', user
-    print 'date:', date
-    print 'comment:', csetcomment
+    print('-----------------------------------------')
+    print('cset:', cset)
+    print('branch:', hgbranch[str(cset)])
+    print('user:', user)
+    print('date:', date)
+    print('comment:', csetcomment)
     if parent:
-	print 'parent:', parent
+        print('parent:', parent)
     if mparent:
-        print 'mparent:', mparent
+        print('mparent:', mparent)
     if tag:
-        print 'tag:', tag
-    print '-----------------------------------------'
+        print('tag:', tag)
+    print('-----------------------------------------')
 
     # checkout the parent if necessary
     if cset != 0:
         if hgbranch[str(cset)] == "branch-" + str(cset):
-            print 'creating new branch', hgbranch[str(cset)]
+            print('creating new branch', hgbranch[str(cset)])
             os.system('git checkout -b %s %s' % (hgbranch[str(cset)], hgvers[parent]))
         else:
-            print 'checking out branch', hgbranch[str(cset)]
+            print('checking out branch', hgbranch[str(cset)])
             os.system('git checkout %s' % hgbranch[str(cset)])
 
     # merge
@@ -209,7 +209,7 @@ for cset in range(int(tip) + 1):
             otherbranch = hgbranch[mparent]
         else:
             otherbranch = hgbranch[parent]
-        print 'merging', otherbranch, 'into', hgbranch[str(cset)]
+        print('merging', otherbranch, 'into', hgbranch[str(cset)])
         os.system(getgitenv(user, date) + 'git merge --no-commit -s ours "" %s %s' % (hgbranch[str(cset)], otherbranch))
 
     # remove everything except .git and .hg directories
@@ -233,12 +233,12 @@ for cset in range(int(tip) + 1):
 
     # delete branch if not used anymore...
     if mparent and len(hgchildren[str(cset)]):
-        print "Deleting unused branch:", otherbranch
+        print("Deleting unused branch:", otherbranch)
         os.system('git branch -d %s' % otherbranch)
 
     # retrieve and record the version
     vvv = os.popen('git show --quiet --pretty=format:%H').read()
-    print 'record', cset, '->', vvv
+    print('record', cset, '->', vvv)
     hgvers[str(cset)] = vvv
 
 if hgnewcsets >= opt_nrepack and opt_nrepack != -1:
@@ -247,7 +247,7 @@ if hgnewcsets >= opt_nrepack and opt_nre
 # write the state for incrementals
 if state:
     if verbose:
-        print 'Writing state'
+        print('Writing state')
     f = open(state, 'w')
     pickle.dump(hgvers, f)
 
diff -pruN 1.2.1+git2.18.0-1/git/contrib/hooks/multimail/CHANGES 1.2.3+git2.25.1-1/git/contrib/hooks/multimail/CHANGES
--- 1.2.1+git2.18.0-1/git/contrib/hooks/multimail/CHANGES	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/contrib/hooks/multimail/CHANGES	2020-02-17 04:47:35.000000000 +0000
@@ -1,3 +1,59 @@
+Release 1.5.0
+=============
+
+Backward-incompatible change
+----------------------------
+
+The name of classes for environment was misnamed as `*Environement`.
+It is now `*Environment`.
+
+New features
+------------
+
+* A Thread-Index header is now added to each email sent (except for
+  combined emails where it would not make sense), so that MS Outlook
+  properly groups messages by threads even though they have a
+  different subject line. Unfortunately, even adding this header the
+  threading still seems to be unreliable, but it is unclear whether
+  this is an issue on our side or on MS Outlook's side (see discussion
+  here: https://github.com/git-multimail/git-multimail/pull/194).
+
+* A new variable multimailhook.ExcludeMergeRevisions was added to send
+  notification emails only for non-merge commits.
+
+* For gitolite environment, it is now possible to specify the mail map
+  in a separate file in addition to gitolite.conf, using the variable
+  multimailhook.MailaddressMap.
+
+Internal changes
+----------------
+
+* The testsuite now uses GIT_PRINT_SHA1_ELLIPSIS where needed for
+  compatibility with recent Git versions. Only tests are affected.
+
+* We don't try to install pyflakes in the continuous integration job
+  for old Python versions where it's no longer available.
+
+* Stop using the deprecated cgi.escape in Python 3.
+
+* New flake8 warnings have been fixed.
+
+* Python 3.6 is now tested against on Travis-CI.
+
+* A bunch of lgtm.com warnings have been fixed.
+
+Bug fixes
+---------
+
+* SMTPMailer logs in only once now. It used to re-login for each email
+  sent which triggered errors for some SMTP servers.
+
+* migrate-mailhook-config was broken by internal refactoring, it
+  should now work again.
+
+This version was tested with Python 2.6 to 3.7. It was tested with Git
+1.7.10.406.gdc801, 2.15.1 and 2.20.1.98.gecbdaf0.
+
 Release 1.4.0
 =============
 
diff -pruN 1.2.1+git2.18.0-1/git/contrib/hooks/multimail/CONTRIBUTING.rst 1.2.3+git2.25.1-1/git/contrib/hooks/multimail/CONTRIBUTING.rst
--- 1.2.1+git2.18.0-1/git/contrib/hooks/multimail/CONTRIBUTING.rst	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/contrib/hooks/multimail/CONTRIBUTING.rst	2020-02-17 04:47:35.000000000 +0000
@@ -4,9 +4,8 @@ Contributing
 git-multimail is an open-source project, built by volunteers. We would
 welcome your help!
 
-The current maintainers are Matthieu Moy
-<matthieu.moy@grenoble-inp.fr> and Michael Haggerty
-<mhagger@alum.mit.edu>.
+The current maintainers are `Matthieu Moy <http://matthieu-moy.fr>`__ and
+`Michael Haggerty <https://github.com/mhagger>`__.
 
 Please note that although a copy of git-multimail is distributed in
 the "contrib" section of the main Git project, development takes place
@@ -33,6 +32,29 @@ mailing list`_.
 Please CC emails regarding git-multimail to the maintainers so that we
 don't overlook them.
 
+Help needed: testers/maintainer for specific environments/OS
+------------------------------------------------------------
+
+The current maintainer uses and tests git-multimail on Linux with the
+Generic environment. More testers, or better contributors are needed
+to test git-multimail on other real-life setups:
+
+* Mac OS X, Windows: git-multimail is currently not supported on these
+  platforms. But since we have no external dependencies and try to
+  write code as portable as possible, it is possible that
+  git-multimail already runs there and if not, it is likely that it
+  could be ported easily.
+
+  Patches to improve support for Windows and OS X are welcome.
+  Ideally, there would be a sub-maintainer for each OS who would test
+  at least once before each release (around twice a year).
+
+* Gerrit, Stash, Gitolite environments: although the testsuite
+  contains tests for these environments, a tester/maintainer for each
+  environment would be welcome to test and report failure (or success)
+  on real-life environments periodically (here also, feedback before
+  each release would be highly appreciated).
+
 
 .. _`git-multimail repository on GitHub`: https://github.com/git-multimail/git-multimail
 .. _`Git mailing list`: git@vger.kernel.org
diff -pruN 1.2.1+git2.18.0-1/git/contrib/hooks/multimail/doc/gitolite.rst 1.2.3+git2.25.1-1/git/contrib/hooks/multimail/doc/gitolite.rst
--- 1.2.1+git2.18.0-1/git/contrib/hooks/multimail/doc/gitolite.rst	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/contrib/hooks/multimail/doc/gitolite.rst	2020-02-17 04:47:35.000000000 +0000
@@ -46,6 +46,15 @@ and add::
       config multimailhook.mailingList = # Where emails should be sent
       config multimailhook.from = # From address to use
 
+Note that by default, gitolite forbids ``<`` and ``>`` in variable
+values (for security/paranoia reasons, see
+`compensating for UNSAFE_PATT
+<http://gitolite.com/gitolite/git-config/index.html#compensating-for-unsafe95patt>`__
+in gitolite's documentation for explanations and a way to disable
+this). As a consequence, you will not be able to use ``First Last
+<First.Last@example.com>`` as recipient email, but specifying
+``First.Last@example.com`` alone works.
+
 Obviously, you can customize all parameters on a per-repository basis by
 adding these ``config multimailhook.*`` lines in the section
 corresponding to a repository or set of repositories.
diff -pruN 1.2.1+git2.18.0-1/git/contrib/hooks/multimail/git_multimail.py 1.2.3+git2.25.1-1/git/contrib/hooks/multimail/git_multimail.py
--- 1.2.1+git2.18.0-1/git/contrib/hooks/multimail/git_multimail.py	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/contrib/hooks/multimail/git_multimail.py	2020-02-17 04:47:35.000000000 +0000
@@ -1,6 +1,6 @@
 #! /usr/bin/env python
 
-__version__ = '1.4.0'
+__version__ = '1.5.0'
 
 # Copyright (c) 2015-2016 Matthieu Moy and others
 # Copyright (c) 2012-2014 Michael Haggerty and others
@@ -64,7 +64,9 @@ except ImportError:
     # Python < 2.6 do not have ssl, but that's OK if we don't use it.
     pass
 import time
-import cgi
+
+import uuid
+import base64
 
 PYTHON3 = sys.version_info >= (3, 0)
 
@@ -73,7 +75,7 @@ if sys.version_info <= (2, 5):
         for element in iterable:
             if not element:
                 return False
-            return True
+        return True
 
 
 def is_ascii(s):
@@ -93,7 +95,7 @@ if PYTHON3:
     unicode = str
 
     def write_str(f, msg):
-        # Try outputing with the default encoding. If it fails,
+        # Try outputting with the default encoding. If it fails,
         # try UTF-8.
         try:
             f.buffer.write(msg.encode(sys.getdefaultencoding()))
@@ -108,6 +110,12 @@ if PYTHON3:
             return out.decode(sys.getdefaultencoding())
         except UnicodeEncodeError:
             return out.decode(ENCODING)
+
+    import html
+
+    def html_escape(s):
+        return html.escape(s)
+
 else:
     def is_string(s):
         try:
@@ -130,6 +138,10 @@ else:
     def next(it):
         return it.next()
 
+    import cgi
+
+    def html_escape(s):
+        return cgi.escape(s, True)
 
 try:
     from email.charset import Charset
@@ -190,6 +202,7 @@ Content-Transfer-Encoding: 8bit
 Message-ID: %(msgid)s
 From: %(fromaddr)s
 Reply-To: %(reply_to)s
+Thread-Index: %(thread_index)s
 X-Git-Host: %(fqdn)s
 X-Git-Repo: %(repo_shortname)s
 X-Git-Refname: %(refname)s
@@ -322,6 +335,7 @@ From: %(fromaddr)s
 Reply-To: %(reply_to)s
 In-Reply-To: %(reply_to_msgid)s
 References: %(reply_to_msgid)s
+Thread-Index: %(thread_index)s
 X-Git-Host: %(fqdn)s
 X-Git-Repo: %(repo_shortname)s
 X-Git-Refname: %(refname)s
@@ -763,6 +777,9 @@ class GitObject(object):
     def __eq__(self, other):
         return isinstance(other, GitObject) and self.sha1 == other.sha1
 
+    def __ne__(self, other):
+        return not self == other
+
     def __hash__(self):
         return hash(self.sha1)
 
@@ -852,7 +869,7 @@ class Change(object):
         if html_escape_val:
             for k in values:
                 if is_string(values[k]):
-                    values[k] = cgi.escape(values[k], True)
+                    values[k] = html_escape(values[k])
         for line in template.splitlines(True):
             yield line % values
 
@@ -909,7 +926,7 @@ class Change(object):
 
         raise NotImplementedError()
 
-    def generate_email_body(self):
+    def generate_email_body(self, push):
         """Generate the main part of the email body, a line at a time.
 
         The text in the body might be truncated after a specified
@@ -936,7 +953,7 @@ class Change(object):
             yield "<pre style='margin:0'>\n"
 
             for line in lines:
-                yield cgi.escape(line)
+                yield html_escape(line)
 
             yield '</pre>\n'
         else:
@@ -1011,7 +1028,7 @@ class Change(object):
                     fgcolor = '404040'
 
                 # Chop the trailing LF, we don't want it inside <pre>.
-                line = cgi.escape(line[:-1])
+                line = html_escape(line[:-1])
 
                 if bgcolor or fgcolor:
                     style = 'display:block; white-space:pre;'
@@ -1060,6 +1077,10 @@ class Revision(Change):
         self.author = read_git_output(['log', '--no-walk', '--format=%aN <%aE>', self.rev.sha1])
         self.recipients = self.environment.get_revision_recipients(self)
 
+        # -s is short for --no-patch, but -s works on older git's (e.g. 1.7)
+        self.parents = read_git_lines(['show', '-s', '--format=%P',
+                                      self.rev.sha1])[0].split()
+
         self.cc_recipients = ''
         if self.environment.get_scancommitforcc():
             self.cc_recipients = ', '.join(to.strip() for to in self._cc_recipients())
@@ -1090,6 +1111,7 @@ class Revision(Change):
             oneline = oneline[:max_subject_length - 6] + ' [...]'
 
         values['rev'] = self.rev.sha1
+        values['parents'] = ' '.join(self.parents)
         values['rev_short'] = self.rev.short
         values['change_type'] = self.change_type
         values['refname'] = self.refname
@@ -1097,6 +1119,7 @@ class Revision(Change):
         values['short_refname'] = self.reference_change.short_refname
         values['refname_type'] = self.reference_change.refname_type
         values['reply_to_msgid'] = self.reference_change.msgid
+        values['thread_index'] = self.reference_change.thread_index
         values['num'] = self.num
         values['tot'] = self.tot
         values['recipients'] = self.recipients
@@ -1244,6 +1267,23 @@ class ReferenceChange(Change):
             old=old, new=new, rev=rev,
             )
 
+    @staticmethod
+    def make_thread_index():
+        """Return a string appropriate for the Thread-Index header,
+        needed by MS Outlook to get threading right.
+
+        The format is (base64-encoded):
+        - 1 byte must be 1
+        - 5 bytes encode a date (hardcoded here)
+        - 16 bytes for a globally unique identifier
+
+        FIXME: Unfortunately, even with the Thread-Index field, MS
+        Outlook doesn't seem to do the threading reliably (see
+        https://github.com/git-multimail/git-multimail/pull/194).
+        """
+        thread_index = b'\x01\x00\x00\x12\x34\x56' + uuid.uuid4().bytes
+        return base64.standard_b64encode(thread_index).decode('ascii')
+
     def __init__(self, environment, refname, short_refname, old, new, rev):
         Change.__init__(self, environment)
         self.change_type = {
@@ -1257,6 +1297,7 @@ class ReferenceChange(Change):
         self.new = new
         self.rev = rev
         self.msgid = make_msgid()
+        self.thread_index = self.make_thread_index()
         self.diffopts = environment.diffopts
         self.graphopts = environment.graphopts
         self.logopts = environment.logopts
@@ -1276,6 +1317,7 @@ class ReferenceChange(Change):
         values['refname'] = self.refname
         values['short_refname'] = self.short_refname
         values['msgid'] = self.msgid
+        values['thread_index'] = self.thread_index
         values['recipients'] = self.recipients
         values['oldrev'] = str(self.old)
         values['oldrev_short'] = self.old.short
@@ -1941,6 +1983,9 @@ class Mailer(object):
     def __init__(self, environment):
         self.environment = environment
 
+    def close(self):
+        pass
+
     def send(self, lines, to_addrs):
         """Send an email consisting of lines.
 
@@ -2054,6 +2099,7 @@ class SMTPMailer(Mailer):
         self.username = smtpuser
         self.password = smtppass
         self.smtpcacerts = smtpcacerts
+        self.loggedin = False
         try:
             def call(klass, server, timeout):
                 try:
@@ -2083,7 +2129,7 @@ class SMTPMailer(Mailer):
                 # equivalent to
                 #     self.smtp.ehlo()
                 #     self.smtp.starttls()
-                # with acces to the ssl layer
+                # with access to the ssl layer
                 self.smtp.ehlo()
                 if not self.smtp.has_extn("starttls"):
                     raise smtplib.SMTPException("STARTTLS extension not supported by server")
@@ -2102,7 +2148,7 @@ class SMTPMailer(Mailer):
                         cert_reqs=ssl.CERT_NONE
                         )
                     self.environment.get_logger().error(
-                        '*** Warning, the server certificat is not verified (smtp) ***\n'
+                        '*** Warning, the server certificate is not verified (smtp) ***\n'
                         '***          set the option smtpCACerts                   ***\n'
                         )
                 if not hasattr(self.smtp.sock, "read"):
@@ -2130,20 +2176,30 @@ class SMTPMailer(Mailer):
                 % (self.smtpserver, sys.exc_info()[1]))
             sys.exit(1)
 
-    def __del__(self):
+    def close(self):
         if hasattr(self, 'smtp'):
             self.smtp.quit()
             del self.smtp
 
+    def __del__(self):
+        self.close()
+
     def send(self, lines, to_addrs):
         try:
             if self.username or self.password:
-                self.smtp.login(self.username, self.password)
+                if not self.loggedin:
+                    self.smtp.login(self.username, self.password)
+                    self.loggedin = True
             msg = ''.join(lines)
             # turn comma-separated list into Python list if needed.
             if is_string(to_addrs):
                 to_addrs = [email for (name, email) in getaddresses([to_addrs])]
             self.smtp.sendmail(self.envelopesender, to_addrs, msg)
+        except socket.timeout:
+            self.environment.get_logger().error(
+                '*** Error sending email ***\n'
+                '*** SMTP server timed out (timeout is %s)\n'
+                % self.smtpservertimeout)
         except smtplib.SMTPResponseException:
             err = sys.exc_info()[1]
             self.environment.get_logger().error(
@@ -2171,7 +2227,8 @@ class OutputMailer(Mailer):
 
     SEPARATOR = '=' * 75 + '\n'
 
-    def __init__(self, f):
+    def __init__(self, f, environment=None):
+        super(OutputMailer, self).__init__(environment=environment)
         self.f = f
 
     def send(self, lines, to_addrs):
@@ -2382,6 +2439,7 @@ class Environment(object):
         self.html_in_footer = False
         self.commitBrowseURL = None
         self.maxcommitemails = 500
+        self.excludemergerevisions = False
         self.diffopts = ['--stat', '--summary', '--find-copies-harder']
         self.graphopts = ['--oneline', '--decorate']
         self.logopts = []
@@ -2621,6 +2679,8 @@ class ConfigOptionsEnvironmentMixin(Conf
 
         self.commitBrowseURL = config.get('commitBrowseURL')
 
+        self.excludemergerevisions = config.get('excludeMergeRevisions')
+
         maxcommitemails = config.get('maxcommitemails')
         if maxcommitemails is not None:
             try:
@@ -3129,7 +3189,7 @@ class ProjectdescEnvironmentMixin(Enviro
         self.COMPUTED_KEYS += ['projectdesc']
 
     def get_projectdesc(self):
-        """Return a one-line descripition of the project."""
+        """Return a one-line description of the project."""
 
         git_dir = get_git_dir()
         try:
@@ -3152,7 +3212,10 @@ class GitoliteEnvironmentHighPrecMixin(E
         return self.osenv.get('GL_USER', 'unknown user')
 
 
-class GitoliteEnvironmentLowPrecMixin(Environment):
+class GitoliteEnvironmentLowPrecMixin(
+        ConfigEnvironmentMixin,
+        Environment):
+
     def get_repo_shortname(self):
         # The gitolite environment variable $GL_REPO is a pretty good
         # repo_shortname (though it's probably not as good as a value
@@ -3162,6 +3225,16 @@ class GitoliteEnvironmentLowPrecMixin(En
             super(GitoliteEnvironmentLowPrecMixin, self).get_repo_shortname()
             )
 
+    @staticmethod
+    def _compile_regex(re_template):
+        return (
+            re.compile(re_template % x)
+            for x in (
+                r'BEGIN\s+USER\s+EMAILS',
+                r'([^\s]+)\s+(.*)',
+                r'END\s+USER\s+EMAILS',
+                ))
+
     def get_fromaddr(self, change=None):
         GL_USER = self.osenv.get('GL_USER')
         if GL_USER is not None:
@@ -3174,18 +3247,42 @@ class GitoliteEnvironmentLowPrecMixin(En
             GL_CONF = self.osenv.get(
                 'GL_CONF',
                 os.path.join(GL_ADMINDIR, 'conf', 'gitolite.conf'))
+
+            mailaddress_map = self.config.get('MailaddressMap')
+            # If relative, consider relative to GL_CONF:
+            if mailaddress_map:
+                mailaddress_map = os.path.join(os.path.dirname(GL_CONF),
+                                               mailaddress_map)
+                if os.path.isfile(mailaddress_map):
+                    f = open(mailaddress_map, 'rU')
+                    try:
+                        # Leading '#' is optional
+                        re_begin, re_user, re_end = self._compile_regex(
+                            r'^(?:\s*#)?\s*%s\s*$')
+                        for l in f:
+                            l = l.rstrip('\n')
+                            if re_begin.match(l) or re_end.match(l):
+                                continue  # Ignore these lines
+                            m = re_user.match(l)
+                            if m:
+                                if m.group(1) == GL_USER:
+                                    return m.group(2)
+                                else:
+                                    continue  # Not this user, but not an error
+                            raise ConfigurationException(
+                                "Syntax error in mail address map.\n"
+                                "Check file {}.\n"
+                                "Line: {}".format(mailaddress_map, l))
+
+                    finally:
+                        f.close()
+
             if os.path.isfile(GL_CONF):
                 f = open(GL_CONF, 'rU')
                 try:
                     in_user_emails_section = False
-                    re_template = r'^\s*#\s*%s\s*$'
-                    re_begin, re_user, re_end = (
-                        re.compile(re_template % x)
-                        for x in (
-                            r'BEGIN\s+USER\s+EMAILS',
-                            re.escape(GL_USER) + r'\s+(.*)',
-                            r'END\s+USER\s+EMAILS',
-                            ))
+                    re_begin, re_user, re_end = self._compile_regex(
+                        r'^\s*#\s*%s\s*$')
                     for l in f:
                         l = l.rstrip('\n')
                         if not in_user_emails_section:
@@ -3195,8 +3292,8 @@ class GitoliteEnvironmentLowPrecMixin(En
                         if re_end.match(l):
                             break
                         m = re_user.match(l)
-                        if m:
-                            return m.group(1)
+                        if m and m.group(1) == GL_USER:
+                            return m.group(2)
                 finally:
                     f.close()
         return super(GitoliteEnvironmentLowPrecMixin, self).get_fromaddr(change)
@@ -3228,7 +3325,7 @@ class StashEnvironmentHighPrecMixin(Envi
         self.__repo = repo
 
     def get_pusher(self):
-        return re.match('(.*?)\s*<', self.__user).group(1)
+        return re.match(r'(.*?)\s*<', self.__user).group(1)
 
     def get_pusher_email(self):
         return self.__user
@@ -3262,7 +3359,7 @@ class GerritEnvironmentHighPrecMixin(Env
             if self.__submitter.find('<') != -1:
                 # Submitter has a configured email, we transformed
                 # __submitter into an RFC 2822 string already.
-                return re.match('(.*?)\s*<', self.__submitter).group(1)
+                return re.match(r'(.*?)\s*<', self.__submitter).group(1)
             else:
                 # Submitter has no configured email, it's just his name.
                 return self.__submitter
@@ -3615,6 +3712,9 @@ class Push(object):
 
             for (num, sha1) in enumerate(sha1s):
                 rev = Revision(change, GitObject(sha1), num=num + 1, tot=len(sha1s))
+                if len(rev.parents) > 1 and change.environment.excludemergerevisions:
+                    # skipping a merge commit
+                    continue
                 if not rev.recipients and rev.cc_recipients:
                     change.environment.log_msg('*** Replacing Cc: with To:')
                     rev.recipients = rev.cc_recipients
@@ -3664,11 +3764,14 @@ def run_as_post_receive_hook(environment
         changes.append(
             ReferenceChange.create(environment, oldrev, newrev, refname)
             )
-    if changes:
-        push = Push(environment, changes)
+    if not changes:
+        mailer.close()
+        return
+    push = Push(environment, changes)
+    try:
         push.send_emails(mailer, body_filter=environment.filter_body)
-    if hasattr(mailer, '__del__'):
-        mailer.__del__()
+    finally:
+        mailer.close()
 
 
 def run_as_update_hook(environment, mailer, refname, oldrev, newrev, force_send=False):
@@ -3687,10 +3790,14 @@ def run_as_update_hook(environment, mail
             refname,
             ),
         ]
+    if not changes:
+        mailer.close()
+        return
     push = Push(environment, changes, force_send)
-    push.send_emails(mailer, body_filter=environment.filter_body)
-    if hasattr(mailer, '__del__'):
-        mailer.__del__()
+    try:
+        push.send_emails(mailer, body_filter=environment.filter_body)
+    finally:
+        mailer.close()
 
 
 def check_ref_filter(environment):
@@ -3860,7 +3967,7 @@ def build_environment_klass(env_name):
         low_prec_mixin = known_env['lowprec']
         environment_mixins.append(low_prec_mixin)
     environment_mixins.append(Environment)
-    klass_name = env_name.capitalize() + 'Environement'
+    klass_name = env_name.capitalize() + 'Environment'
     environment_klass = type(
         klass_name,
         tuple(environment_mixins),
@@ -4057,21 +4164,21 @@ class Logger(object):
                 environment, 'git_multimail.error', environment.error_log_file, logging.ERROR)
             self.loggers.append(error_log_file)
 
-    def info(self, msg):
+    def info(self, msg, *args, **kwargs):
         for l in self.loggers:
-            l.info(msg)
+            l.info(msg, *args, **kwargs)
 
-    def debug(self, msg):
+    def debug(self, msg, *args, **kwargs):
         for l in self.loggers:
-            l.debug(msg)
+            l.debug(msg, *args, **kwargs)
 
-    def warning(self, msg):
+    def warning(self, msg, *args, **kwargs):
         for l in self.loggers:
-            l.warning(msg)
+            l.warning(msg, *args, **kwargs)
 
-    def error(self, msg):
+    def error(self, msg, *args, **kwargs):
         for l in self.loggers:
-            l.error(msg)
+            l.error(msg, *args, **kwargs)
 
 
 def main(args):
@@ -4189,7 +4296,7 @@ def main(args):
             show_env(environment, sys.stderr)
 
         if options.stdout or environment.stdout:
-            mailer = OutputMailer(sys.stdout)
+            mailer = OutputMailer(sys.stdout, environment)
         else:
             mailer = choose_mailer(config, environment)
 
@@ -4234,5 +4341,6 @@ def main(args):
             sys.stderr.write(msg)
         sys.exit(1)
 
+
 if __name__ == '__main__':
     main(sys.argv[1:])
diff -pruN 1.2.1+git2.18.0-1/git/contrib/hooks/multimail/migrate-mailhook-config 1.2.3+git2.25.1-1/git/contrib/hooks/multimail/migrate-mailhook-config
--- 1.2.1+git2.18.0-1/git/contrib/hooks/multimail/migrate-mailhook-config	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/contrib/hooks/multimail/migrate-mailhook-config	2020-02-17 04:47:35.000000000 +0000
@@ -110,11 +110,12 @@ def is_section_empty(section, local):
 
     try:
         read_output(
-            ['git', 'config']
-            + local_option
-            + ['--get-regexp', '^%s\.' % (section,)]
+            ['git', 'config'] +
+            local_option +
+            ['--get-regexp', '^%s\.' % (section,)]
             )
-    except CommandError, e:
+    except CommandError:
+        t, e, traceback = sys.exc_info()
         if e.retcode == 1:
             # This means that no settings were found.
             return True
@@ -188,7 +189,9 @@ def migrate_config(strict=False, retain=
             sys.stderr.write(
                 '...copying "%s.%s" to "%s.%s"\n' % (old.section, name, new.section, name)
                 )
-            new.set_recipients(name, old.get_recipients(name))
+            old_recipients = old.get_all(name, default=None)
+            old_recipients = ', '.join(o.strip() for o in old_recipients)
+            new.set_recipients(name, old_recipients)
 
     if strict:
         sys.stderr.write(
diff -pruN 1.2.1+git2.18.0-1/git/contrib/hooks/multimail/post-receive.example 1.2.3+git2.25.1-1/git/contrib/hooks/multimail/post-receive.example
--- 1.2.1+git2.18.0-1/git/contrib/hooks/multimail/post-receive.example	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/contrib/hooks/multimail/post-receive.example	2020-02-17 04:47:35.000000000 +0000
@@ -30,7 +30,6 @@ script's behavior could be changed or cu
 """
 
 import sys
-import os
 
 # If necessary, add the path to the directory containing
 # git_multimail.py to the Python path as follows.  (This is not
@@ -57,7 +56,7 @@ config = git_multimail.Config('multimail
 
 # Set some Git configuration variables. Equivalent to passing var=val
 # to "git -c var=val" each time git is called, or to adding the
-# configuration in .git/config (must come before instanciating the
+# configuration in .git/config (must come before instantiating the
 # environment) :
 #git_multimail.Config.add_config_parameters('multimailhook.commitEmailFormat=html')
 #git_multimail.Config.add_config_parameters(('user.name=foo', 'user.email=foo@example.com'))
@@ -86,6 +85,7 @@ mailer = git_multimail.choose_mailer(con
 
 # Use Python's smtplib to send emails.  Both arguments are required.
 #mailer = git_multimail.SMTPMailer(
+#    environment=environment,
 #    envelopesender='git-repo@example.com',
 #    # The smtpserver argument can also include a port number; e.g.,
 #    #     smtpserver='mail.example.com:25'
diff -pruN 1.2.1+git2.18.0-1/git/contrib/hooks/multimail/README 1.2.3+git2.25.1-1/git/contrib/hooks/multimail/README
--- 1.2.1+git2.18.0-1/git/contrib/hooks/multimail/README	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/contrib/hooks/multimail/README	1970-01-01 00:00:00.000000000 +0000
@@ -1,748 +0,0 @@
-git-multimail version 1.4.0
-===========================
-
-.. image:: https://travis-ci.org/git-multimail/git-multimail.svg?branch=master
-    :target: https://travis-ci.org/git-multimail/git-multimail
-
-git-multimail is a tool for sending notification emails on pushes to a
-Git repository.  It includes a Python module called ``git_multimail.py``,
-which can either be used as a hook script directly or can be imported
-as a Python module into another script.
-
-git-multimail is derived from the Git project's old
-contrib/hooks/post-receive-email, and is mostly compatible with that
-script.  See README.migrate-from-post-receive-email for details about
-the differences and for how to migrate from post-receive-email to
-git-multimail.
-
-git-multimail, like the rest of the Git project, is licensed under
-GPLv2 (see the COPYING file for details).
-
-Please note: although, as a convenience, git-multimail may be
-distributed along with the main Git project, development of
-git-multimail takes place in its own, separate project.  See section
-"Getting involved" below for more information.
-
-
-By default, for each push received by the repository, git-multimail:
-
-1. Outputs one email summarizing each reference that was changed.
-   These "reference change" (called "refchange" below) emails describe
-   the nature of the change (e.g., was the reference created, deleted,
-   fast-forwarded, etc.) and include a one-line summary of each commit
-   that was added to the reference.
-
-2. Outputs one email for each new commit that was introduced by the
-   reference change.  These "commit" emails include a list of the
-   files changed by the commit, followed by the diffs of files
-   modified by the commit.  The commit emails are threaded to the
-   corresponding reference change email via "In-Reply-To".  This style
-   (similar to the "git format-patch" style used on the Git mailing
-   list) makes it easy to scan through the emails, jump to patches
-   that need further attention, and write comments about specific
-   commits.  Commits are handled in reverse topological order (i.e.,
-   parents shown before children).  For example::
-
-     [git] branch master updated
-     + [git] 01/08: doc: fix xref link from api docs to manual pages
-     + [git] 02/08: api-credentials.txt: show the big picture first
-     + [git] 03/08: api-credentials.txt: mention credential.helper explicitly
-     + [git] 04/08: api-credentials.txt: add "see also" section
-     + [git] 05/08: t3510 (cherry-pick-sequence): add missing '&&'
-     + [git] 06/08: Merge branch 'rr/maint-t3510-cascade-fix'
-     + [git] 07/08: Merge branch 'mm/api-credentials-doc'
-     + [git] 08/08: Git 1.7.11-rc2
-
-   By default, each commit appears in exactly one commit email, the
-   first time that it is pushed to the repository.  If a commit is later
-   merged into another branch, then a one-line summary of the commit
-   is included in the reference change email (as usual), but no
-   additional commit email is generated. See
-   `multimailhook.refFilter(Inclusion|Exclusion|DoSend|DontSend)Regex`
-   below to configure which branches and tags are watched by the hook.
-
-   By default, reference change emails have their "Reply-To" field set
-   to the person who pushed the change, and commit emails have their
-   "Reply-To" field set to the author of the commit.
-
-3. Output one "announce" mail for each new annotated tag, including
-   information about the tag and optionally a shortlog describing the
-   changes since the previous tag.  Such emails might be useful if you
-   use annotated tags to mark releases of your project.
-
-
-Requirements
-------------
-
-* Python 2.x, version 2.4 or later.  No non-standard Python modules
-  are required.  git-multimail has preliminary support for Python 3
-  (but it has been better tested with Python 2).
-
-* The ``git`` command must be in your PATH.  git-multimail is known to
-  work with Git versions back to 1.7.1.  (Earlier versions have not
-  been tested; if you do so, please report your results.)
-
-* To send emails using the default configuration, a standard sendmail
-  program must be located at '/usr/sbin/sendmail' or
-  '/usr/lib/sendmail' and must be configured correctly to send emails.
-  If this is not the case, set multimailhook.sendmailCommand, or see
-  the multimailhook.mailer configuration variable below for how to
-  configure git-multimail to send emails via an SMTP server.
-
-
-Invocation
-----------
-
-``git_multimail.py`` is designed to be used as a ``post-receive`` hook in a
-Git repository (see githooks(5)).  Link or copy it to
-$GIT_DIR/hooks/post-receive within the repository for which email
-notifications are desired.  Usually it should be installed on the
-central repository for a project, to which all commits are eventually
-pushed.
-
-For use on pre-v1.5.1 Git servers, ``git_multimail.py`` can also work as
-an ``update`` hook, taking its arguments on the command line.  To use
-this script in this manner, link or copy it to $GIT_DIR/hooks/update.
-Please note that the script is not completely reliable in this mode
-[1]_.
-
-Alternatively, ``git_multimail.py`` can be imported as a Python module
-into your own Python post-receive script.  This method is a bit more
-work, but allows the behavior of the hook to be customized using
-arbitrary Python code.  For example, you can use a custom environment
-(perhaps inheriting from GenericEnvironment or GitoliteEnvironment) to
-
-* change how the user who did the push is determined
-
-* read users' email addresses from an LDAP server or from a database
-
-* decide which users should be notified about which commits based on
-  the contents of the commits (e.g., for users who want to be notified
-  only about changes affecting particular files or subdirectories)
-
-Or you can change how emails are sent by writing your own Mailer
-class.  The ``post-receive`` script in this directory demonstrates how
-to use ``git_multimail.py`` as a Python module.  (If you make interesting
-changes of this type, please consider sharing them with the
-community.)
-
-
-Troubleshooting/FAQ
--------------------
-
-Please read `<doc/troubleshooting.rst>`__ for frequently asked
-questions and common issues with git-multimail.
-
-
-Configuration
--------------
-
-By default, git-multimail mostly takes its configuration from the
-following ``git config`` settings:
-
-multimailhook.environment
-    This describes the general environment of the repository. In most
-    cases, you do not need to specify a value for this variable:
-    `git-multimail` will autodetect which environment to use.
-    Currently supported values:
-
-    generic
-      the username of the pusher is read from $USER or $USERNAME and
-      the repository name is derived from the repository's path.
-
-    gitolite
-      Environment to use when ``git-multimail`` is ran as a gitolite_
-      hook.
-
-      The username of the pusher is read from $GL_USER, the repository
-      name is read from $GL_REPO, and the From: header value is
-      optionally read from gitolite.conf (see multimailhook.from).
-
-      For more information about gitolite and git-multimail, read
-      `<doc/gitolite.rst>`__
-
-    stash
-      Environment to use when ``git-multimail`` is ran as an Atlassian
-      BitBucket Server (formerly known as Atlassian Stash) hook.
-
-      **Warning:** this mode was provided by a third-party contributor
-      and never tested by the git-multimail maintainers. It is
-      provided as-is and may or may not work for you.
-
-      This value is automatically assumed when the stash-specific
-      flags (``--stash-user`` and ``--stash-repo``) are specified on
-      the command line. When this environment is active, the username
-      and repo come from these two command line flags, which must be
-      specified.
-
-    gerrit
-      Environment to use when ``git-multimail`` is ran as a
-      ``ref-updated`` Gerrit hook.
-
-      This value is used when the gerrit-specific command line flags
-      (``--oldrev``, ``--newrev``, ``--refname``, ``--project``) for
-      gerrit's ref-updated hook are present. When this environment is
-      active, the username of the pusher is taken from the
-      ``--submitter`` argument if that command line option is passed,
-      otherwise 'Gerrit' is used. The repository name is taken from
-      the ``--project`` option on the command line, which must be passed.
-
-      For more information about gerrit and git-multimail, read
-      `<doc/gerrit.rst>`__
-
-    If none of these environments is suitable for your setup, then you
-    can implement a Python class that inherits from Environment and
-    instantiate it via a script that looks like the example
-    post-receive script.
-
-    The environment value can be specified on the command line using
-    the ``--environment`` option. If it is not specified on the
-    command line or by ``multimailhook.environment``, the value is
-    guessed as follows:
-
-    * If stash-specific (respectively gerrit-specific) command flags
-      are present on the command-line, then ``stash`` (respectively
-      ``gerrit``) is used.
-
-    * If the environment variables $GL_USER and $GL_REPO are set, then
-      ``gitolite`` is used.
-
-    * If none of the above apply, then ``generic`` is used.
-
-multimailhook.repoName
-    A short name of this Git repository, to be used in various places
-    in the notification email text.  The default is to use $GL_REPO
-    for gitolite repositories, or otherwise to derive this value from
-    the repository path name.
-
-multimailhook.mailingList
-    The list of email addresses to which notification emails should be
-    sent, as RFC 2822 email addresses separated by commas.  This
-    configuration option can be multivalued.  Leave it unset or set it
-    to the empty string to not send emails by default.  The next few
-    settings can be used to configure specific address lists for
-    specific types of notification email.
-
-multimailhook.refchangeList
-    The list of email addresses to which summary emails about
-    reference changes should be sent, as RFC 2822 email addresses
-    separated by commas.  This configuration option can be
-    multivalued.  The default is the value in
-    multimailhook.mailingList.  Set this value to "none" (or the empty
-    string) to prevent reference change emails from being sent even if
-    multimailhook.mailingList is set.
-
-multimailhook.announceList
-    The list of email addresses to which emails about new annotated
-    tags should be sent, as RFC 2822 email addresses separated by
-    commas.  This configuration option can be multivalued.  The
-    default is the value in multimailhook.refchangeList or
-    multimailhook.mailingList.  Set this value to "none" (or the empty
-    string) to prevent annotated tag announcement emails from being sent
-    even if one of the other values is set.
-
-multimailhook.commitList
-    The list of email addresses to which emails about individual new
-    commits should be sent, as RFC 2822 email addresses separated by
-    commas.  This configuration option can be multivalued.  The
-    default is the value in multimailhook.mailingList.  Set this value
-    to "none" (or the empty string) to prevent notification emails about
-    individual commits from being sent even if
-    multimailhook.mailingList is set.
-
-multimailhook.announceShortlog
-    If this option is set to true, then emails about changes to
-    annotated tags include a shortlog of changes since the previous
-    tag.  This can be useful if the annotated tags represent releases;
-    then the shortlog will be a kind of rough summary of what has
-    happened since the last release.  But if your tagging policy is
-    not so straightforward, then the shortlog might be confusing
-    rather than useful.  Default is false.
-
-multimailhook.commitEmailFormat
-    The format of email messages for the individual commits, can be "text" or
-    "html". In the latter case, the emails will include diffs using colorized
-    HTML instead of plain text used by default. Note that this  currently the
-    ref change emails are always sent in plain text.
-
-    Note that when using "html", the formatting is done by parsing the
-    output of ``git log`` with ``-p``. When using
-    ``multimailhook.commitLogOpts`` to specify a ``--format`` for
-    ``git log``, one may get false positive (e.g. lines in the body of
-    the message starting with ``+++`` or ``---`` colored in red or
-    green).
-
-    By default, all the message is HTML-escaped. See
-    ``multimailhook.htmlInIntro`` to change this behavior.
-
-multimailhook.commitBrowseURL
-    Used to generate a link to an online repository browser in commit
-    emails. This variable must be a string. Format directives like
-    ``%(<variable>)s`` will be expanded the same way as template
-    strings. In particular, ``%(id)s`` will be replaced by the full
-    Git commit identifier (40-chars hexadecimal).
-
-    If the string does not contain any format directive, then
-    ``%(id)s`` will be automatically added to the string. If you don't
-    want ``%(id)s`` to be automatically added, use the empty format
-    directive ``%()s`` anywhere in the string.
-
-    For example, a suitable value for the git-multimail project itself
-    would be
-    ``https://github.com/git-multimail/git-multimail/commit/%(id)s``.
-
-multimailhook.htmlInIntro, multimailhook.htmlInFooter
-    When generating an HTML message, git-multimail escapes any HTML
-    sequence by default. This means that if a template contains HTML
-    like ``<a href="foo">link</a>``, the reader will see the HTML
-    source code and not a proper link.
-
-    Set ``multimailhook.htmlInIntro`` to true to allow writing HTML
-    formatting in introduction templates. Similarly, set
-    ``multimailhook.htmlInFooter`` for HTML in the footer.
-
-    Variables expanded in the template are still escaped. For example,
-    if a repository's path contains a ``<``, it will be rendered as
-    such in the message.
-
-    Read `<doc/customizing-emails.rst>`__ for more details and
-    examples.
-
-multimailhook.refchangeShowGraph
-    If this option is set to true, then summary emails about reference
-    changes will additionally include:
-
-    * a graph of the added commits (if any)
-
-    * a graph of the discarded commits (if any)
-
-    The log is generated by running ``git log --graph`` with the options
-    specified in graphOpts.  The default is false.
-
-multimailhook.refchangeShowLog
-    If this option is set to true, then summary emails about reference
-    changes will include a detailed log of the added commits in
-    addition to the one line summary.  The log is generated by running
-    ``git log`` with the options specified in multimailhook.logOpts.
-    Default is false.
-
-multimailhook.mailer
-    This option changes the way emails are sent.  Accepted values are:
-
-    * **sendmail (the default)**: use the command ``/usr/sbin/sendmail`` or
-      ``/usr/lib/sendmail`` (or sendmailCommand, if configured).  This
-      mode can be further customized via the following options:
-
-      multimailhook.sendmailCommand
-          The command used by mailer ``sendmail`` to send emails.  Shell
-          quoting is allowed in the value of this setting, but remember that
-          Git requires double-quotes to be escaped; e.g.::
-
-              git config multimailhook.sendmailcommand '/usr/sbin/sendmail -oi -t -F \"Git Repo\"'
-
-          Default is '/usr/sbin/sendmail -oi -t' or
-          '/usr/lib/sendmail -oi -t' (depending on which file is
-          present and executable).
-
-      multimailhook.envelopeSender
-          If set then pass this value to sendmail via the -f option to set
-          the envelope sender address.
-
-    * **smtp**: use Python's smtplib.  This is useful when the sendmail
-      command is not available on the system.  This mode can be
-      further customized via the following options:
-
-      multimailhook.smtpServer
-          The name of the SMTP server to connect to.  The value can
-          also include a colon and a port number; e.g.,
-          ``mail.example.com:25``.  Default is 'localhost' using port 25.
-
-      multimailhook.smtpUser, multimailhook.smtpPass
-          Server username and password. Required if smtpEncryption is 'ssl'.
-          Note that the username and password currently need to be
-          set cleartext in the configuration file, which is not
-          recommended. If you need to use this option, be sure your
-          configuration file is read-only.
-
-      multimailhook.envelopeSender
-        The sender address to be passed to the SMTP server.  If
-        unset, then the value of multimailhook.from is used.
-
-      multimailhook.smtpServerTimeout
-        Timeout in seconds.
-
-      multimailhook.smtpEncryption
-        Set the security type. Allowed values: ``none``, ``ssl``, ``tls`` (starttls).
-        Default is ``none``.
-
-      multimailhook.smtpCACerts
-        Set the path to a list of trusted CA certificate to verify the
-        server certificate, only supported when ``smtpEncryption`` is
-        ``tls``. If unset or empty, the server certificate is not
-        verified. If it targets a file containing a list of trusted CA
-        certificates (PEM format) these CAs will be used to verify the
-        server certificate. For debian, you can set
-        ``/etc/ssl/certs/ca-certificates.crt`` for using the system
-        trusted CAs. For self-signed server, you can add your server
-        certificate to the system store::
-
-            cd /usr/local/share/ca-certificates/
-            openssl s_client -starttls smtp \
-                   -connect mail.example.net:587 -showcerts \
-                   </dev/null 2>/dev/null \
-                 | openssl x509 -outform PEM >mail.example.net.crt
-            update-ca-certificates
-
-        and used the updated ``/etc/ssl/certs/ca-certificates.crt``. Or
-        directly use your ``/path/to/mail.example.net.crt``. Default is
-        unset.
-
-      multimailhook.smtpServerDebugLevel
-        Integer number. Set to greater than 0 to activate debugging.
-
-multimailhook.from, multimailhook.fromCommit, multimailhook.fromRefchange
-    If set, use this value in the From: field of generated emails.
-    ``fromCommit`` is used for commit emails, ``fromRefchange`` is
-    used for refchange emails, and ``from`` is used as fall-back in
-    all cases.
-
-    The value for these variables can be either:
-
-    - An email address, which will be used directly.
-
-    - The value ``pusher``, in which case the pusher's address (if
-      available) will be used.
-
-    - The value ``author`` (meaningful only for ``fromCommit``), in which
-      case the commit author's address will be used.
-
-    If config values are unset, the value of the From: header is
-    determined as follows:
-
-    1. (gitolite environment only) Parse gitolite.conf, looking for a
-       block of comments that looks like this::
-
-           # BEGIN USER EMAILS
-           # username Firstname Lastname <email@example.com>
-           # END USER EMAILS
-
-       If that block exists, and there is a line between the BEGIN
-       USER EMAILS and END USER EMAILS lines where the first field
-       matches the gitolite username ($GL_USER), use the rest of the
-       line for the From: header.
-
-    2. If the user.email configuration setting is set, use its value
-       (and the value of user.name, if set).
-
-    3. Use the value of multimailhook.envelopeSender.
-
-multimailhook.administrator
-    The name and/or email address of the administrator of the Git
-    repository; used in FOOTER_TEMPLATE.  Default is
-    multimailhook.envelopesender if it is set; otherwise a generic
-    string is used.
-
-multimailhook.emailPrefix
-    All emails have this string prepended to their subjects, to aid
-    email filtering (though filtering based on the X-Git-* email
-    headers is probably more robust).  Default is the short name of
-    the repository in square brackets; e.g., ``[myrepo]``.  Set this
-    value to the empty string to suppress the email prefix. You may
-    use the placeholder ``%(repo_shortname)s`` for the short name of
-    the repository.
-
-multimailhook.emailMaxLines
-    The maximum number of lines that should be included in the body of
-    a generated email.  If not specified, there is no limit.  Lines
-    beyond the limit are suppressed and counted, and a final line is
-    added indicating the number of suppressed lines.
-
-multimailhook.emailMaxLineLength
-    The maximum length of a line in the email body.  Lines longer than
-    this limit are truncated to this length with a trailing ``[...]``
-    added to indicate the missing text.  The default is 500, because
-    (a) diffs with longer lines are probably from binary files, for
-    which a diff is useless, and (b) even if a text file has such long
-    lines, the diffs are probably unreadable anyway.  To disable line
-    truncation, set this option to 0.
-
-multimailhook.subjectMaxLength
-    The maximum length of the subject line (i.e. the ``oneline`` field
-    in templates, not including the prefix). Lines longer than this
-    limit are truncated to this length with a trailing ``[...]`` added
-    to indicate the missing text. This option The default is to use
-    ``multimailhook.emailMaxLineLength``. This option avoids sending
-    emails with overly long subject lines, but should not be needed if
-    the commit messages follow the Git convention (one short subject
-    line, then a blank line, then the message body). To disable line
-    truncation, set this option to 0.
-
-multimailhook.maxCommitEmails
-    The maximum number of commit emails to send for a given change.
-    When the number of patches is larger that this value, only the
-    summary refchange email is sent.  This can avoid accidental
-    mailbombing, for example on an initial push.  To disable commit
-    emails limit, set this option to 0.  The default is 500.
-
-multimailhook.emailStrictUTF8
-    If this boolean option is set to `true`, then the main part of the
-    email body is forced to be valid UTF-8.  Any characters that are
-    not valid UTF-8 are converted to the Unicode replacement
-    character, U+FFFD.  The default is `true`.
-
-    This option is ineffective with Python 3, where non-UTF-8
-    characters are unconditionally replaced.
-
-multimailhook.diffOpts
-    Options passed to ``git diff-tree`` when generating the summary
-    information for ReferenceChange emails.  Default is ``--stat
-    --summary --find-copies-harder``.  Add -p to those options to
-    include a unified diff of changes in addition to the usual summary
-    output.  Shell quoting is allowed; see ``multimailhook.logOpts`` for
-    details.
-
-multimailhook.graphOpts
-    Options passed to ``git log --graph`` when generating graphs for the
-    reference change summary emails (used only if refchangeShowGraph
-    is true).  The default is '--oneline --decorate'.
-
-    Shell quoting is allowed; see logOpts for details.
-
-multimailhook.logOpts
-    Options passed to ``git log`` to generate additional info for
-    reference change emails (used only if refchangeShowLog is set).
-    For example, adding -p will show each commit's complete diff.  The
-    default is empty.
-
-    Shell quoting is allowed; for example, a log format that contains
-    spaces can be specified using something like::
-
-      git config multimailhook.logopts '--pretty=format:"%h %aN <%aE>%n%s%n%n%b%n"'
-
-    If you want to set this by editing your configuration file
-    directly, remember that Git requires double-quotes to be escaped
-    (see git-config(1) for more information)::
-
-      [multimailhook]
-              logopts = --pretty=format:\"%h %aN <%aE>%n%s%n%n%b%n\"
-
-multimailhook.commitLogOpts
-    Options passed to ``git log`` to generate additional info for
-    revision change emails.  For example, adding --ignore-all-spaces
-    will suppress whitespace changes.  The default options are ``-C
-    --stat -p --cc``.  Shell quoting is allowed; see
-    multimailhook.logOpts for details.
-
-multimailhook.dateSubstitute
-    String to use as a substitute for ``Date:`` in the output of ``git
-    log`` while formatting commit messages. This is useful to avoid
-    emitting a line that can be interpreted by mailers as the start of
-    a cited message (Zimbra webmail in particular). Defaults to
-    ``CommitDate:``. Set to an empty string or ``none`` to deactivate
-    the behavior.
-
-multimailhook.emailDomain
-    Domain name appended to the username of the person doing the push
-    to convert it into an email address
-    (via ``"%s@%s" % (username, emaildomain)``). More complicated
-    schemes can be implemented by overriding Environment and
-    overriding its get_pusher_email() method.
-
-multimailhook.replyTo, multimailhook.replyToCommit, multimailhook.replyToRefchange
-    Addresses to use in the Reply-To: field for commit emails
-    (replyToCommit) and refchange emails (replyToRefchange).
-    multimailhook.replyTo is used as default when replyToCommit or
-    replyToRefchange is not set. The shortcuts ``pusher`` and
-    ``author`` are allowed with the same semantics as for
-    ``multimailhook.from``. In addition, the value ``none`` can be
-    used to omit the ``Reply-To:`` field.
-
-    The default is ``pusher`` for refchange emails, and ``author`` for
-    commit emails.
-
-multimailhook.quiet
-    Do not output the list of email recipients from the hook
-
-multimailhook.stdout
-    For debugging, send emails to stdout rather than to the
-    mailer.  Equivalent to the --stdout command line option
-
-multimailhook.scanCommitForCc
-    If this option is set to true, than recipients from lines in commit body
-    that starts with ``CC:`` will be added to CC list.
-    Default: false
-
-multimailhook.combineWhenSingleCommit
-    If this option is set to true and a single new commit is pushed to
-    a branch, combine the summary and commit email messages into a
-    single email.
-    Default: true
-
-multimailhook.refFilterInclusionRegex, multimailhook.refFilterExclusionRegex, multimailhook.refFilterDoSendRegex, multimailhook.refFilterDontSendRegex
-    **Warning:** these options are experimental. They should work, but
-    the user-interface is not stable yet (in particular, the option
-    names may change). If you want to participate in stabilizing the
-    feature, please contact the maintainers and/or send pull-requests.
-    If you are happy with the current shape of the feature, please
-    report it too.
-
-    Regular expressions that can be used to limit refs for which email
-    updates will be sent.  It is an error to specify both an inclusion
-    and an exclusion regex.  If a ``refFilterInclusionRegex`` is
-    specified, emails will only be sent for refs which match this
-    regex.  If a ``refFilterExclusionRegex`` regex is specified,
-    emails will be sent for all refs except those that match this
-    regex (or that match a predefined regex specific to the
-    environment, such as "^refs/notes" for most environments and
-    "^refs/notes|^refs/changes" for the gerrit environment).
-
-    The expressions are matched against the complete refname, and is
-    considered to match if any substring matches. For example, to
-    filter-out all tags, set ``refFilterExclusionRegex`` to
-    ``^refs/tags/`` (note the leading ``^`` but no trailing ``$``). If
-    you set ``refFilterExclusionRegex`` to ``master``, then any ref
-    containing ``master`` will be excluded (the ``master`` branch, but
-    also ``refs/tags/master`` or ``refs/heads/foo-master-bar``).
-
-    ``refFilterDoSendRegex`` and ``refFilterDontSendRegex`` are
-    analogous to ``refFilterInclusionRegex`` and
-    ``refFilterExclusionRegex`` with one difference: with
-    ``refFilterDoSendRegex`` and ``refFilterDontSendRegex``, commits
-    introduced by one excluded ref will not be considered as new when
-    they reach an included ref. Typically, if you add a branch ``foo``
-    to  ``refFilterDontSendRegex``, push commits to this branch, and
-    later merge branch ``foo`` into ``master``, then the notification
-    email for ``master`` will contain a commit email only for the
-    merge commit. If you include ``foo`` in
-    ``refFilterExclusionRegex``, then at the time of merge, you will
-    receive one commit email per commit in the branch.
-
-    These variables can be multi-valued, like::
-
-      [multimailhook]
-              refFilterExclusionRegex = ^refs/tags/
-              refFilterExclusionRegex = ^refs/heads/master$
-
-    You can also provide a whitespace-separated list like::
-
-      [multimailhook]
-              refFilterExclusionRegex = ^refs/tags/ ^refs/heads/master$
-
-    Both examples exclude tags and the master branch, and are
-    equivalent to::
-
-      [multimailhook]
-              refFilterExclusionRegex = ^refs/tags/|^refs/heads/master$
-
-    ``refFilterInclusionRegex`` and ``refFilterExclusionRegex`` are
-    strictly stronger than ``refFilterDoSendRegex`` and
-    ``refFilterDontSendRegex``. In other words, adding a ref to a
-    DoSend/DontSend regex has no effect if it is already excluded by a
-    Exclusion/Inclusion regex.
-
-multimailhook.logFile, multimailhook.errorLogFile, multimailhook.debugLogFile
-
-    When set, these variable designate path to files where
-    git-multimail will log some messages. Normal messages and error
-    messages are sent to ``logFile``, and error messages are also sent
-    to ``errorLogFile``. Debug messages and all other messages are
-    sent to ``debugLogFile``. The recommended way is to set only one
-    of these variables, but it is also possible to set several of them
-    (part of the information is then duplicated in several log files,
-    for example errors are duplicated to all log files).
-
-    Relative path are relative to the Git repository where the push is
-    done.
-
-multimailhook.verbose
-
-    Verbosity level of git-multimail on its standard output. By
-    default, show only error and info messages. If set to true, show
-    also debug messages.
-
-Email filtering aids
---------------------
-
-All emails include extra headers to enable fine tuned filtering and
-give information for debugging.  All emails include the headers
-``X-Git-Host``, ``X-Git-Repo``, ``X-Git-Refname``, and ``X-Git-Reftype``.
-ReferenceChange emails also include headers ``X-Git-Oldrev`` and ``X-Git-Newrev``;
-Revision emails also include header ``X-Git-Rev``.
-
-
-Customizing email contents
---------------------------
-
-git-multimail mostly generates emails by expanding templates.  The
-templates can be customized.  To avoid the need to edit
-``git_multimail.py`` directly, the preferred way to change the templates
-is to write a separate Python script that imports ``git_multimail.py`` as
-a module, then replaces the templates in place.  See the provided
-post-receive script for an example of how this is done.
-
-
-Customizing git-multimail for your environment
-----------------------------------------------
-
-git-multimail is mostly customized via an "environment" that describes
-the local environment in which Git is running.  Two types of
-environment are built in:
-
-GenericEnvironment
-    a stand-alone Git repository.
-
-GitoliteEnvironment
-    a Git repository that is managed by gitolite_.  For such
-    repositories, the identity of the pusher is read from
-    environment variable $GL_USER, the name of the repository is read
-    from $GL_REPO (if it is not overridden by multimailhook.reponame),
-    and the From: header value is optionally read from gitolite.conf
-    (see multimailhook.from).
-
-By default, git-multimail assumes GitoliteEnvironment if $GL_USER and
-$GL_REPO are set, and otherwise assumes GenericEnvironment.
-Alternatively, you can choose one of these two environments explicitly
-by setting a ``multimailhook.environment`` config setting (which can
-have the value `generic` or `gitolite`) or by passing an --environment
-option to the script.
-
-If you need to customize the script in ways that are not supported by
-the existing environments, you can define your own environment class
-class using arbitrary Python code.  To do so, you need to import
-``git_multimail.py`` as a Python module, as demonstrated by the example
-post-receive script.  Then implement your environment class; it should
-usually inherit from one of the existing Environment classes and
-possibly one or more of the EnvironmentMixin classes.  Then set the
-``environment`` variable to an instance of your own environment class
-and pass it to ``run_as_post_receive_hook()``.
-
-The standard environment classes, GenericEnvironment and
-GitoliteEnvironment, are in fact themselves put together out of a
-number of mixin classes, each of which handles one aspect of the
-customization.  For the finest control over your configuration, you
-can specify exactly which mixin classes your own environment class
-should inherit from, and override individual methods (or even add your
-own mixin classes) to implement entirely new behaviors.  If you
-implement any mixins that might be useful to other people, please
-consider sharing them with the community!
-
-
-Getting involved
-----------------
-
-Please, read `<CONTRIBUTING.rst>`__ for instructions on how to
-contribute to git-multimail.
-
-
-Footnotes
----------
-
-.. [1] Because of the way information is passed to update hooks, the
-       script's method of determining whether a commit has already
-       been seen does not work when it is used as an ``update`` script.
-       In particular, no notification email will be generated for a
-       new commit that is added to multiple references in the same
-       push. A workaround is to use --force-send to force sending the
-       emails.
-
-.. _gitolite: https://github.com/sitaramc/gitolite
diff -pruN 1.2.1+git2.18.0-1/git/contrib/hooks/multimail/README.Git 1.2.3+git2.25.1-1/git/contrib/hooks/multimail/README.Git
--- 1.2.1+git2.18.0-1/git/contrib/hooks/multimail/README.Git	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/contrib/hooks/multimail/README.Git	2020-02-17 04:47:35.000000000 +0000
@@ -6,10 +6,10 @@ website:
     https://github.com/git-multimail/git-multimail
 
 The version in this directory was obtained from the upstream project
-on August 17 2016 and consists of the "git-multimail" subdirectory from
+on January 07 2019 and consists of the "git-multimail" subdirectory from
 revision
 
-    07b1cb6bfd7be156c62e1afa17cae13b850a869f refs/tags/1.4.0
+    04e80e6c40be465cc62b6c246f0fcb8fd2cfd454 refs/tags/1.5.0
 
 Please see the README file in this directory for information about how
 to report bugs or contribute to git-multimail.
diff -pruN 1.2.1+git2.18.0-1/git/contrib/hooks/multimail/README.rst 1.2.3+git2.25.1-1/git/contrib/hooks/multimail/README.rst
--- 1.2.1+git2.18.0-1/git/contrib/hooks/multimail/README.rst	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/contrib/hooks/multimail/README.rst	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,774 @@
+git-multimail version 1.5.0
+===========================
+
+.. image:: https://travis-ci.org/git-multimail/git-multimail.svg?branch=master
+    :target: https://travis-ci.org/git-multimail/git-multimail
+
+git-multimail is a tool for sending notification emails on pushes to a
+Git repository.  It includes a Python module called ``git_multimail.py``,
+which can either be used as a hook script directly or can be imported
+as a Python module into another script.
+
+git-multimail is derived from the Git project's old
+contrib/hooks/post-receive-email, and is mostly compatible with that
+script.  See README.migrate-from-post-receive-email for details about
+the differences and for how to migrate from post-receive-email to
+git-multimail.
+
+git-multimail, like the rest of the Git project, is licensed under
+GPLv2 (see the COPYING file for details).
+
+Please note: although, as a convenience, git-multimail may be
+distributed along with the main Git project, development of
+git-multimail takes place in its own, separate project.  Please, read
+`<CONTRIBUTING.rst>`__ for more information.
+
+
+By default, for each push received by the repository, git-multimail:
+
+1. Outputs one email summarizing each reference that was changed.
+   These "reference change" (called "refchange" below) emails describe
+   the nature of the change (e.g., was the reference created, deleted,
+   fast-forwarded, etc.) and include a one-line summary of each commit
+   that was added to the reference.
+
+2. Outputs one email for each new commit that was introduced by the
+   reference change.  These "commit" emails include a list of the
+   files changed by the commit, followed by the diffs of files
+   modified by the commit.  The commit emails are threaded to the
+   corresponding reference change email via "In-Reply-To".  This style
+   (similar to the "git format-patch" style used on the Git mailing
+   list) makes it easy to scan through the emails, jump to patches
+   that need further attention, and write comments about specific
+   commits.  Commits are handled in reverse topological order (i.e.,
+   parents shown before children).  For example::
+
+     [git] branch master updated
+     + [git] 01/08: doc: fix xref link from api docs to manual pages
+     + [git] 02/08: api-credentials.txt: show the big picture first
+     + [git] 03/08: api-credentials.txt: mention credential.helper explicitly
+     + [git] 04/08: api-credentials.txt: add "see also" section
+     + [git] 05/08: t3510 (cherry-pick-sequence): add missing '&&'
+     + [git] 06/08: Merge branch 'rr/maint-t3510-cascade-fix'
+     + [git] 07/08: Merge branch 'mm/api-credentials-doc'
+     + [git] 08/08: Git 1.7.11-rc2
+
+   By default, each commit appears in exactly one commit email, the
+   first time that it is pushed to the repository.  If a commit is later
+   merged into another branch, then a one-line summary of the commit
+   is included in the reference change email (as usual), but no
+   additional commit email is generated. See
+   `multimailhook.refFilter(Inclusion|Exclusion|DoSend|DontSend)Regex`
+   below to configure which branches and tags are watched by the hook.
+
+   By default, reference change emails have their "Reply-To" field set
+   to the person who pushed the change, and commit emails have their
+   "Reply-To" field set to the author of the commit.
+
+3. Output one "announce" mail for each new annotated tag, including
+   information about the tag and optionally a shortlog describing the
+   changes since the previous tag.  Such emails might be useful if you
+   use annotated tags to mark releases of your project.
+
+
+Requirements
+------------
+
+* Python 2.x, version 2.4 or later.  No non-standard Python modules
+  are required.  git-multimail has preliminary support for Python 3
+  (but it has been better tested with Python 2).
+
+* The ``git`` command must be in your PATH.  git-multimail is known to
+  work with Git versions back to 1.7.1.  (Earlier versions have not
+  been tested; if you do so, please report your results.)
+
+* To send emails using the default configuration, a standard sendmail
+  program must be located at '/usr/sbin/sendmail' or
+  '/usr/lib/sendmail' and must be configured correctly to send emails.
+  If this is not the case, set multimailhook.sendmailCommand, or see
+  the multimailhook.mailer configuration variable below for how to
+  configure git-multimail to send emails via an SMTP server.
+
+* git-multimail is currently tested only on Linux. It may or may not
+  work on other platforms such as Windows and Mac OS. See
+  `<CONTRIBUTING.rst>`__ to improve the situation.
+
+
+Invocation
+----------
+
+``git_multimail.py`` is designed to be used as a ``post-receive`` hook in a
+Git repository (see githooks(5)).  Link or copy it to
+$GIT_DIR/hooks/post-receive within the repository for which email
+notifications are desired.  Usually it should be installed on the
+central repository for a project, to which all commits are eventually
+pushed.
+
+For use on pre-v1.5.1 Git servers, ``git_multimail.py`` can also work as
+an ``update`` hook, taking its arguments on the command line.  To use
+this script in this manner, link or copy it to $GIT_DIR/hooks/update.
+Please note that the script is not completely reliable in this mode
+[1]_.
+
+Alternatively, ``git_multimail.py`` can be imported as a Python module
+into your own Python post-receive script.  This method is a bit more
+work, but allows the behavior of the hook to be customized using
+arbitrary Python code.  For example, you can use a custom environment
+(perhaps inheriting from GenericEnvironment or GitoliteEnvironment) to
+
+* change how the user who did the push is determined
+
+* read users' email addresses from an LDAP server or from a database
+
+* decide which users should be notified about which commits based on
+  the contents of the commits (e.g., for users who want to be notified
+  only about changes affecting particular files or subdirectories)
+
+Or you can change how emails are sent by writing your own Mailer
+class.  The ``post-receive`` script in this directory demonstrates how
+to use ``git_multimail.py`` as a Python module.  (If you make interesting
+changes of this type, please consider sharing them with the
+community.)
+
+
+Troubleshooting/FAQ
+-------------------
+
+Please read `<doc/troubleshooting.rst>`__ for frequently asked
+questions and common issues with git-multimail.
+
+
+Configuration
+-------------
+
+By default, git-multimail mostly takes its configuration from the
+following ``git config`` settings:
+
+multimailhook.environment
+    This describes the general environment of the repository. In most
+    cases, you do not need to specify a value for this variable:
+    `git-multimail` will autodetect which environment to use.
+    Currently supported values:
+
+    generic
+      the username of the pusher is read from $USER or $USERNAME and
+      the repository name is derived from the repository's path.
+
+    gitolite
+      Environment to use when ``git-multimail`` is ran as a gitolite_
+      hook.
+
+      The username of the pusher is read from $GL_USER, the repository
+      name is read from $GL_REPO, and the From: header value is
+      optionally read from gitolite.conf (see multimailhook.from).
+
+      For more information about gitolite and git-multimail, read
+      `<doc/gitolite.rst>`__
+
+    stash
+      Environment to use when ``git-multimail`` is ran as an Atlassian
+      BitBucket Server (formerly known as Atlassian Stash) hook.
+
+      **Warning:** this mode was provided by a third-party contributor
+      and never tested by the git-multimail maintainers. It is
+      provided as-is and may or may not work for you.
+
+      This value is automatically assumed when the stash-specific
+      flags (``--stash-user`` and ``--stash-repo``) are specified on
+      the command line. When this environment is active, the username
+      and repo come from these two command line flags, which must be
+      specified.
+
+    gerrit
+      Environment to use when ``git-multimail`` is ran as a
+      ``ref-updated`` Gerrit hook.
+
+      This value is used when the gerrit-specific command line flags
+      (``--oldrev``, ``--newrev``, ``--refname``, ``--project``) for
+      gerrit's ref-updated hook are present. When this environment is
+      active, the username of the pusher is taken from the
+      ``--submitter`` argument if that command line option is passed,
+      otherwise 'Gerrit' is used. The repository name is taken from
+      the ``--project`` option on the command line, which must be passed.
+
+      For more information about gerrit and git-multimail, read
+      `<doc/gerrit.rst>`__
+
+    If none of these environments is suitable for your setup, then you
+    can implement a Python class that inherits from Environment and
+    instantiate it via a script that looks like the example
+    post-receive script.
+
+    The environment value can be specified on the command line using
+    the ``--environment`` option. If it is not specified on the
+    command line or by ``multimailhook.environment``, the value is
+    guessed as follows:
+
+    * If stash-specific (respectively gerrit-specific) command flags
+      are present on the command-line, then ``stash`` (respectively
+      ``gerrit``) is used.
+
+    * If the environment variables $GL_USER and $GL_REPO are set, then
+      ``gitolite`` is used.
+
+    * If none of the above apply, then ``generic`` is used.
+
+multimailhook.repoName
+    A short name of this Git repository, to be used in various places
+    in the notification email text.  The default is to use $GL_REPO
+    for gitolite repositories, or otherwise to derive this value from
+    the repository path name.
+
+multimailhook.mailingList
+    The list of email addresses to which notification emails should be
+    sent, as RFC 2822 email addresses separated by commas.  This
+    configuration option can be multivalued.  Leave it unset or set it
+    to the empty string to not send emails by default.  The next few
+    settings can be used to configure specific address lists for
+    specific types of notification email.
+
+multimailhook.refchangeList
+    The list of email addresses to which summary emails about
+    reference changes should be sent, as RFC 2822 email addresses
+    separated by commas.  This configuration option can be
+    multivalued.  The default is the value in
+    multimailhook.mailingList.  Set this value to "none" (or the empty
+    string) to prevent reference change emails from being sent even if
+    multimailhook.mailingList is set.
+
+multimailhook.announceList
+    The list of email addresses to which emails about new annotated
+    tags should be sent, as RFC 2822 email addresses separated by
+    commas.  This configuration option can be multivalued.  The
+    default is the value in multimailhook.refchangeList or
+    multimailhook.mailingList.  Set this value to "none" (or the empty
+    string) to prevent annotated tag announcement emails from being sent
+    even if one of the other values is set.
+
+multimailhook.commitList
+    The list of email addresses to which emails about individual new
+    commits should be sent, as RFC 2822 email addresses separated by
+    commas.  This configuration option can be multivalued.  The
+    default is the value in multimailhook.mailingList.  Set this value
+    to "none" (or the empty string) to prevent notification emails about
+    individual commits from being sent even if
+    multimailhook.mailingList is set.
+
+multimailhook.announceShortlog
+    If this option is set to true, then emails about changes to
+    annotated tags include a shortlog of changes since the previous
+    tag.  This can be useful if the annotated tags represent releases;
+    then the shortlog will be a kind of rough summary of what has
+    happened since the last release.  But if your tagging policy is
+    not so straightforward, then the shortlog might be confusing
+    rather than useful.  Default is false.
+
+multimailhook.commitEmailFormat
+    The format of email messages for the individual commits, can be "text" or
+    "html". In the latter case, the emails will include diffs using colorized
+    HTML instead of plain text used by default. Note that this  currently the
+    ref change emails are always sent in plain text.
+
+    Note that when using "html", the formatting is done by parsing the
+    output of ``git log`` with ``-p``. When using
+    ``multimailhook.commitLogOpts`` to specify a ``--format`` for
+    ``git log``, one may get false positive (e.g. lines in the body of
+    the message starting with ``+++`` or ``---`` colored in red or
+    green).
+
+    By default, all the message is HTML-escaped. See
+    ``multimailhook.htmlInIntro`` to change this behavior.
+
+multimailhook.commitBrowseURL
+    Used to generate a link to an online repository browser in commit
+    emails. This variable must be a string. Format directives like
+    ``%(<variable>)s`` will be expanded the same way as template
+    strings. In particular, ``%(id)s`` will be replaced by the full
+    Git commit identifier (40-chars hexadecimal).
+
+    If the string does not contain any format directive, then
+    ``%(id)s`` will be automatically added to the string. If you don't
+    want ``%(id)s`` to be automatically added, use the empty format
+    directive ``%()s`` anywhere in the string.
+
+    For example, a suitable value for the git-multimail project itself
+    would be
+    ``https://github.com/git-multimail/git-multimail/commit/%(id)s``.
+
+multimailhook.htmlInIntro, multimailhook.htmlInFooter
+    When generating an HTML message, git-multimail escapes any HTML
+    sequence by default. This means that if a template contains HTML
+    like ``<a href="foo">link</a>``, the reader will see the HTML
+    source code and not a proper link.
+
+    Set ``multimailhook.htmlInIntro`` to true to allow writing HTML
+    formatting in introduction templates. Similarly, set
+    ``multimailhook.htmlInFooter`` for HTML in the footer.
+
+    Variables expanded in the template are still escaped. For example,
+    if a repository's path contains a ``<``, it will be rendered as
+    such in the message.
+
+    Read `<doc/customizing-emails.rst>`__ for more details and
+    examples.
+
+multimailhook.refchangeShowGraph
+    If this option is set to true, then summary emails about reference
+    changes will additionally include:
+
+    * a graph of the added commits (if any)
+
+    * a graph of the discarded commits (if any)
+
+    The log is generated by running ``git log --graph`` with the options
+    specified in graphOpts.  The default is false.
+
+multimailhook.refchangeShowLog
+    If this option is set to true, then summary emails about reference
+    changes will include a detailed log of the added commits in
+    addition to the one line summary.  The log is generated by running
+    ``git log`` with the options specified in multimailhook.logOpts.
+    Default is false.
+
+multimailhook.mailer
+    This option changes the way emails are sent.  Accepted values are:
+
+    * **sendmail (the default)**: use the command ``/usr/sbin/sendmail`` or
+      ``/usr/lib/sendmail`` (or sendmailCommand, if configured).  This
+      mode can be further customized via the following options:
+
+      multimailhook.sendmailCommand
+          The command used by mailer ``sendmail`` to send emails.  Shell
+          quoting is allowed in the value of this setting, but remember that
+          Git requires double-quotes to be escaped; e.g.::
+
+              git config multimailhook.sendmailcommand '/usr/sbin/sendmail -oi -t -F \"Git Repo\"'
+
+          Default is '/usr/sbin/sendmail -oi -t' or
+          '/usr/lib/sendmail -oi -t' (depending on which file is
+          present and executable).
+
+      multimailhook.envelopeSender
+          If set then pass this value to sendmail via the -f option to set
+          the envelope sender address.
+
+    * **smtp**: use Python's smtplib.  This is useful when the sendmail
+      command is not available on the system.  This mode can be
+      further customized via the following options:
+
+      multimailhook.smtpServer
+          The name of the SMTP server to connect to.  The value can
+          also include a colon and a port number; e.g.,
+          ``mail.example.com:25``.  Default is 'localhost' using port 25.
+
+      multimailhook.smtpUser, multimailhook.smtpPass
+          Server username and password. Required if smtpEncryption is 'ssl'.
+          Note that the username and password currently need to be
+          set cleartext in the configuration file, which is not
+          recommended. If you need to use this option, be sure your
+          configuration file is read-only.
+
+      multimailhook.envelopeSender
+        The sender address to be passed to the SMTP server.  If
+        unset, then the value of multimailhook.from is used.
+
+      multimailhook.smtpServerTimeout
+        Timeout in seconds. Default is 10.
+
+      multimailhook.smtpEncryption
+        Set the security type. Allowed values: ``none``, ``ssl``, ``tls`` (starttls).
+        Default is ``none``.
+
+      multimailhook.smtpCACerts
+        Set the path to a list of trusted CA certificate to verify the
+        server certificate, only supported when ``smtpEncryption`` is
+        ``tls``. If unset or empty, the server certificate is not
+        verified. If it targets a file containing a list of trusted CA
+        certificates (PEM format) these CAs will be used to verify the
+        server certificate. For debian, you can set
+        ``/etc/ssl/certs/ca-certificates.crt`` for using the system
+        trusted CAs. For self-signed server, you can add your server
+        certificate to the system store::
+
+            cd /usr/local/share/ca-certificates/
+            openssl s_client -starttls smtp \
+                   -connect mail.example.net:587 -showcerts \
+                   </dev/null 2>/dev/null \
+                 | openssl x509 -outform PEM >mail.example.net.crt
+            update-ca-certificates
+
+        and used the updated ``/etc/ssl/certs/ca-certificates.crt``. Or
+        directly use your ``/path/to/mail.example.net.crt``. Default is
+        unset.
+
+      multimailhook.smtpServerDebugLevel
+        Integer number. Set to greater than 0 to activate debugging.
+
+multimailhook.from, multimailhook.fromCommit, multimailhook.fromRefchange
+    If set, use this value in the From: field of generated emails.
+    ``fromCommit`` is used for commit emails, ``fromRefchange`` is
+    used for refchange emails, and ``from`` is used as fall-back in
+    all cases.
+
+    The value for these variables can be either:
+
+    - An email address, which will be used directly.
+
+    - The value ``pusher``, in which case the pusher's address (if
+      available) will be used.
+
+    - The value ``author`` (meaningful only for ``fromCommit``), in which
+      case the commit author's address will be used.
+
+    If config values are unset, the value of the From: header is
+    determined as follows:
+
+    1. (gitolite environment only)
+       1.a) If ``multimailhook.MailaddressMap`` is set, and is a path
+       to an existing file (if relative, it is considered relative to
+       the place where ``gitolite.conf`` is located), then this file
+       should contain lines like::
+
+           username Firstname Lastname <email@example.com>
+
+       git-multimail will then look for a line where ``$GL_USER``
+       matches the ``username`` part, and use the rest of the line for
+       the ``From:`` header.
+
+       1.b) Parse gitolite.conf, looking for a block of comments that
+       looks like this::
+
+           # BEGIN USER EMAILS
+           # username Firstname Lastname <email@example.com>
+           # END USER EMAILS
+
+       If that block exists, and there is a line between the BEGIN
+       USER EMAILS and END USER EMAILS lines where the first field
+       matches the gitolite username ($GL_USER), use the rest of the
+       line for the From: header.
+
+    2. If the user.email configuration setting is set, use its value
+       (and the value of user.name, if set).
+
+    3. Use the value of multimailhook.envelopeSender.
+
+multimailhook.MailaddressMap
+    (gitolite environment only)
+    File to look for a ``From:`` address based on the user doing the
+    push. Defaults to unset. See ``multimailhook.from`` for details.
+
+multimailhook.administrator
+    The name and/or email address of the administrator of the Git
+    repository; used in FOOTER_TEMPLATE.  Default is
+    multimailhook.envelopesender if it is set; otherwise a generic
+    string is used.
+
+multimailhook.emailPrefix
+    All emails have this string prepended to their subjects, to aid
+    email filtering (though filtering based on the X-Git-* email
+    headers is probably more robust).  Default is the short name of
+    the repository in square brackets; e.g., ``[myrepo]``.  Set this
+    value to the empty string to suppress the email prefix. You may
+    use the placeholder ``%(repo_shortname)s`` for the short name of
+    the repository.
+
+multimailhook.emailMaxLines
+    The maximum number of lines that should be included in the body of
+    a generated email.  If not specified, there is no limit.  Lines
+    beyond the limit are suppressed and counted, and a final line is
+    added indicating the number of suppressed lines.
+
+multimailhook.emailMaxLineLength
+    The maximum length of a line in the email body.  Lines longer than
+    this limit are truncated to this length with a trailing ``[...]``
+    added to indicate the missing text.  The default is 500, because
+    (a) diffs with longer lines are probably from binary files, for
+    which a diff is useless, and (b) even if a text file has such long
+    lines, the diffs are probably unreadable anyway.  To disable line
+    truncation, set this option to 0.
+
+multimailhook.subjectMaxLength
+    The maximum length of the subject line (i.e. the ``oneline`` field
+    in templates, not including the prefix). Lines longer than this
+    limit are truncated to this length with a trailing ``[...]`` added
+    to indicate the missing text. This option The default is to use
+    ``multimailhook.emailMaxLineLength``. This option avoids sending
+    emails with overly long subject lines, but should not be needed if
+    the commit messages follow the Git convention (one short subject
+    line, then a blank line, then the message body). To disable line
+    truncation, set this option to 0.
+
+multimailhook.maxCommitEmails
+    The maximum number of commit emails to send for a given change.
+    When the number of patches is larger that this value, only the
+    summary refchange email is sent.  This can avoid accidental
+    mailbombing, for example on an initial push.  To disable commit
+    emails limit, set this option to 0.  The default is 500.
+
+multimailhook.excludeMergeRevisions
+    When sending out revision emails, do not consider merge commits (the
+    functional equivalent of `rev-list --no-merges`).
+    The default is `false` (send merge commit emails).
+
+multimailhook.emailStrictUTF8
+    If this boolean option is set to `true`, then the main part of the
+    email body is forced to be valid UTF-8.  Any characters that are
+    not valid UTF-8 are converted to the Unicode replacement
+    character, U+FFFD.  The default is `true`.
+
+    This option is ineffective with Python 3, where non-UTF-8
+    characters are unconditionally replaced.
+
+multimailhook.diffOpts
+    Options passed to ``git diff-tree`` when generating the summary
+    information for ReferenceChange emails.  Default is ``--stat
+    --summary --find-copies-harder``.  Add -p to those options to
+    include a unified diff of changes in addition to the usual summary
+    output.  Shell quoting is allowed; see ``multimailhook.logOpts`` for
+    details.
+
+multimailhook.graphOpts
+    Options passed to ``git log --graph`` when generating graphs for the
+    reference change summary emails (used only if refchangeShowGraph
+    is true).  The default is '--oneline --decorate'.
+
+    Shell quoting is allowed; see logOpts for details.
+
+multimailhook.logOpts
+    Options passed to ``git log`` to generate additional info for
+    reference change emails (used only if refchangeShowLog is set).
+    For example, adding -p will show each commit's complete diff.  The
+    default is empty.
+
+    Shell quoting is allowed; for example, a log format that contains
+    spaces can be specified using something like::
+
+      git config multimailhook.logopts '--pretty=format:"%h %aN <%aE>%n%s%n%n%b%n"'
+
+    If you want to set this by editing your configuration file
+    directly, remember that Git requires double-quotes to be escaped
+    (see git-config(1) for more information)::
+
+      [multimailhook]
+              logopts = --pretty=format:\"%h %aN <%aE>%n%s%n%n%b%n\"
+
+multimailhook.commitLogOpts
+    Options passed to ``git log`` to generate additional info for
+    revision change emails.  For example, adding --ignore-all-spaces
+    will suppress whitespace changes.  The default options are ``-C
+    --stat -p --cc``.  Shell quoting is allowed; see
+    multimailhook.logOpts for details.
+
+multimailhook.dateSubstitute
+    String to use as a substitute for ``Date:`` in the output of ``git
+    log`` while formatting commit messages. This is useful to avoid
+    emitting a line that can be interpreted by mailers as the start of
+    a cited message (Zimbra webmail in particular). Defaults to
+    ``CommitDate:``. Set to an empty string or ``none`` to deactivate
+    the behavior.
+
+multimailhook.emailDomain
+    Domain name appended to the username of the person doing the push
+    to convert it into an email address
+    (via ``"%s@%s" % (username, emaildomain)``). More complicated
+    schemes can be implemented by overriding Environment and
+    overriding its get_pusher_email() method.
+
+multimailhook.replyTo, multimailhook.replyToCommit, multimailhook.replyToRefchange
+    Addresses to use in the Reply-To: field for commit emails
+    (replyToCommit) and refchange emails (replyToRefchange).
+    multimailhook.replyTo is used as default when replyToCommit or
+    replyToRefchange is not set. The shortcuts ``pusher`` and
+    ``author`` are allowed with the same semantics as for
+    ``multimailhook.from``. In addition, the value ``none`` can be
+    used to omit the ``Reply-To:`` field.
+
+    The default is ``pusher`` for refchange emails, and ``author`` for
+    commit emails.
+
+multimailhook.quiet
+    Do not output the list of email recipients from the hook
+
+multimailhook.stdout
+    For debugging, send emails to stdout rather than to the
+    mailer.  Equivalent to the --stdout command line option
+
+multimailhook.scanCommitForCc
+    If this option is set to true, than recipients from lines in commit body
+    that starts with ``CC:`` will be added to CC list.
+    Default: false
+
+multimailhook.combineWhenSingleCommit
+    If this option is set to true and a single new commit is pushed to
+    a branch, combine the summary and commit email messages into a
+    single email.
+    Default: true
+
+multimailhook.refFilterInclusionRegex, multimailhook.refFilterExclusionRegex, multimailhook.refFilterDoSendRegex, multimailhook.refFilterDontSendRegex
+    **Warning:** these options are experimental. They should work, but
+    the user-interface is not stable yet (in particular, the option
+    names may change). If you want to participate in stabilizing the
+    feature, please contact the maintainers and/or send pull-requests.
+    If you are happy with the current shape of the feature, please
+    report it too.
+
+    Regular expressions that can be used to limit refs for which email
+    updates will be sent.  It is an error to specify both an inclusion
+    and an exclusion regex.  If a ``refFilterInclusionRegex`` is
+    specified, emails will only be sent for refs which match this
+    regex.  If a ``refFilterExclusionRegex`` regex is specified,
+    emails will be sent for all refs except those that match this
+    regex (or that match a predefined regex specific to the
+    environment, such as "^refs/notes" for most environments and
+    "^refs/notes|^refs/changes" for the gerrit environment).
+
+    The expressions are matched against the complete refname, and is
+    considered to match if any substring matches. For example, to
+    filter-out all tags, set ``refFilterExclusionRegex`` to
+    ``^refs/tags/`` (note the leading ``^`` but no trailing ``$``). If
+    you set ``refFilterExclusionRegex`` to ``master``, then any ref
+    containing ``master`` will be excluded (the ``master`` branch, but
+    also ``refs/tags/master`` or ``refs/heads/foo-master-bar``).
+
+    ``refFilterDoSendRegex`` and ``refFilterDontSendRegex`` are
+    analogous to ``refFilterInclusionRegex`` and
+    ``refFilterExclusionRegex`` with one difference: with
+    ``refFilterDoSendRegex`` and ``refFilterDontSendRegex``, commits
+    introduced by one excluded ref will not be considered as new when
+    they reach an included ref. Typically, if you add a branch ``foo``
+    to  ``refFilterDontSendRegex``, push commits to this branch, and
+    later merge branch ``foo`` into ``master``, then the notification
+    email for ``master`` will contain a commit email only for the
+    merge commit. If you include ``foo`` in
+    ``refFilterExclusionRegex``, then at the time of merge, you will
+    receive one commit email per commit in the branch.
+
+    These variables can be multi-valued, like::
+
+      [multimailhook]
+              refFilterExclusionRegex = ^refs/tags/
+              refFilterExclusionRegex = ^refs/heads/master$
+
+    You can also provide a whitespace-separated list like::
+
+      [multimailhook]
+              refFilterExclusionRegex = ^refs/tags/ ^refs/heads/master$
+
+    Both examples exclude tags and the master branch, and are
+    equivalent to::
+
+      [multimailhook]
+              refFilterExclusionRegex = ^refs/tags/|^refs/heads/master$
+
+    ``refFilterInclusionRegex`` and ``refFilterExclusionRegex`` are
+    strictly stronger than ``refFilterDoSendRegex`` and
+    ``refFilterDontSendRegex``. In other words, adding a ref to a
+    DoSend/DontSend regex has no effect if it is already excluded by a
+    Exclusion/Inclusion regex.
+
+multimailhook.logFile, multimailhook.errorLogFile, multimailhook.debugLogFile
+
+    When set, these variable designate path to files where
+    git-multimail will log some messages. Normal messages and error
+    messages are sent to ``logFile``, and error messages are also sent
+    to ``errorLogFile``. Debug messages and all other messages are
+    sent to ``debugLogFile``. The recommended way is to set only one
+    of these variables, but it is also possible to set several of them
+    (part of the information is then duplicated in several log files,
+    for example errors are duplicated to all log files).
+
+    Relative path are relative to the Git repository where the push is
+    done.
+
+multimailhook.verbose
+
+    Verbosity level of git-multimail on its standard output. By
+    default, show only error and info messages. If set to true, show
+    also debug messages.
+
+Email filtering aids
+--------------------
+
+All emails include extra headers to enable fine tuned filtering and
+give information for debugging.  All emails include the headers
+``X-Git-Host``, ``X-Git-Repo``, ``X-Git-Refname``, and ``X-Git-Reftype``.
+ReferenceChange emails also include headers ``X-Git-Oldrev`` and ``X-Git-Newrev``;
+Revision emails also include header ``X-Git-Rev``.
+
+
+Customizing email contents
+--------------------------
+
+git-multimail mostly generates emails by expanding templates.  The
+templates can be customized.  To avoid the need to edit
+``git_multimail.py`` directly, the preferred way to change the templates
+is to write a separate Python script that imports ``git_multimail.py`` as
+a module, then replaces the templates in place.  See the provided
+post-receive script for an example of how this is done.
+
+
+Customizing git-multimail for your environment
+----------------------------------------------
+
+git-multimail is mostly customized via an "environment" that describes
+the local environment in which Git is running.  Two types of
+environment are built in:
+
+GenericEnvironment
+    a stand-alone Git repository.
+
+GitoliteEnvironment
+    a Git repository that is managed by gitolite_.  For such
+    repositories, the identity of the pusher is read from
+    environment variable $GL_USER, the name of the repository is read
+    from $GL_REPO (if it is not overridden by multimailhook.reponame),
+    and the From: header value is optionally read from gitolite.conf
+    (see multimailhook.from).
+
+By default, git-multimail assumes GitoliteEnvironment if $GL_USER and
+$GL_REPO are set, and otherwise assumes GenericEnvironment.
+Alternatively, you can choose one of these two environments explicitly
+by setting a ``multimailhook.environment`` config setting (which can
+have the value `generic` or `gitolite`) or by passing an --environment
+option to the script.
+
+If you need to customize the script in ways that are not supported by
+the existing environments, you can define your own environment class
+class using arbitrary Python code.  To do so, you need to import
+``git_multimail.py`` as a Python module, as demonstrated by the example
+post-receive script.  Then implement your environment class; it should
+usually inherit from one of the existing Environment classes and
+possibly one or more of the EnvironmentMixin classes.  Then set the
+``environment`` variable to an instance of your own environment class
+and pass it to ``run_as_post_receive_hook()``.
+
+The standard environment classes, GenericEnvironment and
+GitoliteEnvironment, are in fact themselves put together out of a
+number of mixin classes, each of which handles one aspect of the
+customization.  For the finest control over your configuration, you
+can specify exactly which mixin classes your own environment class
+should inherit from, and override individual methods (or even add your
+own mixin classes) to implement entirely new behaviors.  If you
+implement any mixins that might be useful to other people, please
+consider sharing them with the community!
+
+
+Getting involved
+----------------
+
+Please, read `<CONTRIBUTING.rst>`__ for instructions on how to
+contribute to git-multimail.
+
+
+Footnotes
+---------
+
+.. [1] Because of the way information is passed to update hooks, the
+       script's method of determining whether a commit has already
+       been seen does not work when it is used as an ``update`` script.
+       In particular, no notification email will be generated for a
+       new commit that is added to multiple references in the same
+       push. A workaround is to use --force-send to force sending the
+       emails.
+
+.. _gitolite: https://github.com/sitaramc/gitolite
diff -pruN 1.2.1+git2.18.0-1/git/contrib/hooks/post-receive-email 1.2.3+git2.25.1-1/git/contrib/hooks/post-receive-email
--- 1.2.1+git2.18.0-1/git/contrib/hooks/post-receive-email	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/contrib/hooks/post-receive-email	2020-02-17 04:47:35.000000000 +0000
@@ -329,7 +329,7 @@ generate_update_branch_email()
 	#
 	#  git rev-parse --not --all | grep -v $(git rev-parse $refname)
 	#
-	# Get's us to something pretty safe (apart from the small time
+	# Gets us to something pretty safe (apart from the small time
 	# between refname being read, and git rev-parse running - for that,
 	# I give up)
 	#
diff -pruN 1.2.1+git2.18.0-1/git/contrib/hooks/update-paranoid 1.2.3+git2.25.1-1/git/contrib/hooks/update-paranoid
--- 1.2.1+git2.18.0-1/git/contrib/hooks/update-paranoid	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/contrib/hooks/update-paranoid	2020-02-17 04:47:35.000000000 +0000
@@ -49,7 +49,7 @@ opcode.
 Repository sections are matched on the basename of the repository
 (after removing the .git suffix).
 
-The opcode abbrevations are:
+The opcode abbreviations are:
 
   C: create new ref
   D: delete existing ref
diff -pruN 1.2.1+git2.18.0-1/git/contrib/mw-to-git/git-remote-mediawiki.perl 1.2.3+git2.25.1-1/git/contrib/mw-to-git/git-remote-mediawiki.perl
--- 1.2.1+git2.18.0-1/git/contrib/mw-to-git/git-remote-mediawiki.perl	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/contrib/mw-to-git/git-remote-mediawiki.perl	2020-02-17 04:47:35.000000000 +0000
@@ -79,7 +79,7 @@ chomp($export_media);
 $export_media = !($export_media eq 'false');
 
 my $wiki_login = run_git("config --get remote.${remotename}.mwLogin");
-# Note: mwPassword is discourraged. Use the credential system instead.
+# Note: mwPassword is discouraged. Use the credential system instead.
 my $wiki_passwd = run_git("config --get remote.${remotename}.mwPassword");
 my $wiki_domain = run_git("config --get remote.${remotename}.mwDomain");
 chomp($wiki_login);
diff -pruN 1.2.1+git2.18.0-1/git/contrib/mw-to-git/.perlcriticrc 1.2.3+git2.25.1-1/git/contrib/mw-to-git/.perlcriticrc
--- 1.2.1+git2.18.0-1/git/contrib/mw-to-git/.perlcriticrc	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/contrib/mw-to-git/.perlcriticrc	2020-02-17 04:47:35.000000000 +0000
@@ -14,7 +14,7 @@
 
 # This rule states that each system call should have its return value checked
 # The problem is that it includes the print call. Checking every print call's
-# return value would be harmful to the code readabilty.
+# return value would be harmful to the code readability.
 # This configuration keeps all default function but print.
 [InputOutput::RequireCheckedSyscalls]
 functions = open say close
diff -pruN 1.2.1+git2.18.0-1/git/contrib/mw-to-git/t/install-wiki/db_install.php 1.2.3+git2.25.1-1/git/contrib/mw-to-git/t/install-wiki/db_install.php
--- 1.2.1+git2.18.0-1/git/contrib/mw-to-git/t/install-wiki/db_install.php	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/contrib/mw-to-git/t/install-wiki/db_install.php	2020-02-17 04:47:35.000000000 +0000
@@ -24,7 +24,7 @@ $url = 'http://localhost:'.$port.'/wiki/
 $db_dir = urlencode($tmp);
 $tmp_cookie = tempnam($tmp, "COOKIE_");
 /*
- * Fetchs a page with cURL.
+ * Fetches a page with cURL.
  */
 function get($page_name = "") {
 	$curl = curl_init();
diff -pruN 1.2.1+git2.18.0-1/git/contrib/mw-to-git/t/t9360-mw-to-git-clone.sh 1.2.3+git2.25.1-1/git/contrib/mw-to-git/t/t9360-mw-to-git-clone.sh
--- 1.2.1+git2.18.0-1/git/contrib/mw-to-git/t/t9360-mw-to-git-clone.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/contrib/mw-to-git/t/t9360-mw-to-git-clone.sh	2020-02-17 04:47:35.000000000 +0000
@@ -143,7 +143,7 @@ test_expect_success 'Git clone works wit
 test_expect_success 'Git clone works with multiple specific page cloned ' '
 	wiki_reset &&
 	wiki_editpage foo "I will be there" false &&
-	wiki_editpage bar "I will not disapear" false &&
+	wiki_editpage bar "I will not disappear" false &&
 	wiki_editpage namnam "I be erased" false &&
 	wiki_editpage nyancat "nyan nyan nyan you will not erase me" false &&
 	wiki_delete_page namnam &&
@@ -247,7 +247,7 @@ test_expect_success 'Test of resistance
 	wiki_editpage Notconsidered "this page will not appear on local" false &&
 	wiki_editpage Othercategory "this page will not appear on local" false -c=Cattwo &&
 	wiki_editpage Tobeedited "this page have been modified" true -c=Catone &&
-	wiki_delete_page Tobedeleted
+	wiki_delete_page Tobedeleted &&
 	git clone -c remote.origin.categories="Catone" \
 		mediawiki::'"$WIKI_URL"' mw_dir_14 &&
 	wiki_getallpage ref_page_14 Catone &&
diff -pruN 1.2.1+git2.18.0-1/git/contrib/mw-to-git/t/test-gitmw-lib.sh 1.2.3+git2.25.1-1/git/contrib/mw-to-git/t/test-gitmw-lib.sh
--- 1.2.1+git2.18.0-1/git/contrib/mw-to-git/t/test-gitmw-lib.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/contrib/mw-to-git/t/test-gitmw-lib.sh	2020-02-17 04:47:35.000000000 +0000
@@ -279,7 +279,7 @@ start_lighttpd () {
 	"$LIGHTTPD_DIR"/lighttpd -f "$WEB"/lighttpd.conf
 
 	if test $? -ne 0 ; then
-		echo "Could not execute http deamon lighttpd"
+		echo "Could not execute http daemon lighttpd"
 		exit 1
 	fi
 }
diff -pruN 1.2.1+git2.18.0-1/git/contrib/subtree/git-subtree.sh 1.2.3+git2.25.1-1/git/contrib/subtree/git-subtree.sh
--- 1.2.1+git2.18.0-1/git/contrib/subtree/git-subtree.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/contrib/subtree/git-subtree.sh	2020-02-17 04:47:35.000000000 +0000
@@ -14,7 +14,7 @@ git subtree add   --prefix=<prefix> <rep
 git subtree merge --prefix=<prefix> <commit>
 git subtree pull  --prefix=<prefix> <repository> <ref>
 git subtree push  --prefix=<prefix> <repository> <ref>
-git subtree split --prefix=<prefix> <commit...>
+git subtree split --prefix=<prefix> <commit>
 --
 h,help        show the help
 q             quiet
@@ -77,6 +77,12 @@ assert () {
 	fi
 }
 
+ensure_single_rev () {
+	if test $# -ne 1
+	then
+		die "You must provide exactly one revision.  Got: '$@'"
+	fi
+}
 
 while test $# -gt 0
 do
@@ -185,6 +191,7 @@ if test "$command" != "pull" &&
 then
 	revs=$(git rev-parse $default --revs-only "$@") || exit $?
 	dirs=$(git rev-parse --no-revs --no-flags "$@") || exit $?
+	ensure_single_rev $revs
 	if test -n "$dirs"
 	then
 		die "Error: Use --prefix instead of bare filenames."
@@ -231,12 +238,14 @@ cache_miss () {
 }
 
 check_parents () {
-	missed=$(cache_miss "$@")
+	missed=$(cache_miss "$1")
+	local indent=$(($2 + 1))
 	for miss in $missed
 	do
 		if ! test -r "$cachedir/notree/$miss"
 		then
 			debug "  incorrect order: $miss"
+			process_split_commit "$miss" "" "$indent"
 		fi
 	done
 }
@@ -340,7 +349,12 @@ find_existing_splits () {
 	revs="$2"
 	main=
 	sub=
-	git log --grep="^git-subtree-dir: $dir/*\$" \
+	local grep_format="^git-subtree-dir: $dir/*\$"
+	if test -n "$ignore_joins"
+	then
+		grep_format="^Add '$dir/' from commit '"
+	fi
+	git log --grep="$grep_format" \
 		--no-show-signature --pretty=format:'START %H%n%s%n%n%b%nEND%n' $revs |
 	while read a b junk
 	do
@@ -534,6 +548,7 @@ copy_or_skip () {
 	nonidentical=
 	p=
 	gotparents=
+	copycommit=
 	for parent in $newparents
 	do
 		ptree=$(toptree_for_commit $parent) || exit $?
@@ -541,7 +556,24 @@ copy_or_skip () {
 		if test "$ptree" = "$tree"
 		then
 			# an identical parent could be used in place of this rev.
-			identical="$parent"
+			if test -n "$identical"
+			then
+				# if a previous identical parent was found, check whether
+				# one is already an ancestor of the other
+				mergebase=$(git merge-base $identical $parent)
+				if test "$identical" = "$mergebase"
+				then
+					# current identical commit is an ancestor of parent
+					identical="$parent"
+				elif test "$parent" != "$mergebase"
+				then
+					# no common history; commit must be copied
+					copycommit=1
+				fi
+			else
+				# first identical parent detected
+				identical="$parent"
+			fi
 		else
 			nonidentical="$parent"
 		fi
@@ -564,7 +596,6 @@ copy_or_skip () {
 		fi
 	done
 
-	copycommit=
 	if test -n "$identical" && test -n "$nonidentical"
 	then
 		extras=$(git rev-list --count $identical..$nonidentical)
@@ -598,6 +629,58 @@ ensure_valid_ref_format () {
 		die "'$1' does not look like a ref"
 }
 
+process_split_commit () {
+	local rev="$1"
+	local parents="$2"
+	local indent=$3
+
+	if test $indent -eq 0
+	then
+		revcount=$(($revcount + 1))
+	else
+		# processing commit without normal parent information;
+		# fetch from repo
+		parents=$(git rev-parse "$rev^@")
+		extracount=$(($extracount + 1))
+	fi
+
+	progress "$revcount/$revmax ($createcount) [$extracount]"
+
+	debug "Processing commit: $rev"
+	exists=$(cache_get "$rev")
+	if test -n "$exists"
+	then
+		debug "  prior: $exists"
+		return
+	fi
+	createcount=$(($createcount + 1))
+	debug "  parents: $parents"
+	check_parents "$parents" "$indent"
+	newparents=$(cache_get $parents)
+	debug "  newparents: $newparents"
+
+	tree=$(subtree_for_commit "$rev" "$dir")
+	debug "  tree is: $tree"
+
+	# ugly.  is there no better way to tell if this is a subtree
+	# vs. a mainline commit?  Does it matter?
+	if test -z "$tree"
+	then
+		set_notree "$rev"
+		if test -n "$newparents"
+		then
+			cache_set "$rev" "$rev"
+		fi
+		return
+	fi
+
+	newrev=$(copy_or_skip "$rev" "$tree" "$newparents") || exit $?
+	debug "  newrev is: $newrev"
+	cache_set "$rev" "$newrev"
+	cache_set latest_new "$newrev"
+	cache_set latest_old "$rev"
+}
+
 cmd_add () {
 	if test -e "$dir"
 	then
@@ -640,9 +723,8 @@ cmd_add_repository () {
 }
 
 cmd_add_commit () {
-	revs=$(git rev-parse $default --revs-only "$@") || exit $?
-	set -- $revs
-	rev="$1"
+	rev=$(git rev-parse $default --revs-only "$@") || exit $?
+	ensure_single_rev $rev
 
 	debug "Adding $dir as '$rev'..."
 	git read-tree --prefix="$dir" $rev || exit $?
@@ -689,12 +771,7 @@ cmd_split () {
 		done
 	fi
 
-	if test -n "$ignore_joins"
-	then
-		unrevs=
-	else
-		unrevs="$(find_existing_splits "$dir" "$revs")"
-	fi
+	unrevs="$(find_existing_splits "$dir" "$revs")"
 
 	# We can't restrict rev-list to only $dir here, because some of our
 	# parents have the $dir contents the root, and those won't match.
@@ -703,45 +780,11 @@ cmd_split () {
 	revmax=$(eval "$grl" | wc -l)
 	revcount=0
 	createcount=0
+	extracount=0
 	eval "$grl" |
 	while read rev parents
 	do
-		revcount=$(($revcount + 1))
-		progress "$revcount/$revmax ($createcount)"
-		debug "Processing commit: $rev"
-		exists=$(cache_get "$rev")
-		if test -n "$exists"
-		then
-			debug "  prior: $exists"
-			continue
-		fi
-		createcount=$(($createcount + 1))
-		debug "  parents: $parents"
-		newparents=$(cache_get $parents)
-		debug "  newparents: $newparents"
-
-		tree=$(subtree_for_commit "$rev" "$dir")
-		debug "  tree is: $tree"
-
-		check_parents $parents
-
-		# ugly.  is there no better way to tell if this is a subtree
-		# vs. a mainline commit?  Does it matter?
-		if test -z "$tree"
-		then
-			set_notree "$rev"
-			if test -n "$newparents"
-			then
-				cache_set "$rev" "$rev"
-			fi
-			continue
-		fi
-
-		newrev=$(copy_or_skip "$rev" "$tree" "$newparents") || exit $?
-		debug "  newrev is: $newrev"
-		cache_set "$rev" "$newrev"
-		cache_set latest_new "$newrev"
-		cache_set latest_old "$rev"
+		process_split_commit "$rev" "$parents" 0
 	done || exit $?
 
 	latest_new=$(cache_get latest_new)
@@ -780,16 +823,10 @@ cmd_split () {
 }
 
 cmd_merge () {
-	revs=$(git rev-parse $default --revs-only "$@") || exit $?
+	rev=$(git rev-parse $default --revs-only "$@") || exit $?
+	ensure_single_rev $rev
 	ensure_clean
 
-	set -- $revs
-	if test $# -ne 1
-	then
-		die "You must provide exactly one revision.  Got: '$revs'"
-	fi
-	rev="$1"
-
 	if test -n "$squash"
 	then
 		first_split="$(find_latest_squash "$dir")"
diff -pruN 1.2.1+git2.18.0-1/git/contrib/subtree/Makefile 1.2.3+git2.25.1-1/git/contrib/subtree/Makefile
--- 1.2.1+git2.18.0-1/git/contrib/subtree/Makefile	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/contrib/subtree/Makefile	2020-02-17 04:47:35.000000000 +0000
@@ -59,6 +59,10 @@ $(GIT_SUBTREE): $(GIT_SUBTREE_SH)
 
 doc: $(GIT_SUBTREE_DOC) $(GIT_SUBTREE_HTML)
 
+man: $(GIT_SUBTREE_DOC)
+
+html: $(GIT_SUBTREE_HTML)
+
 install: $(GIT_SUBTREE)
 	$(INSTALL) -d -m 755 $(DESTDIR)$(gitexecdir)
 	$(INSTALL) -m 755 $(GIT_SUBTREE) $(DESTDIR)$(gitexecdir)
diff -pruN 1.2.1+git2.18.0-1/git/contrib/subtree/t/t7900-subtree.sh 1.2.3+git2.25.1-1/git/contrib/subtree/t/t7900-subtree.sh
--- 1.2.1+git2.18.0-1/git/contrib/subtree/t/t7900-subtree.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/contrib/subtree/t/t7900-subtree.sh	2020-02-17 04:47:35.000000000 +0000
@@ -540,26 +540,10 @@ test_expect_success 'make sure exactly t
 		git fetch .. subproj-br &&
 		git merge FETCH_HEAD &&
 
-		chks="sub1
-sub2
-sub3
-sub4" &&
-		chks_sub=$(cat <<TXT | sed '\''s,^,sub dir/,'\''
-$chks
-TXT
-) &&
-		chkms="main-sub1
-main-sub2
-main-sub3
-main-sub4" &&
-		chkms_sub=$(cat <<TXT | sed '\''s,^,sub dir/,'\''
-$chkms
-TXT
-) &&
-
-		subfiles=$(git ls-files) &&
-		check_equal "$subfiles" "$chkms
-$chks"
+		test_write_lines main-sub1 main-sub2 main-sub3 main-sub4 \
+			sub1 sub2 sub3 sub4 >expect &&
+		git ls-files >actual &&
+		test_cmp expect actual
 	)
 '
 
@@ -606,25 +590,11 @@ test_expect_success 'make sure the subpr
 		git fetch .. subproj-br &&
 		git merge FETCH_HEAD &&
 
-		chks="sub1
-sub2
-sub3
-sub4" &&
-		chks_sub=$(cat <<TXT | sed '\''s,^,sub dir/,'\''
-$chks
-TXT
-) &&
-		chkms="main-sub1
-main-sub2
-main-sub3
-main-sub4" &&
-		chkms_sub=$(cat <<TXT | sed '\''s,^,sub dir/,'\''
-$chkms
-TXT
-) &&
-		allchanges=$(git log --name-only --pretty=format:"" | sort | sed "/^$/d") &&
-		check_equal "$allchanges" "$chkms
-$chks"
+		test_write_lines main-sub1 main-sub2 main-sub3 main-sub4 \
+			sub1 sub2 sub3 sub4 >expect &&
+		git log --name-only --pretty=format:"" >log &&
+		sort <log | sed "/^\$/ d" >actual &&
+		test_cmp expect actual
 	)
 '
 
@@ -675,29 +645,16 @@ test_expect_success 'make sure exactly t
 		cd "$subtree_test_count" &&
 		git subtree pull --prefix="sub dir" ./"sub proj" master &&
 
-		chkm="main1
-main2" &&
-		chks="sub1
-sub2
-sub3
-sub4" &&
-		chks_sub=$(cat <<TXT | sed '\''s,^,sub dir/,'\''
-$chks
-TXT
-) &&
-		chkms="main-sub1
-main-sub2
-main-sub3
-main-sub4" &&
-		chkms_sub=$(cat <<TXT | sed '\''s,^,sub dir/,'\''
-$chkms
-TXT
-) &&
-		mainfiles=$(git ls-files) &&
-		check_equal "$mainfiles" "$chkm
-$chkms_sub
-$chks_sub"
-)
+		test_write_lines main1 main2 >chkm &&
+		test_write_lines main-sub1 main-sub2 main-sub3 main-sub4 >chkms &&
+		sed "s,^,sub dir/," chkms >chkms_sub &&
+		test_write_lines sub1 sub2 sub3 sub4 >chks &&
+		sed "s,^,sub dir/," chks >chks_sub &&
+
+		cat chkm chkms_sub chks_sub >expect &&
+		git ls-files >actual &&
+		test_cmp expect actual
+	)
 '
 
 next_test
@@ -708,7 +665,7 @@ test_expect_success 'make sure each file
 	test_create_commit "$subtree_test_count/sub proj" sub1 &&
 	(
 		cd "$subtree_test_count" &&
-		git config log.date relative
+		git config log.date relative &&
 		git fetch ./"sub proj" master &&
 		git subtree add --prefix="sub dir" FETCH_HEAD
 	) &&
@@ -748,37 +705,21 @@ test_expect_success 'make sure each file
 		cd "$subtree_test_count" &&
 		git subtree pull --prefix="sub dir" ./"sub proj" master &&
 
-		chkm="main1
-main2" &&
-		chks="sub1
-sub2
-sub3
-sub4" &&
-		chks_sub=$(cat <<TXT | sed '\''s,^,sub dir/,'\''
-$chks
-TXT
-) &&
-		chkms="main-sub1
-main-sub2
-main-sub3
-main-sub4" &&
-		chkms_sub=$(cat <<TXT | sed '\''s,^,sub dir/,'\''
-$chkms
-TXT
-) &&
+		test_write_lines main1 main2 >chkm &&
+		test_write_lines sub1 sub2 sub3 sub4 >chks &&
+		test_write_lines main-sub1 main-sub2 main-sub3 main-sub4 >chkms &&
+		sed "s,^,sub dir/," chkms >chkms_sub &&
 
 		# main-sub?? and /"sub dir"/main-sub?? both change, because those are the
 		# changes that were split into their own history.  And "sub dir"/sub?? never
 		# change, since they were *only* changed in the subtree branch.
-		allchanges=$(git log --name-only --pretty=format:"" | sort | sed "/^$/d") &&
-		expected=''"$(cat <<TXT | sort
-$chkms
-$chkm
-$chks
-$chkms_sub
-TXT
-)"'' &&
-		check_equal "$allchanges" "$expected"
+		git log --name-only --pretty=format:"" >log &&
+		sort <log >sorted-log &&
+		sed "/^$/ d" sorted-log >actual &&
+
+		cat chkms chkm chks chkms_sub >expect-unsorted &&
+		sort expect-unsorted >expect &&
+		test_cmp expect actual
 	)
 '
 
diff -pruN 1.2.1+git2.18.0-1/git/contrib/svn-fe/svn-fe.txt 1.2.3+git2.25.1-1/git/contrib/svn-fe/svn-fe.txt
--- 1.2.1+git2.18.0-1/git/contrib/svn-fe/svn-fe.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/contrib/svn-fe/svn-fe.txt	2020-02-17 04:47:35.000000000 +0000
@@ -56,7 +56,7 @@ line.  This line has the form `git-svn-i
 
 The resulting repository will generally require further processing
 to put each project in its own repository and to separate the history
-of each branch.  The 'git filter-branch --subdirectory-filter' command
+of each branch.  The 'git filter-repo --subdirectory-filter' command
 may be useful for this purpose.
 
 BUGS
@@ -67,5 +67,5 @@ The exit status does not reflect whether
 
 SEE ALSO
 --------
-git-svn(1), svn2git(1), svk(1), git-filter-branch(1), git-fast-import(1),
+git-svn(1), svn2git(1), svk(1), git-filter-repo(1), git-fast-import(1),
 https://svn.apache.org/repos/asf/subversion/trunk/notes/dump-load-format.txt
diff -pruN 1.2.1+git2.18.0-1/git/contrib/svn-fe/svnrdump_sim.py 1.2.3+git2.25.1-1/git/contrib/svn-fe/svnrdump_sim.py
--- 1.2.1+git2.18.0-1/git/contrib/svn-fe/svnrdump_sim.py	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/contrib/svn-fe/svnrdump_sim.py	2020-02-17 04:47:35.000000000 +0000
@@ -1,4 +1,4 @@
-#!/usr/bin/python
+#!/usr/bin/env python
 """
 Simulates svnrdump by replaying an existing dump from a file, taking care
 of the specified revision range.
@@ -54,7 +54,7 @@ if __name__ == "__main__":
         print("usage: %s dump URL -rLOWER:UPPER")
         sys.exit(1)
     if not sys.argv[1] == 'dump':
-        raise NotImplementedError('only "dump" is suppported.')
+        raise NotImplementedError('only "dump" is supported.')
     url = sys.argv[2]
     r = ('0', 'HEAD')
     if len(sys.argv) == 4 and sys.argv[3][0:2] == '-r':
diff -pruN 1.2.1+git2.18.0-1/git/contrib/vscode/.gitattributes 1.2.3+git2.25.1-1/git/contrib/vscode/.gitattributes
--- 1.2.1+git2.18.0-1/git/contrib/vscode/.gitattributes	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/contrib/vscode/.gitattributes	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1 @@
+init.sh whitespace=-indent-with-non-tab
diff -pruN 1.2.1+git2.18.0-1/git/contrib/vscode/init.sh 1.2.3+git2.25.1-1/git/contrib/vscode/init.sh
--- 1.2.1+git2.18.0-1/git/contrib/vscode/init.sh	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/contrib/vscode/init.sh	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,375 @@
+#!/bin/sh
+
+die () {
+	echo "$*" >&2
+	exit 1
+}
+
+cd "$(dirname "$0")"/../.. ||
+die "Could not cd to top-level directory"
+
+mkdir -p .vscode ||
+die "Could not create .vscode/"
+
+# General settings
+
+cat >.vscode/settings.json.new <<\EOF ||
+{
+    "C_Cpp.intelliSenseEngine": "Default",
+    "C_Cpp.intelliSenseEngineFallback": "Disabled",
+    "[git-commit]": {
+        "editor.wordWrap": "wordWrapColumn",
+        "editor.wordWrapColumn": 72
+    },
+    "[c]": {
+        "editor.detectIndentation": false,
+        "editor.insertSpaces": false,
+        "editor.tabSize": 8,
+        "editor.wordWrap": "wordWrapColumn",
+        "editor.wordWrapColumn": 80,
+        "files.trimTrailingWhitespace": true
+    },
+    "files.associations": {
+        "*.h": "c",
+        "*.c": "c"
+    },
+    "cSpell.ignorePaths": [
+    ],
+    "cSpell.words": [
+        "DATAW",
+        "DBCACHED",
+        "DFCHECK",
+        "DTYPE",
+        "Hamano",
+        "HCAST",
+        "HEXSZ",
+        "HKEY",
+        "HKLM",
+        "IFGITLINK",
+        "IFINVALID",
+        "ISBROKEN",
+        "ISGITLINK",
+        "ISSYMREF",
+        "Junio",
+        "LPDWORD",
+        "LPPROC",
+        "LPWSTR",
+        "MSVCRT",
+        "NOARG",
+        "NOCOMPLETE",
+        "NOINHERIT",
+        "RENORMALIZE",
+        "STARTF",
+        "STARTUPINFOEXW",
+        "Schindelin",
+        "UCRT",
+        "YESNO",
+        "argcp",
+        "beginthreadex",
+        "committish",
+        "contentp",
+        "cpath",
+        "cpidx",
+        "ctim",
+        "dequote",
+        "envw",
+        "ewah",
+        "fdata",
+        "fherr",
+        "fhin",
+        "fhout",
+        "fragp",
+        "fsmonitor",
+        "hnsec",
+        "idents",
+        "includeif",
+        "interpr",
+        "iprog",
+        "isexe",
+        "iskeychar",
+        "kompare",
+        "mksnpath",
+        "mktag",
+        "mktree",
+        "mmblob",
+        "mmbuffer",
+        "mmfile",
+        "noenv",
+        "nparents",
+        "ntpath",
+        "ondisk",
+        "ooid",
+        "oplen",
+        "osdl",
+        "pnew",
+        "pold",
+        "ppinfo",
+        "pushf",
+        "pushv",
+        "rawsz",
+        "rebasing",
+        "reencode",
+        "repo",
+        "rerere",
+        "scld",
+        "sharedrepo",
+        "spawnv",
+        "spawnve",
+        "spawnvpe",
+        "strdup'ing",
+        "submodule",
+        "submodules",
+        "topath",
+        "topo",
+        "tpatch",
+        "unexecutable",
+        "unhide",
+        "unkc",
+        "unkv",
+        "unmark",
+        "unmatch",
+        "unsets",
+        "unshown",
+        "untracked",
+        "untrackedcache",
+        "unuse",
+        "upos",
+        "uval",
+        "vreportf",
+        "wargs",
+        "wargv",
+        "wbuffer",
+        "wcmd",
+        "wcsnicmp",
+        "wcstoutfdup",
+        "wdeltaenv",
+        "wdir",
+        "wenv",
+        "wenvblk",
+        "wenvcmp",
+        "wenviron",
+        "wenvpos",
+        "wenvsz",
+        "wfile",
+        "wfilename",
+        "wfopen",
+        "wfreopen",
+        "wfullpath",
+        "which'll",
+        "wlink",
+        "wmain",
+        "wmkdir",
+        "wmktemp",
+        "wnewpath",
+        "wotype",
+        "wpath",
+        "wpathname",
+        "wpgmptr",
+        "wpnew",
+        "wpointer",
+        "wpold",
+        "wpos",
+        "wputenv",
+        "wrmdir",
+        "wship",
+        "wtarget",
+        "wtemplate",
+        "wunlink",
+        "xcalloc",
+        "xgetcwd",
+        "xmallocz",
+        "xmemdupz",
+        "xmmap",
+        "xopts",
+        "xrealloc",
+        "xsnprintf",
+        "xutftowcs",
+        "xutftowcsn",
+        "xwcstoutf"
+    ],
+    "cSpell.ignoreRegExpList": [
+        "\\\"(DIRC|FSMN|REUC|UNTR)\\\"",
+        "\\\\u[0-9a-fA-Fx]{4}\\b",
+        "\\b(filfre|frotz|xyzzy)\\b",
+        "\\bCMIT_FMT_DEFAULT\\b",
+        "\\bde-munge\\b",
+        "\\bGET_OID_DISAMBIGUATORS\\b",
+        "\\bHASH_RENORMALIZE\\b",
+        "\\bTREESAMEness\\b",
+        "\\bUSE_STDEV\\b",
+        "\\Wchar *\\*\\W*utfs\\W",
+        "cURL's",
+        "nedmalloc'ed",
+        "ntifs\\.h",
+    ],
+}
+EOF
+die "Could not write settings.json"
+
+# Infer some setup-specific locations/names
+
+GCCPATH="$(which gcc)"
+GDBPATH="$(which gdb)"
+MAKECOMMAND="make -j5 DEVELOPER=1"
+OSNAME=
+X=
+case "$(uname -s)" in
+MINGW*)
+	GCCPATH="$(cygpath -am "$GCCPATH")"
+	GDBPATH="$(cygpath -am "$GDBPATH")"
+	MAKE_BASH="$(cygpath -am /git-cmd.exe) --command=usr\\\\bin\\\\bash.exe"
+	MAKECOMMAND="$MAKE_BASH -lc \\\"$MAKECOMMAND\\\""
+	OSNAME=Win32
+	X=.exe
+	;;
+Linux)
+	OSNAME=Linux
+	;;
+Darwin)
+	OSNAME=macOS
+	;;
+esac
+
+# Default build task
+
+cat >.vscode/tasks.json.new <<EOF ||
+{
+    // See https://go.microsoft.com/fwlink/?LinkId=733558
+    // for the documentation about the tasks.json format
+    "version": "2.0.0",
+    "tasks": [
+        {
+            "label": "make",
+            "type": "shell",
+            "command": "$MAKECOMMAND",
+            "group": {
+                "kind": "build",
+                "isDefault": true
+            }
+        }
+    ]
+}
+EOF
+die "Could not install default build task"
+
+# Debugger settings
+
+cat >.vscode/launch.json.new <<EOF ||
+{
+    // Use IntelliSense to learn about possible attributes.
+    // Hover to view descriptions of existing attributes.
+    // For more information, visit:
+    // https://go.microsoft.com/fwlink/?linkid=830387
+    "version": "0.2.0",
+    "configurations": [
+        {
+            "name": "(gdb) Launch",
+            "type": "cppdbg",
+            "request": "launch",
+            "program": "\${workspaceFolder}/git$X",
+            "args": [],
+            "stopAtEntry": false,
+            "cwd": "\${workspaceFolder}",
+            "environment": [],
+            "externalConsole": true,
+            "MIMode": "gdb",
+            "miDebuggerPath": "$GDBPATH",
+            "setupCommands": [
+                {
+                    "description": "Enable pretty-printing for gdb",
+                    "text": "-enable-pretty-printing",
+                    "ignoreFailures": true
+                }
+            ]
+        }
+    ]
+}
+EOF
+die "Could not write launch configuration"
+
+# C/C++ extension settings
+
+make -f - OSNAME=$OSNAME GCCPATH="$GCCPATH" vscode-init \
+	>.vscode/c_cpp_properties.json <<\EOF ||
+include Makefile
+
+vscode-init:
+	@mkdir -p .vscode && \
+	incs= && defs= && \
+	for e in $(ALL_CFLAGS) \
+			'-DGIT_EXEC_PATH="$(gitexecdir_SQ)"' \
+			'-DGIT_LOCALE_PATH="$(localedir_relative_SQ)"' \
+			'-DBINDIR="$(bindir_relative_SQ)"' \
+			'-DFALLBACK_RUNTIME_PREFIX="$(prefix_SQ)"' \
+			'-DDEFAULT_GIT_TEMPLATE_DIR="$(template_dir_SQ)"' \
+			'-DETC_GITCONFIG="$(ETC_GITCONFIG_SQ)"' \
+			'-DETC_GITATTRIBUTES="$(ETC_GITATTRIBUTES_SQ)"' \
+			'-DGIT_LOCALE_PATH="$(localedir_relative_SQ)"' \
+			'-DCURL_DISABLE_TYPECHECK', \
+			'-DGIT_HTML_PATH="$(htmldir_relative_SQ)"' \
+			'-DGIT_MAN_PATH="$(mandir_relative_SQ)"' \
+			'-DGIT_INFO_PATH="$(infodir_relative_SQ)"'; do \
+		case "$$e" in \
+		-I.) \
+			incs="$$(printf '% 16s"$${workspaceRoot}",\n%s' \
+				"" "$$incs")" \
+			;; \
+		-I/*) \
+			incs="$$(printf '% 16s"%s",\n%s' \
+				"" "$${e#-I}" "$$incs")" \
+			;; \
+		-I*) \
+			incs="$$(printf '% 16s"$${workspaceRoot}/%s",\n%s' \
+				"" "$${e#-I}" "$$incs")" \
+			;; \
+		-D*) \
+			defs="$$(printf '% 16s"%s",\n%s' \
+				"" "$$(echo "$${e#-D}" | sed 's/"/\\&/g')" \
+				"$$defs")" \
+			;; \
+		esac; \
+	done && \
+	echo '{' && \
+	echo '    "configurations": [' && \
+	echo '        {' && \
+	echo '            "name": "$(OSNAME)",' && \
+	echo '            "intelliSenseMode": "clang-x64",' && \
+	echo '            "includePath": [' && \
+	echo "$$incs" | sort | sed '$$s/,$$//' && \
+	echo '            ],' && \
+	echo '            "defines": [' && \
+	echo "$$defs" | sort | sed '$$s/,$$//' && \
+	echo '            ],' && \
+	echo '            "browse": {' && \
+	echo '                "limitSymbolsToIncludedHeaders": true,' && \
+	echo '                "databaseFilename": "",' && \
+	echo '                "path": [' && \
+	echo '                    "$${workspaceRoot}"' && \
+	echo '                ]' && \
+	echo '            },' && \
+	echo '            "cStandard": "c11",' && \
+	echo '            "cppStandard": "c++17",' && \
+	echo '            "compilerPath": "$(GCCPATH)"' && \
+	echo '        }' && \
+	echo '    ],' && \
+	echo '    "version": 4' && \
+	echo '}'
+EOF
+die "Could not write settings for the C/C++ extension"
+
+for file in .vscode/settings.json .vscode/tasks.json .vscode/launch.json
+do
+	if test -f $file
+	then
+		if git diff --no-index --quiet --exit-code $file $file.new
+		then
+			rm $file.new
+		else
+			printf "The file $file.new has these changes:\n\n"
+			git --no-pager diff --no-index $file $file.new
+			printf "\n\nMaybe \`mv $file.new $file\`?\n\n"
+		fi
+	else
+		mv $file.new $file
+	fi
+done
diff -pruN 1.2.1+git2.18.0-1/git/contrib/vscode/README.md 1.2.3+git2.25.1-1/git/contrib/vscode/README.md
--- 1.2.1+git2.18.0-1/git/contrib/vscode/README.md	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/contrib/vscode/README.md	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,14 @@
+Configuration for VS Code
+=========================
+
+[VS Code](https://code.visualstudio.com/) is a lightweight but powerful source
+code editor which runs on your desktop and is available for
+[Windows](https://code.visualstudio.com/docs/setup/windows),
+[macOS](https://code.visualstudio.com/docs/setup/mac) and
+[Linux](https://code.visualstudio.com/docs/setup/linux). Among other languages,
+it has [support for C/C++ via an extension](https://github.com/Microsoft/vscode-cpptools).
+
+To start developing Git with VS Code, simply run the Unix shell script called
+`init.sh` in this directory, which creates the configuration files in
+`.vscode/` that VS Code consumes. `init.sh` needs access to `make` and `gcc`,
+so run the script in a Git SDK shell if you are using Windows.
diff -pruN 1.2.1+git2.18.0-1/git/convert.c 1.2.3+git2.25.1-1/git/convert.c
--- 1.2.1+git2.18.0-1/git/convert.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/convert.c	2020-02-17 04:47:35.000000000 +0000
@@ -1,6 +1,6 @@
-#define NO_THE_INDEX_COMPATIBILITY_MACROS
 #include "cache.h"
 #include "config.h"
+#include "object-store.h"
 #include "attr.h"
 #include "run-command.h"
 #include "quote.h"
@@ -8,6 +8,7 @@
 #include "pkt-line.h"
 #include "sub-process.h"
 #include "utf8.h"
+#include "ll-merge.h"
 
 /*
  * convert.c - convert a file when checking it out and checking it in.
@@ -91,7 +92,7 @@ static void gather_stats(const char *buf
  * The same heuristics as diff.c::mmfile_is_binary()
  * We treat files with bare CR as binary
  */
-static int convert_is_binary(unsigned long size, const struct text_stat *stats)
+static int convert_is_binary(const struct text_stat *stats)
 {
 	if (stats->lonecr)
 		return 1;
@@ -109,7 +110,7 @@ static unsigned int gather_convert_stats
 	if (!data || !size)
 		return 0;
 	gather_stats(data, size, &stats);
-	if (convert_is_binary(size, &stats))
+	if (convert_is_binary(&stats))
 		ret |= CONVERT_STAT_BITS_BIN;
 	if (stats.crlf)
 		ret |= CONVERT_STAT_BITS_TXT_CRLF;
@@ -190,7 +191,7 @@ static enum eol output_eol(enum crlf_act
 		/* fall through */
 		return text_eol_is_crlf() ? EOL_CRLF : EOL_LF;
 	}
-	warning("Illegal crlf_action %d\n", (int)crlf_action);
+	warning(_("illegal crlf_action %d"), (int)crlf_action);
 	return core_eol;
 }
 
@@ -203,11 +204,11 @@ static void check_global_conv_flags_eol(
 		 * CRLFs would not be restored by checkout
 		 */
 		if (conv_flags & CONV_EOL_RNDTRP_DIE)
-			die(_("CRLF would be replaced by LF in %s."), path);
+			die(_("CRLF would be replaced by LF in %s"), path);
 		else if (conv_flags & CONV_EOL_RNDTRP_WARN)
 			warning(_("CRLF will be replaced by LF in %s.\n"
 				  "The file will have its original line"
-				  " endings in your working directory."), path);
+				  " endings in your working directory"), path);
 	} else if (old_stats->lonelf && !new_stats->lonelf ) {
 		/*
 		 * CRLFs would be added by checkout
@@ -217,7 +218,7 @@ static void check_global_conv_flags_eol(
 		else if (conv_flags & CONV_EOL_RNDTRP_WARN)
 			warning(_("LF will be replaced by CRLF in %s.\n"
 				  "The file will have its original line"
-				  " endings in your working directory."), path);
+				  " endings in your working directory"), path);
 	}
 }
 
@@ -244,7 +245,7 @@ static int has_crlf_in_index(const struc
 	return has_crlf;
 }
 
-static int will_convert_lf_to_crlf(size_t len, struct text_stat *stats,
+static int will_convert_lf_to_crlf(struct text_stat *stats,
 				   enum crlf_action crlf_action)
 {
 	if (output_eol(crlf_action) != EOL_CRLF)
@@ -259,7 +260,7 @@ static int will_convert_lf_to_crlf(size_
 		if (stats->lonecr || stats->crlf)
 			return 0;
 
-		if (convert_is_binary(len, stats))
+		if (convert_is_binary(stats))
 			return 0;
 	}
 	return 1;
@@ -269,8 +270,12 @@ static int will_convert_lf_to_crlf(size_
 static int validate_encoding(const char *path, const char *enc,
 		      const char *data, size_t len, int die_on_error)
 {
+	const char *stripped;
+
 	/* We only check for UTF here as UTF?? can be an alias for UTF-?? */
-	if (istarts_with(enc, "UTF")) {
+	if (skip_iprefix(enc, "UTF", &stripped)) {
+		skip_prefix(stripped, "-", &stripped);
+
 		/*
 		 * Check for detectable errors in UTF encodings
 		 */
@@ -284,15 +289,10 @@ static int validate_encoding(const char
 			 */
 			const char *advise_msg = _(
 				"The file '%s' contains a byte order "
-				"mark (BOM). Please use UTF-%s as "
+				"mark (BOM). Please use UTF-%.*s as "
 				"working-tree-encoding.");
-			const char *stripped = NULL;
-			char *upper = xstrdup_toupper(enc);
-			upper[strlen(upper)-2] = '\0';
-			if (!skip_prefix(upper, "UTF-", &stripped))
-				skip_prefix(stripped, "UTF", &stripped);
-			advise(advise_msg, path, stripped);
-			free(upper);
+			int stripped_len = strlen(stripped) - strlen("BE");
+			advise(advise_msg, path, stripped_len, stripped);
 			if (die_on_error)
 				die(error_msg, path, enc);
 			else {
@@ -307,12 +307,7 @@ static int validate_encoding(const char
 				"mark (BOM). Please use UTF-%sBE or UTF-%sLE "
 				"(depending on the byte order) as "
 				"working-tree-encoding.");
-			const char *stripped = NULL;
-			char *upper = xstrdup_toupper(enc);
-			if (!skip_prefix(upper, "UTF-", &stripped))
-				skip_prefix(stripped, "UTF", &stripped);
 			advise(advise_msg, path, stripped, stripped);
-			free(upper);
 			if (die_on_error)
 				die(error_msg, path, enc);
 			else {
@@ -334,7 +329,7 @@ static void trace_encoding(const char *c
 	strbuf_addf(&trace, "%s (%s, considered %s):\n", context, path, encoding);
 	for (i = 0; i < len && buf; ++i) {
 		strbuf_addf(
-			&trace,"| \e[2m%2i:\e[0m %2x \e[2m%c\e[0m%c",
+			&trace, "| \033[2m%2i:\033[0m %2x \033[2m%c\033[0m%c",
 			i,
 			(unsigned char) buf[i],
 			(buf[i] > 32 && buf[i] < 127 ? buf[i] : ' '),
@@ -389,7 +384,7 @@ static int encode_to_git(const char *pat
 			 struct strbuf *buf, const char *enc, int conv_flags)
 {
 	char *dst;
-	int dst_len;
+	size_t dst_len;
 	int die_on_error = conv_flags & CONV_WRITE_OBJECT;
 
 	/*
@@ -417,7 +412,7 @@ static int encode_to_git(const char *pat
 	if (!dst) {
 		/*
 		 * We could add the blob "as-is" to Git. However, on checkout
-		 * we would try to reencode to the original encoding. This
+		 * we would try to re-encode to the original encoding. This
 		 * would fail and we would leave the user with a messed-up
 		 * working tree. Let's try to avoid this by screaming loud.
 		 */
@@ -452,7 +447,7 @@ static int encode_to_git(const char *pat
 	 */
 	if (die_on_error && check_roundtrip(enc)) {
 		char *re_src;
-		int re_src_len;
+		size_t re_src_len;
 
 		re_src = reencode_string_len(dst, dst_len,
 					     enc, default_encoding,
@@ -480,7 +475,7 @@ static int encode_to_worktree(const char
 			      struct strbuf *buf, const char *enc)
 {
 	char *dst;
-	int dst_len;
+	size_t dst_len;
 
 	/*
 	 * No encoding is specified or there is nothing to encode.
@@ -492,8 +487,8 @@ static int encode_to_worktree(const char
 	dst = reencode_string_len(src, src_len, enc, default_encoding,
 				  &dst_len);
 	if (!dst) {
-		error("failed to encode '%s' from %s to %s",
-			path, default_encoding, enc);
+		error(_("failed to encode '%s' from %s to %s"),
+		      path, default_encoding, enc);
 		return 0;
 	}
 
@@ -526,7 +521,7 @@ static int crlf_to_git(const struct inde
 	convert_crlf_into_lf = !!stats.crlf;
 
 	if (crlf_action == CRLF_AUTO || crlf_action == CRLF_AUTO_INPUT || crlf_action == CRLF_AUTO_CRLF) {
-		if (convert_is_binary(len, &stats))
+		if (convert_is_binary(&stats))
 			return 0;
 		/*
 		 * If the file in the index has any CR in it, do not
@@ -548,7 +543,7 @@ static int crlf_to_git(const struct inde
 			new_stats.crlf = 0;
 		}
 		/* simulate "git checkout" */
-		if (will_convert_lf_to_crlf(len, &new_stats, crlf_action)) {
+		if (will_convert_lf_to_crlf(&new_stats, crlf_action)) {
 			new_stats.crlf += new_stats.lonelf;
 			new_stats.lonelf = 0;
 		}
@@ -590,7 +585,7 @@ static int crlf_to_git(const struct inde
 	return 1;
 }
 
-static int crlf_to_worktree(const char *path, const char *src, size_t len,
+static int crlf_to_worktree(const char *src, size_t len,
 			    struct strbuf *buf, enum crlf_action crlf_action)
 {
 	char *to_free = NULL;
@@ -600,7 +595,7 @@ static int crlf_to_worktree(const char *
 		return 0;
 
 	gather_stats(src, len, &stats);
-	if (!will_convert_lf_to_crlf(len, &stats, crlf_action))
+	if (!will_convert_lf_to_crlf(&stats, crlf_action))
 		return 0;
 
 	/* are we "faking" in place editing ? */
@@ -670,7 +665,8 @@ static int filter_buffer_or_fd(int in, i
 
 	if (start_command(&child_process)) {
 		strbuf_release(&cmd);
-		return error("cannot fork to run external filter '%s'", params->cmd);
+		return error(_("cannot fork to run external filter '%s'"),
+			     params->cmd);
 	}
 
 	sigchain_push(SIGPIPE, SIG_IGN);
@@ -689,20 +685,21 @@ static int filter_buffer_or_fd(int in, i
 	if (close(child_process.in))
 		write_err = 1;
 	if (write_err)
-		error("cannot feed the input to external filter '%s'", params->cmd);
+		error(_("cannot feed the input to external filter '%s'"),
+		      params->cmd);
 
 	sigchain_pop(SIGPIPE);
 
 	status = finish_command(&child_process);
 	if (status)
-		error("external filter '%s' failed %d", params->cmd, status);
+		error(_("external filter '%s' failed %d"), params->cmd, status);
 
 	strbuf_release(&cmd);
 	return (write_err || status);
 }
 
 static int apply_single_file_filter(const char *path, const char *src, size_t len, int fd,
-                        struct strbuf *dst, const char *cmd)
+				    struct strbuf *dst, const char *cmd)
 {
 	/*
 	 * Create a pipeline to have the command filter the buffer's
@@ -729,14 +726,14 @@ static int apply_single_file_filter(cons
 	if (start_async(&async))
 		return 0;	/* error was already reported */
 
-	if (strbuf_read(&nbuf, async.out, len) < 0) {
-		err = error("read from external filter '%s' failed", cmd);
+	if (strbuf_read(&nbuf, async.out, 0) < 0) {
+		err = error(_("read from external filter '%s' failed"), cmd);
 	}
 	if (close(async.out)) {
-		err = error("read from external filter '%s' failed", cmd);
+		err = error(_("read from external filter '%s' failed"), cmd);
 	}
 	if (finish_async(&async)) {
-		err = error("external filter '%s' failed", cmd);
+		err = error(_("external filter '%s' failed"), cmd);
 	}
 
 	if (!err) {
@@ -775,7 +772,8 @@ static int start_multi_file_filter_fn(st
 
 static void handle_filter_error(const struct strbuf *filter_status,
 				struct cmd2process *entry,
-				const unsigned int wanted_capability) {
+				const unsigned int wanted_capability)
+{
 	if (!strcmp(filter_status->buf, "error"))
 		; /* The filter signaled a problem with the file. */
 	else if (!strcmp(filter_status->buf, "abort") && wanted_capability) {
@@ -790,7 +788,7 @@ static void handle_filter_error(const st
 		 * Something went wrong with the protocol filter.
 		 * Force shutdown and restart if another blob requires filtering.
 		 */
-		error("external filter '%s' failed", entry->subprocess.cmd);
+		error(_("external filter '%s' failed"), entry->subprocess.cmd);
 		subprocess_stop(&subprocess_map, &entry->subprocess);
 		free(entry);
 	}
@@ -838,7 +836,7 @@ static int apply_multi_file_filter(const
 	else if (wanted_capability & CAP_SMUDGE)
 		filter_type = "smudge";
 	else
-		die("unexpected filter type");
+		die(_("unexpected filter type"));
 
 	sigchain_push(SIGPIPE, SIG_IGN);
 
@@ -849,7 +847,7 @@ static int apply_multi_file_filter(const
 
 	err = strlen(path) > LARGE_PACKET_DATA_MAX - strlen("pathname=\n");
 	if (err) {
-		error("path name too long for external filter");
+		error(_("path name too long for external filter"));
 		goto done;
 	}
 
@@ -923,8 +921,8 @@ int async_query_available_blobs(const ch
 	assert(subprocess_map_initialized);
 	entry = (struct cmd2process *)subprocess_find_entry(&subprocess_map, cmd);
 	if (!entry) {
-		error("external filter '%s' is not available anymore although "
-		      "not all paths have been filtered", cmd);
+		error(_("external filter '%s' is not available anymore although "
+			"not all paths have been filtered"), cmd);
 		return 0;
 	}
 	process = &entry->subprocess.process;
@@ -1087,8 +1085,8 @@ static int count_ident(const char *cp, u
 	return cnt;
 }
 
-static int ident_to_git(const char *path, const char *src, size_t len,
-                        struct strbuf *buf, int ident)
+static int ident_to_git(const char *src, size_t len,
+			struct strbuf *buf, int ident)
 {
 	char *dst, *dollar;
 
@@ -1131,8 +1129,8 @@ static int ident_to_git(const char *path
 	return 1;
 }
 
-static int ident_to_worktree(const char *path, const char *src, size_t len,
-                             struct strbuf *buf, int ident)
+static int ident_to_worktree(const char *src, size_t len,
+			     struct strbuf *buf, int ident)
 {
 	struct object_id oid;
 	char *to_free = NULL, *dollar, *spc;
@@ -1290,9 +1288,12 @@ struct conv_attrs {
 	const char *working_tree_encoding; /* Supported encoding or default encoding if NULL */
 };
 
-static void convert_attrs(struct conv_attrs *ca, const char *path)
+static struct attr_check *check;
+
+static void convert_attrs(const struct index_state *istate,
+			  struct conv_attrs *ca, const char *path)
 {
-	static struct attr_check *check;
+	struct attr_check_item *ccheck = NULL;
 
 	if (!check) {
 		check = attr_check_initl("crlf", "ident", "filter",
@@ -1302,30 +1303,25 @@ static void convert_attrs(struct conv_at
 		git_config(read_convert_config, NULL);
 	}
 
-	if (!git_check_attr(path, check)) {
-		struct attr_check_item *ccheck = check->items;
-		ca->crlf_action = git_path_check_crlf(ccheck + 4);
-		if (ca->crlf_action == CRLF_UNDEFINED)
-			ca->crlf_action = git_path_check_crlf(ccheck + 0);
-		ca->ident = git_path_check_ident(ccheck + 1);
-		ca->drv = git_path_check_convert(ccheck + 2);
-		if (ca->crlf_action != CRLF_BINARY) {
-			enum eol eol_attr = git_path_check_eol(ccheck + 3);
-			if (ca->crlf_action == CRLF_AUTO && eol_attr == EOL_LF)
-				ca->crlf_action = CRLF_AUTO_INPUT;
-			else if (ca->crlf_action == CRLF_AUTO && eol_attr == EOL_CRLF)
-				ca->crlf_action = CRLF_AUTO_CRLF;
-			else if (eol_attr == EOL_LF)
-				ca->crlf_action = CRLF_TEXT_INPUT;
-			else if (eol_attr == EOL_CRLF)
-				ca->crlf_action = CRLF_TEXT_CRLF;
-		}
-		ca->working_tree_encoding = git_path_check_encoding(ccheck + 5);
-	} else {
-		ca->drv = NULL;
-		ca->crlf_action = CRLF_UNDEFINED;
-		ca->ident = 0;
+	git_check_attr(istate, path, check);
+	ccheck = check->items;
+	ca->crlf_action = git_path_check_crlf(ccheck + 4);
+	if (ca->crlf_action == CRLF_UNDEFINED)
+		ca->crlf_action = git_path_check_crlf(ccheck + 0);
+	ca->ident = git_path_check_ident(ccheck + 1);
+	ca->drv = git_path_check_convert(ccheck + 2);
+	if (ca->crlf_action != CRLF_BINARY) {
+		enum eol eol_attr = git_path_check_eol(ccheck + 3);
+		if (ca->crlf_action == CRLF_AUTO && eol_attr == EOL_LF)
+			ca->crlf_action = CRLF_AUTO_INPUT;
+		else if (ca->crlf_action == CRLF_AUTO && eol_attr == EOL_CRLF)
+			ca->crlf_action = CRLF_AUTO_CRLF;
+		else if (eol_attr == EOL_LF)
+			ca->crlf_action = CRLF_TEXT_INPUT;
+		else if (eol_attr == EOL_CRLF)
+			ca->crlf_action = CRLF_TEXT_CRLF;
 	}
+	ca->working_tree_encoding = git_path_check_encoding(ccheck + 5);
 
 	/* Save attr and make a decision for action */
 	ca->attr_action = ca->crlf_action;
@@ -1339,11 +1335,28 @@ static void convert_attrs(struct conv_at
 		ca->crlf_action = CRLF_AUTO_INPUT;
 }
 
-int would_convert_to_git_filter_fd(const char *path)
+void reset_parsed_attributes(void)
+{
+	struct convert_driver *drv, *next;
+
+	attr_check_free(check);
+	check = NULL;
+	reset_merge_attributes();
+
+	for (drv = user_convert; drv; drv = next) {
+		next = drv->next;
+		free((void *)drv->name);
+		free(drv);
+	}
+	user_convert = NULL;
+	user_convert_tail = NULL;
+}
+
+int would_convert_to_git_filter_fd(const struct index_state *istate, const char *path)
 {
 	struct conv_attrs ca;
 
-	convert_attrs(&ca, path);
+	convert_attrs(istate, &ca, path);
 	if (!ca.drv)
 		return 0;
 
@@ -1358,11 +1371,11 @@ int would_convert_to_git_filter_fd(const
 	return apply_filter(path, NULL, 0, -1, NULL, ca.drv, CAP_CLEAN, NULL);
 }
 
-const char *get_convert_attr_ascii(const char *path)
+const char *get_convert_attr_ascii(const struct index_state *istate, const char *path)
 {
 	struct conv_attrs ca;
 
-	convert_attrs(&ca, path);
+	convert_attrs(istate, &ca, path);
 	switch (ca.attr_action) {
 	case CRLF_UNDEFINED:
 		return "";
@@ -1391,11 +1404,11 @@ int convert_to_git(const struct index_st
 	int ret = 0;
 	struct conv_attrs ca;
 
-	convert_attrs(&ca, path);
+	convert_attrs(istate, &ca, path);
 
 	ret |= apply_filter(path, src, len, -1, dst, ca.drv, CAP_CLEAN, NULL);
 	if (!ret && ca.drv && ca.drv->required)
-		die("%s: clean filter '%s' failed", path, ca.drv->name);
+		die(_("%s: clean filter '%s' failed"), path, ca.drv->name);
 
 	if (ret && dst) {
 		src = dst->buf;
@@ -1415,7 +1428,7 @@ int convert_to_git(const struct index_st
 			len = dst->len;
 		}
 	}
-	return ret | ident_to_git(path, src, len, dst, ca.ident);
+	return ret | ident_to_git(src, len, dst, ca.ident);
 }
 
 void convert_to_git_filter_fd(const struct index_state *istate,
@@ -1423,29 +1436,30 @@ void convert_to_git_filter_fd(const stru
 			      int conv_flags)
 {
 	struct conv_attrs ca;
-	convert_attrs(&ca, path);
+	convert_attrs(istate, &ca, path);
 
 	assert(ca.drv);
 	assert(ca.drv->clean || ca.drv->process);
 
 	if (!apply_filter(path, NULL, 0, fd, dst, ca.drv, CAP_CLEAN, NULL))
-		die("%s: clean filter '%s' failed", path, ca.drv->name);
+		die(_("%s: clean filter '%s' failed"), path, ca.drv->name);
 
 	encode_to_git(path, dst->buf, dst->len, dst, ca.working_tree_encoding, conv_flags);
 	crlf_to_git(istate, path, dst->buf, dst->len, dst, ca.crlf_action, conv_flags);
-	ident_to_git(path, dst->buf, dst->len, dst, ca.ident);
+	ident_to_git(dst->buf, dst->len, dst, ca.ident);
 }
 
-static int convert_to_working_tree_internal(const char *path, const char *src,
+static int convert_to_working_tree_internal(const struct index_state *istate,
+					    const char *path, const char *src,
 					    size_t len, struct strbuf *dst,
 					    int normalizing, struct delayed_checkout *dco)
 {
 	int ret = 0, ret_filter = 0;
 	struct conv_attrs ca;
 
-	convert_attrs(&ca, path);
+	convert_attrs(istate, &ca, path);
 
-	ret |= ident_to_worktree(path, src, len, dst, ca.ident);
+	ret |= ident_to_worktree(src, len, dst, ca.ident);
 	if (ret) {
 		src = dst->buf;
 		len = dst->len;
@@ -1456,7 +1470,7 @@ static int convert_to_working_tree_inter
 	 * support smudge).  The filters might expect CRLFs.
 	 */
 	if ((ca.drv && (ca.drv->smudge || ca.drv->process)) || !normalizing) {
-		ret |= crlf_to_worktree(path, src, len, dst, ca.crlf_action);
+		ret |= crlf_to_worktree(src, len, dst, ca.crlf_action);
 		if (ret) {
 			src = dst->buf;
 			len = dst->len;
@@ -1472,27 +1486,30 @@ static int convert_to_working_tree_inter
 	ret_filter = apply_filter(
 		path, src, len, -1, dst, ca.drv, CAP_SMUDGE, dco);
 	if (!ret_filter && ca.drv && ca.drv->required)
-		die("%s: smudge filter %s failed", path, ca.drv->name);
+		die(_("%s: smudge filter %s failed"), path, ca.drv->name);
 
 	return ret | ret_filter;
 }
 
-int async_convert_to_working_tree(const char *path, const char *src,
+int async_convert_to_working_tree(const struct index_state *istate,
+				  const char *path, const char *src,
 				  size_t len, struct strbuf *dst,
 				  void *dco)
 {
-	return convert_to_working_tree_internal(path, src, len, dst, 0, dco);
+	return convert_to_working_tree_internal(istate, path, src, len, dst, 0, dco);
 }
 
-int convert_to_working_tree(const char *path, const char *src, size_t len, struct strbuf *dst)
+int convert_to_working_tree(const struct index_state *istate,
+			    const char *path, const char *src,
+			    size_t len, struct strbuf *dst)
 {
-	return convert_to_working_tree_internal(path, src, len, dst, 0, NULL);
+	return convert_to_working_tree_internal(istate, path, src, len, dst, 0, NULL);
 }
 
 int renormalize_buffer(const struct index_state *istate, const char *path,
 		       const char *src, size_t len, struct strbuf *dst)
 {
-	int ret = convert_to_working_tree_internal(path, src, len, dst, 1, NULL);
+	int ret = convert_to_working_tree_internal(istate, path, src, len, dst, 1, NULL);
 	if (ret) {
 		src = dst->buf;
 		len = dst->len;
@@ -1923,15 +1940,17 @@ static struct stream_filter *ident_filte
  * the contents cannot be filtered without reading the whole thing
  * in-core.
  *
- * Note that you would be crazy to set CRLF, smuge/clean or ident to a
+ * Note that you would be crazy to set CRLF, smudge/clean or ident to a
  * large binary blob you would want us not to slurp into the memory!
  */
-struct stream_filter *get_stream_filter(const char *path, const struct object_id *oid)
+struct stream_filter *get_stream_filter(const struct index_state *istate,
+					const char *path,
+					const struct object_id *oid)
 {
 	struct conv_attrs ca;
 	struct stream_filter *filter = NULL;
 
-	convert_attrs(&ca, path);
+	convert_attrs(istate, &ca, path);
 	if (ca.drv && (ca.drv->process || ca.drv->smudge || ca.drv->clean))
 		return NULL;
 
diff -pruN 1.2.1+git2.18.0-1/git/convert.h 1.2.3+git2.25.1-1/git/convert.h
--- 1.2.1+git2.18.0-1/git/convert.h	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/convert.h	2020-02-17 04:47:35.000000000 +0000
@@ -7,6 +7,8 @@
 #include "string-list.h"
 
 struct index_state;
+struct object_id;
+struct strbuf;
 
 #define CONV_EOL_RNDTRP_DIE   (1<<0) /* Die if CRLF to LF to CRLF is different */
 #define CONV_EOL_RNDTRP_WARN  (1<<1) /* Warn if CRLF to LF to CRLF is different */
@@ -57,35 +59,46 @@ struct delayed_checkout {
 
 extern enum eol core_eol;
 extern char *check_roundtrip_encoding;
-extern const char *get_cached_convert_stats_ascii(const struct index_state *istate,
-						  const char *path);
-extern const char *get_wt_convert_stats_ascii(const char *path);
-extern const char *get_convert_attr_ascii(const char *path);
+const char *get_cached_convert_stats_ascii(const struct index_state *istate,
+					   const char *path);
+const char *get_wt_convert_stats_ascii(const char *path);
+const char *get_convert_attr_ascii(const struct index_state *istate,
+				   const char *path);
 
 /* returns 1 if *dst was used */
-extern int convert_to_git(const struct index_state *istate,
-			  const char *path, const char *src, size_t len,
-			  struct strbuf *dst, int conv_flags);
-extern int convert_to_working_tree(const char *path, const char *src,
-				   size_t len, struct strbuf *dst);
-extern int async_convert_to_working_tree(const char *path, const char *src,
-					 size_t len, struct strbuf *dst,
-					 void *dco);
-extern int async_query_available_blobs(const char *cmd, struct string_list *available_paths);
-extern int renormalize_buffer(const struct index_state *istate,
-			      const char *path, const char *src, size_t len,
-			      struct strbuf *dst);
+int convert_to_git(const struct index_state *istate,
+		   const char *path, const char *src, size_t len,
+		   struct strbuf *dst, int conv_flags);
+int convert_to_working_tree(const struct index_state *istate,
+			    const char *path, const char *src,
+			    size_t len, struct strbuf *dst);
+int async_convert_to_working_tree(const struct index_state *istate,
+				  const char *path, const char *src,
+				  size_t len, struct strbuf *dst,
+				  void *dco);
+int async_query_available_blobs(const char *cmd,
+				struct string_list *available_paths);
+int renormalize_buffer(const struct index_state *istate,
+		       const char *path, const char *src, size_t len,
+		       struct strbuf *dst);
 static inline int would_convert_to_git(const struct index_state *istate,
 				       const char *path)
 {
 	return convert_to_git(istate, path, NULL, 0, NULL, 0);
 }
 /* Precondition: would_convert_to_git_filter_fd(path) == true */
-extern void convert_to_git_filter_fd(const struct index_state *istate,
-				     const char *path, int fd,
-				     struct strbuf *dst,
-				     int conv_flags);
-extern int would_convert_to_git_filter_fd(const char *path);
+void convert_to_git_filter_fd(const struct index_state *istate,
+			      const char *path, int fd,
+			      struct strbuf *dst,
+			      int conv_flags);
+int would_convert_to_git_filter_fd(const struct index_state *istate,
+				   const char *path);
+
+/*
+ * Reset the internal list of attributes used by convert_to_git and
+ * convert_to_working_tree.
+ */
+void reset_parsed_attributes(void);
 
 /*****************************************************************
  *
@@ -95,9 +108,11 @@ extern int would_convert_to_git_filter_f
 
 struct stream_filter; /* opaque */
 
-extern struct stream_filter *get_stream_filter(const char *path, const struct object_id *);
-extern void free_stream_filter(struct stream_filter *);
-extern int is_null_stream_filter(struct stream_filter *);
+struct stream_filter *get_stream_filter(const struct index_state *istate,
+					const char *path,
+					const struct object_id *);
+void free_stream_filter(struct stream_filter *);
+int is_null_stream_filter(struct stream_filter *);
 
 /*
  * Use as much input up to *isize_p and fill output up to *osize_p;
@@ -111,8 +126,8 @@ extern int is_null_stream_filter(struct
  * such filters know there is no more input coming and it is time for
  * them to produce the remaining output based on the buffered input.
  */
-extern int stream_filter(struct stream_filter *,
-			 const char *input, size_t *isize_p,
-			 char *output, size_t *osize_p);
+int stream_filter(struct stream_filter *,
+		  const char *input, size_t *isize_p,
+		  char *output, size_t *osize_p);
 
 #endif /* CONVERT_H */
diff -pruN 1.2.1+git2.18.0-1/git/credential-cache--daemon.c 1.2.3+git2.25.1-1/git/credential-cache--daemon.c
--- 1.2.1+git2.18.0-1/git/credential-cache--daemon.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/credential-cache--daemon.c	2020-02-17 04:47:35.000000000 +0000
@@ -91,7 +91,8 @@ static timestamp_t check_expirations(voi
 }
 
 static int read_request(FILE *fh, struct credential *c,
-			struct strbuf *action, int *timeout) {
+			struct strbuf *action, int *timeout)
+{
 	static struct strbuf item = STRBUF_INIT;
 	const char *p;
 
diff -pruN 1.2.1+git2.18.0-1/git/credential.h 1.2.3+git2.25.1-1/git/credential.h
--- 1.2.1+git2.18.0-1/git/credential.h	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/credential.h	2020-02-17 04:47:35.000000000 +0000
@@ -3,8 +3,208 @@
 
 #include "string-list.h"
 
+/**
+ * The credentials API provides an abstracted way of gathering username and
+ * password credentials from the user.
+ *
+ * Typical setup
+ * -------------
+ *
+ * ------------
+ * +-----------------------+
+ * | Git code (C)          |--- to server requiring --->
+ * |                       |        authentication
+ * |.......................|
+ * | C credential API      |--- prompt ---> User
+ * +-----------------------+
+ * 	^      |
+ * 	| pipe |
+ * 	|      v
+ * +-----------------------+
+ * | Git credential helper |
+ * +-----------------------+
+ * ------------
+ *
+ * The Git code (typically a remote-helper) will call the C API to obtain
+ * credential data like a login/password pair (credential_fill). The
+ * API will itself call a remote helper (e.g. "git credential-cache" or
+ * "git credential-store") that may retrieve credential data from a
+ * store. If the credential helper cannot find the information, the C API
+ * will prompt the user. Then, the caller of the API takes care of
+ * contacting the server, and does the actual authentication.
+ *
+ * C API
+ * -----
+ *
+ * The credential C API is meant to be called by Git code which needs to
+ * acquire or store a credential. It is centered around an object
+ * representing a single credential and provides three basic operations:
+ * fill (acquire credentials by calling helpers and/or prompting the user),
+ * approve (mark a credential as successfully used so that it can be stored
+ * for later use), and reject (mark a credential as unsuccessful so that it
+ * can be erased from any persistent storage).
+ *
+ * Example
+ * ~~~~~~~
+ *
+ * The example below shows how the functions of the credential API could be
+ * used to login to a fictitious "foo" service on a remote host:
+ *
+ * -----------------------------------------------------------------------
+ * int foo_login(struct foo_connection *f)
+ * {
+ * 	int status;
+ * 	// Create a credential with some context; we don't yet know the
+ * 	// username or password.
+ *
+ * struct credential c = CREDENTIAL_INIT;
+ * c.protocol = xstrdup("foo");
+ * c.host = xstrdup(f->hostname);
+ *
+ * // Fill in the username and password fields by contacting
+ * // helpers and/or asking the user. The function will die if it
+ * // fails.
+ * credential_fill(&c);
+ *
+ * // Otherwise, we have a username and password. Try to use it.
+ *
+ * status = send_foo_login(f, c.username, c.password);
+ * switch (status) {
+ * case FOO_OK:
+ * // It worked. Store the credential for later use.
+ * credential_accept(&c);
+ * break;
+ * case FOO_BAD_LOGIN:
+ * // Erase the credential from storage so we don't try it again.
+ * credential_reject(&c);
+ * break;
+ * default:
+ * // Some other error occurred. We don't know if the
+ * // credential is good or bad, so report nothing to the
+ * // credential subsystem.
+ * }
+ *
+ * // Free any associated resources.
+ * credential_clear(&c);
+ *
+ * return status;
+ * }
+ * -----------------------------------------------------------------------
+ *
+ * Credential Helpers
+ * ------------------
+ *
+ * Credential helpers are programs executed by Git to fetch or save
+ * credentials from and to long-term storage (where "long-term" is simply
+ * longer than a single Git process; e.g., credentials may be stored
+ * in-memory for a few minutes, or indefinitely on disk).
+ *
+ * Each helper is specified by a single string in the configuration
+ * variable `credential.helper` (and others, see Documentation/git-config.txt).
+ * The string is transformed by Git into a command to be executed using
+ * these rules:
+ *
+ *   1. If the helper string begins with "!", it is considered a shell
+ *      snippet, and everything after the "!" becomes the command.
+ *
+ *   2. Otherwise, if the helper string begins with an absolute path, the
+ *      verbatim helper string becomes the command.
+ *
+ *   3. Otherwise, the string "git credential-" is prepended to the helper
+ *      string, and the result becomes the command.
+ *
+ * The resulting command then has an "operation" argument appended to it
+ * (see below for details), and the result is executed by the shell.
+ *
+ * Here are some example specifications:
+ *
+ * ----------------------------------------------------
+ * # run "git credential-foo"
+ * foo
+ *
+ * # same as above, but pass an argument to the helper
+ * foo --bar=baz
+ *
+ * # the arguments are parsed by the shell, so use shell
+ * # quoting if necessary
+ * foo --bar="whitespace arg"
+ *
+ * # you can also use an absolute path, which will not use the git wrapper
+ * /path/to/my/helper --with-arguments
+ *
+ * # or you can specify your own shell snippet
+ * !f() { echo "password=`cat $HOME/.secret`"; }; f
+ * ----------------------------------------------------
+ *
+ * Generally speaking, rule (3) above is the simplest for users to specify.
+ * Authors of credential helpers should make an effort to assist their
+ * users by naming their program "git-credential-$NAME", and putting it in
+ * the $PATH or $GIT_EXEC_PATH during installation, which will allow a user
+ * to enable it with `git config credential.helper $NAME`.
+ *
+ * When a helper is executed, it will have one "operation" argument
+ * appended to its command line, which is one of:
+ *
+ * `get`::
+ *
+ * 	Return a matching credential, if any exists.
+ *
+ * `store`::
+ *
+ * 	Store the credential, if applicable to the helper.
+ *
+ * `erase`::
+ *
+ * 	Remove a matching credential, if any, from the helper's storage.
+ *
+ * The details of the credential will be provided on the helper's stdin
+ * stream. The exact format is the same as the input/output format of the
+ * `git credential` plumbing command (see the section `INPUT/OUTPUT
+ * FORMAT` in Documentation/git-credential.txt for a detailed specification).
+ *
+ * For a `get` operation, the helper should produce a list of attributes
+ * on stdout in the same format. A helper is free to produce a subset, or
+ * even no values at all if it has nothing useful to provide. Any provided
+ * attributes will overwrite those already known about by Git.  If a helper
+ * outputs a `quit` attribute with a value of `true` or `1`, no further
+ * helpers will be consulted, nor will the user be prompted (if no
+ * credential has been provided, the operation will then fail).
+ *
+ * For a `store` or `erase` operation, the helper's output is ignored.
+ * If it fails to perform the requested operation, it may complain to
+ * stderr to inform the user. If it does not support the requested
+ * operation (e.g., a read-only store), it should silently ignore the
+ * request.
+ *
+ * If a helper receives any other operation, it should silently ignore the
+ * request. This leaves room for future operations to be added (older
+ * helpers will just ignore the new requests).
+ *
+ */
+
+
+/**
+ * This struct represents a single username/password combination
+ * along with any associated context. All string fields should be
+ * heap-allocated (or NULL if they are not known or not applicable).
+ * The meaning of the individual context fields is the same as
+ * their counterparts in the helper protocol.
+ *
+ * This struct should always be initialized with `CREDENTIAL_INIT` or
+ * `credential_init`.
+ */
 struct credential {
+
+	/**
+	 * A `string_list` of helpers. Each string specifies an external
+	 * helper which will be run, in order, to either acquire or store
+	 * credentials. This list is filled-in by the API functions
+	 * according to the corresponding configuration variables before
+	 * consulting helpers, so there usually is no need for a caller to
+	 * modify the helpers field at all.
+	 */
 	struct string_list helpers;
+
 	unsigned approved:1,
 		 configured:1,
 		 quit:1,
@@ -19,16 +219,52 @@ struct credential {
 
 #define CREDENTIAL_INIT { STRING_LIST_INIT_DUP }
 
+/* Initialize a credential structure, setting all fields to empty. */
 void credential_init(struct credential *);
+
+/**
+ * Free any resources associated with the credential structure, returning
+ * it to a pristine initialized state.
+ */
 void credential_clear(struct credential *);
 
+/**
+ * Instruct the credential subsystem to fill the username and
+ * password fields of the passed credential struct by first
+ * consulting helpers, then asking the user. After this function
+ * returns, the username and password fields of the credential are
+ * guaranteed to be non-NULL. If an error occurs, the function will
+ * die().
+ */
 void credential_fill(struct credential *);
+
+/**
+ * Inform the credential subsystem that the provided credentials
+ * were successfully used for authentication.  This will cause the
+ * credential subsystem to notify any helpers of the approval, so
+ * that they may store the result to be used again.  Any errors
+ * from helpers are ignored.
+ */
 void credential_approve(struct credential *);
+
+/**
+ * Inform the credential subsystem that the provided credentials
+ * have been rejected. This will cause the credential subsystem to
+ * notify any helpers of the rejection (which allows them, for
+ * example, to purge the invalid credentials from storage). It
+ * will also free() the username and password fields of the
+ * credential and set them to NULL (readying the credential for
+ * another call to `credential_fill`). Any errors from helpers are
+ * ignored.
+ */
 void credential_reject(struct credential *);
 
 int credential_read(struct credential *, FILE *);
 void credential_write(const struct credential *, FILE *);
+
+/* Parse a URL into broken-down credential fields. */
 void credential_from_url(struct credential *, const char *url);
+
 int credential_match(const struct credential *have,
 		     const struct credential *want);
 
diff -pruN 1.2.1+git2.18.0-1/git/credential-store.c 1.2.3+git2.25.1-1/git/credential-store.c
--- 1.2.1+git2.18.0-1/git/credential-store.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/credential-store.c	2020-02-17 04:47:35.000000000 +0000
@@ -72,15 +72,16 @@ static void store_credential_file(const
 	struct strbuf buf = STRBUF_INIT;
 
 	strbuf_addf(&buf, "%s://", c->protocol);
-	strbuf_addstr_urlencode(&buf, c->username, 1);
+	strbuf_addstr_urlencode(&buf, c->username, is_rfc3986_unreserved);
 	strbuf_addch(&buf, ':');
-	strbuf_addstr_urlencode(&buf, c->password, 1);
+	strbuf_addstr_urlencode(&buf, c->password, is_rfc3986_unreserved);
 	strbuf_addch(&buf, '@');
 	if (c->host)
-		strbuf_addstr_urlencode(&buf, c->host, 1);
+		strbuf_addstr_urlencode(&buf, c->host, is_rfc3986_unreserved);
 	if (c->path) {
 		strbuf_addch(&buf, '/');
-		strbuf_addstr_urlencode(&buf, c->path, 0);
+		strbuf_addstr_urlencode(&buf, c->path,
+					is_rfc3986_reserved_or_unreserved);
 	}
 
 	rewrite_credential_file(fn, c, &buf);
diff -pruN 1.2.1+git2.18.0-1/git/csum-file.h 1.2.3+git2.25.1-1/git/csum-file.h
--- 1.2.1+git2.18.0-1/git/csum-file.h	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/csum-file.h	2020-02-17 04:47:35.000000000 +0000
@@ -1,6 +1,8 @@
 #ifndef CSUM_FILE_H
 #define CSUM_FILE_H
 
+#include "hash.h"
+
 struct progress;
 
 /* A SHA1-protected file */
@@ -23,22 +25,22 @@ struct hashfile_checkpoint {
 	git_hash_ctx ctx;
 };
 
-extern void hashfile_checkpoint(struct hashfile *, struct hashfile_checkpoint *);
-extern int hashfile_truncate(struct hashfile *, struct hashfile_checkpoint *);
+void hashfile_checkpoint(struct hashfile *, struct hashfile_checkpoint *);
+int hashfile_truncate(struct hashfile *, struct hashfile_checkpoint *);
 
 /* finalize_hashfile flags */
 #define CSUM_CLOSE		1
 #define CSUM_FSYNC		2
 #define CSUM_HASH_IN_STREAM	4
 
-extern struct hashfile *hashfd(int fd, const char *name);
-extern struct hashfile *hashfd_check(const char *name);
-extern struct hashfile *hashfd_throughput(int fd, const char *name, struct progress *tp);
-extern int finalize_hashfile(struct hashfile *, unsigned char *, unsigned int);
-extern void hashwrite(struct hashfile *, const void *, unsigned int);
-extern void hashflush(struct hashfile *f);
-extern void crc32_begin(struct hashfile *);
-extern uint32_t crc32_end(struct hashfile *);
+struct hashfile *hashfd(int fd, const char *name);
+struct hashfile *hashfd_check(const char *name);
+struct hashfile *hashfd_throughput(int fd, const char *name, struct progress *tp);
+int finalize_hashfile(struct hashfile *, unsigned char *, unsigned int);
+void hashwrite(struct hashfile *, const void *, unsigned int);
+void hashflush(struct hashfile *f);
+void crc32_begin(struct hashfile *);
+uint32_t crc32_end(struct hashfile *);
 
 static inline void hashwrite_u8(struct hashfile *f, uint8_t data)
 {
diff -pruN 1.2.1+git2.18.0-1/git/daemon.c 1.2.3+git2.25.1-1/git/daemon.c
--- 1.2.1+git2.18.0-1/git/daemon.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/daemon.c	2020-02-17 04:47:35.000000000 +0000
@@ -598,7 +598,7 @@ static void canonicalize_client(struct s
  * Read the host as supplied by the client connection.
  *
  * Returns a pointer to the character after the NUL byte terminating the host
- * arguemnt, or 'extra_args' if there is no host arguemnt.
+ * argument, or 'extra_args' if there is no host argument.
  */
 static char *parse_host_arg(struct hostinfo *hi, char *extra_args, int buflen)
 {
@@ -652,7 +652,7 @@ static void parse_extra_args(struct host
 		 * service that will be run.
 		 *
 		 * If there ends up being a particular arg in the future that
-		 * git-daemon needs to parse specificly (like the 'host' arg)
+		 * git-daemon needs to parse specifically (like the 'host' arg)
 		 * then it can be parsed here and not added to 'git_protocol'.
 		 */
 		if (*arg) {
diff -pruN 1.2.1+git2.18.0-1/git/date.c 1.2.3+git2.25.1-1/git/date.c
--- 1.2.1+git2.18.0-1/git/date.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/date.c	2020-02-17 04:47:35.000000000 +0000
@@ -64,35 +64,29 @@ static time_t gm_time_t(timestamp_t time
  * thing, which means that tz -0100 is passed in as the integer -100,
  * even though it means "sixty minutes off"
  */
-static struct tm *time_to_tm(timestamp_t time, int tz)
+static struct tm *time_to_tm(timestamp_t time, int tz, struct tm *tm)
 {
 	time_t t = gm_time_t(time, tz);
-	return gmtime(&t);
+	return gmtime_r(&t, tm);
 }
 
-static struct tm *time_to_tm_local(timestamp_t time)
+static struct tm *time_to_tm_local(timestamp_t time, struct tm *tm)
 {
 	time_t t = time;
-	return localtime(&t);
+	return localtime_r(&t, tm);
 }
 
 /*
- * What value of "tz" was in effect back then at "time" in the
- * local timezone?
+ * Fill in the localtime 'struct tm' for the supplied time,
+ * and return the local tz.
  */
-static int local_tzoffset(timestamp_t time)
+static int local_time_tzoffset(time_t t, struct tm *tm)
 {
-	time_t t, t_local;
-	struct tm tm;
+	time_t t_local;
 	int offset, eastwest;
 
-	if (date_overflows(time))
-		die("Timestamp too large for this system: %"PRItime, time);
-
-	t = (time_t)time;
-	localtime_r(&t, &tm);
-	t_local = tm_to_time_t(&tm);
-
+	localtime_r(&t, tm);
+	t_local = tm_to_time_t(tm);
 	if (t_local == -1)
 		return 0; /* error; just use +0000 */
 	if (t_local < t) {
@@ -107,16 +101,44 @@ static int local_tzoffset(timestamp_t ti
 	return offset * eastwest;
 }
 
-void show_date_relative(timestamp_t time, int tz,
-			       const struct timeval *now,
-			       struct strbuf *timebuf)
+/*
+ * What value of "tz" was in effect back then at "time" in the
+ * local timezone?
+ */
+static int local_tzoffset(timestamp_t time)
+{
+	struct tm tm;
+
+	if (date_overflows(time))
+		die("Timestamp too large for this system: %"PRItime, time);
+
+	return local_time_tzoffset((time_t)time, &tm);
+}
+
+static void get_time(struct timeval *now)
 {
+	const char *x;
+
+	x = getenv("GIT_TEST_DATE_NOW");
+	if (x) {
+		now->tv_sec = atoi(x);
+		now->tv_usec = 0;
+	}
+	else
+		gettimeofday(now, NULL);
+}
+
+void show_date_relative(timestamp_t time, struct strbuf *timebuf)
+{
+	struct timeval now;
 	timestamp_t diff;
-	if (now->tv_sec < time) {
+
+	get_time(&now);
+	if (now.tv_sec < time) {
 		strbuf_addstr(timebuf, _("in the future"));
 		return;
 	}
-	diff = now->tv_sec - time;
+	diff = now.tv_sec - time;
 	if (diff < 90) {
 		strbuf_addf(timebuf,
 			 Q_("%"PRItime" second ago", "%"PRItime" seconds ago", diff), diff);
@@ -191,9 +213,79 @@ struct date_mode *date_mode_from_type(en
 	return &mode;
 }
 
+static void show_date_normal(struct strbuf *buf, timestamp_t time, struct tm *tm, int tz, struct tm *human_tm, int human_tz, int local)
+{
+	struct {
+		unsigned int	year:1,
+				date:1,
+				wday:1,
+				time:1,
+				seconds:1,
+				tz:1;
+	} hide = { 0 };
+
+	hide.tz = local || tz == human_tz;
+	hide.year = tm->tm_year == human_tm->tm_year;
+	if (hide.year) {
+		if (tm->tm_mon == human_tm->tm_mon) {
+			if (tm->tm_mday > human_tm->tm_mday) {
+				/* Future date: think timezones */
+			} else if (tm->tm_mday == human_tm->tm_mday) {
+				hide.date = hide.wday = 1;
+			} else if (tm->tm_mday + 5 > human_tm->tm_mday) {
+				/* Leave just weekday if it was a few days ago */
+				hide.date = 1;
+			}
+		}
+	}
+
+	/* Show "today" times as just relative times */
+	if (hide.wday) {
+		show_date_relative(time, buf);
+		return;
+	}
+
+	/*
+	 * Always hide seconds for human-readable.
+	 * Hide timezone if showing date.
+	 * Hide weekday and time if showing year.
+	 *
+	 * The logic here is two-fold:
+	 *  (a) only show details when recent enough to matter
+	 *  (b) keep the maximum length "similar", and in check
+	 */
+	if (human_tm->tm_year) {
+		hide.seconds = 1;
+		hide.tz |= !hide.date;
+		hide.wday = hide.time = !hide.year;
+	}
+
+	if (!hide.wday)
+		strbuf_addf(buf, "%.3s ", weekday_names[tm->tm_wday]);
+	if (!hide.date)
+		strbuf_addf(buf, "%.3s %d ", month_names[tm->tm_mon], tm->tm_mday);
+
+	/* Do we want AM/PM depending on locale? */
+	if (!hide.time) {
+		strbuf_addf(buf, "%02d:%02d", tm->tm_hour, tm->tm_min);
+		if (!hide.seconds)
+			strbuf_addf(buf, ":%02d", tm->tm_sec);
+	} else
+		strbuf_rtrim(buf);
+
+	if (!hide.year)
+		strbuf_addf(buf, " %d", tm->tm_year + 1900);
+
+	if (!hide.tz)
+		strbuf_addf(buf, " %+05d", tz);
+}
+
 const char *show_date(timestamp_t time, int tz, const struct date_mode *mode)
 {
 	struct tm *tm;
+	struct tm tmbuf = { 0 };
+	struct tm human_tm = { 0 };
+	int human_tz = -1;
 	static struct strbuf timebuf = STRBUF_INIT;
 
 	if (mode->type == DATE_UNIX) {
@@ -202,6 +294,15 @@ const char *show_date(timestamp_t time,
 		return timebuf.buf;
 	}
 
+	if (mode->type == DATE_HUMAN) {
+		struct timeval now;
+
+		get_time(&now);
+
+		/* Fill in the data for "current time" in human_tz and human_tm */
+		human_tz = local_time_tzoffset(now.tv_sec, &human_tm);
+	}
+
 	if (mode->local)
 		tz = local_tzoffset(time);
 
@@ -212,20 +313,17 @@ const char *show_date(timestamp_t time,
 	}
 
 	if (mode->type == DATE_RELATIVE) {
-		struct timeval now;
-
 		strbuf_reset(&timebuf);
-		gettimeofday(&now, NULL);
-		show_date_relative(time, tz, &now, &timebuf);
+		show_date_relative(time, &timebuf);
 		return timebuf.buf;
 	}
 
 	if (mode->local)
-		tm = time_to_tm_local(time);
+		tm = time_to_tm_local(time, &tmbuf);
 	else
-		tm = time_to_tm(time, tz);
+		tm = time_to_tm(time, tz, &tmbuf);
 	if (!tm) {
-		tm = time_to_tm(0, 0);
+		tm = time_to_tm(0, 0, &tmbuf);
 		tz = 0;
 	}
 
@@ -258,14 +356,7 @@ const char *show_date(timestamp_t time,
 		strbuf_addftime(&timebuf, mode->strftime_fmt, tm, tz,
 				!mode->local);
 	else
-		strbuf_addf(&timebuf, "%.3s %.3s %d %02d:%02d:%02d %d%c%+05d",
-				weekday_names[tm->tm_wday],
-				month_names[tm->tm_mon],
-				tm->tm_mday,
-				tm->tm_hour, tm->tm_min, tm->tm_sec,
-				tm->tm_year + 1900,
-				mode->local ? 0 : ' ',
-				tz);
+		show_date_normal(&timebuf, time, tm, tz, &human_tm, human_tz, mode->local);
 	return timebuf.buf;
 }
 
@@ -819,12 +910,18 @@ static enum date_mode_type parse_date_ty
 		return DATE_SHORT;
 	if (skip_prefix(format, "default", end))
 		return DATE_NORMAL;
+	if (skip_prefix(format, "human", end))
+		return DATE_HUMAN;
 	if (skip_prefix(format, "raw", end))
 		return DATE_RAW;
 	if (skip_prefix(format, "unix", end))
 		return DATE_UNIX;
 	if (skip_prefix(format, "format", end))
 		return DATE_STRFTIME;
+	/*
+	 * Please update $__git_log_date_formats in
+	 * git-completion.bash when you add new formats.
+	 */
 
 	die("unknown date format %s", format);
 }
@@ -833,6 +930,14 @@ void parse_date_format(const char *forma
 {
 	const char *p;
 
+	/* "auto:foo" is "if tty/pager, then foo, otherwise normal" */
+	if (skip_prefix(format, "auto:", &p)) {
+		if (isatty(1) || pager_in_use())
+			format = p;
+		else
+			format = "default";
+	}
+
 	/* historical alias */
 	if (!strcmp(format, "local"))
 		format = "default-local";
@@ -855,10 +960,11 @@ void datestamp(struct strbuf *out)
 {
 	time_t now;
 	int offset;
+	struct tm tm = { 0 };
 
 	time(&now);
 
-	offset = tm_to_time_t(localtime(&now)) - now;
+	offset = tm_to_time_t(localtime_r(&now, &tm)) - now;
 	offset /= 60;
 
 	date_string(now, offset, out);
@@ -887,20 +993,49 @@ static time_t update_tm(struct tm *tm, s
 	return n;
 }
 
+/*
+ * Do we have a pending number at the end, or when
+ * we see a new one? Let's assume it's a month day,
+ * as in "Dec 6, 1992"
+ */
+static void pending_number(struct tm *tm, int *num)
+{
+	int number = *num;
+
+	if (number) {
+		*num = 0;
+		if (tm->tm_mday < 0 && number < 32)
+			tm->tm_mday = number;
+		else if (tm->tm_mon < 0 && number < 13)
+			tm->tm_mon = number-1;
+		else if (tm->tm_year < 0) {
+			if (number > 1969 && number < 2100)
+				tm->tm_year = number - 1900;
+			else if (number > 69 && number < 100)
+				tm->tm_year = number;
+			else if (number < 38)
+				tm->tm_year = 100 + number;
+			/* We screw up for number = 00 ? */
+		}
+	}
+}
+
 static void date_now(struct tm *tm, struct tm *now, int *num)
 {
+	*num = 0;
 	update_tm(tm, now, 0);
 }
 
 static void date_yesterday(struct tm *tm, struct tm *now, int *num)
 {
+	*num = 0;
 	update_tm(tm, now, 24*60*60);
 }
 
 static void date_time(struct tm *tm, struct tm *now, int hour)
 {
 	if (tm->tm_hour < hour)
-		date_yesterday(tm, now, NULL);
+		update_tm(tm, now, 24*60*60);
 	tm->tm_hour = hour;
 	tm->tm_min = 0;
 	tm->tm_sec = 0;
@@ -908,16 +1043,19 @@ static void date_time(struct tm *tm, str
 
 static void date_midnight(struct tm *tm, struct tm *now, int *num)
 {
+	pending_number(tm, num);
 	date_time(tm, now, 0);
 }
 
 static void date_noon(struct tm *tm, struct tm *now, int *num)
 {
+	pending_number(tm, num);
 	date_time(tm, now, 12);
 }
 
 static void date_tea(struct tm *tm, struct tm *now, int *num)
 {
+	pending_number(tm, num);
 	date_time(tm, now, 17);
 }
 
@@ -953,6 +1091,7 @@ static void date_never(struct tm *tm, st
 {
 	time_t n = 0;
 	localtime_r(&n, tm);
+	*num = 0;
 }
 
 static const struct special {
@@ -1110,33 +1249,6 @@ static const char *approxidate_digit(con
 	return end;
 }
 
-/*
- * Do we have a pending number at the end, or when
- * we see a new one? Let's assume it's a month day,
- * as in "Dec 6, 1992"
- */
-static void pending_number(struct tm *tm, int *num)
-{
-	int number = *num;
-
-	if (number) {
-		*num = 0;
-		if (tm->tm_mday < 0 && number < 32)
-			tm->tm_mday = number;
-		else if (tm->tm_mon < 0 && number < 13)
-			tm->tm_mon = number-1;
-		else if (tm->tm_year < 0) {
-			if (number > 1969 && number < 2100)
-				tm->tm_year = number - 1900;
-			else if (number > 69 && number < 100)
-				tm->tm_year = number;
-			else if (number < 38)
-				tm->tm_year = 100 + number;
-			/* We screw up for number = 00 ? */
-		}
-	}
-}
-
 static timestamp_t approxidate_str(const char *date,
 				   const struct timeval *tv,
 				   int *error_ret)
@@ -1174,15 +1286,18 @@ static timestamp_t approxidate_str(const
 	return (timestamp_t)update_tm(&tm, &now, 0);
 }
 
-timestamp_t approxidate_relative(const char *date, const struct timeval *tv)
+timestamp_t approxidate_relative(const char *date)
 {
+	struct timeval tv;
 	timestamp_t timestamp;
 	int offset;
 	int errors = 0;
 
 	if (!parse_date_basic(date, &timestamp, &offset))
 		return timestamp;
-	return approxidate_str(date, tv, &errors);
+
+	get_time(&tv);
+	return approxidate_str(date, (const struct timeval *) &tv, &errors);
 }
 
 timestamp_t approxidate_careful(const char *date, int *error_ret)
@@ -1199,7 +1314,7 @@ timestamp_t approxidate_careful(const ch
 		return timestamp;
 	}
 
-	gettimeofday(&tv, NULL);
+	get_time(&tv);
 	return approxidate_str(date, &tv, error_ret);
 }
 
diff -pruN 1.2.1+git2.18.0-1/git/decorate.c 1.2.3+git2.25.1-1/git/decorate.c
--- 1.2.1+git2.18.0-1/git/decorate.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/decorate.c	2020-02-17 04:47:35.000000000 +0000
@@ -8,7 +8,7 @@
 
 static unsigned int hash_obj(const struct object *obj, unsigned int n)
 {
-	return sha1hash(obj->oid.hash) % n;
+	return oidhash(&obj->oid) % n;
 }
 
 static void *insert_decoration(struct decoration *n, const struct object *base, void *decoration)
diff -pruN 1.2.1+git2.18.0-1/git/decorate.h 1.2.3+git2.25.1-1/git/decorate.h
--- 1.2.1+git2.18.0-1/git/decorate.h	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/decorate.h	2020-02-17 04:47:35.000000000 +0000
@@ -50,12 +50,12 @@ struct decoration {
  * NULL), returning the previously associated pointer. If there is no previous
  * association, this function returns NULL.
  */
-extern void *add_decoration(struct decoration *n, const struct object *obj, void *decoration);
+void *add_decoration(struct decoration *n, const struct object *obj, void *decoration);
 
 /*
  * Return the pointer associated to the given object. If there is no
  * association, this function returns NULL.
  */
-extern void *lookup_decoration(struct decoration *n, const struct object *obj);
+void *lookup_decoration(struct decoration *n, const struct object *obj);
 
 #endif
diff -pruN 1.2.1+git2.18.0-1/git/delta.h 1.2.3+git2.25.1-1/git/delta.h
--- 1.2.1+git2.18.0-1/git/delta.h	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/delta.h	2020-02-17 04:47:35.000000000 +0000
@@ -13,7 +13,7 @@ struct delta_index;
  * before free_delta_index() is called.  The returned pointer must be freed
  * using free_delta_index().
  */
-extern struct delta_index *
+struct delta_index *
 create_delta_index(const void *buf, unsigned long bufsize);
 
 /*
@@ -21,14 +21,14 @@ create_delta_index(const void *buf, unsi
  *
  * Given pointer must be what create_delta_index() returned, or NULL.
  */
-extern void free_delta_index(struct delta_index *index);
+void free_delta_index(struct delta_index *index);
 
 /*
  * sizeof_delta_index: returns memory usage of delta index
  *
  * Given pointer must be what create_delta_index() returned, or NULL.
  */
-extern unsigned long sizeof_delta_index(struct delta_index *index);
+unsigned long sizeof_delta_index(struct delta_index *index);
 
 /*
  * create_delta: create a delta from given index for the given buffer
@@ -40,7 +40,7 @@ extern unsigned long sizeof_delta_index(
  * returned and *delta_size is updated with its size.  The returned buffer
  * must be freed by the caller.
  */
-extern void *
+void *
 create_delta(const struct delta_index *index,
 	     const void *buf, unsigned long bufsize,
 	     unsigned long *delta_size, unsigned long max_delta_size);
@@ -75,9 +75,9 @@ diff_delta(const void *src_buf, unsigned
  * *trg_bufsize is updated with its size.  On failure a NULL pointer is
  * returned.  The returned buffer must be freed by the caller.
  */
-extern void *patch_delta(const void *src_buf, unsigned long src_size,
-			 const void *delta_buf, unsigned long delta_size,
-			 unsigned long *dst_size);
+void *patch_delta(const void *src_buf, unsigned long src_size,
+		  const void *delta_buf, unsigned long delta_size,
+		  unsigned long *dst_size);
 
 /* the smallest possible delta size is 4 bytes */
 #define DELTA_SIZE_MIN	4
diff -pruN 1.2.1+git2.18.0-1/git/delta-islands.c 1.2.3+git2.25.1-1/git/delta-islands.c
--- 1.2.1+git2.18.0-1/git/delta-islands.c	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/delta-islands.c	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,507 @@
+#include "cache.h"
+#include "attr.h"
+#include "object.h"
+#include "blob.h"
+#include "commit.h"
+#include "tag.h"
+#include "tree.h"
+#include "delta.h"
+#include "pack.h"
+#include "tree-walk.h"
+#include "diff.h"
+#include "revision.h"
+#include "list-objects.h"
+#include "progress.h"
+#include "refs.h"
+#include "khash.h"
+#include "pack-bitmap.h"
+#include "pack-objects.h"
+#include "delta-islands.h"
+#include "sha1-array.h"
+#include "config.h"
+
+KHASH_INIT(str, const char *, void *, 1, kh_str_hash_func, kh_str_hash_equal)
+
+static kh_oid_map_t *island_marks;
+static unsigned island_counter;
+static unsigned island_counter_core;
+
+static kh_str_t *remote_islands;
+
+struct remote_island {
+	uint64_t hash;
+	struct oid_array oids;
+};
+
+struct island_bitmap {
+	uint32_t refcount;
+	uint32_t bits[FLEX_ARRAY];
+};
+
+static uint32_t island_bitmap_size;
+
+/*
+ * Allocate a new bitmap; if "old" is not NULL, the new bitmap will be a copy
+ * of "old". Otherwise, the new bitmap is empty.
+ */
+static struct island_bitmap *island_bitmap_new(const struct island_bitmap *old)
+{
+	size_t size = sizeof(struct island_bitmap) + (island_bitmap_size * 4);
+	struct island_bitmap *b = xcalloc(1, size);
+
+	if (old)
+		memcpy(b, old, size);
+
+	b->refcount = 1;
+	return b;
+}
+
+static void island_bitmap_or(struct island_bitmap *a, const struct island_bitmap *b)
+{
+	uint32_t i;
+
+	for (i = 0; i < island_bitmap_size; ++i)
+		a->bits[i] |= b->bits[i];
+}
+
+static int island_bitmap_is_subset(struct island_bitmap *self,
+		struct island_bitmap *super)
+{
+	uint32_t i;
+
+	if (self == super)
+		return 1;
+
+	for (i = 0; i < island_bitmap_size; ++i) {
+		if ((self->bits[i] & super->bits[i]) != self->bits[i])
+			return 0;
+	}
+
+	return 1;
+}
+
+#define ISLAND_BITMAP_BLOCK(x) (x / 32)
+#define ISLAND_BITMAP_MASK(x) (1 << (x % 32))
+
+static void island_bitmap_set(struct island_bitmap *self, uint32_t i)
+{
+	self->bits[ISLAND_BITMAP_BLOCK(i)] |= ISLAND_BITMAP_MASK(i);
+}
+
+static int island_bitmap_get(struct island_bitmap *self, uint32_t i)
+{
+	return (self->bits[ISLAND_BITMAP_BLOCK(i)] & ISLAND_BITMAP_MASK(i)) != 0;
+}
+
+int in_same_island(const struct object_id *trg_oid, const struct object_id *src_oid)
+{
+	khiter_t trg_pos, src_pos;
+
+	/* If we aren't using islands, assume everything goes together. */
+	if (!island_marks)
+		return 1;
+
+	/*
+	 * If we don't have a bitmap for the target, we can delta it
+	 * against anything -- it's not an important object
+	 */
+	trg_pos = kh_get_oid_map(island_marks, *trg_oid);
+	if (trg_pos >= kh_end(island_marks))
+		return 1;
+
+	/*
+	 * if the source (our delta base) doesn't have a bitmap,
+	 * we don't want to base any deltas on it!
+	 */
+	src_pos = kh_get_oid_map(island_marks, *src_oid);
+	if (src_pos >= kh_end(island_marks))
+		return 0;
+
+	return island_bitmap_is_subset(kh_value(island_marks, trg_pos),
+				kh_value(island_marks, src_pos));
+}
+
+int island_delta_cmp(const struct object_id *a, const struct object_id *b)
+{
+	khiter_t a_pos, b_pos;
+	struct island_bitmap *a_bitmap = NULL, *b_bitmap = NULL;
+
+	if (!island_marks)
+		return 0;
+
+	a_pos = kh_get_oid_map(island_marks, *a);
+	if (a_pos < kh_end(island_marks))
+		a_bitmap = kh_value(island_marks, a_pos);
+
+	b_pos = kh_get_oid_map(island_marks, *b);
+	if (b_pos < kh_end(island_marks))
+		b_bitmap = kh_value(island_marks, b_pos);
+
+	if (a_bitmap) {
+		if (!b_bitmap || !island_bitmap_is_subset(a_bitmap, b_bitmap))
+			return -1;
+	}
+	if (b_bitmap) {
+		if (!a_bitmap || !island_bitmap_is_subset(b_bitmap, a_bitmap))
+			return 1;
+	}
+
+	return 0;
+}
+
+static struct island_bitmap *create_or_get_island_marks(struct object *obj)
+{
+	khiter_t pos;
+	int hash_ret;
+
+	pos = kh_put_oid_map(island_marks, obj->oid, &hash_ret);
+	if (hash_ret)
+		kh_value(island_marks, pos) = island_bitmap_new(NULL);
+
+	return kh_value(island_marks, pos);
+}
+
+static void set_island_marks(struct object *obj, struct island_bitmap *marks)
+{
+	struct island_bitmap *b;
+	khiter_t pos;
+	int hash_ret;
+
+	pos = kh_put_oid_map(island_marks, obj->oid, &hash_ret);
+	if (hash_ret) {
+		/*
+		 * We don't have one yet; make a copy-on-write of the
+		 * parent.
+		 */
+		marks->refcount++;
+		kh_value(island_marks, pos) = marks;
+		return;
+	}
+
+	/*
+	 * We do have it. Make sure we split any copy-on-write before
+	 * updating.
+	 */
+	b = kh_value(island_marks, pos);
+	if (b->refcount > 1) {
+		b->refcount--;
+		b = kh_value(island_marks, pos) = island_bitmap_new(b);
+	}
+	island_bitmap_or(b, marks);
+}
+
+static void mark_remote_island_1(struct repository *r,
+				 struct remote_island *rl,
+				 int is_core_island)
+{
+	uint32_t i;
+
+	for (i = 0; i < rl->oids.nr; ++i) {
+		struct island_bitmap *marks;
+		struct object *obj = parse_object(r, &rl->oids.oid[i]);
+
+		if (!obj)
+			continue;
+
+		marks = create_or_get_island_marks(obj);
+		island_bitmap_set(marks, island_counter);
+
+		if (is_core_island && obj->type == OBJ_COMMIT)
+			obj->flags |= NEEDS_BITMAP;
+
+		/* If it was a tag, also make sure we hit the underlying object. */
+		while (obj && obj->type == OBJ_TAG) {
+			obj = ((struct tag *)obj)->tagged;
+			if (obj) {
+				parse_object(r, &obj->oid);
+				marks = create_or_get_island_marks(obj);
+				island_bitmap_set(marks, island_counter);
+			}
+		}
+	}
+
+	if (is_core_island)
+		island_counter_core = island_counter;
+
+	island_counter++;
+}
+
+struct tree_islands_todo {
+	struct object_entry *entry;
+	unsigned int depth;
+};
+
+static int tree_depth_compare(const void *a, const void *b)
+{
+	const struct tree_islands_todo *todo_a = a;
+	const struct tree_islands_todo *todo_b = b;
+
+	return todo_a->depth - todo_b->depth;
+}
+
+void resolve_tree_islands(struct repository *r,
+			  int progress,
+			  struct packing_data *to_pack)
+{
+	struct progress *progress_state = NULL;
+	struct tree_islands_todo *todo;
+	int nr = 0;
+	int i;
+
+	if (!island_marks)
+		return;
+
+	/*
+	 * We process only trees, as commits and tags have already been handled
+	 * (and passed their marks on to root trees, as well. We must make sure
+	 * to process them in descending tree-depth order so that marks
+	 * propagate down the tree properly, even if a sub-tree is found in
+	 * multiple parent trees.
+	 */
+	ALLOC_ARRAY(todo, to_pack->nr_objects);
+	for (i = 0; i < to_pack->nr_objects; i++) {
+		if (oe_type(&to_pack->objects[i]) == OBJ_TREE) {
+			todo[nr].entry = &to_pack->objects[i];
+			todo[nr].depth = oe_tree_depth(to_pack, &to_pack->objects[i]);
+			nr++;
+		}
+	}
+	QSORT(todo, nr, tree_depth_compare);
+
+	if (progress)
+		progress_state = start_progress(_("Propagating island marks"), nr);
+
+	for (i = 0; i < nr; i++) {
+		struct object_entry *ent = todo[i].entry;
+		struct island_bitmap *root_marks;
+		struct tree *tree;
+		struct tree_desc desc;
+		struct name_entry entry;
+		khiter_t pos;
+
+		pos = kh_get_oid_map(island_marks, ent->idx.oid);
+		if (pos >= kh_end(island_marks))
+			continue;
+
+		root_marks = kh_value(island_marks, pos);
+
+		tree = lookup_tree(r, &ent->idx.oid);
+		if (!tree || parse_tree(tree) < 0)
+			die(_("bad tree object %s"), oid_to_hex(&ent->idx.oid));
+
+		init_tree_desc(&desc, tree->buffer, tree->size);
+		while (tree_entry(&desc, &entry)) {
+			struct object *obj;
+
+			if (S_ISGITLINK(entry.mode))
+				continue;
+
+			obj = lookup_object(r, &entry.oid);
+			if (!obj)
+				continue;
+
+			set_island_marks(obj, root_marks);
+		}
+
+		free_tree_buffer(tree);
+
+		display_progress(progress_state, i+1);
+	}
+
+	stop_progress(&progress_state);
+	free(todo);
+}
+
+static regex_t *island_regexes;
+static unsigned int island_regexes_alloc, island_regexes_nr;
+static const char *core_island_name;
+
+static int island_config_callback(const char *k, const char *v, void *cb)
+{
+	if (!strcmp(k, "pack.island")) {
+		struct strbuf re = STRBUF_INIT;
+
+		if (!v)
+			return config_error_nonbool(k);
+
+		ALLOC_GROW(island_regexes, island_regexes_nr + 1, island_regexes_alloc);
+
+		if (*v != '^')
+			strbuf_addch(&re, '^');
+		strbuf_addstr(&re, v);
+
+		if (regcomp(&island_regexes[island_regexes_nr], re.buf, REG_EXTENDED))
+			die(_("failed to load island regex for '%s': %s"), k, re.buf);
+
+		strbuf_release(&re);
+		island_regexes_nr++;
+		return 0;
+	}
+
+	if (!strcmp(k, "pack.islandcore"))
+		return git_config_string(&core_island_name, k, v);
+
+	return 0;
+}
+
+static void add_ref_to_island(const char *island_name, const struct object_id *oid)
+{
+	uint64_t sha_core;
+	struct remote_island *rl = NULL;
+
+	int hash_ret;
+	khiter_t pos = kh_put_str(remote_islands, island_name, &hash_ret);
+
+	if (hash_ret) {
+		kh_key(remote_islands, pos) = xstrdup(island_name);
+		kh_value(remote_islands, pos) = xcalloc(1, sizeof(struct remote_island));
+	}
+
+	rl = kh_value(remote_islands, pos);
+	oid_array_append(&rl->oids, oid);
+
+	memcpy(&sha_core, oid->hash, sizeof(uint64_t));
+	rl->hash += sha_core;
+}
+
+static int find_island_for_ref(const char *refname, const struct object_id *oid,
+			       int flags, void *data)
+{
+	/*
+	 * We should advertise 'ARRAY_SIZE(matches) - 2' as the max,
+	 * so we can diagnose below a config with more capture groups
+	 * than we support.
+	 */
+	regmatch_t matches[16];
+	int i, m;
+	struct strbuf island_name = STRBUF_INIT;
+
+	/* walk backwards to get last-one-wins ordering */
+	for (i = island_regexes_nr - 1; i >= 0; i--) {
+		if (!regexec(&island_regexes[i], refname,
+			     ARRAY_SIZE(matches), matches, 0))
+			break;
+	}
+
+	if (i < 0)
+		return 0;
+
+	if (matches[ARRAY_SIZE(matches) - 1].rm_so != -1)
+		warning(_("island regex from config has "
+			  "too many capture groups (max=%d)"),
+			(int)ARRAY_SIZE(matches) - 2);
+
+	for (m = 1; m < ARRAY_SIZE(matches); m++) {
+		regmatch_t *match = &matches[m];
+
+		if (match->rm_so == -1)
+			continue;
+
+		if (island_name.len)
+			strbuf_addch(&island_name, '-');
+
+		strbuf_add(&island_name, refname + match->rm_so, match->rm_eo - match->rm_so);
+	}
+
+	add_ref_to_island(island_name.buf, oid);
+	strbuf_release(&island_name);
+	return 0;
+}
+
+static struct remote_island *get_core_island(void)
+{
+	if (core_island_name) {
+		khiter_t pos = kh_get_str(remote_islands, core_island_name);
+		if (pos < kh_end(remote_islands))
+			return kh_value(remote_islands, pos);
+	}
+
+	return NULL;
+}
+
+static void deduplicate_islands(struct repository *r)
+{
+	struct remote_island *island, *core = NULL, **list;
+	unsigned int island_count, dst, src, ref, i = 0;
+
+	island_count = kh_size(remote_islands);
+	ALLOC_ARRAY(list, island_count);
+
+	kh_foreach_value(remote_islands, island, {
+		list[i++] = island;
+	});
+
+	for (ref = 0; ref + 1 < island_count; ref++) {
+		for (src = ref + 1, dst = src; src < island_count; src++) {
+			if (list[ref]->hash == list[src]->hash)
+				continue;
+
+			if (src != dst)
+				list[dst] = list[src];
+
+			dst++;
+		}
+		island_count = dst;
+	}
+
+	island_bitmap_size = (island_count / 32) + 1;
+	core = get_core_island();
+
+	for (i = 0; i < island_count; ++i) {
+		mark_remote_island_1(r, list[i], core && list[i]->hash == core->hash);
+	}
+
+	free(list);
+}
+
+void load_delta_islands(struct repository *r, int progress)
+{
+	island_marks = kh_init_oid_map();
+	remote_islands = kh_init_str();
+
+	git_config(island_config_callback, NULL);
+	for_each_ref(find_island_for_ref, NULL);
+	deduplicate_islands(r);
+
+	if (progress)
+		fprintf(stderr, _("Marked %d islands, done.\n"), island_counter);
+}
+
+void propagate_island_marks(struct commit *commit)
+{
+	khiter_t pos = kh_get_oid_map(island_marks, commit->object.oid);
+
+	if (pos < kh_end(island_marks)) {
+		struct commit_list *p;
+		struct island_bitmap *root_marks = kh_value(island_marks, pos);
+
+		parse_commit(commit);
+		set_island_marks(&get_commit_tree(commit)->object, root_marks);
+		for (p = commit->parents; p; p = p->next)
+			set_island_marks(&p->item->object, root_marks);
+	}
+}
+
+int compute_pack_layers(struct packing_data *to_pack)
+{
+	uint32_t i;
+
+	if (!core_island_name || !island_marks)
+		return 1;
+
+	for (i = 0; i < to_pack->nr_objects; ++i) {
+		struct object_entry *entry = &to_pack->objects[i];
+		khiter_t pos = kh_get_oid_map(island_marks, entry->idx.oid);
+
+		oe_set_layer(to_pack, entry, 1);
+
+		if (pos < kh_end(island_marks)) {
+			struct island_bitmap *bitmap = kh_value(island_marks, pos);
+
+			if (island_bitmap_get(bitmap, island_counter_core))
+				oe_set_layer(to_pack, entry, 0);
+		}
+	}
+
+	return 2;
+}
diff -pruN 1.2.1+git2.18.0-1/git/delta-islands.h 1.2.3+git2.25.1-1/git/delta-islands.h
--- 1.2.1+git2.18.0-1/git/delta-islands.h	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/delta-islands.h	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,18 @@
+#ifndef DELTA_ISLANDS_H
+#define DELTA_ISLANDS_H
+
+struct commit;
+struct object_id;
+struct packing_data;
+struct repository;
+
+int island_delta_cmp(const struct object_id *a, const struct object_id *b);
+int in_same_island(const struct object_id *, const struct object_id *);
+void resolve_tree_islands(struct repository *r,
+			  int progress,
+			  struct packing_data *to_pack);
+void load_delta_islands(struct repository *r, int progress);
+void propagate_island_marks(struct commit *commit);
+int compute_pack_layers(struct packing_data *to_pack);
+
+#endif /* DELTA_ISLANDS_H */
diff -pruN 1.2.1+git2.18.0-1/git/diff.c 1.2.3+git2.25.1-1/git/diff.c
--- 1.2.1+git2.18.0-1/git/diff.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/diff.c	2020-02-17 04:47:35.000000000 +0000
@@ -13,6 +13,7 @@
 #include "attr.h"
 #include "run-command.h"
 #include "utf8.h"
+#include "object-store.h"
 #include "userdiff.h"
 #include "submodule-config.h"
 #include "submodule.h"
@@ -22,6 +23,9 @@
 #include "argv-array.h"
 #include "graph.h"
 #include "packfile.h"
+#include "parse-options.h"
+#include "help.h"
+#include "promisor-remote.h"
 
 #ifdef NO_FAST_WORKING_DIRECTORY
 #define FAST_WORKING_DIRECTORY 0
@@ -35,6 +39,7 @@ static int diff_rename_limit_default = 4
 static int diff_suppress_blank_empty;
 static int diff_use_color_default = -1;
 static int diff_color_moved_default;
+static int diff_color_moved_ws_default;
 static int diff_context_default = 3;
 static int diff_interhunk_context_default;
 static const char *diff_word_regex_cfg;
@@ -67,48 +72,46 @@ static char diff_colors[][COLOR_MAXLEN]
 	GIT_COLOR_BOLD_YELLOW,	/* NEW_MOVED ALTERNATIVE */
 	GIT_COLOR_FAINT,	/* NEW_MOVED_DIM */
 	GIT_COLOR_FAINT_ITALIC,	/* NEW_MOVED_ALTERNATIVE_DIM */
+	GIT_COLOR_FAINT,	/* CONTEXT_DIM */
+	GIT_COLOR_FAINT_RED,	/* OLD_DIM */
+	GIT_COLOR_FAINT_GREEN,	/* NEW_DIM */
+	GIT_COLOR_BOLD,		/* CONTEXT_BOLD */
+	GIT_COLOR_BOLD_RED,	/* OLD_BOLD */
+	GIT_COLOR_BOLD_GREEN,	/* NEW_BOLD */
 };
 
-static NORETURN void die_want_option(const char *option_name)
-{
-	die(_("option '%s' requires a value"), option_name);
-}
+static const char *color_diff_slots[] = {
+	[DIFF_CONTEXT]		      = "context",
+	[DIFF_METAINFO]		      = "meta",
+	[DIFF_FRAGINFO]		      = "frag",
+	[DIFF_FILE_OLD]		      = "old",
+	[DIFF_FILE_NEW]		      = "new",
+	[DIFF_COMMIT]		      = "commit",
+	[DIFF_WHITESPACE]	      = "whitespace",
+	[DIFF_FUNCINFO]		      = "func",
+	[DIFF_FILE_OLD_MOVED]	      = "oldMoved",
+	[DIFF_FILE_OLD_MOVED_ALT]     = "oldMovedAlternative",
+	[DIFF_FILE_OLD_MOVED_DIM]     = "oldMovedDimmed",
+	[DIFF_FILE_OLD_MOVED_ALT_DIM] = "oldMovedAlternativeDimmed",
+	[DIFF_FILE_NEW_MOVED]	      = "newMoved",
+	[DIFF_FILE_NEW_MOVED_ALT]     = "newMovedAlternative",
+	[DIFF_FILE_NEW_MOVED_DIM]     = "newMovedDimmed",
+	[DIFF_FILE_NEW_MOVED_ALT_DIM] = "newMovedAlternativeDimmed",
+	[DIFF_CONTEXT_DIM]	      = "contextDimmed",
+	[DIFF_FILE_OLD_DIM]	      = "oldDimmed",
+	[DIFF_FILE_NEW_DIM]	      = "newDimmed",
+	[DIFF_CONTEXT_BOLD]	      = "contextBold",
+	[DIFF_FILE_OLD_BOLD]	      = "oldBold",
+	[DIFF_FILE_NEW_BOLD]	      = "newBold",
+};
+
+define_list_config_array_extra(color_diff_slots, {"plain"});
 
 static int parse_diff_color_slot(const char *var)
 {
-	if (!strcasecmp(var, "context") || !strcasecmp(var, "plain"))
+	if (!strcasecmp(var, "plain"))
 		return DIFF_CONTEXT;
-	if (!strcasecmp(var, "meta"))
-		return DIFF_METAINFO;
-	if (!strcasecmp(var, "frag"))
-		return DIFF_FRAGINFO;
-	if (!strcasecmp(var, "old"))
-		return DIFF_FILE_OLD;
-	if (!strcasecmp(var, "new"))
-		return DIFF_FILE_NEW;
-	if (!strcasecmp(var, "commit"))
-		return DIFF_COMMIT;
-	if (!strcasecmp(var, "whitespace"))
-		return DIFF_WHITESPACE;
-	if (!strcasecmp(var, "func"))
-		return DIFF_FUNCINFO;
-	if (!strcasecmp(var, "oldmoved"))
-		return DIFF_FILE_OLD_MOVED;
-	if (!strcasecmp(var, "oldmovedalternative"))
-		return DIFF_FILE_OLD_MOVED_ALT;
-	if (!strcasecmp(var, "oldmoveddimmed"))
-		return DIFF_FILE_OLD_MOVED_DIM;
-	if (!strcasecmp(var, "oldmovedalternativedimmed"))
-		return DIFF_FILE_OLD_MOVED_ALT_DIM;
-	if (!strcasecmp(var, "newmoved"))
-		return DIFF_FILE_NEW_MOVED;
-	if (!strcasecmp(var, "newmovedalternative"))
-		return DIFF_FILE_NEW_MOVED_ALT;
-	if (!strcasecmp(var, "newmoveddimmed"))
-		return DIFF_FILE_NEW_MOVED_DIM;
-	if (!strcasecmp(var, "newmovedalternativedimmed"))
-		return DIFF_FILE_NEW_MOVED_ALT_DIM;
-	return -1;
+	return LOOKUP_CONFIG(color_diff_slots, var);
 }
 
 static int parse_dirstat_params(struct diff_options *options, const char *params_string,
@@ -172,6 +175,10 @@ static int parse_submodule_params(struct
 		options->submodule_format = DIFF_SUBMODULE_SHORT;
 	else if (!strcmp(value, "diff"))
 		options->submodule_format = DIFF_SUBMODULE_INLINE_DIFF;
+	/*
+	 * Please update $__git_diff_submodule_formats in
+	 * git-completion.bash when you add new formats.
+	 */
 	else
 		return -1;
 	return 0;
@@ -198,6 +205,10 @@ long parse_algorithm_value(const char *v
 		return XDF_PATIENCE_DIFF;
 	else if (!strcasecmp(value, "histogram"))
 		return XDF_HISTOGRAM_DIFF;
+	/*
+	 * Please update $__git_diff_algorithms in git-completion.bash
+	 * when you add new algorithms.
+	 */
 	return -1;
 }
 
@@ -271,14 +282,60 @@ static int parse_color_moved(const char
 		return COLOR_MOVED_NO;
 	else if (!strcmp(arg, "plain"))
 		return COLOR_MOVED_PLAIN;
+	else if (!strcmp(arg, "blocks"))
+		return COLOR_MOVED_BLOCKS;
 	else if (!strcmp(arg, "zebra"))
 		return COLOR_MOVED_ZEBRA;
 	else if (!strcmp(arg, "default"))
 		return COLOR_MOVED_DEFAULT;
+	else if (!strcmp(arg, "dimmed-zebra"))
+		return COLOR_MOVED_ZEBRA_DIM;
 	else if (!strcmp(arg, "dimmed_zebra"))
 		return COLOR_MOVED_ZEBRA_DIM;
 	else
-		return error(_("color moved setting must be one of 'no', 'default', 'zebra', 'dimmed_zebra', 'plain'"));
+		return error(_("color moved setting must be one of 'no', 'default', 'blocks', 'zebra', 'dimmed-zebra', 'plain'"));
+}
+
+static unsigned parse_color_moved_ws(const char *arg)
+{
+	int ret = 0;
+	struct string_list l = STRING_LIST_INIT_DUP;
+	struct string_list_item *i;
+
+	string_list_split(&l, arg, ',', -1);
+
+	for_each_string_list_item(i, &l) {
+		struct strbuf sb = STRBUF_INIT;
+		strbuf_addstr(&sb, i->string);
+		strbuf_trim(&sb);
+
+		if (!strcmp(sb.buf, "no"))
+			ret = 0;
+		else if (!strcmp(sb.buf, "ignore-space-change"))
+			ret |= XDF_IGNORE_WHITESPACE_CHANGE;
+		else if (!strcmp(sb.buf, "ignore-space-at-eol"))
+			ret |= XDF_IGNORE_WHITESPACE_AT_EOL;
+		else if (!strcmp(sb.buf, "ignore-all-space"))
+			ret |= XDF_IGNORE_WHITESPACE;
+		else if (!strcmp(sb.buf, "allow-indentation-change"))
+			ret |= COLOR_MOVED_WS_ALLOW_INDENTATION_CHANGE;
+		else {
+			ret |= COLOR_MOVED_WS_ERROR;
+			error(_("unknown color-moved-ws mode '%s', possible values are 'ignore-space-change', 'ignore-space-at-eol', 'ignore-all-space', 'allow-indentation-change'"), sb.buf);
+		}
+
+		strbuf_release(&sb);
+	}
+
+	if ((ret & COLOR_MOVED_WS_ALLOW_INDENTATION_CHANGE) &&
+	    (ret & XDF_WHITESPACE_FLAGS)) {
+		error(_("color-moved-ws: allow-indentation-change cannot be combined with other whitespace modes"));
+		ret |= COLOR_MOVED_WS_ERROR;
+	}
+
+	string_list_clear(&l, 0);
+
+	return ret;
 }
 
 int git_diff_ui_config(const char *var, const char *value, void *cb)
@@ -294,6 +351,13 @@ int git_diff_ui_config(const char *var,
 		diff_color_moved_default = cm;
 		return 0;
 	}
+	if (!strcmp(var, "diff.colormovedws")) {
+		unsigned cm = parse_color_moved_ws(value);
+		if (cm & COLOR_MOVED_WS_ERROR)
+			return -1;
+		diff_color_moved_ws_default = cm;
+		return 0;
+	}
 	if (!strcmp(var, "diff.context")) {
 		diff_context_default = git_config_int(var, value);
 		if (diff_context_default < 0)
@@ -436,7 +500,7 @@ static const char *external_diff(void)
 
 	if (done_preparing)
 		return external_diff_cmd;
-	external_diff_cmd = getenv("GIT_EXTERNAL_DIFF");
+	external_diff_cmd = xstrdup_or_null(getenv("GIT_EXTERNAL_DIFF"));
 	if (!external_diff_cmd)
 		external_diff_cmd = external_diff_cmd_cfg;
 	done_preparing = 1;
@@ -501,14 +565,15 @@ static int count_lines(const char *data,
 	return count;
 }
 
-static int fill_mmfile(mmfile_t *mf, struct diff_filespec *one)
+static int fill_mmfile(struct repository *r, mmfile_t *mf,
+		       struct diff_filespec *one)
 {
 	if (!DIFF_FILE_VALID(one)) {
 		mf->ptr = (char *)""; /* does not matter */
 		mf->size = 0;
 		return 0;
 	}
-	else if (diff_populate_filespec(one, 0))
+	else if (diff_populate_filespec(r, one, 0))
 		return -1;
 
 	mf->ptr = one->data;
@@ -517,11 +582,12 @@ static int fill_mmfile(mmfile_t *mf, str
 }
 
 /* like fill_mmfile, but only for size, so we can avoid retrieving blob */
-static unsigned long diff_filespec_size(struct diff_filespec *one)
+static unsigned long diff_filespec_size(struct repository *r,
+					struct diff_filespec *one)
 {
 	if (!DIFF_FILE_VALID(one))
 		return 0;
-	diff_populate_filespec(one, CHECK_SIZE_ONLY);
+	diff_populate_filespec(r, one, CHECK_SIZE_ONLY);
 	return one->size;
 }
 
@@ -570,37 +636,55 @@ static void check_blank_at_eof(mmfile_t
 	ecbdata->blank_at_eof_in_postimage = (at - l2) + 1;
 }
 
-static void emit_line_0(struct diff_options *o, const char *set, const char *reset,
+static void emit_line_0(struct diff_options *o,
+			const char *set_sign, const char *set, unsigned reverse, const char *reset,
 			int first, const char *line, int len)
 {
 	int has_trailing_newline, has_trailing_carriage_return;
-	int nofirst;
+	int needs_reset = 0; /* at the end of the line */
 	FILE *file = o->file;
 
 	fputs(diff_line_prefix(o), file);
 
-	if (len == 0) {
-		has_trailing_newline = (first == '\n');
-		has_trailing_carriage_return = (!has_trailing_newline &&
-						(first == '\r'));
-		nofirst = has_trailing_newline || has_trailing_carriage_return;
-	} else {
-		has_trailing_newline = (len > 0 && line[len-1] == '\n');
-		if (has_trailing_newline)
-			len--;
-		has_trailing_carriage_return = (len > 0 && line[len-1] == '\r');
-		if (has_trailing_carriage_return)
-			len--;
-		nofirst = 0;
+	has_trailing_newline = (len > 0 && line[len-1] == '\n');
+	if (has_trailing_newline)
+		len--;
+
+	has_trailing_carriage_return = (len > 0 && line[len-1] == '\r');
+	if (has_trailing_carriage_return)
+		len--;
+
+	if (!len && !first)
+		goto end_of_line;
+
+	if (reverse && want_color(o->use_color)) {
+		fputs(GIT_COLOR_REVERSE, file);
+		needs_reset = 1;
 	}
 
-	if (len || !nofirst) {
+	if (set_sign) {
+		fputs(set_sign, file);
+		needs_reset = 1;
+	}
+
+	if (first)
+		fputc(first, file);
+
+	if (!len)
+		goto end_of_line;
+
+	if (set) {
+		if (set_sign && set != set_sign)
+			fputs(reset, file);
 		fputs(set, file);
-		if (!nofirst)
-			fputc(first, file);
-		fwrite(line, len, 1, file);
-		fputs(reset, file);
+		needs_reset = 1;
 	}
+	fwrite(line, len, 1, file);
+	needs_reset = 1; /* 'line' may contain color codes. */
+
+end_of_line:
+	if (needs_reset)
+		fputs(reset, file);
 	if (has_trailing_carriage_return)
 		fputc('\r', file);
 	if (has_trailing_newline)
@@ -610,7 +694,7 @@ static void emit_line_0(struct diff_opti
 static void emit_line(struct diff_options *o, const char *set, const char *reset,
 		      const char *line, int len)
 {
-	emit_line_0(o, set, reset, line[0], line+1, len-1);
+	emit_line_0(o, set, NULL, 0, reset, 0, line, len);
 }
 
 enum diff_symbol {
@@ -677,6 +761,8 @@ struct emitted_diff_symbol {
 	const char *line;
 	int len;
 	int flags;
+	int indent_off;   /* Offset to first non-whitespace character */
+	int indent_width; /* The visual width of the indentation */
 	enum diff_symbol s;
 };
 #define EMITTED_DIFF_SYMBOL_INIT {NULL}
@@ -707,14 +793,171 @@ struct moved_entry {
 	struct moved_entry *next_line;
 };
 
-static int moved_entry_cmp(const struct diff_options *diffopt,
-			   const struct moved_entry *a,
-			   const struct moved_entry *b,
+struct moved_block {
+	struct moved_entry *match;
+	int wsd; /* The whitespace delta of this block */
+};
+
+static void moved_block_clear(struct moved_block *b)
+{
+	memset(b, 0, sizeof(*b));
+}
+
+#define INDENT_BLANKLINE INT_MIN
+
+static void fill_es_indent_data(struct emitted_diff_symbol *es)
+{
+	unsigned int off = 0, i;
+	int width = 0, tab_width = es->flags & WS_TAB_WIDTH_MASK;
+	const char *s = es->line;
+	const int len = es->len;
+
+	/* skip any \v \f \r at start of indentation */
+	while (s[off] == '\f' || s[off] == '\v' ||
+	       (s[off] == '\r' && off < len - 1))
+		off++;
+
+	/* calculate the visual width of indentation */
+	while(1) {
+		if (s[off] == ' ') {
+			width++;
+			off++;
+		} else if (s[off] == '\t') {
+			width += tab_width - (width % tab_width);
+			while (s[++off] == '\t')
+				width += tab_width;
+		} else {
+			break;
+		}
+	}
+
+	/* check if this line is blank */
+	for (i = off; i < len; i++)
+		if (!isspace(s[i]))
+		    break;
+
+	if (i == len) {
+		es->indent_width = INDENT_BLANKLINE;
+		es->indent_off = len;
+	} else {
+		es->indent_off = off;
+		es->indent_width = width;
+	}
+}
+
+static int compute_ws_delta(const struct emitted_diff_symbol *a,
+			    const struct emitted_diff_symbol *b,
+			    int *out)
+{
+	int a_len = a->len,
+	    b_len = b->len,
+	    a_off = a->indent_off,
+	    a_width = a->indent_width,
+	    b_off = b->indent_off,
+	    b_width = b->indent_width;
+	int delta;
+
+	if (a_width == INDENT_BLANKLINE && b_width == INDENT_BLANKLINE) {
+		*out = INDENT_BLANKLINE;
+		return 1;
+	}
+
+	if (a->s == DIFF_SYMBOL_PLUS)
+		delta = a_width - b_width;
+	else
+		delta = b_width - a_width;
+
+	if (a_len - a_off != b_len - b_off ||
+	    memcmp(a->line + a_off, b->line + b_off, a_len - a_off))
+		return 0;
+
+	*out = delta;
+
+	return 1;
+}
+
+static int cmp_in_block_with_wsd(const struct diff_options *o,
+				 const struct moved_entry *cur,
+				 const struct moved_entry *match,
+				 struct moved_block *pmb,
+				 int n)
+{
+	struct emitted_diff_symbol *l = &o->emitted_symbols->buf[n];
+	int al = cur->es->len, bl = match->es->len, cl = l->len;
+	const char *a = cur->es->line,
+		   *b = match->es->line,
+		   *c = l->line;
+	int a_off = cur->es->indent_off,
+	    a_width = cur->es->indent_width,
+	    c_off = l->indent_off,
+	    c_width = l->indent_width;
+	int delta;
+
+	/*
+	 * We need to check if 'cur' is equal to 'match'.  As those
+	 * are from the same (+/-) side, we do not need to adjust for
+	 * indent changes. However these were found using fuzzy
+	 * matching so we do have to check if they are equal. Here we
+	 * just check the lengths. We delay calling memcmp() to check
+	 * the contents until later as if the length comparison for a
+	 * and c fails we can avoid the call all together.
+	 */
+	if (al != bl)
+		return 1;
+
+	/* If 'l' and 'cur' are both blank then they match. */
+	if (a_width == INDENT_BLANKLINE && c_width == INDENT_BLANKLINE)
+		return 0;
+
+	/*
+	 * The indent changes of the block are known and stored in pmb->wsd;
+	 * however we need to check if the indent changes of the current line
+	 * match those of the current block and that the text of 'l' and 'cur'
+	 * after the indentation match.
+	 */
+	if (cur->es->s == DIFF_SYMBOL_PLUS)
+		delta = a_width - c_width;
+	else
+		delta = c_width - a_width;
+
+	/*
+	 * If the previous lines of this block were all blank then set its
+	 * whitespace delta.
+	 */
+	if (pmb->wsd == INDENT_BLANKLINE)
+		pmb->wsd = delta;
+
+	return !(delta == pmb->wsd && al - a_off == cl - c_off &&
+		 !memcmp(a, b, al) && !
+		 memcmp(a + a_off, c + c_off, al - a_off));
+}
+
+static int moved_entry_cmp(const void *hashmap_cmp_fn_data,
+			   const struct hashmap_entry *eptr,
+			   const struct hashmap_entry *entry_or_key,
 			   const void *keydata)
 {
+	const struct diff_options *diffopt = hashmap_cmp_fn_data;
+	const struct moved_entry *a, *b;
+	unsigned flags = diffopt->color_moved_ws_handling
+			 & XDF_WHITESPACE_FLAGS;
+
+	a = container_of(eptr, const struct moved_entry, ent);
+	b = container_of(entry_or_key, const struct moved_entry, ent);
+
+	if (diffopt->color_moved_ws_handling &
+	    COLOR_MOVED_WS_ALLOW_INDENTATION_CHANGE)
+		/*
+		 * As there is not specific white space config given,
+		 * we'd need to check for a new block, so ignore all
+		 * white space. The setup of the white space
+		 * configuration for the next block is done else where
+		 */
+		flags |= XDF_IGNORE_WHITESPACE;
+
 	return !xdiff_compare_lines(a->es->line, a->es->len,
 				    b->es->line, b->es->len,
-				    diffopt->xdl_opts);
+				    flags);
 }
 
 static struct moved_entry *prepare_entry(struct diff_options *o,
@@ -722,8 +965,10 @@ static struct moved_entry *prepare_entry
 {
 	struct moved_entry *ret = xmalloc(sizeof(*ret));
 	struct emitted_diff_symbol *l = &o->emitted_symbols->buf[line_no];
+	unsigned flags = o->color_moved_ws_handling & XDF_WHITESPACE_FLAGS;
+	unsigned int hash = xdiff_hash_string(l->line, l->len, flags);
 
-	ret->ent.hash = xdiff_hash_string(l->line, l->len, o->xdl_opts);
+	hashmap_entry_init(&ret->ent, hash);
 	ret->es = l;
 	ret->next_line = NULL;
 
@@ -753,33 +998,88 @@ static void add_lines_to_move_detection(
 			continue;
 		}
 
+		if (o->color_moved_ws_handling &
+		    COLOR_MOVED_WS_ALLOW_INDENTATION_CHANGE)
+			fill_es_indent_data(&o->emitted_symbols->buf[n]);
 		key = prepare_entry(o, n);
 		if (prev_line && prev_line->es->s == o->emitted_symbols->buf[n].s)
 			prev_line->next_line = key;
 
-		hashmap_add(hm, key);
+		hashmap_add(hm, &key->ent);
 		prev_line = key;
 	}
 }
 
-static int shrink_potential_moved_blocks(struct moved_entry **pmb,
+static void pmb_advance_or_null(struct diff_options *o,
+				struct moved_entry *match,
+				struct hashmap *hm,
+				struct moved_block *pmb,
+				int pmb_nr)
+{
+	int i;
+	for (i = 0; i < pmb_nr; i++) {
+		struct moved_entry *prev = pmb[i].match;
+		struct moved_entry *cur = (prev && prev->next_line) ?
+				prev->next_line : NULL;
+		if (cur && !hm->cmpfn(o, &cur->ent, &match->ent, NULL)) {
+			pmb[i].match = cur;
+		} else {
+			pmb[i].match = NULL;
+		}
+	}
+}
+
+static void pmb_advance_or_null_multi_match(struct diff_options *o,
+					    struct moved_entry *match,
+					    struct hashmap *hm,
+					    struct moved_block *pmb,
+					    int pmb_nr, int n)
+{
+	int i;
+	char *got_match = xcalloc(1, pmb_nr);
+
+	hashmap_for_each_entry_from(hm, match, ent) {
+		for (i = 0; i < pmb_nr; i++) {
+			struct moved_entry *prev = pmb[i].match;
+			struct moved_entry *cur = (prev && prev->next_line) ?
+					prev->next_line : NULL;
+			if (!cur)
+				continue;
+			if (!cmp_in_block_with_wsd(o, cur, match, &pmb[i], n))
+				got_match[i] |= 1;
+		}
+	}
+
+	for (i = 0; i < pmb_nr; i++) {
+		if (got_match[i]) {
+			/* Advance to the next line */
+			pmb[i].match = pmb[i].match->next_line;
+		} else {
+			moved_block_clear(&pmb[i]);
+		}
+	}
+
+	free(got_match);
+}
+
+static int shrink_potential_moved_blocks(struct moved_block *pmb,
 					 int pmb_nr)
 {
 	int lp, rp;
 
 	/* Shrink the set of potential block to the remaining running */
 	for (lp = 0, rp = pmb_nr - 1; lp <= rp;) {
-		while (lp < pmb_nr && pmb[lp])
+		while (lp < pmb_nr && pmb[lp].match)
 			lp++;
 		/* lp points at the first NULL now */
 
-		while (rp > -1 && !pmb[rp])
+		while (rp > -1 && !pmb[rp].match)
 			rp--;
 		/* rp points at the last non-NULL */
 
 		if (lp < pmb_nr && rp > -1 && lp < rp) {
 			pmb[lp] = pmb[rp];
-			pmb[rp] = NULL;
+			memset(&pmb[rp], 0, sizeof(pmb[rp]));
 			rp--;
 			lp++;
 		}
@@ -799,14 +1099,17 @@ static int shrink_potential_moved_blocks
  * The last block consists of the (n - block_length)'th line up to but not
  * including the nth line.
  *
+ * Returns 0 if the last block is empty or is unset by this function, non zero
+ * otherwise.
+ *
  * NEEDSWORK: This uses the same heuristic as blame_entry_score() in blame.c.
  * Think of a way to unify them.
  */
-static void adjust_last_block(struct diff_options *o, int n, int block_length)
+static int adjust_last_block(struct diff_options *o, int n, int block_length)
 {
 	int i, alnum_count = 0;
 	if (o->color_moved == COLOR_MOVED_PLAIN)
-		return;
+		return block_length;
 	for (i = 1; i < block_length + 1; i++) {
 		const char *c = o->emitted_symbols->buf[n - i].line;
 		for (; *c; c++) {
@@ -814,11 +1117,12 @@ static void adjust_last_block(struct dif
 				continue;
 			alnum_count++;
 			if (alnum_count >= COLOR_MOVED_MIN_ALNUM_COUNT)
-				return;
+				return 1;
 		}
 	}
 	for (i = 1; i < block_length + 1; i++)
 		o->emitted_symbols->buf[n - i].flags &= ~DIFF_SYMBOL_MOVED_LINE;
+	return 0;
 }
 
 /* Find blocks of moved code, delegate actual coloring decision to helper */
@@ -826,9 +1130,9 @@ static void mark_color_as_moved(struct d
 				struct hashmap *add_lines,
 				struct hashmap *del_lines)
 {
-	struct moved_entry **pmb = NULL; /* potentially moved blocks */
+	struct moved_block *pmb = NULL; /* potentially moved blocks */
 	int pmb_nr = 0, pmb_alloc = 0;
-	int n, flipped_block = 1, block_length = 0;
+	int n, flipped_block = 0, block_length = 0;
 
 
 	for (n = 0; n < o->emitted_symbols->nr; n++) {
@@ -836,49 +1140,50 @@ static void mark_color_as_moved(struct d
 		struct moved_entry *key;
 		struct moved_entry *match = NULL;
 		struct emitted_diff_symbol *l = &o->emitted_symbols->buf[n];
-		int i;
+		enum diff_symbol last_symbol = 0;
 
 		switch (l->s) {
 		case DIFF_SYMBOL_PLUS:
 			hm = del_lines;
 			key = prepare_entry(o, n);
-			match = hashmap_get(hm, key, o);
+			match = hashmap_get_entry(hm, key, ent, NULL);
 			free(key);
 			break;
 		case DIFF_SYMBOL_MINUS:
 			hm = add_lines;
 			key = prepare_entry(o, n);
-			match = hashmap_get(hm, key, o);
+			match = hashmap_get_entry(hm, key, ent, NULL);
 			free(key);
 			break;
 		default:
-			flipped_block = 1;
+			flipped_block = 0;
 		}
 
 		if (!match) {
+			int i;
+
 			adjust_last_block(o, n, block_length);
+			for(i = 0; i < pmb_nr; i++)
+				moved_block_clear(&pmb[i]);
 			pmb_nr = 0;
 			block_length = 0;
+			flipped_block = 0;
+			last_symbol = l->s;
 			continue;
 		}
 
-		l->flags |= DIFF_SYMBOL_MOVED_LINE;
-
-		if (o->color_moved == COLOR_MOVED_PLAIN)
+		if (o->color_moved == COLOR_MOVED_PLAIN) {
+			last_symbol = l->s;
+			l->flags |= DIFF_SYMBOL_MOVED_LINE;
 			continue;
-
-		/* Check any potential block runs, advance each or nullify */
-		for (i = 0; i < pmb_nr; i++) {
-			struct moved_entry *p = pmb[i];
-			struct moved_entry *pnext = (p && p->next_line) ?
-					p->next_line : NULL;
-			if (pnext && !hm->cmpfn(o, pnext, match, NULL)) {
-				pmb[i] = p->next_line;
-			} else {
-				pmb[i] = NULL;
-			}
 		}
 
+		if (o->color_moved_ws_handling &
+		    COLOR_MOVED_WS_ALLOW_INDENTATION_CHANGE)
+			pmb_advance_or_null_multi_match(o, match, hm, pmb, pmb_nr, n);
+		else
+			pmb_advance_or_null(o, match, hm, pmb, pmb_nr);
+
 		pmb_nr = shrink_potential_moved_blocks(pmb, pmb_nr);
 
 		if (pmb_nr == 0) {
@@ -886,24 +1191,40 @@ static void mark_color_as_moved(struct d
 			 * The current line is the start of a new block.
 			 * Setup the set of potential blocks.
 			 */
-			for (; match; match = hashmap_get_next(hm, match)) {
+			hashmap_for_each_entry_from(hm, match, ent) {
 				ALLOC_GROW(pmb, pmb_nr + 1, pmb_alloc);
-				pmb[pmb_nr++] = match;
+				if (o->color_moved_ws_handling &
+				    COLOR_MOVED_WS_ALLOW_INDENTATION_CHANGE) {
+					if (compute_ws_delta(l, match->es,
+							     &pmb[pmb_nr].wsd))
+						pmb[pmb_nr++].match = match;
+				} else {
+					pmb[pmb_nr].wsd = 0;
+					pmb[pmb_nr++].match = match;
+				}
 			}
 
-			flipped_block = (flipped_block + 1) % 2;
+			if (adjust_last_block(o, n, block_length) &&
+			    pmb_nr && last_symbol != l->s)
+				flipped_block = (flipped_block + 1) % 2;
+			else
+				flipped_block = 0;
 
-			adjust_last_block(o, n, block_length);
 			block_length = 0;
 		}
 
-		block_length++;
-
-		if (flipped_block)
-			l->flags |= DIFF_SYMBOL_MOVED_LINE_ALT;
+		if (pmb_nr) {
+			block_length++;
+			l->flags |= DIFF_SYMBOL_MOVED_LINE;
+			if (flipped_block && o->color_moved != COLOR_MOVED_BLOCKS)
+				l->flags |= DIFF_SYMBOL_MOVED_LINE_ALT;
+		}
+		last_symbol = l->s;
 	}
 	adjust_last_block(o, n, block_length);
 
+	for(n = 0; n < pmb_nr; n++)
+		moved_block_clear(&pmb[n]);
 	free(pmb);
 }
 
@@ -969,11 +1290,13 @@ static void dim_moved_lines(struct diff_
 }
 
 static void emit_line_ws_markup(struct diff_options *o,
-				const char *set, const char *reset,
-				const char *line, int len, char sign,
+				const char *set_sign, const char *set,
+				const char *reset,
+				int sign_index, const char *line, int len,
 				unsigned ws_rule, int blank_at_eof)
 {
 	const char *ws = NULL;
+	int sign = o->output_indicators[sign_index];
 
 	if (o->ws_error_highlight & ws_rule) {
 		ws = diff_get_color_opt(o, DIFF_WHITESPACE);
@@ -981,14 +1304,17 @@ static void emit_line_ws_markup(struct d
 			ws = NULL;
 	}
 
-	if (!ws)
-		emit_line_0(o, set, reset, sign, line, len);
-	else if (blank_at_eof)
+	if (!ws && !set_sign)
+		emit_line_0(o, set, NULL, 0, reset, sign, line, len);
+	else if (!ws) {
+		emit_line_0(o, set_sign, set, !!set_sign, reset, sign, line, len);
+	} else if (blank_at_eof)
 		/* Blank line at EOF - paint '+' as well */
-		emit_line_0(o, ws, reset, sign, line, len);
+		emit_line_0(o, ws, NULL, 0, reset, sign, line, len);
 	else {
 		/* Emit just the prefix, then the rest. */
-		emit_line_0(o, set, reset, sign, "", 0);
+		emit_line_0(o, set_sign ? set_sign : set, NULL, !!set_sign, reset,
+			    sign, "", 0);
 		ws_check_emit(line, len, ws_rule,
 			      o->file, set, reset, ws);
 	}
@@ -998,7 +1324,7 @@ static void emit_diff_symbol_from_struct
 					 struct emitted_diff_symbol *eds)
 {
 	static const char *nneof = " No newline at end of file\n";
-	const char *context, *reset, *set, *meta, *fraginfo;
+	const char *context, *reset, *set, *set_sign, *meta, *fraginfo;
 	struct strbuf sb = STRBUF_INIT;
 
 	enum diff_symbol s = eds->s;
@@ -1011,7 +1337,7 @@ static void emit_diff_symbol_from_struct
 		context = diff_get_color_opt(o, DIFF_CONTEXT);
 		reset = diff_get_color_opt(o, DIFF_RESET);
 		putc('\n', o->file);
-		emit_line_0(o, context, reset, '\\',
+		emit_line_0(o, context, NULL, 0, reset, '\\',
 			    nneof, strlen(nneof));
 		break;
 	case DIFF_SYMBOL_SUBMODULE_HEADER:
@@ -1038,7 +1364,19 @@ static void emit_diff_symbol_from_struct
 	case DIFF_SYMBOL_CONTEXT:
 		set = diff_get_color_opt(o, DIFF_CONTEXT);
 		reset = diff_get_color_opt(o, DIFF_RESET);
-		emit_line_ws_markup(o, set, reset, line, len, ' ',
+		set_sign = NULL;
+		if (o->flags.dual_color_diffed_diffs) {
+			char c = !len ? 0 : line[0];
+
+			if (c == '+')
+				set = diff_get_color_opt(o, DIFF_FILE_NEW);
+			else if (c == '@')
+				set = diff_get_color_opt(o, DIFF_FRAGINFO);
+			else if (c == '-')
+				set = diff_get_color_opt(o, DIFF_FILE_OLD);
+		}
+		emit_line_ws_markup(o, set_sign, set, reset,
+				    OUTPUT_INDICATOR_CONTEXT, line, len,
 				    flags & (DIFF_SYMBOL_CONTENT_WS_MASK), 0);
 		break;
 	case DIFF_SYMBOL_PLUS:
@@ -1065,7 +1403,24 @@ static void emit_diff_symbol_from_struct
 			set = diff_get_color_opt(o, DIFF_FILE_NEW);
 		}
 		reset = diff_get_color_opt(o, DIFF_RESET);
-		emit_line_ws_markup(o, set, reset, line, len, '+',
+		if (!o->flags.dual_color_diffed_diffs)
+			set_sign = NULL;
+		else {
+			char c = !len ? 0 : line[0];
+
+			set_sign = set;
+			if (c == '-')
+				set = diff_get_color_opt(o, DIFF_FILE_OLD_BOLD);
+			else if (c == '@')
+				set = diff_get_color_opt(o, DIFF_FRAGINFO);
+			else if (c == '+')
+				set = diff_get_color_opt(o, DIFF_FILE_NEW_BOLD);
+			else
+				set = diff_get_color_opt(o, DIFF_CONTEXT_BOLD);
+			flags &= ~DIFF_SYMBOL_CONTENT_WS_MASK;
+		}
+		emit_line_ws_markup(o, set_sign, set, reset,
+				    OUTPUT_INDICATOR_NEW, line, len,
 				    flags & DIFF_SYMBOL_CONTENT_WS_MASK,
 				    flags & DIFF_SYMBOL_CONTENT_BLANK_LINE_EOF);
 		break;
@@ -1093,7 +1448,23 @@ static void emit_diff_symbol_from_struct
 			set = diff_get_color_opt(o, DIFF_FILE_OLD);
 		}
 		reset = diff_get_color_opt(o, DIFF_RESET);
-		emit_line_ws_markup(o, set, reset, line, len, '-',
+		if (!o->flags.dual_color_diffed_diffs)
+			set_sign = NULL;
+		else {
+			char c = !len ? 0 : line[0];
+
+			set_sign = set;
+			if (c == '+')
+				set = diff_get_color_opt(o, DIFF_FILE_NEW_DIM);
+			else if (c == '@')
+				set = diff_get_color_opt(o, DIFF_FRAGINFO);
+			else if (c == '-')
+				set = diff_get_color_opt(o, DIFF_FILE_OLD_DIM);
+			else
+				set = diff_get_color_opt(o, DIFF_CONTEXT_DIM);
+		}
+		emit_line_ws_markup(o, set_sign, set, reset,
+				    OUTPUT_INDICATOR_OLD, line, len,
 				    flags & DIFF_SYMBOL_CONTENT_WS_MASK, 0);
 		break;
 	case DIFF_SYMBOL_WORDS_PORCELAIN:
@@ -1192,7 +1563,7 @@ static void emit_diff_symbol_from_struct
 static void emit_diff_symbol(struct diff_options *o, enum diff_symbol s,
 			     const char *line, int len, unsigned flags)
 {
-	struct emitted_diff_symbol e = {line, len, flags, s};
+	struct emitted_diff_symbol e = {line, len, flags, 0, 0, s};
 
 	if (o->emitted_symbols)
 		append_emitted_diff_symbol(o, &e);
@@ -1250,8 +1621,7 @@ static int new_blank_line_at_eof(struct
 	return ws_blank_line(line, len, ecbdata->ws_rule);
 }
 
-static void emit_add_line(const char *reset,
-			  struct emit_callback *ecbdata,
+static void emit_add_line(struct emit_callback *ecbdata,
 			  const char *line, int len)
 {
 	unsigned flags = WSEH_NEW | ecbdata->ws_rule;
@@ -1261,16 +1631,14 @@ static void emit_add_line(const char *re
 	emit_diff_symbol(ecbdata->opt, DIFF_SYMBOL_PLUS, line, len, flags);
 }
 
-static void emit_del_line(const char *reset,
-			  struct emit_callback *ecbdata,
+static void emit_del_line(struct emit_callback *ecbdata,
 			  const char *line, int len)
 {
 	unsigned flags = WSEH_OLD | ecbdata->ws_rule;
 	emit_diff_symbol(ecbdata->opt, DIFF_SYMBOL_MINUS, line, len, flags);
 }
 
-static void emit_context_line(const char *reset,
-			      struct emit_callback *ecbdata,
+static void emit_context_line(struct emit_callback *ecbdata,
 			      const char *line, int len)
 {
 	unsigned flags = WSEH_CONTEXT | ecbdata->ws_rule;
@@ -1284,6 +1652,7 @@ static void emit_hunk_header(struct emit
 	const char *frag = diff_get_color(ecbdata->color_diff, DIFF_FRAGINFO);
 	const char *func = diff_get_color(ecbdata->color_diff, DIFF_FUNCINFO);
 	const char *reset = diff_get_color(ecbdata->color_diff, DIFF_RESET);
+	const char *reverse = ecbdata->color_diff ? GIT_COLOR_REVERSE : "";
 	static const char atat[2] = { '@', '@' };
 	const char *cp, *ep;
 	struct strbuf msgbuf = STRBUF_INIT;
@@ -1304,8 +1673,13 @@ static void emit_hunk_header(struct emit
 	ep += 2; /* skip over @@ */
 
 	/* The hunk header in fraginfo color */
+	if (ecbdata->opt->flags.dual_color_diffed_diffs)
+		strbuf_addstr(&msgbuf, reverse);
 	strbuf_addstr(&msgbuf, frag);
-	strbuf_add(&msgbuf, line, ep - line);
+	if (ecbdata->opt->flags.suppress_hunk_header_line_count)
+		strbuf_add(&msgbuf, atat, sizeof(atat));
+	else
+		strbuf_add(&msgbuf, line, ep - line);
 	strbuf_addstr(&msgbuf, reset);
 
 	/*
@@ -1338,7 +1712,8 @@ static void emit_hunk_header(struct emit
 	strbuf_release(&msgbuf);
 }
 
-static struct diff_tempfile *claim_diff_tempfile(void) {
+static struct diff_tempfile *claim_diff_tempfile(void)
+{
 	int i;
 	for (i = 0; i < ARRAY_SIZE(diff_temp); i++)
 		if (!diff_temp[i].name)
@@ -1375,7 +1750,6 @@ static void emit_rewrite_lines(struct em
 			       int prefix, const char *data, int size)
 {
 	const char *endp = NULL;
-	const char *reset = diff_get_color(ecb->color_diff, DIFF_RESET);
 
 	while (0 < size) {
 		int len;
@@ -1384,10 +1758,10 @@ static void emit_rewrite_lines(struct em
 		len = endp ? (endp - data + 1) : size;
 		if (prefix != '+') {
 			ecb->lno_in_preimage++;
-			emit_del_line(reset, ecb, data, len);
+			emit_del_line(ecb, data, len);
 		} else {
 			ecb->lno_in_postimage++;
-			emit_add_line(reset, ecb, data, len);
+			emit_add_line(ecb, data, len);
 		}
 		size -= len;
 		data += len;
@@ -1428,12 +1802,12 @@ static void emit_rewrite_diff(const char
 	quote_two_c_style(&a_name, a_prefix, name_a, 0);
 	quote_two_c_style(&b_name, b_prefix, name_b, 0);
 
-	size_one = fill_textconv(textconv_one, one, &data_one);
-	size_two = fill_textconv(textconv_two, two, &data_two);
+	size_one = fill_textconv(o->repo, textconv_one, one, &data_one);
+	size_two = fill_textconv(o->repo, textconv_two, two, &data_two);
 
 	memset(&ecbdata, 0, sizeof(ecbdata));
 	ecbdata.color_diff = want_color(o->use_color);
-	ecbdata.ws_rule = whitespace_rule(name_b);
+	ecbdata.ws_rule = whitespace_rule(o->repo->index, name_b);
 	ecbdata.opt = o;
 	if (ecbdata.ws_rule & WS_BLANK_AT_EOF) {
 		mmfile_t mf1, mf2;
@@ -1613,19 +1987,17 @@ static int color_words_output_graph_pref
 	}
 }
 
-static void fn_out_diff_words_aux(void *priv, char *line, unsigned long len)
+static void fn_out_diff_words_aux(void *priv,
+				  long minus_first, long minus_len,
+				  long plus_first, long plus_len,
+				  const char *func, long funclen)
 {
 	struct diff_words_data *diff_words = priv;
 	struct diff_words_style *style = diff_words->style;
-	int minus_first, minus_len, plus_first, plus_len;
 	const char *minus_begin, *minus_end, *plus_begin, *plus_end;
 	struct diff_options *opt = diff_words->opt;
 	const char *line_prefix;
 
-	if (line[0] != '@' || parse_hunk_header(line, len,
-			&minus_first, &minus_len, &plus_first, &plus_len))
-		return;
-
 	assert(opt);
 	line_prefix = diff_line_prefix(opt);
 
@@ -1775,8 +2147,8 @@ static void diff_words_show(struct diff_
 	xpp.flags = 0;
 	/* as only the hunk header will be parsed, we need a 0-context */
 	xecfg.ctxlen = 0;
-	if (xdi_diff_outf(&minus, &plus, fn_out_diff_words_aux, diff_words,
-			  &xpp, &xecfg))
+	if (xdi_diff_outf(&minus, &plus, fn_out_diff_words_aux, NULL,
+			  diff_words, &xpp, &xecfg))
 		die("unable to generate word diff");
 	free(minus.ptr);
 	free(plus.ptr);
@@ -1821,23 +2193,25 @@ static void diff_words_flush(struct emit
 	}
 }
 
-static void diff_filespec_load_driver(struct diff_filespec *one)
+static void diff_filespec_load_driver(struct diff_filespec *one,
+				      struct index_state *istate)
 {
 	/* Use already-loaded driver */
 	if (one->driver)
 		return;
 
 	if (S_ISREG(one->mode))
-		one->driver = userdiff_find_by_path(one->path);
+		one->driver = userdiff_find_by_path(istate, one->path);
 
 	/* Fallback to default settings */
 	if (!one->driver)
 		one->driver = userdiff_find_by_name("default");
 }
 
-static const char *userdiff_word_regex(struct diff_filespec *one)
+static const char *userdiff_word_regex(struct diff_filespec *one,
+				       struct index_state *istate)
 {
-	diff_filespec_load_driver(one);
+	diff_filespec_load_driver(one, istate);
 	return one->driver->word_regex;
 }
 
@@ -1860,9 +2234,9 @@ static void init_diff_words_data(struct
 			xcalloc(1, sizeof(struct emitted_diff_symbols));
 
 	if (!o->word_regex)
-		o->word_regex = userdiff_word_regex(one);
+		o->word_regex = userdiff_word_regex(one, o->repo->index);
 	if (!o->word_regex)
-		o->word_regex = userdiff_word_regex(two);
+		o->word_regex = userdiff_word_regex(two, o->repo->index);
 	if (!o->word_regex)
 		o->word_regex = diff_word_regex_cfg;
 	if (o->word_regex) {
@@ -1871,8 +2245,8 @@ static void init_diff_words_data(struct
 		if (regcomp(ecbdata->diff_words->word_regex,
 			    o->word_regex,
 			    REG_EXTENDED | REG_NEWLINE))
-			die ("Invalid regular expression: %s",
-			     o->word_regex);
+			die("invalid regular expression: %s",
+			    o->word_regex);
 	}
 	for (i = 0; i < ARRAY_SIZE(diff_words_styles); i++) {
 		if (o->word_diff == diff_words_styles[i].type) {
@@ -1924,7 +2298,7 @@ const char *diff_line_prefix(struct diff
 	return msgbuf->buf;
 }
 
-static unsigned long sane_truncate_line(struct emit_callback *ecb, char *line, unsigned long len)
+static unsigned long sane_truncate_line(char *line, unsigned long len)
 {
 	const char *cp;
 	unsigned long allot;
@@ -1958,7 +2332,6 @@ static void find_lno(const char *line, s
 static void fn_out_consume(void *priv, char *line, unsigned long len)
 {
 	struct emit_callback *ecbdata = priv;
-	const char *reset = diff_get_color(ecbdata->color_diff, DIFF_RESET);
 	struct diff_options *o = ecbdata->opt;
 
 	o->found_changes = 1;
@@ -1989,7 +2362,7 @@ static void fn_out_consume(void *priv, c
 	if (line[0] == '@') {
 		if (ecbdata->diff_words)
 			diff_words_flush(ecbdata);
-		len = sane_truncate_line(ecbdata, line, len);
+		len = sane_truncate_line(line, len);
 		find_lno(line, ecbdata);
 		emit_hunk_header(ecbdata, line, len);
 		return;
@@ -2025,16 +2398,16 @@ static void fn_out_consume(void *priv, c
 	switch (line[0]) {
 	case '+':
 		ecbdata->lno_in_postimage++;
-		emit_add_line(reset, ecbdata, line + 1, len - 1);
+		emit_add_line(ecbdata, line + 1, len - 1);
 		break;
 	case '-':
 		ecbdata->lno_in_preimage++;
-		emit_del_line(reset, ecbdata, line + 1, len - 1);
+		emit_del_line(ecbdata, line + 1, len - 1);
 		break;
 	case ' ':
 		ecbdata->lno_in_postimage++;
 		ecbdata->lno_in_preimage++;
-		emit_context_line(reset, ecbdata, line + 1, len - 1);
+		emit_context_line(ecbdata, line + 1, len - 1);
 		break;
 	default:
 		/* incomplete line at the end */
@@ -2122,22 +2495,6 @@ static void pprint_rename(struct strbuf
 	}
 }
 
-struct diffstat_t {
-	int nr;
-	int alloc;
-	struct diffstat_file {
-		char *from_name;
-		char *name;
-		char *print_name;
-		const char *comments;
-		unsigned is_unmerged:1;
-		unsigned is_binary:1;
-		unsigned is_renamed:1;
-		unsigned is_interesting:1;
-		uintmax_t added, deleted;
-	} **files;
-};
-
 static struct diffstat_file *diffstat_add(struct diffstat_t *diffstat,
 					  const char *name_a,
 					  const char *name_b)
@@ -2178,7 +2535,7 @@ static int scale_linear(int it, int widt
 	/*
 	 * make sure that at least one '-' or '+' is printed if
 	 * there is any change to this path. The easiest way is to
-	 * scale linearly as if the alloted width is one column shorter
+	 * scale linearly as if the allotted width is one column shorter
 	 * than it is, and then add 1 to the result.
 	 */
 	return 1 + (it * (width - 1) / max_change);
@@ -2663,16 +3020,11 @@ static void show_dirstat(struct diff_opt
 		struct diff_filepair *p = q->queue[i];
 		const char *name;
 		unsigned long copied, added, damage;
-		int content_changed;
 
 		name = p->two->path ? p->two->path : p->one->path;
 
-		if (p->one->oid_valid && p->two->oid_valid)
-			content_changed = oidcmp(&p->one->oid, &p->two->oid);
-		else
-			content_changed = 1;
-
-		if (!content_changed) {
+		if (p->one->oid_valid && p->two->oid_valid &&
+		    oideq(&p->one->oid, &p->two->oid)) {
 			/*
 			 * The SHA1 has not changed, so pre-/post-content is
 			 * identical. We can therefore skip looking at the
@@ -2695,18 +3047,19 @@ static void show_dirstat(struct diff_opt
 		}
 
 		if (DIFF_FILE_VALID(p->one) && DIFF_FILE_VALID(p->two)) {
-			diff_populate_filespec(p->one, 0);
-			diff_populate_filespec(p->two, 0);
-			diffcore_count_changes(p->one, p->two, NULL, NULL,
+			diff_populate_filespec(options->repo, p->one, 0);
+			diff_populate_filespec(options->repo, p->two, 0);
+			diffcore_count_changes(options->repo,
+					       p->one, p->two, NULL, NULL,
 					       &copied, &added);
 			diff_free_filespec_data(p->one);
 			diff_free_filespec_data(p->two);
 		} else if (DIFF_FILE_VALID(p->one)) {
-			diff_populate_filespec(p->one, CHECK_SIZE_ONLY);
+			diff_populate_filespec(options->repo, p->one, CHECK_SIZE_ONLY);
 			copied = added = 0;
 			diff_free_filespec_data(p->one);
 		} else if (DIFF_FILE_VALID(p->two)) {
-			diff_populate_filespec(p->two, CHECK_SIZE_ONLY);
+			diff_populate_filespec(options->repo, p->two, CHECK_SIZE_ONLY);
 			copied = 0;
 			added = p->two->size;
 			diff_free_filespec_data(p->two);
@@ -2719,7 +3072,7 @@ static void show_dirstat(struct diff_opt
 		 * made to the preimage.
 		 * If the resulting damage is zero, we know that
 		 * diffcore_count_changes() considers the two entries to
-		 * be identical, but since content_changed is true, we
+		 * be identical, but since the oid changed, we
 		 * know that there must have been _some_ kind of change,
 		 * so we force all entries to have damage > 0.
 		 */
@@ -2788,7 +3141,7 @@ static void show_dirstat_by_line(struct
 	gather_dirstat(options, &dir, changed, "", 0);
 }
 
-static void free_diffstat_info(struct diffstat_t *diffstat)
+void free_diffstat_info(struct diffstat_t *diffstat)
 {
 	int i;
 	for (i = 0; i < diffstat->nr; i++) {
@@ -2827,12 +3180,21 @@ static int is_conflict_marker(const char
 	for (cnt = 1; cnt < marker_size; cnt++)
 		if (line[cnt] != firstchar)
 			return 0;
-	/* line[1] thru line[marker_size-1] are same as firstchar */
+	/* line[1] through line[marker_size-1] are same as firstchar */
 	if (len < marker_size + 1 || !isspace(line[marker_size]))
 		return 0;
 	return 1;
 }
 
+static void checkdiff_consume_hunk(void *priv,
+				   long ob, long on, long nb, long nn,
+				   const char *func, long funclen)
+
+{
+	struct checkdiff_t *data = priv;
+	data->lineno = nb - 1;
+}
+
 static void checkdiff_consume(void *priv, char *line, unsigned long len)
 {
 	struct checkdiff_t *data = priv;
@@ -2868,12 +3230,6 @@ static void checkdiff_consume(void *priv
 			      data->o->file, set, reset, ws);
 	} else if (line[0] == ' ') {
 		data->lineno++;
-	} else if (line[0] == '@') {
-		char *plus = strchr(line, '+');
-		if (plus)
-			data->lineno = strtol(plus, NULL, 10) - 1;
-		else
-			die("invalid diff");
 	}
 }
 
@@ -2930,7 +3286,7 @@ static void emit_binary_diff_body(struct
 	}
 
 	if (delta && delta_size < deflate_size) {
-		char *s = xstrfmt("%lu", orig_size);
+		char *s = xstrfmt("%"PRIuMAX , (uintmax_t)orig_size);
 		emit_diff_symbol(o, DIFF_SYMBOL_BINARY_DIFF_HEADER_DELTA,
 				 s, strlen(s), 0);
 		free(s);
@@ -2980,15 +3336,16 @@ static void emit_binary_diff(struct diff
 	emit_binary_diff_body(o, two, one);
 }
 
-int diff_filespec_is_binary(struct diff_filespec *one)
+int diff_filespec_is_binary(struct repository *r,
+			    struct diff_filespec *one)
 {
 	if (one->is_binary == -1) {
-		diff_filespec_load_driver(one);
+		diff_filespec_load_driver(one, r->index);
 		if (one->driver->binary != -1)
 			one->is_binary = one->driver->binary;
 		else {
 			if (!one->data && DIFF_FILE_VALID(one))
-				diff_populate_filespec(one, CHECK_BINARY);
+				diff_populate_filespec(r, one, CHECK_BINARY);
 			if (one->is_binary == -1 && one->data)
 				one->is_binary = buffer_is_binary(one->data,
 						one->size);
@@ -2999,9 +3356,10 @@ int diff_filespec_is_binary(struct diff_
 	return one->is_binary;
 }
 
-static const struct userdiff_funcname *diff_funcname_pattern(struct diff_filespec *one)
+static const struct userdiff_funcname *
+diff_funcname_pattern(struct diff_options *o, struct diff_filespec *one)
 {
-	diff_filespec_load_driver(one);
+	diff_filespec_load_driver(one, o->repo->index);
 	return one->driver->funcname.pattern ? &one->driver->funcname : NULL;
 }
 
@@ -3013,13 +3371,14 @@ void diff_set_mnemonic_prefix(struct dif
 		options->b_prefix = b;
 }
 
-struct userdiff_driver *get_textconv(struct diff_filespec *one)
+struct userdiff_driver *get_textconv(struct repository *r,
+				     struct diff_filespec *one)
 {
 	if (!DIFF_FILE_VALID(one))
 		return NULL;
 
-	diff_filespec_load_driver(one);
-	return userdiff_get_textconv(one->driver);
+	diff_filespec_load_driver(one, r->index);
+	return userdiff_get_textconv(r, one->driver);
 }
 
 static void builtin_diff(const char *name_a,
@@ -3068,8 +3427,8 @@ static void builtin_diff(const char *nam
 	}
 
 	if (o->flags.allow_textconv) {
-		textconv_one = get_textconv(one);
-		textconv_two = get_textconv(two);
+		textconv_one = get_textconv(o->repo, one);
+		textconv_two = get_textconv(o->repo, two);
 	}
 
 	/* Never use a non-valid filename anywhere if at all possible */
@@ -3110,13 +3469,13 @@ static void builtin_diff(const char *nam
 		if ((one->mode ^ two->mode) & S_IFMT)
 			goto free_ab_and_return;
 		if (complete_rewrite &&
-		    (textconv_one || !diff_filespec_is_binary(one)) &&
-		    (textconv_two || !diff_filespec_is_binary(two))) {
+		    (textconv_one || !diff_filespec_is_binary(o->repo, one)) &&
+		    (textconv_two || !diff_filespec_is_binary(o->repo, two))) {
 			emit_diff_symbol(o, DIFF_SYMBOL_HEADER,
 					 header.buf, header.len, 0);
 			strbuf_reset(&header);
 			emit_rewrite_diff(name_a, name_b, one, two,
-						textconv_one, textconv_two, o);
+					  textconv_one, textconv_two, o);
 			o->found_changes = 1;
 			goto free_ab_and_return;
 		}
@@ -3128,13 +3487,13 @@ static void builtin_diff(const char *nam
 		strbuf_reset(&header);
 		goto free_ab_and_return;
 	} else if (!o->flags.text &&
-	    ( (!textconv_one && diff_filespec_is_binary(one)) ||
-	      (!textconv_two && diff_filespec_is_binary(two)) )) {
+		   ( (!textconv_one && diff_filespec_is_binary(o->repo, one)) ||
+		     (!textconv_two && diff_filespec_is_binary(o->repo, two)) )) {
 		struct strbuf sb = STRBUF_INIT;
 		if (!one->data && !two->data &&
 		    S_ISREG(one->mode) && S_ISREG(two->mode) &&
 		    !o->flags.binary) {
-			if (!oidcmp(&one->oid, &two->oid)) {
+			if (oideq(&one->oid, &two->oid)) {
 				if (must_show_header)
 					emit_diff_symbol(o, DIFF_SYMBOL_HEADER,
 							 header.buf, header.len,
@@ -3150,7 +3509,8 @@ static void builtin_diff(const char *nam
 			strbuf_release(&sb);
 			goto free_ab_and_return;
 		}
-		if (fill_mmfile(&mf1, one) < 0 || fill_mmfile(&mf2, two) < 0)
+		if (fill_mmfile(o->repo, &mf1, one) < 0 ||
+		    fill_mmfile(o->repo, &mf2, two) < 0)
 			die("unable to read files to diff");
 		/* Quite common confusing case */
 		if (mf1.size == mf2.size &&
@@ -3174,7 +3534,7 @@ static void builtin_diff(const char *nam
 		o->found_changes = 1;
 	} else {
 		/* Crazy xdl interfaces.. */
-		const char *diffopts = getenv("GIT_DIFF_OPTS");
+		const char *diffopts;
 		const char *v;
 		xpparam_t xpp;
 		xdemitconf_t xecfg;
@@ -3187,23 +3547,26 @@ static void builtin_diff(const char *nam
 			strbuf_reset(&header);
 		}
 
-		mf1.size = fill_textconv(textconv_one, one, &mf1.ptr);
-		mf2.size = fill_textconv(textconv_two, two, &mf2.ptr);
+		mf1.size = fill_textconv(o->repo, textconv_one, one, &mf1.ptr);
+		mf2.size = fill_textconv(o->repo, textconv_two, two, &mf2.ptr);
 
-		pe = diff_funcname_pattern(one);
+		pe = diff_funcname_pattern(o, one);
 		if (!pe)
-			pe = diff_funcname_pattern(two);
+			pe = diff_funcname_pattern(o, two);
 
 		memset(&xpp, 0, sizeof(xpp));
 		memset(&xecfg, 0, sizeof(xecfg));
 		memset(&ecbdata, 0, sizeof(ecbdata));
+		if (o->flags.suppress_diff_headers)
+			lbl[0] = NULL;
 		ecbdata.label_path = lbl;
 		ecbdata.color_diff = want_color(o->use_color);
-		ecbdata.ws_rule = whitespace_rule(name_b);
+		ecbdata.ws_rule = whitespace_rule(o->repo->index, name_b);
 		if (ecbdata.ws_rule & WS_BLANK_AT_EOF)
 			check_blank_at_eof(&mf1, &mf2, &ecbdata);
 		ecbdata.opt = o;
-		ecbdata.header = header.len ? &header : NULL;
+		if (header.len && !o->flags.suppress_diff_headers)
+			ecbdata.header = &header;
 		xpp.flags = o->xdl_opts;
 		xpp.anchors = o->anchors;
 		xpp.anchors_nr = o->anchors_nr;
@@ -3214,16 +3577,19 @@ static void builtin_diff(const char *nam
 			xecfg.flags |= XDL_EMIT_FUNCCONTEXT;
 		if (pe)
 			xdiff_set_find_func(&xecfg, pe->pattern, pe->cflags);
+
+		diffopts = getenv("GIT_DIFF_OPTS");
 		if (!diffopts)
 			;
 		else if (skip_prefix(diffopts, "--unified=", &v))
 			xecfg.ctxlen = strtoul(v, NULL, 10);
 		else if (skip_prefix(diffopts, "-u", &v))
 			xecfg.ctxlen = strtoul(v, NULL, 10);
+
 		if (o->word_diff)
 			init_diff_words_data(&ecbdata, o, one, two);
-		if (xdi_diff_outf(&mf1, &mf2, fn_out_consume, &ecbdata,
-				  &xpp, &xecfg))
+		if (xdi_diff_outf(&mf1, &mf2, NULL, fn_out_consume,
+				  &ecbdata, &xpp, &xecfg))
 			die("unable to generate diff for %s", one->path);
 		if (o->word_diff)
 			free_diff_words_data(&ecbdata);
@@ -3296,22 +3662,23 @@ static void builtin_diffstat(const char
 		return;
 	}
 
-	same_contents = !oidcmp(&one->oid, &two->oid);
+	same_contents = oideq(&one->oid, &two->oid);
 
-	if (diff_filespec_is_binary(one) || diff_filespec_is_binary(two)) {
+	if (diff_filespec_is_binary(o->repo, one) ||
+	    diff_filespec_is_binary(o->repo, two)) {
 		data->is_binary = 1;
 		if (same_contents) {
 			data->added = 0;
 			data->deleted = 0;
 		} else {
-			data->added = diff_filespec_size(two);
-			data->deleted = diff_filespec_size(one);
+			data->added = diff_filespec_size(o->repo, two);
+			data->deleted = diff_filespec_size(o->repo, one);
 		}
 	}
 
 	else if (complete_rewrite) {
-		diff_populate_filespec(one, 0);
-		diff_populate_filespec(two, 0);
+		diff_populate_filespec(o->repo, one, 0);
+		diff_populate_filespec(o->repo, two, 0);
 		data->deleted = count_lines(one->data, one->size);
 		data->added = count_lines(two->data, two->size);
 	}
@@ -3321,7 +3688,8 @@ static void builtin_diffstat(const char
 		xpparam_t xpp;
 		xdemitconf_t xecfg;
 
-		if (fill_mmfile(&mf1, one) < 0 || fill_mmfile(&mf2, two) < 0)
+		if (fill_mmfile(o->repo, &mf1, one) < 0 ||
+		    fill_mmfile(o->repo, &mf2, two) < 0)
 			die("unable to read files to diff");
 
 		memset(&xpp, 0, sizeof(xpp));
@@ -3331,8 +3699,8 @@ static void builtin_diffstat(const char
 		xpp.anchors_nr = o->anchors_nr;
 		xecfg.ctxlen = o->context;
 		xecfg.interhunkctxlen = o->interhunkcontext;
-		if (xdi_diff_outf(&mf1, &mf2, diffstat_consume, diffstat,
-				  &xpp, &xecfg))
+		if (xdi_diff_outf(&mf1, &mf2, discard_hunk_line,
+				  diffstat_consume, diffstat, &xpp, &xecfg))
 			die("unable to generate diffstat for %s", one->path);
 	}
 
@@ -3356,10 +3724,11 @@ static void builtin_checkdiff(const char
 	data.filename = name_b ? name_b : name_a;
 	data.lineno = 0;
 	data.o = o;
-	data.ws_rule = whitespace_rule(attr_path);
-	data.conflict_marker_size = ll_merge_marker_size(attr_path);
+	data.ws_rule = whitespace_rule(o->repo->index, attr_path);
+	data.conflict_marker_size = ll_merge_marker_size(o->repo->index, attr_path);
 
-	if (fill_mmfile(&mf1, one) < 0 || fill_mmfile(&mf2, two) < 0)
+	if (fill_mmfile(o->repo, &mf1, one) < 0 ||
+	    fill_mmfile(o->repo, &mf2, two) < 0)
 		die("unable to read files to diff");
 
 	/*
@@ -3368,7 +3737,7 @@ static void builtin_checkdiff(const char
 	 * introduced changes, and as long as the "new" side is text, we
 	 * can and should check what it introduces.
 	 */
-	if (diff_filespec_is_binary(two))
+	if (diff_filespec_is_binary(o->repo, two))
 		goto free_and_return;
 	else {
 		/* Crazy xdl interfaces.. */
@@ -3379,7 +3748,8 @@ static void builtin_checkdiff(const char
 		memset(&xecfg, 0, sizeof(xecfg));
 		xecfg.ctxlen = 1; /* at least one context line */
 		xpp.flags = 0;
-		if (xdi_diff_outf(&mf1, &mf2, checkdiff_consume, &data,
+		if (xdi_diff_outf(&mf1, &mf2, checkdiff_consume_hunk,
+				  checkdiff_consume, &data,
 				  &xpp, &xecfg))
 			die("unable to generate checkdiff for %s", one->path);
 
@@ -3441,7 +3811,10 @@ void fill_filespec(struct diff_filespec
  * the work tree has that object contents, return true, so that
  * prepare_temp_file() does not have to inflate and extract.
  */
-static int reuse_worktree_file(const char *name, const struct object_id *oid, int want_file)
+static int reuse_worktree_file(struct index_state *istate,
+			       const char *name,
+			       const struct object_id *oid,
+			       int want_file)
 {
 	const struct cache_entry *ce;
 	struct stat st;
@@ -3460,7 +3833,7 @@ static int reuse_worktree_file(const cha
 	 * by diff-cache --cached, which does read the cache before
 	 * calling us.
 	 */
-	if (!active_cache)
+	if (!istate->cache)
 		return 0;
 
 	/* We want to avoid the working directory if our caller
@@ -3479,20 +3852,20 @@ static int reuse_worktree_file(const cha
 	 * Similarly, if we'd have to convert the file contents anyway, that
 	 * makes the optimization not worthwhile.
 	 */
-	if (!want_file && would_convert_to_git(&the_index, name))
+	if (!want_file && would_convert_to_git(istate, name))
 		return 0;
 
 	len = strlen(name);
-	pos = cache_name_pos(name, len);
+	pos = index_name_pos(istate, name, len);
 	if (pos < 0)
 		return 0;
-	ce = active_cache[pos];
+	ce = istate->cache[pos];
 
 	/*
 	 * This is not the sha1 we are looking for, or
 	 * unreusable because it is not a regular file.
 	 */
-	if (oidcmp(oid, &ce->oid) || !S_ISREG(ce->ce_mode))
+	if (!oideq(oid, &ce->oid) || !S_ISREG(ce->ce_mode))
 		return 0;
 
 	/*
@@ -3506,7 +3879,7 @@ static int reuse_worktree_file(const cha
 	 * If ce matches the file in the work tree, we can reuse it.
 	 */
 	if (ce_uptodate(ce) ||
-	    (!lstat(name, &st) && !ce_match_stat(ce, &st, 0)))
+	    (!lstat(name, &st) && !ie_match_stat(istate, ce, &st, 0)))
 		return 1;
 
 	return 0;
@@ -3539,7 +3912,9 @@ static int diff_populate_gitlink(struct
  * grab the data for the blob (or file) for our own in-core comparison.
  * diff_filespec has data and size fields for this purpose.
  */
-int diff_populate_filespec(struct diff_filespec *s, unsigned int flags)
+int diff_populate_filespec(struct repository *r,
+			   struct diff_filespec *s,
+			   unsigned int flags)
 {
 	int size_only = flags & CHECK_SIZE_ONLY;
 	int err = 0;
@@ -3566,7 +3941,7 @@ int diff_populate_filespec(struct diff_f
 		return diff_populate_gitlink(s, size_only);
 
 	if (!s->oid_valid ||
-	    reuse_worktree_file(s->path, &s->oid, 0)) {
+	    reuse_worktree_file(r->index, s->path, &s->oid, 0)) {
 		struct strbuf buf = STRBUF_INIT;
 		struct stat st;
 		int fd;
@@ -3599,7 +3974,7 @@ int diff_populate_filespec(struct diff_f
 		 * point if the path requires us to run the content
 		 * conversion.
 		 */
-		if (size_only && !would_convert_to_git(&the_index, s->path))
+		if (size_only && !would_convert_to_git(r->index, s->path))
 			return 0;
 
 		/*
@@ -3626,7 +4001,7 @@ int diff_populate_filespec(struct diff_f
 		/*
 		 * Convert from working tree format to canonical git format
 		 */
-		if (convert_to_git(&the_index, s->path, s->data, s->size, &buf, conv_flags)) {
+		if (convert_to_git(r->index, s->path, s->data, s->size, &buf, conv_flags)) {
 			size_t size = 0;
 			munmap(s->data, s->size);
 			s->should_munmap = 0;
@@ -3638,8 +4013,7 @@ int diff_populate_filespec(struct diff_f
 	else {
 		enum object_type type;
 		if (size_only || (flags & CHECK_BINARY)) {
-			type = oid_object_info(the_repository, &s->oid,
-					       &s->size);
+			type = oid_object_info(r, &s->oid, &s->size);
 			if (type < 0)
 				die("unable to read %s",
 				    oid_to_hex(&s->oid));
@@ -3677,7 +4051,8 @@ void diff_free_filespec_data(struct diff
 	FREE_AND_NULL(s->cnt_data);
 }
 
-static void prep_temp_blob(const char *path, struct diff_tempfile *temp,
+static void prep_temp_blob(struct index_state *istate,
+			   const char *path, struct diff_tempfile *temp,
 			   void *blob,
 			   unsigned long size,
 			   const struct object_id *oid,
@@ -3695,7 +4070,7 @@ static void prep_temp_blob(const char *p
 	temp->tempfile = mks_tempfile_ts(tempfile.buf, strlen(base) + 1);
 	if (!temp->tempfile)
 		die_errno("unable to create temp-file");
-	if (convert_to_working_tree(path,
+	if (convert_to_working_tree(istate, path,
 			(const char *)blob, (size_t)size, &buf)) {
 		blob = buf.buf;
 		size = buf.len;
@@ -3711,8 +4086,9 @@ static void prep_temp_blob(const char *p
 	free(path_dup);
 }
 
-static struct diff_tempfile *prepare_temp_file(const char *name,
-		struct diff_filespec *one)
+static struct diff_tempfile *prepare_temp_file(struct repository *r,
+					       const char *name,
+					       struct diff_filespec *one)
 {
 	struct diff_tempfile *temp = claim_diff_tempfile();
 
@@ -3729,7 +4105,7 @@ static struct diff_tempfile *prepare_tem
 
 	if (!S_ISGITLINK(one->mode) &&
 	    (!one->oid_valid ||
-	     reuse_worktree_file(name, &one->oid, 1))) {
+	     reuse_worktree_file(r->index, name, &one->oid, 1))) {
 		struct stat st;
 		if (lstat(name, &st) < 0) {
 			if (errno == ENOENT)
@@ -3740,7 +4116,7 @@ static struct diff_tempfile *prepare_tem
 			struct strbuf sb = STRBUF_INIT;
 			if (strbuf_readlink(&sb, name, st.st_size) < 0)
 				die_errno("readlink(%s)", name);
-			prep_temp_blob(name, temp, sb.buf, sb.len,
+			prep_temp_blob(r->index, name, temp, sb.buf, sb.len,
 				       (one->oid_valid ?
 					&one->oid : &null_oid),
 				       (one->oid_valid ?
@@ -3765,19 +4141,21 @@ static struct diff_tempfile *prepare_tem
 		return temp;
 	}
 	else {
-		if (diff_populate_filespec(one, 0))
+		if (diff_populate_filespec(r, one, 0))
 			die("cannot read data blob for %s", one->path);
-		prep_temp_blob(name, temp, one->data, one->size,
+		prep_temp_blob(r->index, name, temp,
+			       one->data, one->size,
 			       &one->oid, one->mode);
 	}
 	return temp;
 }
 
-static void add_external_diff_name(struct argv_array *argv,
+static void add_external_diff_name(struct repository *r,
+				   struct argv_array *argv,
 				   const char *name,
 				   struct diff_filespec *df)
 {
-	struct diff_tempfile *temp = prepare_temp_file(name, df);
+	struct diff_tempfile *temp = prepare_temp_file(r, name, df);
 	argv_array_push(argv, temp->name);
 	argv_array_push(argv, temp->hex);
 	argv_array_push(argv, temp->mode);
@@ -3795,7 +4173,6 @@ static void run_external_diff(const char
 			      struct diff_filespec *one,
 			      struct diff_filespec *two,
 			      const char *xfrm_msg,
-			      int complete_rewrite,
 			      struct diff_options *o)
 {
 	struct argv_array argv = ARGV_ARRAY_INIT;
@@ -3806,11 +4183,11 @@ static void run_external_diff(const char
 	argv_array_push(&argv, name);
 
 	if (one && two) {
-		add_external_diff_name(&argv, name, one);
+		add_external_diff_name(o->repo, &argv, name, one);
 		if (!other)
-			add_external_diff_name(&argv, name, two);
+			add_external_diff_name(o->repo, &argv, name, two);
 		else {
-			add_external_diff_name(&argv, other, two);
+			add_external_diff_name(o->repo, &argv, other, two);
 			argv_array_push(&argv, other);
 			argv_array_push(&argv, xfrm_msg);
 		}
@@ -3819,6 +4196,8 @@ static void run_external_diff(const char
 	argv_array_pushf(&env, "GIT_DIFF_PATH_COUNTER=%d", ++o->diff_path_counter);
 	argv_array_pushf(&env, "GIT_DIFF_PATH_TOTAL=%d", q->nr);
 
+	diff_free_filespec_data(one);
+	diff_free_filespec_data(two);
 	if (run_command_v_opt_cd_env(argv.argv, RUN_USING_SHELL, NULL, env.argv))
 		die(_("external diff died, stopping at %s"), name);
 
@@ -3840,7 +4219,7 @@ static const char *diff_abbrev_oid(const
 		char *hex = oid_to_hex(oid);
 		if (abbrev < 0)
 			abbrev = FALLBACK_DEFAULT_ABBREV;
-		if (abbrev > GIT_SHA1_HEXSZ)
+		if (abbrev > the_hash_algo->hexsz)
 			BUG("oid abbreviation out of range: %d", abbrev);
 		if (abbrev)
 			hex[abbrev] = '\0';
@@ -3897,14 +4276,16 @@ static void fill_metainfo(struct strbuf
 	default:
 		*must_show_header = 0;
 	}
-	if (one && two && oidcmp(&one->oid, &two->oid)) {
+	if (one && two && !oideq(&one->oid, &two->oid)) {
 		const unsigned hexsz = the_hash_algo->hexsz;
 		int abbrev = o->flags.full_index ? hexsz : DEFAULT_ABBREV;
 
 		if (o->flags.binary) {
 			mmfile_t mf;
-			if ((!fill_mmfile(&mf, one) && diff_filespec_is_binary(one)) ||
-			    (!fill_mmfile(&mf, two) && diff_filespec_is_binary(two)))
+			if ((!fill_mmfile(o->repo, &mf, one) &&
+			     diff_filespec_is_binary(o->repo, one)) ||
+			    (!fill_mmfile(o->repo, &mf, two) &&
+			     diff_filespec_is_binary(o->repo, two)))
 				abbrev = hexsz;
 		}
 		strbuf_addf(msg, "%s%sindex %s..%s", line_prefix, set,
@@ -3932,7 +4313,9 @@ static void run_diff_cmd(const char *pgm
 
 
 	if (o->flags.allow_external) {
-		struct userdiff_driver *drv = userdiff_find_by_path(attr_path);
+		struct userdiff_driver *drv;
+
+		drv = userdiff_find_by_path(o->repo->index, attr_path);
 		if (drv && drv->external)
 			pgm = drv->external;
 	}
@@ -3949,8 +4332,7 @@ static void run_diff_cmd(const char *pgm
 	}
 
 	if (pgm) {
-		run_external_diff(pgm, name, other, one, two, xfrm_msg,
-				  complete_rewrite, o);
+		run_external_diff(pgm, name, other, one, two, xfrm_msg, o);
 		return;
 	}
 	if (one && two)
@@ -3961,7 +4343,7 @@ static void run_diff_cmd(const char *pgm
 		fprintf(o->file, "* Unmerged path %s\n", name);
 }
 
-static void diff_fill_oid_info(struct diff_filespec *one)
+static void diff_fill_oid_info(struct diff_filespec *one, struct index_state *istate)
 {
 	if (DIFF_FILE_VALID(one)) {
 		if (!one->oid_valid) {
@@ -3972,7 +4354,7 @@ static void diff_fill_oid_info(struct di
 			}
 			if (lstat(one->path, &st) < 0)
 				die_errno("stat '%s'", one->path);
-			if (index_path(&one->oid, one->path, &st, 0))
+			if (index_path(istate, &one->oid, one->path, &st, 0))
 				die("cannot hash %s", one->path);
 		}
 	}
@@ -3983,12 +4365,12 @@ static void diff_fill_oid_info(struct di
 static void strip_prefix(int prefix_length, const char **namep, const char **otherp)
 {
 	/* Strip the prefix but do not molest /dev/null and absolute paths */
-	if (*namep && **namep != '/') {
+	if (*namep && !is_absolute_path(*namep)) {
 		*namep += prefix_length;
 		if (**namep == '/')
 			++*namep;
 	}
-	if (*otherp && **otherp != '/') {
+	if (*otherp && !is_absolute_path(*otherp)) {
 		*otherp += prefix_length;
 		if (**otherp == '/')
 			++*otherp;
@@ -4020,8 +4402,8 @@ static void run_diff(struct diff_filepai
 		return;
 	}
 
-	diff_fill_oid_info(one);
-	diff_fill_oid_info(two);
+	diff_fill_oid_info(one, o->repo->index);
+	diff_fill_oid_info(two, o->repo->index);
 
 	if (!pgm &&
 	    DIFF_FILE_VALID(one) && DIFF_FILE_VALID(two) &&
@@ -4032,7 +4414,8 @@ static void run_diff(struct diff_filepai
 		 */
 		struct diff_filespec *null = alloc_filespec(two->path);
 		run_diff_cmd(NULL, name, other, attr_path,
-			     one, null, &msg, o, p);
+			     one, null, &msg,
+			     o, p);
 		free(null);
 		strbuf_release(&msg);
 
@@ -4056,7 +4439,8 @@ static void run_diffstat(struct diff_fil
 
 	if (DIFF_PAIR_UNMERGED(p)) {
 		/* unmerged */
-		builtin_diffstat(p->one->path, NULL, NULL, NULL, diffstat, o, p);
+		builtin_diffstat(p->one->path, NULL, NULL, NULL,
+				 diffstat, o, p);
 		return;
 	}
 
@@ -4066,10 +4450,11 @@ static void run_diffstat(struct diff_fil
 	if (o->prefix_length)
 		strip_prefix(o->prefix_length, &name, &other);
 
-	diff_fill_oid_info(p->one);
-	diff_fill_oid_info(p->two);
+	diff_fill_oid_info(p->one, o->repo->index);
+	diff_fill_oid_info(p->two, o->repo->index);
 
-	builtin_diffstat(name, other, p->one, p->two, diffstat, o, p);
+	builtin_diffstat(name, other, p->one, p->two,
+			 diffstat, o, p);
 }
 
 static void run_checkdiff(struct diff_filepair *p, struct diff_options *o)
@@ -4090,18 +4475,24 @@ static void run_checkdiff(struct diff_fi
 	if (o->prefix_length)
 		strip_prefix(o->prefix_length, &name, &other);
 
-	diff_fill_oid_info(p->one);
-	diff_fill_oid_info(p->two);
+	diff_fill_oid_info(p->one, o->repo->index);
+	diff_fill_oid_info(p->two, o->repo->index);
 
 	builtin_checkdiff(name, other, attr_path, p->one, p->two, o);
 }
 
-void diff_setup(struct diff_options *options)
+static void prep_parse_options(struct diff_options *options);
+
+void repo_diff_setup(struct repository *r, struct diff_options *options)
 {
 	memcpy(options, &default_diff_options, sizeof(*options));
 
 	options->file = stdout;
+	options->repo = r;
 
+	options->output_indicators[OUTPUT_INDICATOR_NEW] = '+';
+	options->output_indicators[OUTPUT_INDICATOR_OLD] = '-';
+	options->output_indicators[OUTPUT_INDICATOR_CONTEXT] = ' ';
 	options->abbrev = DEFAULT_ABBREV;
 	options->line_termination = '\n';
 	options->break_opt = -1;
@@ -4132,6 +4523,9 @@ void diff_setup(struct diff_options *opt
 	}
 
 	options->color_moved = diff_color_moved_default;
+	options->color_moved_ws_handling = diff_color_moved_ws_default;
+
+	prep_parse_options(options);
 }
 
 void diff_setup_done(struct diff_options *options)
@@ -4215,16 +4609,6 @@ void diff_setup_done(struct diff_options
 
 	if (options->detect_rename && options->rename_limit < 0)
 		options->rename_limit = diff_rename_limit_default;
-	if (options->setup & DIFF_SETUP_USE_CACHE) {
-		if (!active_cache)
-			/* read-cache does not die even when it fails
-			 * so it is safe for us to do this here.  Also
-			 * it does not smudge active_cache or active_nr
-			 * when it fails, so we do not have to worry about
-			 * cleaning it up ourselves either.
-			 */
-			read_cache();
-	}
 	if (hexsz < options->abbrev)
 		options->abbrev = hexsz; /* full */
 
@@ -4245,68 +4629,8 @@ void diff_setup_done(struct diff_options
 
 	if (!options->use_color || external_diff())
 		options->color_moved = 0;
-}
-
-static int opt_arg(const char *arg, int arg_short, const char *arg_long, int *val)
-{
-	char c, *eq;
-	int len;
 
-	if (*arg != '-')
-		return 0;
-	c = *++arg;
-	if (!c)
-		return 0;
-	if (c == arg_short) {
-		c = *++arg;
-		if (!c)
-			return 1;
-		if (val && isdigit(c)) {
-			char *end;
-			int n = strtoul(arg, &end, 10);
-			if (*end)
-				return 0;
-			*val = n;
-			return 1;
-		}
-		return 0;
-	}
-	if (c != '-')
-		return 0;
-	arg++;
-	eq = strchrnul(arg, '=');
-	len = eq - arg;
-	if (!len || strncmp(arg, arg_long, len))
-		return 0;
-	if (*eq) {
-		int n;
-		char *end;
-		if (!isdigit(*++eq))
-			return 0;
-		n = strtoul(eq, &end, 10);
-		if (*end)
-			return 0;
-		*val = n;
-	}
-	return 1;
-}
-
-static int diff_scoreopt_parse(const char *opt);
-
-static inline int short_opt(char opt, const char **argv,
-			    const char **optarg)
-{
-	const char *arg = argv[0];
-	if (arg[0] != '-' || arg[1] != opt)
-		return 0;
-	if (arg[2] != '\0') {
-		*optarg = arg + 2;
-		return 1;
-	}
-	if (!argv[1])
-		die("Option '%c' requires a value", opt);
-	*optarg = argv[1];
-	return 2;
+	FREE_AND_NULL(options->parseopts);
 }
 
 int parse_long_opt(const char *opt, const char **argv,
@@ -4330,77 +4654,56 @@ int parse_long_opt(const char *opt, cons
 	return 2;
 }
 
-static int stat_opt(struct diff_options *options, const char **av)
+static int diff_opt_stat(const struct option *opt, const char *value, int unset)
 {
-	const char *arg = av[0];
-	char *end;
+	struct diff_options *options = opt->value;
 	int width = options->stat_width;
 	int name_width = options->stat_name_width;
 	int graph_width = options->stat_graph_width;
 	int count = options->stat_count;
-	int argcount = 1;
+	char *end;
 
-	if (!skip_prefix(arg, "--stat", &arg))
-		BUG("stat option does not begin with --stat: %s", arg);
-	end = (char *)arg;
+	BUG_ON_OPT_NEG(unset);
 
-	switch (*arg) {
-	case '-':
-		if (skip_prefix(arg, "-width", &arg)) {
-			if (*arg == '=')
-				width = strtoul(arg + 1, &end, 10);
-			else if (!*arg && !av[1])
-				die_want_option("--stat-width");
-			else if (!*arg) {
-				width = strtoul(av[1], &end, 10);
-				argcount = 2;
-			}
-		} else if (skip_prefix(arg, "-name-width", &arg)) {
-			if (*arg == '=')
-				name_width = strtoul(arg + 1, &end, 10);
-			else if (!*arg && !av[1])
-				die_want_option("--stat-name-width");
-			else if (!*arg) {
-				name_width = strtoul(av[1], &end, 10);
-				argcount = 2;
-			}
-		} else if (skip_prefix(arg, "-graph-width", &arg)) {
-			if (*arg == '=')
-				graph_width = strtoul(arg + 1, &end, 10);
-			else if (!*arg && !av[1])
-				die_want_option("--stat-graph-width");
-			else if (!*arg) {
-				graph_width = strtoul(av[1], &end, 10);
-				argcount = 2;
-			}
-		} else if (skip_prefix(arg, "-count", &arg)) {
-			if (*arg == '=')
-				count = strtoul(arg + 1, &end, 10);
-			else if (!*arg && !av[1])
-				die_want_option("--stat-count");
-			else if (!*arg) {
-				count = strtoul(av[1], &end, 10);
-				argcount = 2;
-			}
+	if (!strcmp(opt->long_name, "stat")) {
+		if (value) {
+			width = strtoul(value, &end, 10);
+			if (*end == ',')
+				name_width = strtoul(end+1, &end, 10);
+			if (*end == ',')
+				count = strtoul(end+1, &end, 10);
+			if (*end)
+				return error(_("invalid --stat value: %s"), value);
 		}
-		break;
-	case '=':
-		width = strtoul(arg+1, &end, 10);
-		if (*end == ',')
-			name_width = strtoul(end+1, &end, 10);
-		if (*end == ',')
-			count = strtoul(end+1, &end, 10);
-	}
+	} else if (!strcmp(opt->long_name, "stat-width")) {
+		width = strtoul(value, &end, 10);
+		if (*end)
+			return error(_("%s expects a numerical value"),
+				     opt->long_name);
+	} else if (!strcmp(opt->long_name, "stat-name-width")) {
+		name_width = strtoul(value, &end, 10);
+		if (*end)
+			return error(_("%s expects a numerical value"),
+				     opt->long_name);
+	} else if (!strcmp(opt->long_name, "stat-graph-width")) {
+		graph_width = strtoul(value, &end, 10);
+		if (*end)
+			return error(_("%s expects a numerical value"),
+				     opt->long_name);
+	} else if (!strcmp(opt->long_name, "stat-count")) {
+		count = strtoul(value, &end, 10);
+		if (*end)
+			return error(_("%s expects a numerical value"),
+				     opt->long_name);
+	} else
+		BUG("%s should not get here", opt->long_name);
 
-	/* Important! This checks all the error cases! */
-	if (*end)
-		return 0;
 	options->output_format |= DIFF_FORMAT_DIFFSTAT;
 	options->stat_name_width = name_width;
 	options->stat_graph_width = graph_width;
 	options->stat_width = width;
 	options->stat_count = count;
-	return argcount;
+	return 0;
 }
 
 static int parse_dirstat_opt(struct diff_options *options, const char *params)
@@ -4418,14 +4721,6 @@ static int parse_dirstat_opt(struct diff
 	return 1;
 }
 
-static int parse_submodule_opt(struct diff_options *options, const char *value)
-{
-	if (parse_submodule_params(options, value))
-		die(_("Failed to parse --submodule option parameter: '%s'"),
-			value);
-	return 1;
-}
-
 static const char diff_status_letters[] = {
 	DIFF_STATUS_ADDED,
 	DIFF_STATUS_COPIED,
@@ -4457,10 +4752,19 @@ static unsigned filter_bit_tst(char stat
 	return opt->filter & filter_bit[(int) status];
 }
 
-static int parse_diff_filter_opt(const char *optarg, struct diff_options *opt)
+unsigned diff_filter_bit(char status)
 {
+	prepare_filter_bits();
+	return filter_bit[(int) status];
+}
+
+static int diff_opt_diff_filter(const struct option *option,
+				const char *optarg, int unset)
+{
+	struct diff_options *opt = option->value;
 	int i, optch;
 
+	BUG_ON_OPT_NEG(unset);
 	prepare_filter_bits();
 
 	/*
@@ -4491,7 +4795,8 @@ static int parse_diff_filter_opt(const c
 
 		bit = (0 <= optch && optch <= 'Z') ? filter_bit[optch] : 0;
 		if (!bit)
-			return optarg[i];
+			return error(_("unknown change class '%c' in --diff-filter=%s"),
+				     optarg[i], optarg);
 		if (negate)
 			opt->filter &= ~bit;
 		else
@@ -4500,30 +4805,35 @@ static int parse_diff_filter_opt(const c
 	return 0;
 }
 
-static void enable_patch_output(int *fmt) {
+static void enable_patch_output(int *fmt)
+{
 	*fmt &= ~DIFF_FORMAT_NO_OUTPUT;
 	*fmt |= DIFF_FORMAT_PATCH;
 }
 
-static int parse_ws_error_highlight_opt(struct diff_options *opt, const char *arg)
+static int diff_opt_ws_error_highlight(const struct option *option,
+				       const char *arg, int unset)
 {
+	struct diff_options *opt = option->value;
 	int val = parse_ws_error_highlight(arg);
 
-	if (val < 0) {
-		error("unknown value after ws-error-highlight=%.*s",
-		      -1 - val, arg);
-		return 0;
-	}
+	BUG_ON_OPT_NEG(unset);
+	if (val < 0)
+		return error(_("unknown value after ws-error-highlight=%.*s"),
+			     -1 - val, arg);
 	opt->ws_error_highlight = val;
-	return 1;
+	return 0;
 }
 
-static int parse_objfind_opt(struct diff_options *opt, const char *arg)
+static int diff_opt_find_object(const struct option *option,
+				const char *arg, int unset)
 {
+	struct diff_options *opt = option->value;
 	struct object_id oid;
 
+	BUG_ON_OPT_NEG(unset);
 	if (get_oid(arg, &oid))
-		return error("unable to resolve '%s'", arg);
+		return error(_("unable to resolve '%s'"), arg);
 
 	if (!opt->objfind)
 		opt->objfind = xcalloc(1, sizeof(*opt->objfind));
@@ -4532,194 +4842,384 @@ static int parse_objfind_opt(struct diff
 	opt->flags.recursive = 1;
 	opt->flags.tree_in_recursive = 1;
 	oidset_insert(opt->objfind, &oid);
-	return 1;
+	return 0;
 }
 
-int diff_opt_parse(struct diff_options *options,
-		   const char **av, int ac, const char *prefix)
+static int diff_opt_anchored(const struct option *opt,
+			     const char *arg, int unset)
 {
-	const char *arg = av[0];
-	const char *optarg;
-	int argcount;
+	struct diff_options *options = opt->value;
 
-	if (!prefix)
-		prefix = "";
+	BUG_ON_OPT_NEG(unset);
+	options->xdl_opts = DIFF_WITH_ALG(options, PATIENCE_DIFF);
+	ALLOC_GROW(options->anchors, options->anchors_nr + 1,
+		   options->anchors_alloc);
+	options->anchors[options->anchors_nr++] = xstrdup(arg);
+	return 0;
+}
 
-	/* Output format options */
-	if (!strcmp(arg, "-p") || !strcmp(arg, "-u") || !strcmp(arg, "--patch")
-	    || opt_arg(arg, 'U', "unified", &options->context))
-		enable_patch_output(&options->output_format);
-	else if (!strcmp(arg, "--raw"))
-		options->output_format |= DIFF_FORMAT_RAW;
-	else if (!strcmp(arg, "--patch-with-raw")) {
-		enable_patch_output(&options->output_format);
-		options->output_format |= DIFF_FORMAT_RAW;
-	} else if (!strcmp(arg, "--numstat"))
-		options->output_format |= DIFF_FORMAT_NUMSTAT;
-	else if (!strcmp(arg, "--shortstat"))
-		options->output_format |= DIFF_FORMAT_SHORTSTAT;
-	else if (skip_prefix(arg, "-X", &arg) ||
-		 skip_to_optional_arg(arg, "--dirstat", &arg))
-		return parse_dirstat_opt(options, arg);
-	else if (!strcmp(arg, "--cumulative"))
-		return parse_dirstat_opt(options, "cumulative");
-	else if (skip_to_optional_arg(arg, "--dirstat-by-file", &arg)) {
-		parse_dirstat_opt(options, "files");
-		return parse_dirstat_opt(options, arg);
-	}
-	else if (!strcmp(arg, "--check"))
-		options->output_format |= DIFF_FORMAT_CHECKDIFF;
-	else if (!strcmp(arg, "--summary"))
-		options->output_format |= DIFF_FORMAT_SUMMARY;
-	else if (!strcmp(arg, "--patch-with-stat")) {
-		enable_patch_output(&options->output_format);
-		options->output_format |= DIFF_FORMAT_DIFFSTAT;
-	} else if (!strcmp(arg, "--name-only"))
-		options->output_format |= DIFF_FORMAT_NAME;
-	else if (!strcmp(arg, "--name-status"))
-		options->output_format |= DIFF_FORMAT_NAME_STATUS;
-	else if (!strcmp(arg, "-s") || !strcmp(arg, "--no-patch"))
-		options->output_format |= DIFF_FORMAT_NO_OUTPUT;
-	else if (starts_with(arg, "--stat"))
-		/* --stat, --stat-width, --stat-name-width, or --stat-count */
-		return stat_opt(options, av);
-	else if (!strcmp(arg, "--compact-summary")) {
-		 options->flags.stat_with_summary = 1;
-		 options->output_format |= DIFF_FORMAT_DIFFSTAT;
-	} else if (!strcmp(arg, "--no-compact-summary"))
-		 options->flags.stat_with_summary = 0;
-
-	/* renames options */
-	else if (starts_with(arg, "-B") ||
-		 skip_to_optional_arg(arg, "--break-rewrites", NULL)) {
-		if ((options->break_opt = diff_scoreopt_parse(arg)) == -1)
-			return error("invalid argument to -B: %s", arg+2);
-	}
-	else if (starts_with(arg, "-M") ||
-		 skip_to_optional_arg(arg, "--find-renames", NULL)) {
-		if ((options->rename_score = diff_scoreopt_parse(arg)) == -1)
-			return error("invalid argument to -M: %s", arg+2);
-		options->detect_rename = DIFF_DETECT_RENAME;
-	}
-	else if (!strcmp(arg, "-D") || !strcmp(arg, "--irreversible-delete")) {
-		options->irreversible_delete = 1;
-	}
-	else if (starts_with(arg, "-C") ||
-		 skip_to_optional_arg(arg, "--find-copies", NULL)) {
-		if (options->detect_rename == DIFF_DETECT_COPY)
-			options->flags.find_copies_harder = 1;
-		if ((options->rename_score = diff_scoreopt_parse(arg)) == -1)
-			return error("invalid argument to -C: %s", arg+2);
-		options->detect_rename = DIFF_DETECT_COPY;
-	}
-	else if (!strcmp(arg, "--no-renames"))
-		options->detect_rename = 0;
-	else if (!strcmp(arg, "--rename-empty"))
-		options->flags.rename_empty = 1;
-	else if (!strcmp(arg, "--no-rename-empty"))
-		options->flags.rename_empty = 0;
-	else if (skip_to_optional_arg_default(arg, "--relative", &arg, NULL)) {
-		options->flags.relative_name = 1;
-		if (arg)
-			options->prefix = arg;
+static int diff_opt_binary(const struct option *opt,
+			   const char *arg, int unset)
+{
+	struct diff_options *options = opt->value;
+
+	BUG_ON_OPT_NEG(unset);
+	BUG_ON_OPT_ARG(arg);
+	enable_patch_output(&options->output_format);
+	options->flags.binary = 1;
+	return 0;
+}
+
+static int diff_opt_break_rewrites(const struct option *opt,
+				   const char *arg, int unset)
+{
+	int *break_opt = opt->value;
+	int opt1, opt2;
+
+	BUG_ON_OPT_NEG(unset);
+	if (!arg)
+		arg = "";
+	opt1 = parse_rename_score(&arg);
+	if (*arg == 0)
+		opt2 = 0;
+	else if (*arg != '/')
+		return error(_("%s expects <n>/<m> form"), opt->long_name);
+	else {
+		arg++;
+		opt2 = parse_rename_score(&arg);
 	}
+	if (*arg != 0)
+		return error(_("%s expects <n>/<m> form"), opt->long_name);
+	*break_opt = opt1 | (opt2 << 16);
+	return 0;
+}
 
-	/* xdiff options */
-	else if (!strcmp(arg, "--minimal"))
-		DIFF_XDL_SET(options, NEED_MINIMAL);
-	else if (!strcmp(arg, "--no-minimal"))
-		DIFF_XDL_CLR(options, NEED_MINIMAL);
-	else if (!strcmp(arg, "-w") || !strcmp(arg, "--ignore-all-space"))
-		DIFF_XDL_SET(options, IGNORE_WHITESPACE);
-	else if (!strcmp(arg, "-b") || !strcmp(arg, "--ignore-space-change"))
-		DIFF_XDL_SET(options, IGNORE_WHITESPACE_CHANGE);
-	else if (!strcmp(arg, "--ignore-space-at-eol"))
-		DIFF_XDL_SET(options, IGNORE_WHITESPACE_AT_EOL);
-	else if (!strcmp(arg, "--ignore-cr-at-eol"))
-		DIFF_XDL_SET(options, IGNORE_CR_AT_EOL);
-	else if (!strcmp(arg, "--ignore-blank-lines"))
-		DIFF_XDL_SET(options, IGNORE_BLANK_LINES);
-	else if (!strcmp(arg, "--indent-heuristic"))
-		DIFF_XDL_SET(options, INDENT_HEURISTIC);
-	else if (!strcmp(arg, "--no-indent-heuristic"))
-		DIFF_XDL_CLR(options, INDENT_HEURISTIC);
-	else if (!strcmp(arg, "--patience")) {
-		int i;
-		options->xdl_opts = DIFF_WITH_ALG(options, PATIENCE_DIFF);
-		/*
-		 * Both --patience and --anchored use PATIENCE_DIFF
-		 * internally, so remove any anchors previously
-		 * specified.
-		 */
-		for (i = 0; i < options->anchors_nr; i++)
-			free(options->anchors[i]);
-		options->anchors_nr = 0;
-	} else if (!strcmp(arg, "--histogram"))
-		options->xdl_opts = DIFF_WITH_ALG(options, HISTOGRAM_DIFF);
-	else if ((argcount = parse_long_opt("diff-algorithm", av, &optarg))) {
-		long value = parse_algorithm_value(optarg);
-		if (value < 0)
-			return error("option diff-algorithm accepts \"myers\", "
-				     "\"minimal\", \"patience\" and \"histogram\"");
-		/* clear out previous settings */
-		DIFF_XDL_CLR(options, NEED_MINIMAL);
-		options->xdl_opts &= ~XDF_DIFF_ALGORITHM_MASK;
-		options->xdl_opts |= value;
-		return argcount;
-	} else if (skip_prefix(arg, "--anchored=", &arg)) {
-		options->xdl_opts = DIFF_WITH_ALG(options, PATIENCE_DIFF);
-		ALLOC_GROW(options->anchors, options->anchors_nr + 1,
-			   options->anchors_alloc);
-		options->anchors[options->anchors_nr++] = xstrdup(arg);
-	}
-
-	/* flags options */
-	else if (!strcmp(arg, "--binary")) {
-		enable_patch_output(&options->output_format);
-		options->flags.binary = 1;
-	}
-	else if (!strcmp(arg, "--full-index"))
-		options->flags.full_index = 1;
-	else if (!strcmp(arg, "-a") || !strcmp(arg, "--text"))
-		options->flags.text = 1;
-	else if (!strcmp(arg, "-R"))
-		options->flags.reverse_diff = 1;
-	else if (!strcmp(arg, "--find-copies-harder"))
-		options->flags.find_copies_harder = 1;
-	else if (!strcmp(arg, "--follow"))
-		options->flags.follow_renames = 1;
-	else if (!strcmp(arg, "--no-follow")) {
-		options->flags.follow_renames = 0;
-		options->flags.default_follow_renames = 0;
-	} else if (skip_to_optional_arg_default(arg, "--color", &arg, "always")) {
-		int value = git_config_colorbool(NULL, arg);
-		if (value < 0)
-			return error("option `color' expects \"always\", \"auto\", or \"never\"");
-		options->use_color = value;
-	}
-	else if (!strcmp(arg, "--no-color"))
-		options->use_color = 0;
-	else if (!strcmp(arg, "--color-moved")) {
+static int diff_opt_char(const struct option *opt,
+			 const char *arg, int unset)
+{
+	char *value = opt->value;
+
+	BUG_ON_OPT_NEG(unset);
+	if (arg[1])
+		return error(_("%s expects a character, got '%s'"),
+			     opt->long_name, arg);
+	*value = arg[0];
+	return 0;
+}
+
+static int diff_opt_color_moved(const struct option *opt,
+				const char *arg, int unset)
+{
+	struct diff_options *options = opt->value;
+
+	if (unset) {
+		options->color_moved = COLOR_MOVED_NO;
+	} else if (!arg) {
 		if (diff_color_moved_default)
 			options->color_moved = diff_color_moved_default;
 		if (options->color_moved == COLOR_MOVED_NO)
 			options->color_moved = COLOR_MOVED_DEFAULT;
-	} else if (!strcmp(arg, "--no-color-moved"))
-		options->color_moved = COLOR_MOVED_NO;
-	else if (skip_prefix(arg, "--color-moved=", &arg)) {
+	} else {
 		int cm = parse_color_moved(arg);
 		if (cm < 0)
-			die("bad --color-moved argument: %s", arg);
+			return error(_("bad --color-moved argument: %s"), arg);
 		options->color_moved = cm;
-	} else if (skip_to_optional_arg_default(arg, "--color-words", &options->word_regex, NULL)) {
-		options->use_color = 1;
-		options->word_diff = DIFF_WORDS_COLOR;
 	}
-	else if (!strcmp(arg, "--word-diff")) {
-		if (options->word_diff == DIFF_WORDS_NONE)
-			options->word_diff = DIFF_WORDS_PLAIN;
+	return 0;
+}
+
+static int diff_opt_color_moved_ws(const struct option *opt,
+				   const char *arg, int unset)
+{
+	struct diff_options *options = opt->value;
+	unsigned cm;
+
+	if (unset) {
+		options->color_moved_ws_handling = 0;
+		return 0;
+	}
+
+	cm = parse_color_moved_ws(arg);
+	if (cm & COLOR_MOVED_WS_ERROR)
+		return error(_("invalid mode '%s' in --color-moved-ws"), arg);
+	options->color_moved_ws_handling = cm;
+	return 0;
+}
+
+static int diff_opt_color_words(const struct option *opt,
+				const char *arg, int unset)
+{
+	struct diff_options *options = opt->value;
+
+	BUG_ON_OPT_NEG(unset);
+	options->use_color = 1;
+	options->word_diff = DIFF_WORDS_COLOR;
+	options->word_regex = arg;
+	return 0;
+}
+
+static int diff_opt_compact_summary(const struct option *opt,
+				    const char *arg, int unset)
+{
+	struct diff_options *options = opt->value;
+
+	BUG_ON_OPT_ARG(arg);
+	if (unset) {
+		options->flags.stat_with_summary = 0;
+	} else {
+		options->flags.stat_with_summary = 1;
+		options->output_format |= DIFF_FORMAT_DIFFSTAT;
+	}
+	return 0;
+}
+
+static int diff_opt_diff_algorithm(const struct option *opt,
+				   const char *arg, int unset)
+{
+	struct diff_options *options = opt->value;
+	long value = parse_algorithm_value(arg);
+
+	BUG_ON_OPT_NEG(unset);
+	if (value < 0)
+		return error(_("option diff-algorithm accepts \"myers\", "
+			       "\"minimal\", \"patience\" and \"histogram\""));
+
+	/* clear out previous settings */
+	DIFF_XDL_CLR(options, NEED_MINIMAL);
+	options->xdl_opts &= ~XDF_DIFF_ALGORITHM_MASK;
+	options->xdl_opts |= value;
+	return 0;
+}
+
+static int diff_opt_dirstat(const struct option *opt,
+			    const char *arg, int unset)
+{
+	struct diff_options *options = opt->value;
+
+	BUG_ON_OPT_NEG(unset);
+	if (!strcmp(opt->long_name, "cumulative")) {
+		if (arg)
+			BUG("how come --cumulative take a value?");
+		arg = "cumulative";
+	} else if (!strcmp(opt->long_name, "dirstat-by-file"))
+		parse_dirstat_opt(options, "files");
+	parse_dirstat_opt(options, arg ? arg : "");
+	return 0;
+}
+
+static int diff_opt_find_copies(const struct option *opt,
+				const char *arg, int unset)
+{
+	struct diff_options *options = opt->value;
+
+	BUG_ON_OPT_NEG(unset);
+	if (!arg)
+		arg = "";
+	options->rename_score = parse_rename_score(&arg);
+	if (*arg != 0)
+		return error(_("invalid argument to %s"), opt->long_name);
+
+	if (options->detect_rename == DIFF_DETECT_COPY)
+		options->flags.find_copies_harder = 1;
+	else
+		options->detect_rename = DIFF_DETECT_COPY;
+
+	return 0;
+}
+
+static int diff_opt_find_renames(const struct option *opt,
+				 const char *arg, int unset)
+{
+	struct diff_options *options = opt->value;
+
+	BUG_ON_OPT_NEG(unset);
+	if (!arg)
+		arg = "";
+	options->rename_score = parse_rename_score(&arg);
+	if (*arg != 0)
+		return error(_("invalid argument to %s"), opt->long_name);
+
+	options->detect_rename = DIFF_DETECT_RENAME;
+	return 0;
+}
+
+static int diff_opt_follow(const struct option *opt,
+			   const char *arg, int unset)
+{
+	struct diff_options *options = opt->value;
+
+	BUG_ON_OPT_ARG(arg);
+	if (unset) {
+		options->flags.follow_renames = 0;
+		options->flags.default_follow_renames = 0;
+	} else {
+		options->flags.follow_renames = 1;
+	}
+	return 0;
+}
+
+static int diff_opt_ignore_submodules(const struct option *opt,
+				      const char *arg, int unset)
+{
+	struct diff_options *options = opt->value;
+
+	BUG_ON_OPT_NEG(unset);
+	if (!arg)
+		arg = "all";
+	options->flags.override_submodule_config = 1;
+	handle_ignore_submodules_arg(options, arg);
+	return 0;
+}
+
+static int diff_opt_line_prefix(const struct option *opt,
+				const char *optarg, int unset)
+{
+	struct diff_options *options = opt->value;
+
+	BUG_ON_OPT_NEG(unset);
+	options->line_prefix = optarg;
+	options->line_prefix_length = strlen(options->line_prefix);
+	graph_setup_line_prefix(options);
+	return 0;
+}
+
+static int diff_opt_no_prefix(const struct option *opt,
+			      const char *optarg, int unset)
+{
+	struct diff_options *options = opt->value;
+
+	BUG_ON_OPT_NEG(unset);
+	BUG_ON_OPT_ARG(optarg);
+	options->a_prefix = "";
+	options->b_prefix = "";
+	return 0;
+}
+
+static enum parse_opt_result diff_opt_output(struct parse_opt_ctx_t *ctx,
+					     const struct option *opt,
+					     const char *arg, int unset)
+{
+	struct diff_options *options = opt->value;
+	char *path;
+
+	BUG_ON_OPT_NEG(unset);
+	path = prefix_filename(ctx->prefix, arg);
+	options->file = xfopen(path, "w");
+	options->close_file = 1;
+	if (options->use_color != GIT_COLOR_ALWAYS)
+		options->use_color = GIT_COLOR_NEVER;
+	free(path);
+	return 0;
+}
+
+static int diff_opt_patience(const struct option *opt,
+			     const char *arg, int unset)
+{
+	struct diff_options *options = opt->value;
+	int i;
+
+	BUG_ON_OPT_NEG(unset);
+	BUG_ON_OPT_ARG(arg);
+	options->xdl_opts = DIFF_WITH_ALG(options, PATIENCE_DIFF);
+	/*
+	 * Both --patience and --anchored use PATIENCE_DIFF
+	 * internally, so remove any anchors previously
+	 * specified.
+	 */
+	for (i = 0; i < options->anchors_nr; i++)
+		free(options->anchors[i]);
+	options->anchors_nr = 0;
+	return 0;
+}
+
+static int diff_opt_pickaxe_regex(const struct option *opt,
+				  const char *arg, int unset)
+{
+	struct diff_options *options = opt->value;
+
+	BUG_ON_OPT_NEG(unset);
+	options->pickaxe = arg;
+	options->pickaxe_opts |= DIFF_PICKAXE_KIND_G;
+	return 0;
+}
+
+static int diff_opt_pickaxe_string(const struct option *opt,
+				   const char *arg, int unset)
+{
+	struct diff_options *options = opt->value;
+
+	BUG_ON_OPT_NEG(unset);
+	options->pickaxe = arg;
+	options->pickaxe_opts |= DIFF_PICKAXE_KIND_S;
+	return 0;
+}
+
+static int diff_opt_relative(const struct option *opt,
+			     const char *arg, int unset)
+{
+	struct diff_options *options = opt->value;
+
+	BUG_ON_OPT_NEG(unset);
+	options->flags.relative_name = 1;
+	if (arg)
+		options->prefix = arg;
+	return 0;
+}
+
+static int diff_opt_submodule(const struct option *opt,
+			      const char *arg, int unset)
+{
+	struct diff_options *options = opt->value;
+
+	BUG_ON_OPT_NEG(unset);
+	if (!arg)
+		arg = "log";
+	if (parse_submodule_params(options, arg))
+		return error(_("failed to parse --submodule option parameter: '%s'"),
+			     arg);
+	return 0;
+}
+
+static int diff_opt_textconv(const struct option *opt,
+			     const char *arg, int unset)
+{
+	struct diff_options *options = opt->value;
+
+	BUG_ON_OPT_ARG(arg);
+	if (unset) {
+		options->flags.allow_textconv = 0;
+	} else {
+		options->flags.allow_textconv = 1;
+		options->flags.textconv_set_via_cmdline = 1;
 	}
-	else if (skip_prefix(arg, "--word-diff=", &arg)) {
+	return 0;
+}
+
+static int diff_opt_unified(const struct option *opt,
+			    const char *arg, int unset)
+{
+	struct diff_options *options = opt->value;
+	char *s;
+
+	BUG_ON_OPT_NEG(unset);
+
+	if (arg) {
+		options->context = strtol(arg, &s, 10);
+		if (*s)
+			return error(_("%s expects a numerical value"), "--unified");
+	}
+	enable_patch_output(&options->output_format);
+
+	return 0;
+}
+
+static int diff_opt_word_diff(const struct option *opt,
+			      const char *arg, int unset)
+{
+	struct diff_options *options = opt->value;
+
+	BUG_ON_OPT_NEG(unset);
+	if (arg) {
 		if (!strcmp(arg, "plain"))
 			options->word_diff = DIFF_WORDS_PLAIN;
 		else if (!strcmp(arg, "color")) {
@@ -4731,118 +5231,305 @@ int diff_opt_parse(struct diff_options *
 		else if (!strcmp(arg, "none"))
 			options->word_diff = DIFF_WORDS_NONE;
 		else
-			die("bad --word-diff argument: %s", arg);
-	}
-	else if ((argcount = parse_long_opt("word-diff-regex", av, &optarg))) {
+			return error(_("bad --word-diff argument: %s"), arg);
+	} else {
 		if (options->word_diff == DIFF_WORDS_NONE)
 			options->word_diff = DIFF_WORDS_PLAIN;
-		options->word_regex = optarg;
-		return argcount;
 	}
-	else if (!strcmp(arg, "--exit-code"))
-		options->flags.exit_with_status = 1;
-	else if (!strcmp(arg, "--quiet"))
-		options->flags.quick = 1;
-	else if (!strcmp(arg, "--ext-diff"))
-		options->flags.allow_external = 1;
-	else if (!strcmp(arg, "--no-ext-diff"))
-		options->flags.allow_external = 0;
-	else if (!strcmp(arg, "--textconv")) {
-		options->flags.allow_textconv = 1;
-		options->flags.textconv_set_via_cmdline = 1;
-	} else if (!strcmp(arg, "--no-textconv"))
-		options->flags.allow_textconv = 0;
-	else if (skip_to_optional_arg_default(arg, "--ignore-submodules", &arg, "all")) {
-		options->flags.override_submodule_config = 1;
-		handle_ignore_submodules_arg(options, arg);
-	} else if (skip_to_optional_arg_default(arg, "--submodule", &arg, "log"))
-		return parse_submodule_opt(options, arg);
-	else if (skip_prefix(arg, "--ws-error-highlight=", &arg))
-		return parse_ws_error_highlight_opt(options, arg);
-	else if (!strcmp(arg, "--ita-invisible-in-index"))
-		options->ita_invisible_in_index = 1;
-	else if (!strcmp(arg, "--ita-visible-in-index"))
-		options->ita_invisible_in_index = 0;
-
-	/* misc options */
-	else if (!strcmp(arg, "-z"))
-		options->line_termination = 0;
-	else if ((argcount = short_opt('l', av, &optarg))) {
-		options->rename_limit = strtoul(optarg, NULL, 10);
-		return argcount;
-	}
-	else if ((argcount = short_opt('S', av, &optarg))) {
-		options->pickaxe = optarg;
-		options->pickaxe_opts |= DIFF_PICKAXE_KIND_S;
-		return argcount;
-	} else if ((argcount = short_opt('G', av, &optarg))) {
-		options->pickaxe = optarg;
-		options->pickaxe_opts |= DIFF_PICKAXE_KIND_G;
-		return argcount;
-	}
-	else if (!strcmp(arg, "--pickaxe-all"))
-		options->pickaxe_opts |= DIFF_PICKAXE_ALL;
-	else if (!strcmp(arg, "--pickaxe-regex"))
-		options->pickaxe_opts |= DIFF_PICKAXE_REGEX;
-	else if ((argcount = short_opt('O', av, &optarg))) {
-		options->orderfile = prefix_filename(prefix, optarg);
-		return argcount;
-	} else if (skip_prefix(arg, "--find-object=", &arg))
-		return parse_objfind_opt(options, arg);
-	else if ((argcount = parse_long_opt("diff-filter", av, &optarg))) {
-		int offending = parse_diff_filter_opt(optarg, options);
-		if (offending)
-			die("unknown change class '%c' in --diff-filter=%s",
-			    offending, optarg);
-		return argcount;
-	}
-	else if (!strcmp(arg, "--no-abbrev"))
-		options->abbrev = 0;
-	else if (!strcmp(arg, "--abbrev"))
-		options->abbrev = DEFAULT_ABBREV;
-	else if (skip_prefix(arg, "--abbrev=", &arg)) {
-		options->abbrev = strtoul(arg, NULL, 10);
-		if (options->abbrev < MINIMUM_ABBREV)
-			options->abbrev = MINIMUM_ABBREV;
-		else if (the_hash_algo->hexsz < options->abbrev)
-			options->abbrev = the_hash_algo->hexsz;
-	}
-	else if ((argcount = parse_long_opt("src-prefix", av, &optarg))) {
-		options->a_prefix = optarg;
-		return argcount;
-	}
-	else if ((argcount = parse_long_opt("line-prefix", av, &optarg))) {
-		options->line_prefix = optarg;
-		options->line_prefix_length = strlen(options->line_prefix);
-		graph_setup_line_prefix(options);
-		return argcount;
-	}
-	else if ((argcount = parse_long_opt("dst-prefix", av, &optarg))) {
-		options->b_prefix = optarg;
-		return argcount;
-	}
-	else if (!strcmp(arg, "--no-prefix"))
-		options->a_prefix = options->b_prefix = "";
-	else if (opt_arg(arg, '\0', "inter-hunk-context",
-			 &options->interhunkcontext))
-		;
-	else if (!strcmp(arg, "-W"))
-		options->flags.funccontext = 1;
-	else if (!strcmp(arg, "--function-context"))
-		options->flags.funccontext = 1;
-	else if (!strcmp(arg, "--no-function-context"))
-		options->flags.funccontext = 0;
-	else if ((argcount = parse_long_opt("output", av, &optarg))) {
-		char *path = prefix_filename(prefix, optarg);
-		options->file = xfopen(path, "w");
-		options->close_file = 1;
-		if (options->use_color != GIT_COLOR_ALWAYS)
-			options->use_color = GIT_COLOR_NEVER;
-		free(path);
-		return argcount;
-	} else
-		return 0;
-	return 1;
+	return 0;
+}
+
+static int diff_opt_word_diff_regex(const struct option *opt,
+				    const char *arg, int unset)
+{
+	struct diff_options *options = opt->value;
+
+	BUG_ON_OPT_NEG(unset);
+	if (options->word_diff == DIFF_WORDS_NONE)
+		options->word_diff = DIFF_WORDS_PLAIN;
+	options->word_regex = arg;
+	return 0;
+}
+
+static void prep_parse_options(struct diff_options *options)
+{
+	struct option parseopts[] = {
+		OPT_GROUP(N_("Diff output format options")),
+		OPT_BITOP('p', "patch", &options->output_format,
+			  N_("generate patch"),
+			  DIFF_FORMAT_PATCH, DIFF_FORMAT_NO_OUTPUT),
+		OPT_BIT_F('s', "no-patch", &options->output_format,
+			  N_("suppress diff output"),
+			  DIFF_FORMAT_NO_OUTPUT, PARSE_OPT_NONEG),
+		OPT_BITOP('u', NULL, &options->output_format,
+			  N_("generate patch"),
+			  DIFF_FORMAT_PATCH, DIFF_FORMAT_NO_OUTPUT),
+		OPT_CALLBACK_F('U', "unified", options, N_("<n>"),
+			       N_("generate diffs with <n> lines context"),
+			       PARSE_OPT_NONEG | PARSE_OPT_OPTARG, diff_opt_unified),
+		OPT_BOOL('W', "function-context", &options->flags.funccontext,
+			 N_("generate diffs with <n> lines context")),
+		OPT_BIT_F(0, "raw", &options->output_format,
+			  N_("generate the diff in raw format"),
+			  DIFF_FORMAT_RAW, PARSE_OPT_NONEG),
+		OPT_BITOP(0, "patch-with-raw", &options->output_format,
+			  N_("synonym for '-p --raw'"),
+			  DIFF_FORMAT_PATCH | DIFF_FORMAT_RAW,
+			  DIFF_FORMAT_NO_OUTPUT),
+		OPT_BITOP(0, "patch-with-stat", &options->output_format,
+			  N_("synonym for '-p --stat'"),
+			  DIFF_FORMAT_PATCH | DIFF_FORMAT_DIFFSTAT,
+			  DIFF_FORMAT_NO_OUTPUT),
+		OPT_BIT_F(0, "numstat", &options->output_format,
+			  N_("machine friendly --stat"),
+			  DIFF_FORMAT_NUMSTAT, PARSE_OPT_NONEG),
+		OPT_BIT_F(0, "shortstat", &options->output_format,
+			  N_("output only the last line of --stat"),
+			  DIFF_FORMAT_SHORTSTAT, PARSE_OPT_NONEG),
+		OPT_CALLBACK_F('X', "dirstat", options, N_("<param1,param2>..."),
+			       N_("output the distribution of relative amount of changes for each sub-directory"),
+			       PARSE_OPT_NONEG | PARSE_OPT_OPTARG,
+			       diff_opt_dirstat),
+		OPT_CALLBACK_F(0, "cumulative", options, NULL,
+			       N_("synonym for --dirstat=cumulative"),
+			       PARSE_OPT_NONEG | PARSE_OPT_NOARG,
+			       diff_opt_dirstat),
+		OPT_CALLBACK_F(0, "dirstat-by-file", options, N_("<param1,param2>..."),
+			       N_("synonym for --dirstat=files,param1,param2..."),
+			       PARSE_OPT_NONEG | PARSE_OPT_OPTARG,
+			       diff_opt_dirstat),
+		OPT_BIT_F(0, "check", &options->output_format,
+			  N_("warn if changes introduce conflict markers or whitespace errors"),
+			  DIFF_FORMAT_CHECKDIFF, PARSE_OPT_NONEG),
+		OPT_BIT_F(0, "summary", &options->output_format,
+			  N_("condensed summary such as creations, renames and mode changes"),
+			  DIFF_FORMAT_SUMMARY, PARSE_OPT_NONEG),
+		OPT_BIT_F(0, "name-only", &options->output_format,
+			  N_("show only names of changed files"),
+			  DIFF_FORMAT_NAME, PARSE_OPT_NONEG),
+		OPT_BIT_F(0, "name-status", &options->output_format,
+			  N_("show only names and status of changed files"),
+			  DIFF_FORMAT_NAME_STATUS, PARSE_OPT_NONEG),
+		OPT_CALLBACK_F(0, "stat", options, N_("<width>[,<name-width>[,<count>]]"),
+			       N_("generate diffstat"),
+			       PARSE_OPT_NONEG | PARSE_OPT_OPTARG, diff_opt_stat),
+		OPT_CALLBACK_F(0, "stat-width", options, N_("<width>"),
+			       N_("generate diffstat with a given width"),
+			       PARSE_OPT_NONEG, diff_opt_stat),
+		OPT_CALLBACK_F(0, "stat-name-width", options, N_("<width>"),
+			       N_("generate diffstat with a given name width"),
+			       PARSE_OPT_NONEG, diff_opt_stat),
+		OPT_CALLBACK_F(0, "stat-graph-width", options, N_("<width>"),
+			       N_("generate diffstat with a given graph width"),
+			       PARSE_OPT_NONEG, diff_opt_stat),
+		OPT_CALLBACK_F(0, "stat-count", options, N_("<count>"),
+			       N_("generate diffstat with limited lines"),
+			       PARSE_OPT_NONEG, diff_opt_stat),
+		OPT_CALLBACK_F(0, "compact-summary", options, NULL,
+			       N_("generate compact summary in diffstat"),
+			       PARSE_OPT_NOARG, diff_opt_compact_summary),
+		OPT_CALLBACK_F(0, "binary", options, NULL,
+			       N_("output a binary diff that can be applied"),
+			       PARSE_OPT_NONEG | PARSE_OPT_NOARG, diff_opt_binary),
+		OPT_BOOL(0, "full-index", &options->flags.full_index,
+			 N_("show full pre- and post-image object names on the \"index\" lines")),
+		OPT_COLOR_FLAG(0, "color", &options->use_color,
+			       N_("show colored diff")),
+		OPT_CALLBACK_F(0, "ws-error-highlight", options, N_("<kind>"),
+			       N_("highlight whitespace errors in the 'context', 'old' or 'new' lines in the diff"),
+			       PARSE_OPT_NONEG, diff_opt_ws_error_highlight),
+		OPT_SET_INT('z', NULL, &options->line_termination,
+			    N_("do not munge pathnames and use NULs as output field terminators in --raw or --numstat"),
+			    0),
+		OPT__ABBREV(&options->abbrev),
+		OPT_STRING_F(0, "src-prefix", &options->a_prefix, N_("<prefix>"),
+			     N_("show the given source prefix instead of \"a/\""),
+			     PARSE_OPT_NONEG),
+		OPT_STRING_F(0, "dst-prefix", &options->b_prefix, N_("<prefix>"),
+			     N_("show the given destination prefix instead of \"b/\""),
+			     PARSE_OPT_NONEG),
+		OPT_CALLBACK_F(0, "line-prefix", options, N_("<prefix>"),
+			       N_("prepend an additional prefix to every line of output"),
+			       PARSE_OPT_NONEG, diff_opt_line_prefix),
+		OPT_CALLBACK_F(0, "no-prefix", options, NULL,
+			       N_("do not show any source or destination prefix"),
+			       PARSE_OPT_NONEG | PARSE_OPT_NOARG, diff_opt_no_prefix),
+		OPT_INTEGER_F(0, "inter-hunk-context", &options->interhunkcontext,
+			      N_("show context between diff hunks up to the specified number of lines"),
+			      PARSE_OPT_NONEG),
+		OPT_CALLBACK_F(0, "output-indicator-new",
+			       &options->output_indicators[OUTPUT_INDICATOR_NEW],
+			       N_("<char>"),
+			       N_("specify the character to indicate a new line instead of '+'"),
+			       PARSE_OPT_NONEG, diff_opt_char),
+		OPT_CALLBACK_F(0, "output-indicator-old",
+			       &options->output_indicators[OUTPUT_INDICATOR_OLD],
+			       N_("<char>"),
+			       N_("specify the character to indicate an old line instead of '-'"),
+			       PARSE_OPT_NONEG, diff_opt_char),
+		OPT_CALLBACK_F(0, "output-indicator-context",
+			       &options->output_indicators[OUTPUT_INDICATOR_CONTEXT],
+			       N_("<char>"),
+			       N_("specify the character to indicate a context instead of ' '"),
+			       PARSE_OPT_NONEG, diff_opt_char),
+
+		OPT_GROUP(N_("Diff rename options")),
+		OPT_CALLBACK_F('B', "break-rewrites", &options->break_opt, N_("<n>[/<m>]"),
+			       N_("break complete rewrite changes into pairs of delete and create"),
+			       PARSE_OPT_NONEG | PARSE_OPT_OPTARG,
+			       diff_opt_break_rewrites),
+		OPT_CALLBACK_F('M', "find-renames", options, N_("<n>"),
+			       N_("detect renames"),
+			       PARSE_OPT_NONEG | PARSE_OPT_OPTARG,
+			       diff_opt_find_renames),
+		OPT_SET_INT_F('D', "irreversible-delete", &options->irreversible_delete,
+			      N_("omit the preimage for deletes"),
+			      1, PARSE_OPT_NONEG),
+		OPT_CALLBACK_F('C', "find-copies", options, N_("<n>"),
+			       N_("detect copies"),
+			       PARSE_OPT_NONEG | PARSE_OPT_OPTARG,
+			       diff_opt_find_copies),
+		OPT_BOOL(0, "find-copies-harder", &options->flags.find_copies_harder,
+			 N_("use unmodified files as source to find copies")),
+		OPT_SET_INT_F(0, "no-renames", &options->detect_rename,
+			      N_("disable rename detection"),
+			      0, PARSE_OPT_NONEG),
+		OPT_BOOL(0, "rename-empty", &options->flags.rename_empty,
+			 N_("use empty blobs as rename source")),
+		OPT_CALLBACK_F(0, "follow", options, NULL,
+			       N_("continue listing the history of a file beyond renames"),
+			       PARSE_OPT_NOARG, diff_opt_follow),
+		OPT_INTEGER('l', NULL, &options->rename_limit,
+			    N_("prevent rename/copy detection if the number of rename/copy targets exceeds given limit")),
+
+		OPT_GROUP(N_("Diff algorithm options")),
+		OPT_BIT(0, "minimal", &options->xdl_opts,
+			N_("produce the smallest possible diff"),
+			XDF_NEED_MINIMAL),
+		OPT_BIT_F('w', "ignore-all-space", &options->xdl_opts,
+			  N_("ignore whitespace when comparing lines"),
+			  XDF_IGNORE_WHITESPACE, PARSE_OPT_NONEG),
+		OPT_BIT_F('b', "ignore-space-change", &options->xdl_opts,
+			  N_("ignore changes in amount of whitespace"),
+			  XDF_IGNORE_WHITESPACE_CHANGE, PARSE_OPT_NONEG),
+		OPT_BIT_F(0, "ignore-space-at-eol", &options->xdl_opts,
+			  N_("ignore changes in whitespace at EOL"),
+			  XDF_IGNORE_WHITESPACE_AT_EOL, PARSE_OPT_NONEG),
+		OPT_BIT_F(0, "ignore-cr-at-eol", &options->xdl_opts,
+			  N_("ignore carrier-return at the end of line"),
+			  XDF_IGNORE_CR_AT_EOL, PARSE_OPT_NONEG),
+		OPT_BIT_F(0, "ignore-blank-lines", &options->xdl_opts,
+			  N_("ignore changes whose lines are all blank"),
+			  XDF_IGNORE_BLANK_LINES, PARSE_OPT_NONEG),
+		OPT_BIT(0, "indent-heuristic", &options->xdl_opts,
+			N_("heuristic to shift diff hunk boundaries for easy reading"),
+			XDF_INDENT_HEURISTIC),
+		OPT_CALLBACK_F(0, "patience", options, NULL,
+			       N_("generate diff using the \"patience diff\" algorithm"),
+			       PARSE_OPT_NONEG | PARSE_OPT_NOARG,
+			       diff_opt_patience),
+		OPT_BITOP(0, "histogram", &options->xdl_opts,
+			  N_("generate diff using the \"histogram diff\" algorithm"),
+			  XDF_HISTOGRAM_DIFF, XDF_DIFF_ALGORITHM_MASK),
+		OPT_CALLBACK_F(0, "diff-algorithm", options, N_("<algorithm>"),
+			       N_("choose a diff algorithm"),
+			       PARSE_OPT_NONEG, diff_opt_diff_algorithm),
+		OPT_CALLBACK_F(0, "anchored", options, N_("<text>"),
+			       N_("generate diff using the \"anchored diff\" algorithm"),
+			       PARSE_OPT_NONEG, diff_opt_anchored),
+		OPT_CALLBACK_F(0, "word-diff", options, N_("<mode>"),
+			       N_("show word diff, using <mode> to delimit changed words"),
+			       PARSE_OPT_NONEG | PARSE_OPT_OPTARG, diff_opt_word_diff),
+		OPT_CALLBACK_F(0, "word-diff-regex", options, N_("<regex>"),
+			       N_("use <regex> to decide what a word is"),
+			       PARSE_OPT_NONEG, diff_opt_word_diff_regex),
+		OPT_CALLBACK_F(0, "color-words", options, N_("<regex>"),
+			       N_("equivalent to --word-diff=color --word-diff-regex=<regex>"),
+			       PARSE_OPT_NONEG | PARSE_OPT_OPTARG, diff_opt_color_words),
+		OPT_CALLBACK_F(0, "color-moved", options, N_("<mode>"),
+			       N_("moved lines of code are colored differently"),
+			       PARSE_OPT_OPTARG, diff_opt_color_moved),
+		OPT_CALLBACK_F(0, "color-moved-ws", options, N_("<mode>"),
+			       N_("how white spaces are ignored in --color-moved"),
+			       0, diff_opt_color_moved_ws),
+
+		OPT_GROUP(N_("Other diff options")),
+		OPT_CALLBACK_F(0, "relative", options, N_("<prefix>"),
+			       N_("when run from subdir, exclude changes outside and show relative paths"),
+			       PARSE_OPT_NONEG | PARSE_OPT_OPTARG,
+			       diff_opt_relative),
+		OPT_BOOL('a', "text", &options->flags.text,
+			 N_("treat all files as text")),
+		OPT_BOOL('R', NULL, &options->flags.reverse_diff,
+			 N_("swap two inputs, reverse the diff")),
+		OPT_BOOL(0, "exit-code", &options->flags.exit_with_status,
+			 N_("exit with 1 if there were differences, 0 otherwise")),
+		OPT_BOOL(0, "quiet", &options->flags.quick,
+			 N_("disable all output of the program")),
+		OPT_BOOL(0, "ext-diff", &options->flags.allow_external,
+			 N_("allow an external diff helper to be executed")),
+		OPT_CALLBACK_F(0, "textconv", options, NULL,
+			       N_("run external text conversion filters when comparing binary files"),
+			       PARSE_OPT_NOARG, diff_opt_textconv),
+		OPT_CALLBACK_F(0, "ignore-submodules", options, N_("<when>"),
+			       N_("ignore changes to submodules in the diff generation"),
+			       PARSE_OPT_NONEG | PARSE_OPT_OPTARG,
+			       diff_opt_ignore_submodules),
+		OPT_CALLBACK_F(0, "submodule", options, N_("<format>"),
+			       N_("specify how differences in submodules are shown"),
+			       PARSE_OPT_NONEG | PARSE_OPT_OPTARG,
+			       diff_opt_submodule),
+		OPT_SET_INT_F(0, "ita-invisible-in-index", &options->ita_invisible_in_index,
+			      N_("hide 'git add -N' entries from the index"),
+			      1, PARSE_OPT_NONEG),
+		OPT_SET_INT_F(0, "ita-visible-in-index", &options->ita_invisible_in_index,
+			      N_("treat 'git add -N' entries as real in the index"),
+			      0, PARSE_OPT_NONEG),
+		OPT_CALLBACK_F('S', NULL, options, N_("<string>"),
+			       N_("look for differences that change the number of occurrences of the specified string"),
+			       0, diff_opt_pickaxe_string),
+		OPT_CALLBACK_F('G', NULL, options, N_("<regex>"),
+			       N_("look for differences that change the number of occurrences of the specified regex"),
+			       0, diff_opt_pickaxe_regex),
+		OPT_BIT_F(0, "pickaxe-all", &options->pickaxe_opts,
+			  N_("show all changes in the changeset with -S or -G"),
+			  DIFF_PICKAXE_ALL, PARSE_OPT_NONEG),
+		OPT_BIT_F(0, "pickaxe-regex", &options->pickaxe_opts,
+			  N_("treat <string> in -S as extended POSIX regular expression"),
+			  DIFF_PICKAXE_REGEX, PARSE_OPT_NONEG),
+		OPT_FILENAME('O', NULL, &options->orderfile,
+			     N_("control the order in which files appear in the output")),
+		OPT_CALLBACK_F(0, "find-object", options, N_("<object-id>"),
+			       N_("look for differences that change the number of occurrences of the specified object"),
+			       PARSE_OPT_NONEG, diff_opt_find_object),
+		OPT_CALLBACK_F(0, "diff-filter", options, N_("[(A|C|D|M|R|T|U|X|B)...[*]]"),
+			       N_("select files by diff type"),
+			       PARSE_OPT_NONEG, diff_opt_diff_filter),
+		{ OPTION_CALLBACK, 0, "output", options, N_("<file>"),
+		  N_("Output to a specific file"),
+		  PARSE_OPT_NONEG, NULL, 0, diff_opt_output },
+
+		OPT_END()
+	};
+
+	ALLOC_ARRAY(options->parseopts, ARRAY_SIZE(parseopts));
+	memcpy(options->parseopts, parseopts, sizeof(parseopts));
+}
+
+int diff_opt_parse(struct diff_options *options,
+		   const char **av, int ac, const char *prefix)
+{
+	if (!prefix)
+		prefix = "";
+
+	ac = parse_options(ac, av, prefix, options->parseopts, NULL,
+			   PARSE_OPT_KEEP_DASHDASH |
+			   PARSE_OPT_KEEP_UNKNOWN |
+			   PARSE_OPT_NO_INTERNAL_HELP |
+			   PARSE_OPT_ONE_SHOT |
+			   PARSE_OPT_STOP_AT_NON_OPTION);
+
+	return ac;
 }
 
 int parse_rename_score(const char **cp_p)
@@ -4881,47 +5568,6 @@ int parse_rename_score(const char **cp_p
 	return (int)((num >= scale) ? MAX_SCORE : (MAX_SCORE * num / scale));
 }
 
-static int diff_scoreopt_parse(const char *opt)
-{
-	int opt1, opt2, cmd;
-
-	if (*opt++ != '-')
-		return -1;
-	cmd = *opt++;
-	if (cmd == '-') {
-		/* convert the long-form arguments into short-form versions */
-		if (skip_prefix(opt, "break-rewrites", &opt)) {
-			if (*opt == 0 || *opt++ == '=')
-				cmd = 'B';
-		} else if (skip_prefix(opt, "find-copies", &opt)) {
-			if (*opt == 0 || *opt++ == '=')
-				cmd = 'C';
-		} else if (skip_prefix(opt, "find-renames", &opt)) {
-			if (*opt == 0 || *opt++ == '=')
-				cmd = 'M';
-		}
-	}
-	if (cmd != 'M' && cmd != 'C' && cmd != 'B')
-		return -1; /* that is not a -M, -C, or -B option */
-
-	opt1 = parse_rename_score(&opt);
-	if (cmd != 'B')
-		opt2 = 0;
-	else {
-		if (*opt == 0)
-			opt2 = 0;
-		else if (*opt != '/')
-			return -1; /* we expect -B80/99 or -B80 */
-		else {
-			opt++;
-			opt2 = parse_rename_score(&opt);
-		}
-	}
-	if (*opt != 0)
-		return -1;
-	return opt1 | (opt2 << 16);
-}
-
 struct diff_queue_struct diff_queued_diff;
 
 void diff_q(struct diff_queue_struct *queue, struct diff_filepair *dp)
@@ -4955,7 +5601,7 @@ const char *diff_aligned_abbrev(const st
 	const char *abbrev;
 
 	/* Do we want all 40 hex characters? */
-	if (len == GIT_SHA1_HEXSZ)
+	if (len == the_hash_algo->hexsz)
 		return oid_to_hex(oid);
 
 	/* An abbreviated value is fine, possibly followed by an ellipsis. */
@@ -4985,7 +5631,7 @@ const char *diff_aligned_abbrev(const st
 	 * the automatic sizing is supposed to give abblen that ensures
 	 * uniqueness across all objects (statistically speaking).
 	 */
-	if (abblen < GIT_SHA1_HEXSZ - 3) {
+	if (abblen < the_hash_algo->hexsz - 3) {
 		static char hex[GIT_MAX_HEXSZ + 1];
 		if (len < abblen && abblen <= len + 2)
 			xsnprintf(hex, sizeof(hex), "%s%.*s", abbrev, len+3-abblen, "..");
@@ -5057,7 +5703,7 @@ int diff_unmodified_pair(struct diff_fil
 	 * dealing with a change.
 	 */
 	if (one->oid_valid && two->oid_valid &&
-	    !oidcmp(&one->oid, &two->oid) &&
+	    oideq(&one->oid, &two->oid) &&
 	    !one->dirty_submodule && !two->dirty_submodule)
 		return 1; /* no change */
 	if (!one->oid_valid && !two->oid_valid)
@@ -5191,7 +5837,7 @@ static void diff_resolve_rename_copy(voi
 			else
 				p->status = DIFF_STATUS_RENAMED;
 		}
-		else if (oidcmp(&p->one->oid, &p->two->oid) ||
+		else if (!oideq(&p->one->oid, &p->two->oid) ||
 			 p->one->mode != p->two->mode ||
 			 p->one->dirty_submodule ||
 			 p->two->dirty_submodule ||
@@ -5319,7 +5965,7 @@ static void diff_summary(struct diff_opt
 }
 
 struct patch_id_t {
-	git_SHA_CTX *ctx;
+	git_hash_ctx *ctx;
 	int patchlen;
 };
 
@@ -5336,45 +5982,58 @@ static int remove_space(char *line, int
 	return dst - line;
 }
 
+void flush_one_hunk(struct object_id *result, git_hash_ctx *ctx)
+{
+	unsigned char hash[GIT_MAX_RAWSZ];
+	unsigned short carry = 0;
+	int i;
+
+	the_hash_algo->final_fn(hash, ctx);
+	the_hash_algo->init_fn(ctx);
+	/* 20-byte sum, with carry */
+	for (i = 0; i < the_hash_algo->rawsz; ++i) {
+		carry += result->hash[i] + hash[i];
+		result->hash[i] = carry;
+		carry >>= 8;
+	}
+}
+
 static void patch_id_consume(void *priv, char *line, unsigned long len)
 {
 	struct patch_id_t *data = priv;
 	int new_len;
 
-	/* Ignore line numbers when computing the SHA1 of the patch */
-	if (starts_with(line, "@@ -"))
-		return;
-
 	new_len = remove_space(line, len);
 
-	git_SHA1_Update(data->ctx, line, new_len);
+	the_hash_algo->update_fn(data->ctx, line, new_len);
 	data->patchlen += new_len;
 }
 
-static void patch_id_add_string(git_SHA_CTX *ctx, const char *str)
+static void patch_id_add_string(git_hash_ctx *ctx, const char *str)
 {
-	git_SHA1_Update(ctx, str, strlen(str));
+	the_hash_algo->update_fn(ctx, str, strlen(str));
 }
 
-static void patch_id_add_mode(git_SHA_CTX *ctx, unsigned mode)
+static void patch_id_add_mode(git_hash_ctx *ctx, unsigned mode)
 {
 	/* large enough for 2^32 in octal */
 	char buf[12];
 	int len = xsnprintf(buf, sizeof(buf), "%06o", mode);
-	git_SHA1_Update(ctx, buf, len);
+	the_hash_algo->update_fn(ctx, buf, len);
 }
 
-/* returns 0 upon success, and writes result into sha1 */
-static int diff_get_patch_id(struct diff_options *options, struct object_id *oid, int diff_header_only)
+/* returns 0 upon success, and writes result into oid */
+static int diff_get_patch_id(struct diff_options *options, struct object_id *oid, int diff_header_only, int stable)
 {
 	struct diff_queue_struct *q = &diff_queued_diff;
 	int i;
-	git_SHA_CTX ctx;
+	git_hash_ctx ctx;
 	struct patch_id_t data;
 
-	git_SHA1_Init(&ctx);
+	the_hash_algo->init_fn(&ctx);
 	memset(&data, 0, sizeof(struct patch_id_t));
 	data.ctx = &ctx;
+	oidclr(oid);
 
 	for (i = 0; i < q->nr; i++) {
 		xpparam_t xpp;
@@ -5397,70 +6056,75 @@ static int diff_get_patch_id(struct diff
 		if (DIFF_PAIR_UNMERGED(p))
 			continue;
 
-		diff_fill_oid_info(p->one);
-		diff_fill_oid_info(p->two);
+		diff_fill_oid_info(p->one, options->repo->index);
+		diff_fill_oid_info(p->two, options->repo->index);
 
 		len1 = remove_space(p->one->path, strlen(p->one->path));
 		len2 = remove_space(p->two->path, strlen(p->two->path));
 		patch_id_add_string(&ctx, "diff--git");
 		patch_id_add_string(&ctx, "a/");
-		git_SHA1_Update(&ctx, p->one->path, len1);
+		the_hash_algo->update_fn(&ctx, p->one->path, len1);
 		patch_id_add_string(&ctx, "b/");
-		git_SHA1_Update(&ctx, p->two->path, len2);
+		the_hash_algo->update_fn(&ctx, p->two->path, len2);
 
 		if (p->one->mode == 0) {
 			patch_id_add_string(&ctx, "newfilemode");
 			patch_id_add_mode(&ctx, p->two->mode);
 			patch_id_add_string(&ctx, "---/dev/null");
 			patch_id_add_string(&ctx, "+++b/");
-			git_SHA1_Update(&ctx, p->two->path, len2);
+			the_hash_algo->update_fn(&ctx, p->two->path, len2);
 		} else if (p->two->mode == 0) {
 			patch_id_add_string(&ctx, "deletedfilemode");
 			patch_id_add_mode(&ctx, p->one->mode);
 			patch_id_add_string(&ctx, "---a/");
-			git_SHA1_Update(&ctx, p->one->path, len1);
+			the_hash_algo->update_fn(&ctx, p->one->path, len1);
 			patch_id_add_string(&ctx, "+++/dev/null");
 		} else {
 			patch_id_add_string(&ctx, "---a/");
-			git_SHA1_Update(&ctx, p->one->path, len1);
+			the_hash_algo->update_fn(&ctx, p->one->path, len1);
 			patch_id_add_string(&ctx, "+++b/");
-			git_SHA1_Update(&ctx, p->two->path, len2);
+			the_hash_algo->update_fn(&ctx, p->two->path, len2);
 		}
 
 		if (diff_header_only)
 			continue;
 
-		if (fill_mmfile(&mf1, p->one) < 0 ||
-		    fill_mmfile(&mf2, p->two) < 0)
+		if (fill_mmfile(options->repo, &mf1, p->one) < 0 ||
+		    fill_mmfile(options->repo, &mf2, p->two) < 0)
 			return error("unable to read files to diff");
 
-		if (diff_filespec_is_binary(p->one) ||
-		    diff_filespec_is_binary(p->two)) {
-			git_SHA1_Update(&ctx, oid_to_hex(&p->one->oid),
-					GIT_SHA1_HEXSZ);
-			git_SHA1_Update(&ctx, oid_to_hex(&p->two->oid),
-					GIT_SHA1_HEXSZ);
+		if (diff_filespec_is_binary(options->repo, p->one) ||
+		    diff_filespec_is_binary(options->repo, p->two)) {
+			the_hash_algo->update_fn(&ctx, oid_to_hex(&p->one->oid),
+					the_hash_algo->hexsz);
+			the_hash_algo->update_fn(&ctx, oid_to_hex(&p->two->oid),
+					the_hash_algo->hexsz);
 			continue;
 		}
 
 		xpp.flags = 0;
 		xecfg.ctxlen = 3;
 		xecfg.flags = 0;
-		if (xdi_diff_outf(&mf1, &mf2, patch_id_consume, &data,
-				  &xpp, &xecfg))
+		if (xdi_diff_outf(&mf1, &mf2, discard_hunk_line,
+				  patch_id_consume, &data, &xpp, &xecfg))
 			return error("unable to generate patch-id diff for %s",
 				     p->one->path);
+
+		if (stable)
+			flush_one_hunk(oid, &ctx);
 	}
 
-	git_SHA1_Final(oid->hash, &ctx);
+	if (!stable)
+		the_hash_algo->final_fn(oid->hash, &ctx);
+
 	return 0;
 }
 
-int diff_flush_patch_id(struct diff_options *options, struct object_id *oid, int diff_header_only)
+int diff_flush_patch_id(struct diff_options *options, struct object_id *oid, int diff_header_only, int stable)
 {
 	struct diff_queue_struct *q = &diff_queued_diff;
 	int i;
-	int result = diff_get_patch_id(options, oid, diff_header_only);
+	int result = diff_get_patch_id(options, oid, diff_header_only, stable);
 
 	for (i = 0; i < q->nr; i++)
 		diff_free_filepair(q->queue[i]);
@@ -5541,18 +6205,22 @@ static void diff_flush_patch_all_file_pa
 		if (o->color_moved) {
 			struct hashmap add_lines, del_lines;
 
-			hashmap_init(&del_lines,
-				     (hashmap_cmp_fn)moved_entry_cmp, o, 0);
-			hashmap_init(&add_lines,
-				     (hashmap_cmp_fn)moved_entry_cmp, o, 0);
+			if (o->color_moved_ws_handling &
+			    COLOR_MOVED_WS_ALLOW_INDENTATION_CHANGE)
+				o->color_moved_ws_handling |= XDF_IGNORE_WHITESPACE;
+
+			hashmap_init(&del_lines, moved_entry_cmp, o, 0);
+			hashmap_init(&add_lines, moved_entry_cmp, o, 0);
 
 			add_lines_to_move_detection(o, &add_lines, &del_lines);
 			mark_color_as_moved(o, &add_lines, &del_lines);
 			if (o->color_moved == COLOR_MOVED_ZEBRA_DIM)
 				dim_moved_lines(o);
 
-			hashmap_free(&add_lines, 0);
-			hashmap_free(&del_lines, 0);
+			hashmap_free_entries(&add_lines, struct moved_entry,
+						ent);
+			hashmap_free_entries(&del_lines, struct moved_entry,
+						ent);
 		}
 
 		for (i = 0; i < esm.nr; i++)
@@ -5560,8 +6228,10 @@ static void diff_flush_patch_all_file_pa
 
 		for (i = 0; i < esm.nr; i++)
 			free((void *)esm.buf[i].line);
+		esm.nr = 0;
+
+		o->emitted_symbols = NULL;
 	}
-	esm.nr = 0;
 }
 
 void diff_flush(struct diff_options *options)
@@ -5597,12 +6267,7 @@ void diff_flush(struct diff_options *opt
 	    dirstat_by_line) {
 		struct diffstat_t diffstat;
 
-		memset(&diffstat, 0, sizeof(struct diffstat_t));
-		for (i = 0; i < q->nr; i++) {
-			struct diff_filepair *p = q->queue[i];
-			if (check_pair_status(p))
-				diff_flush_stat(p, options, &diffstat);
-		}
+		compute_diffstat(options, &diffstat, q);
 		if (output_format & DIFF_FORMAT_NUMSTAT)
 			show_numstat(&diffstat, options);
 		if (output_format & DIFF_FORMAT_DIFFSTAT)
@@ -5736,19 +6401,21 @@ static void diffcore_apply_filter(struct
 }
 
 /* Check whether two filespecs with the same mode and size are identical */
-static int diff_filespec_is_identical(struct diff_filespec *one,
+static int diff_filespec_is_identical(struct repository *r,
+				      struct diff_filespec *one,
 				      struct diff_filespec *two)
 {
 	if (S_ISGITLINK(one->mode))
 		return 0;
-	if (diff_populate_filespec(one, 0))
+	if (diff_populate_filespec(r, one, 0))
 		return 0;
-	if (diff_populate_filespec(two, 0))
+	if (diff_populate_filespec(r, two, 0))
 		return 0;
 	return !memcmp(one->data, two->data, one->size);
 }
 
-static int diff_filespec_check_stat_unmatch(struct diff_filepair *p)
+static int diff_filespec_check_stat_unmatch(struct repository *r,
+					    struct diff_filepair *p)
 {
 	if (p->done_skip_stat_unmatch)
 		return p->skip_stat_unmatch_result;
@@ -5772,10 +6439,10 @@ static int diff_filespec_check_stat_unma
 	    !DIFF_FILE_VALID(p->two) ||
 	    (p->one->oid_valid && p->two->oid_valid) ||
 	    (p->one->mode != p->two->mode) ||
-	    diff_populate_filespec(p->one, CHECK_SIZE_ONLY) ||
-	    diff_populate_filespec(p->two, CHECK_SIZE_ONLY) ||
+	    diff_populate_filespec(r, p->one, CHECK_SIZE_ONLY) ||
+	    diff_populate_filespec(r, p->two, CHECK_SIZE_ONLY) ||
 	    (p->one->size != p->two->size) ||
-	    !diff_filespec_is_identical(p->one, p->two)) /* (2) */
+	    !diff_filespec_is_identical(r, p->one, p->two)) /* (2) */
 		p->skip_stat_unmatch_result = 1;
 	return p->skip_stat_unmatch_result;
 }
@@ -5790,7 +6457,7 @@ static void diffcore_skip_stat_unmatch(s
 	for (i = 0; i < q->nr; i++) {
 		struct diff_filepair *p = q->queue[i];
 
-		if (diff_filespec_check_stat_unmatch(p))
+		if (diff_filespec_check_stat_unmatch(diffopt->repo, p))
 			diff_q(&outq, p);
 		else {
 			/*
@@ -5818,21 +6485,55 @@ static int diffnamecmp(const void *a_, c
 	return strcmp(name_a, name_b);
 }
 
-void diffcore_fix_diff_index(struct diff_options *options)
+void diffcore_fix_diff_index(void)
 {
 	struct diff_queue_struct *q = &diff_queued_diff;
 	QSORT(q->queue, q->nr, diffnamecmp);
 }
 
+static void add_if_missing(struct repository *r,
+			   struct oid_array *to_fetch,
+			   const struct diff_filespec *filespec)
+{
+	if (filespec && filespec->oid_valid &&
+	    !S_ISGITLINK(filespec->mode) &&
+	    oid_object_info_extended(r, &filespec->oid, NULL,
+				     OBJECT_INFO_FOR_PREFETCH))
+		oid_array_append(to_fetch, &filespec->oid);
+}
+
 void diffcore_std(struct diff_options *options)
 {
+	if (options->repo == the_repository && has_promisor_remote()) {
+		/*
+		 * Prefetch the diff pairs that are about to be flushed.
+		 */
+		int i;
+		struct diff_queue_struct *q = &diff_queued_diff;
+		struct oid_array to_fetch = OID_ARRAY_INIT;
+
+		for (i = 0; i < q->nr; i++) {
+			struct diff_filepair *p = q->queue[i];
+			add_if_missing(options->repo, &to_fetch, p->one);
+			add_if_missing(options->repo, &to_fetch, p->two);
+		}
+		if (to_fetch.nr)
+			/*
+			 * NEEDSWORK: Consider deduplicating the OIDs sent.
+			 */
+			promisor_remote_get_direct(options->repo,
+						   to_fetch.oid, to_fetch.nr);
+		oid_array_clear(&to_fetch);
+	}
+
 	/* NOTE please keep the following in sync with diff_tree_combined() */
 	if (options->skip_stat_unmatch)
 		diffcore_skip_stat_unmatch(options);
 	if (!options->found_follow) {
 		/* See try_to_follow_renames() in tree-diff.c */
 		if (options->break_opt != -1)
-			diffcore_break(options->break_opt);
+			diffcore_break(options->repo,
+				       options->break_opt);
 		if (options->detect_rename)
 			diffcore_rename(options);
 		if (options->break_opt != -1)
@@ -5899,6 +6600,20 @@ static int is_submodule_ignored(const ch
 	return ignored;
 }
 
+void compute_diffstat(struct diff_options *options,
+		      struct diffstat_t *diffstat,
+		      struct diff_queue_struct *q)
+{
+	int i;
+
+	memset(diffstat, 0, sizeof(struct diffstat_t));
+	for (i = 0; i < q->nr; i++) {
+		struct diff_filepair *p = q->queue[i];
+		if (check_pair_status(p))
+			diff_flush_stat(p, options, diffstat);
+	}
+}
+
 void diff_addremove(struct diff_options *options,
 		    int addremove, unsigned mode,
 		    const struct object_id *oid,
@@ -5983,7 +6698,7 @@ void diff_change(struct diff_options *op
 		return;
 
 	if (options->flags.quick && options->skip_stat_unmatch &&
-	    !diff_filespec_check_stat_unmatch(p))
+	    !diff_filespec_check_stat_unmatch(options->repo, p))
 		return;
 
 	options->flags.has_changes = 1;
@@ -6005,8 +6720,10 @@ struct diff_filepair *diff_unmerge(struc
 	return pair;
 }
 
-static char *run_textconv(const char *pgm, struct diff_filespec *spec,
-		size_t *outsize)
+static char *run_textconv(struct repository *r,
+			  const char *pgm,
+			  struct diff_filespec *spec,
+			  size_t *outsize)
 {
 	struct diff_tempfile *temp;
 	const char *argv[3];
@@ -6015,7 +6732,7 @@ static char *run_textconv(const char *pg
 	struct strbuf buf = STRBUF_INIT;
 	int err = 0;
 
-	temp = prepare_temp_file(spec->path, spec);
+	temp = prepare_temp_file(r, spec->path, spec);
 	*arg++ = pgm;
 	*arg++ = temp->name;
 	*arg = NULL;
@@ -6042,7 +6759,8 @@ static char *run_textconv(const char *pg
 	return strbuf_detach(&buf, outsize);
 }
 
-size_t fill_textconv(struct userdiff_driver *driver,
+size_t fill_textconv(struct repository *r,
+		     struct userdiff_driver *driver,
 		     struct diff_filespec *df,
 		     char **outbuf)
 {
@@ -6053,7 +6771,7 @@ size_t fill_textconv(struct userdiff_dri
 			*outbuf = "";
 			return 0;
 		}
-		if (diff_populate_filespec(df, 0))
+		if (diff_populate_filespec(r, df, 0))
 			die("unable to read files to diff");
 		*outbuf = df->data;
 		return df->size;
@@ -6070,7 +6788,7 @@ size_t fill_textconv(struct userdiff_dri
 			return size;
 	}
 
-	*outbuf = run_textconv(driver->textconv, df, &size);
+	*outbuf = run_textconv(r, driver->textconv, df, &size);
 	if (!*outbuf)
 		die("unable to read files to diff");
 
@@ -6090,7 +6808,8 @@ size_t fill_textconv(struct userdiff_dri
 	return size;
 }
 
-int textconv_object(const char *path,
+int textconv_object(struct repository *r,
+		    const char *path,
 		    unsigned mode,
 		    const struct object_id *oid,
 		    int oid_valid,
@@ -6102,13 +6821,13 @@ int textconv_object(const char *path,
 
 	df = alloc_filespec(path);
 	fill_filespec(df, oid, oid_valid, mode);
-	textconv = get_textconv(df);
+	textconv = get_textconv(r, df);
 	if (!textconv) {
 		free_filespec(df);
 		return 0;
 	}
 
-	*buf_size = fill_textconv(textconv, df, buf);
+	*buf_size = fill_textconv(r, textconv, df, buf);
 	free_filespec(df);
 	return 1;
 }
diff -pruN 1.2.1+git2.18.0-1/git/diffcore-break.c 1.2.3+git2.25.1-1/git/diffcore-break.c
--- 1.2.1+git2.18.0-1/git/diffcore-break.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/diffcore-break.c	2020-02-17 04:47:35.000000000 +0000
@@ -5,7 +5,8 @@
 #include "diff.h"
 #include "diffcore.h"
 
-static int should_break(struct diff_filespec *src,
+static int should_break(struct repository *r,
+			struct diff_filespec *src,
 			struct diff_filespec *dst,
 			int break_score,
 			int *merge_score_p)
@@ -58,10 +59,11 @@ static int should_break(struct diff_file
 	}
 
 	if (src->oid_valid && dst->oid_valid &&
-	    !oidcmp(&src->oid, &dst->oid))
+	    oideq(&src->oid, &dst->oid))
 		return 0; /* they are the same */
 
-	if (diff_populate_filespec(src, 0) || diff_populate_filespec(dst, 0))
+	if (diff_populate_filespec(r, src, 0) ||
+	    diff_populate_filespec(r, dst, 0))
 		return 0; /* error but caught downstream */
 
 	max_size = ((src->size > dst->size) ? src->size : dst->size);
@@ -71,7 +73,7 @@ static int should_break(struct diff_file
 	if (!src->size)
 		return 0; /* we do not let empty files get renamed */
 
-	if (diffcore_count_changes(src, dst,
+	if (diffcore_count_changes(r, src, dst,
 				   &src->cnt_data, &dst->cnt_data,
 				   &src_copied, &literal_added))
 		return 0;
@@ -114,7 +116,7 @@ static int should_break(struct diff_file
 	return 1;
 }
 
-void diffcore_break(int break_score)
+void diffcore_break(struct repository *r, int break_score)
 {
 	struct diff_queue_struct *q = &diff_queued_diff;
 	struct diff_queue_struct outq;
@@ -178,7 +180,7 @@ void diffcore_break(int break_score)
 		    object_type(p->one->mode) == OBJ_BLOB &&
 		    object_type(p->two->mode) == OBJ_BLOB &&
 		    !strcmp(p->one->path, p->two->path)) {
-			if (should_break(p->one, p->two,
+			if (should_break(r, p->one, p->two,
 					 break_score, &score)) {
 				/* Split this into delete and create */
 				struct diff_filespec *null_one, *null_two;
@@ -284,17 +286,17 @@ void diffcore_merge_broken(void)
 					/* Peer survived.  Merge them */
 					merge_broken(p, pp, &outq);
 					q->queue[j] = NULL;
-					break;
+					goto next;
 				}
 			}
-			if (q->nr <= j)
-				/* The peer did not survive, so we keep
-				 * it in the output.
-				 */
-				diff_q(&outq, p);
+			/* The peer did not survive, so we keep
+			 * it in the output.
+			 */
+			diff_q(&outq, p);
 		}
 		else
 			diff_q(&outq, p);
+next:;
 	}
 	free(q->queue);
 	*q = outq;
diff -pruN 1.2.1+git2.18.0-1/git/diffcore-delta.c 1.2.3+git2.25.1-1/git/diffcore-delta.c
--- 1.2.1+git2.18.0-1/git/diffcore-delta.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/diffcore-delta.c	2020-02-17 04:47:35.000000000 +0000
@@ -121,14 +121,15 @@ static int spanhash_cmp(const void *a_,
 		a->hashval > b->hashval ? 1 : 0;
 }
 
-static struct spanhash_top *hash_chars(struct diff_filespec *one)
+static struct spanhash_top *hash_chars(struct repository *r,
+				       struct diff_filespec *one)
 {
 	int i, n;
 	unsigned int accum1, accum2, hashval;
 	struct spanhash_top *hash;
 	unsigned char *buf = one->data;
 	unsigned int sz = one->size;
-	int is_text = !diff_filespec_is_binary(one);
+	int is_text = !diff_filespec_is_binary(r, one);
 
 	i = INITIAL_HASH_SIZE;
 	hash = xmalloc(st_add(sizeof(*hash),
@@ -162,7 +163,8 @@ static struct spanhash_top *hash_chars(s
 	return hash;
 }
 
-int diffcore_count_changes(struct diff_filespec *src,
+int diffcore_count_changes(struct repository *r,
+			   struct diff_filespec *src,
 			   struct diff_filespec *dst,
 			   void **src_count_p,
 			   void **dst_count_p,
@@ -177,14 +179,14 @@ int diffcore_count_changes(struct diff_f
 	if (src_count_p)
 		src_count = *src_count_p;
 	if (!src_count) {
-		src_count = hash_chars(src);
+		src_count = hash_chars(r, src);
 		if (src_count_p)
 			*src_count_p = src_count;
 	}
 	if (dst_count_p)
 		dst_count = *dst_count_p;
 	if (!dst_count) {
-		dst_count = hash_chars(dst);
+		dst_count = hash_chars(r, dst);
 		if (dst_count_p)
 			*dst_count_p = dst_count;
 	}
diff -pruN 1.2.1+git2.18.0-1/git/diffcore.h 1.2.3+git2.25.1-1/git/diffcore.h
--- 1.2.1+git2.18.0-1/git/diffcore.h	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/diffcore.h	2020-02-17 04:47:35.000000000 +0000
@@ -4,6 +4,12 @@
 #ifndef DIFFCORE_H
 #define DIFFCORE_H
 
+#include "cache.h"
+
+struct diff_options;
+struct repository;
+struct userdiff_driver;
+
 /* This header file is internal between diff.c and its diff transformers
  * (e.g. diffcore-rename, diffcore-pickaxe).  Never include this header
  * in anything else.
@@ -22,8 +28,12 @@
 
 #define MINIMUM_BREAK_SIZE     400 /* do not break a file smaller than this */
 
-struct userdiff_driver;
-
+/**
+ * the internal representation for a single file (blob).  It records the blob
+ * object name (if known -- for a work tree file it typically is a NUL SHA-1),
+ * filemode and pathname.  This is what the `diff_addremove()`, `diff_change()`
+ * and `diff_unmerge()` synthesize and feed `diff_queue()` function with.
+ */
 struct diff_filespec {
 	struct object_id oid;
 	char *path;
@@ -50,18 +60,29 @@ struct diff_filespec {
 	struct userdiff_driver *driver;
 };
 
-extern struct diff_filespec *alloc_filespec(const char *);
-extern void free_filespec(struct diff_filespec *);
-extern void fill_filespec(struct diff_filespec *, const struct object_id *,
-			  int, unsigned short);
+struct diff_filespec *alloc_filespec(const char *);
+void free_filespec(struct diff_filespec *);
+void fill_filespec(struct diff_filespec *, const struct object_id *,
+		   int, unsigned short);
 
 #define CHECK_SIZE_ONLY 1
 #define CHECK_BINARY    2
-extern int diff_populate_filespec(struct diff_filespec *, unsigned int);
-extern void diff_free_filespec_data(struct diff_filespec *);
-extern void diff_free_filespec_blob(struct diff_filespec *);
-extern int diff_filespec_is_binary(struct diff_filespec *);
-
+int diff_populate_filespec(struct repository *, struct diff_filespec *, unsigned int);
+void diff_free_filespec_data(struct diff_filespec *);
+void diff_free_filespec_blob(struct diff_filespec *);
+int diff_filespec_is_binary(struct repository *, struct diff_filespec *);
+
+/**
+ * This records a pair of `struct diff_filespec`; the filespec for a file in
+ * the "old" set (i.e. preimage) is called `one`, and the filespec for a file
+ * in the "new" set (i.e. postimage) is called `two`.  A change that represents
+ * file creation has NULL in `one`, and file deletion has NULL in `two`.
+ *
+ * A `filepair` starts pointing at `one` and `two` that are from the same
+ * filename, but `diffcore_std()` can break pairs and match component filespecs
+ * with other filespecs from a different filepair to form new filepair. This is
+ * called 'rename detection'.
+ */
 struct diff_filepair {
 	struct diff_filespec *one;
 	struct diff_filespec *two;
@@ -73,6 +94,7 @@ struct diff_filepair {
 	unsigned done_skip_stat_unmatch : 1;
 	unsigned skip_stat_unmatch_result : 1;
 };
+
 #define DIFF_PAIR_UNMERGED(p) ((p)->is_unmerged)
 
 #define DIFF_PAIR_RENAME(p) ((p)->renamed_pair)
@@ -86,15 +108,29 @@ struct diff_filepair {
 
 #define DIFF_PAIR_MODE_CHANGED(p) ((p)->one->mode != (p)->two->mode)
 
-extern void diff_free_filepair(struct diff_filepair *);
+void diff_free_filepair(struct diff_filepair *);
 
-extern int diff_unmodified_pair(struct diff_filepair *);
+int diff_unmodified_pair(struct diff_filepair *);
 
+/**
+ * This is a collection of filepairs.  Notable members are:
+ *
+ * - `queue`:
+ * An array of pointers to `struct diff_filepair`. This dynamically grows as
+ * you add filepairs;
+ *
+ * - `alloc`:
+ * The allocated size of the `queue` array;
+ *
+ * - `nr`:
+ * The number of elements in the `queue` array.
+ */
 struct diff_queue_struct {
 	struct diff_filepair **queue;
 	int alloc;
 	int nr;
 };
+
 #define DIFF_QUEUE_CLEAR(q) \
 	do { \
 		(q)->queue = NULL; \
@@ -102,16 +138,16 @@ struct diff_queue_struct {
 	} while (0)
 
 extern struct diff_queue_struct diff_queued_diff;
-extern struct diff_filepair *diff_queue(struct diff_queue_struct *,
-					struct diff_filespec *,
-					struct diff_filespec *);
-extern void diff_q(struct diff_queue_struct *, struct diff_filepair *);
-
-extern void diffcore_break(int);
-extern void diffcore_rename(struct diff_options *);
-extern void diffcore_merge_broken(void);
-extern void diffcore_pickaxe(struct diff_options *);
-extern void diffcore_order(const char *orderfile);
+struct diff_filepair *diff_queue(struct diff_queue_struct *,
+				 struct diff_filespec *,
+				 struct diff_filespec *);
+void diff_q(struct diff_queue_struct *, struct diff_filepair *);
+
+void diffcore_break(struct repository *, int);
+void diffcore_rename(struct diff_options *);
+void diffcore_merge_broken(void);
+void diffcore_pickaxe(struct diff_options *);
+void diffcore_order(const char *orderfile);
 
 /* low-level interface to diffcore_order */
 struct obj_order {
@@ -138,11 +174,12 @@ void diff_debug_queue(const char *, stru
 #define diff_debug_queue(a,b) do { /* nothing */ } while (0)
 #endif
 
-extern int diffcore_count_changes(struct diff_filespec *src,
-				  struct diff_filespec *dst,
-				  void **src_count_p,
-				  void **dst_count_p,
-				  unsigned long *src_copied,
-				  unsigned long *literal_added);
+int diffcore_count_changes(struct repository *r,
+			   struct diff_filespec *src,
+			   struct diff_filespec *dst,
+			   void **src_count_p,
+			   void **dst_count_p,
+			   unsigned long *src_copied,
+			   unsigned long *literal_added);
 
 #endif
diff -pruN 1.2.1+git2.18.0-1/git/diffcore-pickaxe.c 1.2.3+git2.25.1-1/git/diffcore-pickaxe.c
--- 1.2.1+git2.18.0-1/git/diffcore-pickaxe.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/diffcore-pickaxe.c	2020-02-17 04:47:35.000000000 +0000
@@ -62,7 +62,8 @@ static int diff_grep(mmfile_t *one, mmfi
 	ecbdata.hit = 0;
 	xecfg.ctxlen = o->context;
 	xecfg.interhunkctxlen = o->interhunkcontext;
-	if (xdi_diff_outf(one, two, diffgrep_consume, &ecbdata, &xpp, &xecfg))
+	if (xdi_diff_outf(one, two, discard_hunk_line, diffgrep_consume,
+			  &ecbdata, &xpp, &xecfg))
 		return 0;
 	return ecbdata.hit;
 }
@@ -139,8 +140,8 @@ static int pickaxe_match(struct diff_fil
 		return 0;
 
 	if (o->flags.allow_textconv) {
-		textconv_one = get_textconv(p->one);
-		textconv_two = get_textconv(p->two);
+		textconv_one = get_textconv(o->repo, p->one);
+		textconv_two = get_textconv(o->repo, p->two);
 	}
 
 	/*
@@ -153,8 +154,14 @@ static int pickaxe_match(struct diff_fil
 	if (textconv_one == textconv_two && diff_unmodified_pair(p))
 		return 0;
 
-	mf1.size = fill_textconv(textconv_one, p->one, &mf1.ptr);
-	mf2.size = fill_textconv(textconv_two, p->two, &mf2.ptr);
+	if ((o->pickaxe_opts & DIFF_PICKAXE_KIND_G) &&
+	    !o->flags.text &&
+	    ((!textconv_one && diff_filespec_is_binary(o->repo, p->one)) ||
+	     (!textconv_two && diff_filespec_is_binary(o->repo, p->two))))
+		return 0;
+
+	mf1.size = fill_textconv(o->repo, textconv_one, p->one, &mf1.ptr);
+	mf2.size = fill_textconv(o->repo, textconv_two, p->two, &mf2.ptr);
 
 	ret = fn(DIFF_FILE_VALID(p->one) ? &mf1 : NULL,
 		 DIFF_FILE_VALID(p->two) ? &mf2 : NULL,
diff -pruN 1.2.1+git2.18.0-1/git/diffcore-rename.c 1.2.3+git2.25.1-1/git/diffcore-rename.c
--- 1.2.1+git2.18.0-1/git/diffcore-rename.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/diffcore-rename.c	2020-02-17 04:47:35.000000000 +0000
@@ -4,6 +4,7 @@
 #include "cache.h"
 #include "diff.h"
 #include "diffcore.h"
+#include "object-store.h"
 #include "hashmap.h"
 #include "progress.h"
 
@@ -22,7 +23,7 @@ static int find_rename_dst(struct diff_f
 	first = 0;
 	last = rename_dst_nr;
 	while (last > first) {
-		int next = (last + first) >> 1;
+		int next = first + ((last - first) >> 1);
 		struct diff_rename_dst *dst = &(rename_dst[next]);
 		int cmp = strcmp(two->path, dst->two->path);
 		if (!cmp)
@@ -82,7 +83,7 @@ static struct diff_rename_src *register_
 	first = 0;
 	last = rename_src_nr;
 	while (last > first) {
-		int next = (last + first) >> 1;
+		int next = first + ((last - first) >> 1);
 		struct diff_rename_src *src = &(rename_src[next]);
 		int cmp = strcmp(one->path, src->p->one->path);
 		if (!cmp)
@@ -127,7 +128,8 @@ struct diff_score {
 	short name_score;
 };
 
-static int estimate_similarity(struct diff_filespec *src,
+static int estimate_similarity(struct repository *r,
+			       struct diff_filespec *src,
 			       struct diff_filespec *dst,
 			       int minimum_score)
 {
@@ -164,10 +166,10 @@ static int estimate_similarity(struct di
 	 * say whether the size is valid or not!)
 	 */
 	if (!src->cnt_data &&
-	    diff_populate_filespec(src, CHECK_SIZE_ONLY))
+	    diff_populate_filespec(r, src, CHECK_SIZE_ONLY))
 		return 0;
 	if (!dst->cnt_data &&
-	    diff_populate_filespec(dst, CHECK_SIZE_ONLY))
+	    diff_populate_filespec(r, dst, CHECK_SIZE_ONLY))
 		return 0;
 
 	max_size = ((src->size > dst->size) ? src->size : dst->size);
@@ -185,12 +187,12 @@ static int estimate_similarity(struct di
 	if (max_size * (MAX_SCORE-minimum_score) < delta_size * MAX_SCORE)
 		return 0;
 
-	if (!src->cnt_data && diff_populate_filespec(src, 0))
+	if (!src->cnt_data && diff_populate_filespec(r, src, 0))
 		return 0;
-	if (!dst->cnt_data && diff_populate_filespec(dst, 0))
+	if (!dst->cnt_data && diff_populate_filespec(r, dst, 0))
 		return 0;
 
-	if (diffcore_count_changes(src, dst,
+	if (diffcore_count_changes(r, src, dst,
 				   &src->cnt_data, &dst->cnt_data,
 				   &src_copied, &literal_added))
 		return 0;
@@ -255,15 +257,16 @@ struct file_similarity {
 	struct diff_filespec *filespec;
 };
 
-static unsigned int hash_filespec(struct diff_filespec *filespec)
+static unsigned int hash_filespec(struct repository *r,
+				  struct diff_filespec *filespec)
 {
 	if (!filespec->oid_valid) {
-		if (diff_populate_filespec(filespec, 0))
+		if (diff_populate_filespec(r, filespec, 0))
 			return 0;
 		hash_object_file(filespec->data, filespec->size, "blob",
 				 &filespec->oid);
 	}
-	return sha1hash(filespec->oid.hash);
+	return oidhash(&filespec->oid);
 }
 
 static int find_identical_files(struct hashmap *srcs,
@@ -271,21 +274,22 @@ static int find_identical_files(struct h
 				struct diff_options *options)
 {
 	int renames = 0;
-
 	struct diff_filespec *target = rename_dst[dst_index].two;
 	struct file_similarity *p, *best = NULL;
 	int i = 100, best_score = -1;
+	unsigned int hash = hash_filespec(options->repo, target);
 
 	/*
 	 * Find the best source match for specified destination.
 	 */
-	p = hashmap_get_from_hash(srcs, hash_filespec(target), NULL);
-	for (; p; p = hashmap_get_next(srcs, p)) {
+	p = hashmap_get_entry_from_hash(srcs, hash, NULL,
+					struct file_similarity, entry);
+	hashmap_for_each_entry_from(srcs, p, entry) {
 		int score;
 		struct diff_filespec *source = p->filespec;
 
 		/* False hash collision? */
-		if (oidcmp(&source->oid, &target->oid))
+		if (!oideq(&source->oid, &target->oid))
 			continue;
 		/* Non-regular files? If so, the modes must match! */
 		if (!S_ISREG(source->mode) || !S_ISREG(target->mode)) {
@@ -315,15 +319,17 @@ static int find_identical_files(struct h
 	return renames;
 }
 
-static void insert_file_table(struct hashmap *table, int index, struct diff_filespec *filespec)
+static void insert_file_table(struct repository *r,
+			      struct hashmap *table, int index,
+			      struct diff_filespec *filespec)
 {
 	struct file_similarity *entry = xmalloc(sizeof(*entry));
 
 	entry->index = index;
 	entry->filespec = filespec;
 
-	hashmap_entry_init(entry, hash_filespec(filespec));
-	hashmap_add(table, entry);
+	hashmap_entry_init(&entry->entry, hash_filespec(r, filespec));
+	hashmap_add(table, &entry->entry);
 }
 
 /*
@@ -343,14 +349,16 @@ static int find_exact_renames(struct dif
 	 */
 	hashmap_init(&file_table, NULL, NULL, rename_src_nr);
 	for (i = rename_src_nr-1; i >= 0; i--)
-		insert_file_table(&file_table, i, rename_src[i].p->one);
+		insert_file_table(options->repo,
+				  &file_table, i,
+				  rename_src[i].p->one);
 
 	/* Walk the destinations and find best source match */
 	for (i = 0; i < rename_dst_nr; i++)
 		renames += find_identical_files(&file_table, i, options);
 
 	/* Free the hash data structure and entries */
-	hashmap_free(&file_table, 1);
+	hashmap_free_entries(&file_table, struct file_similarity, entry);
 
 	return renames;
 }
@@ -556,7 +564,8 @@ void diffcore_rename(struct diff_options
 			    diff_unmodified_pair(rename_src[j].p))
 				continue;
 
-			this_src.score = estimate_similarity(one, two,
+			this_src.score = estimate_similarity(options->repo,
+							     one, two,
 							     minimum_score);
 			this_src.name_score = basename_same(one, two);
 			this_src.dst = i;
@@ -575,7 +584,7 @@ void diffcore_rename(struct diff_options
 	stop_progress(&progress);
 
 	/* cost matrix sorted by most to least similar pair */
-	QSORT(mx, dst_cnt * NUM_CANDIDATE_PER_DST, score_compare);
+	STABLE_QSORT(mx, dst_cnt * NUM_CANDIDATE_PER_DST, score_compare);
 
 	rename_count += find_renames(mx, dst_cnt, minimum_score, 0);
 	if (detect_rename == DIFF_DETECT_COPY)
diff -pruN 1.2.1+git2.18.0-1/git/diff-delta.c 1.2.3+git2.25.1-1/git/diff-delta.c
--- 1.2.1+git2.18.0-1/git/diff-delta.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/diff-delta.c	2020-02-17 04:47:35.000000000 +0000
@@ -326,6 +326,8 @@ create_delta(const struct delta_index *i
 	const unsigned char *ref_data, *ref_top, *data, *top;
 	unsigned char *out;
 
+	*delta_size = 0;
+
 	if (!trg_buf || !trg_size)
 		return NULL;
 
diff -pruN 1.2.1+git2.18.0-1/git/diff.h 1.2.3+git2.25.1-1/git/diff.h
--- 1.2.1+git2.18.0-1/git/diff.h	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/diff.h	2020-02-17 04:47:35.000000000 +0000
@@ -9,15 +9,60 @@
 #include "object.h"
 #include "oidset.h"
 
-struct rev_info;
+/**
+ * The diff API is for programs that compare two sets of files (e.g. two trees,
+ * one tree and the index) and present the found difference in various ways.
+ * The calling program is responsible for feeding the API pairs of files, one
+ * from the "old" set and the corresponding one from "new" set, that are
+ * different.
+ * The library called through this API is called diffcore, and is responsible
+ * for two things.
+ *
+ * - finding total rewrites (`-B`), renames (`-M`) and copies (`-C`), and
+ * changes that touch a string (`-S`), as specified by the caller.
+ *
+ * - outputting the differences in various formats, as specified by the caller.
+ *
+ * Calling sequence
+ * ----------------
+ *
+ * - Prepare `struct diff_options` to record the set of diff options, and then
+ * call `repo_diff_setup()` to initialize this structure.  This sets up the
+ * vanilla default.
+ *
+ * - Fill in the options structure to specify desired output format, rename
+ * detection, etc.  `diff_opt_parse()` can be used to parse options given
+ * from the command line in a way consistent with existing git-diff family
+ * of programs.
+ *
+ * - Call `diff_setup_done()`; this inspects the options set up so far for
+ * internal consistency and make necessary tweaking to it (e.g. if textual
+ * patch output was asked, recursive behaviour is turned on); the callback
+ * set_default in diff_options can be used to tweak this more.
+ *
+ * - As you find different pairs of files, call `diff_change()` to feed
+ * modified files, `diff_addremove()` to feed created or deleted files, or
+ * `diff_unmerge()` to feed a file whose state is 'unmerged' to the API.
+ * These are thin wrappers to a lower-level `diff_queue()` function that is
+ * flexible enough to record any of these kinds of changes.
+ *
+ * - Once you finish feeding the pairs of files, call `diffcore_std()`.
+ * This will tell the diffcore library to go ahead and do its work.
+ *
+ * - Calling `diff_flush()` will produce the output.
+ */
+
+struct combine_diff_path;
+struct commit;
+struct diff_filespec;
 struct diff_options;
 struct diff_queue_struct;
+struct oid_array;
+struct option;
+struct repository;
+struct rev_info;
 struct strbuf;
-struct diff_filespec;
 struct userdiff_driver;
-struct oid_array;
-struct commit;
-struct combine_diff_path;
 
 typedef int (*pathchange_fn_t)(struct diff_options *options,
 		 struct combine_diff_path *path);
@@ -63,37 +108,85 @@ typedef struct strbuf *(*diff_prefix_fn_
 
 #define DIFF_FLAGS_INIT { 0 }
 struct diff_flags {
-	unsigned recursive:1;
-	unsigned tree_in_recursive:1;
-	unsigned binary:1;
-	unsigned text:1;
-	unsigned full_index:1;
-	unsigned silent_on_remove:1;
-	unsigned find_copies_harder:1;
-	unsigned follow_renames:1;
-	unsigned rename_empty:1;
-	unsigned has_changes:1;
-	unsigned quick:1;
-	unsigned no_index:1;
-	unsigned allow_external:1;
-	unsigned exit_with_status:1;
-	unsigned reverse_diff:1;
-	unsigned check_failed:1;
-	unsigned relative_name:1;
-	unsigned ignore_submodules:1;
-	unsigned dirstat_cumulative:1;
-	unsigned dirstat_by_file:1;
-	unsigned allow_textconv:1;
-	unsigned textconv_set_via_cmdline:1;
-	unsigned diff_from_contents:1;
-	unsigned dirty_submodules:1;
-	unsigned ignore_untracked_in_submodules:1;
-	unsigned ignore_dirty_submodules:1;
-	unsigned override_submodule_config:1;
-	unsigned dirstat_by_line:1;
-	unsigned funccontext:1;
-	unsigned default_follow_renames:1;
-	unsigned stat_with_summary:1;
+
+	/**
+	 * Tells if tree traversal done by tree-diff should recursively descend
+	 * into a tree object pair that are different in preimage and postimage set.
+	 */
+	unsigned recursive;
+	unsigned tree_in_recursive;
+
+	/* Affects the way how a file that is seemingly binary is treated. */
+	unsigned binary;
+	unsigned text;
+
+	/**
+	 * Tells the patch output format not to use abbreviated object names on the
+	 * "index" lines.
+	 */
+	unsigned full_index;
+
+	/* Affects if diff-files shows removed files. */
+	unsigned silent_on_remove;
+
+	/**
+	 * Tells the diffcore library that the caller is feeding unchanged
+	 * filepairs to allow copies from unmodified files be detected.
+	 */
+	unsigned find_copies_harder;
+
+	unsigned follow_renames;
+	unsigned rename_empty;
+
+	/* Internal; used for optimization to see if there is any change. */
+	unsigned has_changes;
+
+	unsigned quick;
+
+	/**
+	 * Tells diff-files that the input is not tracked files but files in random
+	 * locations on the filesystem.
+	 */
+	unsigned no_index;
+
+	/**
+	 * Tells output routine that it is Ok to call user specified patch output
+	 * routine.  Plumbing disables this to ensure stable output.
+	 */
+	unsigned allow_external;
+
+	/**
+	 * For communication between the calling program and the options parser;
+	 * tell the calling program to signal the presence of difference using
+	 * program exit code.
+	 */
+	unsigned exit_with_status;
+
+	/**
+	 * Tells the library that the calling program is feeding the filepairs
+	 * reversed; `one` is two, and `two` is one.
+	 */
+	unsigned reverse_diff;
+
+	unsigned check_failed;
+	unsigned relative_name;
+	unsigned ignore_submodules;
+	unsigned dirstat_cumulative;
+	unsigned dirstat_by_file;
+	unsigned allow_textconv;
+	unsigned textconv_set_via_cmdline;
+	unsigned diff_from_contents;
+	unsigned dirty_submodules;
+	unsigned ignore_untracked_in_submodules;
+	unsigned ignore_dirty_submodules;
+	unsigned override_submodule_config;
+	unsigned dirstat_by_line;
+	unsigned funccontext;
+	unsigned default_follow_renames;
+	unsigned stat_with_summary;
+	unsigned suppress_diff_headers;
+	unsigned dual_color_diffed_diffs;
+	unsigned suppress_hunk_header_line_count;
 };
 
 static inline void diff_flags_or(struct diff_flags *a,
@@ -126,36 +219,72 @@ enum diff_submodule_format {
 	DIFF_SUBMODULE_INLINE_DIFF
 };
 
+/**
+ * the set of options the calling program wants to affect the operation of
+ * diffcore library with.
+ */
 struct diff_options {
 	const char *orderfile;
+
+	/**
+	 * A constant string (can and typically does contain newlines to look for
+	 * a block of text, not just a single line) to filter out the filepairs
+	 * that do not change the number of strings contained in its preimage and
+	 * postimage of the diff_queue.
+	 */
 	const char *pickaxe;
+
 	const char *single_follow;
 	const char *a_prefix, *b_prefix;
 	const char *line_prefix;
 	size_t line_prefix_length;
+
+	/**
+	 * collection of boolean options that affects the operation, but some do
+	 * not have anything to do with the diffcore library.
+	 */
 	struct diff_flags flags;
 
 	/* diff-filter bits */
 	unsigned int filter;
 
 	int use_color;
+
+	/* Number of context lines to generate in patch output. */
 	int context;
+
 	int interhunkcontext;
+
+	/* Affects the way detection logic for complete rewrites, renames and
+	 * copies.
+	 */
 	int break_opt;
 	int detect_rename;
+
 	int irreversible_delete;
 	int skip_stat_unmatch;
 	int line_termination;
+
+	/* The output format used when `diff_flush()` is run. */
 	int output_format;
+
 	unsigned pickaxe_opts;
+
+	/* Affects the way detection logic for complete rewrites, renames and
+	 * copies.
+	 */
 	int rename_score;
 	int rename_limit;
+
 	int needed_rename_limit;
 	int degraded_cc_to_c;
 	int show_rename_progress;
 	int dirstat_permille;
 	int setup;
+
+	/* Number of hexdigits to abbreviate raw format output to. */
 	int abbrev;
+
 	int ita_invisible_in_index;
 /* white-space error highlighting */
 #define WSEH_NEW (1<<12)
@@ -165,7 +294,7 @@ struct diff_options {
 	const char *prefix;
 	int prefix_length;
 	const char *stat_sep;
-	long xdl_opts;
+	int xdl_opts;
 
 	/* see Documentation/diff-options.txt */
 	char **anchors;
@@ -187,11 +316,17 @@ struct diff_options {
 	/* to support internal diff recursion by --follow hack*/
 	int found_follow;
 
+	/* Callback which allows tweaking the options in diff_setup_done(). */
 	void (*set_default)(struct diff_options *);
 
 	FILE *file;
 	int close_file;
 
+#define OUTPUT_INDICATOR_NEW 0
+#define OUTPUT_INDICATOR_OLD 1
+#define OUTPUT_INDICATOR_CONTEXT 2
+	char output_indicators[3];
+
 	struct pathspec pathspec;
 	pathchange_fn_t pathchange;
 	change_fn_t change;
@@ -208,13 +343,24 @@ struct diff_options {
 	enum {
 		COLOR_MOVED_NO = 0,
 		COLOR_MOVED_PLAIN = 1,
-		COLOR_MOVED_ZEBRA = 2,
-		COLOR_MOVED_ZEBRA_DIM = 3,
+		COLOR_MOVED_BLOCKS = 2,
+		COLOR_MOVED_ZEBRA = 3,
+		COLOR_MOVED_ZEBRA_DIM = 4,
 	} color_moved;
 	#define COLOR_MOVED_DEFAULT COLOR_MOVED_ZEBRA
 	#define COLOR_MOVED_MIN_ALNUM_COUNT 20
+
+	/* XDF_WHITESPACE_FLAGS regarding block detection are set at 2, 3, 4 */
+	#define COLOR_MOVED_WS_ALLOW_INDENTATION_CHANGE (1<<5)
+	#define COLOR_MOVED_WS_ERROR (1<<0)
+	unsigned color_moved_ws_handling;
+
+	struct repository *repo;
+	struct option *parseopts;
 };
 
+unsigned diff_filter_bit(char status);
+
 void diff_emit_submodule_del(struct diff_options *o, const char *line);
 void diff_emit_submodule_add(struct diff_options *o, const char *line);
 void diff_emit_submodule_untracked(struct diff_options *o, const char *path);
@@ -224,6 +370,22 @@ void diff_emit_submodule_error(struct di
 void diff_emit_submodule_pipethrough(struct diff_options *o,
 				     const char *line, int len);
 
+struct diffstat_t {
+	int nr;
+	int alloc;
+	struct diffstat_file {
+		char *from_name;
+		char *name;
+		char *print_name;
+		const char *comments;
+		unsigned is_unmerged:1;
+		unsigned is_binary:1;
+		unsigned is_renamed:1;
+		unsigned is_interesting:1;
+		uintmax_t added, deleted;
+	} **files;
+};
+
 enum color_diff {
 	DIFF_RESET = 0,
 	DIFF_CONTEXT = 1,
@@ -241,8 +403,15 @@ enum color_diff {
 	DIFF_FILE_NEW_MOVED = 13,
 	DIFF_FILE_NEW_MOVED_ALT = 14,
 	DIFF_FILE_NEW_MOVED_DIM = 15,
-	DIFF_FILE_NEW_MOVED_ALT_DIM = 16
+	DIFF_FILE_NEW_MOVED_ALT_DIM = 16,
+	DIFF_CONTEXT_DIM = 17,
+	DIFF_FILE_OLD_DIM = 18,
+	DIFF_FILE_NEW_DIM = 19,
+	DIFF_CONTEXT_BOLD = 20,
+	DIFF_FILE_OLD_BOLD = 21,
+	DIFF_FILE_NEW_BOLD = 22,
 };
+
 const char *diff_get_color(int diff_use_color, enum color_diff ix);
 #define diff_get_color_opt(o, ix) \
 	diff_get_color((o)->use_color, ix)
@@ -253,15 +422,15 @@ const char *diff_line_prefix(struct diff
 
 extern const char mime_boundary_leader[];
 
-extern struct combine_diff_path *diff_tree_paths(
+struct combine_diff_path *diff_tree_paths(
 	struct combine_diff_path *p, const struct object_id *oid,
 	const struct object_id **parents_oid, int nparent,
 	struct strbuf *base, struct diff_options *opt);
-extern int diff_tree_oid(const struct object_id *old_oid,
-			 const struct object_id *new_oid,
-			 const char *base, struct diff_options *opt);
-extern int diff_root_tree_oid(const struct object_id *new_oid, const char *base,
-			      struct diff_options *opt);
+int diff_tree_oid(const struct object_id *old_oid,
+		  const struct object_id *new_oid,
+		  const char *base, struct diff_options *opt);
+int diff_root_tree_oid(const struct object_id *new_oid, const char *base,
+		       struct diff_options *opt);
 
 struct combine_diff_path {
 	struct combine_diff_path *next;
@@ -272,59 +441,66 @@ struct combine_diff_path {
 		char status;
 		unsigned int mode;
 		struct object_id oid;
+		struct strbuf path;
 	} parent[FLEX_ARRAY];
 };
 #define combine_diff_path_size(n, l) \
 	st_add4(sizeof(struct combine_diff_path), (l), 1, \
 		st_mult(sizeof(struct combine_diff_parent), (n)))
 
-extern void show_combined_diff(struct combine_diff_path *elem, int num_parent,
-			      int dense, struct rev_info *);
+void show_combined_diff(struct combine_diff_path *elem, int num_parent,
+			int dense, struct rev_info *);
 
-extern void diff_tree_combined(const struct object_id *oid, const struct oid_array *parents, int dense, struct rev_info *rev);
+void diff_tree_combined(const struct object_id *oid, const struct oid_array *parents, int dense, struct rev_info *rev);
 
-extern void diff_tree_combined_merge(const struct commit *commit, int dense, struct rev_info *rev);
+void diff_tree_combined_merge(const struct commit *commit, int dense, struct rev_info *rev);
 
 void diff_set_mnemonic_prefix(struct diff_options *options, const char *a, const char *b);
 
-extern int diff_can_quit_early(struct diff_options *);
+int diff_can_quit_early(struct diff_options *);
 
-extern void diff_addremove(struct diff_options *,
-			   int addremove,
-			   unsigned mode,
-			   const struct object_id *oid,
-			   int oid_valid,
-			   const char *fullpath, unsigned dirty_submodule);
-
-extern void diff_change(struct diff_options *,
-			unsigned mode1, unsigned mode2,
-			const struct object_id *old_oid,
-			const struct object_id *new_oid,
-			int old_oid_valid, int new_oid_valid,
-			const char *fullpath,
-			unsigned dirty_submodule1, unsigned dirty_submodule2);
+void diff_addremove(struct diff_options *,
+		    int addremove,
+		    unsigned mode,
+		    const struct object_id *oid,
+		    int oid_valid,
+		    const char *fullpath, unsigned dirty_submodule);
 
-extern struct diff_filepair *diff_unmerge(struct diff_options *, const char *path);
+void diff_change(struct diff_options *,
+		 unsigned mode1, unsigned mode2,
+		 const struct object_id *old_oid,
+		 const struct object_id *new_oid,
+		 int old_oid_valid, int new_oid_valid,
+		 const char *fullpath,
+		 unsigned dirty_submodule1, unsigned dirty_submodule2);
+
+struct diff_filepair *diff_unmerge(struct diff_options *, const char *path);
+
+void compute_diffstat(struct diff_options *options, struct diffstat_t *diffstat,
+		      struct diff_queue_struct *q);
+void free_diffstat_info(struct diffstat_t *diffstat);
 
 #define DIFF_SETUP_REVERSE      	1
-#define DIFF_SETUP_USE_CACHE		2
 #define DIFF_SETUP_USE_SIZE_CACHE	4
 
 /*
  * Poor man's alternative to parse-option, to allow both stuck form
  * (--option=value) and separate form (--option value).
  */
-extern int parse_long_opt(const char *opt, const char **argv,
-			 const char **optarg);
+int parse_long_opt(const char *opt, const char **argv,
+		   const char **optarg);
 
-extern int git_diff_basic_config(const char *var, const char *value, void *cb);
-extern int git_diff_heuristic_config(const char *var, const char *value, void *cb);
-extern void init_diff_ui_defaults(void);
-extern int git_diff_ui_config(const char *var, const char *value, void *cb);
-extern void diff_setup(struct diff_options *);
-extern int diff_opt_parse(struct diff_options *, const char **, int, const char *);
-extern void diff_setup_done(struct diff_options *);
-extern int git_config_rename(const char *var, const char *value);
+int git_diff_basic_config(const char *var, const char *value, void *cb);
+int git_diff_heuristic_config(const char *var, const char *value, void *cb);
+void init_diff_ui_defaults(void);
+int git_diff_ui_config(const char *var, const char *value, void *cb);
+#ifndef NO_THE_REPOSITORY_COMPATIBILITY_MACROS
+#define diff_setup(diffopts) repo_diff_setup(the_repository, diffopts)
+#endif
+void repo_diff_setup(struct repository *, struct diff_options *);
+int diff_opt_parse(struct diff_options *, const char **, int, const char *);
+void diff_setup_done(struct diff_options *);
+int git_config_rename(const char *var, const char *value);
 
 #define DIFF_DETECT_RENAME	1
 #define DIFF_DETECT_COPY	2
@@ -342,8 +518,8 @@ extern int git_config_rename(const char
 
 #define DIFF_PICKAXE_IGNORE_CASE	32
 
-extern void diffcore_std(struct diff_options *);
-extern void diffcore_fix_diff_index(struct diff_options *);
+void diffcore_std(struct diff_options *);
+void diffcore_fix_diff_index(void);
 
 #define COMMON_DIFF_OPTIONS_HELP \
 "\ncommon diff options:\n" \
@@ -373,9 +549,9 @@ extern void diffcore_fix_diff_index(stru
 "                show all files diff when -S is used and hit is found.\n" \
 "  -a  --text    treat all files as text.\n"
 
-extern int diff_queue_is_empty(void);
-extern void diff_flush(struct diff_options*);
-extern void diff_warn_rename_limit(const char *varname, int needed, int degraded_cc);
+int diff_queue_is_empty(void);
+void diff_flush(struct diff_options*);
+void diff_warn_rename_limit(const char *varname, int needed, int degraded_cc);
 
 /* diff-raw status letters */
 #define DIFF_STATUS_ADDED		'A'
@@ -397,24 +573,27 @@ extern void diff_warn_rename_limit(const
  * This is different from find_unique_abbrev() in that
  * it stuffs the result with dots for alignment.
  */
-extern const char *diff_aligned_abbrev(const struct object_id *sha1, int);
+const char *diff_aligned_abbrev(const struct object_id *sha1, int);
 
 /* do not report anything on removed paths */
 #define DIFF_SILENT_ON_REMOVED 01
 /* report racily-clean paths as modified */
 #define DIFF_RACY_IS_MODIFIED 02
-extern int run_diff_files(struct rev_info *revs, unsigned int option);
-extern int run_diff_index(struct rev_info *revs, int cached);
+int run_diff_files(struct rev_info *revs, unsigned int option);
+int run_diff_index(struct rev_info *revs, int cached);
 
-extern int do_diff_cache(const struct object_id *, struct diff_options *);
-extern int diff_flush_patch_id(struct diff_options *, struct object_id *, int);
+int do_diff_cache(const struct object_id *, struct diff_options *);
+int diff_flush_patch_id(struct diff_options *, struct object_id *, int, int);
+void flush_one_hunk(struct object_id *result, git_hash_ctx *ctx);
 
-extern int diff_result_code(struct diff_options *, int);
+int diff_result_code(struct diff_options *, int);
 
-extern void diff_no_index(struct rev_info *, int, const char **);
+int diff_no_index(struct rev_info *,
+		  int implicit_no_index, int, const char **);
 
-extern int index_differs_from(const char *def, const struct diff_flags *flags,
-			      int ita_invisible_in_index);
+int index_differs_from(struct repository *r, const char *def,
+		       const struct diff_flags *flags,
+		       int ita_invisible_in_index);
 
 /*
  * Fill the contents of the filespec "df", respecting any textconv defined by
@@ -427,30 +606,36 @@ extern int index_differs_from(const char
  * struct. If it is non-NULL, then "outbuf" points to a newly allocated buffer
  * that should be freed by the caller.
  */
-extern size_t fill_textconv(struct userdiff_driver *driver,
-			    struct diff_filespec *df,
-			    char **outbuf);
+size_t fill_textconv(struct repository *r,
+		     struct userdiff_driver *driver,
+		     struct diff_filespec *df,
+		     char **outbuf);
 
 /*
  * Look up the userdiff driver for the given filespec, and return it if
  * and only if it has textconv enabled (otherwise return NULL). The result
  * can be passed to fill_textconv().
  */
-extern struct userdiff_driver *get_textconv(struct diff_filespec *one);
+struct userdiff_driver *get_textconv(struct repository *r,
+				     struct diff_filespec *one);
 
 /*
  * Prepare diff_filespec and convert it using diff textconv API
  * if the textconv driver exists.
  * Return 1 if the conversion succeeds, 0 otherwise.
  */
-extern int textconv_object(const char *path, unsigned mode, const struct object_id *oid, int oid_valid, char **buf, unsigned long *buf_size);
-
-extern int parse_rename_score(const char **cp_p);
-
-extern long parse_algorithm_value(const char *value);
-
-extern void print_stat_summary(FILE *fp, int files,
-			       int insertions, int deletions);
-extern void setup_diff_pager(struct diff_options *);
+int textconv_object(struct repository *repo,
+		    const char *path,
+		    unsigned mode,
+		    const struct object_id *oid, int oid_valid,
+		    char **buf, unsigned long *buf_size);
+
+int parse_rename_score(const char **cp_p);
+
+long parse_algorithm_value(const char *value);
+
+void print_stat_summary(FILE *fp, int files,
+			int insertions, int deletions);
+void setup_diff_pager(struct diff_options *);
 
 #endif /* DIFF_H */
diff -pruN 1.2.1+git2.18.0-1/git/diff-lib.c 1.2.3+git2.25.1-1/git/diff-lib.c
--- 1.2.1+git2.18.0-1/git/diff-lib.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/diff-lib.c	2020-02-17 04:47:35.000000000 +0000
@@ -70,7 +70,7 @@ static int match_stat_with_submodule(str
 				     struct stat *st, unsigned ce_option,
 				     unsigned *dirty_submodule)
 {
-	int changed = ce_match_stat(ce, st, ce_option);
+	int changed = ie_match_stat(diffopt->repo->index, ce, st, ce_option);
 	if (S_ISGITLINK(ce->ce_mode)) {
 		struct diff_flags orig_flags = diffopt->flags;
 		if (!diffopt->flags.override_submodule_config)
@@ -93,15 +93,16 @@ int run_diff_files(struct rev_info *revs
 	unsigned ce_option = ((option & DIFF_RACY_IS_MODIFIED)
 			      ? CE_MATCH_RACY_IS_DIRTY : 0);
 	uint64_t start = getnanotime();
+	struct index_state *istate = revs->diffopt.repo->index;
 
 	diff_set_mnemonic_prefix(&revs->diffopt, "i/", "w/");
 
 	if (diff_unmerged_stage < 0)
 		diff_unmerged_stage = 2;
-	entries = active_nr;
+	entries = istate->cache_nr;
 	for (i = 0; i < entries; i++) {
 		unsigned int oldmode, newmode;
-		struct cache_entry *ce = active_cache[i];
+		struct cache_entry *ce = istate->cache[i];
 		int changed;
 		unsigned dirty_submodule = 0;
 		const struct object_id *old_oid, *new_oid;
@@ -109,7 +110,7 @@ int run_diff_files(struct rev_info *revs
 		if (diff_can_quit_early(&revs->diffopt))
 			break;
 
-		if (!ce_path_match(ce, &revs->prune_data, NULL))
+		if (!ce_path_match(istate, ce, &revs->prune_data, NULL))
 			continue;
 
 		if (ce_stage(ce)) {
@@ -145,7 +146,7 @@ int run_diff_files(struct rev_info *revs
 			dpath->mode = wt_mode;
 
 			while (i < entries) {
-				struct cache_entry *nce = active_cache[i];
+				struct cache_entry *nce = istate->cache[i];
 				int stage;
 
 				if (strcmp(ce->name, nce->name))
@@ -231,7 +232,7 @@ int run_diff_files(struct rev_info *revs
 
 		if (!changed && !dirty_submodule) {
 			ce_mark_uptodate(ce);
-			mark_fsmonitor_valid(ce);
+			mark_fsmonitor_valid(istate, ce);
 			if (!revs->diffopt.flags.find_copies_harder)
 				continue;
 		}
@@ -342,7 +343,7 @@ static int show_modified(struct rev_info
 	}
 
 	if (revs->combine_merges && !cached &&
-	    (oidcmp(oid, &old_entry->oid) || oidcmp(&old_entry->oid, &new_entry->oid))) {
+	    (!oideq(oid, &old_entry->oid) || !oideq(&old_entry->oid, &new_entry->oid))) {
 		struct combine_diff_path *p;
 		int pathlen = ce_namelen(new_entry);
 
@@ -366,7 +367,7 @@ static int show_modified(struct rev_info
 	}
 
 	oldmode = old_entry->ce_mode;
-	if (mode == oldmode && !oidcmp(oid, &old_entry->oid) && !dirty_submodule &&
+	if (mode == oldmode && oideq(oid, &old_entry->oid) && !dirty_submodule &&
 	    !revs->diffopt.flags.find_copies_harder)
 		return 0;
 
@@ -389,8 +390,12 @@ static void do_oneway_diff(struct unpack
 	struct rev_info *revs = o->unpack_data;
 	int match_missing, cached;
 
-	/* i-t-a entries do not actually exist in the index */
-	if (revs->diffopt.ita_invisible_in_index &&
+	/*
+	 * i-t-a entries do not actually exist in the index (if we're
+	 * looking at its content)
+	 */
+	if (o->index_only &&
+	    revs->diffopt.ita_invisible_in_index &&
 	    idx && ce_intent_to_add(idx)) {
 		idx = NULL;
 		if (!tree)
@@ -470,7 +475,9 @@ static int oneway_diff(const struct cach
 	if (tree == o->df_conflict_entry)
 		tree = NULL;
 
-	if (ce_path_match(idx ? idx : tree, &revs->prune_data, NULL)) {
+	if (ce_path_match(revs->diffopt.repo->index,
+			  idx ? idx : tree,
+			  &revs->prune_data, NULL)) {
 		do_oneway_diff(o, idx, tree);
 		if (diff_can_quit_early(&revs->diffopt)) {
 			o->exiting_early = 1;
@@ -502,7 +509,7 @@ static int diff_cache(struct rev_info *r
 	opts.merge = 1;
 	opts.fn = oneway_diff;
 	opts.unpack_data = revs;
-	opts.src_index = &the_index;
+	opts.src_index = revs->diffopt.repo->index;
 	opts.dst_index = NULL;
 	opts.pathspec = &revs->diffopt.pathspec;
 	opts.pathspec->recursive = 1;
@@ -514,17 +521,20 @@ static int diff_cache(struct rev_info *r
 int run_diff_index(struct rev_info *revs, int cached)
 {
 	struct object_array_entry *ent;
-	uint64_t start = getnanotime();
 
+	if (revs->pending.nr != 1)
+		BUG("run_diff_index must be passed exactly one tree");
+
+	trace_performance_enter();
 	ent = revs->pending.objects;
 	if (diff_cache(revs, &ent->item->oid, ent->name, cached))
 		exit(128);
 
 	diff_set_mnemonic_prefix(&revs->diffopt, "c/", cached ? "i/" : "w/");
-	diffcore_fix_diff_index(&revs->diffopt);
+	diffcore_fix_diff_index();
 	diffcore_std(&revs->diffopt);
 	diff_flush(&revs->diffopt);
-	trace_performance_since(start, "diff-index");
+	trace_performance_leave("diff-index");
 	return 0;
 }
 
@@ -532,7 +542,7 @@ int do_diff_cache(const struct object_id
 {
 	struct rev_info revs;
 
-	init_revisions(&revs, NULL);
+	repo_init_revisions(opt->repo, &revs, NULL);
 	copy_pathspec(&revs.prune_data, &opt->pathspec);
 	revs.diffopt = *opt;
 
@@ -541,13 +551,14 @@ int do_diff_cache(const struct object_id
 	return 0;
 }
 
-int index_differs_from(const char *def, const struct diff_flags *flags,
+int index_differs_from(struct repository *r,
+		       const char *def, const struct diff_flags *flags,
 		       int ita_invisible_in_index)
 {
 	struct rev_info rev;
 	struct setup_revision_opt opt;
 
-	init_revisions(&rev, NULL);
+	repo_init_revisions(r, &rev, NULL);
 	memset(&opt, 0, sizeof(opt));
 	opt.def = def;
 	setup_revisions(0, NULL, &rev, &opt);
diff -pruN 1.2.1+git2.18.0-1/git/diff-no-index.c 1.2.3+git2.25.1-1/git/diff-no-index.c
--- 1.2.1+git2.18.0-1/git/diff-no-index.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/diff-no-index.c	2020-02-17 04:47:35.000000000 +0000
@@ -14,6 +14,7 @@
 #include "revision.h"
 #include "log-tree.h"
 #include "builtin.h"
+#include "parse-options.h"
 #include "string-list.h"
 #include "dir.h"
 
@@ -233,30 +234,37 @@ static void fixup_paths(const char **pat
 	}
 }
 
-void diff_no_index(struct rev_info *revs,
-		   int argc, const char **argv)
+static const char * const diff_no_index_usage[] = {
+	N_("git diff --no-index [<options>] <path> <path>"),
+	NULL
+};
+
+int diff_no_index(struct rev_info *revs,
+		  int implicit_no_index,
+		  int argc, const char **argv)
 {
-	int i;
+	int i, no_index;
 	const char *paths[2];
 	struct strbuf replacement = STRBUF_INIT;
 	const char *prefix = revs->prefix;
-
-	diff_setup(&revs->diffopt);
-	for (i = 1; i < argc - 2; ) {
-		int j;
-		if (!strcmp(argv[i], "--no-index"))
-			i++;
-		else if (!strcmp(argv[i], "--"))
-			i++;
-		else {
-			j = diff_opt_parse(&revs->diffopt, argv + i, argc - i,
-					   revs->prefix);
-			if (j <= 0)
-				die("invalid diff option/value: %s", argv[i]);
-			i += j;
-		}
+	struct option no_index_options[] = {
+		OPT_BOOL_F(0, "no-index", &no_index, "",
+			   PARSE_OPT_NONEG | PARSE_OPT_HIDDEN),
+		OPT_END(),
+	};
+	struct option *options;
+
+	options = parse_options_concat(no_index_options,
+				       revs->diffopt.parseopts);
+	argc = parse_options(argc, argv, revs->prefix, options,
+			     diff_no_index_usage, 0);
+	if (argc != 2) {
+		if (implicit_no_index)
+			warning(_("Not a git repository. Use --no-index to "
+				  "compare two paths outside a working tree"));
+		usage_with_options(diff_no_index_usage, options);
 	}
-
+	FREE_AND_NULL(options);
 	for (i = 0; i < 2; i++) {
 		const char *p = argv[argc - 2 + i];
 		if (!strcmp(p, "-"))
@@ -288,7 +296,7 @@ void diff_no_index(struct rev_info *revs
 	revs->diffopt.flags.exit_with_status = 1;
 
 	if (queue_diff(&revs->diffopt, paths[0], paths[1]))
-		exit(1);
+		return 1;
 	diff_set_mnemonic_prefix(&revs->diffopt, "1/", "2/");
 	diffcore_std(&revs->diffopt);
 	diff_flush(&revs->diffopt);
@@ -299,5 +307,5 @@ void diff_no_index(struct rev_info *revs
 	 * The return code for --no-index imitates diff(1):
 	 * 0 = no changes, 1 = changes, else error
 	 */
-	exit(diff_result_code(&revs->diffopt, 0));
+	return diff_result_code(&revs->diffopt, 0);
 }
diff -pruN 1.2.1+git2.18.0-1/git/dir.c 1.2.3+git2.25.1-1/git/dir.c
--- 1.2.1+git2.18.0-1/git/dir.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/dir.c	2020-02-17 04:47:35.000000000 +0000
@@ -2,15 +2,13 @@
  * This handles recursive filename detection with exclude
  * files, index knowledge etc..
  *
- * See Documentation/technical/api-directory-listing.txt
- *
  * Copyright (C) Linus Torvalds, 2005-2006
  *		 Junio Hamano, 2005-2006
  */
-#define NO_THE_INDEX_COMPATIBILITY_MACROS
 #include "cache.h"
 #include "config.h"
 #include "dir.h"
+#include "object-store.h"
 #include "attr.h"
 #include "refs.h"
 #include "wildmatch.h"
@@ -43,7 +41,8 @@ struct cached_dir {
 	int nr_files;
 	int nr_dirs;
 
-	struct dirent *de;
+	const char *d_name;
+	int d_type;
 	const char *file;
 	struct untracked_cache_dir *ucd;
 };
@@ -52,8 +51,8 @@ static enum path_treatment read_director
 	struct index_state *istate, const char *path, int len,
 	struct untracked_cache_dir *untracked,
 	int check_only, int stop_at_first_file, const struct pathspec *pathspec);
-static int get_dtype(struct dirent *de, struct index_state *istate,
-		     const char *path, int len);
+static int resolve_dtype(int dtype, struct index_state *istate,
+			 const char *path, int len);
 
 int count_slashes(const char *s)
 {
@@ -139,7 +138,7 @@ static size_t common_prefix_len(const st
 	 * ":(icase)path" is treated as a pathspec full of
 	 * wildcard. In other words, only prefix is considered common
 	 * prefix. If the pathspec is abc/foo abc/bar, running in
-	 * subdir xyz, the common prefix is still xyz, not xuz/abc as
+	 * subdir xyz, the common prefix is still xyz, not xyz/abc as
 	 * in non-:(icase).
 	 */
 	GUARD_PATHSPEC(pathspec,
@@ -273,51 +272,33 @@ static int do_read_blob(const struct obj
 
 #define DO_MATCH_EXCLUDE   (1<<0)
 #define DO_MATCH_DIRECTORY (1<<1)
-#define DO_MATCH_SUBMODULE (1<<2)
-
-static int match_attrs(const char *name, int namelen,
-		       const struct pathspec_item *item)
-{
-	int i;
-
-	git_check_attr(name, item->attr_check);
-	for (i = 0; i < item->attr_match_nr; i++) {
-		const char *value;
-		int matched;
-		enum attr_match_mode match_mode;
-
-		value = item->attr_check->items[i].value;
-		match_mode = item->attr_match[i].match_mode;
-
-		if (ATTR_TRUE(value))
-			matched = (match_mode == MATCH_SET);
-		else if (ATTR_FALSE(value))
-			matched = (match_mode == MATCH_UNSET);
-		else if (ATTR_UNSET(value))
-			matched = (match_mode == MATCH_UNSPECIFIED);
-		else
-			matched = (match_mode == MATCH_VALUE &&
-				   !strcmp(item->attr_match[i].value, value));
-		if (!matched)
-			return 0;
-	}
-
-	return 1;
-}
+#define DO_MATCH_LEADING_PATHSPEC (1<<2)
 
 /*
- * Does 'match' match the given name?
- * A match is found if
+ * Does the given pathspec match the given name?  A match is found if
+ *
+ * (1) the pathspec string is leading directory of 'name' ("RECURSIVELY"), or
+ * (2) the pathspec string has a leading part matching 'name' ("LEADING"), or
+ * (3) the pathspec string is a wildcard and matches 'name' ("WILDCARD"), or
+ * (4) the pathspec string is exactly the same as 'name' ("EXACT").
  *
- * (1) the 'match' string is leading directory of 'name', or
- * (2) the 'match' string is a wildcard and matches 'name', or
- * (3) the 'match' string is exactly the same as 'name'.
+ * Return value tells which case it was (1-4), or 0 when there is no match.
  *
- * and the return value tells which case it was.
+ * It may be instructive to look at a small table of concrete examples
+ * to understand the differences between 1, 2, and 4:
  *
- * It returns 0 when there is no match.
+ *                              Pathspecs
+ *                |    a/b    |   a/b/    |   a/b/c
+ *          ------+-----------+-----------+------------
+ *          a/b   |  EXACT    |  EXACT[1] | LEADING[2]
+ *  Names   a/b/  | RECURSIVE |   EXACT   | LEADING[2]
+ *          a/b/c | RECURSIVE | RECURSIVE |   EXACT
+ *
+ * [1] Only if DO_MATCH_DIRECTORY is passed; otherwise, this is NOT a match.
+ * [2] Only if DO_MATCH_LEADING_PATHSPEC is passed; otherwise, not a match.
  */
-static int match_pathspec_item(const struct pathspec_item *item, int prefix,
+static int match_pathspec_item(const struct index_state *istate,
+			       const struct pathspec_item *item, int prefix,
 			       const char *name, int namelen, unsigned flags)
 {
 	/* name/namelen has prefix cut off by caller */
@@ -357,7 +338,8 @@ static int match_pathspec_item(const str
 	    strncmp(item->match, name - prefix, item->prefix))
 		return 0;
 
-	if (item->attr_match_nr && !match_attrs(name, namelen, item))
+	if (item->attr_match_nr &&
+	    !match_pathspec_attrs(istate, name, namelen, item))
 		return 0;
 
 	/* If the match was just the prefix, we matched */
@@ -381,21 +363,29 @@ static int match_pathspec_item(const str
 			 item->nowildcard_len - prefix))
 		return MATCHED_FNMATCH;
 
-	/* Perform checks to see if "name" is a super set of the pathspec */
-	if (flags & DO_MATCH_SUBMODULE) {
+	/* Perform checks to see if "name" is a leading string of the pathspec */
+	if (flags & DO_MATCH_LEADING_PATHSPEC) {
 		/* name is a literal prefix of the pathspec */
+		int offset = name[namelen-1] == '/' ? 1 : 0;
 		if ((namelen < matchlen) &&
-		    (match[namelen] == '/') &&
+		    (match[namelen-offset] == '/') &&
 		    !ps_strncmp(item, match, name, namelen))
-			return MATCHED_RECURSIVELY;
+			return MATCHED_RECURSIVELY_LEADING_PATHSPEC;
 
-		/* name" doesn't match up to the first wild character */
+		/* name doesn't match up to the first wild character */
 		if (item->nowildcard_len < item->len &&
 		    ps_strncmp(item, match, name,
 			       item->nowildcard_len - prefix))
 			return 0;
 
 		/*
+		 * name has no wildcard, and it didn't match as a leading
+		 * pathspec so return.
+		 */
+		if (item->nowildcard_len == item->len)
+			return 0;
+
+		/*
 		 * Here is where we would perform a wildmatch to check if
 		 * "name" can be matched as a directory (or a prefix) against
 		 * the pathspec.  Since wildmatch doesn't have this capability
@@ -404,7 +394,7 @@ static int match_pathspec_item(const str
 		 * The submodules themselves will be able to perform more
 		 * accurate matching to determine if the pathspec matches.
 		 */
-		return MATCHED_RECURSIVELY;
+		return MATCHED_RECURSIVELY_LEADING_PATHSPEC;
 	}
 
 	return 0;
@@ -425,7 +415,8 @@ static int match_pathspec_item(const str
  * pathspec did not match any names, which could indicate that the
  * user mistyped the nth pathspec.
  */
-static int do_match_pathspec(const struct pathspec *ps,
+static int do_match_pathspec(const struct index_state *istate,
+			     const struct pathspec *ps,
 			     const char *name, int namelen,
 			     int prefix, char *seen,
 			     unsigned flags)
@@ -471,7 +462,7 @@ static int do_match_pathspec(const struc
 		 */
 		if (seen && ps->items[i].magic & PATHSPEC_EXCLUDE)
 			seen[i] = MATCHED_FNMATCH;
-		how = match_pathspec_item(ps->items+i, prefix, name,
+		how = match_pathspec_item(istate, ps->items+i, prefix, name,
 					  namelen, flags);
 		if (ps->recursive &&
 		    (ps->magic & PATHSPEC_MAXDEPTH) &&
@@ -495,17 +486,18 @@ static int do_match_pathspec(const struc
 	return retval;
 }
 
-int match_pathspec(const struct pathspec *ps,
+int match_pathspec(const struct index_state *istate,
+		   const struct pathspec *ps,
 		   const char *name, int namelen,
 		   int prefix, char *seen, int is_dir)
 {
 	int positive, negative;
 	unsigned flags = is_dir ? DO_MATCH_DIRECTORY : 0;
-	positive = do_match_pathspec(ps, name, namelen,
+	positive = do_match_pathspec(istate, ps, name, namelen,
 				     prefix, seen, flags);
 	if (!(ps->magic & PATHSPEC_EXCLUDE) || !positive)
 		return positive;
-	negative = do_match_pathspec(ps, name, namelen,
+	negative = do_match_pathspec(istate, ps, name, namelen,
 				     prefix, seen,
 				     flags | DO_MATCH_EXCLUDE);
 	return negative ? 0 : positive;
@@ -514,21 +506,21 @@ int match_pathspec(const struct pathspec
 /**
  * Check if a submodule is a superset of the pathspec
  */
-int submodule_path_match(const struct pathspec *ps,
+int submodule_path_match(const struct index_state *istate,
+			 const struct pathspec *ps,
 			 const char *submodule_name,
 			 char *seen)
 {
-	int matched = do_match_pathspec(ps, submodule_name,
+	int matched = do_match_pathspec(istate, ps, submodule_name,
 					strlen(submodule_name),
 					0, seen,
 					DO_MATCH_DIRECTORY |
-					DO_MATCH_SUBMODULE);
+					DO_MATCH_LEADING_PATHSPEC);
 	return matched;
 }
 
 int report_path_error(const char *ps_matched,
-		      const struct pathspec *pathspec,
-		      const char *prefix)
+		      const struct pathspec *pathspec)
 {
 	/*
 	 * Make sure all pathspec matched; otherwise it is an error.
@@ -560,7 +552,7 @@ int report_path_error(const char *ps_mat
 		if (found_dup)
 			continue;
 
-		error("pathspec '%s' did not match any file(s) known to git.",
+		error(_("pathspec '%s' did not match any file(s) known to git"),
 		      pathspec->items[num].original);
 		errors++;
 	}
@@ -587,7 +579,7 @@ int no_wildcard(const char *string)
 	return string[simple_length(string)] == '\0';
 }
 
-void parse_exclude_pattern(const char **pattern,
+void parse_path_pattern(const char **pattern,
 			   int *patternlen,
 			   unsigned *flags,
 			   int *nowildcardlen)
@@ -597,20 +589,20 @@ void parse_exclude_pattern(const char **
 
 	*flags = 0;
 	if (*p == '!') {
-		*flags |= EXC_FLAG_NEGATIVE;
+		*flags |= PATTERN_FLAG_NEGATIVE;
 		p++;
 	}
 	len = strlen(p);
 	if (len && p[len - 1] == '/') {
 		len--;
-		*flags |= EXC_FLAG_MUSTBEDIR;
+		*flags |= PATTERN_FLAG_MUSTBEDIR;
 	}
 	for (i = 0; i < len; i++) {
 		if (p[i] == '/')
 			break;
 	}
 	if (i == len)
-		*flags |= EXC_FLAG_NODIR;
+		*flags |= PATTERN_FLAG_NODIR;
 	*nowildcardlen = simple_length(p);
 	/*
 	 * we should have excluded the trailing slash from 'p' too,
@@ -620,35 +612,190 @@ void parse_exclude_pattern(const char **
 	if (*nowildcardlen > len)
 		*nowildcardlen = len;
 	if (*p == '*' && no_wildcard(p + 1))
-		*flags |= EXC_FLAG_ENDSWITH;
+		*flags |= PATTERN_FLAG_ENDSWITH;
 	*pattern = p;
 	*patternlen = len;
 }
 
-void add_exclude(const char *string, const char *base,
-		 int baselen, struct exclude_list *el, int srcpos)
+int pl_hashmap_cmp(const void *unused_cmp_data,
+		   const struct hashmap_entry *a,
+		   const struct hashmap_entry *b,
+		   const void *key)
+{
+	const struct pattern_entry *ee1 =
+			container_of(a, struct pattern_entry, ent);
+	const struct pattern_entry *ee2 =
+			container_of(b, struct pattern_entry, ent);
+
+	size_t min_len = ee1->patternlen <= ee2->patternlen
+			 ? ee1->patternlen
+			 : ee2->patternlen;
+
+	if (ignore_case)
+		return strncasecmp(ee1->pattern, ee2->pattern, min_len);
+	return strncmp(ee1->pattern, ee2->pattern, min_len);
+}
+
+static void add_pattern_to_hashsets(struct pattern_list *pl, struct path_pattern *given)
 {
-	struct exclude *x;
+	struct pattern_entry *translated;
+	char *truncated;
+	char *data = NULL;
+
+	if (!pl->use_cone_patterns)
+		return;
+
+	if (given->flags & PATTERN_FLAG_NEGATIVE &&
+	    given->flags & PATTERN_FLAG_MUSTBEDIR &&
+	    !strcmp(given->pattern, "/*")) {
+		pl->full_cone = 0;
+		return;
+	}
+
+	if (!given->flags && !strcmp(given->pattern, "/*")) {
+		pl->full_cone = 1;
+		return;
+	}
+
+	if (given->patternlen > 2 &&
+	    !strcmp(given->pattern + given->patternlen - 2, "/*")) {
+		if (!(given->flags & PATTERN_FLAG_NEGATIVE)) {
+			/* Not a cone pattern. */
+			pl->use_cone_patterns = 0;
+			warning(_("unrecognized pattern: '%s'"), given->pattern);
+			goto clear_hashmaps;
+		}
+
+		truncated = xstrdup(given->pattern);
+		truncated[given->patternlen - 2] = 0;
+
+		translated = xmalloc(sizeof(struct pattern_entry));
+		translated->pattern = truncated;
+		translated->patternlen = given->patternlen - 2;
+		hashmap_entry_init(&translated->ent,
+				   ignore_case ?
+				   strihash(translated->pattern) :
+				   strhash(translated->pattern));
+
+		if (!hashmap_get_entry(&pl->recursive_hashmap,
+				       translated, ent, NULL)) {
+			/* We did not see the "parent" included */
+			warning(_("unrecognized negative pattern: '%s'"),
+				given->pattern);
+			free(truncated);
+			free(translated);
+			goto clear_hashmaps;
+		}
+
+		hashmap_add(&pl->parent_hashmap, &translated->ent);
+		hashmap_remove(&pl->recursive_hashmap, &translated->ent, &data);
+		free(data);
+		return;
+	}
+
+	if (given->flags & PATTERN_FLAG_NEGATIVE) {
+		warning(_("unrecognized negative pattern: '%s'"),
+			given->pattern);
+		goto clear_hashmaps;
+	}
+
+	translated = xmalloc(sizeof(struct pattern_entry));
+
+	translated->pattern = xstrdup(given->pattern);
+	translated->patternlen = given->patternlen;
+	hashmap_entry_init(&translated->ent,
+			   ignore_case ?
+			   strihash(translated->pattern) :
+			   strhash(translated->pattern));
+
+	hashmap_add(&pl->recursive_hashmap, &translated->ent);
+
+	if (hashmap_get_entry(&pl->parent_hashmap, translated, ent, NULL)) {
+		/* we already included this at the parent level */
+		warning(_("your sparse-checkout file may have issues: pattern '%s' is repeated"),
+			given->pattern);
+		hashmap_remove(&pl->parent_hashmap, &translated->ent, &data);
+		free(data);
+		free(translated);
+	}
+
+	return;
+
+clear_hashmaps:
+	warning(_("disabling cone pattern matching"));
+	hashmap_free_entries(&pl->parent_hashmap, struct pattern_entry, ent);
+	hashmap_free_entries(&pl->recursive_hashmap, struct pattern_entry, ent);
+	pl->use_cone_patterns = 0;
+}
+
+static int hashmap_contains_path(struct hashmap *map,
+				 struct strbuf *pattern)
+{
+	struct pattern_entry p;
+
+	/* Check straight mapping */
+	p.pattern = pattern->buf;
+	p.patternlen = pattern->len;
+	hashmap_entry_init(&p.ent,
+			   ignore_case ?
+			   strihash(p.pattern) :
+			   strhash(p.pattern));
+	return !!hashmap_get_entry(map, &p, ent, NULL);
+}
+
+int hashmap_contains_parent(struct hashmap *map,
+			    const char *path,
+			    struct strbuf *buffer)
+{
+	char *slash_pos;
+
+	strbuf_setlen(buffer, 0);
+
+	if (path[0] != '/')
+		strbuf_addch(buffer, '/');
+
+	strbuf_addstr(buffer, path);
+
+	slash_pos = strrchr(buffer->buf, '/');
+
+	while (slash_pos > buffer->buf) {
+		strbuf_setlen(buffer, slash_pos - buffer->buf);
+
+		if (hashmap_contains_path(map, buffer))
+			return 1;
+
+		slash_pos = strrchr(buffer->buf, '/');
+	}
+
+	return 0;
+}
+
+void add_pattern(const char *string, const char *base,
+		 int baselen, struct pattern_list *pl, int srcpos)
+{
+	struct path_pattern *pattern;
 	int patternlen;
 	unsigned flags;
 	int nowildcardlen;
 
-	parse_exclude_pattern(&string, &patternlen, &flags, &nowildcardlen);
-	if (flags & EXC_FLAG_MUSTBEDIR) {
-		FLEXPTR_ALLOC_MEM(x, pattern, string, patternlen);
+	parse_path_pattern(&string, &patternlen, &flags, &nowildcardlen);
+	if (flags & PATTERN_FLAG_MUSTBEDIR) {
+		FLEXPTR_ALLOC_MEM(pattern, pattern, string, patternlen);
 	} else {
-		x = xmalloc(sizeof(*x));
-		x->pattern = string;
+		pattern = xmalloc(sizeof(*pattern));
+		pattern->pattern = string;
 	}
-	x->patternlen = patternlen;
-	x->nowildcardlen = nowildcardlen;
-	x->base = base;
-	x->baselen = baselen;
-	x->flags = flags;
-	x->srcpos = srcpos;
-	ALLOC_GROW(el->excludes, el->nr + 1, el->alloc);
-	el->excludes[el->nr++] = x;
-	x->el = el;
+	pattern->patternlen = patternlen;
+	pattern->nowildcardlen = nowildcardlen;
+	pattern->base = base;
+	pattern->baselen = baselen;
+	pattern->flags = flags;
+	pattern->srcpos = srcpos;
+	ALLOC_GROW(pl->patterns, pl->nr + 1, pl->alloc);
+	pl->patterns[pl->nr++] = pattern;
+	pattern->pl = pl;
+
+	add_pattern_to_hashsets(pl, pattern);
 }
 
 static int read_skip_worktree_file_from_index(const struct index_state *istate,
@@ -669,19 +816,19 @@ static int read_skip_worktree_file_from_
 }
 
 /*
- * Frees memory within el which was allocated for exclude patterns and
- * the file buffer.  Does not free el itself.
+ * Frees memory within pl which was allocated for exclude patterns and
+ * the file buffer.  Does not free pl itself.
  */
-void clear_exclude_list(struct exclude_list *el)
+void clear_pattern_list(struct pattern_list *pl)
 {
 	int i;
 
-	for (i = 0; i < el->nr; i++)
-		free(el->excludes[i]);
-	free(el->excludes);
-	free(el->filebuf);
+	for (i = 0; i < pl->nr; i++)
+		free(pl->patterns[i]);
+	free(pl->patterns);
+	free(pl->filebuf);
 
-	memset(el, 0, sizeof(*el));
+	memset(pl, 0, sizeof(*pl));
 }
 
 static void trim_trailing_spaces(char *buf)
@@ -727,7 +874,7 @@ static struct untracked_cache_dir *looku
 	first = 0;
 	last = dir->dirs_nr;
 	while (last > first) {
-		int cmp, next = (last + first) >> 1;
+		int cmp, next = first + ((last - first) >> 1);
 		d = dir->dirs[next];
 		cmp = strncmp(name, d->name, len);
 		if (!cmp && strlen(d->name) > len)
@@ -788,21 +935,21 @@ static void invalidate_directory(struct
 		dir->dirs[i]->recurse = 0;
 }
 
-static int add_excludes_from_buffer(char *buf, size_t size,
+static int add_patterns_from_buffer(char *buf, size_t size,
 				    const char *base, int baselen,
-				    struct exclude_list *el);
+				    struct pattern_list *pl);
 
 /*
  * Given a file with name "fname", read it (either from disk, or from
  * an index if 'istate' is non-null), parse it and store the
- * exclude rules in "el".
+ * exclude rules in "pl".
  *
  * If "ss" is not NULL, compute SHA-1 of the exclude file and fill
- * stat data from disk (only valid if add_excludes returns zero). If
+ * stat data from disk (only valid if add_patterns returns zero). If
  * ss_valid is non-zero, "ss" must contain good value as input.
  */
-static int add_excludes(const char *fname, const char *base, int baselen,
-			struct exclude_list *el, struct index_state *istate,
+static int add_patterns(const char *fname, const char *base, int baselen,
+			struct pattern_list *pl, struct index_state *istate,
 			struct oid_stat *oid_stat)
 {
 	struct stat st;
@@ -863,21 +1010,24 @@ static int add_excludes(const char *fnam
 		}
 	}
 
-	add_excludes_from_buffer(buf, size, base, baselen, el);
+	add_patterns_from_buffer(buf, size, base, baselen, pl);
 	return 0;
 }
 
-static int add_excludes_from_buffer(char *buf, size_t size,
+static int add_patterns_from_buffer(char *buf, size_t size,
 				    const char *base, int baselen,
-				    struct exclude_list *el)
+				    struct pattern_list *pl)
 {
 	int i, lineno = 1;
 	char *entry;
 
-	el->filebuf = buf;
+	hashmap_init(&pl->recursive_hashmap, pl_hashmap_cmp, NULL, 0);
+	hashmap_init(&pl->parent_hashmap, pl_hashmap_cmp, NULL, 0);
+
+	pl->filebuf = buf;
 
 	if (skip_utf8_bom(&buf, size))
-		size -= buf - el->filebuf;
+		size -= buf - pl->filebuf;
 
 	entry = buf;
 
@@ -886,7 +1036,7 @@ static int add_excludes_from_buffer(char
 			if (entry != buf + i && entry[0] != '#') {
 				buf[i - (i && buf[i-1] == '\r')] = 0;
 				trim_trailing_spaces(entry);
-				add_exclude(entry, base, baselen, el, lineno);
+				add_pattern(entry, base, baselen, pl, lineno);
 			}
 			lineno++;
 			entry = buf + i + 1;
@@ -895,17 +1045,17 @@ static int add_excludes_from_buffer(char
 	return 0;
 }
 
-int add_excludes_from_file_to_list(const char *fname, const char *base,
-				   int baselen, struct exclude_list *el,
+int add_patterns_from_file_to_list(const char *fname, const char *base,
+				   int baselen, struct pattern_list *pl,
 				   struct index_state *istate)
 {
-	return add_excludes(fname, base, baselen, el, istate, NULL);
+	return add_patterns(fname, base, baselen, pl, istate, NULL);
 }
 
-int add_excludes_from_blob_to_list(
+int add_patterns_from_blob_to_list(
 	struct object_id *oid,
 	const char *base, int baselen,
-	struct exclude_list *el)
+	struct pattern_list *pl)
 {
 	char *buf;
 	size_t size;
@@ -915,31 +1065,31 @@ int add_excludes_from_blob_to_list(
 	if (r != 1)
 		return r;
 
-	add_excludes_from_buffer(buf, size, base, baselen, el);
+	add_patterns_from_buffer(buf, size, base, baselen, pl);
 	return 0;
 }
 
-struct exclude_list *add_exclude_list(struct dir_struct *dir,
+struct pattern_list *add_pattern_list(struct dir_struct *dir,
 				      int group_type, const char *src)
 {
-	struct exclude_list *el;
+	struct pattern_list *pl;
 	struct exclude_list_group *group;
 
 	group = &dir->exclude_list_group[group_type];
-	ALLOC_GROW(group->el, group->nr + 1, group->alloc);
-	el = &group->el[group->nr++];
-	memset(el, 0, sizeof(*el));
-	el->src = src;
-	return el;
+	ALLOC_GROW(group->pl, group->nr + 1, group->alloc);
+	pl = &group->pl[group->nr++];
+	memset(pl, 0, sizeof(*pl));
+	pl->src = src;
+	return pl;
 }
 
 /*
  * Used to set up core.excludesfile and .git/info/exclude lists.
  */
-static void add_excludes_from_file_1(struct dir_struct *dir, const char *fname,
+static void add_patterns_from_file_1(struct dir_struct *dir, const char *fname,
 				     struct oid_stat *oid_stat)
 {
-	struct exclude_list *el;
+	struct pattern_list *pl;
 	/*
 	 * catch setup_standard_excludes() that's called before
 	 * dir->untracked is assigned. That function behaves
@@ -947,15 +1097,15 @@ static void add_excludes_from_file_1(str
 	 */
 	if (!dir->untracked)
 		dir->unmanaged_exclude_files++;
-	el = add_exclude_list(dir, EXC_FILE, fname);
-	if (add_excludes(fname, "", 0, el, NULL, oid_stat) < 0)
-		die("cannot use %s as an exclude file", fname);
+	pl = add_pattern_list(dir, EXC_FILE, fname);
+	if (add_patterns(fname, "", 0, pl, NULL, oid_stat) < 0)
+		die(_("cannot use %s as an exclude file"), fname);
 }
 
-void add_excludes_from_file(struct dir_struct *dir, const char *fname)
+void add_patterns_from_file(struct dir_struct *dir, const char *fname)
 {
 	dir->unmanaged_exclude_files++; /* see validate_untracked_cache() */
-	add_excludes_from_file_1(dir, fname, NULL);
+	add_patterns_from_file_1(dir, fname, NULL);
 }
 
 int match_basename(const char *basename, int basenamelen,
@@ -966,7 +1116,7 @@ int match_basename(const char *basename,
 		if (patternlen == basenamelen &&
 		    !fspathncmp(pattern, basename, basenamelen))
 			return 1;
-	} else if (flags & EXC_FLAG_ENDSWITH) {
+	} else if (flags & PATTERN_FLAG_ENDSWITH) {
 		/* "*literal" matching against "fooliteral" */
 		if (patternlen - 1 <= basenamelen &&
 		    !fspathncmp(pattern + 1,
@@ -1047,85 +1197,138 @@ int match_pathname(const char *pathname,
  * any, determines the fate.  Returns the exclude_list element which
  * matched, or NULL for undecided.
  */
-static struct exclude *last_exclude_matching_from_list(const char *pathname,
+static struct path_pattern *last_matching_pattern_from_list(const char *pathname,
 						       int pathlen,
 						       const char *basename,
 						       int *dtype,
-						       struct exclude_list *el,
+						       struct pattern_list *pl,
 						       struct index_state *istate)
 {
-	struct exclude *exc = NULL; /* undecided */
+	struct path_pattern *res = NULL; /* undecided */
 	int i;
 
-	if (!el->nr)
+	if (!pl->nr)
 		return NULL;	/* undefined */
 
-	for (i = el->nr - 1; 0 <= i; i--) {
-		struct exclude *x = el->excludes[i];
-		const char *exclude = x->pattern;
-		int prefix = x->nowildcardlen;
-
-		if (x->flags & EXC_FLAG_MUSTBEDIR) {
-			if (*dtype == DT_UNKNOWN)
-				*dtype = get_dtype(NULL, istate, pathname, pathlen);
+	for (i = pl->nr - 1; 0 <= i; i--) {
+		struct path_pattern *pattern = pl->patterns[i];
+		const char *exclude = pattern->pattern;
+		int prefix = pattern->nowildcardlen;
+
+		if (pattern->flags & PATTERN_FLAG_MUSTBEDIR) {
+			*dtype = resolve_dtype(*dtype, istate, pathname, pathlen);
 			if (*dtype != DT_DIR)
 				continue;
 		}
 
-		if (x->flags & EXC_FLAG_NODIR) {
+		if (pattern->flags & PATTERN_FLAG_NODIR) {
 			if (match_basename(basename,
 					   pathlen - (basename - pathname),
-					   exclude, prefix, x->patternlen,
-					   x->flags)) {
-				exc = x;
+					   exclude, prefix, pattern->patternlen,
+					   pattern->flags)) {
+				res = pattern;
 				break;
 			}
 			continue;
 		}
 
-		assert(x->baselen == 0 || x->base[x->baselen - 1] == '/');
+		assert(pattern->baselen == 0 ||
+		       pattern->base[pattern->baselen - 1] == '/');
 		if (match_pathname(pathname, pathlen,
-				   x->base, x->baselen ? x->baselen - 1 : 0,
-				   exclude, prefix, x->patternlen, x->flags)) {
-			exc = x;
+				   pattern->base,
+				   pattern->baselen ? pattern->baselen - 1 : 0,
+				   exclude, prefix, pattern->patternlen,
+				   pattern->flags)) {
+			res = pattern;
 			break;
 		}
 	}
-	return exc;
+	return res;
 }
 
 /*
- * Scan the list and let the last match determine the fate.
- * Return 1 for exclude, 0 for include and -1 for undecided.
+ * Scan the list of patterns to determine if the ordered list
+ * of patterns matches on 'pathname'.
+ *
+ * Return 1 for a match, 0 for not matched and -1 for undecided.
  */
-int is_excluded_from_list(const char *pathname,
-			  int pathlen, const char *basename, int *dtype,
-			  struct exclude_list *el, struct index_state *istate)
+enum pattern_match_result path_matches_pattern_list(
+				const char *pathname, int pathlen,
+				const char *basename, int *dtype,
+				struct pattern_list *pl,
+				struct index_state *istate)
 {
-	struct exclude *exclude;
-	exclude = last_exclude_matching_from_list(pathname, pathlen, basename,
-						  dtype, el, istate);
-	if (exclude)
-		return exclude->flags & EXC_FLAG_NEGATIVE ? 0 : 1;
-	return -1; /* undecided */
+	struct path_pattern *pattern;
+	struct strbuf parent_pathname = STRBUF_INIT;
+	int result = NOT_MATCHED;
+	const char *slash_pos;
+
+	if (!pl->use_cone_patterns) {
+		pattern = last_matching_pattern_from_list(pathname, pathlen, basename,
+							dtype, pl, istate);
+		if (pattern) {
+			if (pattern->flags & PATTERN_FLAG_NEGATIVE)
+				return NOT_MATCHED;
+			else
+				return MATCHED;
+		}
+
+		return UNDECIDED;
+	}
+
+	if (pl->full_cone)
+		return MATCHED;
+
+	strbuf_addch(&parent_pathname, '/');
+	strbuf_add(&parent_pathname, pathname, pathlen);
+
+	if (hashmap_contains_path(&pl->recursive_hashmap,
+				  &parent_pathname)) {
+		result = MATCHED_RECURSIVE;
+		goto done;
+	}
+
+	slash_pos = strrchr(parent_pathname.buf, '/');
+
+	if (slash_pos == parent_pathname.buf) {
+		/* include every file in root */
+		result = MATCHED;
+		goto done;
+	}
+
+	strbuf_setlen(&parent_pathname, slash_pos - parent_pathname.buf);
+
+	if (hashmap_contains_path(&pl->parent_hashmap, &parent_pathname)) {
+		result = MATCHED;
+		goto done;
+	}
+
+	if (hashmap_contains_parent(&pl->recursive_hashmap,
+				    pathname,
+				    &parent_pathname))
+		result = MATCHED_RECURSIVE;
+
+done:
+	strbuf_release(&parent_pathname);
+	return result;
 }
 
-static struct exclude *last_exclude_matching_from_lists(struct dir_struct *dir,
-							struct index_state *istate,
-		const char *pathname, int pathlen, const char *basename,
-		int *dtype_p)
+static struct path_pattern *last_matching_pattern_from_lists(
+		struct dir_struct *dir, struct index_state *istate,
+		const char *pathname, int pathlen,
+		const char *basename, int *dtype_p)
 {
 	int i, j;
 	struct exclude_list_group *group;
-	struct exclude *exclude;
+	struct path_pattern *pattern;
 	for (i = EXC_CMDL; i <= EXC_FILE; i++) {
 		group = &dir->exclude_list_group[i];
 		for (j = group->nr - 1; j >= 0; j--) {
-			exclude = last_exclude_matching_from_list(
+			pattern = last_matching_pattern_from_list(
 				pathname, pathlen, basename, dtype_p,
-				&group->el[j], istate);
-			if (exclude)
-				return exclude;
+				&group->pl[j], istate);
+			if (pattern)
+				return pattern;
 		}
 	}
 	return NULL;
@@ -1140,7 +1343,7 @@ static void prep_exclude(struct dir_stru
 			 const char *base, int baselen)
 {
 	struct exclude_list_group *group;
-	struct exclude_list *el;
+	struct pattern_list *pl;
 	struct exclude_stack *stk = NULL;
 	struct untracked_cache_dir *untracked;
 	int current;
@@ -1156,17 +1359,17 @@ static void prep_exclude(struct dir_stru
 		if (stk->baselen <= baselen &&
 		    !strncmp(dir->basebuf.buf, base, stk->baselen))
 			break;
-		el = &group->el[dir->exclude_stack->exclude_ix];
+		pl = &group->pl[dir->exclude_stack->exclude_ix];
 		dir->exclude_stack = stk->prev;
-		dir->exclude = NULL;
-		free((char *)el->src); /* see strbuf_detach() below */
-		clear_exclude_list(el);
+		dir->pattern = NULL;
+		free((char *)pl->src); /* see strbuf_detach() below */
+		clear_pattern_list(pl);
 		free(stk);
 		group->nr--;
 	}
 
 	/* Skip traversing into sub directories if the parent is excluded */
-	if (dir->exclude)
+	if (dir->pattern)
 		return;
 
 	/*
@@ -1207,7 +1410,7 @@ static void prep_exclude(struct dir_stru
 		stk->baselen = cp - base;
 		stk->exclude_ix = group->nr;
 		stk->ucd = untracked;
-		el = add_exclude_list(dir, EXC_DIRS, NULL);
+		pl = add_pattern_list(dir, EXC_DIRS, NULL);
 		strbuf_add(&dir->basebuf, base + current, stk->baselen - current);
 		assert(stk->baselen == dir->basebuf.len);
 
@@ -1215,15 +1418,15 @@ static void prep_exclude(struct dir_stru
 		if (stk->baselen) {
 			int dt = DT_DIR;
 			dir->basebuf.buf[stk->baselen - 1] = 0;
-			dir->exclude = last_exclude_matching_from_lists(dir,
+			dir->pattern = last_matching_pattern_from_lists(dir,
 									istate,
 				dir->basebuf.buf, stk->baselen - 1,
 				dir->basebuf.buf + current, &dt);
 			dir->basebuf.buf[stk->baselen - 1] = '/';
-			if (dir->exclude &&
-			    dir->exclude->flags & EXC_FLAG_NEGATIVE)
-				dir->exclude = NULL;
-			if (dir->exclude) {
+			if (dir->pattern &&
+			    dir->pattern->flags & PATTERN_FLAG_NEGATIVE)
+				dir->pattern = NULL;
+			if (dir->pattern) {
 				dir->exclude_stack = stk;
 				return;
 			}
@@ -1249,34 +1452,34 @@ static void prep_exclude(struct dir_stru
 			/*
 			 * dir->basebuf gets reused by the traversal, but we
 			 * need fname to remain unchanged to ensure the src
-			 * member of each struct exclude correctly
+			 * member of each struct path_pattern correctly
 			 * back-references its source file.  Other invocations
-			 * of add_exclude_list provide stable strings, so we
+			 * of add_pattern_list provide stable strings, so we
 			 * strbuf_detach() and free() here in the caller.
 			 */
 			struct strbuf sb = STRBUF_INIT;
 			strbuf_addbuf(&sb, &dir->basebuf);
 			strbuf_addstr(&sb, dir->exclude_per_dir);
-			el->src = strbuf_detach(&sb, NULL);
-			add_excludes(el->src, el->src, stk->baselen, el, istate,
+			pl->src = strbuf_detach(&sb, NULL);
+			add_patterns(pl->src, pl->src, stk->baselen, pl, istate,
 				     untracked ? &oid_stat : NULL);
 		}
 		/*
 		 * NEEDSWORK: when untracked cache is enabled, prep_exclude()
 		 * will first be called in valid_cached_dir() then maybe many
-		 * times more in last_exclude_matching(). When the cache is
-		 * used, last_exclude_matching() will not be called and
+		 * times more in last_matching_pattern(). When the cache is
+		 * used, last_matching_pattern() will not be called and
 		 * reading .gitignore content will be a waste.
 		 *
 		 * So when it's called by valid_cached_dir() and we can get
 		 * .gitignore SHA-1 from the index (i.e. .gitignore is not
 		 * modified on work tree), we could delay reading the
 		 * .gitignore content until we absolutely need it in
-		 * last_exclude_matching(). Be careful about ignore rule
+		 * last_matching_pattern(). Be careful about ignore rule
 		 * order, though, if you do that.
 		 */
 		if (untracked &&
-		    oidcmp(&oid_stat.oid, &untracked->exclude_oid)) {
+		    !oideq(&oid_stat.oid, &untracked->exclude_oid)) {
 			invalidate_gitignore(dir->untracked, untracked);
 			oidcpy(&untracked->exclude_oid, &oid_stat.oid);
 		}
@@ -1292,7 +1495,7 @@ static void prep_exclude(struct dir_stru
  * Returns the exclude_list element which matched, or NULL for
  * undecided.
  */
-struct exclude *last_exclude_matching(struct dir_struct *dir,
+struct path_pattern *last_matching_pattern(struct dir_struct *dir,
 				      struct index_state *istate,
 				      const char *pathname,
 				      int *dtype_p)
@@ -1303,10 +1506,10 @@ struct exclude *last_exclude_matching(st
 
 	prep_exclude(dir, istate, pathname, basename-pathname);
 
-	if (dir->exclude)
-		return dir->exclude;
+	if (dir->pattern)
+		return dir->pattern;
 
-	return last_exclude_matching_from_lists(dir, istate, pathname, pathlen,
+	return last_matching_pattern_from_lists(dir, istate, pathname, pathlen,
 			basename, dtype_p);
 }
 
@@ -1318,10 +1521,10 @@ struct exclude *last_exclude_matching(st
 int is_excluded(struct dir_struct *dir, struct index_state *istate,
 		const char *pathname, int *dtype_p)
 {
-	struct exclude *exclude =
-		last_exclude_matching(dir, istate, pathname, dtype_p);
-	if (exclude)
-		return exclude->flags & EXC_FLAG_NEGATIVE ? 0 : 1;
+	struct path_pattern *pattern =
+		last_matching_pattern(dir, istate, pathname, dtype_p);
+	if (pattern)
+		return pattern->flags & PATTERN_FLAG_NEGATIVE ? 0 : 1;
 	return 0;
 }
 
@@ -1456,6 +1659,8 @@ static enum path_treatment treat_directo
 	const char *dirname, int len, int baselen, int exclude,
 	const struct pathspec *pathspec)
 {
+	int nested_repo = 0;
+
 	/* The "len-1" is to strip the final '/' */
 	switch (directory_exists_in_index(istate, dirname, len-1)) {
 	case index_directory:
@@ -1465,6 +1670,17 @@ static enum path_treatment treat_directo
 		return path_none;
 
 	case index_nonexistent:
+		if ((dir->flags & DIR_SKIP_NESTED_GIT) ||
+		    !(dir->flags & DIR_NO_GITLINKS)) {
+			struct strbuf sb = STRBUF_INIT;
+			strbuf_addstr(&sb, dirname);
+			nested_repo = is_nonbare_repository_dir(&sb);
+			strbuf_release(&sb);
+		}
+		if (nested_repo)
+			return ((dir->flags & DIR_SKIP_NESTED_GIT) ? path_none :
+				(exclude ? path_excluded : path_untracked));
+
 		if (dir->flags & DIR_SHOW_OTHER_DIRECTORIES)
 			break;
 		if (exclude &&
@@ -1491,11 +1707,6 @@ static enum path_treatment treat_directo
 
 			return path_none;
 		}
-		if (!(dir->flags & DIR_NO_GITLINKS)) {
-			struct object_id oid;
-			if (resolve_gitlink_ref(dirname, "HEAD", &oid) == 0)
-				return exclude ? path_excluded : path_untracked;
-		}
 		return path_recurse;
 	}
 
@@ -1631,10 +1842,9 @@ static int get_index_dtype(struct index_
 	return DT_UNKNOWN;
 }
 
-static int get_dtype(struct dirent *de, struct index_state *istate,
-		     const char *path, int len)
+static int resolve_dtype(int dtype, struct index_state *istate,
+			 const char *path, int len)
 {
-	int dtype = de ? DTYPE(de) : DT_UNKNOWN;
 	struct stat st;
 
 	if (dtype != DT_UNKNOWN)
@@ -1659,14 +1869,13 @@ static enum path_treatment treat_one_pat
 					  struct strbuf *path,
 					  int baselen,
 					  const struct pathspec *pathspec,
-					  int dtype, struct dirent *de)
+					  int dtype)
 {
 	int exclude;
 	int has_path_in_index = !!index_file_exists(istate, path->buf, path->len, ignore_case);
 	enum path_treatment path_treatment;
 
-	if (dtype == DT_UNKNOWN)
-		dtype = get_dtype(de, istate, path->buf, path->len);
+	dtype = resolve_dtype(dtype, istate, path->buf, path->len);
 
 	/* Always exclude indexed files */
 	if (dtype != DT_DIR && has_path_in_index)
@@ -1774,21 +1983,18 @@ static enum path_treatment treat_path(st
 				      int baselen,
 				      const struct pathspec *pathspec)
 {
-	int dtype;
-	struct dirent *de = cdir->de;
-
-	if (!de)
+	if (!cdir->d_name)
 		return treat_path_fast(dir, untracked, cdir, istate, path,
 				       baselen, pathspec);
-	if (is_dot_or_dotdot(de->d_name) || !fspathcmp(de->d_name, ".git"))
+	if (is_dot_or_dotdot(cdir->d_name) || !fspathcmp(cdir->d_name, ".git"))
 		return path_none;
 	strbuf_setlen(path, baselen);
-	strbuf_addstr(path, de->d_name);
+	strbuf_addstr(path, cdir->d_name);
 	if (simplify_away(path->buf, path->len, pathspec))
 		return path_none;
 
-	dtype = DTYPE(de);
-	return treat_one_path(dir, untracked, istate, path, baselen, pathspec, dtype, de);
+	return treat_one_path(dir, untracked, istate, path, baselen, pathspec,
+			      cdir->d_type);
 }
 
 static void add_untracked(struct untracked_cache_dir *dir, const char *name)
@@ -1832,7 +2038,7 @@ static int valid_cached_dir(struct dir_s
 
 	/*
 	 * prep_exclude will be called eventually on this directory,
-	 * but it's called much later in last_exclude_matching(). We
+	 * but it's called much later in last_matching_pattern(). We
 	 * need it now to determine the validity of the cache for this
 	 * path. The next calls will be nearly no-op, the way
 	 * prep_exclude() is designed.
@@ -1876,10 +2082,17 @@ static int open_cached_dir(struct cached
 
 static int read_cached_dir(struct cached_dir *cdir)
 {
+	struct dirent *de;
+
 	if (cdir->fdir) {
-		cdir->de = readdir(cdir->fdir);
-		if (!cdir->de)
+		de = readdir(cdir->fdir);
+		if (!de) {
+			cdir->d_name = NULL;
+			cdir->d_type = DT_UNKNOWN;
 			return -1;
+		}
+		cdir->d_name = de->d_name;
+		cdir->d_type = DTYPE(de);
 		return 0;
 	}
 	while (cdir->nr_dirs < cdir->untracked->dirs_nr) {
@@ -1915,6 +2128,40 @@ static void close_cached_dir(struct cach
 	}
 }
 
+static void add_path_to_appropriate_result_list(struct dir_struct *dir,
+	struct untracked_cache_dir *untracked,
+	struct cached_dir *cdir,
+	struct index_state *istate,
+	struct strbuf *path,
+	int baselen,
+	const struct pathspec *pathspec,
+	enum path_treatment state)
+{
+	/* add the path to the appropriate result list */
+	switch (state) {
+	case path_excluded:
+		if (dir->flags & DIR_SHOW_IGNORED)
+			dir_add_name(dir, istate, path->buf, path->len);
+		else if ((dir->flags & DIR_SHOW_IGNORED_TOO) ||
+			((dir->flags & DIR_COLLECT_IGNORED) &&
+			exclude_matches_pathspec(path->buf, path->len,
+						 pathspec)))
+			dir_add_ignored(dir, istate, path->buf, path->len);
+		break;
+
+	case path_untracked:
+		if (dir->flags & DIR_SHOW_IGNORED)
+			break;
+		dir_add_name(dir, istate, path->buf, path->len);
+		if (cdir->fdir)
+			add_untracked(untracked, path->buf + baselen);
+		break;
+
+	default:
+		break;
+	}
+}
+
 /*
  * Read a directory tree. We currently ignore anything but
  * directories, regular files and symlinks. That's because git
@@ -1939,6 +2186,15 @@ static enum path_treatment read_director
 	struct untracked_cache_dir *untracked, int check_only,
 	int stop_at_first_file, const struct pathspec *pathspec)
 {
+	/*
+	 * WARNING WARNING WARNING:
+	 *
+	 * Any updates to the traversal logic here may need corresponding
+	 * updates in treat_leading_path().  See the commit message for the
+	 * commit adding this warning as well as the commit preceding it
+	 * for details.
+	 */
+
 	struct cached_dir cdir;
 	enum path_treatment state, subdir_state, dir_state = path_none;
 	struct strbuf path = STRBUF_INIT;
@@ -1962,8 +2218,11 @@ static enum path_treatment read_director
 		/* recurse into subdir if instructed by treat_path */
 		if ((state == path_recurse) ||
 			((state == path_untracked) &&
-			 (dir->flags & DIR_SHOW_IGNORED_TOO) &&
-			 (get_dtype(cdir.de, istate, path.buf, path.len) == DT_DIR))) {
+			 (resolve_dtype(cdir.d_type, istate, path.buf, path.len) == DT_DIR) &&
+			 ((dir->flags & DIR_SHOW_IGNORED_TOO) ||
+			  (pathspec &&
+			   do_match_pathspec(istate, pathspec, path.buf, path.len,
+					     baselen, NULL, DO_MATCH_LEADING_PATHSPEC) == MATCHED_RECURSIVELY_LEADING_PATHSPEC)))) {
 			struct untracked_cache_dir *ud;
 			ud = lookup_untracked(dir->untracked, untracked,
 					      path.buf + baselen,
@@ -1974,6 +2233,12 @@ static enum path_treatment read_director
 							 check_only, stop_at_first_file, pathspec);
 			if (subdir_state > dir_state)
 				dir_state = subdir_state;
+
+			if (pathspec &&
+			    !match_pathspec(istate, pathspec, path.buf, path.len,
+					    0 /* prefix */, NULL,
+					    0 /* do NOT special case dirs */))
+				state = path_none;
 		}
 
 		if (check_only) {
@@ -2009,29 +2274,9 @@ static enum path_treatment read_director
 			continue;
 		}
 
-		/* add the path to the appropriate result list */
-		switch (state) {
-		case path_excluded:
-			if (dir->flags & DIR_SHOW_IGNORED)
-				dir_add_name(dir, istate, path.buf, path.len);
-			else if ((dir->flags & DIR_SHOW_IGNORED_TOO) ||
-				((dir->flags & DIR_COLLECT_IGNORED) &&
-				exclude_matches_pathspec(path.buf, path.len,
-							 pathspec)))
-				dir_add_ignored(dir, istate, path.buf, path.len);
-			break;
-
-		case path_untracked:
-			if (dir->flags & DIR_SHOW_IGNORED)
-				break;
-			dir_add_name(dir, istate, path.buf, path.len);
-			if (cdir.fdir)
-				add_untracked(untracked, path.buf + baselen);
-			break;
-
-		default:
-			break;
-		}
+		add_path_to_appropriate_result_list(dir, untracked, &cdir,
+						    istate, &path, baselen,
+						    pathspec, state);
 	}
 	close_cached_dir(&cdir);
  out:
@@ -2061,41 +2306,95 @@ static int treat_leading_path(struct dir
 			      const char *path, int len,
 			      const struct pathspec *pathspec)
 {
+	/*
+	 * WARNING WARNING WARNING:
+	 *
+	 * Any updates to the traversal logic here may need corresponding
+	 * updates in read_directory_recursive().  See 777b420347 (dir:
+	 * synchronize treat_leading_path() and read_directory_recursive(),
+	 * 2019-12-19) and its parent commit for details.
+	 */
+
 	struct strbuf sb = STRBUF_INIT;
-	int baselen, rc = 0;
+	struct strbuf subdir = STRBUF_INIT;
+	int prevlen, baselen;
 	const char *cp;
-	int old_flags = dir->flags;
+	struct cached_dir cdir;
+	enum path_treatment state = path_none;
+
+	/*
+	 * For each directory component of path, we are going to check whether
+	 * that path is relevant given the pathspec.  For example, if path is
+	 *    foo/bar/baz/
+	 * then we will ask treat_path() whether we should go into foo, then
+	 * whether we should go into bar, then whether baz is relevant.
+	 * Checking each is important because e.g. if path is
+	 *    .git/info/
+	 * then we need to check .git to know we shouldn't traverse it.
+	 * If the return from treat_path() is:
+	 *    * path_none, for any path, we return false.
+	 *    * path_recurse, for all path components, we return true
+	 *    * <anything else> for some intermediate component, we make sure
+	 *        to add that path to the relevant list but return false
+	 *        signifying that we shouldn't recurse into it.
+	 */
 
 	while (len && path[len - 1] == '/')
 		len--;
 	if (!len)
 		return 1;
+
+	memset(&cdir, 0, sizeof(cdir));
+	cdir.d_type = DT_DIR;
 	baselen = 0;
-	dir->flags &= ~DIR_SHOW_OTHER_DIRECTORIES;
+	prevlen = 0;
 	while (1) {
-		cp = path + baselen + !!baselen;
+		prevlen = baselen + !!baselen;
+		cp = path + prevlen;
 		cp = memchr(cp, '/', path + len - cp);
 		if (!cp)
 			baselen = len;
 		else
 			baselen = cp - path;
-		strbuf_setlen(&sb, 0);
+		strbuf_reset(&sb);
 		strbuf_add(&sb, path, baselen);
 		if (!is_directory(sb.buf))
 			break;
-		if (simplify_away(sb.buf, sb.len, pathspec))
-			break;
-		if (treat_one_path(dir, NULL, istate, &sb, baselen, pathspec,
-				   DT_DIR, NULL) == path_none)
+		strbuf_reset(&sb);
+		strbuf_add(&sb, path, prevlen);
+		strbuf_reset(&subdir);
+		strbuf_add(&subdir, path+prevlen, baselen-prevlen);
+		cdir.d_name = subdir.buf;
+		state = treat_path(dir, NULL, &cdir, istate, &sb, prevlen,
+				    pathspec);
+		if (state == path_untracked &&
+		    resolve_dtype(cdir.d_type, istate, sb.buf, sb.len) == DT_DIR &&
+		    (dir->flags & DIR_SHOW_IGNORED_TOO ||
+		     do_match_pathspec(istate, pathspec, sb.buf, sb.len,
+				       baselen, NULL, DO_MATCH_LEADING_PATHSPEC) == MATCHED_RECURSIVELY_LEADING_PATHSPEC)) {
+			if (!match_pathspec(istate, pathspec, sb.buf, sb.len,
+					    0 /* prefix */, NULL,
+					    0 /* do NOT special case dirs */))
+				state = path_none;
+			add_path_to_appropriate_result_list(dir, NULL, &cdir,
+							    istate,
+							    &sb, baselen,
+							    pathspec, state);
+			state = path_recurse;
+		}
+
+		if (state != path_recurse)
 			break; /* do not recurse into it */
-		if (len <= baselen) {
-			rc = 1;
+		if (len <= baselen)
 			break; /* finished checking */
-		}
 	}
+	add_path_to_appropriate_result_list(dir, NULL, &cdir, istate,
+					    &sb, baselen, pathspec,
+					    state);
+
+	strbuf_release(&subdir);
 	strbuf_release(&sb);
-	dir->flags = old_flags;
-	return rc;
+	return state == path_recurse;
 }
 
 static const char *get_ident_string(void)
@@ -2230,7 +2529,7 @@ static struct untracked_cache_dir *valid
 		return NULL;
 
 	if (!ident_in_untracked(dir->untracked)) {
-		warning(_("Untracked cache is disabled on this system or location."));
+		warning(_("untracked cache is disabled on this system or location"));
 		return NULL;
 	}
 
@@ -2242,12 +2541,12 @@ static struct untracked_cache_dir *valid
 
 	/* Validate $GIT_DIR/info/exclude and core.excludesfile */
 	root = dir->untracked->root;
-	if (oidcmp(&dir->ss_info_exclude.oid,
+	if (!oideq(&dir->ss_info_exclude.oid,
 		   &dir->untracked->ss_info_exclude.oid)) {
 		invalidate_gitignore(dir->untracked, root);
 		dir->untracked->ss_info_exclude = dir->ss_info_exclude;
 	}
-	if (oidcmp(&dir->ss_excludes_file.oid,
+	if (!oideq(&dir->ss_excludes_file.oid,
 		   &dir->untracked->ss_excludes_file.oid)) {
 		invalidate_gitignore(dir->untracked, root);
 		dir->untracked->ss_excludes_file = dir->ss_excludes_file;
@@ -2262,10 +2561,13 @@ int read_directory(struct dir_struct *di
 		   const char *path, int len, const struct pathspec *pathspec)
 {
 	struct untracked_cache_dir *untracked;
-	uint64_t start = getnanotime();
 
-	if (has_symlink_leading_path(path, len))
+	trace_performance_enter();
+
+	if (has_symlink_leading_path(path, len)) {
+		trace_performance_leave("read directory %.*s", len, path);
 		return dir->nr;
+	}
 
 	untracked = validate_untracked_cache(dir, len, pathspec);
 	if (!untracked)
@@ -2301,7 +2603,7 @@ int read_directory(struct dir_struct *di
 		dir->nr = i;
 	}
 
-	trace_performance_since(start, "read directory %.*s", len, path);
+	trace_performance_leave("read directory %.*s", len, path);
 	if (dir->untracked) {
 		static int force_untracked_cache = -1;
 		static struct trace_key trace_untracked_stats = TRACE_KEY_INIT(UNTRACKED_STATS);
@@ -2337,6 +2639,14 @@ int file_exists(const char *f)
 	return lstat(f, &sb) == 0;
 }
 
+int repo_file_exists(struct repository *repo, const char *path)
+{
+	if (repo != the_repository)
+		BUG("do not know how to check file existence in arbitrary repo");
+
+	return file_exists(path);
+}
+
 static int cmp_icase(char a, char b)
 {
 	if (a == b)
@@ -2459,7 +2769,7 @@ static int remove_dir_recurse(struct str
 				 * wanted anyway
 				 */
 				continue;
-			/* fall thru */
+			/* fall through */
 		} else if (S_ISDIR(st.st_mode)) {
 			if (!remove_dir_recurse(path, flag, &kept_down))
 				continue; /* happy */
@@ -2497,18 +2807,18 @@ void setup_standard_excludes(struct dir_
 {
 	dir->exclude_per_dir = ".gitignore";
 
-	/* core.excludefile defaulting to $XDG_HOME/git/ignore */
+	/* core.excludesfile defaulting to $XDG_CONFIG_HOME/git/ignore */
 	if (!excludes_file)
 		excludes_file = xdg_config_home("ignore");
 	if (excludes_file && !access_or_warn(excludes_file, R_OK, 0))
-		add_excludes_from_file_1(dir, excludes_file,
+		add_patterns_from_file_1(dir, excludes_file,
 					 dir->untracked ? &dir->ss_excludes_file : NULL);
 
 	/* per repository user preference */
 	if (startup_info->have_repository) {
 		const char *path = git_path_info_exclude();
 		if (!access_or_warn(path, R_OK, 0))
-			add_excludes_from_file_1(dir, path,
+			add_patterns_from_file_1(dir, path,
 						 dir->untracked ? &dir->ss_info_exclude : NULL);
 	}
 }
@@ -2540,18 +2850,18 @@ void clear_directory(struct dir_struct *
 {
 	int i, j;
 	struct exclude_list_group *group;
-	struct exclude_list *el;
+	struct pattern_list *pl;
 	struct exclude_stack *stk;
 
 	for (i = EXC_CMDL; i <= EXC_FILE; i++) {
 		group = &dir->exclude_list_group[i];
 		for (j = 0; j < group->nr; j++) {
-			el = &group->el[j];
+			pl = &group->pl[j];
 			if (i == EXC_DIRS)
-				free((char *)el->src);
-			clear_exclude_list(el);
+				free((char *)pl->src);
+			clear_pattern_list(pl);
 		}
-		free(group->el);
+		free(group->pl);
 	}
 
 	stk = dir->exclude_stack;
@@ -2567,13 +2877,9 @@ struct ondisk_untracked_cache {
 	struct stat_data info_exclude_stat;
 	struct stat_data excludes_file_stat;
 	uint32_t dir_flags;
-	unsigned char info_exclude_sha1[20];
-	unsigned char excludes_file_sha1[20];
-	char exclude_per_dir[FLEX_ARRAY];
 };
 
 #define ouc_offset(x) offsetof(struct ondisk_untracked_cache, x)
-#define ouc_size(len) (ouc_offset(exclude_per_dir) + len + 1)
 
 struct write_data {
 	int index;	   /* number of written untracked_cache_dir */
@@ -2656,20 +2962,21 @@ void write_untracked_extension(struct st
 	struct write_data wd;
 	unsigned char varbuf[16];
 	int varint_len;
-	size_t len = strlen(untracked->exclude_per_dir);
+	const unsigned hashsz = the_hash_algo->rawsz;
 
-	FLEX_ALLOC_MEM(ouc, exclude_per_dir, untracked->exclude_per_dir, len);
+	ouc = xcalloc(1, sizeof(*ouc));
 	stat_data_to_disk(&ouc->info_exclude_stat, &untracked->ss_info_exclude.stat);
 	stat_data_to_disk(&ouc->excludes_file_stat, &untracked->ss_excludes_file.stat);
-	hashcpy(ouc->info_exclude_sha1, untracked->ss_info_exclude.oid.hash);
-	hashcpy(ouc->excludes_file_sha1, untracked->ss_excludes_file.oid.hash);
 	ouc->dir_flags = htonl(untracked->dir_flags);
 
 	varint_len = encode_varint(untracked->ident.len, varbuf);
 	strbuf_add(out, varbuf, varint_len);
 	strbuf_addbuf(out, &untracked->ident);
 
-	strbuf_add(out, ouc, ouc_size(len));
+	strbuf_add(out, ouc, sizeof(*ouc));
+	strbuf_add(out, untracked->ss_info_exclude.oid.hash, hashsz);
+	strbuf_add(out, untracked->ss_excludes_file.oid.hash, hashsz);
+	strbuf_add(out, untracked->exclude_per_dir, strlen(untracked->exclude_per_dir) + 1);
 	FREE_AND_NULL(ouc);
 
 	if (!untracked->root) {
@@ -2754,54 +3061,49 @@ static int read_one_dir(struct untracked
 			struct read_data *rd)
 {
 	struct untracked_cache_dir ud, *untracked;
-	const unsigned char *next, *data = rd->data, *end = rd->end;
+	const unsigned char *data = rd->data, *end = rd->end;
+	const unsigned char *eos;
 	unsigned int value;
-	int i, len;
+	int i;
 
 	memset(&ud, 0, sizeof(ud));
 
-	next = data;
-	value = decode_varint(&next);
-	if (next > end)
+	value = decode_varint(&data);
+	if (data > end)
 		return -1;
 	ud.recurse	   = 1;
 	ud.untracked_alloc = value;
 	ud.untracked_nr	   = value;
 	if (ud.untracked_nr)
 		ALLOC_ARRAY(ud.untracked, ud.untracked_nr);
-	data = next;
 
-	next = data;
-	ud.dirs_alloc = ud.dirs_nr = decode_varint(&next);
-	if (next > end)
+	ud.dirs_alloc = ud.dirs_nr = decode_varint(&data);
+	if (data > end)
 		return -1;
 	ALLOC_ARRAY(ud.dirs, ud.dirs_nr);
-	data = next;
 
-	len = strlen((const char *)data);
-	next = data + len + 1;
-	if (next > rd->end)
+	eos = memchr(data, '\0', end - data);
+	if (!eos || eos == end)
 		return -1;
-	*untracked_ = untracked = xmalloc(st_add(sizeof(*untracked), len));
+
+	*untracked_ = untracked = xmalloc(st_add3(sizeof(*untracked), eos - data, 1));
 	memcpy(untracked, &ud, sizeof(ud));
-	memcpy(untracked->name, data, len + 1);
-	data = next;
+	memcpy(untracked->name, data, eos - data + 1);
+	data = eos + 1;
 
 	for (i = 0; i < untracked->untracked_nr; i++) {
-		len = strlen((const char *)data);
-		next = data + len + 1;
-		if (next > rd->end)
+		eos = memchr(data, '\0', end - data);
+		if (!eos || eos == end)
 			return -1;
-		untracked->untracked[i] = xstrdup((const char*)data);
-		data = next;
+		untracked->untracked[i] = xmemdupz(data, eos - data);
+		data = eos + 1;
 	}
 
 	rd->ucd[rd->index++] = untracked;
 	rd->data = data;
 
 	for (i = 0; i < untracked->dirs_nr; i++) {
-		len = read_one_dir(untracked->dirs + i, rd);
-		if (len < 0)
+		if (read_one_dir(untracked->dirs + i, rd) < 0)
 			return -1;
 	}
 	return 0;
@@ -2856,6 +3158,9 @@ struct untracked_cache *read_untracked_e
 	int ident_len;
 	ssize_t len;
 	const char *exclude_per_dir;
+	const unsigned hashsz = the_hash_algo->rawsz;
+	const unsigned offset = sizeof(struct ondisk_untracked_cache);
+	const unsigned exclude_per_dir_offset = offset + 2 * hashsz;
 
 	if (sz <= 1 || end[-1] != '\0')
 		return NULL;
@@ -2867,7 +3172,7 @@ struct untracked_cache *read_untracked_e
 	ident = (const char *)next;
 	next += ident_len;
 
-	if (next + ouc_size(0) > end)
+	if (next + exclude_per_dir_offset + 1 > end)
 		return NULL;
 
 	uc = xcalloc(1, sizeof(*uc));
@@ -2875,15 +3180,15 @@ struct untracked_cache *read_untracked_e
 	strbuf_add(&uc->ident, ident, ident_len);
 	load_oid_stat(&uc->ss_info_exclude,
 		      next + ouc_offset(info_exclude_stat),
-		      next + ouc_offset(info_exclude_sha1));
+		      next + offset);
 	load_oid_stat(&uc->ss_excludes_file,
 		      next + ouc_offset(excludes_file_stat),
-		      next + ouc_offset(excludes_file_sha1));
+		      next + offset + hashsz);
 	uc->dir_flags = get_be32(next + ouc_offset(dir_flags));
-	exclude_per_dir = (const char *)next + ouc_offset(exclude_per_dir);
+	exclude_per_dir = (const char *)next + exclude_per_dir_offset;
 	uc->exclude_per_dir = xstrdup(exclude_per_dir);
 	/* NUL after exclude_per_dir is covered by sizeof(*ouc) */
-	next += ouc_size(strlen(exclude_per_dir));
+	next += exclude_per_dir_offset + strlen(exclude_per_dir) + 1;
 	if (next >= end)
 		goto done2;
 
@@ -3028,7 +3333,7 @@ static void connect_wt_gitdir_in_nested(
 		return;
 
 	if (repo_read_index(&subrepo) < 0)
-		die("index file corrupt in repo %s", subrepo.gitdir);
+		die(_("index file corrupt in repo %s"), subrepo.gitdir);
 
 	for (i = 0; i < subrepo.index->cache_nr; i++) {
 		const struct cache_entry *ce = subrepo.index->cache[i];
diff -pruN 1.2.1+git2.18.0-1/git/dir.h 1.2.3+git2.25.1-1/git/dir.h
--- 1.2.1+git2.18.0-1/git/dir.h	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/dir.h	2020-02-17 04:47:35.000000000 +0000
@@ -1,34 +1,68 @@
 #ifndef DIR_H
 #define DIR_H
 
-/* See Documentation/technical/api-directory-listing.txt */
-
 #include "cache.h"
+#include "hashmap.h"
 #include "strbuf.h"
 
+/**
+ * The directory listing API is used to enumerate paths in the work tree,
+ * optionally taking `.git/info/exclude` and `.gitignore` files per directory
+ * into account.
+ */
+
+/**
+ * Calling sequence
+ * ----------------
+ *
+ * Note: The index may be checked for .gitignore files that are
+ * CE_SKIP_WORKTREE marked. If you want to exclude files, make sure you have
+ * loaded the index first.
+ *
+ * - Prepare `struct dir_struct dir` and clear it with `memset(&dir, 0,
+ * sizeof(dir))`.
+ *
+ * - To add single exclude pattern, call `add_pattern_list()` and then
+ *   `add_pattern()`.
+ *
+ * - To add patterns from a file (e.g. `.git/info/exclude`), call
+ *   `add_patterns_from_file()` , and/or set `dir.exclude_per_dir`.  A
+ *   short-hand function `setup_standard_excludes()` can be used to set
+ *   up the standard set of exclude settings.
+ *
+ * - Set options described in the Data Structure section above.
+ *
+ * - Call `read_directory()`.
+ *
+ * - Use `dir.entries[]`.
+ *
+ * - Call `clear_directory()` when none of the contained elements are no longer in use.
+ *
+ */
+
 struct dir_entry {
 	unsigned int len;
 	char name[FLEX_ARRAY]; /* more */
 };
 
-#define EXC_FLAG_NODIR 1
-#define EXC_FLAG_ENDSWITH 4
-#define EXC_FLAG_MUSTBEDIR 8
-#define EXC_FLAG_NEGATIVE 16
+#define PATTERN_FLAG_NODIR 1
+#define PATTERN_FLAG_ENDSWITH 4
+#define PATTERN_FLAG_MUSTBEDIR 8
+#define PATTERN_FLAG_NEGATIVE 16
 
-struct exclude {
+struct path_pattern {
 	/*
-	 * This allows callers of last_exclude_matching() etc.
+	 * This allows callers of last_matching_pattern() etc.
 	 * to determine the origin of the matching pattern.
 	 */
-	struct exclude_list *el;
+	struct pattern_list *pl;
 
 	const char *pattern;
 	int patternlen;
 	int nowildcardlen;
 	const char *base;
 	int baselen;
-	unsigned flags;		/* EXC_FLAG_* */
+	unsigned flags;		/* PATTERN_FLAG_* */
 
 	/*
 	 * Counting starts from 1 for line numbers in ignore files,
@@ -37,6 +71,13 @@ struct exclude {
 	int srcpos;
 };
 
+/* used for hashmaps for cone patterns */
+struct pattern_entry {
+	struct hashmap_entry ent;
+	char *pattern;
+	size_t patternlen;
+};
+
 /*
  * Each excludes file will be parsed into a fresh exclude_list which
  * is appended to the relevant exclude_list_group (either EXC_DIRS or
@@ -44,7 +85,7 @@ struct exclude {
  * can also be used to represent the list of --exclude values passed
  * via CLI args.
  */
-struct exclude_list {
+struct pattern_list {
 	int nr;
 	int alloc;
 
@@ -54,7 +95,27 @@ struct exclude_list {
 	/* origin of list, e.g. path to filename, or descriptive string */
 	const char *src;
 
-	struct exclude **excludes;
+	struct path_pattern **patterns;
+
+	/*
+	 * While scanning the excludes, we attempt to match the patterns
+	 * with a more restricted set that allows us to use hashsets for
+	 * matching logic, which is faster than the linear lookup in the
+	 * excludes array above. If non-zero, that check succeeded.
+	 */
+	unsigned use_cone_patterns;
+	unsigned full_cone;
+
+	/*
+	 * Stores paths where everything starting with those paths
+	 * is included.
+	 */
+	struct hashmap recursive_hashmap;
+
+	/*
+	 * Used to check single-level parents of blobs.
+	 */
+	struct hashmap parent_hashmap;
 };
 
 /*
@@ -72,7 +133,7 @@ struct exclude_stack {
 
 struct exclude_list_group {
 	int nr, alloc;
-	struct exclude_list *el;
+	struct pattern_list *pl;
 };
 
 struct oid_stat {
@@ -144,24 +205,101 @@ struct untracked_cache {
 	unsigned int use_fsmonitor : 1;
 };
 
+/**
+ * structure is used to pass directory traversal options to the library and to
+ * record the paths discovered. A single `struct dir_struct` is used regardless
+ * of whether or not the traversal recursively descends into subdirectories.
+ */
 struct dir_struct {
-	int nr, alloc;
-	int ignored_nr, ignored_alloc;
+
+	/* The number of members in `entries[]` array. */
+	int nr;
+
+	/* Internal use; keeps track of allocation of `entries[]` array.*/
+	int alloc;
+
+	/* The number of members in `ignored[]` array. */
+	int ignored_nr;
+
+	int ignored_alloc;
+
+	/* bit-field of options */
 	enum {
+
+		/**
+		 * Return just ignored files in `entries[]`, not untracked files.
+		 * This flag is mutually exclusive with `DIR_SHOW_IGNORED_TOO`.
+		 */
 		DIR_SHOW_IGNORED = 1<<0,
+
+		/* Include a directory that is not tracked. */
 		DIR_SHOW_OTHER_DIRECTORIES = 1<<1,
+
+		/* Do not include a directory that is not tracked and is empty. */
 		DIR_HIDE_EMPTY_DIRECTORIES = 1<<2,
+
+		/**
+		 * If set, recurse into a directory that looks like a Git directory.
+		 * Otherwise it is shown as a directory.
+		 */
 		DIR_NO_GITLINKS = 1<<3,
+
+		/**
+		 * Special mode for git-add. Return ignored files in `ignored[]` and
+		 * untracked files in `entries[]`. Only returns ignored files that match
+		 * pathspec exactly (no wildcards). Does not recurse into ignored
+		 * directories.
+		 */
 		DIR_COLLECT_IGNORED = 1<<4,
+
+		/**
+		 * Similar to `DIR_SHOW_IGNORED`, but return ignored files in
+		 * `ignored[]` in addition to untracked files in `entries[]`.
+		 * This flag is mutually exclusive with `DIR_SHOW_IGNORED`.
+		 */
 		DIR_SHOW_IGNORED_TOO = 1<<5,
+
 		DIR_COLLECT_KILLED_ONLY = 1<<6,
+
+		/**
+		 * Only has meaning if `DIR_SHOW_IGNORED_TOO` is also set; if this is
+		 * set, the untracked contents of untracked directories are also
+		 * returned in `entries[]`.
+		 */
 		DIR_KEEP_UNTRACKED_CONTENTS = 1<<7,
-		DIR_SHOW_IGNORED_TOO_MODE_MATCHING = 1<<8
+
+		/**
+		 * Only has meaning if `DIR_SHOW_IGNORED_TOO` is also set; if this is
+		 * set, returns ignored files and directories that match an exclude
+		 * pattern. If a directory matches an exclude pattern, then the
+		 * directory is returned and the contained paths are not. A directory
+		 * that does not match an exclude pattern will not be returned even if
+		 * all of its contents are ignored. In this case, the contents are
+		 * returned as individual entries.
+		 *
+		 * If this is set, files and directories that explicitly match an ignore
+		 * pattern are reported. Implicitly ignored directories (directories that
+		 * do not match an ignore pattern, but whose contents are all ignored)
+		 * are not reported, instead all of the contents are reported.
+		 */
+		DIR_SHOW_IGNORED_TOO_MODE_MATCHING = 1<<8,
+
+		DIR_SKIP_NESTED_GIT = 1<<9
 	} flags;
+
+	/* An array of `struct dir_entry`, each element of which describes a path. */
 	struct dir_entry **entries;
+
+	/**
+	 * used for ignored paths with the `DIR_SHOW_IGNORED_TOO` and
+	 * `DIR_COLLECT_IGNORED` flags.
+	 */
 	struct dir_entry **ignored;
 
-	/* Exclude info */
+	/**
+	 * The name of the file to be read in each directory for excluded files
+	 * (typically `.gitignore`).
+	 */
 	const char *exclude_per_dir;
 
 	/*
@@ -191,7 +329,7 @@ struct dir_struct {
 	 * matching exclude struct if the directory is excluded.
 	 */
 	struct exclude_stack *exclude_stack;
-	struct exclude *exclude;
+	struct path_pattern *pattern;
 	struct strbuf basebuf;
 
 	/* Enable untracked file cache if set */
@@ -202,7 +340,7 @@ struct dir_struct {
 };
 
 /*Count the number of slashes for string s*/
-extern int count_slashes(const char *s);
+int count_slashes(const char *s);
 
 /*
  * The ordering of these constants is significant, with
@@ -211,28 +349,44 @@ extern int count_slashes(const char *s);
  * when populating the seen[] array.
  */
 #define MATCHED_RECURSIVELY 1
-#define MATCHED_FNMATCH 2
-#define MATCHED_EXACTLY 3
-extern int simple_length(const char *match);
-extern int no_wildcard(const char *string);
-extern char *common_prefix(const struct pathspec *pathspec);
-extern int match_pathspec(const struct pathspec *pathspec,
-			  const char *name, int namelen,
-			  int prefix, char *seen, int is_dir);
-extern int report_path_error(const char *ps_matched, const struct pathspec *pathspec, const char *prefix);
-extern int within_depth(const char *name, int namelen, int depth, int max_depth);
-
-extern int fill_directory(struct dir_struct *dir,
-			  struct index_state *istate,
-			  const struct pathspec *pathspec);
-extern int read_directory(struct dir_struct *, struct index_state *istate,
-			  const char *path, int len,
-			  const struct pathspec *pathspec);
-
-extern int is_excluded_from_list(const char *pathname, int pathlen,
-				 const char *basename, int *dtype,
-				 struct exclude_list *el,
-				 struct index_state *istate);
+#define MATCHED_RECURSIVELY_LEADING_PATHSPEC 2
+#define MATCHED_FNMATCH 3
+#define MATCHED_EXACTLY 4
+int simple_length(const char *match);
+int no_wildcard(const char *string);
+char *common_prefix(const struct pathspec *pathspec);
+int match_pathspec(const struct index_state *istate,
+		   const struct pathspec *pathspec,
+		   const char *name, int namelen,
+		   int prefix, char *seen, int is_dir);
+int report_path_error(const char *ps_matched, const struct pathspec *pathspec);
+int within_depth(const char *name, int namelen, int depth, int max_depth);
+
+int fill_directory(struct dir_struct *dir,
+		   struct index_state *istate,
+		   const struct pathspec *pathspec);
+int read_directory(struct dir_struct *, struct index_state *istate,
+		   const char *path, int len,
+		   const struct pathspec *pathspec);
+
+enum pattern_match_result {
+	UNDECIDED = -1,
+	NOT_MATCHED = 0,
+	MATCHED = 1,
+	MATCHED_RECURSIVE = 2,
+};
+
+/*
+ * Scan the list of patterns to determine if the ordered list
+ * of patterns matches on 'pathname'.
+ *
+ * Return 1 for a match, 0 for not matched and -1 for undecided.
+ */
+enum pattern_match_result path_matches_pattern_list(const char *pathname,
+				int pathlen,
+				const char *basename, int *dtype,
+				struct pattern_list *pl,
+				struct index_state *istate);
 struct dir_entry *dir_add_ignored(struct dir_struct *dir,
 				  struct index_state *istate,
 				  const char *pathname, int len);
@@ -241,37 +395,46 @@ struct dir_entry *dir_add_ignored(struct
  * these implement the matching logic for dir.c:excluded_from_list and
  * attr.c:path_matches()
  */
-extern int match_basename(const char *, int,
-			  const char *, int, int, unsigned);
-extern int match_pathname(const char *, int,
-			  const char *, int,
-			  const char *, int, int, unsigned);
-
-extern struct exclude *last_exclude_matching(struct dir_struct *dir,
-					     struct index_state *istate,
-					     const char *name, int *dtype);
-
-extern int is_excluded(struct dir_struct *dir,
-		       struct index_state *istate,
-		       const char *name, int *dtype);
-
-extern struct exclude_list *add_exclude_list(struct dir_struct *dir,
-					     int group_type, const char *src);
-extern int add_excludes_from_file_to_list(const char *fname, const char *base, int baselen,
-					  struct exclude_list *el, struct  index_state *istate);
-extern void add_excludes_from_file(struct dir_struct *, const char *fname);
-extern int add_excludes_from_blob_to_list(struct object_id *oid,
-					  const char *base, int baselen,
-					  struct exclude_list *el);
-extern void parse_exclude_pattern(const char **string, int *patternlen, unsigned *flags, int *nowildcardlen);
-extern void add_exclude(const char *string, const char *base,
-			int baselen, struct exclude_list *el, int srcpos);
-extern void clear_exclude_list(struct exclude_list *el);
-extern void clear_directory(struct dir_struct *dir);
-extern int file_exists(const char *);
+int match_basename(const char *, int,
+		   const char *, int, int, unsigned);
+int match_pathname(const char *, int,
+		   const char *, int,
+		   const char *, int, int, unsigned);
+
+struct path_pattern *last_matching_pattern(struct dir_struct *dir,
+					   struct index_state *istate,
+					   const char *name, int *dtype);
+
+int is_excluded(struct dir_struct *dir,
+		struct index_state *istate,
+		const char *name, int *dtype);
+
+int pl_hashmap_cmp(const void *unused_cmp_data,
+		   const struct hashmap_entry *a,
+		   const struct hashmap_entry *b,
+		   const void *key);
+int hashmap_contains_parent(struct hashmap *map,
+			    const char *path,
+			    struct strbuf *buffer);
+struct pattern_list *add_pattern_list(struct dir_struct *dir,
+				      int group_type, const char *src);
+int add_patterns_from_file_to_list(const char *fname, const char *base, int baselen,
+				   struct pattern_list *pl, struct  index_state *istate);
+void add_patterns_from_file(struct dir_struct *, const char *fname);
+int add_patterns_from_blob_to_list(struct object_id *oid,
+				   const char *base, int baselen,
+				   struct pattern_list *pl);
+void parse_path_pattern(const char **string, int *patternlen, unsigned *flags, int *nowildcardlen);
+void add_pattern(const char *string, const char *base,
+		 int baselen, struct pattern_list *pl, int srcpos);
+void clear_pattern_list(struct pattern_list *pl);
+void clear_directory(struct dir_struct *dir);
+
+int repo_file_exists(struct repository *repo, const char *path);
+int file_exists(const char *);
 
-extern int is_inside_dir(const char *dir);
-extern int dir_inside_of(const char *subdir, const char *dir);
+int is_inside_dir(const char *dir);
+int dir_inside_of(const char *subdir, const char *dir);
 
 static inline int is_dot_or_dotdot(const char *name)
 {
@@ -280,9 +443,9 @@ static inline int is_dot_or_dotdot(const
 		 (name[1] == '.' && name[2] == '\0')));
 }
 
-extern int is_empty_dir(const char *dir);
+int is_empty_dir(const char *dir);
 
-extern void setup_standard_excludes(struct dir_struct *dir);
+void setup_standard_excludes(struct dir_struct *dir);
 
 
 /* Constants for remove_dir_recursively: */
@@ -310,41 +473,44 @@ extern void setup_standard_excludes(stru
  * This function uses path as temporary scratch space, but restores it
  * before returning.
  */
-extern int remove_dir_recursively(struct strbuf *path, int flag);
+int remove_dir_recursively(struct strbuf *path, int flag);
 
 /* tries to remove the path with empty directories along it, ignores ENOENT */
-extern int remove_path(const char *path);
+int remove_path(const char *path);
 
-extern int fspathcmp(const char *a, const char *b);
-extern int fspathncmp(const char *a, const char *b, size_t count);
+int fspathcmp(const char *a, const char *b);
+int fspathncmp(const char *a, const char *b, size_t count);
 
 /*
  * The prefix part of pattern must not contains wildcards.
  */
 struct pathspec_item;
-extern int git_fnmatch(const struct pathspec_item *item,
-		       const char *pattern, const char *string,
-		       int prefix);
-
-extern int submodule_path_match(const struct pathspec *ps,
-				const char *submodule_name,
-				char *seen);
+int git_fnmatch(const struct pathspec_item *item,
+		const char *pattern, const char *string,
+		int prefix);
+
+int submodule_path_match(const struct index_state *istate,
+			 const struct pathspec *ps,
+			 const char *submodule_name,
+			 char *seen);
 
-static inline int ce_path_match(const struct cache_entry *ce,
+static inline int ce_path_match(const struct index_state *istate,
+				const struct cache_entry *ce,
 				const struct pathspec *pathspec,
 				char *seen)
 {
-	return match_pathspec(pathspec, ce->name, ce_namelen(ce), 0, seen,
+	return match_pathspec(istate, pathspec, ce->name, ce_namelen(ce), 0, seen,
 			      S_ISDIR(ce->ce_mode) || S_ISGITLINK(ce->ce_mode));
 }
 
-static inline int dir_path_match(const struct dir_entry *ent,
+static inline int dir_path_match(const struct index_state *istate,
+				 const struct dir_entry *ent,
 				 const struct pathspec *pathspec,
 				 int prefix, char *seen)
 {
 	int has_trailing_dir = ent->len && ent->name[ent->len - 1] == '/';
 	int len = has_trailing_dir ? ent->len - 1 : ent->len;
-	return match_pathspec(pathspec, ent->name, len, prefix, seen,
+	return match_pathspec(istate, pathspec, ent->name, len, prefix, seen,
 			      has_trailing_dir);
 }
 
@@ -368,10 +534,10 @@ void remove_untracked_cache(struct index
  * When `recurse_into_nested` is set, recurse into any nested submodules,
  * connecting them as well.
  */
-extern void connect_work_tree_and_git_dir(const char *work_tree,
-					  const char *git_dir,
-					  int recurse_into_nested);
-extern void relocate_gitdir(const char *path,
-			    const char *old_git_dir,
-			    const char *new_git_dir);
+void connect_work_tree_and_git_dir(const char *work_tree,
+				   const char *git_dir,
+				   int recurse_into_nested);
+void relocate_gitdir(const char *path,
+		     const char *old_git_dir,
+		     const char *new_git_dir);
 #endif
diff -pruN 1.2.1+git2.18.0-1/git/dir-iterator.c 1.2.3+git2.25.1-1/git/dir-iterator.c
--- 1.2.1+git2.18.0-1/git/dir-iterator.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/dir-iterator.c	2020-02-17 04:47:35.000000000 +0000
@@ -4,8 +4,6 @@
 #include "dir-iterator.h"
 
 struct dir_iterator_level {
-	int initialized;
-
 	DIR *dir;
 
 	/*
@@ -13,16 +11,6 @@ struct dir_iterator_level {
 	 * (including a trailing '/'):
 	 */
 	size_t prefix_len;
-
-	/*
-	 * The last action that has been taken with the current entry
-	 * (needed for directories, which have to be included in the
-	 * iteration and also iterated into):
-	 */
-	enum {
-		DIR_STATE_ITER,
-		DIR_STATE_RECURSE
-	} dir_state;
 };
 
 /*
@@ -34,9 +22,11 @@ struct dir_iterator_int {
 	struct dir_iterator base;
 
 	/*
-	 * The number of levels currently on the stack. This is always
-	 * at least 1, because when it becomes zero the iteration is
-	 * ended and this struct is freed.
+	 * The number of levels currently on the stack. After the first
+	 * call to dir_iterator_begin(), if it succeeds to open the
+	 * first level's dir, this will always be at least 1. Then,
+	 * when it comes to zero the iteration is ended and this
+	 * struct is freed.
 	 */
 	size_t levels_nr;
 
@@ -48,117 +38,142 @@ struct dir_iterator_int {
 	 * that will be included in this iteration.
 	 */
 	struct dir_iterator_level *levels;
+
+	/* Combination of flags for this dir-iterator */
+	unsigned int flags;
 };
 
+/*
+ * Push a level in the iter stack and initialize it with information from
+ * the directory pointed by iter->base->path. It is assumed that this
+ * strbuf points to a valid directory path. Return 0 on success and -1
+ * otherwise, setting errno accordingly and leaving the stack unchanged.
+ */
+static int push_level(struct dir_iterator_int *iter)
+{
+	struct dir_iterator_level *level;
+
+	ALLOC_GROW(iter->levels, iter->levels_nr + 1, iter->levels_alloc);
+	level = &iter->levels[iter->levels_nr++];
+
+	if (!is_dir_sep(iter->base.path.buf[iter->base.path.len - 1]))
+		strbuf_addch(&iter->base.path, '/');
+	level->prefix_len = iter->base.path.len;
+
+	level->dir = opendir(iter->base.path.buf);
+	if (!level->dir) {
+		int saved_errno = errno;
+		if (errno != ENOENT) {
+			warning_errno("error opening directory '%s'",
+				      iter->base.path.buf);
+		}
+		iter->levels_nr--;
+		errno = saved_errno;
+		return -1;
+	}
+
+	return 0;
+}
+
+/*
+ * Pop the top level on the iter stack, releasing any resources associated
+ * with it. Return the new value of iter->levels_nr.
+ */
+static int pop_level(struct dir_iterator_int *iter)
+{
+	struct dir_iterator_level *level =
+		&iter->levels[iter->levels_nr - 1];
+
+	if (level->dir && closedir(level->dir))
+		warning_errno("error closing directory '%s'",
+			      iter->base.path.buf);
+	level->dir = NULL;
+
+	return --iter->levels_nr;
+}
+
+/*
+ * Populate iter->base with the necessary information on the next iteration
+ * entry, represented by the given dirent de. Return 0 on success and -1
+ * otherwise, setting errno accordingly.
+ */
+static int prepare_next_entry_data(struct dir_iterator_int *iter,
+				   struct dirent *de)
+{
+	int err, saved_errno;
+
+	strbuf_addstr(&iter->base.path, de->d_name);
+	/*
+	 * We have to reset these because the path strbuf might have
+	 * been realloc()ed at the previous strbuf_addstr().
+	 */
+	iter->base.relative_path = iter->base.path.buf +
+				   iter->levels[0].prefix_len;
+	iter->base.basename = iter->base.path.buf +
+			      iter->levels[iter->levels_nr - 1].prefix_len;
+
+	if (iter->flags & DIR_ITERATOR_FOLLOW_SYMLINKS)
+		err = stat(iter->base.path.buf, &iter->base.st);
+	else
+		err = lstat(iter->base.path.buf, &iter->base.st);
+
+	saved_errno = errno;
+	if (err && errno != ENOENT)
+		warning_errno("failed to stat '%s'", iter->base.path.buf);
+
+	errno = saved_errno;
+	return err;
+}
+
 int dir_iterator_advance(struct dir_iterator *dir_iterator)
 {
 	struct dir_iterator_int *iter =
 		(struct dir_iterator_int *)dir_iterator;
 
+	if (S_ISDIR(iter->base.st.st_mode) && push_level(iter)) {
+		if (errno != ENOENT && iter->flags & DIR_ITERATOR_PEDANTIC)
+			goto error_out;
+		if (iter->levels_nr == 0)
+			goto error_out;
+	}
+
+	/* Loop until we find an entry that we can give back to the caller. */
 	while (1) {
+		struct dirent *de;
 		struct dir_iterator_level *level =
 			&iter->levels[iter->levels_nr - 1];
-		struct dirent *de;
-
-		if (!level->initialized) {
-			/*
-			 * Note: dir_iterator_begin() ensures that
-			 * path is not the empty string.
-			 */
-			if (!is_dir_sep(iter->base.path.buf[iter->base.path.len - 1]))
-				strbuf_addch(&iter->base.path, '/');
-			level->prefix_len = iter->base.path.len;
-
-			level->dir = opendir(iter->base.path.buf);
-			if (!level->dir && errno != ENOENT) {
-				warning("error opening directory %s: %s",
-					iter->base.path.buf, strerror(errno));
-				/* Popping the level is handled below */
-			}
 
-			level->initialized = 1;
-		} else if (S_ISDIR(iter->base.st.st_mode)) {
-			if (level->dir_state == DIR_STATE_ITER) {
-				/*
-				 * The directory was just iterated
-				 * over; now prepare to iterate into
-				 * it.
-				 */
-				level->dir_state = DIR_STATE_RECURSE;
-				ALLOC_GROW(iter->levels, iter->levels_nr + 1,
-					   iter->levels_alloc);
-				level = &iter->levels[iter->levels_nr++];
-				level->initialized = 0;
-				continue;
-			} else {
-				/*
-				 * The directory has already been
-				 * iterated over and iterated into;
-				 * we're done with it.
-				 */
+		strbuf_setlen(&iter->base.path, level->prefix_len);
+		errno = 0;
+		de = readdir(level->dir);
+
+		if (!de) {
+			if (errno) {
+				warning_errno("error reading directory '%s'",
+					      iter->base.path.buf);
+				if (iter->flags & DIR_ITERATOR_PEDANTIC)
+					goto error_out;
+			} else if (pop_level(iter) == 0) {
+				return dir_iterator_abort(dir_iterator);
 			}
+			continue;
 		}
 
-		if (!level->dir) {
-			/*
-			 * This level is exhausted (or wasn't opened
-			 * successfully); pop up a level.
-			 */
-			if (--iter->levels_nr == 0)
-				return dir_iterator_abort(dir_iterator);
+		if (is_dot_or_dotdot(de->d_name))
+			continue;
 
+		if (prepare_next_entry_data(iter, de)) {
+			if (errno != ENOENT && iter->flags & DIR_ITERATOR_PEDANTIC)
+				goto error_out;
 			continue;
 		}
 
-		/*
-		 * Loop until we find an entry that we can give back
-		 * to the caller:
-		 */
-		while (1) {
-			strbuf_setlen(&iter->base.path, level->prefix_len);
-			errno = 0;
-			de = readdir(level->dir);
-
-			if (!de) {
-				/* This level is exhausted; pop up a level. */
-				if (errno) {
-					warning("error reading directory %s: %s",
-						iter->base.path.buf, strerror(errno));
-				} else if (closedir(level->dir))
-					warning("error closing directory %s: %s",
-						iter->base.path.buf, strerror(errno));
-
-				level->dir = NULL;
-				if (--iter->levels_nr == 0)
-					return dir_iterator_abort(dir_iterator);
-				break;
-			}
-
-			if (is_dot_or_dotdot(de->d_name))
-				continue;
-
-			strbuf_addstr(&iter->base.path, de->d_name);
-			if (lstat(iter->base.path.buf, &iter->base.st) < 0) {
-				if (errno != ENOENT)
-					warning("error reading path '%s': %s",
-						iter->base.path.buf,
-						strerror(errno));
-				continue;
-			}
-
-			/*
-			 * We have to set these each time because
-			 * the path strbuf might have been realloc()ed.
-			 */
-			iter->base.relative_path =
-				iter->base.path.buf + iter->levels[0].prefix_len;
-			iter->base.basename =
-				iter->base.path.buf + level->prefix_len;
-			level->dir_state = DIR_STATE_ITER;
-
-			return ITER_OK;
-		}
+		return ITER_OK;
 	}
+
+error_out:
+	dir_iterator_abort(dir_iterator);
+	return ITER_ERROR;
 }
 
 int dir_iterator_abort(struct dir_iterator *dir_iterator)
@@ -170,9 +185,11 @@ int dir_iterator_abort(struct dir_iterat
 			&iter->levels[iter->levels_nr - 1];
 
 		if (level->dir && closedir(level->dir)) {
+			int saved_errno = errno;
 			strbuf_setlen(&iter->base.path, level->prefix_len);
-			warning("error closing directory %s: %s",
-				iter->base.path.buf, strerror(errno));
+			errno = saved_errno;
+			warning_errno("error closing directory '%s'",
+				      iter->base.path.buf);
 		}
 	}
 
@@ -182,21 +199,37 @@ int dir_iterator_abort(struct dir_iterat
 	return ITER_DONE;
 }
 
-struct dir_iterator *dir_iterator_begin(const char *path)
+struct dir_iterator *dir_iterator_begin(const char *path, unsigned int flags)
 {
 	struct dir_iterator_int *iter = xcalloc(1, sizeof(*iter));
 	struct dir_iterator *dir_iterator = &iter->base;
-
-	if (!path || !*path)
-		BUG("empty path passed to dir_iterator_begin()");
+	int saved_errno;
 
 	strbuf_init(&iter->base.path, PATH_MAX);
 	strbuf_addstr(&iter->base.path, path);
 
 	ALLOC_GROW(iter->levels, 10, iter->levels_alloc);
+	iter->levels_nr = 0;
+	iter->flags = flags;
 
-	iter->levels_nr = 1;
-	iter->levels[0].initialized = 0;
+	/*
+	 * Note: stat already checks for NULL or empty strings and
+	 * inexistent paths.
+	 */
+	if (stat(iter->base.path.buf, &iter->base.st) < 0) {
+		saved_errno = errno;
+		goto error_out;
+	}
+
+	if (!S_ISDIR(iter->base.st.st_mode)) {
+		saved_errno = ENOTDIR;
+		goto error_out;
+	}
 
 	return dir_iterator;
+
+error_out:
+	dir_iterator_abort(dir_iterator);
+	errno = saved_errno;
+	return NULL;
 }
diff -pruN 1.2.1+git2.18.0-1/git/dir-iterator.h 1.2.3+git2.25.1-1/git/dir-iterator.h
--- 1.2.1+git2.18.0-1/git/dir-iterator.h	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/dir-iterator.h	2020-02-17 04:47:35.000000000 +0000
@@ -1,23 +1,30 @@
 #ifndef DIR_ITERATOR_H
 #define DIR_ITERATOR_H
 
+#include "strbuf.h"
+
 /*
  * Iterate over a directory tree.
  *
  * Iterate over a directory tree, recursively, including paths of all
  * types and hidden paths. Skip "." and ".." entries and don't follow
- * symlinks except for the original path.
+ * symlinks except for the original path. Note that the original path
+ * is not included in the iteration.
  *
  * Every time dir_iterator_advance() is called, update the members of
  * the dir_iterator structure to reflect the next path in the
  * iteration. The order that paths are iterated over within a
- * directory is undefined, but directory paths are always iterated
- * over before the subdirectory contents.
+ * directory is undefined, directory paths are always given before
+ * their contents.
  *
  * A typical iteration looks like this:
  *
  *     int ok;
- *     struct iterator *iter = dir_iterator_begin(path);
+ *     unsigned int flags = DIR_ITERATOR_PEDANTIC;
+ *     struct dir_iterator *iter = dir_iterator_begin(path, flags);
+ *
+ *     if (!iter)
+ *             goto error_handler;
  *
  *     while ((ok = dir_iterator_advance(iter)) == ITER_OK) {
  *             if (want_to_stop_iteration()) {
@@ -38,6 +45,29 @@
  * dir_iterator_advance() again.
  */
 
+/*
+ * Flags for dir_iterator_begin:
+ *
+ * - DIR_ITERATOR_PEDANTIC: override dir-iterator's default behavior
+ *   in case of an error at dir_iterator_advance(), which is to keep
+ *   looking for a next valid entry. With this flag, resources are freed
+ *   and ITER_ERROR is returned immediately. In both cases, a meaningful
+ *   warning is emitted. Note: ENOENT errors are always ignored so that
+ *   the API users may remove files during iteration.
+ *
+ * - DIR_ITERATOR_FOLLOW_SYMLINKS: make dir-iterator follow symlinks.
+ *   i.e., linked directories' contents will be iterated over and
+ *   iter->base.st will contain information on the referred files,
+ *   not the symlinks themselves, which is the default behavior. Broken
+ *   symlinks are ignored.
+ *
+ * Warning: circular symlinks are also followed when
+ * DIR_ITERATOR_FOLLOW_SYMLINKS is set. The iteration may end up with
+ * an ELOOP if they happen and DIR_ITERATOR_PEDANTIC is set.
+ */
+#define DIR_ITERATOR_PEDANTIC (1 << 0)
+#define DIR_ITERATOR_FOLLOW_SYMLINKS (1 << 1)
+
 struct dir_iterator {
 	/* The current path: */
 	struct strbuf path;
@@ -52,28 +82,38 @@ struct dir_iterator {
 	/* The current basename: */
 	const char *basename;
 
-	/* The result of calling lstat() on path: */
+	/*
+	 * The result of calling lstat() on path; or stat(), if the
+	 * DIR_ITERATOR_FOLLOW_SYMLINKS flag was set at
+	 * dir_iterator's initialization.
+	 */
 	struct stat st;
 };
 
 /*
- * Start a directory iteration over path. Return a dir_iterator that
- * holds the internal state of the iteration.
+ * Start a directory iteration over path with the combination of
+ * options specified by flags. On success, return a dir_iterator
+ * that holds the internal state of the iteration. In case of
+ * failure, return NULL and set errno accordingly.
  *
  * The iteration includes all paths under path, not including path
  * itself and not including "." or ".." entries.
  *
- * path is the starting directory. An internal copy will be made.
+ * Parameters are:
+ *  - path is the starting directory. An internal copy will be made.
+ *  - flags is a combination of the possible flags to initialize a
+ *    dir-iterator or 0 for default behavior.
  */
-struct dir_iterator *dir_iterator_begin(const char *path);
+struct dir_iterator *dir_iterator_begin(const char *path, unsigned int flags);
 
 /*
  * Advance the iterator to the first or next item and return ITER_OK.
  * If the iteration is exhausted, free the dir_iterator and any
- * resources associated with it and return ITER_DONE. On error, free
- * dir_iterator and associated resources and return ITER_ERROR. It is
- * a bug to use iterator or call this function again after it has
- * returned ITER_DONE or ITER_ERROR.
+ * resources associated with it and return ITER_DONE.
+ *
+ * It is a bug to use iterator or call this function again after it
+ * has returned ITER_DONE or ITER_ERROR (which may be returned iff
+ * the DIR_ITERATOR_PEDANTIC flag was set).
  */
 int dir_iterator_advance(struct dir_iterator *iterator);
 
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/asciidoc.conf 1.2.3+git2.25.1-1/git/Documentation/asciidoc.conf
--- 1.2.1+git2.18.0-1/git/Documentation/asciidoc.conf	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/asciidoc.conf	2020-02-17 04:47:35.000000000 +0000
@@ -78,9 +78,9 @@ template::[header-declarations]
 <refmeta>
 <refentrytitle>{mantitle}</refentrytitle>
 <manvolnum>{manvolnum}</manvolnum>
-<refmiscinfo class="source">Git</refmiscinfo>
-<refmiscinfo class="version">{git_version}</refmiscinfo>
-<refmiscinfo class="manual">Git Manual</refmiscinfo>
+<refmiscinfo class="source">{mansource}</refmiscinfo>
+<refmiscinfo class="version">{manversion}</refmiscinfo>
+<refmiscinfo class="manual">{manmanual}</refmiscinfo>
 </refmeta>
 <refnamediv>
   <refname>{manname}</refname>
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/asciidoctor-extensions.rb 1.2.3+git2.25.1-1/git/Documentation/asciidoctor-extensions.rb
--- 1.2.1+git2.18.0-1/git/Documentation/asciidoctor-extensions.rb	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/asciidoctor-extensions.rb	2020-02-17 04:47:35.000000000 +0000
@@ -9,20 +9,40 @@ module Git
       named :chrome
 
       def process(parent, target, attrs)
-        if parent.document.basebackend? 'html'
-          prefix = parent.document.attr('git-relative-html-prefix')
-          %(<a href="#{prefix}#{target}.html">#{target}(#{attrs[1]})</a>\n)
+        prefix = parent.document.attr('git-relative-html-prefix')
+        if parent.document.doctype == 'book'
+          "<ulink url=\"#{prefix}#{target}.html\">" \
+          "#{target}(#{attrs[1]})</ulink>"
+        elsif parent.document.basebackend? 'html'
+          %(<a href="#{prefix}#{target}.html">#{target}(#{attrs[1]})</a>)
         elsif parent.document.basebackend? 'docbook'
           "<citerefentry>\n" \
             "<refentrytitle>#{target}</refentrytitle>" \
             "<manvolnum>#{attrs[1]}</manvolnum>\n" \
-          "</citerefentry>\n"
+          "</citerefentry>"
         end
       end
     end
+
+    class DocumentPostProcessor < Asciidoctor::Extensions::Postprocessor
+      def process document, output
+        if document.basebackend? 'docbook'
+          mansource = document.attributes['mansource']
+          manversion = document.attributes['manversion']
+          manmanual = document.attributes['manmanual']
+          new_tags = "" \
+            "<refmiscinfo class=\"source\">#{mansource}</refmiscinfo>\n" \
+            "<refmiscinfo class=\"version\">#{manversion}</refmiscinfo>\n" \
+            "<refmiscinfo class=\"manual\">#{manmanual}</refmiscinfo>\n"
+          output = output.sub(/<\/refmeta>/, new_tags + "</refmeta>")
+        end
+        output
+      end
+    end
   end
 end
 
 Asciidoctor::Extensions.register do
   inline_macro Git::Documentation::LinkGitProcessor, :linkgit
+  postprocessor Git::Documentation::DocumentPostProcessor
 end
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/blame-options.txt 1.2.3+git2.25.1-1/git/Documentation/blame-options.txt
--- 1.2.1+git2.18.0-1/git/Documentation/blame-options.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/blame-options.txt	2020-02-17 04:47:35.000000000 +0000
@@ -110,5 +110,24 @@ commit. And the default value is 40. If
 `-C` options given, the <num> argument of the last `-C` will
 take effect.
 
+--ignore-rev <rev>::
+	Ignore changes made by the revision when assigning blame, as if the
+	change never happened.  Lines that were changed or added by an ignored
+	commit will be blamed on the previous commit that changed that line or
+	nearby lines.  This option may be specified multiple times to ignore
+	more than one revision.  If the `blame.markIgnoredLines` config option
+	is set, then lines that were changed by an ignored commit and attributed to
+	another commit will be marked with a `?` in the blame output.  If the
+	`blame.markUnblamableLines` config option is set, then those lines touched
+	by an ignored commit that we could not attribute to another revision are
+	marked with a '*'.
+
+--ignore-revs-file <file>::
+	Ignore revisions listed in `file`, which must be in the same format as an
+	`fsck.skipList`.  This option may be repeated, and these files will be
+	processed after any files specified with the `blame.ignoreRevsFile` config
+	option.  An empty file name, `""`, will clear the list of revs from
+	previously processed files.
+
 -h::
 	Show help message.
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/CodingGuidelines 1.2.3+git2.25.1-1/git/Documentation/CodingGuidelines
--- 1.2.1+git2.18.0-1/git/Documentation/CodingGuidelines	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/CodingGuidelines	2020-02-17 04:47:35.000000000 +0000
@@ -75,7 +75,7 @@ For shell scripts specifically (not exha
 
  - If you want to find out if a command is available on the user's
    $PATH, you should use 'type <command>', instead of 'which <command>'.
-   The output of 'which' is not machine parseable and its exit code
+   The output of 'which' is not machine parsable and its exit code
    is not reliable across platforms.
 
  - We use POSIX compliant parameter substitutions and avoid bashisms;
@@ -118,6 +118,24 @@ For shell scripts specifically (not exha
 		do this
 	fi
 
+ - If a command sequence joined with && or || or | spans multiple
+   lines, put each command on a separate line and put && and || and |
+   operators at the end of each line, rather than the start. This
+   means you don't need to use \ to join lines, since the above
+   operators imply the sequence isn't finished.
+
+	(incorrect)
+	grep blob verify_pack_result \
+	| awk -f print_1.awk \
+	| sort >actual &&
+	...
+
+	(correct)
+	grep blob verify_pack_result |
+	awk -f print_1.awk |
+	sort >actual &&
+	...
+
  - We prefer "test" over "[ ... ]".
 
  - We do not write the noiseword "function" in front of shell
@@ -177,10 +195,30 @@ For C programs:
    by e.g. "echo DEVELOPER=1 >>config.mak".
 
  - We try to support a wide range of C compilers to compile Git with,
-   including old ones. That means that you should not use C99
-   initializers, even if a lot of compilers grok it.
+   including old ones.  You should not use features from newer C
+   standard, even if your compiler groks them.
+
+   There are a few exceptions to this guideline:
 
- - Variables have to be declared at the beginning of the block.
+   . since early 2012 with e1327023ea, we have been using an enum
+     definition whose last element is followed by a comma.  This, like
+     an array initializer that ends with a trailing comma, can be used
+     to reduce the patch noise when adding a new identifier at the end.
+
+   . since mid 2017 with cbc0f81d, we have been using designated
+     initializers for struct (e.g. "struct t v = { .val = 'a' };").
+
+   . since mid 2017 with 512f41cf, we have been using designated
+     initializers for array (e.g. "int array[10] = { [5] = 2 }").
+
+   These used to be forbidden, but we have not heard any breakage
+   report, and they are assumed to be safe.
+
+ - Variables have to be declared at the beginning of the block, before
+   the first statement (i.e. -Wdeclaration-after-statement).
+
+ - Declaring a variable in the for loop "for (int i = 0; i < 10; i++)"
+   is still not allowed in this codebase.
 
  - NULL pointers shall be written as NULL, not as 0.
 
@@ -358,7 +396,10 @@ For C programs:
    string_list for sorted string lists, a hash map (mapping struct
    objects) named "struct decorate", amongst other things.
 
- - When you come up with an API, document it.
+ - When you come up with an API, document its functions and structures
+   in the header file that exposes the API to its callers. Use what is
+   in "strbuf.h" as a model for the appropriate tone and level of
+   detail.
 
  - The first #include in C files, except in platform specific compat/
    implementations, must be either "git-compat-util.h", "cache.h" or
@@ -391,6 +432,12 @@ For C programs:
    must be declared with "extern" in header files. However, function
    declarations should not use "extern", as that is already the default.
 
+ - You can launch gdb around your program using the shorthand GIT_DEBUGGER.
+   Run `GIT_DEBUGGER=1 ./bin-wrappers/git foo` to simply use gdb as is, or
+   run `GIT_DEBUGGER="<debugger> <debugger-args>" ./bin-wrappers/git foo` to
+   use your own debugger and arguments. Example: `GIT_DEBUGGER="ddd --gdb"
+   ./bin-wrappers/git log` (See `wrap-for-bin.sh`.)
+
 For Perl programs:
 
  - Most of the C guidelines above apply.
@@ -559,11 +606,14 @@ Writing Documentation:
  or commands:
 
  Literal examples (e.g. use of command-line options, command names,
- branch names, configuration and environment variables) must be
- typeset in monospace (i.e. wrapped with backticks):
+ branch names, URLs, pathnames (files and directories), configuration and
+ environment variables) must be typeset in monospace (i.e. wrapped with
+ backticks):
    `--pretty=oneline`
    `git rev-list`
    `remote.pushDefault`
+   `http://git.example.com`
+   `.git/config`
    `GIT_DIR`
    `HEAD`
 
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/config/add.txt 1.2.3+git2.25.1-1/git/Documentation/config/add.txt
--- 1.2.1+git2.18.0-1/git/Documentation/config/add.txt	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/config/add.txt	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,12 @@
+add.ignoreErrors::
+add.ignore-errors (deprecated)::
+	Tells 'git add' to continue adding files when some files cannot be
+	added due to indexing errors. Equivalent to the `--ignore-errors`
+	option of linkgit:git-add[1].  `add.ignore-errors` is deprecated,
+	as it does not follow the usual naming convention for configuration
+	variables.
+
+add.interactive.useBuiltin::
+	[EXPERIMENTAL] Set to `true` to use the experimental built-in
+	implementation of the interactive version of linkgit:git-add[1]
+	instead of the Perl script version. Is `false` by default.
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/config/advice.txt 1.2.3+git2.25.1-1/git/Documentation/config/advice.txt
--- 1.2.1+git2.18.0-1/git/Documentation/config/advice.txt	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/config/advice.txt	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,113 @@
+advice.*::
+	These variables control various optional help messages designed to
+	aid new users. All 'advice.*' variables default to 'true', and you
+	can tell Git that you do not need help by setting these to 'false':
++
+--
+	fetchShowForcedUpdates::
+		Advice shown when linkgit:git-fetch[1] takes a long time
+		to calculate forced updates after ref updates, or to warn
+		that the check is disabled.
+	pushUpdateRejected::
+		Set this variable to 'false' if you want to disable
+		'pushNonFFCurrent',
+		'pushNonFFMatching', 'pushAlreadyExists',
+		'pushFetchFirst', and 'pushNeedsForce'
+		simultaneously.
+	pushNonFFCurrent::
+		Advice shown when linkgit:git-push[1] fails due to a
+		non-fast-forward update to the current branch.
+	pushNonFFMatching::
+		Advice shown when you ran linkgit:git-push[1] and pushed
+		'matching refs' explicitly (i.e. you used ':', or
+		specified a refspec that isn't your current branch) and
+		it resulted in a non-fast-forward error.
+	pushAlreadyExists::
+		Shown when linkgit:git-push[1] rejects an update that
+		does not qualify for fast-forwarding (e.g., a tag.)
+	pushFetchFirst::
+		Shown when linkgit:git-push[1] rejects an update that
+		tries to overwrite a remote ref that points at an
+		object we do not have.
+	pushNeedsForce::
+		Shown when linkgit:git-push[1] rejects an update that
+		tries to overwrite a remote ref that points at an
+		object that is not a commit-ish, or make the remote
+		ref point at an object that is not a commit-ish.
+	pushUnqualifiedRefname::
+		Shown when linkgit:git-push[1] gives up trying to
+		guess based on the source and destination refs what
+		remote ref namespace the source belongs in, but where
+		we can still suggest that the user push to either
+		refs/heads/* or refs/tags/* based on the type of the
+		source object.
+	statusAheadBehind::
+		Shown when linkgit:git-status[1] computes the ahead/behind
+		counts for a local ref compared to its remote tracking ref,
+		and that calculation takes longer than expected. Will not
+		appear if `status.aheadBehind` is false or the option
+		`--no-ahead-behind` is given.
+	statusHints::
+		Show directions on how to proceed from the current
+		state in the output of linkgit:git-status[1], in
+		the template shown when writing commit messages in
+		linkgit:git-commit[1], and in the help message shown
+		by linkgit:git-switch[1] or
+		linkgit:git-checkout[1] when switching branch.
+	statusUoption::
+		Advise to consider using the `-u` option to linkgit:git-status[1]
+		when the command takes more than 2 seconds to enumerate untracked
+		files.
+	commitBeforeMerge::
+		Advice shown when linkgit:git-merge[1] refuses to
+		merge to avoid overwriting local changes.
+	resetQuiet::
+		Advice to consider using the `--quiet` option to linkgit:git-reset[1]
+		when the command takes more than 2 seconds to enumerate unstaged
+		changes after reset.
+	resolveConflict::
+		Advice shown by various commands when conflicts
+		prevent the operation from being performed.
+	sequencerInUse::
+		Advice shown when a sequencer command is already in progress.
+	implicitIdentity::
+		Advice on how to set your identity configuration when
+		your information is guessed from the system username and
+		domain name.
+	detachedHead::
+		Advice shown when you used
+		linkgit:git-switch[1] or linkgit:git-checkout[1]
+		to move to the detach HEAD state, to instruct how to
+		create a local branch after the fact.
+	checkoutAmbiguousRemoteBranchName::
+		Advice shown when the argument to
+		linkgit:git-checkout[1] and linkgit:git-switch[1]
+		ambiguously resolves to a
+		remote tracking branch on more than one remote in
+		situations where an unambiguous argument would have
+		otherwise caused a remote-tracking branch to be
+		checked out. See the `checkout.defaultRemote`
+		configuration variable for how to set a given remote
+		to used by default in some situations where this
+		advice would be printed.
+	amWorkDir::
+		Advice that shows the location of the patch file when
+		linkgit:git-am[1] fails to apply it.
+	rmHints::
+		In case of failure in the output of linkgit:git-rm[1],
+		show directions on how to proceed from the current state.
+	addEmbeddedRepo::
+		Advice on what to do when you've accidentally added one
+		git repo inside of another.
+	ignoredHook::
+		Advice shown if a hook is ignored because the hook is not
+		set as executable.
+	waitingForEditor::
+		Print a message to the terminal whenever Git is waiting for
+		editor input from the user.
+	nestedTag::
+		Advice shown if a user attempts to recursively tag a tag object.
+	submoduleAlternateErrorStrategyDie::
+		Advice shown when a submodule.alternateErrorStrategy option
+		configured to "die" causes a fatal error.
+--
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/config/alias.txt 1.2.3+git2.25.1-1/git/Documentation/config/alias.txt
--- 1.2.1+git2.18.0-1/git/Documentation/config/alias.txt	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/config/alias.txt	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,28 @@
+alias.*::
+	Command aliases for the linkgit:git[1] command wrapper - e.g.
+	after defining `alias.last = cat-file commit HEAD`, the invocation
+	`git last` is equivalent to `git cat-file commit HEAD`. To avoid
+	confusion and troubles with script usage, aliases that
+	hide existing Git commands are ignored. Arguments are split by
+	spaces, the usual shell quoting and escaping is supported.
+	A quote pair or a backslash can be used to quote them.
++
+Note that the first word of an alias does not necessarily have to be a
+command. It can be a command-line option that will be passed into the
+invocation of `git`. In particular, this is useful when used with `-c`
+to pass in one-time configurations or `-p` to force pagination. For example,
+`loud-rebase = -c commit.verbose=true rebase` can be defined such that
+running `git loud-rebase` would be equivalent to
+`git -c commit.verbose=true rebase`. Also, `ps = -p status` would be a
+helpful alias since `git ps` would paginate the output of `git status`
+where the original command does not.
++
+If the alias expansion is prefixed with an exclamation point,
+it will be treated as a shell command.  For example, defining
+`alias.new = !gitk --all --not ORIG_HEAD`, the invocation
+`git new` is equivalent to running the shell command
+`gitk --all --not ORIG_HEAD`.  Note that shell commands will be
+executed from the top-level directory of a repository, which may
+not necessarily be the current directory.
+`GIT_PREFIX` is set as returned by running `git rev-parse --show-prefix`
+from the original current directory. See linkgit:git-rev-parse[1].
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/config/am.txt 1.2.3+git2.25.1-1/git/Documentation/config/am.txt
--- 1.2.1+git2.18.0-1/git/Documentation/config/am.txt	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/config/am.txt	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,14 @@
+am.keepcr::
+	If true, git-am will call git-mailsplit for patches in mbox format
+	with parameter `--keep-cr`. In this case git-mailsplit will
+	not remove `\r` from lines ending with `\r\n`. Can be overridden
+	by giving `--no-keep-cr` from the command line.
+	See linkgit:git-am[1], linkgit:git-mailsplit[1].
+
+am.threeWay::
+	By default, `git am` will fail if the patch does not apply cleanly. When
+	set to true, this setting tells `git am` to fall back on 3-way merge if
+	the patch records the identity of blobs it is supposed to apply to and
+	we have those blobs available locally (equivalent to giving the `--3way`
+	option from the command line). Defaults to `false`.
+	See linkgit:git-am[1].
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/config/apply.txt 1.2.3+git2.25.1-1/git/Documentation/config/apply.txt
--- 1.2.1+git2.18.0-1/git/Documentation/config/apply.txt	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/config/apply.txt	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,11 @@
+apply.ignoreWhitespace::
+	When set to 'change', tells 'git apply' to ignore changes in
+	whitespace, in the same way as the `--ignore-space-change`
+	option.
+	When set to one of: no, none, never, false tells 'git apply' to
+	respect all whitespace differences.
+	See linkgit:git-apply[1].
+
+apply.whitespace::
+	Tells 'git apply' how to handle whitespaces, in the same way
+	as the `--whitespace` option. See linkgit:git-apply[1].
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/config/blame.txt 1.2.3+git2.25.1-1/git/Documentation/config/blame.txt
--- 1.2.1+git2.18.0-1/git/Documentation/config/blame.txt	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/config/blame.txt	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,37 @@
+blame.blankBoundary::
+	Show blank commit object name for boundary commits in
+	linkgit:git-blame[1]. This option defaults to false.
+
+blame.coloring::
+	This determines the coloring scheme to be applied to blame
+	output. It can be 'repeatedLines', 'highlightRecent',
+	or 'none' which is the default.
+
+blame.date::
+	Specifies the format used to output dates in linkgit:git-blame[1].
+	If unset the iso format is used. For supported values,
+	see the discussion of the `--date` option at linkgit:git-log[1].
+
+blame.showEmail::
+	Show the author email instead of author name in linkgit:git-blame[1].
+	This option defaults to false.
+
+blame.showRoot::
+	Do not treat root commits as boundaries in linkgit:git-blame[1].
+	This option defaults to false.
+
+blame.ignoreRevsFile::
+	Ignore revisions listed in the file, one unabbreviated object name per
+	line, in linkgit:git-blame[1].  Whitespace and comments beginning with
+	`#` are ignored.  This option may be repeated multiple times.  Empty
+	file names will reset the list of ignored revisions.  This option will
+	be handled before the command line option `--ignore-revs-file`.
+
+blame.markUnblamables::
+	Mark lines that were changed by an ignored revision that we could not
+	attribute to another commit with a '*' in the output of
+	linkgit:git-blame[1].
+
+blame.markIgnoredLines::
+	Mark lines that were changed by an ignored revision that we attributed to
+	another commit with a '?' in the output of linkgit:git-blame[1].
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/config/branch.txt 1.2.3+git2.25.1-1/git/Documentation/config/branch.txt
--- 1.2.1+git2.18.0-1/git/Documentation/config/branch.txt	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/config/branch.txt	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,102 @@
+branch.autoSetupMerge::
+	Tells 'git branch', 'git switch' and 'git checkout' to set up new branches
+	so that linkgit:git-pull[1] will appropriately merge from the
+	starting point branch. Note that even if this option is not set,
+	this behavior can be chosen per-branch using the `--track`
+	and `--no-track` options. The valid settings are: `false` -- no
+	automatic setup is done; `true` -- automatic setup is done when the
+	starting point is a remote-tracking branch; `always` --
+	automatic setup is done when the starting point is either a
+	local branch or remote-tracking
+	branch. This option defaults to true.
+
+branch.autoSetupRebase::
+	When a new branch is created with 'git branch', 'git switch' or 'git checkout'
+	that tracks another branch, this variable tells Git to set
+	up pull to rebase instead of merge (see "branch.<name>.rebase").
+	When `never`, rebase is never automatically set to true.
+	When `local`, rebase is set to true for tracked branches of
+	other local branches.
+	When `remote`, rebase is set to true for tracked branches of
+	remote-tracking branches.
+	When `always`, rebase will be set to true for all tracking
+	branches.
+	See "branch.autoSetupMerge" for details on how to set up a
+	branch to track another branch.
+	This option defaults to never.
+
+branch.sort::
+	This variable controls the sort ordering of branches when displayed by
+	linkgit:git-branch[1]. Without the "--sort=<value>" option provided, the
+	value of this variable will be used as the default.
+	See linkgit:git-for-each-ref[1] field names for valid values.
+
+branch.<name>.remote::
+	When on branch <name>, it tells 'git fetch' and 'git push'
+	which remote to fetch from/push to.  The remote to push to
+	may be overridden with `remote.pushDefault` (for all branches).
+	The remote to push to, for the current branch, may be further
+	overridden by `branch.<name>.pushRemote`.  If no remote is
+	configured, or if you are not on any branch, it defaults to
+	`origin` for fetching and `remote.pushDefault` for pushing.
+	Additionally, `.` (a period) is the current local repository
+	(a dot-repository), see `branch.<name>.merge`'s final note below.
+
+branch.<name>.pushRemote::
+	When on branch <name>, it overrides `branch.<name>.remote` for
+	pushing.  It also overrides `remote.pushDefault` for pushing
+	from branch <name>.  When you pull from one place (e.g. your
+	upstream) and push to another place (e.g. your own publishing
+	repository), you would want to set `remote.pushDefault` to
+	specify the remote to push to for all branches, and use this
+	option to override it for a specific branch.
+
+branch.<name>.merge::
+	Defines, together with branch.<name>.remote, the upstream branch
+	for the given branch. It tells 'git fetch'/'git pull'/'git rebase' which
+	branch to merge and can also affect 'git push' (see push.default).
+	When in branch <name>, it tells 'git fetch' the default
+	refspec to be marked for merging in FETCH_HEAD. The value is
+	handled like the remote part of a refspec, and must match a
+	ref which is fetched from the remote given by
+	"branch.<name>.remote".
+	The merge information is used by 'git pull' (which at first calls
+	'git fetch') to lookup the default branch for merging. Without
+	this option, 'git pull' defaults to merge the first refspec fetched.
+	Specify multiple values to get an octopus merge.
+	If you wish to setup 'git pull' so that it merges into <name> from
+	another branch in the local repository, you can point
+	branch.<name>.merge to the desired branch, and use the relative path
+	setting `.` (a period) for branch.<name>.remote.
+
+branch.<name>.mergeOptions::
+	Sets default options for merging into branch <name>. The syntax and
+	supported options are the same as those of linkgit:git-merge[1], but
+	option values containing whitespace characters are currently not
+	supported.
+
+branch.<name>.rebase::
+	When true, rebase the branch <name> on top of the fetched branch,
+	instead of merging the default branch from the default remote when
+	"git pull" is run. See "pull.rebase" for doing this in a non
+	branch-specific manner.
++
+When `merges`, pass the `--rebase-merges` option to 'git rebase'
+so that the local merge commits are included in the rebase (see
+linkgit:git-rebase[1] for details).
++
+When `preserve` (deprecated in favor of `merges`), also pass
+`--preserve-merges` along to 'git rebase' so that locally committed merge
+commits will not be flattened by running 'git pull'.
++
+When the value is `interactive`, the rebase is run in interactive mode.
++
+*NOTE*: this is a possibly dangerous operation; do *not* use
+it unless you understand the implications (see linkgit:git-rebase[1]
+for details).
+
+branch.<name>.description::
+	Branch description, can be edited with
+	`git branch --edit-description`. Branch description is
+	automatically added in the format-patch cover letter or
+	request-pull summary.
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/config/browser.txt 1.2.3+git2.25.1-1/git/Documentation/config/browser.txt
--- 1.2.1+git2.18.0-1/git/Documentation/config/browser.txt	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/config/browser.txt	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,9 @@
+browser.<tool>.cmd::
+	Specify the command to invoke the specified browser. The
+	specified command is evaluated in shell with the URLs passed
+	as arguments. (See linkgit:git-web{litdd}browse[1].)
+
+browser.<tool>.path::
+	Override the path for the given tool that may be used to
+	browse HTML help (see `-w` option in linkgit:git-help[1]) or a
+	working repository in gitweb (see linkgit:git-instaweb[1]).
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/config/checkout.txt 1.2.3+git2.25.1-1/git/Documentation/config/checkout.txt
--- 1.2.1+git2.18.0-1/git/Documentation/config/checkout.txt	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/config/checkout.txt	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,18 @@
+checkout.defaultRemote::
+	When you run 'git checkout <something>'
+	or 'git switch <something>' and only have one
+	remote, it may implicitly fall back on checking out and
+	tracking e.g. 'origin/<something>'. This stops working as soon
+	as you have more than one remote with a '<something>'
+	reference. This setting allows for setting the name of a
+	preferred remote that should always win when it comes to
+	disambiguation. The typical use-case is to set this to
+	`origin`.
++
+Currently this is used by linkgit:git-switch[1] and
+linkgit:git-checkout[1] when 'git checkout <something>'
+or 'git switch <something>'
+will checkout the '<something>' branch on another remote,
+and by linkgit:git-worktree[1] when 'git worktree add' refers to a
+remote branch. This setting might be used for other checkout-like
+commands or functionality in the future.
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/config/clean.txt 1.2.3+git2.25.1-1/git/Documentation/config/clean.txt
--- 1.2.1+git2.18.0-1/git/Documentation/config/clean.txt	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/config/clean.txt	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,3 @@
+clean.requireForce::
+	A boolean to make git-clean do nothing unless given -f,
+	-i or -n.   Defaults to true.
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/config/color.txt 1.2.3+git2.25.1-1/git/Documentation/config/color.txt
--- 1.2.1+git2.18.0-1/git/Documentation/config/color.txt	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/config/color.txt	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,201 @@
+color.advice::
+	A boolean to enable/disable color in hints (e.g. when a push
+	failed, see `advice.*` for a list).  May be set to `always`,
+	`false` (or `never`) or `auto` (or `true`), in which case colors
+	are used only when the error output goes to a terminal. If
+	unset, then the value of `color.ui` is used (`auto` by default).
+
+color.advice.hint::
+	Use customized color for hints.
+
+color.blame.highlightRecent::
+	This can be used to color the metadata of a blame line depending
+	on age of the line.
++
+This setting should be set to a comma-separated list of color and date settings,
+starting and ending with a color, the dates should be set from oldest to newest.
+The metadata will be colored given the colors if the line was introduced
+before the given timestamp, overwriting older timestamped colors.
++
+Instead of an absolute timestamp relative timestamps work as well, e.g.
+2.weeks.ago is valid to address anything older than 2 weeks.
++
+It defaults to 'blue,12 month ago,white,1 month ago,red', which colors
+everything older than one year blue, recent changes between one month and
+one year old are kept white, and lines introduced within the last month are
+colored red.
+
+color.blame.repeatedLines::
+	Use the customized color for the part of git-blame output that
+	is repeated meta information per line (such as commit id,
+	author name, date and timezone). Defaults to cyan.
+
+color.branch::
+	A boolean to enable/disable color in the output of
+	linkgit:git-branch[1]. May be set to `always`,
+	`false` (or `never`) or `auto` (or `true`), in which case colors are used
+	only when the output is to a terminal. If unset, then the
+	value of `color.ui` is used (`auto` by default).
+
+color.branch.<slot>::
+	Use customized color for branch coloration. `<slot>` is one of
+	`current` (the current branch), `local` (a local branch),
+	`remote` (a remote-tracking branch in refs/remotes/),
+	`upstream` (upstream tracking branch), `plain` (other
+	refs).
+
+color.diff::
+	Whether to use ANSI escape sequences to add color to patches.
+	If this is set to `always`, linkgit:git-diff[1],
+	linkgit:git-log[1], and linkgit:git-show[1] will use color
+	for all patches.  If it is set to `true` or `auto`, those
+	commands will only use color when output is to the terminal.
+	If unset, then the value of `color.ui` is used (`auto` by
+	default).
++
+This does not affect linkgit:git-format-patch[1] or the
+'git-diff-{asterisk}' plumbing commands.  Can be overridden on the
+command line with the `--color[=<when>]` option.
+
+color.diff.<slot>::
+	Use customized color for diff colorization.  `<slot>` specifies
+	which part of the patch to use the specified color, and is one
+	of `context` (context text - `plain` is a historical synonym),
+	`meta` (metainformation), `frag`
+	(hunk header), 'func' (function in hunk header), `old` (removed lines),
+	`new` (added lines), `commit` (commit headers), `whitespace`
+	(highlighting whitespace errors), `oldMoved` (deleted lines),
+	`newMoved` (added lines), `oldMovedDimmed`, `oldMovedAlternative`,
+	`oldMovedAlternativeDimmed`, `newMovedDimmed`, `newMovedAlternative`
+	`newMovedAlternativeDimmed` (See the '<mode>'
+	setting of '--color-moved' in linkgit:git-diff[1] for details),
+	`contextDimmed`, `oldDimmed`, `newDimmed`, `contextBold`,
+	`oldBold`, and `newBold` (see linkgit:git-range-diff[1] for details).
+
+color.decorate.<slot>::
+	Use customized color for 'git log --decorate' output.  `<slot>` is one
+	of `branch`, `remoteBranch`, `tag`, `stash` or `HEAD` for local
+	branches, remote-tracking branches, tags, stash and HEAD, respectively
+	and `grafted` for grafted commits.
+
+color.grep::
+	When set to `always`, always highlight matches.  When `false` (or
+	`never`), never.  When set to `true` or `auto`, use color only
+	when the output is written to the terminal.  If unset, then the
+	value of `color.ui` is used (`auto` by default).
+
+color.grep.<slot>::
+	Use customized color for grep colorization.  `<slot>` specifies which
+	part of the line to use the specified color, and is one of
++
+--
+`context`;;
+	non-matching text in context lines (when using `-A`, `-B`, or `-C`)
+`filename`;;
+	filename prefix (when not using `-h`)
+`function`;;
+	function name lines (when using `-p`)
+`lineNumber`;;
+	line number prefix (when using `-n`)
+`column`;;
+	column number prefix (when using `--column`)
+`match`;;
+	matching text (same as setting `matchContext` and `matchSelected`)
+`matchContext`;;
+	matching text in context lines
+`matchSelected`;;
+	matching text in selected lines
+`selected`;;
+	non-matching text in selected lines
+`separator`;;
+	separators between fields on a line (`:`, `-`, and `=`)
+	and between hunks (`--`)
+--
+
+color.interactive::
+	When set to `always`, always use colors for interactive prompts
+	and displays (such as those used by "git-add --interactive" and
+	"git-clean --interactive"). When false (or `never`), never.
+	When set to `true` or `auto`, use colors only when the output is
+	to the terminal. If unset, then the value of `color.ui` is
+	used (`auto` by default).
+
+color.interactive.<slot>::
+	Use customized color for 'git add --interactive' and 'git clean
+	--interactive' output. `<slot>` may be `prompt`, `header`, `help`
+	or `error`, for four distinct types of normal output from
+	interactive commands.
+
+color.pager::
+	A boolean to enable/disable colored output when the pager is in
+	use (default is true).
+
+color.push::
+	A boolean to enable/disable color in push errors. May be set to
+	`always`, `false` (or `never`) or `auto` (or `true`), in which
+	case colors are used only when the error output goes to a terminal.
+	If unset, then the value of `color.ui` is used (`auto` by default).
+
+color.push.error::
+	Use customized color for push errors.
+
+color.remote::
+	If set, keywords at the start of the line are highlighted. The
+	keywords are "error", "warning", "hint" and "success", and are
+	matched case-insensitively. May be set to `always`, `false` (or
+	`never`) or `auto` (or `true`). If unset, then the value of
+	`color.ui` is used (`auto` by default).
+
+color.remote.<slot>::
+	Use customized color for each remote keyword. `<slot>` may be
+	`hint`, `warning`, `success` or `error` which match the
+	corresponding keyword.
+
+color.showBranch::
+	A boolean to enable/disable color in the output of
+	linkgit:git-show-branch[1]. May be set to `always`,
+	`false` (or `never`) or `auto` (or `true`), in which case colors are used
+	only when the output is to a terminal. If unset, then the
+	value of `color.ui` is used (`auto` by default).
+
+color.status::
+	A boolean to enable/disable color in the output of
+	linkgit:git-status[1]. May be set to `always`,
+	`false` (or `never`) or `auto` (or `true`), in which case colors are used
+	only when the output is to a terminal. If unset, then the
+	value of `color.ui` is used (`auto` by default).
+
+color.status.<slot>::
+	Use customized color for status colorization. `<slot>` is
+	one of `header` (the header text of the status message),
+	`added` or `updated` (files which are added but not committed),
+	`changed` (files which are changed but not added in the index),
+	`untracked` (files which are not tracked by Git),
+	`branch` (the current branch),
+	`nobranch` (the color the 'no branch' warning is shown in, defaulting
+	to red),
+	`localBranch` or `remoteBranch` (the local and remote branch names,
+	respectively, when branch and tracking information is displayed in the
+	status short-format), or
+	`unmerged` (files which have unmerged changes).
+
+color.transport::
+	A boolean to enable/disable color when pushes are rejected. May be
+	set to `always`, `false` (or `never`) or `auto` (or `true`), in which
+	case colors are used only when the error output goes to a terminal.
+	If unset, then the value of `color.ui` is used (`auto` by default).
+
+color.transport.rejected::
+	Use customized color when a push was rejected.
+
+color.ui::
+	This variable determines the default value for variables such
+	as `color.diff` and `color.grep` that control the use of color
+	per command family. Its scope will expand as more commands learn
+	configuration to set a default for the `--color` option.  Set it
+	to `false` or `never` if you prefer Git commands not to use
+	color unless enabled explicitly with some other configuration
+	or the `--color` option. Set it to `always` if you want all
+	output not intended for machine consumption to use color, to
+	`true` or `auto` (this is the default since Git 1.8.4) if you
+	want such output to use color when written to the terminal.
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/config/column.txt 1.2.3+git2.25.1-1/git/Documentation/config/column.txt
--- 1.2.1+git2.18.0-1/git/Documentation/config/column.txt	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/config/column.txt	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,55 @@
+column.ui::
+	Specify whether supported commands should output in columns.
+	This variable consists of a list of tokens separated by spaces
+	or commas:
++
+These options control when the feature should be enabled
+(defaults to 'never'):
++
+--
+`always`;;
+	always show in columns
+`never`;;
+	never show in columns
+`auto`;;
+	show in columns if the output is to the terminal
+--
++
+These options control layout (defaults to 'column').  Setting any
+of these implies 'always' if none of 'always', 'never', or 'auto' are
+specified.
++
+--
+`column`;;
+	fill columns before rows
+`row`;;
+	fill rows before columns
+`plain`;;
+	show in one column
+--
++
+Finally, these options can be combined with a layout option (defaults
+to 'nodense'):
++
+--
+`dense`;;
+	make unequal size columns to utilize more space
+`nodense`;;
+	make equal size columns
+--
+
+column.branch::
+	Specify whether to output branch listing in `git branch` in columns.
+	See `column.ui` for details.
+
+column.clean::
+	Specify the layout when list items in `git clean -i`, which always
+	shows files and directories in columns. See `column.ui` for details.
+
+column.status::
+	Specify whether to output untracked files in `git status` in columns.
+	See `column.ui` for details.
+
+column.tag::
+	Specify whether to output tag listing in `git tag` in columns.
+	See `column.ui` for details.
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/config/commit.txt 1.2.3+git2.25.1-1/git/Documentation/config/commit.txt
--- 1.2.1+git2.18.0-1/git/Documentation/config/commit.txt	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/config/commit.txt	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,29 @@
+commit.cleanup::
+	This setting overrides the default of the `--cleanup` option in
+	`git commit`. See linkgit:git-commit[1] for details. Changing the
+	default can be useful when you always want to keep lines that begin
+	with comment character `#` in your log message, in which case you
+	would do `git config commit.cleanup whitespace` (note that you will
+	have to remove the help lines that begin with `#` in the commit log
+	template yourself, if you do this).
+
+commit.gpgSign::
+
+	A boolean to specify whether all commits should be GPG signed.
+	Use of this option when doing operations such as rebase can
+	result in a large number of commits being signed. It may be
+	convenient to use an agent to avoid typing your GPG passphrase
+	several times.
+
+commit.status::
+	A boolean to enable/disable inclusion of status information in the
+	commit message template when using an editor to prepare the commit
+	message.  Defaults to true.
+
+commit.template::
+	Specify the pathname of a file to use as the template for
+	new commit messages.
+
+commit.verbose::
+	A boolean or int to specify the level of verbose with `git commit`.
+	See linkgit:git-commit[1].
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/config/completion.txt 1.2.3+git2.25.1-1/git/Documentation/config/completion.txt
--- 1.2.1+git2.18.0-1/git/Documentation/config/completion.txt	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/config/completion.txt	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,7 @@
+completion.commands::
+	This is only used by git-completion.bash to add or remove
+	commands from the list of completed commands. Normally only
+	porcelain commands and a few select others are completed. You
+	can add more commands, separated by space, in this
+	variable. Prefixing the command with '-' will remove it from
+	the existing list.
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/config/core.txt 1.2.3+git2.25.1-1/git/Documentation/config/core.txt
--- 1.2.1+git2.18.0-1/git/Documentation/config/core.txt	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/config/core.txt	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,617 @@
+core.fileMode::
+	Tells Git if the executable bit of files in the working tree
+	is to be honored.
++
+Some filesystems lose the executable bit when a file that is
+marked as executable is checked out, or checks out a
+non-executable file with executable bit on.
+linkgit:git-clone[1] or linkgit:git-init[1] probe the filesystem
+to see if it handles the executable bit correctly
+and this variable is automatically set as necessary.
++
+A repository, however, may be on a filesystem that handles
+the filemode correctly, and this variable is set to 'true'
+when created, but later may be made accessible from another
+environment that loses the filemode (e.g. exporting ext4 via
+CIFS mount, visiting a Cygwin created repository with
+Git for Windows or Eclipse).
+In such a case it may be necessary to set this variable to 'false'.
+See linkgit:git-update-index[1].
++
+The default is true (when core.filemode is not specified in the config file).
+
+core.hideDotFiles::
+	(Windows-only) If true, mark newly-created directories and files whose
+	name starts with a dot as hidden.  If 'dotGitOnly', only the `.git/`
+	directory is hidden, but no other files starting with a dot.  The
+	default mode is 'dotGitOnly'.
+
+core.ignoreCase::
+	Internal variable which enables various workarounds to enable
+	Git to work better on filesystems that are not case sensitive,
+	like APFS, HFS+, FAT, NTFS, etc. For example, if a directory listing
+	finds "makefile" when Git expects "Makefile", Git will assume
+	it is really the same file, and continue to remember it as
+	"Makefile".
++
+The default is false, except linkgit:git-clone[1] or linkgit:git-init[1]
+will probe and set core.ignoreCase true if appropriate when the repository
+is created.
++
+Git relies on the proper configuration of this variable for your operating
+and file system. Modifying this value may result in unexpected behavior.
+
+core.precomposeUnicode::
+	This option is only used by Mac OS implementation of Git.
+	When core.precomposeUnicode=true, Git reverts the unicode decomposition
+	of filenames done by Mac OS. This is useful when sharing a repository
+	between Mac OS and Linux or Windows.
+	(Git for Windows 1.7.10 or higher is needed, or Git under cygwin 1.7).
+	When false, file names are handled fully transparent by Git,
+	which is backward compatible with older versions of Git.
+
+core.protectHFS::
+	If set to true, do not allow checkout of paths that would
+	be considered equivalent to `.git` on an HFS+ filesystem.
+	Defaults to `true` on Mac OS, and `false` elsewhere.
+
+core.protectNTFS::
+	If set to true, do not allow checkout of paths that would
+	cause problems with the NTFS filesystem, e.g. conflict with
+	8.3 "short" names.
+	Defaults to `true` on Windows, and `false` elsewhere.
+
+core.fsmonitor::
+	If set, the value of this variable is used as a command which
+	will identify all files that may have changed since the
+	requested date/time. This information is used to speed up git by
+	avoiding unnecessary processing of files that have not changed.
+	See the "fsmonitor-watchman" section of linkgit:githooks[5].
+
+core.trustctime::
+	If false, the ctime differences between the index and the
+	working tree are ignored; useful when the inode change time
+	is regularly modified by something outside Git (file system
+	crawlers and some backup systems).
+	See linkgit:git-update-index[1]. True by default.
+
+core.splitIndex::
+	If true, the split-index feature of the index will be used.
+	See linkgit:git-update-index[1]. False by default.
+
+core.untrackedCache::
+	Determines what to do about the untracked cache feature of the
+	index. It will be kept, if this variable is unset or set to
+	`keep`. It will automatically be added if set to `true`. And
+	it will automatically be removed, if set to `false`. Before
+	setting it to `true`, you should check that mtime is working
+	properly on your system.
+	See linkgit:git-update-index[1]. `keep` by default, unless
+	`feature.manyFiles` is enabled which sets this setting to
+	`true` by default.
+
+core.checkStat::
+	When missing or is set to `default`, many fields in the stat
+	structure are checked to detect if a file has been modified
+	since Git looked at it.  When this configuration variable is
+	set to `minimal`, sub-second part of mtime and ctime, the
+	uid and gid of the owner of the file, the inode number (and
+	the device number, if Git was compiled to use it), are
+	excluded from the check among these fields, leaving only the
+	whole-second part of mtime (and ctime, if `core.trustCtime`
+	is set) and the filesize to be checked.
++
+There are implementations of Git that do not leave usable values in
+some fields (e.g. JGit); by excluding these fields from the
+comparison, the `minimal` mode may help interoperability when the
+same repository is used by these other systems at the same time.
+
+core.quotePath::
+	Commands that output paths (e.g. 'ls-files', 'diff'), will
+	quote "unusual" characters in the pathname by enclosing the
+	pathname in double-quotes and escaping those characters with
+	backslashes in the same way C escapes control characters (e.g.
+	`\t` for TAB, `\n` for LF, `\\` for backslash) or bytes with
+	values larger than 0x80 (e.g. octal `\302\265` for "micro" in
+	UTF-8).  If this variable is set to false, bytes higher than
+	0x80 are not considered "unusual" any more. Double-quotes,
+	backslash and control characters are always escaped regardless
+	of the setting of this variable.  A simple space character is
+	not considered "unusual".  Many commands can output pathnames
+	completely verbatim using the `-z` option. The default value
+	is true.
+
+core.eol::
+	Sets the line ending type to use in the working directory for
+	files that are marked as text (either by having the `text`
+	attribute set, or by having `text=auto` and Git auto-detecting
+	the contents as text).
+	Alternatives are 'lf', 'crlf' and 'native', which uses the platform's
+	native line ending.  The default value is `native`.  See
+	linkgit:gitattributes[5] for more information on end-of-line
+	conversion. Note that this value is ignored if `core.autocrlf`
+	is set to `true` or `input`.
+
+core.safecrlf::
+	If true, makes Git check if converting `CRLF` is reversible when
+	end-of-line conversion is active.  Git will verify if a command
+	modifies a file in the work tree either directly or indirectly.
+	For example, committing a file followed by checking out the
+	same file should yield the original file in the work tree.  If
+	this is not the case for the current setting of
+	`core.autocrlf`, Git will reject the file.  The variable can
+	be set to "warn", in which case Git will only warn about an
+	irreversible conversion but continue the operation.
++
+CRLF conversion bears a slight chance of corrupting data.
+When it is enabled, Git will convert CRLF to LF during commit and LF to
+CRLF during checkout.  A file that contains a mixture of LF and
+CRLF before the commit cannot be recreated by Git.  For text
+files this is the right thing to do: it corrects line endings
+such that we have only LF line endings in the repository.
+But for binary files that are accidentally classified as text the
+conversion can corrupt data.
++
+If you recognize such corruption early you can easily fix it by
+setting the conversion type explicitly in .gitattributes.  Right
+after committing you still have the original file in your work
+tree and this file is not yet corrupted.  You can explicitly tell
+Git that this file is binary and Git will handle the file
+appropriately.
++
+Unfortunately, the desired effect of cleaning up text files with
+mixed line endings and the undesired effect of corrupting binary
+files cannot be distinguished.  In both cases CRLFs are removed
+in an irreversible way.  For text files this is the right thing
+to do because CRLFs are line endings, while for binary files
+converting CRLFs corrupts data.
++
+Note, this safety check does not mean that a checkout will generate a
+file identical to the original file for a different setting of
+`core.eol` and `core.autocrlf`, but only for the current one.  For
+example, a text file with `LF` would be accepted with `core.eol=lf`
+and could later be checked out with `core.eol=crlf`, in which case the
+resulting file would contain `CRLF`, although the original file
+contained `LF`.  However, in both work trees the line endings would be
+consistent, that is either all `LF` or all `CRLF`, but never mixed.  A
+file with mixed line endings would be reported by the `core.safecrlf`
+mechanism.
+
+core.autocrlf::
+	Setting this variable to "true" is the same as setting
+	the `text` attribute to "auto" on all files and core.eol to "crlf".
+	Set to true if you want to have `CRLF` line endings in your
+	working directory and the repository has LF line endings.
+	This variable can be set to 'input',
+	in which case no output conversion is performed.
+
+core.checkRoundtripEncoding::
+	A comma and/or whitespace separated list of encodings that Git
+	performs UTF-8 round trip checks on if they are used in an
+	`working-tree-encoding` attribute (see linkgit:gitattributes[5]).
+	The default value is `SHIFT-JIS`.
+
+core.symlinks::
+	If false, symbolic links are checked out as small plain files that
+	contain the link text. linkgit:git-update-index[1] and
+	linkgit:git-add[1] will not change the recorded type to regular
+	file. Useful on filesystems like FAT that do not support
+	symbolic links.
++
+The default is true, except linkgit:git-clone[1] or linkgit:git-init[1]
+will probe and set core.symlinks false if appropriate when the repository
+is created.
+
+core.gitProxy::
+	A "proxy command" to execute (as 'command host port') instead
+	of establishing direct connection to the remote server when
+	using the Git protocol for fetching. If the variable value is
+	in the "COMMAND for DOMAIN" format, the command is applied only
+	on hostnames ending with the specified domain string. This variable
+	may be set multiple times and is matched in the given order;
+	the first match wins.
++
+Can be overridden by the `GIT_PROXY_COMMAND` environment variable
+(which always applies universally, without the special "for"
+handling).
++
+The special string `none` can be used as the proxy command to
+specify that no proxy be used for a given domain pattern.
+This is useful for excluding servers inside a firewall from
+proxy use, while defaulting to a common proxy for external domains.
+
+core.sshCommand::
+	If this variable is set, `git fetch` and `git push` will
+	use the specified command instead of `ssh` when they need to
+	connect to a remote system. The command is in the same form as
+	the `GIT_SSH_COMMAND` environment variable and is overridden
+	when the environment variable is set.
+
+core.ignoreStat::
+	If true, Git will avoid using lstat() calls to detect if files have
+	changed by setting the "assume-unchanged" bit for those tracked files
+	which it has updated identically in both the index and working tree.
++
+When files are modified outside of Git, the user will need to stage
+the modified files explicitly (e.g. see 'Examples' section in
+linkgit:git-update-index[1]).
+Git will not normally detect changes to those files.
++
+This is useful on systems where lstat() calls are very slow, such as
+CIFS/Microsoft Windows.
++
+False by default.
+
+core.preferSymlinkRefs::
+	Instead of the default "symref" format for HEAD
+	and other symbolic reference files, use symbolic links.
+	This is sometimes needed to work with old scripts that
+	expect HEAD to be a symbolic link.
+
+core.alternateRefsCommand::
+	When advertising tips of available history from an alternate, use the shell to
+	execute the specified command instead of linkgit:git-for-each-ref[1]. The
+	first argument is the absolute path of the alternate. Output must contain one
+	hex object id per line (i.e., the same as produced by `git for-each-ref
+	--format='%(objectname)'`).
++
+Note that you cannot generally put `git for-each-ref` directly into the config
+value, as it does not take a repository path as an argument (but you can wrap
+the command above in a shell script).
+
+core.alternateRefsPrefixes::
+	When listing references from an alternate, list only references that begin
+	with the given prefix. Prefixes match as if they were given as arguments to
+	linkgit:git-for-each-ref[1]. To list multiple prefixes, separate them with
+	whitespace. If `core.alternateRefsCommand` is set, setting
+	`core.alternateRefsPrefixes` has no effect.
+
+core.bare::
+	If true this repository is assumed to be 'bare' and has no
+	working directory associated with it.  If this is the case a
+	number of commands that require a working directory will be
+	disabled, such as linkgit:git-add[1] or linkgit:git-merge[1].
++
+This setting is automatically guessed by linkgit:git-clone[1] or
+linkgit:git-init[1] when the repository was created.  By default a
+repository that ends in "/.git" is assumed to be not bare (bare =
+false), while all other repositories are assumed to be bare (bare
+= true).
+
+core.worktree::
+	Set the path to the root of the working tree.
+	If `GIT_COMMON_DIR` environment variable is set, core.worktree
+	is ignored and not used for determining the root of working tree.
+	This can be overridden by the `GIT_WORK_TREE` environment
+	variable and the `--work-tree` command-line option.
+	The value can be an absolute path or relative to the path to
+	the .git directory, which is either specified by --git-dir
+	or GIT_DIR, or automatically discovered.
+	If --git-dir or GIT_DIR is specified but none of
+	--work-tree, GIT_WORK_TREE and core.worktree is specified,
+	the current working directory is regarded as the top level
+	of your working tree.
++
+Note that this variable is honored even when set in a configuration
+file in a ".git" subdirectory of a directory and its value differs
+from the latter directory (e.g. "/path/to/.git/config" has
+core.worktree set to "/different/path"), which is most likely a
+misconfiguration.  Running Git commands in the "/path/to" directory will
+still use "/different/path" as the root of the work tree and can cause
+confusion unless you know what you are doing (e.g. you are creating a
+read-only snapshot of the same index to a location different from the
+repository's usual working tree).
+
+core.logAllRefUpdates::
+	Enable the reflog. Updates to a ref <ref> is logged to the file
+	"`$GIT_DIR/logs/<ref>`", by appending the new and old
+	SHA-1, the date/time and the reason of the update, but
+	only when the file exists.  If this configuration
+	variable is set to `true`, missing "`$GIT_DIR/logs/<ref>`"
+	file is automatically created for branch heads (i.e. under
+	`refs/heads/`), remote refs (i.e. under `refs/remotes/`),
+	note refs (i.e. under `refs/notes/`), and the symbolic ref `HEAD`.
+	If it is set to `always`, then a missing reflog is automatically
+	created for any ref under `refs/`.
++
+This information can be used to determine what commit
+was the tip of a branch "2 days ago".
++
+This value is true by default in a repository that has
+a working directory associated with it, and false by
+default in a bare repository.
+
+core.repositoryFormatVersion::
+	Internal variable identifying the repository format and layout
+	version.
+
+core.sharedRepository::
+	When 'group' (or 'true'), the repository is made shareable between
+	several users in a group (making sure all the files and objects are
+	group-writable). When 'all' (or 'world' or 'everybody'), the
+	repository will be readable by all users, additionally to being
+	group-shareable. When 'umask' (or 'false'), Git will use permissions
+	reported by umask(2). When '0xxx', where '0xxx' is an octal number,
+	files in the repository will have this mode value. '0xxx' will override
+	user's umask value (whereas the other options will only override
+	requested parts of the user's umask value). Examples: '0660' will make
+	the repo read/write-able for the owner and group, but inaccessible to
+	others (equivalent to 'group' unless umask is e.g. '0022'). '0640' is a
+	repository that is group-readable but not group-writable.
+	See linkgit:git-init[1]. False by default.
+
+core.warnAmbiguousRefs::
+	If true, Git will warn you if the ref name you passed it is ambiguous
+	and might match multiple refs in the repository. True by default.
+
+core.compression::
+	An integer -1..9, indicating a default compression level.
+	-1 is the zlib default. 0 means no compression,
+	and 1..9 are various speed/size tradeoffs, 9 being slowest.
+	If set, this provides a default to other compression variables,
+	such as `core.looseCompression` and `pack.compression`.
+
+core.looseCompression::
+	An integer -1..9, indicating the compression level for objects that
+	are not in a pack file. -1 is the zlib default. 0 means no
+	compression, and 1..9 are various speed/size tradeoffs, 9 being
+	slowest.  If not set,  defaults to core.compression.  If that is
+	not set,  defaults to 1 (best speed).
+
+core.packedGitWindowSize::
+	Number of bytes of a pack file to map into memory in a
+	single mapping operation.  Larger window sizes may allow
+	your system to process a smaller number of large pack files
+	more quickly.  Smaller window sizes will negatively affect
+	performance due to increased calls to the operating system's
+	memory manager, but may improve performance when accessing
+	a large number of large pack files.
++
+Default is 1 MiB if NO_MMAP was set at compile time, otherwise 32
+MiB on 32 bit platforms and 1 GiB on 64 bit platforms.  This should
+be reasonable for all users/operating systems.  You probably do
+not need to adjust this value.
++
+Common unit suffixes of 'k', 'm', or 'g' are supported.
+
+core.packedGitLimit::
+	Maximum number of bytes to map simultaneously into memory
+	from pack files.  If Git needs to access more than this many
+	bytes at once to complete an operation it will unmap existing
+	regions to reclaim virtual address space within the process.
++
+Default is 256 MiB on 32 bit platforms and 32 TiB (effectively
+unlimited) on 64 bit platforms.
+This should be reasonable for all users/operating systems, except on
+the largest projects.  You probably do not need to adjust this value.
++
+Common unit suffixes of 'k', 'm', or 'g' are supported.
+
+core.deltaBaseCacheLimit::
+	Maximum number of bytes to reserve for caching base objects
+	that may be referenced by multiple deltified objects.  By storing the
+	entire decompressed base objects in a cache Git is able
+	to avoid unpacking and decompressing frequently used base
+	objects multiple times.
++
+Default is 96 MiB on all platforms.  This should be reasonable
+for all users/operating systems, except on the largest projects.
+You probably do not need to adjust this value.
++
+Common unit suffixes of 'k', 'm', or 'g' are supported.
+
+core.bigFileThreshold::
+	Files larger than this size are stored deflated, without
+	attempting delta compression.  Storing large files without
+	delta compression avoids excessive memory usage, at the
+	slight expense of increased disk usage. Additionally files
+	larger than this size are always treated as binary.
++
+Default is 512 MiB on all platforms.  This should be reasonable
+for most projects as source code and other text files can still
+be delta compressed, but larger binary media files won't be.
++
+Common unit suffixes of 'k', 'm', or 'g' are supported.
+
+core.excludesFile::
+	Specifies the pathname to the file that contains patterns to
+	describe paths that are not meant to be tracked, in addition
+	to `.gitignore` (per-directory) and `.git/info/exclude`.
+	Defaults to `$XDG_CONFIG_HOME/git/ignore`.
+	If `$XDG_CONFIG_HOME` is either not set or empty, `$HOME/.config/git/ignore`
+	is used instead. See linkgit:gitignore[5].
+
+core.askPass::
+	Some commands (e.g. svn and http interfaces) that interactively
+	ask for a password can be told to use an external program given
+	via the value of this variable. Can be overridden by the `GIT_ASKPASS`
+	environment variable. If not set, fall back to the value of the
+	`SSH_ASKPASS` environment variable or, failing that, a simple password
+	prompt. The external program shall be given a suitable prompt as
+	command-line argument and write the password on its STDOUT.
+
+core.attributesFile::
+	In addition to `.gitattributes` (per-directory) and
+	`.git/info/attributes`, Git looks into this file for attributes
+	(see linkgit:gitattributes[5]). Path expansions are made the same
+	way as for `core.excludesFile`. Its default value is
+	`$XDG_CONFIG_HOME/git/attributes`. If `$XDG_CONFIG_HOME` is either not
+	set or empty, `$HOME/.config/git/attributes` is used instead.
+
+core.hooksPath::
+	By default Git will look for your hooks in the
+	`$GIT_DIR/hooks` directory. Set this to different path,
+	e.g. `/etc/git/hooks`, and Git will try to find your hooks in
+	that directory, e.g. `/etc/git/hooks/pre-receive` instead of
+	in `$GIT_DIR/hooks/pre-receive`.
++
+The path can be either absolute or relative. A relative path is
+taken as relative to the directory where the hooks are run (see
+the "DESCRIPTION" section of linkgit:githooks[5]).
++
+This configuration variable is useful in cases where you'd like to
+centrally configure your Git hooks instead of configuring them on a
+per-repository basis, or as a more flexible and centralized
+alternative to having an `init.templateDir` where you've changed
+default hooks.
+
+core.editor::
+	Commands such as `commit` and `tag` that let you edit
+	messages by launching an editor use the value of this
+	variable when it is set, and the environment variable
+	`GIT_EDITOR` is not set.  See linkgit:git-var[1].
+
+core.commentChar::
+	Commands such as `commit` and `tag` that let you edit
+	messages consider a line that begins with this character
+	commented, and removes them after the editor returns
+	(default '#').
++
+If set to "auto", `git-commit` would select a character that is not
+the beginning character of any line in existing commit messages.
+
+core.filesRefLockTimeout::
+	The length of time, in milliseconds, to retry when trying to
+	lock an individual reference. Value 0 means not to retry at
+	all; -1 means to try indefinitely. Default is 100 (i.e.,
+	retry for 100ms).
+
+core.packedRefsTimeout::
+	The length of time, in milliseconds, to retry when trying to
+	lock the `packed-refs` file. Value 0 means not to retry at
+	all; -1 means to try indefinitely. Default is 1000 (i.e.,
+	retry for 1 second).
+
+core.pager::
+	Text viewer for use by Git commands (e.g., 'less').  The value
+	is meant to be interpreted by the shell.  The order of preference
+	is the `$GIT_PAGER` environment variable, then `core.pager`
+	configuration, then `$PAGER`, and then the default chosen at
+	compile time (usually 'less').
++
+When the `LESS` environment variable is unset, Git sets it to `FRX`
+(if `LESS` environment variable is set, Git does not change it at
+all).  If you want to selectively override Git's default setting
+for `LESS`, you can set `core.pager` to e.g. `less -S`.  This will
+be passed to the shell by Git, which will translate the final
+command to `LESS=FRX less -S`. The environment does not set the
+`S` option but the command line does, instructing less to truncate
+long lines. Similarly, setting `core.pager` to `less -+F` will
+deactivate the `F` option specified by the environment from the
+command-line, deactivating the "quit if one screen" behavior of
+`less`.  One can specifically activate some flags for particular
+commands: for example, setting `pager.blame` to `less -S` enables
+line truncation only for `git blame`.
++
+Likewise, when the `LV` environment variable is unset, Git sets it
+to `-c`.  You can override this setting by exporting `LV` with
+another value or setting `core.pager` to `lv +c`.
+
+core.whitespace::
+	A comma separated list of common whitespace problems to
+	notice.  'git diff' will use `color.diff.whitespace` to
+	highlight them, and 'git apply --whitespace=error' will
+	consider them as errors.  You can prefix `-` to disable
+	any of them (e.g. `-trailing-space`):
++
+* `blank-at-eol` treats trailing whitespaces at the end of the line
+  as an error (enabled by default).
+* `space-before-tab` treats a space character that appears immediately
+  before a tab character in the initial indent part of the line as an
+  error (enabled by default).
+* `indent-with-non-tab` treats a line that is indented with space
+  characters instead of the equivalent tabs as an error (not enabled by
+  default).
+* `tab-in-indent` treats a tab character in the initial indent part of
+  the line as an error (not enabled by default).
+* `blank-at-eof` treats blank lines added at the end of file as an error
+  (enabled by default).
+* `trailing-space` is a short-hand to cover both `blank-at-eol` and
+  `blank-at-eof`.
+* `cr-at-eol` treats a carriage-return at the end of line as
+  part of the line terminator, i.e. with it, `trailing-space`
+  does not trigger if the character before such a carriage-return
+  is not a whitespace (not enabled by default).
+* `tabwidth=<n>` tells how many character positions a tab occupies; this
+  is relevant for `indent-with-non-tab` and when Git fixes `tab-in-indent`
+  errors. The default tab width is 8. Allowed values are 1 to 63.
+
+core.fsyncObjectFiles::
+	This boolean will enable 'fsync()' when writing object files.
++
+This is a total waste of time and effort on a filesystem that orders
+data writes properly, but can be useful for filesystems that do not use
+journalling (traditional UNIX filesystems) or that only journal metadata
+and not file contents (OS X's HFS+, or Linux ext3 with "data=writeback").
+
+core.preloadIndex::
+	Enable parallel index preload for operations like 'git diff'
++
+This can speed up operations like 'git diff' and 'git status' especially
+on filesystems like NFS that have weak caching semantics and thus
+relatively high IO latencies.  When enabled, Git will do the
+index comparison to the filesystem data in parallel, allowing
+overlapping IO's.  Defaults to true.
+
+core.unsetenvvars::
+	Windows-only: comma-separated list of environment variables'
+	names that need to be unset before spawning any other process.
+	Defaults to `PERL5LIB` to account for the fact that Git for
+	Windows insists on using its own Perl interpreter.
+
+core.restrictinheritedhandles::
+	Windows-only: override whether spawned processes inherit only standard
+	file handles (`stdin`, `stdout` and `stderr`) or all handles. Can be
+	`auto`, `true` or `false`. Defaults to `auto`, which means `true` on
+	Windows 7 and later, and `false` on older Windows versions.
+
+core.createObject::
+	You can set this to 'link', in which case a hardlink followed by
+	a delete of the source are used to make sure that object creation
+	will not overwrite existing objects.
++
+On some file system/operating system combinations, this is unreliable.
+Set this config setting to 'rename' there; However, This will remove the
+check that makes sure that existing object files will not get overwritten.
+
+core.notesRef::
+	When showing commit messages, also show notes which are stored in
+	the given ref.  The ref must be fully qualified.  If the given
+	ref does not exist, it is not an error but means that no
+	notes should be printed.
++
+This setting defaults to "refs/notes/commits", and it can be overridden by
+the `GIT_NOTES_REF` environment variable.  See linkgit:git-notes[1].
+
+core.commitGraph::
+	If true, then git will read the commit-graph file (if it exists)
+	to parse the graph structure of commits. Defaults to true. See
+	linkgit:git-commit-graph[1] for more information.
+
+core.useReplaceRefs::
+	If set to `false`, behave as if the `--no-replace-objects`
+	option was given on the command line. See linkgit:git[1] and
+	linkgit:git-replace[1] for more information.
+
+core.multiPackIndex::
+	Use the multi-pack-index file to track multiple packfiles using a
+	single index. See link:technical/multi-pack-index.html[the
+	multi-pack-index design document].
+
+core.sparseCheckout::
+	Enable "sparse checkout" feature. See linkgit:git-sparse-checkout[1]
+	for more information.
+
+core.sparseCheckoutCone::
+	Enables the "cone mode" of the sparse checkout feature. When the
+	sparse-checkout file contains a limited set of patterns, then this
+	mode provides significant performance advantages. See
+	linkgit:git-sparse-checkout[1] for more information.
+
+core.abbrev::
+	Set the length object names are abbreviated to.  If
+	unspecified or set to "auto", an appropriate value is
+	computed based on the approximate number of packed objects
+	in your repository, which hopefully is enough for
+	abbreviated object names to stay unique for some time.
+	The minimum length is 4.
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/config/credential.txt 1.2.3+git2.25.1-1/git/Documentation/config/credential.txt
--- 1.2.1+git2.18.0-1/git/Documentation/config/credential.txt	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/config/credential.txt	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,26 @@
+credential.helper::
+	Specify an external helper to be called when a username or
+	password credential is needed; the helper may consult external
+	storage to avoid prompting the user for the credentials. Note
+	that multiple helpers may be defined. See linkgit:gitcredentials[7]
+	for details.
+
+credential.useHttpPath::
+	When acquiring credentials, consider the "path" component of an http
+	or https URL to be important. Defaults to false. See
+	linkgit:gitcredentials[7] for more information.
+
+credential.username::
+	If no username is set for a network authentication, use this username
+	by default. See credential.<context>.* below, and
+	linkgit:gitcredentials[7].
+
+credential.<url>.*::
+	Any of the credential.* options above can be applied selectively to
+	some credentials. For example "credential.https://example.com.username"
+	would set the default username only for https connections to
+	example.com. See linkgit:gitcredentials[7] for details on how URLs are
+	matched.
+
+credentialCache.ignoreSIGHUP::
+	Tell git-credential-cache--daemon to ignore SIGHUP, instead of quitting.
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/config/difftool.txt 1.2.3+git2.25.1-1/git/Documentation/config/difftool.txt
--- 1.2.1+git2.18.0-1/git/Documentation/config/difftool.txt	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/config/difftool.txt	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,14 @@
+difftool.<tool>.path::
+	Override the path for the given tool.  This is useful in case
+	your tool is not in the PATH.
+
+difftool.<tool>.cmd::
+	Specify the command to invoke the specified diff tool.
+	The specified command is evaluated in shell with the following
+	variables available:  'LOCAL' is set to the name of the temporary
+	file containing the contents of the diff pre-image and 'REMOTE'
+	is set to the name of the temporary file containing the contents
+	of the diff post-image.
+
+difftool.prompt::
+	Prompt before each invocation of the diff tool.
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/config/diff.txt 1.2.3+git2.25.1-1/git/Documentation/config/diff.txt
--- 1.2.1+git2.18.0-1/git/Documentation/config/diff.txt	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/config/diff.txt	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,231 @@
+diff.autoRefreshIndex::
+	When using 'git diff' to compare with work tree
+	files, do not consider stat-only change as changed.
+	Instead, silently run `git update-index --refresh` to
+	update the cached stat information for paths whose
+	contents in the work tree match the contents in the
+	index.  This option defaults to true.  Note that this
+	affects only 'git diff' Porcelain, and not lower level
+	'diff' commands such as 'git diff-files'.
+
+diff.dirstat::
+	A comma separated list of `--dirstat` parameters specifying the
+	default behavior of the `--dirstat` option to linkgit:git-diff[1]
+	and friends. The defaults can be overridden on the command line
+	(using `--dirstat=<param1,param2,...>`). The fallback defaults
+	(when not changed by `diff.dirstat`) are `changes,noncumulative,3`.
+	The following parameters are available:
++
+--
+`changes`;;
+	Compute the dirstat numbers by counting the lines that have been
+	removed from the source, or added to the destination. This ignores
+	the amount of pure code movements within a file.  In other words,
+	rearranging lines in a file is not counted as much as other changes.
+	This is the default behavior when no parameter is given.
+`lines`;;
+	Compute the dirstat numbers by doing the regular line-based diff
+	analysis, and summing the removed/added line counts. (For binary
+	files, count 64-byte chunks instead, since binary files have no
+	natural concept of lines). This is a more expensive `--dirstat`
+	behavior than the `changes` behavior, but it does count rearranged
+	lines within a file as much as other changes. The resulting output
+	is consistent with what you get from the other `--*stat` options.
+`files`;;
+	Compute the dirstat numbers by counting the number of files changed.
+	Each changed file counts equally in the dirstat analysis. This is
+	the computationally cheapest `--dirstat` behavior, since it does
+	not have to look at the file contents at all.
+`cumulative`;;
+	Count changes in a child directory for the parent directory as well.
+	Note that when using `cumulative`, the sum of the percentages
+	reported may exceed 100%. The default (non-cumulative) behavior can
+	be specified with the `noncumulative` parameter.
+<limit>;;
+	An integer parameter specifies a cut-off percent (3% by default).
+	Directories contributing less than this percentage of the changes
+	are not shown in the output.
+--
++
+Example: The following will count changed files, while ignoring
+directories with less than 10% of the total amount of changed files,
+and accumulating child directory counts in the parent directories:
+`files,10,cumulative`.
+
+diff.statGraphWidth::
+	Limit the width of the graph part in --stat output. If set, applies
+	to all commands generating --stat output except format-patch.
+
+diff.context::
+	Generate diffs with <n> lines of context instead of the default
+	of 3. This value is overridden by the -U option.
+
+diff.interHunkContext::
+	Show the context between diff hunks, up to the specified number
+	of lines, thereby fusing the hunks that are close to each other.
+	This value serves as the default for the `--inter-hunk-context`
+	command line option.
+
+diff.external::
+	If this config variable is set, diff generation is not
+	performed using the internal diff machinery, but using the
+	given command.  Can be overridden with the `GIT_EXTERNAL_DIFF'
+	environment variable.  The command is called with parameters
+	as described under "git Diffs" in linkgit:git[1].  Note: if
+	you want to use an external diff program only on a subset of
+	your files, you might want to use linkgit:gitattributes[5] instead.
+
+diff.ignoreSubmodules::
+	Sets the default value of --ignore-submodules. Note that this
+	affects only 'git diff' Porcelain, and not lower level 'diff'
+	commands such as 'git diff-files'. 'git checkout'
+	and 'git switch' also honor
+	this setting when reporting uncommitted changes. Setting it to
+	'all' disables the submodule summary normally shown by 'git commit'
+	and 'git status' when `status.submoduleSummary` is set unless it is
+	overridden by using the --ignore-submodules command-line option.
+	The 'git submodule' commands are not affected by this setting.
+
+diff.mnemonicPrefix::
+	If set, 'git diff' uses a prefix pair that is different from the
+	standard "a/" and "b/" depending on what is being compared.  When
+	this configuration is in effect, reverse diff output also swaps
+	the order of the prefixes:
+`git diff`;;
+	compares the (i)ndex and the (w)ork tree;
+`git diff HEAD`;;
+	 compares a (c)ommit and the (w)ork tree;
+`git diff --cached`;;
+	compares a (c)ommit and the (i)ndex;
+`git diff HEAD:file1 file2`;;
+	compares an (o)bject and a (w)ork tree entity;
+`git diff --no-index a b`;;
+	compares two non-git things (1) and (2).
+
+diff.noprefix::
+	If set, 'git diff' does not show any source or destination prefix.
+
+diff.orderFile::
+	File indicating how to order files within a diff.
+	See the '-O' option to linkgit:git-diff[1] for details.
+	If `diff.orderFile` is a relative pathname, it is treated as
+	relative to the top of the working tree.
+
+diff.renameLimit::
+	The number of files to consider when performing the copy/rename
+	detection; equivalent to the 'git diff' option `-l`. This setting
+	has no effect if rename detection is turned off.
+
+diff.renames::
+	Whether and how Git detects renames.  If set to "false",
+	rename detection is disabled. If set to "true", basic rename
+	detection is enabled.  If set to "copies" or "copy", Git will
+	detect copies, as well.  Defaults to true.  Note that this
+	affects only 'git diff' Porcelain like linkgit:git-diff[1] and
+	linkgit:git-log[1], and not lower level commands such as
+	linkgit:git-diff-files[1].
+
+diff.suppressBlankEmpty::
+	A boolean to inhibit the standard behavior of printing a space
+	before each empty output line. Defaults to false.
+
+diff.submodule::
+	Specify the format in which differences in submodules are
+	shown.  The "short" format just shows the names of the commits
+	at the beginning and end of the range. The "log" format lists
+	the commits in the range like linkgit:git-submodule[1] `summary`
+	does. The "diff" format shows an inline diff of the changed
+	contents of the submodule. Defaults to "short".
+
+diff.wordRegex::
+	A POSIX Extended Regular Expression used to determine what is a "word"
+	when performing word-by-word difference calculations.  Character
+	sequences that match the regular expression are "words", all other
+	characters are *ignorable* whitespace.
+
+diff.<driver>.command::
+	The custom diff driver command.  See linkgit:gitattributes[5]
+	for details.
+
+diff.<driver>.xfuncname::
+	The regular expression that the diff driver should use to
+	recognize the hunk header.  A built-in pattern may also be used.
+	See linkgit:gitattributes[5] for details.
+
+diff.<driver>.binary::
+	Set this option to true to make the diff driver treat files as
+	binary.  See linkgit:gitattributes[5] for details.
+
+diff.<driver>.textconv::
+	The command that the diff driver should call to generate the
+	text-converted version of a file.  The result of the
+	conversion is used to generate a human-readable diff.  See
+	linkgit:gitattributes[5] for details.
+
+diff.<driver>.wordRegex::
+	The regular expression that the diff driver should use to
+	split words in a line.  See linkgit:gitattributes[5] for
+	details.
+
+diff.<driver>.cachetextconv::
+	Set this option to true to make the diff driver cache the text
+	conversion outputs.  See linkgit:gitattributes[5] for details.
+
+diff.tool::
+	Controls which diff tool is used by linkgit:git-difftool[1].
+	This variable overrides the value configured in `merge.tool`.
+	The list below shows the valid built-in values.
+	Any other value is treated as a custom diff tool and requires
+	that a corresponding difftool.<tool>.cmd variable is defined.
+
+diff.guitool::
+	Controls which diff tool is used by linkgit:git-difftool[1] when
+	the -g/--gui flag is specified. This variable overrides the value
+	configured in `merge.guitool`. The list below shows the valid
+	built-in values. Any other value is treated as a custom diff tool
+	and requires that a corresponding difftool.<guitool>.cmd variable
+	is defined.
+
+include::../mergetools-diff.txt[]
+
+diff.indentHeuristic::
+	Set this option to `false` to disable the default heuristics
+	that shift diff hunk boundaries to make patches easier to read.
+
+diff.algorithm::
+	Choose a diff algorithm.  The variants are as follows:
++
+--
+`default`, `myers`;;
+	The basic greedy diff algorithm. Currently, this is the default.
+`minimal`;;
+	Spend extra time to make sure the smallest possible diff is
+	produced.
+`patience`;;
+	Use "patience diff" algorithm when generating patches.
+`histogram`;;
+	This algorithm extends the patience algorithm to "support
+	low-occurrence common elements".
+--
++
+
+diff.wsErrorHighlight::
+	Highlight whitespace errors in the `context`, `old` or `new`
+	lines of the diff.  Multiple values are separated by comma,
+	`none` resets previous values, `default` reset the list to
+	`new` and `all` is a shorthand for `old,new,context`.  The
+	whitespace errors are colored with `color.diff.whitespace`.
+	The command line option `--ws-error-highlight=<kind>`
+	overrides this setting.
+
+diff.colorMoved::
+	If set to either a valid `<mode>` or a true value, moved lines
+	in a diff are colored differently, for details of valid modes
+	see '--color-moved' in linkgit:git-diff[1]. If simply set to
+	true the default color mode will be used. When set to false,
+	moved lines are not colored.
+
+diff.colorMovedWS::
+	When moved lines are colored using e.g. the `diff.colorMoved` setting,
+	this option controls the `<mode>` how spaces are treated
+	for details of valid modes see '--color-moved-ws' in linkgit:git-diff[1].
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/config/fastimport.txt 1.2.3+git2.25.1-1/git/Documentation/config/fastimport.txt
--- 1.2.1+git2.18.0-1/git/Documentation/config/fastimport.txt	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/config/fastimport.txt	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,8 @@
+fastimport.unpackLimit::
+	If the number of objects imported by linkgit:git-fast-import[1]
+	is below this limit, then the objects will be unpacked into
+	loose object files.  However if the number of imported objects
+	equals or exceeds this limit then the pack will be stored as a
+	pack.  Storing the pack from a fast-import can make the import
+	operation complete faster, especially on slow filesystems.  If
+	not set, the value of `transfer.unpackLimit` is used instead.
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/config/feature.txt 1.2.3+git2.25.1-1/git/Documentation/config/feature.txt
--- 1.2.1+git2.18.0-1/git/Documentation/config/feature.txt	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/config/feature.txt	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,37 @@
+feature.*::
+	The config settings that start with `feature.` modify the defaults of
+	a group of other config settings. These groups are created by the Git
+	developer community as recommended defaults and are subject to change.
+	In particular, new config options may be added with different defaults.
+
+feature.experimental::
+	Enable config options that are new to Git, and are being considered for
+	future defaults. Config settings included here may be added or removed
+	with each release, including minor version updates. These settings may
+	have unintended interactions since they are so new. Please enable this
+	setting if you are interested in providing feedback on experimental
+	features. The new default values are:
++
+* `pack.useSparse=true` uses a new algorithm when constructing a pack-file
+which can improve `git push` performance in repos with many files.
++
+* `fetch.negotiationAlgorithm=skipping` may improve fetch negotiation times by
+skipping more commits at a time, reducing the number of round trips.
++
+* `fetch.writeCommitGraph=true` writes a commit-graph after every `git fetch`
+command that downloads a pack-file from a remote. Using the `--split` option,
+most executions will create a very small commit-graph file on top of the
+existing commit-graph file(s). Occasionally, these files will merge and the
+write may take longer. Having an updated commit-graph file helps performance
+of many Git commands, including `git merge-base`, `git push -f`, and
+`git log --graph`.
+
+feature.manyFiles::
+	Enable config options that optimize for repos with many files in the
+	working directory. With many files, commands such as `git status` and
+	`git checkout` may be slow and these new defaults improve performance:
++
+* `index.version=4` enables path-prefix compression in the index.
++
+* `core.untrackedCache=true` enables the untracked cache. This setting assumes
+that mtime is working on your machine.
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/config/fetch.txt 1.2.3+git2.25.1-1/git/Documentation/config/fetch.txt
--- 1.2.1+git2.18.0-1/git/Documentation/config/fetch.txt	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/config/fetch.txt	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,91 @@
+fetch.recurseSubmodules::
+	This option can be either set to a boolean value or to 'on-demand'.
+	Setting it to a boolean changes the behavior of fetch and pull to
+	unconditionally recurse into submodules when set to true or to not
+	recurse at all when set to false. When set to 'on-demand' (the default
+	value), fetch and pull will only recurse into a populated submodule
+	when its superproject retrieves a commit that updates the submodule's
+	reference.
+
+fetch.fsckObjects::
+	If it is set to true, git-fetch-pack will check all fetched
+	objects. See `transfer.fsckObjects` for what's
+	checked. Defaults to false. If not set, the value of
+	`transfer.fsckObjects` is used instead.
+
+fetch.fsck.<msg-id>::
+	Acts like `fsck.<msg-id>`, but is used by
+	linkgit:git-fetch-pack[1] instead of linkgit:git-fsck[1]. See
+	the `fsck.<msg-id>` documentation for details.
+
+fetch.fsck.skipList::
+	Acts like `fsck.skipList`, but is used by
+	linkgit:git-fetch-pack[1] instead of linkgit:git-fsck[1]. See
+	the `fsck.skipList` documentation for details.
+
+fetch.unpackLimit::
+	If the number of objects fetched over the Git native
+	transfer is below this
+	limit, then the objects will be unpacked into loose object
+	files. However if the number of received objects equals or
+	exceeds this limit then the received pack will be stored as
+	a pack, after adding any missing delta bases.  Storing the
+	pack from a push can make the push operation complete faster,
+	especially on slow filesystems.  If not set, the value of
+	`transfer.unpackLimit` is used instead.
+
+fetch.prune::
+	If true, fetch will automatically behave as if the `--prune`
+	option was given on the command line.  See also `remote.<name>.prune`
+	and the PRUNING section of linkgit:git-fetch[1].
+
+fetch.pruneTags::
+	If true, fetch will automatically behave as if the
+	`refs/tags/*:refs/tags/*` refspec was provided when pruning,
+	if not set already. This allows for setting both this option
+	and `fetch.prune` to maintain a 1=1 mapping to upstream
+	refs. See also `remote.<name>.pruneTags` and the PRUNING
+	section of linkgit:git-fetch[1].
+
+fetch.output::
+	Control how ref update status is printed. Valid values are
+	`full` and `compact`. Default value is `full`. See section
+	OUTPUT in linkgit:git-fetch[1] for detail.
+
+fetch.negotiationAlgorithm::
+	Control how information about the commits in the local repository is
+	sent when negotiating the contents of the packfile to be sent by the
+	server. Set to "skipping" to use an algorithm that skips commits in an
+	effort to converge faster, but may result in a larger-than-necessary
+	packfile; The default is "default" which instructs Git to use the default algorithm
+	that never skips commits (unless the server has acknowledged it or one
+	of its descendants). If `feature.experimental` is enabled, then this
+	setting defaults to "skipping".
+	Unknown values will cause 'git fetch' to error out.
++
+See also the `--negotiation-tip` option for linkgit:git-fetch[1].
+
+fetch.showForcedUpdates::
+	Set to false to enable `--no-show-forced-updates` in
+	linkgit:git-fetch[1] and linkgit:git-pull[1] commands.
+	Defaults to true.
+
+fetch.parallel::
+	Specifies the maximal number of fetch operations to be run in parallel
+	at a time (submodules, or remotes when the `--multiple` option of
+	linkgit:git-fetch[1] is in effect).
++
+A value of 0 will give some reasonable default. If unset, it defaults to 1.
++
+For submodules, this setting can be overridden using the `submodule.fetchJobs`
+config setting.
+
+fetch.writeCommitGraph::
+	Set to true to write a commit-graph after every `git fetch` command
+	that downloads a pack-file from a remote. Using the `--split` option,
+	most executions will create a very small commit-graph file on top of
+	the existing commit-graph file(s). Occasionally, these files will
+	merge and the write may take longer. Having an updated commit-graph
+	file helps performance of many Git commands, including `git merge-base`,
+	`git push -f`, and `git log --graph`. Defaults to false, unless
+	`feature.experimental` is true.
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/config/filter.txt 1.2.3+git2.25.1-1/git/Documentation/config/filter.txt
--- 1.2.1+git2.18.0-1/git/Documentation/config/filter.txt	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/config/filter.txt	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,9 @@
+filter.<driver>.clean::
+	The command which is used to convert the content of a worktree
+	file to a blob upon checkin.  See linkgit:gitattributes[5] for
+	details.
+
+filter.<driver>.smudge::
+	The command which is used to convert the content of a blob
+	object to a worktree file upon checkout.  See
+	linkgit:gitattributes[5] for details.
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/config/fmt-merge-msg.txt 1.2.3+git2.25.1-1/git/Documentation/config/fmt-merge-msg.txt
--- 1.2.1+git2.18.0-1/git/Documentation/config/fmt-merge-msg.txt	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/config/fmt-merge-msg.txt	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,10 @@
+merge.branchdesc::
+	In addition to branch names, populate the log message with
+	the branch description text associated with them.  Defaults
+	to false.
+
+merge.log::
+	In addition to branch names, populate the log message with at
+	most the specified number of one-line descriptions from the
+	actual commits that are being merged.  Defaults to false, and
+	true is a synonym for 20.
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/config/format.txt 1.2.3+git2.25.1-1/git/Documentation/config/format.txt
--- 1.2.1+git2.18.0-1/git/Documentation/config/format.txt	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/config/format.txt	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,125 @@
+format.attach::
+	Enable multipart/mixed attachments as the default for
+	'format-patch'.  The value can also be a double quoted string
+	which will enable attachments as the default and set the
+	value as the boundary.  See the --attach option in
+	linkgit:git-format-patch[1].
+
+format.from::
+	Provides the default value for the `--from` option to format-patch.
+	Accepts a boolean value, or a name and email address.  If false,
+	format-patch defaults to `--no-from`, using commit authors directly in
+	the "From:" field of patch mails.  If true, format-patch defaults to
+	`--from`, using your committer identity in the "From:" field of patch
+	mails and including a "From:" field in the body of the patch mail if
+	different.  If set to a non-boolean value, format-patch uses that
+	value instead of your committer identity.  Defaults to false.
+
+format.numbered::
+	A boolean which can enable or disable sequence numbers in patch
+	subjects.  It defaults to "auto" which enables it only if there
+	is more than one patch.  It can be enabled or disabled for all
+	messages by setting it to "true" or "false".  See --numbered
+	option in linkgit:git-format-patch[1].
+
+format.headers::
+	Additional email headers to include in a patch to be submitted
+	by mail.  See linkgit:git-format-patch[1].
+
+format.to::
+format.cc::
+	Additional recipients to include in a patch to be submitted
+	by mail.  See the --to and --cc options in
+	linkgit:git-format-patch[1].
+
+format.subjectPrefix::
+	The default for format-patch is to output files with the '[PATCH]'
+	subject prefix. Use this variable to change that prefix.
+
+format.coverFromDescription::
+	The default mode for format-patch to determine which parts of
+	the cover letter will be populated using the branch's
+	description. See the `--cover-from-description` option in
+	linkgit:git-format-patch[1].
+
+format.signature::
+	The default for format-patch is to output a signature containing
+	the Git version number. Use this variable to change that default.
+	Set this variable to the empty string ("") to suppress
+	signature generation.
+
+format.signatureFile::
+	Works just like format.signature except the contents of the
+	file specified by this variable will be used as the signature.
+
+format.suffix::
+	The default for format-patch is to output files with the suffix
+	`.patch`. Use this variable to change that suffix (make sure to
+	include the dot if you want it).
+
+format.pretty::
+	The default pretty format for log/show/whatchanged command,
+	See linkgit:git-log[1], linkgit:git-show[1],
+	linkgit:git-whatchanged[1].
+
+format.thread::
+	The default threading style for 'git format-patch'.  Can be
+	a boolean value, or `shallow` or `deep`.  `shallow` threading
+	makes every mail a reply to the head of the series,
+	where the head is chosen from the cover letter, the
+	`--in-reply-to`, and the first patch mail, in this order.
+	`deep` threading makes every mail a reply to the previous one.
+	A true boolean value is the same as `shallow`, and a false
+	value disables threading.
+
+format.signOff::
+	A boolean value which lets you enable the `-s/--signoff` option of
+	format-patch by default. *Note:* Adding the Signed-off-by: line to a
+	patch should be a conscious act and means that you certify you have
+	the rights to submit this work under the same open source license.
+	Please see the 'SubmittingPatches' document for further discussion.
+
+format.coverLetter::
+	A boolean that controls whether to generate a cover-letter when
+	format-patch is invoked, but in addition can be set to "auto", to
+	generate a cover-letter only when there's more than one patch.
+	Default is false.
+
+format.outputDirectory::
+	Set a custom directory to store the resulting files instead of the
+	current working directory. All directory components will be created.
+
+format.useAutoBase::
+	A boolean value which lets you enable the `--base=auto` option of
+	format-patch by default.
+
+format.notes::
+	Provides the default value for the `--notes` option to
+	format-patch. Accepts a boolean value, or a ref which specifies
+	where to get notes. If false, format-patch defaults to
+	`--no-notes`. If true, format-patch defaults to `--notes`. If
+	set to a non-boolean value, format-patch defaults to
+	`--notes=<ref>`, where `ref` is the non-boolean value. Defaults
+	to false.
++
+If one wishes to use the ref `ref/notes/true`, please use that literal
+instead.
++
+This configuration can be specified multiple times in order to allow
+multiple notes refs to be included. In that case, it will behave
+similarly to multiple `--[no-]notes[=]` options passed in. That is, a
+value of `true` will show the default notes, a value of `<ref>` will
+also show notes from that notes ref and a value of `false` will negate
+previous configurations and not show notes.
++
+For example,
++
+------------
+[format]
+	notes = true
+	notes = foo
+	notes = false
+	notes = bar
+------------
++
+will only show notes from `refs/notes/bar`.
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/config/fsck.txt 1.2.3+git2.25.1-1/git/Documentation/config/fsck.txt
--- 1.2.1+git2.18.0-1/git/Documentation/config/fsck.txt	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/config/fsck.txt	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,67 @@
+fsck.<msg-id>::
+	During fsck git may find issues with legacy data which
+	wouldn't be generated by current versions of git, and which
+	wouldn't be sent over the wire if `transfer.fsckObjects` was
+	set. This feature is intended to support working with legacy
+	repositories containing such data.
++
+Setting `fsck.<msg-id>` will be picked up by linkgit:git-fsck[1], but
+to accept pushes of such data set `receive.fsck.<msg-id>` instead, or
+to clone or fetch it set `fetch.fsck.<msg-id>`.
++
+The rest of the documentation discusses `fsck.*` for brevity, but the
+same applies for the corresponding `receive.fsck.*` and
+`fetch.<msg-id>.*`. variables.
++
+Unlike variables like `color.ui` and `core.editor` the
+`receive.fsck.<msg-id>` and `fetch.fsck.<msg-id>` variables will not
+fall back on the `fsck.<msg-id>` configuration if they aren't set. To
+uniformly configure the same fsck settings in different circumstances
+all three of them they must all set to the same values.
++
+When `fsck.<msg-id>` is set, errors can be switched to warnings and
+vice versa by configuring the `fsck.<msg-id>` setting where the
+`<msg-id>` is the fsck message ID and the value is one of `error`,
+`warn` or `ignore`. For convenience, fsck prefixes the error/warning
+with the message ID, e.g. "missingEmail: invalid author/committer
+line - missing email" means that setting `fsck.missingEmail = ignore`
+will hide that issue.
++
+In general, it is better to enumerate existing objects with problems
+with `fsck.skipList`, instead of listing the kind of breakages these
+problematic objects share to be ignored, as doing the latter will
+allow new instances of the same breakages go unnoticed.
++
+Setting an unknown `fsck.<msg-id>` value will cause fsck to die, but
+doing the same for `receive.fsck.<msg-id>` and `fetch.fsck.<msg-id>`
+will only cause git to warn.
+
+fsck.skipList::
+	The path to a list of object names (i.e. one unabbreviated SHA-1 per
+	line) that are known to be broken in a non-fatal way and should
+	be ignored. On versions of Git 2.20 and later comments ('#'), empty
+	lines, and any leading and trailing whitespace is ignored. Everything
+	but a SHA-1 per line will error out on older versions.
++
+This feature is useful when an established project should be accepted
+despite early commits containing errors that can be safely ignored
+such as invalid committer email addresses.  Note: corrupt objects
+cannot be skipped with this setting.
++
+Like `fsck.<msg-id>` this variable has corresponding
+`receive.fsck.skipList` and `fetch.fsck.skipList` variants.
++
+Unlike variables like `color.ui` and `core.editor` the
+`receive.fsck.skipList` and `fetch.fsck.skipList` variables will not
+fall back on the `fsck.skipList` configuration if they aren't set. To
+uniformly configure the same fsck settings in different circumstances
+all three of them they must all set to the same values.
++
+Older versions of Git (before 2.20) documented that the object names
+list should be sorted. This was never a requirement, the object names
+could appear in any order, but when reading the list we tracked whether
+the list was sorted for the purposes of an internal binary search
+implementation, which could save itself some work with an already sorted
+list. Unless you had a humongous list there was no reason to go out of
+your way to pre-sort the list. After Git version 2.20 a hash implementation
+is used instead, so there's now no reason to pre-sort the list.
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/config/gc.txt 1.2.3+git2.25.1-1/git/Documentation/config/gc.txt
--- 1.2.1+git2.18.0-1/git/Documentation/config/gc.txt	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/config/gc.txt	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,136 @@
+gc.aggressiveDepth::
+	The depth parameter used in the delta compression
+	algorithm used by 'git gc --aggressive'.  This defaults
+	to 50, which is the default for the `--depth` option when
+	`--aggressive` isn't in use.
++
+See the documentation for the `--depth` option in
+linkgit:git-repack[1] for more details.
+
+gc.aggressiveWindow::
+	The window size parameter used in the delta compression
+	algorithm used by 'git gc --aggressive'.  This defaults
+	to 250, which is a much more aggressive window size than
+	the default `--window` of 10.
++
+See the documentation for the `--window` option in
+linkgit:git-repack[1] for more details.
+
+gc.auto::
+	When there are approximately more than this many loose
+	objects in the repository, `git gc --auto` will pack them.
+	Some Porcelain commands use this command to perform a
+	light-weight garbage collection from time to time.  The
+	default value is 6700.
++
+Setting this to 0 disables not only automatic packing based on the
+number of loose objects, but any other heuristic `git gc --auto` will
+otherwise use to determine if there's work to do, such as
+`gc.autoPackLimit`.
+
+gc.autoPackLimit::
+	When there are more than this many packs that are not
+	marked with `*.keep` file in the repository, `git gc
+	--auto` consolidates them into one larger pack.  The
+	default value is 50.  Setting this to 0 disables it.
+	Setting `gc.auto` to 0 will also disable this.
++
+See the `gc.bigPackThreshold` configuration variable below. When in
+use, it'll affect how the auto pack limit works.
+
+gc.autoDetach::
+	Make `git gc --auto` return immediately and run in background
+	if the system supports it. Default is true.
+
+gc.bigPackThreshold::
+	If non-zero, all packs larger than this limit are kept when
+	`git gc` is run. This is very similar to `--keep-base-pack`
+	except that all packs that meet the threshold are kept, not
+	just the base pack. Defaults to zero. Common unit suffixes of
+	'k', 'm', or 'g' are supported.
++
+Note that if the number of kept packs is more than gc.autoPackLimit,
+this configuration variable is ignored, all packs except the base pack
+will be repacked. After this the number of packs should go below
+gc.autoPackLimit and gc.bigPackThreshold should be respected again.
++
+If the amount of memory estimated for `git repack` to run smoothly is
+not available and `gc.bigPackThreshold` is not set, the largest pack
+will also be excluded (this is the equivalent of running `git gc` with
+`--keep-base-pack`).
+
+gc.writeCommitGraph::
+	If true, then gc will rewrite the commit-graph file when
+	linkgit:git-gc[1] is run. When using `git gc --auto`
+	the commit-graph will be updated if housekeeping is
+	required. Default is true. See linkgit:git-commit-graph[1]
+	for details.
+
+gc.logExpiry::
+	If the file gc.log exists, then `git gc --auto` will print
+	its content and exit with status zero instead of running
+	unless that file is more than 'gc.logExpiry' old.  Default is
+	"1.day".  See `gc.pruneExpire` for more ways to specify its
+	value.
+
+gc.packRefs::
+	Running `git pack-refs` in a repository renders it
+	unclonable by Git versions prior to 1.5.1.2 over dumb
+	transports such as HTTP.  This variable determines whether
+	'git gc' runs `git pack-refs`. This can be set to `notbare`
+	to enable it within all non-bare repos or it can be set to a
+	boolean value.  The default is `true`.
+
+gc.pruneExpire::
+	When 'git gc' is run, it will call 'prune --expire 2.weeks.ago'.
+	Override the grace period with this config variable.  The value
+	"now" may be used to disable this grace period and always prune
+	unreachable objects immediately, or "never" may be used to
+	suppress pruning.  This feature helps prevent corruption when
+	'git gc' runs concurrently with another process writing to the
+	repository; see the "NOTES" section of linkgit:git-gc[1].
+
+gc.worktreePruneExpire::
+	When 'git gc' is run, it calls
+	'git worktree prune --expire 3.months.ago'.
+	This config variable can be used to set a different grace
+	period. The value "now" may be used to disable the grace
+	period and prune `$GIT_DIR/worktrees` immediately, or "never"
+	may be used to suppress pruning.
+
+gc.reflogExpire::
+gc.<pattern>.reflogExpire::
+	'git reflog expire' removes reflog entries older than
+	this time; defaults to 90 days. The value "now" expires all
+	entries immediately, and "never" suppresses expiration
+	altogether. With "<pattern>" (e.g.
+	"refs/stash") in the middle the setting applies only to
+	the refs that match the <pattern>.
+
+gc.reflogExpireUnreachable::
+gc.<pattern>.reflogExpireUnreachable::
+	'git reflog expire' removes reflog entries older than
+	this time and are not reachable from the current tip;
+	defaults to 30 days. The value "now" expires all entries
+	immediately, and "never" suppresses expiration altogether.
+	With "<pattern>" (e.g. "refs/stash")
+	in the middle, the setting applies only to the refs that
+	match the <pattern>.
++
+These types of entries are generally created as a result of using `git
+commit --amend` or `git rebase` and are the commits prior to the amend
+or rebase occurring.  Since these changes are not part of the current
+project most users will want to expire them sooner, which is why the
+default is more aggressive than `gc.reflogExpire`.
+
+gc.rerereResolved::
+	Records of conflicted merge you resolved earlier are
+	kept for this many days when 'git rerere gc' is run.
+	You can also use more human-readable "1.month.ago", etc.
+	The default is 60 days.  See linkgit:git-rerere[1].
+
+gc.rerereUnresolved::
+	Records of conflicted merge you have not resolved are
+	kept for this many days when 'git rerere gc' is run.
+	You can also use more human-readable "1.month.ago", etc.
+	The default is 15 days.  See linkgit:git-rerere[1].
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/config/gitcvs.txt 1.2.3+git2.25.1-1/git/Documentation/config/gitcvs.txt
--- 1.2.1+git2.18.0-1/git/Documentation/config/gitcvs.txt	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/config/gitcvs.txt	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,67 @@
+gitcvs.commitMsgAnnotation::
+	Append this string to each commit message. Set to empty string
+	to disable this feature. Defaults to "via git-CVS emulator".
+
+gitcvs.enabled::
+	Whether the CVS server interface is enabled for this repository.
+	See linkgit:git-cvsserver[1].
+
+gitcvs.logFile::
+	Path to a log file where the CVS server interface well... logs
+	various stuff. See linkgit:git-cvsserver[1].
+
+gitcvs.usecrlfattr::
+	If true, the server will look up the end-of-line conversion
+	attributes for files to determine the `-k` modes to use. If
+	the attributes force Git to treat a file as text,
+	the `-k` mode will be left blank so CVS clients will
+	treat it as text. If they suppress text conversion, the file
+	will be set with '-kb' mode, which suppresses any newline munging
+	the client might otherwise do. If the attributes do not allow
+	the file type to be determined, then `gitcvs.allBinary` is
+	used. See linkgit:gitattributes[5].
+
+gitcvs.allBinary::
+	This is used if `gitcvs.usecrlfattr` does not resolve
+	the correct '-kb' mode to use. If true, all
+	unresolved files are sent to the client in
+	mode '-kb'. This causes the client to treat them
+	as binary files, which suppresses any newline munging it
+	otherwise might do. Alternatively, if it is set to "guess",
+	then the contents of the file are examined to decide if
+	it is binary, similar to `core.autocrlf`.
+
+gitcvs.dbName::
+	Database used by git-cvsserver to cache revision information
+	derived from the Git repository. The exact meaning depends on the
+	used database driver, for SQLite (which is the default driver) this
+	is a filename. Supports variable substitution (see
+	linkgit:git-cvsserver[1] for details). May not contain semicolons (`;`).
+	Default: '%Ggitcvs.%m.sqlite'
+
+gitcvs.dbDriver::
+	Used Perl DBI driver. You can specify any available driver
+	for this here, but it might not work. git-cvsserver is tested
+	with 'DBD::SQLite', reported to work with 'DBD::Pg', and
+	reported *not* to work with 'DBD::mysql'. Experimental feature.
+	May not contain double colons (`:`). Default: 'SQLite'.
+	See linkgit:git-cvsserver[1].
+
+gitcvs.dbUser, gitcvs.dbPass::
+	Database user and password. Only useful if setting `gitcvs.dbDriver`,
+	since SQLite has no concept of database users and/or passwords.
+	'gitcvs.dbUser' supports variable substitution (see
+	linkgit:git-cvsserver[1] for details).
+
+gitcvs.dbTableNamePrefix::
+	Database table name prefix.  Prepended to the names of any
+	database tables used, allowing a single database to be used
+	for several repositories.  Supports variable substitution (see
+	linkgit:git-cvsserver[1] for details).  Any non-alphabetic
+	characters will be replaced with underscores.
+
+All gitcvs variables except for `gitcvs.usecrlfattr` and
+`gitcvs.allBinary` can also be specified as
+'gitcvs.<access_method>.<varname>' (where 'access_method'
+is one of "ext" and "pserver") to make them apply only for the given
+access method.
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/config/gitweb.txt 1.2.3+git2.25.1-1/git/Documentation/config/gitweb.txt
--- 1.2.1+git2.18.0-1/git/Documentation/config/gitweb.txt	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/config/gitweb.txt	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,16 @@
+gitweb.category::
+gitweb.description::
+gitweb.owner::
+gitweb.url::
+	See linkgit:gitweb[1] for description.
+
+gitweb.avatar::
+gitweb.blame::
+gitweb.grep::
+gitweb.highlight::
+gitweb.patches::
+gitweb.pickaxe::
+gitweb.remote_heads::
+gitweb.showSizes::
+gitweb.snapshot::
+	See linkgit:gitweb.conf[5] for description.
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/config/gpg.txt 1.2.3+git2.25.1-1/git/Documentation/config/gpg.txt
--- 1.2.1+git2.18.0-1/git/Documentation/config/gpg.txt	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/config/gpg.txt	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,20 @@
+gpg.program::
+	Use this custom program instead of "`gpg`" found on `$PATH` when
+	making or verifying a PGP signature. The program must support the
+	same command-line interface as GPG, namely, to verify a detached
+	signature, "`gpg --verify $signature - <$file`" is run, and the
+	program is expected to signal a good signature by exiting with
+	code 0, and to generate an ASCII-armored detached signature, the
+	standard input of "`gpg -bsau $key`" is fed with the contents to be
+	signed, and the program is expected to send the result to its
+	standard output.
+
+gpg.format::
+	Specifies which key format to use when signing with `--gpg-sign`.
+	Default is "openpgp" and another possible value is "x509".
+
+gpg.<format>.program::
+	Use this to customize the program used for the signing format you
+	chose. (see `gpg.program` and `gpg.format`) `gpg.program` can still
+	be used as a legacy synonym for `gpg.openpgp.program`. The default
+	value for `gpg.x509.program` is "gpgsm".
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/config/grep.txt 1.2.3+git2.25.1-1/git/Documentation/config/grep.txt
--- 1.2.1+git2.18.0-1/git/Documentation/config/grep.txt	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/config/grep.txt	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,24 @@
+grep.lineNumber::
+	If set to true, enable `-n` option by default.
+
+grep.column::
+	If set to true, enable the `--column` option by default.
+
+grep.patternType::
+	Set the default matching behavior. Using a value of 'basic', 'extended',
+	'fixed', or 'perl' will enable the `--basic-regexp`, `--extended-regexp`,
+	`--fixed-strings`, or `--perl-regexp` option accordingly, while the
+	value 'default' will return to the default matching behavior.
+
+grep.extendedRegexp::
+	If set to true, enable `--extended-regexp` option by default. This
+	option is ignored when the `grep.patternType` option is set to a value
+	other than 'default'.
+
+grep.threads::
+	Number of grep worker threads to use.
+	See `grep.threads` in linkgit:git-grep[1] for more information.
+
+grep.fallbackToNoIndex::
+	If set to true, fall back to git grep --no-index if git grep
+	is executed outside of a git repository.  Defaults to false.
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/config/guitool.txt 1.2.3+git2.25.1-1/git/Documentation/config/guitool.txt
--- 1.2.1+git2.18.0-1/git/Documentation/config/guitool.txt	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/config/guitool.txt	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,50 @@
+guitool.<name>.cmd::
+	Specifies the shell command line to execute when the corresponding item
+	of the linkgit:git-gui[1] `Tools` menu is invoked. This option is
+	mandatory for every tool. The command is executed from the root of
+	the working directory, and in the environment it receives the name of
+	the tool as `GIT_GUITOOL`, the name of the currently selected file as
+	'FILENAME', and the name of the current branch as 'CUR_BRANCH' (if
+	the head is detached, 'CUR_BRANCH' is empty).
+
+guitool.<name>.needsFile::
+	Run the tool only if a diff is selected in the GUI. It guarantees
+	that 'FILENAME' is not empty.
+
+guitool.<name>.noConsole::
+	Run the command silently, without creating a window to display its
+	output.
+
+guitool.<name>.noRescan::
+	Don't rescan the working directory for changes after the tool
+	finishes execution.
+
+guitool.<name>.confirm::
+	Show a confirmation dialog before actually running the tool.
+
+guitool.<name>.argPrompt::
+	Request a string argument from the user, and pass it to the tool
+	through the `ARGS` environment variable. Since requesting an
+	argument implies confirmation, the 'confirm' option has no effect
+	if this is enabled. If the option is set to 'true', 'yes', or '1',
+	the dialog uses a built-in generic prompt; otherwise the exact
+	value of the variable is used.
+
+guitool.<name>.revPrompt::
+	Request a single valid revision from the user, and set the
+	`REVISION` environment variable. In other aspects this option
+	is similar to 'argPrompt', and can be used together with it.
+
+guitool.<name>.revUnmerged::
+	Show only unmerged branches in the 'revPrompt' subdialog.
+	This is useful for tools similar to merge or rebase, but not
+	for things like checkout or reset.
+
+guitool.<name>.title::
+	Specifies the title to use for the prompt dialog. The default
+	is the tool name.
+
+guitool.<name>.prompt::
+	Specifies the general prompt string to display at the top of
+	the dialog, before subsections for 'argPrompt' and 'revPrompt'.
+	The default value includes the actual command.
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/config/gui.txt 1.2.3+git2.25.1-1/git/Documentation/config/gui.txt
--- 1.2.1+git2.18.0-1/git/Documentation/config/gui.txt	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/config/gui.txt	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,57 @@
+gui.commitMsgWidth::
+	Defines how wide the commit message window is in the
+	linkgit:git-gui[1]. "75" is the default.
+
+gui.diffContext::
+	Specifies how many context lines should be used in calls to diff
+	made by the linkgit:git-gui[1]. The default is "5".
+
+gui.displayUntracked::
+	Determines if linkgit:git-gui[1] shows untracked files
+	in the file list. The default is "true".
+
+gui.encoding::
+	Specifies the default encoding to use for displaying of
+	file contents in linkgit:git-gui[1] and linkgit:gitk[1].
+	It can be overridden by setting the 'encoding' attribute
+	for relevant files (see linkgit:gitattributes[5]).
+	If this option is not set, the tools default to the
+	locale encoding.
+
+gui.matchTrackingBranch::
+	Determines if new branches created with linkgit:git-gui[1] should
+	default to tracking remote branches with matching names or
+	not. Default: "false".
+
+gui.newBranchTemplate::
+	Is used as suggested name when creating new branches using the
+	linkgit:git-gui[1].
+
+gui.pruneDuringFetch::
+	"true" if linkgit:git-gui[1] should prune remote-tracking branches when
+	performing a fetch. The default value is "false".
+
+gui.trustmtime::
+	Determines if linkgit:git-gui[1] should trust the file modification
+	timestamp or not. By default the timestamps are not trusted.
+
+gui.spellingDictionary::
+	Specifies the dictionary used for spell checking commit messages in
+	the linkgit:git-gui[1]. When set to "none" spell checking is turned
+	off.
+
+gui.fastCopyBlame::
+	If true, 'git gui blame' uses `-C` instead of `-C -C` for original
+	location detection. It makes blame significantly faster on huge
+	repositories at the expense of less thorough copy detection.
+
+gui.copyBlameThreshold::
+	Specifies the threshold to use in 'git gui blame' original location
+	detection, measured in alphanumeric characters. See the
+	linkgit:git-blame[1] manual for more information on copy detection.
+
+gui.blamehistoryctx::
+	Specifies the radius of history context in days to show in
+	linkgit:gitk[1] for the selected commit, when the `Show History
+	Context` menu item is invoked from 'git gui blame'. If this
+	variable is set to zero, the whole history is shown.
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/config/help.txt 1.2.3+git2.25.1-1/git/Documentation/config/help.txt
--- 1.2.1+git2.18.0-1/git/Documentation/config/help.txt	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/config/help.txt	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,23 @@
+help.browser::
+	Specify the browser that will be used to display help in the
+	'web' format. See linkgit:git-help[1].
+
+help.format::
+	Override the default help format used by linkgit:git-help[1].
+	Values 'man', 'info', 'web' and 'html' are supported. 'man' is
+	the default. 'web' and 'html' are the same.
+
+help.autoCorrect::
+	Automatically correct and execute mistyped commands after
+	waiting for the given number of deciseconds (0.1 sec). If more
+	than one command can be deduced from the entered text, nothing
+	will be executed.  If the value of this option is negative,
+	the corrected command will be executed immediately. If the
+	value is 0 - the command will be just shown but not executed.
+	This is the default.
+
+help.htmlPath::
+	Specify the path where the HTML documentation resides. File system paths
+	and URLs are supported. HTML pages will be prefixed with this path when
+	help is displayed in the 'web' format. This defaults to the documentation
+	path of your Git installation.
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/config/http.txt 1.2.3+git2.25.1-1/git/Documentation/config/http.txt
--- 1.2.1+git2.18.0-1/git/Documentation/config/http.txt	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/config/http.txt	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,288 @@
+http.proxy::
+	Override the HTTP proxy, normally configured using the 'http_proxy',
+	'https_proxy', and 'all_proxy' environment variables (see `curl(1)`). In
+	addition to the syntax understood by curl, it is possible to specify a
+	proxy string with a user name but no password, in which case git will
+	attempt to acquire one in the same way it does for other credentials. See
+	linkgit:gitcredentials[7] for more information. The syntax thus is
+	'[protocol://][user[:password]@]proxyhost[:port]'. This can be overridden
+	on a per-remote basis; see remote.<name>.proxy
+
+http.proxyAuthMethod::
+	Set the method with which to authenticate against the HTTP proxy. This
+	only takes effect if the configured proxy string contains a user name part
+	(i.e. is of the form 'user@host' or 'user@host:port'). This can be
+	overridden on a per-remote basis; see `remote.<name>.proxyAuthMethod`.
+	Both can be overridden by the `GIT_HTTP_PROXY_AUTHMETHOD` environment
+	variable.  Possible values are:
++
+--
+* `anyauth` - Automatically pick a suitable authentication method. It is
+  assumed that the proxy answers an unauthenticated request with a 407
+  status code and one or more Proxy-authenticate headers with supported
+  authentication methods. This is the default.
+* `basic` - HTTP Basic authentication
+* `digest` - HTTP Digest authentication; this prevents the password from being
+  transmitted to the proxy in clear text
+* `negotiate` - GSS-Negotiate authentication (compare the --negotiate option
+  of `curl(1)`)
+* `ntlm` - NTLM authentication (compare the --ntlm option of `curl(1)`)
+--
+
+http.emptyAuth::
+	Attempt authentication without seeking a username or password.  This
+	can be used to attempt GSS-Negotiate authentication without specifying
+	a username in the URL, as libcurl normally requires a username for
+	authentication.
+
+http.delegation::
+	Control GSSAPI credential delegation. The delegation is disabled
+	by default in libcurl since version 7.21.7. Set parameter to tell
+	the server what it is allowed to delegate when it comes to user
+	credentials. Used with GSS/kerberos. Possible values are:
++
+--
+* `none` - Don't allow any delegation.
+* `policy` - Delegates if and only if the OK-AS-DELEGATE flag is set in the
+  Kerberos service ticket, which is a matter of realm policy.
+* `always` - Unconditionally allow the server to delegate.
+--
+
+
+http.extraHeader::
+	Pass an additional HTTP header when communicating with a server.  If
+	more than one such entry exists, all of them are added as extra
+	headers.  To allow overriding the settings inherited from the system
+	config, an empty value will reset the extra headers to the empty list.
+
+http.cookieFile::
+	The pathname of a file containing previously stored cookie lines,
+	which should be used
+	in the Git http session, if they match the server. The file format
+	of the file to read cookies from should be plain HTTP headers or
+	the Netscape/Mozilla cookie file format (see `curl(1)`).
+	NOTE that the file specified with http.cookieFile is used only as
+	input unless http.saveCookies is set.
+
+http.saveCookies::
+	If set, store cookies received during requests to the file specified by
+	http.cookieFile. Has no effect if http.cookieFile is unset.
+
+http.version::
+	Use the specified HTTP protocol version when communicating with a server.
+	If you want to force the default. The available and default version depend
+	on libcurl. Currently the possible values of
+	this option are:
+
+	- HTTP/2
+	- HTTP/1.1
+
+http.sslVersion::
+	The SSL version to use when negotiating an SSL connection, if you
+	want to force the default.  The available and default version
+	depend on whether libcurl was built against NSS or OpenSSL and the
+	particular configuration of the crypto library in use. Internally
+	this sets the 'CURLOPT_SSL_VERSION' option; see the libcurl
+	documentation for more details on the format of this option and
+	for the ssl version supported. Currently the possible values of
+	this option are:
+
+	- sslv2
+	- sslv3
+	- tlsv1
+	- tlsv1.0
+	- tlsv1.1
+	- tlsv1.2
+	- tlsv1.3
+
++
+Can be overridden by the `GIT_SSL_VERSION` environment variable.
+To force git to use libcurl's default ssl version and ignore any
+explicit http.sslversion option, set `GIT_SSL_VERSION` to the
+empty string.
+
+http.sslCipherList::
+  A list of SSL ciphers to use when negotiating an SSL connection.
+  The available ciphers depend on whether libcurl was built against
+  NSS or OpenSSL and the particular configuration of the crypto
+  library in use.  Internally this sets the 'CURLOPT_SSL_CIPHER_LIST'
+  option; see the libcurl documentation for more details on the format
+  of this list.
++
+Can be overridden by the `GIT_SSL_CIPHER_LIST` environment variable.
+To force git to use libcurl's default cipher list and ignore any
+explicit http.sslCipherList option, set `GIT_SSL_CIPHER_LIST` to the
+empty string.
+
+http.sslVerify::
+	Whether to verify the SSL certificate when fetching or pushing
+	over HTTPS. Defaults to true. Can be overridden by the
+	`GIT_SSL_NO_VERIFY` environment variable.
+
+http.sslCert::
+	File containing the SSL certificate when fetching or pushing
+	over HTTPS. Can be overridden by the `GIT_SSL_CERT` environment
+	variable.
+
+http.sslKey::
+	File containing the SSL private key when fetching or pushing
+	over HTTPS. Can be overridden by the `GIT_SSL_KEY` environment
+	variable.
+
+http.sslCertPasswordProtected::
+	Enable Git's password prompt for the SSL certificate.  Otherwise
+	OpenSSL will prompt the user, possibly many times, if the
+	certificate or private key is encrypted.  Can be overridden by the
+	`GIT_SSL_CERT_PASSWORD_PROTECTED` environment variable.
+
+http.sslCAInfo::
+	File containing the certificates to verify the peer with when
+	fetching or pushing over HTTPS. Can be overridden by the
+	`GIT_SSL_CAINFO` environment variable.
+
+http.sslCAPath::
+	Path containing files with the CA certificates to verify the peer
+	with when fetching or pushing over HTTPS. Can be overridden
+	by the `GIT_SSL_CAPATH` environment variable.
+
+http.sslBackend::
+	Name of the SSL backend to use (e.g. "openssl" or "schannel").
+	This option is ignored if cURL lacks support for choosing the SSL
+	backend at runtime.
+
+http.schannelCheckRevoke::
+	Used to enforce or disable certificate revocation checks in cURL
+	when http.sslBackend is set to "schannel". Defaults to `true` if
+	unset. Only necessary to disable this if Git consistently errors
+	and the message is about checking the revocation status of a
+	certificate. This option is ignored if cURL lacks support for
+	setting the relevant SSL option at runtime.
+
+http.schannelUseSSLCAInfo::
+	As of cURL v7.60.0, the Secure Channel backend can use the
+	certificate bundle provided via `http.sslCAInfo`, but that would
+	override the Windows Certificate Store. Since this is not desirable
+	by default, Git will tell cURL not to use that bundle by default
+	when the `schannel` backend was configured via `http.sslBackend`,
+	unless `http.schannelUseSSLCAInfo` overrides this behavior.
+
+http.pinnedpubkey::
+	Public key of the https service. It may either be the filename of
+	a PEM or DER encoded public key file or a string starting with
+	'sha256//' followed by the base64 encoded sha256 hash of the
+	public key. See also libcurl 'CURLOPT_PINNEDPUBLICKEY'. git will
+	exit with an error if this option is set but not supported by
+	cURL.
+
+http.sslTry::
+	Attempt to use AUTH SSL/TLS and encrypted data transfers
+	when connecting via regular FTP protocol. This might be needed
+	if the FTP server requires it for security reasons or you wish
+	to connect securely whenever remote FTP server supports it.
+	Default is false since it might trigger certificate verification
+	errors on misconfigured servers.
+
+http.maxRequests::
+	How many HTTP requests to launch in parallel. Can be overridden
+	by the `GIT_HTTP_MAX_REQUESTS` environment variable. Default is 5.
+
+http.minSessions::
+	The number of curl sessions (counted across slots) to be kept across
+	requests. They will not be ended with curl_easy_cleanup() until
+	http_cleanup() is invoked. If USE_CURL_MULTI is not defined, this
+	value will be capped at 1. Defaults to 1.
+
+http.postBuffer::
+	Maximum size in bytes of the buffer used by smart HTTP
+	transports when POSTing data to the remote system.
+	For requests larger than this buffer size, HTTP/1.1 and
+	Transfer-Encoding: chunked is used to avoid creating a
+	massive pack file locally.  Default is 1 MiB, which is
+	sufficient for most requests.
++
+Note that raising this limit is only effective for disabling chunked
+transfer encoding and therefore should be used only where the remote
+server or a proxy only supports HTTP/1.0 or is noncompliant with the
+HTTP standard.  Raising this is not, in general, an effective solution
+for most push problems, but can increase memory consumption
+significantly since the entire buffer is allocated even for small
+pushes.
+
+http.lowSpeedLimit, http.lowSpeedTime::
+	If the HTTP transfer speed is less than 'http.lowSpeedLimit'
+	for longer than 'http.lowSpeedTime' seconds, the transfer is aborted.
+	Can be overridden by the `GIT_HTTP_LOW_SPEED_LIMIT` and
+	`GIT_HTTP_LOW_SPEED_TIME` environment variables.
+
+http.noEPSV::
+	A boolean which disables using of EPSV ftp command by curl.
+	This can helpful with some "poor" ftp servers which don't
+	support EPSV mode. Can be overridden by the `GIT_CURL_FTP_NO_EPSV`
+	environment variable. Default is false (curl will use EPSV).
+
+http.userAgent::
+	The HTTP USER_AGENT string presented to an HTTP server.  The default
+	value represents the version of the client Git such as git/1.7.1.
+	This option allows you to override this value to a more common value
+	such as Mozilla/4.0.  This may be necessary, for instance, if
+	connecting through a firewall that restricts HTTP connections to a set
+	of common USER_AGENT strings (but not including those like git/1.7.1).
+	Can be overridden by the `GIT_HTTP_USER_AGENT` environment variable.
+
+http.followRedirects::
+	Whether git should follow HTTP redirects. If set to `true`, git
+	will transparently follow any redirect issued by a server it
+	encounters. If set to `false`, git will treat all redirects as
+	errors. If set to `initial`, git will follow redirects only for
+	the initial request to a remote, but not for subsequent
+	follow-up HTTP requests. Since git uses the redirected URL as
+	the base for the follow-up requests, this is generally
+	sufficient. The default is `initial`.
+
+http.<url>.*::
+	Any of the http.* options above can be applied selectively to some URLs.
+	For a config key to match a URL, each element of the config key is
+	compared to that of the URL, in the following order:
++
+--
+. Scheme (e.g., `https` in `https://example.com/`). This field
+  must match exactly between the config key and the URL.
+
+. Host/domain name (e.g., `example.com` in `https://example.com/`).
+  This field must match between the config key and the URL. It is
+  possible to specify a `*` as part of the host name to match all subdomains
+  at this level. `https://*.example.com/` for example would match
+  `https://foo.example.com/`, but not `https://foo.bar.example.com/`.
+
+. Port number (e.g., `8080` in `http://example.com:8080/`).
+  This field must match exactly between the config key and the URL.
+  Omitted port numbers are automatically converted to the correct
+  default for the scheme before matching.
+
+. Path (e.g., `repo.git` in `https://example.com/repo.git`). The
+  path field of the config key must match the path field of the URL
+  either exactly or as a prefix of slash-delimited path elements.  This means
+  a config key with path `foo/` matches URL path `foo/bar`.  A prefix can only
+  match on a slash (`/`) boundary.  Longer matches take precedence (so a config
+  key with path `foo/bar` is a better match to URL path `foo/bar` than a config
+  key with just path `foo/`).
+
+. User name (e.g., `user` in `https://user@example.com/repo.git`). If
+  the config key has a user name it must match the user name in the
+  URL exactly. If the config key does not have a user name, that
+  config key will match a URL with any user name (including none),
+  but at a lower precedence than a config key with a user name.
+--
++
+The list above is ordered by decreasing precedence; a URL that matches
+a config key's path is preferred to one that matches its user name. For example,
+if the URL is `https://user@example.com/foo/bar` a config key match of
+`https://example.com/foo` will be preferred over a config key match of
+`https://user@example.com`.
++
+All URLs are normalized before attempting any matching (the password part,
+if embedded in the URL, is always ignored for matching purposes) so that
+equivalent URLs that are simply spelled differently will match properly.
+Environment variable settings always override any matches.  The URLs that are
+matched against are those given directly to Git commands.  This means any URLs
+visited as a result of a redirection do not participate in matching.
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/config/i18n.txt 1.2.3+git2.25.1-1/git/Documentation/config/i18n.txt
--- 1.2.1+git2.18.0-1/git/Documentation/config/i18n.txt	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/config/i18n.txt	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,10 @@
+i18n.commitEncoding::
+	Character encoding the commit messages are stored in; Git itself
+	does not care per se, but this information is necessary e.g. when
+	importing commits from emails or in the gitk graphical history
+	browser (and possibly at other places in the future or in other
+	porcelains). See e.g. linkgit:git-mailinfo[1]. Defaults to 'utf-8'.
+
+i18n.logOutputEncoding::
+	Character encoding the commit messages are converted to when
+	running 'git log' and friends.
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/config/imap.txt 1.2.3+git2.25.1-1/git/Documentation/config/imap.txt
--- 1.2.1+git2.18.0-1/git/Documentation/config/imap.txt	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/config/imap.txt	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,44 @@
+imap.folder::
+	The folder to drop the mails into, which is typically the Drafts
+	folder. For example: "INBOX.Drafts", "INBOX/Drafts" or
+	"[Gmail]/Drafts". Required.
+
+imap.tunnel::
+	Command used to setup a tunnel to the IMAP server through which
+	commands will be piped instead of using a direct network connection
+	to the server. Required when imap.host is not set.
+
+imap.host::
+	A URL identifying the server. Use an `imap://` prefix for non-secure
+	connections and an `imaps://` prefix for secure connections.
+	Ignored when imap.tunnel is set, but required otherwise.
+
+imap.user::
+	The username to use when logging in to the server.
+
+imap.pass::
+	The password to use when logging in to the server.
+
+imap.port::
+	An integer port number to connect to on the server.
+	Defaults to 143 for imap:// hosts and 993 for imaps:// hosts.
+	Ignored when imap.tunnel is set.
+
+imap.sslverify::
+	A boolean to enable/disable verification of the server certificate
+	used by the SSL/TLS connection. Default is `true`. Ignored when
+	imap.tunnel is set.
+
+imap.preformattedHTML::
+	A boolean to enable/disable the use of html encoding when sending
+	a patch.  An html encoded patch will be bracketed with <pre>
+	and have a content type of text/html.  Ironically, enabling this
+	option causes Thunderbird to send the patch as a plain/text,
+	format=fixed email.  Default is `false`.
+
+imap.authMethod::
+	Specify authenticate method for authentication with IMAP server.
+	If Git was built with the NO_CURL option, or if your curl version is older
+	than 7.34.0, or if you're running git-imap-send with the `--no-curl`
+	option, the only supported method is 'CRAM-MD5'. If this is not set
+	then 'git imap-send' uses the basic IMAP plaintext LOGIN command.
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/config/index.txt 1.2.3+git2.25.1-1/git/Documentation/config/index.txt
--- 1.2.1+git2.18.0-1/git/Documentation/config/index.txt	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/config/index.txt	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,27 @@
+index.recordEndOfIndexEntries::
+	Specifies whether the index file should include an "End Of Index
+	Entry" section. This reduces index load time on multiprocessor
+	machines but produces a message "ignoring EOIE extension" when
+	reading the index using Git versions before 2.20. Defaults to
+	'true' if index.threads has been explicitly enabled, 'false'
+	otherwise.
+
+index.recordOffsetTable::
+	Specifies whether the index file should include an "Index Entry
+	Offset Table" section. This reduces index load time on
+	multiprocessor machines but produces a message "ignoring IEOT
+	extension" when reading the index using Git versions before 2.20.
+	Defaults to 'true' if index.threads has been explicitly enabled,
+	'false' otherwise.
+
+index.threads::
+	Specifies the number of threads to spawn when loading the index.
+	This is meant to reduce index load time on multiprocessor machines.
+	Specifying 0 or 'true' will cause Git to auto-detect the number of
+	CPU's and set the number of threads accordingly. Specifying 1 or
+	'false' will disable multithreading. Defaults to 'true'.
+
+index.version::
+	Specify the version with which new index files should be
+	initialized.  This does not affect existing repositories.
+	If `feature.manyFiles` is enabled, then the default is 4.
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/config/init.txt 1.2.3+git2.25.1-1/git/Documentation/config/init.txt
--- 1.2.1+git2.18.0-1/git/Documentation/config/init.txt	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/config/init.txt	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,3 @@
+init.templateDir::
+	Specify the directory from which templates will be copied.
+	(See the "TEMPLATE DIRECTORY" section of linkgit:git-init[1].)
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/config/instaweb.txt 1.2.3+git2.25.1-1/git/Documentation/config/instaweb.txt
--- 1.2.1+git2.18.0-1/git/Documentation/config/instaweb.txt	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/config/instaweb.txt	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,20 @@
+instaweb.browser::
+	Specify the program that will be used to browse your working
+	repository in gitweb. See linkgit:git-instaweb[1].
+
+instaweb.httpd::
+	The HTTP daemon command-line to start gitweb on your working
+	repository. See linkgit:git-instaweb[1].
+
+instaweb.local::
+	If true the web server started by linkgit:git-instaweb[1] will
+	be bound to the local IP (127.0.0.1).
+
+instaweb.modulePath::
+	The default module path for linkgit:git-instaweb[1] to use
+	instead of /usr/lib/apache2/modules.  Only used if httpd
+	is Apache.
+
+instaweb.port::
+	The port number to bind the gitweb httpd to. See
+	linkgit:git-instaweb[1].
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/config/interactive.txt 1.2.3+git2.25.1-1/git/Documentation/config/interactive.txt
--- 1.2.1+git2.18.0-1/git/Documentation/config/interactive.txt	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/config/interactive.txt	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,17 @@
+interactive.singleKey::
+	In interactive commands, allow the user to provide one-letter
+	input with a single key (i.e., without hitting enter).
+	Currently this is used by the `--patch` mode of
+	linkgit:git-add[1], linkgit:git-checkout[1],
+	linkgit:git-restore[1], linkgit:git-commit[1],
+	linkgit:git-reset[1], and linkgit:git-stash[1]. Note that this
+	setting is silently ignored if portable keystroke input
+	is not available; requires the Perl module Term::ReadKey.
+
+interactive.diffFilter::
+	When an interactive command (such as `git add --patch`) shows
+	a colorized diff, git will pipe the diff through the shell
+	command defined by this configuration variable. The command may
+	mark up the diff further for human consumption, provided that it
+	retains a one-to-one correspondence with the lines in the
+	original diff. Defaults to disabled (no filtering).
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/config/log.txt 1.2.3+git2.25.1-1/git/Documentation/config/log.txt
--- 1.2.1+git2.18.0-1/git/Documentation/config/log.txt	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/config/log.txt	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,44 @@
+log.abbrevCommit::
+	If true, makes linkgit:git-log[1], linkgit:git-show[1], and
+	linkgit:git-whatchanged[1] assume `--abbrev-commit`. You may
+	override this option with `--no-abbrev-commit`.
+
+log.date::
+	Set the default date-time mode for the 'log' command.
+	Setting a value for log.date is similar to using 'git log''s
+	`--date` option.  See linkgit:git-log[1] for details.
+
+log.decorate::
+	Print out the ref names of any commits that are shown by the log
+	command. If 'short' is specified, the ref name prefixes 'refs/heads/',
+	'refs/tags/' and 'refs/remotes/' will not be printed. If 'full' is
+	specified, the full ref name (including prefix) will be printed.
+	If 'auto' is specified, then if the output is going to a terminal,
+	the ref names are shown as if 'short' were given, otherwise no ref
+	names are shown. This is the same as the `--decorate` option
+	of the `git log`.
+
+log.follow::
+	If `true`, `git log` will act as if the `--follow` option was used when
+	a single <path> is given.  This has the same limitations as `--follow`,
+	i.e. it cannot be used to follow multiple files and does not work well
+	on non-linear history.
+
+log.graphColors::
+	A list of colors, separated by commas, that can be used to draw
+	history lines in `git log --graph`.
+
+log.showRoot::
+	If true, the initial commit will be shown as a big creation event.
+	This is equivalent to a diff against an empty tree.
+	Tools like linkgit:git-log[1] or linkgit:git-whatchanged[1], which
+	normally hide the root commit will now show it. True by default.
+
+log.showSignature::
+	If true, makes linkgit:git-log[1], linkgit:git-show[1], and
+	linkgit:git-whatchanged[1] assume `--show-signature`.
+
+log.mailmap::
+	If true, makes linkgit:git-log[1], linkgit:git-show[1], and
+	linkgit:git-whatchanged[1] assume `--use-mailmap`, otherwise
+	assume `--no-use-mailmap`. True by default.
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/config/mailinfo.txt 1.2.3+git2.25.1-1/git/Documentation/config/mailinfo.txt
--- 1.2.1+git2.18.0-1/git/Documentation/config/mailinfo.txt	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/config/mailinfo.txt	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,6 @@
+mailinfo.scissors::
+	If true, makes linkgit:git-mailinfo[1] (and therefore
+	linkgit:git-am[1]) act by default as if the --scissors option
+	was provided on the command-line. When active, this features
+	removes everything from the message body before a scissors
+	line (i.e. consisting mainly of ">8", "8<" and "-").
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/config/mailmap.txt 1.2.3+git2.25.1-1/git/Documentation/config/mailmap.txt
--- 1.2.1+git2.18.0-1/git/Documentation/config/mailmap.txt	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/config/mailmap.txt	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,15 @@
+mailmap.file::
+	The location of an augmenting mailmap file. The default
+	mailmap, located in the root of the repository, is loaded
+	first, then the mailmap file pointed to by this variable.
+	The location of the mailmap file may be in a repository
+	subdirectory, or somewhere outside of the repository itself.
+	See linkgit:git-shortlog[1] and linkgit:git-blame[1].
+
+mailmap.blob::
+	Like `mailmap.file`, but consider the value as a reference to a
+	blob in the repository. If both `mailmap.file` and
+	`mailmap.blob` are given, both are parsed, with entries from
+	`mailmap.file` taking precedence. In a bare repository, this
+	defaults to `HEAD:.mailmap`. In a non-bare repository, it
+	defaults to empty.
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/config/man.txt 1.2.3+git2.25.1-1/git/Documentation/config/man.txt
--- 1.2.1+git2.18.0-1/git/Documentation/config/man.txt	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/config/man.txt	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,12 @@
+man.viewer::
+	Specify the programs that may be used to display help in the
+	'man' format. See linkgit:git-help[1].
+
+man.<tool>.cmd::
+	Specify the command to invoke the specified man viewer. The
+	specified command is evaluated in shell with the man page
+	passed as argument. (See linkgit:git-help[1].)
+
+man.<tool>.path::
+	Override the path for the given tool that may be used to
+	display help in the 'man' format. See linkgit:git-help[1].
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/config/mergetool.txt 1.2.3+git2.25.1-1/git/Documentation/config/mergetool.txt
--- 1.2.1+git2.18.0-1/git/Documentation/config/mergetool.txt	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/config/mergetool.txt	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,53 @@
+mergetool.<tool>.path::
+	Override the path for the given tool.  This is useful in case
+	your tool is not in the PATH.
+
+mergetool.<tool>.cmd::
+	Specify the command to invoke the specified merge tool.  The
+	specified command is evaluated in shell with the following
+	variables available: 'BASE' is the name of a temporary file
+	containing the common base of the files to be merged, if available;
+	'LOCAL' is the name of a temporary file containing the contents of
+	the file on the current branch; 'REMOTE' is the name of a temporary
+	file containing the contents of the file from the branch being
+	merged; 'MERGED' contains the name of the file to which the merge
+	tool should write the results of a successful merge.
+
+mergetool.<tool>.trustExitCode::
+	For a custom merge command, specify whether the exit code of
+	the merge command can be used to determine whether the merge was
+	successful.  If this is not set to true then the merge target file
+	timestamp is checked and the merge assumed to have been successful
+	if the file has been updated, otherwise the user is prompted to
+	indicate the success of the merge.
+
+mergetool.meld.hasOutput::
+	Older versions of `meld` do not support the `--output` option.
+	Git will attempt to detect whether `meld` supports `--output`
+	by inspecting the output of `meld --help`.  Configuring
+	`mergetool.meld.hasOutput` will make Git skip these checks and
+	use the configured value instead.  Setting `mergetool.meld.hasOutput`
+	to `true` tells Git to unconditionally use the `--output` option,
+	and `false` avoids using `--output`.
+
+mergetool.keepBackup::
+	After performing a merge, the original file with conflict markers
+	can be saved as a file with a `.orig` extension.  If this variable
+	is set to `false` then this file is not preserved.  Defaults to
+	`true` (i.e. keep the backup files).
+
+mergetool.keepTemporaries::
+	When invoking a custom merge tool, Git uses a set of temporary
+	files to pass to the tool. If the tool returns an error and this
+	variable is set to `true`, then these temporary files will be
+	preserved, otherwise they will be removed after the tool has
+	exited. Defaults to `false`.
+
+mergetool.writeToTemp::
+	Git writes temporary 'BASE', 'LOCAL', and 'REMOTE' versions of
+	conflicting files in the worktree by default.  Git will attempt
+	to use a temporary directory for these files when set `true`.
+	Defaults to `false`.
+
+mergetool.prompt::
+	Prompt before each invocation of the merge resolution program.
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/config/merge.txt 1.2.3+git2.25.1-1/git/Documentation/config/merge.txt
--- 1.2.1+git2.18.0-1/git/Documentation/config/merge.txt	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/config/merge.txt	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,106 @@
+merge.conflictStyle::
+	Specify the style in which conflicted hunks are written out to
+	working tree files upon merge.  The default is "merge", which
+	shows a `<<<<<<<` conflict marker, changes made by one side,
+	a `=======` marker, changes made by the other side, and then
+	a `>>>>>>>` marker.  An alternate style, "diff3", adds a `|||||||`
+	marker and the original text before the `=======` marker.
+
+merge.defaultToUpstream::
+	If merge is called without any commit argument, merge the upstream
+	branches configured for the current branch by using their last
+	observed values stored in their remote-tracking branches.
+	The values of the `branch.<current branch>.merge` that name the
+	branches at the remote named by `branch.<current branch>.remote`
+	are consulted, and then they are mapped via `remote.<remote>.fetch`
+	to their corresponding remote-tracking branches, and the tips of
+	these tracking branches are merged.
+
+merge.ff::
+	By default, Git does not create an extra merge commit when merging
+	a commit that is a descendant of the current commit. Instead, the
+	tip of the current branch is fast-forwarded. When set to `false`,
+	this variable tells Git to create an extra merge commit in such
+	a case (equivalent to giving the `--no-ff` option from the command
+	line). When set to `only`, only such fast-forward merges are
+	allowed (equivalent to giving the `--ff-only` option from the
+	command line).
+
+merge.verifySignatures::
+	If true, this is equivalent to the --verify-signatures command
+	line option. See linkgit:git-merge[1] for details.
+
+include::fmt-merge-msg.txt[]
+
+merge.renameLimit::
+	The number of files to consider when performing rename detection
+	during a merge; if not specified, defaults to the value of
+	diff.renameLimit. This setting has no effect if rename detection
+	is turned off.
+
+merge.renames::
+	Whether Git detects renames.  If set to "false", rename detection
+	is disabled. If set to "true", basic rename detection is enabled.
+	Defaults to the value of diff.renames.
+
+merge.directoryRenames::
+	Whether Git detects directory renames, affecting what happens at
+	merge time to new files added to a directory on one side of
+	history when that directory was renamed on the other side of
+	history.  If merge.directoryRenames is set to "false", directory
+	rename detection is disabled, meaning that such new files will be
+	left behind in the old directory.  If set to "true", directory
+	rename detection is enabled, meaning that such new files will be
+	moved into the new directory.  If set to "conflict", a conflict
+	will be reported for such paths.  If merge.renames is false,
+	merge.directoryRenames is ignored and treated as false.  Defaults
+	to "conflict".
+
+merge.renormalize::
+	Tell Git that canonical representation of files in the
+	repository has changed over time (e.g. earlier commits record
+	text files with CRLF line endings, but recent ones use LF line
+	endings).  In such a repository, Git can convert the data
+	recorded in commits to a canonical form before performing a
+	merge to reduce unnecessary conflicts.  For more information,
+	see section "Merging branches with differing checkin/checkout
+	attributes" in linkgit:gitattributes[5].
+
+merge.stat::
+	Whether to print the diffstat between ORIG_HEAD and the merge result
+	at the end of the merge.  True by default.
+
+merge.tool::
+	Controls which merge tool is used by linkgit:git-mergetool[1].
+	The list below shows the valid built-in values.
+	Any other value is treated as a custom merge tool and requires
+	that a corresponding mergetool.<tool>.cmd variable is defined.
+
+merge.guitool::
+	Controls which merge tool is used by linkgit:git-mergetool[1] when the
+	-g/--gui flag is specified. The list below shows the valid built-in values.
+	Any other value is treated as a custom merge tool and requires that a
+	corresponding mergetool.<guitool>.cmd variable is defined.
+
+include::../mergetools-merge.txt[]
+
+merge.verbosity::
+	Controls the amount of output shown by the recursive merge
+	strategy.  Level 0 outputs nothing except a final error
+	message if conflicts were detected. Level 1 outputs only
+	conflicts, 2 outputs conflicts and file changes.  Level 5 and
+	above outputs debugging information.  The default is level 2.
+	Can be overridden by the `GIT_MERGE_VERBOSITY` environment variable.
+
+merge.<driver>.name::
+	Defines a human-readable name for a custom low-level
+	merge driver.  See linkgit:gitattributes[5] for details.
+
+merge.<driver>.driver::
+	Defines the command that implements a custom low-level
+	merge driver.  See linkgit:gitattributes[5] for details.
+
+merge.<driver>.recursive::
+	Names a low-level merge driver to be used when
+	performing an internal merge between common ancestors.
+	See linkgit:gitattributes[5] for details.
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/config/notes.txt 1.2.3+git2.25.1-1/git/Documentation/config/notes.txt
--- 1.2.1+git2.18.0-1/git/Documentation/config/notes.txt	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/config/notes.txt	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,59 @@
+notes.mergeStrategy::
+	Which merge strategy to choose by default when resolving notes
+	conflicts.  Must be one of `manual`, `ours`, `theirs`, `union`, or
+	`cat_sort_uniq`.  Defaults to `manual`.  See "NOTES MERGE STRATEGIES"
+	section of linkgit:git-notes[1] for more information on each strategy.
+
+notes.<name>.mergeStrategy::
+	Which merge strategy to choose when doing a notes merge into
+	refs/notes/<name>.  This overrides the more general
+	"notes.mergeStrategy".  See the "NOTES MERGE STRATEGIES" section in
+	linkgit:git-notes[1] for more information on the available strategies.
+
+notes.displayRef::
+	The (fully qualified) refname from which to show notes when
+	showing commit messages.  The value of this variable can be set
+	to a glob, in which case notes from all matching refs will be
+	shown.  You may also specify this configuration variable
+	several times.  A warning will be issued for refs that do not
+	exist, but a glob that does not match any refs is silently
+	ignored.
++
+This setting can be overridden with the `GIT_NOTES_DISPLAY_REF`
+environment variable, which must be a colon separated list of refs or
+globs.
++
+The effective value of "core.notesRef" (possibly overridden by
+GIT_NOTES_REF) is also implicitly added to the list of refs to be
+displayed.
+
+notes.rewrite.<command>::
+	When rewriting commits with <command> (currently `amend` or
+	`rebase`) and this variable is set to `true`, Git
+	automatically copies your notes from the original to the
+	rewritten commit.  Defaults to `true`, but see
+	"notes.rewriteRef" below.
+
+notes.rewriteMode::
+	When copying notes during a rewrite (see the
+	"notes.rewrite.<command>" option), determines what to do if
+	the target commit already has a note.  Must be one of
+	`overwrite`, `concatenate`, `cat_sort_uniq`, or `ignore`.
+	Defaults to `concatenate`.
++
+This setting can be overridden with the `GIT_NOTES_REWRITE_MODE`
+environment variable.
+
+notes.rewriteRef::
+	When copying notes during a rewrite, specifies the (fully
+	qualified) ref whose notes should be copied.  The ref may be a
+	glob, in which case notes in all matching refs will be copied.
+	You may also specify this configuration several times.
++
+Does not have a default value; you must configure this variable to
+enable note rewriting.  Set it to `refs/notes/commits` to enable
+rewriting for the default commit notes.
++
+This setting can be overridden with the `GIT_NOTES_REWRITE_REF`
+environment variable, which must be a colon separated list of refs or
+globs.
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/config/pack.txt 1.2.3+git2.25.1-1/git/Documentation/config/pack.txt
--- 1.2.1+git2.18.0-1/git/Documentation/config/pack.txt	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/config/pack.txt	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,128 @@
+pack.window::
+	The size of the window used by linkgit:git-pack-objects[1] when no
+	window size is given on the command line. Defaults to 10.
+
+pack.depth::
+	The maximum delta depth used by linkgit:git-pack-objects[1] when no
+	maximum depth is given on the command line. Defaults to 50.
+	Maximum value is 4095.
+
+pack.windowMemory::
+	The maximum size of memory that is consumed by each thread
+	in linkgit:git-pack-objects[1] for pack window memory when
+	no limit is given on the command line.  The value can be
+	suffixed with "k", "m", or "g".  When left unconfigured (or
+	set explicitly to 0), there will be no limit.
+
+pack.compression::
+	An integer -1..9, indicating the compression level for objects
+	in a pack file. -1 is the zlib default. 0 means no
+	compression, and 1..9 are various speed/size tradeoffs, 9 being
+	slowest.  If not set,  defaults to core.compression.  If that is
+	not set,  defaults to -1, the zlib default, which is "a default
+	compromise between speed and compression (currently equivalent
+	to level 6)."
++
+Note that changing the compression level will not automatically recompress
+all existing objects. You can force recompression by passing the -F option
+to linkgit:git-repack[1].
+
+pack.island::
+	An extended regular expression configuring a set of delta
+	islands. See "DELTA ISLANDS" in linkgit:git-pack-objects[1]
+	for details.
+
+pack.islandCore::
+	Specify an island name which gets to have its objects be
+	packed first. This creates a kind of pseudo-pack at the front
+	of one pack, so that the objects from the specified island are
+	hopefully faster to copy into any pack that should be served
+	to a user requesting these objects. In practice this means
+	that the island specified should likely correspond to what is
+	the most commonly cloned in the repo. See also "DELTA ISLANDS"
+	in linkgit:git-pack-objects[1].
+
+pack.deltaCacheSize::
+	The maximum memory in bytes used for caching deltas in
+	linkgit:git-pack-objects[1] before writing them out to a pack.
+	This cache is used to speed up the writing object phase by not
+	having to recompute the final delta result once the best match
+	for all objects is found.  Repacking large repositories on machines
+	which are tight with memory might be badly impacted by this though,
+	especially if this cache pushes the system into swapping.
+	A value of 0 means no limit. The smallest size of 1 byte may be
+	used to virtually disable this cache. Defaults to 256 MiB.
+
+pack.deltaCacheLimit::
+	The maximum size of a delta, that is cached in
+	linkgit:git-pack-objects[1]. This cache is used to speed up the
+	writing object phase by not having to recompute the final delta
+	result once the best match for all objects is found.
+	Defaults to 1000. Maximum value is 65535.
+
+pack.threads::
+	Specifies the number of threads to spawn when searching for best
+	delta matches.  This requires that linkgit:git-pack-objects[1]
+	be compiled with pthreads otherwise this option is ignored with a
+	warning. This is meant to reduce packing time on multiprocessor
+	machines. The required amount of memory for the delta search window
+	is however multiplied by the number of threads.
+	Specifying 0 will cause Git to auto-detect the number of CPU's
+	and set the number of threads accordingly.
+
+pack.indexVersion::
+	Specify the default pack index version.  Valid values are 1 for
+	legacy pack index used by Git versions prior to 1.5.2, and 2 for
+	the new pack index with capabilities for packs larger than 4 GB
+	as well as proper protection against the repacking of corrupted
+	packs.  Version 2 is the default.  Note that version 2 is enforced
+	and this config option ignored whenever the corresponding pack is
+	larger than 2 GB.
++
+If you have an old Git that does not understand the version 2 `*.idx` file,
+cloning or fetching over a non native protocol (e.g. "http")
+that will copy both `*.pack` file and corresponding `*.idx` file from the
+other side may give you a repository that cannot be accessed with your
+older version of Git. If the `*.pack` file is smaller than 2 GB, however,
+you can use linkgit:git-index-pack[1] on the *.pack file to regenerate
+the `*.idx` file.
+
+pack.packSizeLimit::
+	The maximum size of a pack.  This setting only affects
+	packing to a file when repacking, i.e. the git:// protocol
+	is unaffected.  It can be overridden by the `--max-pack-size`
+	option of linkgit:git-repack[1].  Reaching this limit results
+	in the creation of multiple packfiles; which in turn prevents
+	bitmaps from being created.
+	The minimum size allowed is limited to 1 MiB.
+	The default is unlimited.
+	Common unit suffixes of 'k', 'm', or 'g' are
+	supported.
+
+pack.useBitmaps::
+	When true, git will use pack bitmaps (if available) when packing
+	to stdout (e.g., during the server side of a fetch). Defaults to
+	true. You should not generally need to turn this off unless
+	you are debugging pack bitmaps.
+
+pack.useSparse::
+	When true, git will default to using the '--sparse' option in
+	'git pack-objects' when the '--revs' option is present. This
+	algorithm only walks trees that appear in paths that introduce new
+	objects. This can have significant performance benefits when
+	computing a pack to send a small change. However, it is possible
+	that extra objects are added to the pack-file if the included
+	commits contain certain types of direct renames. Default is `false`
+	unless `feature.experimental` is enabled.
+
+pack.writeBitmaps (deprecated)::
+	This is a deprecated synonym for `repack.writeBitmaps`.
+
+pack.writeBitmapHashCache::
+	When true, git will include a "hash cache" section in the bitmap
+	index (if one is written). This cache can be used to feed git's
+	delta heuristics, potentially leading to better deltas between
+	bitmapped and non-bitmapped objects (e.g., when serving a fetch
+	between an older, bitmapped pack and objects that have been
+	pushed since the last gc). The downside is that it consumes 4
+	bytes per object of disk space. Defaults to true.
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/config/pager.txt 1.2.3+git2.25.1-1/git/Documentation/config/pager.txt
--- 1.2.1+git2.18.0-1/git/Documentation/config/pager.txt	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/config/pager.txt	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,8 @@
+pager.<cmd>::
+	If the value is boolean, turns on or off pagination of the
+	output of a particular Git subcommand when writing to a tty.
+	Otherwise, turns on pagination for the subcommand using the
+	pager specified by the value of `pager.<cmd>`.  If `--paginate`
+	or `--no-pager` is specified on the command line, it takes
+	precedence over this option.  To disable pagination for all
+	commands, set `core.pager` or `GIT_PAGER` to `cat`.
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/config/pretty.txt 1.2.3+git2.25.1-1/git/Documentation/config/pretty.txt
--- 1.2.1+git2.18.0-1/git/Documentation/config/pretty.txt	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/config/pretty.txt	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,9 @@
+pretty.<name>::
+	Alias for a --pretty= format string, as specified in
+	linkgit:git-log[1]. Any aliases defined here can be used just
+	as the built-in pretty formats could. For example,
+	running `git config pretty.changelog "format:* %H %s"`
+	would cause the invocation `git log --pretty=changelog`
+	to be equivalent to running `git log "--pretty=format:* %H %s"`.
+	Note that an alias with the same name as a built-in format
+	will be silently ignored.
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/config/protocol.txt 1.2.3+git2.25.1-1/git/Documentation/config/protocol.txt
--- 1.2.1+git2.18.0-1/git/Documentation/config/protocol.txt	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/config/protocol.txt	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,64 @@
+protocol.allow::
+	If set, provide a user defined default policy for all protocols which
+	don't explicitly have a policy (`protocol.<name>.allow`).  By default,
+	if unset, known-safe protocols (http, https, git, ssh, file) have a
+	default policy of `always`, known-dangerous protocols (ext) have a
+	default policy of `never`, and all other protocols have a default
+	policy of `user`.  Supported policies:
++
+--
+
+* `always` - protocol is always able to be used.
+
+* `never` - protocol is never able to be used.
+
+* `user` - protocol is only able to be used when `GIT_PROTOCOL_FROM_USER` is
+  either unset or has a value of 1.  This policy should be used when you want a
+  protocol to be directly usable by the user but don't want it used by commands which
+  execute clone/fetch/push commands without user input, e.g. recursive
+  submodule initialization.
+
+--
+
+protocol.<name>.allow::
+	Set a policy to be used by protocol `<name>` with clone/fetch/push
+	commands. See `protocol.allow` above for the available policies.
++
+The protocol names currently used by git are:
++
+--
+  - `file`: any local file-based path (including `file://` URLs,
+    or local paths)
+
+  - `git`: the anonymous git protocol over a direct TCP
+    connection (or proxy, if configured)
+
+  - `ssh`: git over ssh (including `host:path` syntax,
+    `ssh://`, etc).
+
+  - `http`: git over http, both "smart http" and "dumb http".
+    Note that this does _not_ include `https`; if you want to configure
+    both, you must do so individually.
+
+  - any external helpers are named by their protocol (e.g., use
+    `hg` to allow the `git-remote-hg` helper)
+--
+
+protocol.version::
+	Experimental. If set, clients will attempt to communicate with a
+	server using the specified protocol version.  If unset, no
+	attempt will be made by the client to communicate using a
+	particular protocol version, this results in protocol version 0
+	being used.
+	Supported versions:
++
+--
+
+* `0` - the original wire protocol.
+
+* `1` - the original wire protocol with the addition of a version string
+  in the initial response from the server.
+
+* `2` - link:technical/protocol-v2.html[wire protocol version 2].
+
+--
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/config/pull.txt 1.2.3+git2.25.1-1/git/Documentation/config/pull.txt
--- 1.2.1+git2.18.0-1/git/Documentation/config/pull.txt	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/config/pull.txt	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,36 @@
+pull.ff::
+	By default, Git does not create an extra merge commit when merging
+	a commit that is a descendant of the current commit. Instead, the
+	tip of the current branch is fast-forwarded. When set to `false`,
+	this variable tells Git to create an extra merge commit in such
+	a case (equivalent to giving the `--no-ff` option from the command
+	line). When set to `only`, only such fast-forward merges are
+	allowed (equivalent to giving the `--ff-only` option from the
+	command line). This setting overrides `merge.ff` when pulling.
+
+pull.rebase::
+	When true, rebase branches on top of the fetched branch, instead
+	of merging the default branch from the default remote when "git
+	pull" is run. See "branch.<name>.rebase" for setting this on a
+	per-branch basis.
++
+When `merges`, pass the `--rebase-merges` option to 'git rebase'
+so that the local merge commits are included in the rebase (see
+linkgit:git-rebase[1] for details).
++
+When `preserve` (deprecated in favor of `merges`), also pass
+`--preserve-merges` along to 'git rebase' so that locally committed merge
+commits will not be flattened by running 'git pull'.
++
+When the value is `interactive`, the rebase is run in interactive mode.
++
+*NOTE*: this is a possibly dangerous operation; do *not* use
+it unless you understand the implications (see linkgit:git-rebase[1]
+for details).
+
+pull.octopus::
+	The default merge strategy to use when pulling multiple branches
+	at once.
+
+pull.twohead::
+	The default merge strategy to use when pulling a single branch.
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/config/push.txt 1.2.3+git2.25.1-1/git/Documentation/config/push.txt
--- 1.2.1+git2.18.0-1/git/Documentation/config/push.txt	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/config/push.txt	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,113 @@
+push.default::
+	Defines the action `git push` should take if no refspec is
+	explicitly given.  Different values are well-suited for
+	specific workflows; for instance, in a purely central workflow
+	(i.e. the fetch source is equal to the push destination),
+	`upstream` is probably what you want.  Possible values are:
++
+--
+
+* `nothing` - do not push anything (error out) unless a refspec is
+  explicitly given. This is primarily meant for people who want to
+  avoid mistakes by always being explicit.
+
+* `current` - push the current branch to update a branch with the same
+  name on the receiving end.  Works in both central and non-central
+  workflows.
+
+* `upstream` - push the current branch back to the branch whose
+  changes are usually integrated into the current branch (which is
+  called `@{upstream}`).  This mode only makes sense if you are
+  pushing to the same repository you would normally pull from
+  (i.e. central workflow).
+
+* `tracking` - This is a deprecated synonym for `upstream`.
+
+* `simple` - in centralized workflow, work like `upstream` with an
+  added safety to refuse to push if the upstream branch's name is
+  different from the local one.
++
+When pushing to a remote that is different from the remote you normally
+pull from, work as `current`.  This is the safest option and is suited
+for beginners.
++
+This mode has become the default in Git 2.0.
+
+* `matching` - push all branches having the same name on both ends.
+  This makes the repository you are pushing to remember the set of
+  branches that will be pushed out (e.g. if you always push 'maint'
+  and 'master' there and no other branches, the repository you push
+  to will have these two branches, and your local 'maint' and
+  'master' will be pushed there).
++
+To use this mode effectively, you have to make sure _all_ the
+branches you would push out are ready to be pushed out before
+running 'git push', as the whole point of this mode is to allow you
+to push all of the branches in one go.  If you usually finish work
+on only one branch and push out the result, while other branches are
+unfinished, this mode is not for you.  Also this mode is not
+suitable for pushing into a shared central repository, as other
+people may add new branches there, or update the tip of existing
+branches outside your control.
++
+This used to be the default, but not since Git 2.0 (`simple` is the
+new default).
+
+--
+
+push.followTags::
+	If set to true enable `--follow-tags` option by default.  You
+	may override this configuration at time of push by specifying
+	`--no-follow-tags`.
+
+push.gpgSign::
+	May be set to a boolean value, or the string 'if-asked'. A true
+	value causes all pushes to be GPG signed, as if `--signed` is
+	passed to linkgit:git-push[1]. The string 'if-asked' causes
+	pushes to be signed if the server supports it, as if
+	`--signed=if-asked` is passed to 'git push'. A false value may
+	override a value from a lower-priority config file. An explicit
+	command-line flag always overrides this config option.
+
+push.pushOption::
+	When no `--push-option=<option>` argument is given from the
+	command line, `git push` behaves as if each <value> of
+	this variable is given as `--push-option=<value>`.
++
+This is a multi-valued variable, and an empty value can be used in a
+higher priority configuration file (e.g. `.git/config` in a
+repository) to clear the values inherited from a lower priority
+configuration files (e.g. `$HOME/.gitconfig`).
++
+--
+
+Example:
+
+/etc/gitconfig
+  push.pushoption = a
+  push.pushoption = b
+
+~/.gitconfig
+  push.pushoption = c
+
+repo/.git/config
+  push.pushoption =
+  push.pushoption = b
+
+This will result in only b (a and c are cleared).
+
+--
+
+push.recurseSubmodules::
+	Make sure all submodule commits used by the revisions to be pushed
+	are available on a remote-tracking branch. If the value is 'check'
+	then Git will verify that all submodule commits that changed in the
+	revisions to be pushed are available on at least one remote of the
+	submodule. If any commits are missing, the push will be aborted and
+	exit with non-zero status. If the value is 'on-demand' then all
+	submodules that changed in the revisions to be pushed will be
+	pushed. If on-demand was not able to push all necessary revisions
+	it will also be aborted and exit with non-zero status. If the value
+	is 'no' then default behavior of ignoring submodules when pushing
+	is retained. You may override this configuration at time of push by
+	specifying '--recurse-submodules=check|on-demand|no'.
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/config/rebase.txt 1.2.3+git2.25.1-1/git/Documentation/config/rebase.txt
--- 1.2.1+git2.18.0-1/git/Documentation/config/rebase.txt	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/config/rebase.txt	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,64 @@
+rebase.useBuiltin::
+	Unused configuration variable. Used in Git versions 2.20 and
+	2.21 as an escape hatch to enable the legacy shellscript
+	implementation of rebase. Now the built-in rewrite of it in C
+	is always used. Setting this will emit a warning, to alert any
+	remaining users that setting this now does nothing.
+
+rebase.stat::
+	Whether to show a diffstat of what changed upstream since the last
+	rebase. False by default.
+
+rebase.autoSquash::
+	If set to true enable `--autosquash` option by default.
+
+rebase.autoStash::
+	When set to true, automatically create a temporary stash entry
+	before the operation begins, and apply it after the operation
+	ends.  This means that you can run rebase on a dirty worktree.
+	However, use with care: the final stash application after a
+	successful rebase might result in non-trivial conflicts.
+	This option can be overridden by the `--no-autostash` and
+	`--autostash` options of linkgit:git-rebase[1].
+	Defaults to false.
+
+rebase.missingCommitsCheck::
+	If set to "warn", git rebase -i will print a warning if some
+	commits are removed (e.g. a line was deleted), however the
+	rebase will still proceed. If set to "error", it will print
+	the previous warning and stop the rebase, 'git rebase
+	--edit-todo' can then be used to correct the error. If set to
+	"ignore", no checking is done.
+	To drop a commit without warning or error, use the `drop`
+	command in the todo list.
+	Defaults to "ignore".
+
+rebase.instructionFormat::
+	A format string, as specified in linkgit:git-log[1], to be used for the
+	todo list during an interactive rebase.  The format will
+	automatically have the long commit hash prepended to the format.
+
+rebase.abbreviateCommands::
+	If set to true, `git rebase` will use abbreviated command names in the
+	todo list resulting in something like this:
++
+-------------------------------------------
+	p deadbee The oneline of the commit
+	p fa1afe1 The oneline of the next commit
+	...
+-------------------------------------------
++
+instead of:
++
+-------------------------------------------
+	pick deadbee The oneline of the commit
+	pick fa1afe1 The oneline of the next commit
+	...
+-------------------------------------------
++
+Defaults to false.
+
+rebase.rescheduleFailedExec::
+	Automatically reschedule `exec` commands that failed. This only makes
+	sense in interactive mode (or when an `--exec` option was provided).
+	This is the same as specifying the `--reschedule-failed-exec` option.
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/config/receive.txt 1.2.3+git2.25.1-1/git/Documentation/config/receive.txt
--- 1.2.1+git2.18.0-1/git/Documentation/config/receive.txt	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/config/receive.txt	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,123 @@
+receive.advertiseAtomic::
+	By default, git-receive-pack will advertise the atomic push
+	capability to its clients. If you don't want to advertise this
+	capability, set this variable to false.
+
+receive.advertisePushOptions::
+	When set to true, git-receive-pack will advertise the push options
+	capability to its clients. False by default.
+
+receive.autogc::
+	By default, git-receive-pack will run "git-gc --auto" after
+	receiving data from git-push and updating refs.  You can stop
+	it by setting this variable to false.
+
+receive.certNonceSeed::
+	By setting this variable to a string, `git receive-pack`
+	will accept a `git push --signed` and verifies it by using
+	a "nonce" protected by HMAC using this string as a secret
+	key.
+
+receive.certNonceSlop::
+	When a `git push --signed` sent a push certificate with a
+	"nonce" that was issued by a receive-pack serving the same
+	repository within this many seconds, export the "nonce"
+	found in the certificate to `GIT_PUSH_CERT_NONCE` to the
+	hooks (instead of what the receive-pack asked the sending
+	side to include).  This may allow writing checks in
+	`pre-receive` and `post-receive` a bit easier.  Instead of
+	checking `GIT_PUSH_CERT_NONCE_SLOP` environment variable
+	that records by how many seconds the nonce is stale to
+	decide if they want to accept the certificate, they only
+	can check `GIT_PUSH_CERT_NONCE_STATUS` is `OK`.
+
+receive.fsckObjects::
+	If it is set to true, git-receive-pack will check all received
+	objects. See `transfer.fsckObjects` for what's checked.
+	Defaults to false. If not set, the value of
+	`transfer.fsckObjects` is used instead.
+
+receive.fsck.<msg-id>::
+	Acts like `fsck.<msg-id>`, but is used by
+	linkgit:git-receive-pack[1] instead of
+	linkgit:git-fsck[1]. See the `fsck.<msg-id>` documentation for
+	details.
+
+receive.fsck.skipList::
+	Acts like `fsck.skipList`, but is used by
+	linkgit:git-receive-pack[1] instead of
+	linkgit:git-fsck[1]. See the `fsck.skipList` documentation for
+	details.
+
+receive.keepAlive::
+	After receiving the pack from the client, `receive-pack` may
+	produce no output (if `--quiet` was specified) while processing
+	the pack, causing some networks to drop the TCP connection.
+	With this option set, if `receive-pack` does not transmit
+	any data in this phase for `receive.keepAlive` seconds, it will
+	send a short keepalive packet.  The default is 5 seconds; set
+	to 0 to disable keepalives entirely.
+
+receive.unpackLimit::
+	If the number of objects received in a push is below this
+	limit then the objects will be unpacked into loose object
+	files. However if the number of received objects equals or
+	exceeds this limit then the received pack will be stored as
+	a pack, after adding any missing delta bases.  Storing the
+	pack from a push can make the push operation complete faster,
+	especially on slow filesystems.  If not set, the value of
+	`transfer.unpackLimit` is used instead.
+
+receive.maxInputSize::
+	If the size of the incoming pack stream is larger than this
+	limit, then git-receive-pack will error out, instead of
+	accepting the pack file. If not set or set to 0, then the size
+	is unlimited.
+
+receive.denyDeletes::
+	If set to true, git-receive-pack will deny a ref update that deletes
+	the ref. Use this to prevent such a ref deletion via a push.
+
+receive.denyDeleteCurrent::
+	If set to true, git-receive-pack will deny a ref update that
+	deletes the currently checked out branch of a non-bare repository.
+
+receive.denyCurrentBranch::
+	If set to true or "refuse", git-receive-pack will deny a ref update
+	to the currently checked out branch of a non-bare repository.
+	Such a push is potentially dangerous because it brings the HEAD
+	out of sync with the index and working tree. If set to "warn",
+	print a warning of such a push to stderr, but allow the push to
+	proceed. If set to false or "ignore", allow such pushes with no
+	message. Defaults to "refuse".
++
+Another option is "updateInstead" which will update the working
+tree if pushing into the current branch.  This option is
+intended for synchronizing working directories when one side is not easily
+accessible via interactive ssh (e.g. a live web site, hence the requirement
+that the working directory be clean). This mode also comes in handy when
+developing inside a VM to test and fix code on different Operating Systems.
++
+By default, "updateInstead" will refuse the push if the working tree or
+the index have any difference from the HEAD, but the `push-to-checkout`
+hook can be used to customize this.  See linkgit:githooks[5].
+
+receive.denyNonFastForwards::
+	If set to true, git-receive-pack will deny a ref update which is
+	not a fast-forward. Use this to prevent such an update via a push,
+	even if that push is forced. This configuration variable is
+	set when initializing a shared repository.
+
+receive.hideRefs::
+	This variable is the same as `transfer.hideRefs`, but applies
+	only to `receive-pack` (and so affects pushes, but not fetches).
+	An attempt to update or delete a hidden ref by `git push` is
+	rejected.
+
+receive.updateServerInfo::
+	If set to true, git-receive-pack will run git-update-server-info
+	after receiving data from git-push and updating refs.
+
+receive.shallowUpdate::
+	If set to true, .git/shallow can be updated when new refs
+	require new shallow roots. Otherwise those refs are rejected.
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/config/remotes.txt 1.2.3+git2.25.1-1/git/Documentation/config/remotes.txt
--- 1.2.1+git2.18.0-1/git/Documentation/config/remotes.txt	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/config/remotes.txt	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,3 @@
+remotes.<group>::
+	The list of remotes which are fetched by "git remote update
+	<group>".  See linkgit:git-remote[1].
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/config/remote.txt 1.2.3+git2.25.1-1/git/Documentation/config/remote.txt
--- 1.2.1+git2.18.0-1/git/Documentation/config/remote.txt	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/config/remote.txt	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,86 @@
+remote.pushDefault::
+	The remote to push to by default.  Overrides
+	`branch.<name>.remote` for all branches, and is overridden by
+	`branch.<name>.pushRemote` for specific branches.
+
+remote.<name>.url::
+	The URL of a remote repository.  See linkgit:git-fetch[1] or
+	linkgit:git-push[1].
+
+remote.<name>.pushurl::
+	The push URL of a remote repository.  See linkgit:git-push[1].
+
+remote.<name>.proxy::
+	For remotes that require curl (http, https and ftp), the URL to
+	the proxy to use for that remote.  Set to the empty string to
+	disable proxying for that remote.
+
+remote.<name>.proxyAuthMethod::
+	For remotes that require curl (http, https and ftp), the method to use for
+	authenticating against the proxy in use (probably set in
+	`remote.<name>.proxy`). See `http.proxyAuthMethod`.
+
+remote.<name>.fetch::
+	The default set of "refspec" for linkgit:git-fetch[1]. See
+	linkgit:git-fetch[1].
+
+remote.<name>.push::
+	The default set of "refspec" for linkgit:git-push[1]. See
+	linkgit:git-push[1].
+
+remote.<name>.mirror::
+	If true, pushing to this remote will automatically behave
+	as if the `--mirror` option was given on the command line.
+
+remote.<name>.skipDefaultUpdate::
+	If true, this remote will be skipped by default when updating
+	using linkgit:git-fetch[1] or the `update` subcommand of
+	linkgit:git-remote[1].
+
+remote.<name>.skipFetchAll::
+	If true, this remote will be skipped by default when updating
+	using linkgit:git-fetch[1] or the `update` subcommand of
+	linkgit:git-remote[1].
+
+remote.<name>.receivepack::
+	The default program to execute on the remote side when pushing.  See
+	option --receive-pack of linkgit:git-push[1].
+
+remote.<name>.uploadpack::
+	The default program to execute on the remote side when fetching.  See
+	option --upload-pack of linkgit:git-fetch-pack[1].
+
+remote.<name>.tagOpt::
+	Setting this value to --no-tags disables automatic tag following when
+	fetching from remote <name>. Setting it to --tags will fetch every
+	tag from remote <name>, even if they are not reachable from remote
+	branch heads. Passing these flags directly to linkgit:git-fetch[1] can
+	override this setting. See options --tags and --no-tags of
+	linkgit:git-fetch[1].
+
+remote.<name>.vcs::
+	Setting this to a value <vcs> will cause Git to interact with
+	the remote with the git-remote-<vcs> helper.
+
+remote.<name>.prune::
+	When set to true, fetching from this remote by default will also
+	remove any remote-tracking references that no longer exist on the
+	remote (as if the `--prune` option was given on the command line).
+	Overrides `fetch.prune` settings, if any.
+
+remote.<name>.pruneTags::
+	When set to true, fetching from this remote by default will also
+	remove any local tags that no longer exist on the remote if pruning
+	is activated in general via `remote.<name>.prune`, `fetch.prune` or
+	`--prune`. Overrides `fetch.pruneTags` settings, if any.
++
+See also `remote.<name>.prune` and the PRUNING section of
+linkgit:git-fetch[1].
+
+remote.<name>.promisor::
+	When set to true, this remote will be used to fetch promisor
+	objects.
+
+remote.<name>.partialclonefilter::
+	The filter that will be applied when fetching from this
+	promisor remote.
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/config/repack.txt 1.2.3+git2.25.1-1/git/Documentation/config/repack.txt
--- 1.2.1+git2.18.0-1/git/Documentation/config/repack.txt	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/config/repack.txt	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,27 @@
+repack.useDeltaBaseOffset::
+	By default, linkgit:git-repack[1] creates packs that use
+	delta-base offset. If you need to share your repository with
+	Git older than version 1.4.4, either directly or via a dumb
+	protocol such as http, then you need to set this option to
+	"false" and repack. Access from old Git versions over the
+	native protocol are unaffected by this option.
+
+repack.packKeptObjects::
+	If set to true, makes `git repack` act as if
+	`--pack-kept-objects` was passed. See linkgit:git-repack[1] for
+	details. Defaults to `false` normally, but `true` if a bitmap
+	index is being written (either via `--write-bitmap-index` or
+	`repack.writeBitmaps`).
+
+repack.useDeltaIslands::
+	If set to true, makes `git repack` act as if `--delta-islands`
+	was passed. Defaults to `false`.
+
+repack.writeBitmaps::
+	When true, git will write a bitmap index when packing all
+	objects to disk (e.g., when `git repack -a` is run).  This
+	index can speed up the "counting objects" phase of subsequent
+	packs created for clones and fetches, at the cost of some disk
+	space and extra time spent on the initial repack.  This has
+	no effect if multiple packfiles are created.
+	Defaults to true on bare repos, false otherwise.
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/config/rerere.txt 1.2.3+git2.25.1-1/git/Documentation/config/rerere.txt
--- 1.2.1+git2.18.0-1/git/Documentation/config/rerere.txt	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/config/rerere.txt	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,12 @@
+rerere.autoUpdate::
+	When set to true, `git-rerere` updates the index with the
+	resulting contents after it cleanly resolves conflicts using
+	previously recorded resolution.  Defaults to false.
+
+rerere.enabled::
+	Activate recording of resolved conflicts, so that identical
+	conflict hunks can be resolved automatically, should they be
+	encountered again.  By default, linkgit:git-rerere[1] is
+	enabled if there is an `rr-cache` directory under the
+	`$GIT_DIR`, e.g. if "rerere" was previously used in the
+	repository.
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/config/reset.txt 1.2.3+git2.25.1-1/git/Documentation/config/reset.txt
--- 1.2.1+git2.18.0-1/git/Documentation/config/reset.txt	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/config/reset.txt	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,2 @@
+reset.quiet::
+	When set to true, 'git reset' will default to the '--quiet' option.
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/config/sendemail.txt 1.2.3+git2.25.1-1/git/Documentation/config/sendemail.txt
--- 1.2.1+git2.18.0-1/git/Documentation/config/sendemail.txt	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/config/sendemail.txt	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,63 @@
+sendemail.identity::
+	A configuration identity. When given, causes values in the
+	'sendemail.<identity>' subsection to take precedence over
+	values in the 'sendemail' section. The default identity is
+	the value of `sendemail.identity`.
+
+sendemail.smtpEncryption::
+	See linkgit:git-send-email[1] for description.  Note that this
+	setting is not subject to the 'identity' mechanism.
+
+sendemail.smtpssl (deprecated)::
+	Deprecated alias for 'sendemail.smtpEncryption = ssl'.
+
+sendemail.smtpsslcertpath::
+	Path to ca-certificates (either a directory or a single file).
+	Set it to an empty string to disable certificate verification.
+
+sendemail.<identity>.*::
+	Identity-specific versions of the 'sendemail.*' parameters
+	found below, taking precedence over those when this
+	identity is selected, through either the command-line or
+	`sendemail.identity`.
+
+sendemail.aliasesFile::
+sendemail.aliasFileType::
+sendemail.annotate::
+sendemail.bcc::
+sendemail.cc::
+sendemail.ccCmd::
+sendemail.chainReplyTo::
+sendemail.confirm::
+sendemail.envelopeSender::
+sendemail.from::
+sendemail.multiEdit::
+sendemail.signedoffbycc::
+sendemail.smtpPass::
+sendemail.suppresscc::
+sendemail.suppressFrom::
+sendemail.to::
+sendemail.tocmd::
+sendemail.smtpDomain::
+sendemail.smtpServer::
+sendemail.smtpServerPort::
+sendemail.smtpServerOption::
+sendemail.smtpUser::
+sendemail.thread::
+sendemail.transferEncoding::
+sendemail.validate::
+sendemail.xmailer::
+	See linkgit:git-send-email[1] for description.
+
+sendemail.signedoffcc (deprecated)::
+	Deprecated alias for `sendemail.signedoffbycc`.
+
+sendemail.smtpBatchSize::
+	Number of messages to be sent per connection, after that a relogin
+	will happen.  If the value is 0 or undefined, send all messages in
+	one connection.
+	See also the `--batch-size` option of linkgit:git-send-email[1].
+
+sendemail.smtpReloginDelay::
+	Seconds wait before reconnecting to smtp server.
+	See also the `--relogin-delay` option of linkgit:git-send-email[1].
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/config/sequencer.txt 1.2.3+git2.25.1-1/git/Documentation/config/sequencer.txt
--- 1.2.1+git2.18.0-1/git/Documentation/config/sequencer.txt	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/config/sequencer.txt	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,5 @@
+sequence.editor::
+	Text editor used by `git rebase -i` for editing the rebase instruction file.
+	The value is meant to be interpreted by the shell when it is used.
+	It can be overridden by the `GIT_SEQUENCE_EDITOR` environment variable.
+	When not configured the default commit message editor is used instead.
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/config/showbranch.txt 1.2.3+git2.25.1-1/git/Documentation/config/showbranch.txt
--- 1.2.1+git2.18.0-1/git/Documentation/config/showbranch.txt	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/config/showbranch.txt	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,3 @@
+showBranch.default::
+	The default set of branches for linkgit:git-show-branch[1].
+	See linkgit:git-show-branch[1].
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/config/splitindex.txt 1.2.3+git2.25.1-1/git/Documentation/config/splitindex.txt
--- 1.2.1+git2.18.0-1/git/Documentation/config/splitindex.txt	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/config/splitindex.txt	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,24 @@
+splitIndex.maxPercentChange::
+	When the split index feature is used, this specifies the
+	percent of entries the split index can contain compared to the
+	total number of entries in both the split index and the shared
+	index before a new shared index is written.
+	The value should be between 0 and 100. If the value is 0 then
+	a new shared index is always written, if it is 100 a new
+	shared index is never written.
+	By default the value is 20, so a new shared index is written
+	if the number of entries in the split index would be greater
+	than 20 percent of the total number of entries.
+	See linkgit:git-update-index[1].
+
+splitIndex.sharedIndexExpire::
+	When the split index feature is used, shared index files that
+	were not modified since the time this variable specifies will
+	be removed when a new shared index file is created. The value
+	"now" expires all entries immediately, and "never" suppresses
+	expiration altogether.
+	The default value is "2.weeks.ago".
+	Note that a shared index file is considered modified (for the
+	purpose of expiration) each time a new split-index file is
+	either created based on it or read from it.
+	See linkgit:git-update-index[1].
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/config/ssh.txt 1.2.3+git2.25.1-1/git/Documentation/config/ssh.txt
--- 1.2.1+git2.18.0-1/git/Documentation/config/ssh.txt	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/config/ssh.txt	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,35 @@
+ssh.variant::
+	By default, Git determines the command line arguments to use
+	based on the basename of the configured SSH command (configured
+	using the environment variable `GIT_SSH` or `GIT_SSH_COMMAND` or
+	the config setting `core.sshCommand`). If the basename is
+	unrecognized, Git will attempt to detect support of OpenSSH
+	options by first invoking the configured SSH command with the
+	`-G` (print configuration) option and will subsequently use
+	OpenSSH options (if that is successful) or no options besides
+	the host and remote command (if it fails).
++
+The config variable `ssh.variant` can be set to override this detection.
+Valid values are `ssh` (to use OpenSSH options), `plink`, `putty`,
+`tortoiseplink`, `simple` (no options except the host and remote command).
+The default auto-detection can be explicitly requested using the value
+`auto`.  Any other value is treated as `ssh`.  This setting can also be
+overridden via the environment variable `GIT_SSH_VARIANT`.
++
+The current command-line parameters used for each variant are as
+follows:
++
+--
+
+* `ssh` - [-p port] [-4] [-6] [-o option] [username@]host command
+
+* `simple` - [username@]host command
+
+* `plink` or `putty` - [-P port] [-4] [-6] [username@]host command
+
+* `tortoiseplink` - [-P port] [-4] [-6] -batch [username@]host command
+
+--
++
+Except for the `simple` variant, command-line parameters are likely to
+change as git gains new features.
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/config/stash.txt 1.2.3+git2.25.1-1/git/Documentation/config/stash.txt
--- 1.2.1+git2.18.0-1/git/Documentation/config/stash.txt	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/config/stash.txt	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,24 @@
+stash.useBuiltin::
+       Set to `false` to use the legacy shell script implementation of
+       linkgit:git-stash[1]. Is `true` by default, which means use
+       the built-in rewrite of it in C.
++
+The C rewrite is first included with Git version 2.22 (and Git for Windows
+version 2.19). This option serves as an escape hatch to re-enable the
+legacy version in case any bugs are found in the rewrite. This option and
+the shell script version of linkgit:git-stash[1] will be removed in some
+future release.
++
+If you find some reason to set this option to `false`, other than
+one-off testing, you should report the behavior difference as a bug in
+Git (see https://git-scm.com/community for details).
+
+stash.showPatch::
+	If this is set to true, the `git stash show` command without an
+	option will show the stash entry in patch form.  Defaults to false.
+	See description of 'show' command in linkgit:git-stash[1].
+
+stash.showStat::
+	If this is set to true, the `git stash show` command without an
+	option will show diffstat of the stash entry.  Defaults to true.
+	See description of 'show' command in linkgit:git-stash[1].
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/config/status.txt 1.2.3+git2.25.1-1/git/Documentation/config/status.txt
--- 1.2.1+git2.18.0-1/git/Documentation/config/status.txt	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/config/status.txt	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,77 @@
+status.relativePaths::
+	By default, linkgit:git-status[1] shows paths relative to the
+	current directory. Setting this variable to `false` shows paths
+	relative to the repository root (this was the default for Git
+	prior to v1.5.4).
+
+status.short::
+	Set to true to enable --short by default in linkgit:git-status[1].
+	The option --no-short takes precedence over this variable.
+
+status.branch::
+	Set to true to enable --branch by default in linkgit:git-status[1].
+	The option --no-branch takes precedence over this variable.
+
+status.aheadBehind::
+	Set to true to enable `--ahead-behind` and false to enable
+	`--no-ahead-behind` by default in linkgit:git-status[1] for
+	non-porcelain status formats.  Defaults to true.
+
+status.displayCommentPrefix::
+	If set to true, linkgit:git-status[1] will insert a comment
+	prefix before each output line (starting with
+	`core.commentChar`, i.e. `#` by default). This was the
+	behavior of linkgit:git-status[1] in Git 1.8.4 and previous.
+	Defaults to false.
+
+status.renameLimit::
+	The number of files to consider when performing rename detection
+	in linkgit:git-status[1] and linkgit:git-commit[1]. Defaults to
+	the value of diff.renameLimit.
+
+status.renames::
+	Whether and how Git detects renames in linkgit:git-status[1] and
+	linkgit:git-commit[1] .  If set to "false", rename detection is
+	disabled. If set to "true", basic rename detection is enabled.
+	If set to "copies" or "copy", Git will detect copies, as well.
+	Defaults to the value of diff.renames.
+
+status.showStash::
+	If set to true, linkgit:git-status[1] will display the number of
+	entries currently stashed away.
+	Defaults to false.
+
+status.showUntrackedFiles::
+	By default, linkgit:git-status[1] and linkgit:git-commit[1] show
+	files which are not currently tracked by Git. Directories which
+	contain only untracked files, are shown with the directory name
+	only. Showing untracked files means that Git needs to lstat() all
+	the files in the whole repository, which might be slow on some
+	systems. So, this variable controls how the commands displays
+	the untracked files. Possible values are:
++
+--
+* `no` - Show no untracked files.
+* `normal` - Show untracked files and directories.
+* `all` - Show also individual files in untracked directories.
+--
++
+If this variable is not specified, it defaults to 'normal'.
+This variable can be overridden with the -u|--untracked-files option
+of linkgit:git-status[1] and linkgit:git-commit[1].
+
+status.submoduleSummary::
+	Defaults to false.
+	If this is set to a non zero number or true (identical to -1 or an
+	unlimited number), the submodule summary will be enabled and a
+	summary of commits for modified submodules will be shown (see
+	--summary-limit option of linkgit:git-submodule[1]). Please note
+	that the summary output command will be suppressed for all
+	submodules when `diff.ignoreSubmodules` is set to 'all' or only
+	for those submodules where `submodule.<name>.ignore=all`. The only
+	exception to that rule is that status and commit will show staged
+	submodule changes. To
+	also view the summary for ignored submodules you can either use
+	the --ignore-submodules=dirty command-line option or the 'git
+	submodule summary' command, which shows a similar output but does
+	not honor these settings.
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/config/submodule.txt 1.2.3+git2.25.1-1/git/Documentation/config/submodule.txt
--- 1.2.1+git2.18.0-1/git/Documentation/config/submodule.txt	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/config/submodule.txt	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,84 @@
+submodule.<name>.url::
+	The URL for a submodule. This variable is copied from the .gitmodules
+	file to the git config via 'git submodule init'. The user can change
+	the configured URL before obtaining the submodule via 'git submodule
+	update'. If neither submodule.<name>.active or submodule.active are
+	set, the presence of this variable is used as a fallback to indicate
+	whether the submodule is of interest to git commands.
+	See linkgit:git-submodule[1] and linkgit:gitmodules[5] for details.
+
+submodule.<name>.update::
+	The method by which a submodule is updated by 'git submodule update',
+	which is the only affected command, others such as
+	'git checkout --recurse-submodules' are unaffected. It exists for
+	historical reasons, when 'git submodule' was the only command to
+	interact with submodules; settings like `submodule.active`
+	and `pull.rebase` are more specific. It is populated by
+	`git submodule init` from the linkgit:gitmodules[5] file.
+	See description of 'update' command in linkgit:git-submodule[1].
+
+submodule.<name>.branch::
+	The remote branch name for a submodule, used by `git submodule
+	update --remote`.  Set this option to override the value found in
+	the `.gitmodules` file.  See linkgit:git-submodule[1] and
+	linkgit:gitmodules[5] for details.
+
+submodule.<name>.fetchRecurseSubmodules::
+	This option can be used to control recursive fetching of this
+	submodule. It can be overridden by using the --[no-]recurse-submodules
+	command-line option to "git fetch" and "git pull".
+	This setting will override that from in the linkgit:gitmodules[5]
+	file.
+
+submodule.<name>.ignore::
+	Defines under what circumstances "git status" and the diff family show
+	a submodule as modified. When set to "all", it will never be considered
+	modified (but it will nonetheless show up in the output of status and
+	commit when it has been staged), "dirty" will ignore all changes
+	to the submodules work tree and
+	takes only differences between the HEAD of the submodule and the commit
+	recorded in the superproject into account. "untracked" will additionally
+	let submodules with modified tracked files in their work tree show up.
+	Using "none" (the default when this option is not set) also shows
+	submodules that have untracked files in their work tree as changed.
+	This setting overrides any setting made in .gitmodules for this submodule,
+	both settings can be overridden on the command line by using the
+	"--ignore-submodules" option. The 'git submodule' commands are not
+	affected by this setting.
+
+submodule.<name>.active::
+	Boolean value indicating if the submodule is of interest to git
+	commands.  This config option takes precedence over the
+	submodule.active config option. See linkgit:gitsubmodules[7] for
+	details.
+
+submodule.active::
+	A repeated field which contains a pathspec used to match against a
+	submodule's path to determine if the submodule is of interest to git
+	commands. See linkgit:gitsubmodules[7] for details.
+
+submodule.recurse::
+	Specifies if commands recurse into submodules by default. This
+	applies to all commands that have a `--recurse-submodules` option,
+	except `clone`.
+	Defaults to false.
+
+submodule.fetchJobs::
+	Specifies how many submodules are fetched/cloned at the same time.
+	A positive integer allows up to that number of submodules fetched
+	in parallel. A value of 0 will give some reasonable default.
+	If unset, it defaults to 1.
+
+submodule.alternateLocation::
+	Specifies how the submodules obtain alternates when submodules are
+	cloned. Possible values are `no`, `superproject`.
+	By default `no` is assumed, which doesn't add references. When the
+	value is set to `superproject` the submodule to be cloned computes
+	its alternates location relative to the superprojects alternate.
+
+submodule.alternateErrorStrategy::
+	Specifies how to treat errors with the alternates for a submodule
+	as computed via `submodule.alternateLocation`. Possible values are
+	`ignore`, `info`, `die`. Default is `die`. Note that if set to `ignore`
+	or `info`, and if there is an error with the computed alternate, the
+	clone proceeds as if no alternate was specified.
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/config/tag.txt 1.2.3+git2.25.1-1/git/Documentation/config/tag.txt
--- 1.2.1+git2.18.0-1/git/Documentation/config/tag.txt	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/config/tag.txt	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,24 @@
+tag.forceSignAnnotated::
+	A boolean to specify whether annotated tags created should be GPG signed.
+	If `--annotate` is specified on the command line, it takes
+	precedence over this option.
+
+tag.sort::
+	This variable controls the sort ordering of tags when displayed by
+	linkgit:git-tag[1]. Without the "--sort=<value>" option provided, the
+	value of this variable will be used as the default.
+
+tag.gpgSign::
+	A boolean to specify whether all tags should be GPG signed.
+	Use of this option when running in an automated script can
+	result in a large number of tags being signed. It is therefore
+	convenient to use an agent to avoid typing your gpg passphrase
+	several times. Note that this option doesn't affect tag signing
+	behavior enabled by "-u <keyid>" or "--local-user=<keyid>" options.
+
+tar.umask::
+	This variable can be used to restrict the permission bits of
+	tar archive entries.  The default is 0002, which turns off the
+	world write bit.  The special value "user" indicates that the
+	archiving user's umask will be used instead.  See umask(2) and
+	linkgit:git-archive[1].
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/config/trace2.txt 1.2.3+git2.25.1-1/git/Documentation/config/trace2.txt
--- 1.2.1+git2.18.0-1/git/Documentation/config/trace2.txt	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/config/trace2.txt	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,62 @@
+Trace2 config settings are only read from the system and global
+config files; repository local and worktree config files and `-c`
+command line arguments are not respected.
+
+trace2.normalTarget::
+	This variable controls the normal target destination.
+	It may be overridden by the `GIT_TRACE2` environment variable.
+	The following table shows possible values.
+
+trace2.perfTarget::
+	This variable controls the performance target destination.
+	It may be overridden by the `GIT_TRACE2_PERF` environment variable.
+	The following table shows possible values.
+
+trace2.eventTarget::
+	This variable controls the event target destination.
+	It may be overridden by the `GIT_TRACE2_EVENT` environment variable.
+	The following table shows possible values.
++
+include::../trace2-target-values.txt[]
+
+trace2.normalBrief::
+	Boolean.  When true `time`, `filename`, and `line` fields are
+	omitted from normal output.  May be overridden by the
+	`GIT_TRACE2_BRIEF` environment variable.  Defaults to false.
+
+trace2.perfBrief::
+	Boolean.  When true `time`, `filename`, and `line` fields are
+	omitted from PERF output.  May be overridden by the
+	`GIT_TRACE2_PERF_BRIEF` environment variable.  Defaults to false.
+
+trace2.eventBrief::
+	Boolean.  When true `time`, `filename`, and `line` fields are
+	omitted from event output.  May be overridden by the
+	`GIT_TRACE2_EVENT_BRIEF` environment variable.  Defaults to false.
+
+trace2.eventNesting::
+	Integer.  Specifies desired depth of nested regions in the
+	event output.  Regions deeper than this value will be
+	omitted.  May be overridden by the `GIT_TRACE2_EVENT_NESTING`
+	environment variable.  Defaults to 2.
+
+trace2.configParams::
+	A comma-separated list of patterns of "important" config
+	settings that should be recorded in the trace2 output.
+	For example, `core.*,remote.*.url` would cause the trace2
+	output to contain events listing each configured remote.
+	May be overridden by the `GIT_TRACE2_CONFIG_PARAMS` environment
+	variable.  Unset by default.
+
+trace2.destinationDebug::
+	Boolean.  When true Git will print error messages when a
+	trace target destination cannot be opened for writing.
+	By default, these errors are suppressed and tracing is
+	silently disabled.  May be overridden by the
+	`GIT_TRACE2_DST_DEBUG` environment variable.
+
+trace2.maxFiles::
+	Integer.  When writing trace files to a target directory, do not
+	write additional traces if we would exceed this many files. Instead,
+	write a sentinel file that will block further tracing to this
+	directory. Defaults to 0, which disables this check.
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/config/transfer.txt 1.2.3+git2.25.1-1/git/Documentation/config/transfer.txt
--- 1.2.1+git2.18.0-1/git/Documentation/config/transfer.txt	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/config/transfer.txt	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,71 @@
+transfer.fsckObjects::
+	When `fetch.fsckObjects` or `receive.fsckObjects` are
+	not set, the value of this variable is used instead.
+	Defaults to false.
++
+When set, the fetch or receive will abort in the case of a malformed
+object or a link to a nonexistent object. In addition, various other
+issues are checked for, including legacy issues (see `fsck.<msg-id>`),
+and potential security issues like the existence of a `.GIT` directory
+or a malicious `.gitmodules` file (see the release notes for v2.2.1
+and v2.17.1 for details). Other sanity and security checks may be
+added in future releases.
++
+On the receiving side, failing fsckObjects will make those objects
+unreachable, see "QUARANTINE ENVIRONMENT" in
+linkgit:git-receive-pack[1]. On the fetch side, malformed objects will
+instead be left unreferenced in the repository.
++
+Due to the non-quarantine nature of the `fetch.fsckObjects`
+implementation it cannot be relied upon to leave the object store
+clean like `receive.fsckObjects` can.
++
+As objects are unpacked they're written to the object store, so there
+can be cases where malicious objects get introduced even though the
+"fetch" failed, only to have a subsequent "fetch" succeed because only
+new incoming objects are checked, not those that have already been
+written to the object store. That difference in behavior should not be
+relied upon. In the future, such objects may be quarantined for
+"fetch" as well.
++
+For now, the paranoid need to find some way to emulate the quarantine
+environment if they'd like the same protection as "push". E.g. in the
+case of an internal mirror do the mirroring in two steps, one to fetch
+the untrusted objects, and then do a second "push" (which will use the
+quarantine) to another internal repo, and have internal clients
+consume this pushed-to repository, or embargo internal fetches and
+only allow them once a full "fsck" has run (and no new fetches have
+happened in the meantime).
+
+transfer.hideRefs::
+	String(s) `receive-pack` and `upload-pack` use to decide which
+	refs to omit from their initial advertisements.  Use more than
+	one definition to specify multiple prefix strings. A ref that is
+	under the hierarchies listed in the value of this variable is
+	excluded, and is hidden when responding to `git push` or `git
+	fetch`.  See `receive.hideRefs` and `uploadpack.hideRefs` for
+	program-specific versions of this config.
++
+You may also include a `!` in front of the ref name to negate the entry,
+explicitly exposing it, even if an earlier entry marked it as hidden.
+If you have multiple hideRefs values, later entries override earlier ones
+(and entries in more-specific config files override less-specific ones).
++
+If a namespace is in use, the namespace prefix is stripped from each
+reference before it is matched against `transfer.hiderefs` patterns.
+For example, if `refs/heads/master` is specified in `transfer.hideRefs` and
+the current namespace is `foo`, then `refs/namespaces/foo/refs/heads/master`
+is omitted from the advertisements but `refs/heads/master` and
+`refs/namespaces/bar/refs/heads/master` are still advertised as so-called
+"have" lines. In order to match refs before stripping, add a `^` in front of
+the ref name. If you combine `!` and `^`, `!` must be specified first.
++
+Even if you hide refs, a client may still be able to steal the target
+objects via the techniques described in the "SECURITY" section of the
+linkgit:gitnamespaces[7] man page; it's best to keep private data in a
+separate repository.
+
+transfer.unpackLimit::
+	When `fetch.unpackLimit` or `receive.unpackLimit` are
+	not set, the value of this variable is used instead.
+	The default value is 100.
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/config/uploadarchive.txt 1.2.3+git2.25.1-1/git/Documentation/config/uploadarchive.txt
--- 1.2.1+git2.18.0-1/git/Documentation/config/uploadarchive.txt	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/config/uploadarchive.txt	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,6 @@
+uploadarchive.allowUnreachable::
+	If true, allow clients to use `git archive --remote` to request
+	any tree, whether reachable from the ref tips or not. See the
+	discussion in the "SECURITY" section of
+	linkgit:git-upload-archive[1] for more details. Defaults to
+	`false`.
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/config/uploadpack.txt 1.2.3+git2.25.1-1/git/Documentation/config/uploadpack.txt
--- 1.2.1+git2.18.0-1/git/Documentation/config/uploadpack.txt	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/config/uploadpack.txt	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,65 @@
+uploadpack.hideRefs::
+	This variable is the same as `transfer.hideRefs`, but applies
+	only to `upload-pack` (and so affects only fetches, not pushes).
+	An attempt to fetch a hidden ref by `git fetch` will fail.  See
+	also `uploadpack.allowTipSHA1InWant`.
+
+uploadpack.allowTipSHA1InWant::
+	When `uploadpack.hideRefs` is in effect, allow `upload-pack`
+	to accept a fetch request that asks for an object at the tip
+	of a hidden ref (by default, such a request is rejected).
+	See also `uploadpack.hideRefs`.  Even if this is false, a client
+	may be able to steal objects via the techniques described in the
+	"SECURITY" section of the linkgit:gitnamespaces[7] man page; it's
+	best to keep private data in a separate repository.
+
+uploadpack.allowReachableSHA1InWant::
+	Allow `upload-pack` to accept a fetch request that asks for an
+	object that is reachable from any ref tip. However, note that
+	calculating object reachability is computationally expensive.
+	Defaults to `false`.  Even if this is false, a client may be able
+	to steal objects via the techniques described in the "SECURITY"
+	section of the linkgit:gitnamespaces[7] man page; it's best to
+	keep private data in a separate repository.
+
+uploadpack.allowAnySHA1InWant::
+	Allow `upload-pack` to accept a fetch request that asks for any
+	object at all.
+	Defaults to `false`.
+
+uploadpack.keepAlive::
+	When `upload-pack` has started `pack-objects`, there may be a
+	quiet period while `pack-objects` prepares the pack. Normally
+	it would output progress information, but if `--quiet` was used
+	for the fetch, `pack-objects` will output nothing at all until
+	the pack data begins. Some clients and networks may consider
+	the server to be hung and give up. Setting this option instructs
+	`upload-pack` to send an empty keepalive packet every
+	`uploadpack.keepAlive` seconds. Setting this option to 0
+	disables keepalive packets entirely. The default is 5 seconds.
+
+uploadpack.packObjectsHook::
+	If this option is set, when `upload-pack` would run
+	`git pack-objects` to create a packfile for a client, it will
+	run this shell command instead.  The `pack-objects` command and
+	arguments it _would_ have run (including the `git pack-objects`
+	at the beginning) are appended to the shell command. The stdin
+	and stdout of the hook are treated as if `pack-objects` itself
+	was run. I.e., `upload-pack` will feed input intended for
+	`pack-objects` to the hook, and expects a completed packfile on
+	stdout.
++
+Note that this configuration variable is ignored if it is seen in the
+repository-level config (this is a safety measure against fetching from
+untrusted repositories).
+
+uploadpack.allowFilter::
+	If this option is set, `upload-pack` will support partial
+	clone and partial fetch object filtering.
+
+uploadpack.allowRefInWant::
+	If this option is set, `upload-pack` will support the `ref-in-want`
+	feature of the protocol version 2 `fetch` command.  This feature
+	is intended for the benefit of load-balanced servers which may
+	not have the same view of what OIDs their refs point to due to
+	replication delay.
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/config/url.txt 1.2.3+git2.25.1-1/git/Documentation/config/url.txt
--- 1.2.1+git2.18.0-1/git/Documentation/config/url.txt	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/config/url.txt	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,30 @@
+url.<base>.insteadOf::
+	Any URL that starts with this value will be rewritten to
+	start, instead, with <base>. In cases where some site serves a
+	large number of repositories, and serves them with multiple
+	access methods, and some users need to use different access
+	methods, this feature allows people to specify any of the
+	equivalent URLs and have Git automatically rewrite the URL to
+	the best alternative for the particular user, even for a
+	never-before-seen repository on the site.  When more than one
+	insteadOf strings match a given URL, the longest match is used.
++
+Note that any protocol restrictions will be applied to the rewritten
+URL. If the rewrite changes the URL to use a custom protocol or remote
+helper, you may need to adjust the `protocol.*.allow` config to permit
+the request.  In particular, protocols you expect to use for submodules
+must be set to `always` rather than the default of `user`. See the
+description of `protocol.allow` above.
+
+url.<base>.pushInsteadOf::
+	Any URL that starts with this value will not be pushed to;
+	instead, it will be rewritten to start with <base>, and the
+	resulting URL will be pushed to. In cases where some site serves
+	a large number of repositories, and serves them with multiple
+	access methods, some of which do not allow push, this feature
+	allows people to specify a pull-only URL and have Git
+	automatically use an appropriate URL to push, even for a
+	never-before-seen repository on the site.  When more than one
+	pushInsteadOf strings match a given URL, the longest match is
+	used.  If a remote has an explicit pushurl, Git will ignore this
+	setting for that remote.
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/config/user.txt 1.2.3+git2.25.1-1/git/Documentation/config/user.txt
--- 1.2.1+git2.18.0-1/git/Documentation/config/user.txt	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/config/user.txt	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,38 @@
+user.name::
+user.email::
+author.name::
+author.email::
+committer.name::
+committer.email::
+	The `user.name` and `user.email` variables determine what ends
+	up in the `author` and `committer` field of commit
+	objects.
+	If you need the `author` or `committer` to be different, the
+	`author.name`, `author.email`, `committer.name` or
+	`committer.email` variables can be set.
+	Also, all of these can be overridden by the `GIT_AUTHOR_NAME`,
+	`GIT_AUTHOR_EMAIL`, `GIT_COMMITTER_NAME`,
+	`GIT_COMMITTER_EMAIL` and `EMAIL` environment variables.
++
+Note that the `name` forms of these variables conventionally refer to
+some form of a personal name.  See linkgit:git-commit[1] and the
+environment variables section of linkgit:git[1] for more information on
+these settings and the `credential.username` option if you're looking
+for authentication credentials instead.
+
+user.useConfigOnly::
+	Instruct Git to avoid trying to guess defaults for `user.email`
+	and `user.name`, and instead retrieve the values only from the
+	configuration. For example, if you have multiple email addresses
+	and would like to use a different one for each repository, then
+	with this configuration option set to `true` in the global config
+	along with a name, Git will prompt you to set up an email before
+	making new commits in a newly cloned repository.
+	Defaults to `false`.
+
+user.signingKey::
+	If linkgit:git-tag[1] or linkgit:git-commit[1] is not selecting the
+	key you want it to automatically when creating a signed tag or
+	commit, you can override the default selection with this variable.
+	This option is passed unchanged to gpg's --local-user parameter,
+	so you may specify a key using any method that gpg supports.
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/config/versionsort.txt 1.2.3+git2.25.1-1/git/Documentation/config/versionsort.txt
--- 1.2.1+git2.18.0-1/git/Documentation/config/versionsort.txt	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/config/versionsort.txt	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,33 @@
+versionsort.prereleaseSuffix (deprecated)::
+	Deprecated alias for `versionsort.suffix`.  Ignored if
+	`versionsort.suffix` is set.
+
+versionsort.suffix::
+	Even when version sort is used in linkgit:git-tag[1], tagnames
+	with the same base version but different suffixes are still sorted
+	lexicographically, resulting e.g. in prerelease tags appearing
+	after the main release (e.g. "1.0-rc1" after "1.0").  This
+	variable can be specified to determine the sorting order of tags
+	with different suffixes.
++
+By specifying a single suffix in this variable, any tagname containing
+that suffix will appear before the corresponding main release.  E.g. if
+the variable is set to "-rc", then all "1.0-rcX" tags will appear before
+"1.0".  If specified multiple times, once per suffix, then the order of
+suffixes in the configuration will determine the sorting order of tagnames
+with those suffixes.  E.g. if "-pre" appears before "-rc" in the
+configuration, then all "1.0-preX" tags will be listed before any
+"1.0-rcX" tags.  The placement of the main release tag relative to tags
+with various suffixes can be determined by specifying the empty suffix
+among those other suffixes.  E.g. if the suffixes "-rc", "", "-ck" and
+"-bfs" appear in the configuration in this order, then all "v4.8-rcX" tags
+are listed first, followed by "v4.8", then "v4.8-ckX" and finally
+"v4.8-bfsX".
++
+If more than one suffixes match the same tagname, then that tagname will
+be sorted according to the suffix which starts at the earliest position in
+the tagname.  If more than one different matching suffixes start at
+that earliest position, then that tagname will be sorted according to the
+longest of those suffixes.
+The sorting order between different suffixes is undefined if they are
+in multiple config files.
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/config/web.txt 1.2.3+git2.25.1-1/git/Documentation/config/web.txt
--- 1.2.1+git2.18.0-1/git/Documentation/config/web.txt	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/config/web.txt	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,4 @@
+web.browser::
+	Specify a web browser that may be used by some commands.
+	Currently only linkgit:git-instaweb[1] and linkgit:git-help[1]
+	may use it.
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/config/worktree.txt 1.2.3+git2.25.1-1/git/Documentation/config/worktree.txt
--- 1.2.1+git2.18.0-1/git/Documentation/config/worktree.txt	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/config/worktree.txt	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,9 @@
+worktree.guessRemote::
+	If no branch is specified and neither `-b` nor `-B` nor
+	`--detach` is used, then `git worktree add` defaults to
+	creating a new branch from HEAD.  If `worktree.guessRemote` is
+	set to true, `worktree add` tries to find a remote-tracking
+	branch whose name uniquely matches the new branch name.  If
+	such a branch exists, it is checked out and set as "upstream"
+	for the new branch.  If no such match can be found, it falls
+	back to creating a new branch from the current HEAD.
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/config.txt 1.2.3+git2.25.1-1/git/Documentation/config.txt
--- 1.2.1+git2.18.0-1/git/Documentation/config.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/config.txt	2020-02-17 04:47:35.000000000 +0000
@@ -2,8 +2,9 @@ CONFIGURATION FILE
 ------------------
 
 The Git configuration file contains a number of variables that affect
-the Git commands' behavior. The `.git/config` file in each repository
-is used to store the configuration for that repository, and
+the Git commands' behavior. The files `.git/config` and optionally
+`config.worktree` (see `extensions.worktreeConfig` below) in each
+repository are used to store the configuration for that repository, and
 `$HOME/.gitconfig` is used to store a per-user configuration as
 fallback values for the `.git/config` file. The file `/etc/gitconfig`
 can be used to store a system-wide default configuration.
@@ -141,7 +142,21 @@ refer to linkgit:gitignore[5] for detail
 
 `gitdir/i`::
 	This is the same as `gitdir` except that matching is done
-	case-insensitively (e.g. on case-insensitive file sytems)
+	case-insensitively (e.g. on case-insensitive file systems)
+
+`onbranch`::
+	The data that follows the keyword `onbranch:` is taken to be a
+	pattern with standard globbing wildcards and two additional
+	ones, `**/` and `/**`, that can match multiple path components.
+	If we are in a worktree where the name of the branch that is
+	currently checked out matches the pattern, the include condition
+	is met.
++
+If the pattern ends with `/`, `**` will be automatically added. For
+example, the pattern `foo/` becomes `foo/**`. In other words, it matches
+all branches that begin with `foo/`. This is useful if your branches are
+organized hierarchically and you would like to apply a configuration to
+all the branches in that hierarchy.
 
 A few more notes on matching via `gitdir` and `gitdir/i`:
 
@@ -163,46 +178,53 @@ to either specify only the realpath vers
 Example
 ~~~~~~~
 
-	# Core variables
-	[core]
-		; Don't trust file modes
-		filemode = false
-
-	# Our diff algorithm
-	[diff]
-		external = /usr/local/bin/diff-wrapper
-		renames = true
-
-	[branch "devel"]
-		remote = origin
-		merge = refs/heads/devel
-
-	# Proxy settings
-	[core]
-		gitProxy="ssh" for "kernel.org"
-		gitProxy=default-proxy ; for the rest
-
-	[include]
-		path = /path/to/foo.inc ; include by absolute path
-		path = foo.inc ; find "foo.inc" relative to the current file
-		path = ~/foo.inc ; find "foo.inc" in your `$HOME` directory
-
-	; include if $GIT_DIR is /path/to/foo/.git
-	[includeIf "gitdir:/path/to/foo/.git"]
-		path = /path/to/foo.inc
-
-	; include for all repositories inside /path/to/group
-	[includeIf "gitdir:/path/to/group/"]
-		path = /path/to/foo.inc
-
-	; include for all repositories inside $HOME/to/group
-	[includeIf "gitdir:~/to/group/"]
-		path = /path/to/foo.inc
-
-	; relative paths are always relative to the including
-	; file (if the condition is true); their location is not
-	; affected by the condition
-	[includeIf "gitdir:/path/to/group/"]
+----
+# Core variables
+[core]
+	; Don't trust file modes
+	filemode = false
+
+# Our diff algorithm
+[diff]
+	external = /usr/local/bin/diff-wrapper
+	renames = true
+
+[branch "devel"]
+	remote = origin
+	merge = refs/heads/devel
+
+# Proxy settings
+[core]
+	gitProxy="ssh" for "kernel.org"
+	gitProxy=default-proxy ; for the rest
+
+[include]
+	path = /path/to/foo.inc ; include by absolute path
+	path = foo.inc ; find "foo.inc" relative to the current file
+	path = ~/foo.inc ; find "foo.inc" in your `$HOME` directory
+
+; include if $GIT_DIR is /path/to/foo/.git
+[includeIf "gitdir:/path/to/foo/.git"]
+	path = /path/to/foo.inc
+
+; include for all repositories inside /path/to/group
+[includeIf "gitdir:/path/to/group/"]
+	path = /path/to/foo.inc
+
+; include for all repositories inside $HOME/to/group
+[includeIf "gitdir:~/to/group/"]
+	path = /path/to/foo.inc
+
+; relative paths are always relative to the including
+; file (if the condition is true); their location is not
+; affected by the condition
+[includeIf "gitdir:/path/to/group/"]
+	path = foo.inc
+----
+
+	; include only if we are in a worktree where foo-branch is
+	; currently checked out
+	[includeIf "onbranch:foo-branch"]
 		path = foo.inc
 
 Values
@@ -225,7 +247,7 @@ boolean::
 	false;; Boolean false literals are `no`, `off`, `false`,
 		`0` and the empty string.
 +
-When converting value to the canonical form using `--bool` type
+When converting a value to its canonical form using the `--type=bool` type
 specifier, 'git config' will ensure that the output is "true" or
 "false" (spelled in lowercase).
 
@@ -287,3301 +309,156 @@ inventing new variables for use in your
 names do not conflict with those that are used by Git itself and
 other popular tools, and describe them in your documentation.
 
+include::config/advice.txt[]
 
-advice.*::
-	These variables control various optional help messages designed to
-	aid new users. All 'advice.*' variables default to 'true', and you
-	can tell Git that you do not need help by setting these to 'false':
-+
---
-	pushUpdateRejected::
-		Set this variable to 'false' if you want to disable
-		'pushNonFFCurrent',
-		'pushNonFFMatching', 'pushAlreadyExists',
-		'pushFetchFirst', and 'pushNeedsForce'
-		simultaneously.
-	pushNonFFCurrent::
-		Advice shown when linkgit:git-push[1] fails due to a
-		non-fast-forward update to the current branch.
-	pushNonFFMatching::
-		Advice shown when you ran linkgit:git-push[1] and pushed
-		'matching refs' explicitly (i.e. you used ':', or
-		specified a refspec that isn't your current branch) and
-		it resulted in a non-fast-forward error.
-	pushAlreadyExists::
-		Shown when linkgit:git-push[1] rejects an update that
-		does not qualify for fast-forwarding (e.g., a tag.)
-	pushFetchFirst::
-		Shown when linkgit:git-push[1] rejects an update that
-		tries to overwrite a remote ref that points at an
-		object we do not have.
-	pushNeedsForce::
-		Shown when linkgit:git-push[1] rejects an update that
-		tries to overwrite a remote ref that points at an
-		object that is not a commit-ish, or make the remote
-		ref point at an object that is not a commit-ish.
-	statusHints::
-		Show directions on how to proceed from the current
-		state in the output of linkgit:git-status[1], in
-		the template shown when writing commit messages in
-		linkgit:git-commit[1], and in the help message shown
-		by linkgit:git-checkout[1] when switching branch.
-	statusUoption::
-		Advise to consider using the `-u` option to linkgit:git-status[1]
-		when the command takes more than 2 seconds to enumerate untracked
-		files.
-	commitBeforeMerge::
-		Advice shown when linkgit:git-merge[1] refuses to
-		merge to avoid overwriting local changes.
-	resolveConflict::
-		Advice shown by various commands when conflicts
-		prevent the operation from being performed.
-	implicitIdentity::
-		Advice on how to set your identity configuration when
-		your information is guessed from the system username and
-		domain name.
-	detachedHead::
-		Advice shown when you used linkgit:git-checkout[1] to
-		move to the detach HEAD state, to instruct how to create
-		a local branch after the fact.
-	amWorkDir::
-		Advice that shows the location of the patch file when
-		linkgit:git-am[1] fails to apply it.
-	rmHints::
-		In case of failure in the output of linkgit:git-rm[1],
-		show directions on how to proceed from the current state.
-	addEmbeddedRepo::
-		Advice on what to do when you've accidentally added one
-		git repo inside of another.
-	ignoredHook::
-		Advice shown if an hook is ignored because the hook is not
-		set as executable.
-	waitingForEditor::
-		Print a message to the terminal whenever Git is waiting for
-		editor input from the user.
---
-
-core.fileMode::
-	Tells Git if the executable bit of files in the working tree
-	is to be honored.
-+
-Some filesystems lose the executable bit when a file that is
-marked as executable is checked out, or checks out a
-non-executable file with executable bit on.
-linkgit:git-clone[1] or linkgit:git-init[1] probe the filesystem
-to see if it handles the executable bit correctly
-and this variable is automatically set as necessary.
-+
-A repository, however, may be on a filesystem that handles
-the filemode correctly, and this variable is set to 'true'
-when created, but later may be made accessible from another
-environment that loses the filemode (e.g. exporting ext4 via
-CIFS mount, visiting a Cygwin created repository with
-Git for Windows or Eclipse).
-In such a case it may be necessary to set this variable to 'false'.
-See linkgit:git-update-index[1].
-+
-The default is true (when core.filemode is not specified in the config file).
+include::config/core.txt[]
 
-core.hideDotFiles::
-	(Windows-only) If true, mark newly-created directories and files whose
-	name starts with a dot as hidden.  If 'dotGitOnly', only the `.git/`
-	directory is hidden, but no other files starting with a dot.  The
-	default mode is 'dotGitOnly'.
-
-core.ignoreCase::
-	If true, this option enables various workarounds to enable
-	Git to work better on filesystems that are not case sensitive,
-	like FAT. For example, if a directory listing finds
-	"makefile" when Git expects "Makefile", Git will assume
-	it is really the same file, and continue to remember it as
-	"Makefile".
-+
-The default is false, except linkgit:git-clone[1] or linkgit:git-init[1]
-will probe and set core.ignoreCase true if appropriate when the repository
-is created.
-
-core.precomposeUnicode::
-	This option is only used by Mac OS implementation of Git.
-	When core.precomposeUnicode=true, Git reverts the unicode decomposition
-	of filenames done by Mac OS. This is useful when sharing a repository
-	between Mac OS and Linux or Windows.
-	(Git for Windows 1.7.10 or higher is needed, or Git under cygwin 1.7).
-	When false, file names are handled fully transparent by Git,
-	which is backward compatible with older versions of Git.
-
-core.protectHFS::
-	If set to true, do not allow checkout of paths that would
-	be considered equivalent to `.git` on an HFS+ filesystem.
-	Defaults to `true` on Mac OS, and `false` elsewhere.
-
-core.protectNTFS::
-	If set to true, do not allow checkout of paths that would
-	cause problems with the NTFS filesystem, e.g. conflict with
-	8.3 "short" names.
-	Defaults to `true` on Windows, and `false` elsewhere.
-
-core.fsmonitor::
-	If set, the value of this variable is used as a command which
-	will identify all files that may have changed since the
-	requested date/time. This information is used to speed up git by
-	avoiding unnecessary processing of files that have not changed.
-	See the "fsmonitor-watchman" section of linkgit:githooks[5].
-
-core.trustctime::
-	If false, the ctime differences between the index and the
-	working tree are ignored; useful when the inode change time
-	is regularly modified by something outside Git (file system
-	crawlers and some backup systems).
-	See linkgit:git-update-index[1]. True by default.
-
-core.splitIndex::
-	If true, the split-index feature of the index will be used.
-	See linkgit:git-update-index[1]. False by default.
-
-core.untrackedCache::
-	Determines what to do about the untracked cache feature of the
-	index. It will be kept, if this variable is unset or set to
-	`keep`. It will automatically be added if set to `true`. And
-	it will automatically be removed, if set to `false`. Before
-	setting it to `true`, you should check that mtime is working
-	properly on your system.
-	See linkgit:git-update-index[1]. `keep` by default.
-
-core.checkStat::
-	Determines which stat fields to match between the index
-	and work tree. The user can set this to 'default' or
-	'minimal'. Default (or explicitly 'default'), is to check
-	all fields, including the sub-second part of mtime and ctime.
-
-core.quotePath::
-	Commands that output paths (e.g. 'ls-files', 'diff'), will
-	quote "unusual" characters in the pathname by enclosing the
-	pathname in double-quotes and escaping those characters with
-	backslashes in the same way C escapes control characters (e.g.
-	`\t` for TAB, `\n` for LF, `\\` for backslash) or bytes with
-	values larger than 0x80 (e.g. octal `\302\265` for "micro" in
-	UTF-8).  If this variable is set to false, bytes higher than
-	0x80 are not considered "unusual" any more. Double-quotes,
-	backslash and control characters are always escaped regardless
-	of the setting of this variable.  A simple space character is
-	not considered "unusual".  Many commands can output pathnames
-	completely verbatim using the `-z` option. The default value
-	is true.
-
-core.eol::
-	Sets the line ending type to use in the working directory for
-	files that have the `text` property set when core.autocrlf is false.
-	Alternatives are 'lf', 'crlf' and 'native', which uses the platform's
-	native line ending.  The default value is `native`.  See
-	linkgit:gitattributes[5] for more information on end-of-line
-	conversion.
-
-core.safecrlf::
-	If true, makes Git check if converting `CRLF` is reversible when
-	end-of-line conversion is active.  Git will verify if a command
-	modifies a file in the work tree either directly or indirectly.
-	For example, committing a file followed by checking out the
-	same file should yield the original file in the work tree.  If
-	this is not the case for the current setting of
-	`core.autocrlf`, Git will reject the file.  The variable can
-	be set to "warn", in which case Git will only warn about an
-	irreversible conversion but continue the operation.
-+
-CRLF conversion bears a slight chance of corrupting data.
-When it is enabled, Git will convert CRLF to LF during commit and LF to
-CRLF during checkout.  A file that contains a mixture of LF and
-CRLF before the commit cannot be recreated by Git.  For text
-files this is the right thing to do: it corrects line endings
-such that we have only LF line endings in the repository.
-But for binary files that are accidentally classified as text the
-conversion can corrupt data.
-+
-If you recognize such corruption early you can easily fix it by
-setting the conversion type explicitly in .gitattributes.  Right
-after committing you still have the original file in your work
-tree and this file is not yet corrupted.  You can explicitly tell
-Git that this file is binary and Git will handle the file
-appropriately.
-+
-Unfortunately, the desired effect of cleaning up text files with
-mixed line endings and the undesired effect of corrupting binary
-files cannot be distinguished.  In both cases CRLFs are removed
-in an irreversible way.  For text files this is the right thing
-to do because CRLFs are line endings, while for binary files
-converting CRLFs corrupts data.
-+
-Note, this safety check does not mean that a checkout will generate a
-file identical to the original file for a different setting of
-`core.eol` and `core.autocrlf`, but only for the current one.  For
-example, a text file with `LF` would be accepted with `core.eol=lf`
-and could later be checked out with `core.eol=crlf`, in which case the
-resulting file would contain `CRLF`, although the original file
-contained `LF`.  However, in both work trees the line endings would be
-consistent, that is either all `LF` or all `CRLF`, but never mixed.  A
-file with mixed line endings would be reported by the `core.safecrlf`
-mechanism.
-
-core.autocrlf::
-	Setting this variable to "true" is the same as setting
-	the `text` attribute to "auto" on all files and core.eol to "crlf".
-	Set to true if you want to have `CRLF` line endings in your
-	working directory and the repository has LF line endings.
-	This variable can be set to 'input',
-	in which case no output conversion is performed.
-
-core.checkRoundtripEncoding::
-	A comma and/or whitespace separated list of encodings that Git
-	performs UTF-8 round trip checks on if they are used in an
-	`working-tree-encoding` attribute (see linkgit:gitattributes[5]).
-	The default value is `SHIFT-JIS`.
-
-core.symlinks::
-	If false, symbolic links are checked out as small plain files that
-	contain the link text. linkgit:git-update-index[1] and
-	linkgit:git-add[1] will not change the recorded type to regular
-	file. Useful on filesystems like FAT that do not support
-	symbolic links.
-+
-The default is true, except linkgit:git-clone[1] or linkgit:git-init[1]
-will probe and set core.symlinks false if appropriate when the repository
-is created.
-
-core.gitProxy::
-	A "proxy command" to execute (as 'command host port') instead
-	of establishing direct connection to the remote server when
-	using the Git protocol for fetching. If the variable value is
-	in the "COMMAND for DOMAIN" format, the command is applied only
-	on hostnames ending with the specified domain string. This variable
-	may be set multiple times and is matched in the given order;
-	the first match wins.
-+
-Can be overridden by the `GIT_PROXY_COMMAND` environment variable
-(which always applies universally, without the special "for"
-handling).
-+
-The special string `none` can be used as the proxy command to
-specify that no proxy be used for a given domain pattern.
-This is useful for excluding servers inside a firewall from
-proxy use, while defaulting to a common proxy for external domains.
-
-core.sshCommand::
-	If this variable is set, `git fetch` and `git push` will
-	use the specified command instead of `ssh` when they need to
-	connect to a remote system. The command is in the same form as
-	the `GIT_SSH_COMMAND` environment variable and is overridden
-	when the environment variable is set.
-
-core.ignoreStat::
-	If true, Git will avoid using lstat() calls to detect if files have
-	changed by setting the "assume-unchanged" bit for those tracked files
-	which it has updated identically in both the index and working tree.
-+
-When files are modified outside of Git, the user will need to stage
-the modified files explicitly (e.g. see 'Examples' section in
-linkgit:git-update-index[1]).
-Git will not normally detect changes to those files.
-+
-This is useful on systems where lstat() calls are very slow, such as
-CIFS/Microsoft Windows.
-+
-False by default.
+include::config/add.txt[]
 
-core.preferSymlinkRefs::
-	Instead of the default "symref" format for HEAD
-	and other symbolic reference files, use symbolic links.
-	This is sometimes needed to work with old scripts that
-	expect HEAD to be a symbolic link.
-
-core.bare::
-	If true this repository is assumed to be 'bare' and has no
-	working directory associated with it.  If this is the case a
-	number of commands that require a working directory will be
-	disabled, such as linkgit:git-add[1] or linkgit:git-merge[1].
-+
-This setting is automatically guessed by linkgit:git-clone[1] or
-linkgit:git-init[1] when the repository was created.  By default a
-repository that ends in "/.git" is assumed to be not bare (bare =
-false), while all other repositories are assumed to be bare (bare
-= true).
-
-core.worktree::
-	Set the path to the root of the working tree.
-	If `GIT_COMMON_DIR` environment variable is set, core.worktree
-	is ignored and not used for determining the root of working tree.
-	This can be overridden by the `GIT_WORK_TREE` environment
-	variable and the `--work-tree` command-line option.
-	The value can be an absolute path or relative to the path to
-	the .git directory, which is either specified by --git-dir
-	or GIT_DIR, or automatically discovered.
-	If --git-dir or GIT_DIR is specified but none of
-	--work-tree, GIT_WORK_TREE and core.worktree is specified,
-	the current working directory is regarded as the top level
-	of your working tree.
-+
-Note that this variable is honored even when set in a configuration
-file in a ".git" subdirectory of a directory and its value differs
-from the latter directory (e.g. "/path/to/.git/config" has
-core.worktree set to "/different/path"), which is most likely a
-misconfiguration.  Running Git commands in the "/path/to" directory will
-still use "/different/path" as the root of the work tree and can cause
-confusion unless you know what you are doing (e.g. you are creating a
-read-only snapshot of the same index to a location different from the
-repository's usual working tree).
-
-core.logAllRefUpdates::
-	Enable the reflog. Updates to a ref <ref> is logged to the file
-	"`$GIT_DIR/logs/<ref>`", by appending the new and old
-	SHA-1, the date/time and the reason of the update, but
-	only when the file exists.  If this configuration
-	variable is set to `true`, missing "`$GIT_DIR/logs/<ref>`"
-	file is automatically created for branch heads (i.e. under
-	`refs/heads/`), remote refs (i.e. under `refs/remotes/`),
-	note refs (i.e. under `refs/notes/`), and the symbolic ref `HEAD`.
-	If it is set to `always`, then a missing reflog is automatically
-	created for any ref under `refs/`.
-+
-This information can be used to determine what commit
-was the tip of a branch "2 days ago".
-+
-This value is true by default in a repository that has
-a working directory associated with it, and false by
-default in a bare repository.
-
-core.repositoryFormatVersion::
-	Internal variable identifying the repository format and layout
-	version.
-
-core.sharedRepository::
-	When 'group' (or 'true'), the repository is made shareable between
-	several users in a group (making sure all the files and objects are
-	group-writable). When 'all' (or 'world' or 'everybody'), the
-	repository will be readable by all users, additionally to being
-	group-shareable. When 'umask' (or 'false'), Git will use permissions
-	reported by umask(2). When '0xxx', where '0xxx' is an octal number,
-	files in the repository will have this mode value. '0xxx' will override
-	user's umask value (whereas the other options will only override
-	requested parts of the user's umask value). Examples: '0660' will make
-	the repo read/write-able for the owner and group, but inaccessible to
-	others (equivalent to 'group' unless umask is e.g. '0022'). '0640' is a
-	repository that is group-readable but not group-writable.
-	See linkgit:git-init[1]. False by default.
-
-core.warnAmbiguousRefs::
-	If true, Git will warn you if the ref name you passed it is ambiguous
-	and might match multiple refs in the repository. True by default.
-
-core.compression::
-	An integer -1..9, indicating a default compression level.
-	-1 is the zlib default. 0 means no compression,
-	and 1..9 are various speed/size tradeoffs, 9 being slowest.
-	If set, this provides a default to other compression variables,
-	such as `core.looseCompression` and `pack.compression`.
-
-core.looseCompression::
-	An integer -1..9, indicating the compression level for objects that
-	are not in a pack file. -1 is the zlib default. 0 means no
-	compression, and 1..9 are various speed/size tradeoffs, 9 being
-	slowest.  If not set,  defaults to core.compression.  If that is
-	not set,  defaults to 1 (best speed).
-
-core.packedGitWindowSize::
-	Number of bytes of a pack file to map into memory in a
-	single mapping operation.  Larger window sizes may allow
-	your system to process a smaller number of large pack files
-	more quickly.  Smaller window sizes will negatively affect
-	performance due to increased calls to the operating system's
-	memory manager, but may improve performance when accessing
-	a large number of large pack files.
-+
-Default is 1 MiB if NO_MMAP was set at compile time, otherwise 32
-MiB on 32 bit platforms and 1 GiB on 64 bit platforms.  This should
-be reasonable for all users/operating systems.  You probably do
-not need to adjust this value.
-+
-Common unit suffixes of 'k', 'm', or 'g' are supported.
+include::config/alias.txt[]
 
-core.packedGitLimit::
-	Maximum number of bytes to map simultaneously into memory
-	from pack files.  If Git needs to access more than this many
-	bytes at once to complete an operation it will unmap existing
-	regions to reclaim virtual address space within the process.
-+
-Default is 256 MiB on 32 bit platforms and 32 TiB (effectively
-unlimited) on 64 bit platforms.
-This should be reasonable for all users/operating systems, except on
-the largest projects.  You probably do not need to adjust this value.
-+
-Common unit suffixes of 'k', 'm', or 'g' are supported.
+include::config/am.txt[]
 
-core.deltaBaseCacheLimit::
-	Maximum number of bytes to reserve for caching base objects
-	that may be referenced by multiple deltified objects.  By storing the
-	entire decompressed base objects in a cache Git is able
-	to avoid unpacking and decompressing frequently used base
-	objects multiple times.
-+
-Default is 96 MiB on all platforms.  This should be reasonable
-for all users/operating systems, except on the largest projects.
-You probably do not need to adjust this value.
-+
-Common unit suffixes of 'k', 'm', or 'g' are supported.
+include::config/apply.txt[]
 
-core.bigFileThreshold::
-	Files larger than this size are stored deflated, without
-	attempting delta compression.  Storing large files without
-	delta compression avoids excessive memory usage, at the
-	slight expense of increased disk usage. Additionally files
-	larger than this size are always treated as binary.
-+
-Default is 512 MiB on all platforms.  This should be reasonable
-for most projects as source code and other text files can still
-be delta compressed, but larger binary media files won't be.
-+
-Common unit suffixes of 'k', 'm', or 'g' are supported.
+include::config/blame.txt[]
 
-core.excludesFile::
-	Specifies the pathname to the file that contains patterns to
-	describe paths that are not meant to be tracked, in addition
-	to '.gitignore' (per-directory) and '.git/info/exclude'.
-	Defaults to `$XDG_CONFIG_HOME/git/ignore`.
-	If `$XDG_CONFIG_HOME` is either not set or empty, `$HOME/.config/git/ignore`
-	is used instead. See linkgit:gitignore[5].
-
-core.askPass::
-	Some commands (e.g. svn and http interfaces) that interactively
-	ask for a password can be told to use an external program given
-	via the value of this variable. Can be overridden by the `GIT_ASKPASS`
-	environment variable. If not set, fall back to the value of the
-	`SSH_ASKPASS` environment variable or, failing that, a simple password
-	prompt. The external program shall be given a suitable prompt as
-	command-line argument and write the password on its STDOUT.
-
-core.attributesFile::
-	In addition to '.gitattributes' (per-directory) and
-	'.git/info/attributes', Git looks into this file for attributes
-	(see linkgit:gitattributes[5]). Path expansions are made the same
-	way as for `core.excludesFile`. Its default value is
-	`$XDG_CONFIG_HOME/git/attributes`. If `$XDG_CONFIG_HOME` is either not
-	set or empty, `$HOME/.config/git/attributes` is used instead.
-
-core.hooksPath::
-	By default Git will look for your hooks in the
-	'$GIT_DIR/hooks' directory. Set this to different path,
-	e.g. '/etc/git/hooks', and Git will try to find your hooks in
-	that directory, e.g. '/etc/git/hooks/pre-receive' instead of
-	in '$GIT_DIR/hooks/pre-receive'.
-+
-The path can be either absolute or relative. A relative path is
-taken as relative to the directory where the hooks are run (see
-the "DESCRIPTION" section of linkgit:githooks[5]).
-+
-This configuration variable is useful in cases where you'd like to
-centrally configure your Git hooks instead of configuring them on a
-per-repository basis, or as a more flexible and centralized
-alternative to having an `init.templateDir` where you've changed
-default hooks.
-
-core.editor::
-	Commands such as `commit` and `tag` that let you edit
-	messages by launching an editor use the value of this
-	variable when it is set, and the environment variable
-	`GIT_EDITOR` is not set.  See linkgit:git-var[1].
-
-core.commentChar::
-	Commands such as `commit` and `tag` that let you edit
-	messages consider a line that begins with this character
-	commented, and removes them after the editor returns
-	(default '#').
-+
-If set to "auto", `git-commit` would select a character that is not
-the beginning character of any line in existing commit messages.
+include::config/branch.txt[]
 
-core.filesRefLockTimeout::
-	The length of time, in milliseconds, to retry when trying to
-	lock an individual reference. Value 0 means not to retry at
-	all; -1 means to try indefinitely. Default is 100 (i.e.,
-	retry for 100ms).
-
-core.packedRefsTimeout::
-	The length of time, in milliseconds, to retry when trying to
-	lock the `packed-refs` file. Value 0 means not to retry at
-	all; -1 means to try indefinitely. Default is 1000 (i.e.,
-	retry for 1 second).
-
-sequence.editor::
-	Text editor used by `git rebase -i` for editing the rebase instruction file.
-	The value is meant to be interpreted by the shell when it is used.
-	It can be overridden by the `GIT_SEQUENCE_EDITOR` environment variable.
-	When not configured the default commit message editor is used instead.
-
-core.pager::
-	Text viewer for use by Git commands (e.g., 'less').  The value
-	is meant to be interpreted by the shell.  The order of preference
-	is the `$GIT_PAGER` environment variable, then `core.pager`
-	configuration, then `$PAGER`, and then the default chosen at
-	compile time (usually 'less').
-+
-When the `LESS` environment variable is unset, Git sets it to `FRX`
-(if `LESS` environment variable is set, Git does not change it at
-all).  If you want to selectively override Git's default setting
-for `LESS`, you can set `core.pager` to e.g. `less -S`.  This will
-be passed to the shell by Git, which will translate the final
-command to `LESS=FRX less -S`. The environment does not set the
-`S` option but the command line does, instructing less to truncate
-long lines. Similarly, setting `core.pager` to `less -+F` will
-deactivate the `F` option specified by the environment from the
-command-line, deactivating the "quit if one screen" behavior of
-`less`.  One can specifically activate some flags for particular
-commands: for example, setting `pager.blame` to `less -S` enables
-line truncation only for `git blame`.
-+
-Likewise, when the `LV` environment variable is unset, Git sets it
-to `-c`.  You can override this setting by exporting `LV` with
-another value or setting `core.pager` to `lv +c`.
-
-core.whitespace::
-	A comma separated list of common whitespace problems to
-	notice.  'git diff' will use `color.diff.whitespace` to
-	highlight them, and 'git apply --whitespace=error' will
-	consider them as errors.  You can prefix `-` to disable
-	any of them (e.g. `-trailing-space`):
-+
-* `blank-at-eol` treats trailing whitespaces at the end of the line
-  as an error (enabled by default).
-* `space-before-tab` treats a space character that appears immediately
-  before a tab character in the initial indent part of the line as an
-  error (enabled by default).
-* `indent-with-non-tab` treats a line that is indented with space
-  characters instead of the equivalent tabs as an error (not enabled by
-  default).
-* `tab-in-indent` treats a tab character in the initial indent part of
-  the line as an error (not enabled by default).
-* `blank-at-eof` treats blank lines added at the end of file as an error
-  (enabled by default).
-* `trailing-space` is a short-hand to cover both `blank-at-eol` and
-  `blank-at-eof`.
-* `cr-at-eol` treats a carriage-return at the end of line as
-  part of the line terminator, i.e. with it, `trailing-space`
-  does not trigger if the character before such a carriage-return
-  is not a whitespace (not enabled by default).
-* `tabwidth=<n>` tells how many character positions a tab occupies; this
-  is relevant for `indent-with-non-tab` and when Git fixes `tab-in-indent`
-  errors. The default tab width is 8. Allowed values are 1 to 63.
+include::config/browser.txt[]
 
-core.fsyncObjectFiles::
-	This boolean will enable 'fsync()' when writing object files.
-+
-This is a total waste of time and effort on a filesystem that orders
-data writes properly, but can be useful for filesystems that do not use
-journalling (traditional UNIX filesystems) or that only journal metadata
-and not file contents (OS X's HFS+, or Linux ext3 with "data=writeback").
+include::config/checkout.txt[]
 
-core.preloadIndex::
-	Enable parallel index preload for operations like 'git diff'
-+
-This can speed up operations like 'git diff' and 'git status' especially
-on filesystems like NFS that have weak caching semantics and thus
-relatively high IO latencies.  When enabled, Git will do the
-index comparison to the filesystem data in parallel, allowing
-overlapping IO's.  Defaults to true.
-
-core.createObject::
-	You can set this to 'link', in which case a hardlink followed by
-	a delete of the source are used to make sure that object creation
-	will not overwrite existing objects.
-+
-On some file system/operating system combinations, this is unreliable.
-Set this config setting to 'rename' there; However, This will remove the
-check that makes sure that existing object files will not get overwritten.
-
-core.notesRef::
-	When showing commit messages, also show notes which are stored in
-	the given ref.  The ref must be fully qualified.  If the given
-	ref does not exist, it is not an error but means that no
-	notes should be printed.
-+
-This setting defaults to "refs/notes/commits", and it can be overridden by
-the `GIT_NOTES_REF` environment variable.  See linkgit:git-notes[1].
+include::config/clean.txt[]
 
-core.commitGraph::
-	Enable git commit graph feature. Allows reading from the
-	commit-graph file.
-
-core.sparseCheckout::
-	Enable "sparse checkout" feature. See section "Sparse checkout" in
-	linkgit:git-read-tree[1] for more information.
-
-core.abbrev::
-	Set the length object names are abbreviated to.  If
-	unspecified or set to "auto", an appropriate value is
-	computed based on the approximate number of packed objects
-	in your repository, which hopefully is enough for
-	abbreviated object names to stay unique for some time.
-	The minimum length is 4.
-
-add.ignoreErrors::
-add.ignore-errors (deprecated)::
-	Tells 'git add' to continue adding files when some files cannot be
-	added due to indexing errors. Equivalent to the `--ignore-errors`
-	option of linkgit:git-add[1].  `add.ignore-errors` is deprecated,
-	as it does not follow the usual naming convention for configuration
-	variables.
-
-alias.*::
-	Command aliases for the linkgit:git[1] command wrapper - e.g.
-	after defining "alias.last = cat-file commit HEAD", the invocation
-	"git last" is equivalent to "git cat-file commit HEAD". To avoid
-	confusion and troubles with script usage, aliases that
-	hide existing Git commands are ignored. Arguments are split by
-	spaces, the usual shell quoting and escaping is supported.
-	A quote pair or a backslash can be used to quote them.
-+
-If the alias expansion is prefixed with an exclamation point,
-it will be treated as a shell command.  For example, defining
-"alias.new = !gitk --all --not ORIG_HEAD", the invocation
-"git new" is equivalent to running the shell command
-"gitk --all --not ORIG_HEAD".  Note that shell commands will be
-executed from the top-level directory of a repository, which may
-not necessarily be the current directory.
-`GIT_PREFIX` is set as returned by running 'git rev-parse --show-prefix'
-from the original current directory. See linkgit:git-rev-parse[1].
-
-am.keepcr::
-	If true, git-am will call git-mailsplit for patches in mbox format
-	with parameter `--keep-cr`. In this case git-mailsplit will
-	not remove `\r` from lines ending with `\r\n`. Can be overridden
-	by giving `--no-keep-cr` from the command line.
-	See linkgit:git-am[1], linkgit:git-mailsplit[1].
-
-am.threeWay::
-	By default, `git am` will fail if the patch does not apply cleanly. When
-	set to true, this setting tells `git am` to fall back on 3-way merge if
-	the patch records the identity of blobs it is supposed to apply to and
-	we have those blobs available locally (equivalent to giving the `--3way`
-	option from the command line). Defaults to `false`.
-	See linkgit:git-am[1].
-
-apply.ignoreWhitespace::
-	When set to 'change', tells 'git apply' to ignore changes in
-	whitespace, in the same way as the `--ignore-space-change`
-	option.
-	When set to one of: no, none, never, false tells 'git apply' to
-	respect all whitespace differences.
-	See linkgit:git-apply[1].
-
-apply.whitespace::
-	Tells 'git apply' how to handle whitespaces, in the same way
-	as the `--whitespace` option. See linkgit:git-apply[1].
-
-blame.showRoot::
-	Do not treat root commits as boundaries in linkgit:git-blame[1].
-	This option defaults to false.
-
-blame.blankBoundary::
-	Show blank commit object name for boundary commits in
-	linkgit:git-blame[1]. This option defaults to false.
-
-blame.showEmail::
-	Show the author email instead of author name in linkgit:git-blame[1].
-	This option defaults to false.
-
-blame.date::
-	Specifies the format used to output dates in linkgit:git-blame[1].
-	If unset the iso format is used. For supported values,
-	see the discussion of the `--date` option at linkgit:git-log[1].
-
-branch.autoSetupMerge::
-	Tells 'git branch' and 'git checkout' to set up new branches
-	so that linkgit:git-pull[1] will appropriately merge from the
-	starting point branch. Note that even if this option is not set,
-	this behavior can be chosen per-branch using the `--track`
-	and `--no-track` options. The valid settings are: `false` -- no
-	automatic setup is done; `true` -- automatic setup is done when the
-	starting point is a remote-tracking branch; `always` --
-	automatic setup is done when the starting point is either a
-	local branch or remote-tracking
-	branch. This option defaults to true.
-
-branch.autoSetupRebase::
-	When a new branch is created with 'git branch' or 'git checkout'
-	that tracks another branch, this variable tells Git to set
-	up pull to rebase instead of merge (see "branch.<name>.rebase").
-	When `never`, rebase is never automatically set to true.
-	When `local`, rebase is set to true for tracked branches of
-	other local branches.
-	When `remote`, rebase is set to true for tracked branches of
-	remote-tracking branches.
-	When `always`, rebase will be set to true for all tracking
-	branches.
-	See "branch.autoSetupMerge" for details on how to set up a
-	branch to track another branch.
-	This option defaults to never.
-
-branch.<name>.remote::
-	When on branch <name>, it tells 'git fetch' and 'git push'
-	which remote to fetch from/push to.  The remote to push to
-	may be overridden with `remote.pushDefault` (for all branches).
-	The remote to push to, for the current branch, may be further
-	overridden by `branch.<name>.pushRemote`.  If no remote is
-	configured, or if you are not on any branch, it defaults to
-	`origin` for fetching and `remote.pushDefault` for pushing.
-	Additionally, `.` (a period) is the current local repository
-	(a dot-repository), see `branch.<name>.merge`'s final note below.
-
-branch.<name>.pushRemote::
-	When on branch <name>, it overrides `branch.<name>.remote` for
-	pushing.  It also overrides `remote.pushDefault` for pushing
-	from branch <name>.  When you pull from one place (e.g. your
-	upstream) and push to another place (e.g. your own publishing
-	repository), you would want to set `remote.pushDefault` to
-	specify the remote to push to for all branches, and use this
-	option to override it for a specific branch.
-
-branch.<name>.merge::
-	Defines, together with branch.<name>.remote, the upstream branch
-	for the given branch. It tells 'git fetch'/'git pull'/'git rebase' which
-	branch to merge and can also affect 'git push' (see push.default).
-	When in branch <name>, it tells 'git fetch' the default
-	refspec to be marked for merging in FETCH_HEAD. The value is
-	handled like the remote part of a refspec, and must match a
-	ref which is fetched from the remote given by
-	"branch.<name>.remote".
-	The merge information is used by 'git pull' (which at first calls
-	'git fetch') to lookup the default branch for merging. Without
-	this option, 'git pull' defaults to merge the first refspec fetched.
-	Specify multiple values to get an octopus merge.
-	If you wish to setup 'git pull' so that it merges into <name> from
-	another branch in the local repository, you can point
-	branch.<name>.merge to the desired branch, and use the relative path
-	setting `.` (a period) for branch.<name>.remote.
-
-branch.<name>.mergeOptions::
-	Sets default options for merging into branch <name>. The syntax and
-	supported options are the same as those of linkgit:git-merge[1], but
-	option values containing whitespace characters are currently not
-	supported.
-
-branch.<name>.rebase::
-	When true, rebase the branch <name> on top of the fetched branch,
-	instead of merging the default branch from the default remote when
-	"git pull" is run. See "pull.rebase" for doing this in a non
-	branch-specific manner.
-+
-When `merges`, pass the `--rebase-merges` option to 'git rebase'
-so that the local merge commits are included in the rebase (see
-linkgit:git-rebase[1] for details).
-+
-When preserve, also pass `--preserve-merges` along to 'git rebase'
-so that locally committed merge commits will not be flattened
-by running 'git pull'.
-+
-When the value is `interactive`, the rebase is run in interactive mode.
-+
-*NOTE*: this is a possibly dangerous operation; do *not* use
-it unless you understand the implications (see linkgit:git-rebase[1]
-for details).
-
-branch.<name>.description::
-	Branch description, can be edited with
-	`git branch --edit-description`. Branch description is
-	automatically added in the format-patch cover letter or
-	request-pull summary.
-
-browser.<tool>.cmd::
-	Specify the command to invoke the specified browser. The
-	specified command is evaluated in shell with the URLs passed
-	as arguments. (See linkgit:git-web{litdd}browse[1].)
-
-browser.<tool>.path::
-	Override the path for the given tool that may be used to
-	browse HTML help (see `-w` option in linkgit:git-help[1]) or a
-	working repository in gitweb (see linkgit:git-instaweb[1]).
-
-clean.requireForce::
-	A boolean to make git-clean do nothing unless given -f,
-	-i or -n.   Defaults to true.
-
-color.advice::
-	A boolean to enable/disable color in hints (e.g. when a push
-	failed, see `advice.*` for a list).  May be set to `always`,
-	`false` (or `never`) or `auto` (or `true`), in which case colors
-	are used only when the error output goes to a terminal. If
-	unset, then the value of `color.ui` is used (`auto` by default).
-
-color.advice.hint::
-	Use customized color for hints.
-
-color.branch::
-	A boolean to enable/disable color in the output of
-	linkgit:git-branch[1]. May be set to `always`,
-	`false` (or `never`) or `auto` (or `true`), in which case colors are used
-	only when the output is to a terminal. If unset, then the
-	value of `color.ui` is used (`auto` by default).
-
-color.branch.<slot>::
-	Use customized color for branch coloration. `<slot>` is one of
-	`current` (the current branch), `local` (a local branch),
-	`remote` (a remote-tracking branch in refs/remotes/),
-	`upstream` (upstream tracking branch), `plain` (other
-	refs).
-
-color.diff::
-	Whether to use ANSI escape sequences to add color to patches.
-	If this is set to `always`, linkgit:git-diff[1],
-	linkgit:git-log[1], and linkgit:git-show[1] will use color
-	for all patches.  If it is set to `true` or `auto`, those
-	commands will only use color when output is to the terminal.
-	If unset, then the value of `color.ui` is used (`auto` by
-	default).
-+
-This does not affect linkgit:git-format-patch[1] or the
-'git-diff-{asterisk}' plumbing commands.  Can be overridden on the
-command line with the `--color[=<when>]` option.
-
-diff.colorMoved::
-	If set to either a valid `<mode>` or a true value, moved lines
-	in a diff are colored differently, for details of valid modes
-	see '--color-moved' in linkgit:git-diff[1]. If simply set to
-	true the default color mode will be used. When set to false,
-	moved lines are not colored.
-
-color.diff.<slot>::
-	Use customized color for diff colorization.  `<slot>` specifies
-	which part of the patch to use the specified color, and is one
-	of `context` (context text - `plain` is a historical synonym),
-	`meta` (metainformation), `frag`
-	(hunk header), 'func' (function in hunk header), `old` (removed lines),
-	`new` (added lines), `commit` (commit headers), `whitespace`
-	(highlighting whitespace errors), `oldMoved` (deleted lines),
-	`newMoved` (added lines), `oldMovedDimmed`, `oldMovedAlternative`,
-	`oldMovedAlternativeDimmed`, `newMovedDimmed`, `newMovedAlternative`
-	and `newMovedAlternativeDimmed` (See the '<mode>'
-	setting of '--color-moved' in linkgit:git-diff[1] for details).
-
-color.decorate.<slot>::
-	Use customized color for 'git log --decorate' output.  `<slot>` is one
-	of `branch`, `remoteBranch`, `tag`, `stash` or `HEAD` for local
-	branches, remote-tracking branches, tags, stash and HEAD, respectively.
-
-color.grep::
-	When set to `always`, always highlight matches.  When `false` (or
-	`never`), never.  When set to `true` or `auto`, use color only
-	when the output is written to the terminal.  If unset, then the
-	value of `color.ui` is used (`auto` by default).
-
-color.grep.<slot>::
-	Use customized color for grep colorization.  `<slot>` specifies which
-	part of the line to use the specified color, and is one of
-+
---
-`context`;;
-	non-matching text in context lines (when using `-A`, `-B`, or `-C`)
-`filename`;;
-	filename prefix (when not using `-h`)
-`function`;;
-	function name lines (when using `-p`)
-`linenumber`;;
-	line number prefix (when using `-n`)
-`match`;;
-	matching text (same as setting `matchContext` and `matchSelected`)
-`matchContext`;;
-	matching text in context lines
-`matchSelected`;;
-	matching text in selected lines
-`selected`;;
-	non-matching text in selected lines
-`separator`;;
-	separators between fields on a line (`:`, `-`, and `=`)
-	and between hunks (`--`)
---
-
-color.interactive::
-	When set to `always`, always use colors for interactive prompts
-	and displays (such as those used by "git-add --interactive" and
-	"git-clean --interactive"). When false (or `never`), never.
-	When set to `true` or `auto`, use colors only when the output is
-	to the terminal. If unset, then the value of `color.ui` is
-	used (`auto` by default).
-
-color.interactive.<slot>::
-	Use customized color for 'git add --interactive' and 'git clean
-	--interactive' output. `<slot>` may be `prompt`, `header`, `help`
-	or `error`, for four distinct types of normal output from
-	interactive commands.
-
-color.pager::
-	A boolean to enable/disable colored output when the pager is in
-	use (default is true).
-
-color.push::
-	A boolean to enable/disable color in push errors. May be set to
-	`always`, `false` (or `never`) or `auto` (or `true`), in which
-	case colors are used only when the error output goes to a terminal.
-	If unset, then the value of `color.ui` is used (`auto` by default).
-
-color.push.error::
-	Use customized color for push errors.
-
-color.showBranch::
-	A boolean to enable/disable color in the output of
-	linkgit:git-show-branch[1]. May be set to `always`,
-	`false` (or `never`) or `auto` (or `true`), in which case colors are used
-	only when the output is to a terminal. If unset, then the
-	value of `color.ui` is used (`auto` by default).
-
-color.status::
-	A boolean to enable/disable color in the output of
-	linkgit:git-status[1]. May be set to `always`,
-	`false` (or `never`) or `auto` (or `true`), in which case colors are used
-	only when the output is to a terminal. If unset, then the
-	value of `color.ui` is used (`auto` by default).
-
-color.status.<slot>::
-	Use customized color for status colorization. `<slot>` is
-	one of `header` (the header text of the status message),
-	`added` or `updated` (files which are added but not committed),
-	`changed` (files which are changed but not added in the index),
-	`untracked` (files which are not tracked by Git),
-	`branch` (the current branch),
-	`nobranch` (the color the 'no branch' warning is shown in, defaulting
-	to red),
-	`localBranch` or `remoteBranch` (the local and remote branch names,
-	respectively, when branch and tracking information is displayed in the
-	status short-format), or
-	`unmerged` (files which have unmerged changes).
-
-color.blame.repeatedLines::
-	Use the customized color for the part of git-blame output that
-	is repeated meta information per line (such as commit id,
-	author name, date and timezone). Defaults to cyan.
-
-color.blame.highlightRecent::
-	This can be used to color the metadata of a blame line depending
-	on age of the line.
-+
-This setting should be set to a comma-separated list of color and date settings,
-starting and ending with a color, the dates should be set from oldest to newest.
-The metadata will be colored given the colors if the the line was introduced
-before the given timestamp, overwriting older timestamped colors.
-+
-Instead of an absolute timestamp relative timestamps work as well, e.g.
-2.weeks.ago is valid to address anything older than 2 weeks.
-+
-It defaults to 'blue,12 month ago,white,1 month ago,red', which colors
-everything older than one year blue, recent changes between one month and
-one year old are kept white, and lines introduced within the last month are
-colored red.
-
-blame.coloring::
-	This determines the coloring scheme to be applied to blame
-	output. It can be 'repeatedLines', 'highlightRecent',
-	or 'none' which is the default.
-
-color.transport::
-	A boolean to enable/disable color when pushes are rejected. May be
-	set to `always`, `false` (or `never`) or `auto` (or `true`), in which
-	case colors are used only when the error output goes to a terminal.
-	If unset, then the value of `color.ui` is used (`auto` by default).
-
-color.transport.rejected::
-	Use customized color when a push was rejected.
-
-color.ui::
-	This variable determines the default value for variables such
-	as `color.diff` and `color.grep` that control the use of color
-	per command family. Its scope will expand as more commands learn
-	configuration to set a default for the `--color` option.  Set it
-	to `false` or `never` if you prefer Git commands not to use
-	color unless enabled explicitly with some other configuration
-	or the `--color` option. Set it to `always` if you want all
-	output not intended for machine consumption to use color, to
-	`true` or `auto` (this is the default since Git 1.8.4) if you
-	want such output to use color when written to the terminal.
-
-column.ui::
-	Specify whether supported commands should output in columns.
-	This variable consists of a list of tokens separated by spaces
-	or commas:
-+
-These options control when the feature should be enabled
-(defaults to 'never'):
-+
---
-`always`;;
-	always show in columns
-`never`;;
-	never show in columns
-`auto`;;
-	show in columns if the output is to the terminal
---
-+
-These options control layout (defaults to 'column').  Setting any
-of these implies 'always' if none of 'always', 'never', or 'auto' are
-specified.
-+
---
-`column`;;
-	fill columns before rows
-`row`;;
-	fill rows before columns
-`plain`;;
-	show in one column
---
-+
-Finally, these options can be combined with a layout option (defaults
-to 'nodense'):
-+
---
-`dense`;;
-	make unequal size columns to utilize more space
-`nodense`;;
-	make equal size columns
---
-
-column.branch::
-	Specify whether to output branch listing in `git branch` in columns.
-	See `column.ui` for details.
-
-column.clean::
-	Specify the layout when list items in `git clean -i`, which always
-	shows files and directories in columns. See `column.ui` for details.
-
-column.status::
-	Specify whether to output untracked files in `git status` in columns.
-	See `column.ui` for details.
-
-column.tag::
-	Specify whether to output tag listing in `git tag` in columns.
-	See `column.ui` for details.
-
-commit.cleanup::
-	This setting overrides the default of the `--cleanup` option in
-	`git commit`. See linkgit:git-commit[1] for details. Changing the
-	default can be useful when you always want to keep lines that begin
-	with comment character `#` in your log message, in which case you
-	would do `git config commit.cleanup whitespace` (note that you will
-	have to remove the help lines that begin with `#` in the commit log
-	template yourself, if you do this).
-
-commit.gpgSign::
-
-	A boolean to specify whether all commits should be GPG signed.
-	Use of this option when doing operations such as rebase can
-	result in a large number of commits being signed. It may be
-	convenient to use an agent to avoid typing your GPG passphrase
-	several times.
-
-commit.status::
-	A boolean to enable/disable inclusion of status information in the
-	commit message template when using an editor to prepare the commit
-	message.  Defaults to true.
-
-commit.template::
-	Specify the pathname of a file to use as the template for
-	new commit messages.
-
-commit.verbose::
-	A boolean or int to specify the level of verbose with `git commit`.
-	See linkgit:git-commit[1].
-
-credential.helper::
-	Specify an external helper to be called when a username or
-	password credential is needed; the helper may consult external
-	storage to avoid prompting the user for the credentials. Note
-	that multiple helpers may be defined. See linkgit:gitcredentials[7]
-	for details.
-
-credential.useHttpPath::
-	When acquiring credentials, consider the "path" component of an http
-	or https URL to be important. Defaults to false. See
-	linkgit:gitcredentials[7] for more information.
-
-credential.username::
-	If no username is set for a network authentication, use this username
-	by default. See credential.<context>.* below, and
-	linkgit:gitcredentials[7].
-
-credential.<url>.*::
-	Any of the credential.* options above can be applied selectively to
-	some credentials. For example "credential.https://example.com.username"
-	would set the default username only for https connections to
-	example.com. See linkgit:gitcredentials[7] for details on how URLs are
-	matched.
-
-credentialCache.ignoreSIGHUP::
-	Tell git-credential-cache--daemon to ignore SIGHUP, instead of quitting.
-
-completion.commands::
-	This is only used by git-completion.bash to add or remove
-	commands from the list of completed commands. Normally only
-	porcelain commands and a few select others are completed. You
-	can add more commands, separated by space, in this
-	variable. Prefixing the command with '-' will remove it from
-	the existing list.
-
-include::diff-config.txt[]
-
-difftool.<tool>.path::
-	Override the path for the given tool.  This is useful in case
-	your tool is not in the PATH.
-
-difftool.<tool>.cmd::
-	Specify the command to invoke the specified diff tool.
-	The specified command is evaluated in shell with the following
-	variables available:  'LOCAL' is set to the name of the temporary
-	file containing the contents of the diff pre-image and 'REMOTE'
-	is set to the name of the temporary file containing the contents
-	of the diff post-image.
-
-difftool.prompt::
-	Prompt before each invocation of the diff tool.
-
-fastimport.unpackLimit::
-	If the number of objects imported by linkgit:git-fast-import[1]
-	is below this limit, then the objects will be unpacked into
-	loose object files.  However if the number of imported objects
-	equals or exceeds this limit then the pack will be stored as a
-	pack.  Storing the pack from a fast-import can make the import
-	operation complete faster, especially on slow filesystems.  If
-	not set, the value of `transfer.unpackLimit` is used instead.
-
-fetch.recurseSubmodules::
-	This option can be either set to a boolean value or to 'on-demand'.
-	Setting it to a boolean changes the behavior of fetch and pull to
-	unconditionally recurse into submodules when set to true or to not
-	recurse at all when set to false. When set to 'on-demand' (the default
-	value), fetch and pull will only recurse into a populated submodule
-	when its superproject retrieves a commit that updates the submodule's
-	reference.
-
-fetch.fsckObjects::
-	If it is set to true, git-fetch-pack will check all fetched
-	objects. It will abort in the case of a malformed object or a
-	broken link. The result of an abort are only dangling objects.
-	Defaults to false. If not set, the value of `transfer.fsckObjects`
-	is used instead.
-
-fetch.unpackLimit::
-	If the number of objects fetched over the Git native
-	transfer is below this
-	limit, then the objects will be unpacked into loose object
-	files. However if the number of received objects equals or
-	exceeds this limit then the received pack will be stored as
-	a pack, after adding any missing delta bases.  Storing the
-	pack from a push can make the push operation complete faster,
-	especially on slow filesystems.  If not set, the value of
-	`transfer.unpackLimit` is used instead.
-
-fetch.prune::
-	If true, fetch will automatically behave as if the `--prune`
-	option was given on the command line.  See also `remote.<name>.prune`
-	and the PRUNING section of linkgit:git-fetch[1].
-
-fetch.pruneTags::
-	If true, fetch will automatically behave as if the
-	`refs/tags/*:refs/tags/*` refspec was provided when pruning,
-	if not set already. This allows for setting both this option
-	and `fetch.prune` to maintain a 1=1 mapping to upstream
-	refs. See also `remote.<name>.pruneTags` and the PRUNING
-	section of linkgit:git-fetch[1].
-
-fetch.output::
-	Control how ref update status is printed. Valid values are
-	`full` and `compact`. Default value is `full`. See section
-	OUTPUT in linkgit:git-fetch[1] for detail.
-
-format.attach::
-	Enable multipart/mixed attachments as the default for
-	'format-patch'.  The value can also be a double quoted string
-	which will enable attachments as the default and set the
-	value as the boundary.  See the --attach option in
-	linkgit:git-format-patch[1].
-
-format.from::
-	Provides the default value for the `--from` option to format-patch.
-	Accepts a boolean value, or a name and email address.  If false,
-	format-patch defaults to `--no-from`, using commit authors directly in
-	the "From:" field of patch mails.  If true, format-patch defaults to
-	`--from`, using your committer identity in the "From:" field of patch
-	mails and including a "From:" field in the body of the patch mail if
-	different.  If set to a non-boolean value, format-patch uses that
-	value instead of your committer identity.  Defaults to false.
-
-format.numbered::
-	A boolean which can enable or disable sequence numbers in patch
-	subjects.  It defaults to "auto" which enables it only if there
-	is more than one patch.  It can be enabled or disabled for all
-	messages by setting it to "true" or "false".  See --numbered
-	option in linkgit:git-format-patch[1].
-
-format.headers::
-	Additional email headers to include in a patch to be submitted
-	by mail.  See linkgit:git-format-patch[1].
-
-format.to::
-format.cc::
-	Additional recipients to include in a patch to be submitted
-	by mail.  See the --to and --cc options in
-	linkgit:git-format-patch[1].
-
-format.subjectPrefix::
-	The default for format-patch is to output files with the '[PATCH]'
-	subject prefix. Use this variable to change that prefix.
-
-format.signature::
-	The default for format-patch is to output a signature containing
-	the Git version number. Use this variable to change that default.
-	Set this variable to the empty string ("") to suppress
-	signature generation.
-
-format.signatureFile::
-	Works just like format.signature except the contents of the
-	file specified by this variable will be used as the signature.
-
-format.suffix::
-	The default for format-patch is to output files with the suffix
-	`.patch`. Use this variable to change that suffix (make sure to
-	include the dot if you want it).
-
-format.pretty::
-	The default pretty format for log/show/whatchanged command,
-	See linkgit:git-log[1], linkgit:git-show[1],
-	linkgit:git-whatchanged[1].
-
-format.thread::
-	The default threading style for 'git format-patch'.  Can be
-	a boolean value, or `shallow` or `deep`.  `shallow` threading
-	makes every mail a reply to the head of the series,
-	where the head is chosen from the cover letter, the
-	`--in-reply-to`, and the first patch mail, in this order.
-	`deep` threading makes every mail a reply to the previous one.
-	A true boolean value is the same as `shallow`, and a false
-	value disables threading.
-
-format.signOff::
-	A boolean value which lets you enable the `-s/--signoff` option of
-	format-patch by default. *Note:* Adding the Signed-off-by: line to a
-	patch should be a conscious act and means that you certify you have
-	the rights to submit this work under the same open source license.
-	Please see the 'SubmittingPatches' document for further discussion.
-
-format.coverLetter::
-	A boolean that controls whether to generate a cover-letter when
-	format-patch is invoked, but in addition can be set to "auto", to
-	generate a cover-letter only when there's more than one patch.
-
-format.outputDirectory::
-	Set a custom directory to store the resulting files instead of the
-	current working directory.
-
-format.useAutoBase::
-	A boolean value which lets you enable the `--base=auto` option of
-	format-patch by default.
-
-filter.<driver>.clean::
-	The command which is used to convert the content of a worktree
-	file to a blob upon checkin.  See linkgit:gitattributes[5] for
-	details.
-
-filter.<driver>.smudge::
-	The command which is used to convert the content of a blob
-	object to a worktree file upon checkout.  See
-	linkgit:gitattributes[5] for details.
-
-fsck.<msg-id>::
-	Allows overriding the message type (error, warn or ignore) of a
-	specific message ID such as `missingEmail`.
-+
-For convenience, fsck prefixes the error/warning with the message ID,
-e.g.  "missingEmail: invalid author/committer line - missing email" means
-that setting `fsck.missingEmail = ignore` will hide that issue.
-+
-This feature is intended to support working with legacy repositories
-which cannot be repaired without disruptive changes.
+include::config/color.txt[]
 
-fsck.skipList::
-	The path to a sorted list of object names (i.e. one SHA-1 per
-	line) that are known to be broken in a non-fatal way and should
-	be ignored. This feature is useful when an established project
-	should be accepted despite early commits containing errors that
-	can be safely ignored such as invalid committer email addresses.
-	Note: corrupt objects cannot be skipped with this setting.
-
-gc.aggressiveDepth::
-	The depth parameter used in the delta compression
-	algorithm used by 'git gc --aggressive'.  This defaults
-	to 50.
-
-gc.aggressiveWindow::
-	The window size parameter used in the delta compression
-	algorithm used by 'git gc --aggressive'.  This defaults
-	to 250.
-
-gc.auto::
-	When there are approximately more than this many loose
-	objects in the repository, `git gc --auto` will pack them.
-	Some Porcelain commands use this command to perform a
-	light-weight garbage collection from time to time.  The
-	default value is 6700.  Setting this to 0 disables it.
-
-gc.autoPackLimit::
-	When there are more than this many packs that are not
-	marked with `*.keep` file in the repository, `git gc
-	--auto` consolidates them into one larger pack.  The
-	default	value is 50.  Setting this to 0 disables it.
-
-gc.autoDetach::
-	Make `git gc --auto` return immediately and run in background
-	if the system supports it. Default is true.
-
-gc.bigPackThreshold::
-	If non-zero, all packs larger than this limit are kept when
-	`git gc` is run. This is very similar to `--keep-base-pack`
-	except that all packs that meet the threshold are kept, not
-	just the base pack. Defaults to zero. Common unit suffixes of
-	'k', 'm', or 'g' are supported.
-+
-Note that if the number of kept packs is more than gc.autoPackLimit,
-this configuration variable is ignored, all packs except the base pack
-will be repacked. After this the number of packs should go below
-gc.autoPackLimit and gc.bigPackThreshold should be respected again.
-
-gc.logExpiry::
-	If the file gc.log exists, then `git gc --auto` won't run
-	unless that file is more than 'gc.logExpiry' old.  Default is
-	"1.day".  See `gc.pruneExpire` for more ways to specify its
-	value.
-
-gc.packRefs::
-	Running `git pack-refs` in a repository renders it
-	unclonable by Git versions prior to 1.5.1.2 over dumb
-	transports such as HTTP.  This variable determines whether
-	'git gc' runs `git pack-refs`. This can be set to `notbare`
-	to enable it within all non-bare repos or it can be set to a
-	boolean value.  The default is `true`.
-
-gc.pruneExpire::
-	When 'git gc' is run, it will call 'prune --expire 2.weeks.ago'.
-	Override the grace period with this config variable.  The value
-	"now" may be used to disable this grace period and always prune
-	unreachable objects immediately, or "never" may be used to
-	suppress pruning.  This feature helps prevent corruption when
-	'git gc' runs concurrently with another process writing to the
-	repository; see the "NOTES" section of linkgit:git-gc[1].
-
-gc.worktreePruneExpire::
-	When 'git gc' is run, it calls
-	'git worktree prune --expire 3.months.ago'.
-	This config variable can be used to set a different grace
-	period. The value "now" may be used to disable the grace
-	period and prune `$GIT_DIR/worktrees` immediately, or "never"
-	may be used to suppress pruning.
-
-gc.reflogExpire::
-gc.<pattern>.reflogExpire::
-	'git reflog expire' removes reflog entries older than
-	this time; defaults to 90 days. The value "now" expires all
-	entries immediately, and "never" suppresses expiration
-	altogether. With "<pattern>" (e.g.
-	"refs/stash") in the middle the setting applies only to
-	the refs that match the <pattern>.
-
-gc.reflogExpireUnreachable::
-gc.<pattern>.reflogExpireUnreachable::
-	'git reflog expire' removes reflog entries older than
-	this time and are not reachable from the current tip;
-	defaults to 30 days. The value "now" expires all entries
-	immediately, and "never" suppresses expiration altogether.
-	With "<pattern>" (e.g. "refs/stash")
-	in the middle, the setting applies only to the refs that
-	match the <pattern>.
-
-gc.rerereResolved::
-	Records of conflicted merge you resolved earlier are
-	kept for this many days when 'git rerere gc' is run.
-	You can also use more human-readable "1.month.ago", etc.
-	The default is 60 days.  See linkgit:git-rerere[1].
-
-gc.rerereUnresolved::
-	Records of conflicted merge you have not resolved are
-	kept for this many days when 'git rerere gc' is run.
-	You can also use more human-readable "1.month.ago", etc.
-	The default is 15 days.  See linkgit:git-rerere[1].
-
-gitcvs.commitMsgAnnotation::
-	Append this string to each commit message. Set to empty string
-	to disable this feature. Defaults to "via git-CVS emulator".
-
-gitcvs.enabled::
-	Whether the CVS server interface is enabled for this repository.
-	See linkgit:git-cvsserver[1].
-
-gitcvs.logFile::
-	Path to a log file where the CVS server interface well... logs
-	various stuff. See linkgit:git-cvsserver[1].
-
-gitcvs.usecrlfattr::
-	If true, the server will look up the end-of-line conversion
-	attributes for files to determine the `-k` modes to use. If
-	the attributes force Git to treat a file as text,
-	the `-k` mode will be left blank so CVS clients will
-	treat it as text. If they suppress text conversion, the file
-	will be set with '-kb' mode, which suppresses any newline munging
-	the client might otherwise do. If the attributes do not allow
-	the file type to be determined, then `gitcvs.allBinary` is
-	used. See linkgit:gitattributes[5].
-
-gitcvs.allBinary::
-	This is used if `gitcvs.usecrlfattr` does not resolve
-	the correct '-kb' mode to use. If true, all
-	unresolved files are sent to the client in
-	mode '-kb'. This causes the client to treat them
-	as binary files, which suppresses any newline munging it
-	otherwise might do. Alternatively, if it is set to "guess",
-	then the contents of the file are examined to decide if
-	it is binary, similar to `core.autocrlf`.
-
-gitcvs.dbName::
-	Database used by git-cvsserver to cache revision information
-	derived from the Git repository. The exact meaning depends on the
-	used database driver, for SQLite (which is the default driver) this
-	is a filename. Supports variable substitution (see
-	linkgit:git-cvsserver[1] for details). May not contain semicolons (`;`).
-	Default: '%Ggitcvs.%m.sqlite'
-
-gitcvs.dbDriver::
-	Used Perl DBI driver. You can specify any available driver
-	for this here, but it might not work. git-cvsserver is tested
-	with 'DBD::SQLite', reported to work with 'DBD::Pg', and
-	reported *not* to work with 'DBD::mysql'. Experimental feature.
-	May not contain double colons (`:`). Default: 'SQLite'.
-	See linkgit:git-cvsserver[1].
-
-gitcvs.dbUser, gitcvs.dbPass::
-	Database user and password. Only useful if setting `gitcvs.dbDriver`,
-	since SQLite has no concept of database users and/or passwords.
-	'gitcvs.dbUser' supports variable substitution (see
-	linkgit:git-cvsserver[1] for details).
-
-gitcvs.dbTableNamePrefix::
-	Database table name prefix.  Prepended to the names of any
-	database tables used, allowing a single database to be used
-	for several repositories.  Supports variable substitution (see
-	linkgit:git-cvsserver[1] for details).  Any non-alphabetic
-	characters will be replaced with underscores.
-
-All gitcvs variables except for `gitcvs.usecrlfattr` and
-`gitcvs.allBinary` can also be specified as
-'gitcvs.<access_method>.<varname>' (where 'access_method'
-is one of "ext" and "pserver") to make them apply only for the given
-access method.
-
-gitweb.category::
-gitweb.description::
-gitweb.owner::
-gitweb.url::
-	See linkgit:gitweb[1] for description.
-
-gitweb.avatar::
-gitweb.blame::
-gitweb.grep::
-gitweb.highlight::
-gitweb.patches::
-gitweb.pickaxe::
-gitweb.remote_heads::
-gitweb.showSizes::
-gitweb.snapshot::
-	See linkgit:gitweb.conf[5] for description.
-
-grep.lineNumber::
-	If set to true, enable `-n` option by default.
-
-grep.patternType::
-	Set the default matching behavior. Using a value of 'basic', 'extended',
-	'fixed', or 'perl' will enable the `--basic-regexp`, `--extended-regexp`,
-	`--fixed-strings`, or `--perl-regexp` option accordingly, while the
-	value 'default' will return to the default matching behavior.
-
-grep.extendedRegexp::
-	If set to true, enable `--extended-regexp` option by default. This
-	option is ignored when the `grep.patternType` option is set to a value
-	other than 'default'.
-
-grep.threads::
-	Number of grep worker threads to use.
-	See `grep.threads` in linkgit:git-grep[1] for more information.
-
-grep.fallbackToNoIndex::
-	If set to true, fall back to git grep --no-index if git grep
-	is executed outside of a git repository.  Defaults to false.
-
-gpg.program::
-	Use this custom program instead of "`gpg`" found on `$PATH` when
-	making or verifying a PGP signature. The program must support the
-	same command-line interface as GPG, namely, to verify a detached
-	signature, "`gpg --verify $file - <$signature`" is run, and the
-	program is expected to signal a good signature by exiting with
-	code 0, and to generate an ASCII-armored detached signature, the
-	standard input of "`gpg -bsau $key`" is fed with the contents to be
-	signed, and the program is expected to send the result to its
-	standard output.
-
-gui.commitMsgWidth::
-	Defines how wide the commit message window is in the
-	linkgit:git-gui[1]. "75" is the default.
-
-gui.diffContext::
-	Specifies how many context lines should be used in calls to diff
-	made by the linkgit:git-gui[1]. The default is "5".
-
-gui.displayUntracked::
-	Determines if linkgit:git-gui[1] shows untracked files
-	in the file list. The default is "true".
-
-gui.encoding::
-	Specifies the default encoding to use for displaying of
-	file contents in linkgit:git-gui[1] and linkgit:gitk[1].
-	It can be overridden by setting the 'encoding' attribute
-	for relevant files (see linkgit:gitattributes[5]).
-	If this option is not set, the tools default to the
-	locale encoding.
-
-gui.matchTrackingBranch::
-	Determines if new branches created with linkgit:git-gui[1] should
-	default to tracking remote branches with matching names or
-	not. Default: "false".
-
-gui.newBranchTemplate::
-	Is used as suggested name when creating new branches using the
-	linkgit:git-gui[1].
-
-gui.pruneDuringFetch::
-	"true" if linkgit:git-gui[1] should prune remote-tracking branches when
-	performing a fetch. The default value is "false".
-
-gui.trustmtime::
-	Determines if linkgit:git-gui[1] should trust the file modification
-	timestamp or not. By default the timestamps are not trusted.
-
-gui.spellingDictionary::
-	Specifies the dictionary used for spell checking commit messages in
-	the linkgit:git-gui[1]. When set to "none" spell checking is turned
-	off.
-
-gui.fastCopyBlame::
-	If true, 'git gui blame' uses `-C` instead of `-C -C` for original
-	location detection. It makes blame significantly faster on huge
-	repositories at the expense of less thorough copy detection.
-
-gui.copyBlameThreshold::
-	Specifies the threshold to use in 'git gui blame' original location
-	detection, measured in alphanumeric characters. See the
-	linkgit:git-blame[1] manual for more information on copy detection.
-
-gui.blamehistoryctx::
-	Specifies the radius of history context in days to show in
-	linkgit:gitk[1] for the selected commit, when the `Show History
-	Context` menu item is invoked from 'git gui blame'. If this
-	variable is set to zero, the whole history is shown.
-
-guitool.<name>.cmd::
-	Specifies the shell command line to execute when the corresponding item
-	of the linkgit:git-gui[1] `Tools` menu is invoked. This option is
-	mandatory for every tool. The command is executed from the root of
-	the working directory, and in the environment it receives the name of
-	the tool as `GIT_GUITOOL`, the name of the currently selected file as
-	'FILENAME', and the name of the current branch as 'CUR_BRANCH' (if
-	the head is detached, 'CUR_BRANCH' is empty).
-
-guitool.<name>.needsFile::
-	Run the tool only if a diff is selected in the GUI. It guarantees
-	that 'FILENAME' is not empty.
-
-guitool.<name>.noConsole::
-	Run the command silently, without creating a window to display its
-	output.
-
-guitool.<name>.noRescan::
-	Don't rescan the working directory for changes after the tool
-	finishes execution.
-
-guitool.<name>.confirm::
-	Show a confirmation dialog before actually running the tool.
-
-guitool.<name>.argPrompt::
-	Request a string argument from the user, and pass it to the tool
-	through the `ARGS` environment variable. Since requesting an
-	argument implies confirmation, the 'confirm' option has no effect
-	if this is enabled. If the option is set to 'true', 'yes', or '1',
-	the dialog uses a built-in generic prompt; otherwise the exact
-	value of the variable is used.
-
-guitool.<name>.revPrompt::
-	Request a single valid revision from the user, and set the
-	`REVISION` environment variable. In other aspects this option
-	is similar to 'argPrompt', and can be used together with it.
-
-guitool.<name>.revUnmerged::
-	Show only unmerged branches in the 'revPrompt' subdialog.
-	This is useful for tools similar to merge or rebase, but not
-	for things like checkout or reset.
-
-guitool.<name>.title::
-	Specifies the title to use for the prompt dialog. The default
-	is the tool name.
-
-guitool.<name>.prompt::
-	Specifies the general prompt string to display at the top of
-	the dialog, before subsections for 'argPrompt' and 'revPrompt'.
-	The default value includes the actual command.
-
-help.browser::
-	Specify the browser that will be used to display help in the
-	'web' format. See linkgit:git-help[1].
-
-help.format::
-	Override the default help format used by linkgit:git-help[1].
-	Values 'man', 'info', 'web' and 'html' are supported. 'man' is
-	the default. 'web' and 'html' are the same.
-
-help.autoCorrect::
-	Automatically correct and execute mistyped commands after
-	waiting for the given number of deciseconds (0.1 sec). If more
-	than one command can be deduced from the entered text, nothing
-	will be executed.  If the value of this option is negative,
-	the corrected command will be executed immediately. If the
-	value is 0 - the command will be just shown but not executed.
-	This is the default.
-
-help.htmlPath::
-	Specify the path where the HTML documentation resides. File system paths
-	and URLs are supported. HTML pages will be prefixed with this path when
-	help is displayed in the 'web' format. This defaults to the documentation
-	path of your Git installation.
-
-http.proxy::
-	Override the HTTP proxy, normally configured using the 'http_proxy',
-	'https_proxy', and 'all_proxy' environment variables (see `curl(1)`). In
-	addition to the syntax understood by curl, it is possible to specify a
-	proxy string with a user name but no password, in which case git will
-	attempt to acquire one in the same way it does for other credentials. See
-	linkgit:gitcredentials[7] for more information. The syntax thus is
-	'[protocol://][user[:password]@]proxyhost[:port]'. This can be overridden
-	on a per-remote basis; see remote.<name>.proxy
-
-http.proxyAuthMethod::
-	Set the method with which to authenticate against the HTTP proxy. This
-	only takes effect if the configured proxy string contains a user name part
-	(i.e. is of the form 'user@host' or 'user@host:port'). This can be
-	overridden on a per-remote basis; see `remote.<name>.proxyAuthMethod`.
-	Both can be overridden by the `GIT_HTTP_PROXY_AUTHMETHOD` environment
-	variable.  Possible values are:
-+
---
-* `anyauth` - Automatically pick a suitable authentication method. It is
-  assumed that the proxy answers an unauthenticated request with a 407
-  status code and one or more Proxy-authenticate headers with supported
-  authentication methods. This is the default.
-* `basic` - HTTP Basic authentication
-* `digest` - HTTP Digest authentication; this prevents the password from being
-  transmitted to the proxy in clear text
-* `negotiate` - GSS-Negotiate authentication (compare the --negotiate option
-  of `curl(1)`)
-* `ntlm` - NTLM authentication (compare the --ntlm option of `curl(1)`)
---
-
-http.emptyAuth::
-	Attempt authentication without seeking a username or password.  This
-	can be used to attempt GSS-Negotiate authentication without specifying
-	a username in the URL, as libcurl normally requires a username for
-	authentication.
-
-http.delegation::
-	Control GSSAPI credential delegation. The delegation is disabled
-	by default in libcurl since version 7.21.7. Set parameter to tell
-	the server what it is allowed to delegate when it comes to user
-	credentials. Used with GSS/kerberos. Possible values are:
-+
---
-* `none` - Don't allow any delegation.
-* `policy` - Delegates if and only if the OK-AS-DELEGATE flag is set in the
-  Kerberos service ticket, which is a matter of realm policy.
-* `always` - Unconditionally allow the server to delegate.
---
-
-
-http.extraHeader::
-	Pass an additional HTTP header when communicating with a server.  If
-	more than one such entry exists, all of them are added as extra
-	headers.  To allow overriding the settings inherited from the system
-	config, an empty value will reset the extra headers to the empty list.
-
-http.cookieFile::
-	The pathname of a file containing previously stored cookie lines,
-	which should be used
-	in the Git http session, if they match the server. The file format
-	of the file to read cookies from should be plain HTTP headers or
-	the Netscape/Mozilla cookie file format (see `curl(1)`).
-	NOTE that the file specified with http.cookieFile is used only as
-	input unless http.saveCookies is set.
-
-http.saveCookies::
-	If set, store cookies received during requests to the file specified by
-	http.cookieFile. Has no effect if http.cookieFile is unset.
-
-http.sslVersion::
-	The SSL version to use when negotiating an SSL connection, if you
-	want to force the default.  The available and default version
-	depend on whether libcurl was built against NSS or OpenSSL and the
-	particular configuration of the crypto library in use. Internally
-	this sets the 'CURLOPT_SSL_VERSION' option; see the libcurl
-	documentation for more details on the format of this option and
-	for the ssl version supported. Actually the possible values of
-	this option are:
-
-	- sslv2
-	- sslv3
-	- tlsv1
-	- tlsv1.0
-	- tlsv1.1
-	- tlsv1.2
-	- tlsv1.3
+include::config/column.txt[]
 
-+
-Can be overridden by the `GIT_SSL_VERSION` environment variable.
-To force git to use libcurl's default ssl version and ignore any
-explicit http.sslversion option, set `GIT_SSL_VERSION` to the
-empty string.
-
-http.sslCipherList::
-  A list of SSL ciphers to use when negotiating an SSL connection.
-  The available ciphers depend on whether libcurl was built against
-  NSS or OpenSSL and the particular configuration of the crypto
-  library in use.  Internally this sets the 'CURLOPT_SSL_CIPHER_LIST'
-  option; see the libcurl documentation for more details on the format
-  of this list.
-+
-Can be overridden by the `GIT_SSL_CIPHER_LIST` environment variable.
-To force git to use libcurl's default cipher list and ignore any
-explicit http.sslCipherList option, set `GIT_SSL_CIPHER_LIST` to the
-empty string.
-
-http.sslVerify::
-	Whether to verify the SSL certificate when fetching or pushing
-	over HTTPS. Defaults to true. Can be overridden by the
-	`GIT_SSL_NO_VERIFY` environment variable.
-
-http.sslCert::
-	File containing the SSL certificate when fetching or pushing
-	over HTTPS. Can be overridden by the `GIT_SSL_CERT` environment
-	variable.
-
-http.sslKey::
-	File containing the SSL private key when fetching or pushing
-	over HTTPS. Can be overridden by the `GIT_SSL_KEY` environment
-	variable.
-
-http.sslCertPasswordProtected::
-	Enable Git's password prompt for the SSL certificate.  Otherwise
-	OpenSSL will prompt the user, possibly many times, if the
-	certificate or private key is encrypted.  Can be overridden by the
-	`GIT_SSL_CERT_PASSWORD_PROTECTED` environment variable.
-
-http.sslCAInfo::
-	File containing the certificates to verify the peer with when
-	fetching or pushing over HTTPS. Can be overridden by the
-	`GIT_SSL_CAINFO` environment variable.
-
-http.sslCAPath::
-	Path containing files with the CA certificates to verify the peer
-	with when fetching or pushing over HTTPS. Can be overridden
-	by the `GIT_SSL_CAPATH` environment variable.
-
-http.pinnedpubkey::
-	Public key of the https service. It may either be the filename of
-	a PEM or DER encoded public key file or a string starting with
-	'sha256//' followed by the base64 encoded sha256 hash of the
-	public key. See also libcurl 'CURLOPT_PINNEDPUBLICKEY'. git will
-	exit with an error if this option is set but not supported by
-	cURL.
-
-http.sslTry::
-	Attempt to use AUTH SSL/TLS and encrypted data transfers
-	when connecting via regular FTP protocol. This might be needed
-	if the FTP server requires it for security reasons or you wish
-	to connect securely whenever remote FTP server supports it.
-	Default is false since it might trigger certificate verification
-	errors on misconfigured servers.
-
-http.maxRequests::
-	How many HTTP requests to launch in parallel. Can be overridden
-	by the `GIT_HTTP_MAX_REQUESTS` environment variable. Default is 5.
-
-http.minSessions::
-	The number of curl sessions (counted across slots) to be kept across
-	requests. They will not be ended with curl_easy_cleanup() until
-	http_cleanup() is invoked. If USE_CURL_MULTI is not defined, this
-	value will be capped at 1. Defaults to 1.
-
-http.postBuffer::
-	Maximum size in bytes of the buffer used by smart HTTP
-	transports when POSTing data to the remote system.
-	For requests larger than this buffer size, HTTP/1.1 and
-	Transfer-Encoding: chunked is used to avoid creating a
-	massive pack file locally.  Default is 1 MiB, which is
-	sufficient for most requests.
-
-http.lowSpeedLimit, http.lowSpeedTime::
-	If the HTTP transfer speed is less than 'http.lowSpeedLimit'
-	for longer than 'http.lowSpeedTime' seconds, the transfer is aborted.
-	Can be overridden by the `GIT_HTTP_LOW_SPEED_LIMIT` and
-	`GIT_HTTP_LOW_SPEED_TIME` environment variables.
-
-http.noEPSV::
-	A boolean which disables using of EPSV ftp command by curl.
-	This can helpful with some "poor" ftp servers which don't
-	support EPSV mode. Can be overridden by the `GIT_CURL_FTP_NO_EPSV`
-	environment variable. Default is false (curl will use EPSV).
-
-http.userAgent::
-	The HTTP USER_AGENT string presented to an HTTP server.  The default
-	value represents the version of the client Git such as git/1.7.1.
-	This option allows you to override this value to a more common value
-	such as Mozilla/4.0.  This may be necessary, for instance, if
-	connecting through a firewall that restricts HTTP connections to a set
-	of common USER_AGENT strings (but not including those like git/1.7.1).
-	Can be overridden by the `GIT_HTTP_USER_AGENT` environment variable.
-
-http.followRedirects::
-	Whether git should follow HTTP redirects. If set to `true`, git
-	will transparently follow any redirect issued by a server it
-	encounters. If set to `false`, git will treat all redirects as
-	errors. If set to `initial`, git will follow redirects only for
-	the initial request to a remote, but not for subsequent
-	follow-up HTTP requests. Since git uses the redirected URL as
-	the base for the follow-up requests, this is generally
-	sufficient. The default is `initial`.
-
-http.<url>.*::
-	Any of the http.* options above can be applied selectively to some URLs.
-	For a config key to match a URL, each element of the config key is
-	compared to that of the URL, in the following order:
-+
---
-. Scheme (e.g., `https` in `https://example.com/`). This field
-  must match exactly between the config key and the URL.
-
-. Host/domain name (e.g., `example.com` in `https://example.com/`).
-  This field must match between the config key and the URL. It is
-  possible to specify a `*` as part of the host name to match all subdomains
-  at this level. `https://*.example.com/` for example would match
-  `https://foo.example.com/`, but not `https://foo.bar.example.com/`.
-
-. Port number (e.g., `8080` in `http://example.com:8080/`).
-  This field must match exactly between the config key and the URL.
-  Omitted port numbers are automatically converted to the correct
-  default for the scheme before matching.
-
-. Path (e.g., `repo.git` in `https://example.com/repo.git`). The
-  path field of the config key must match the path field of the URL
-  either exactly or as a prefix of slash-delimited path elements.  This means
-  a config key with path `foo/` matches URL path `foo/bar`.  A prefix can only
-  match on a slash (`/`) boundary.  Longer matches take precedence (so a config
-  key with path `foo/bar` is a better match to URL path `foo/bar` than a config
-  key with just path `foo/`).
-
-. User name (e.g., `user` in `https://user@example.com/repo.git`). If
-  the config key has a user name it must match the user name in the
-  URL exactly. If the config key does not have a user name, that
-  config key will match a URL with any user name (including none),
-  but at a lower precedence than a config key with a user name.
---
-+
-The list above is ordered by decreasing precedence; a URL that matches
-a config key's path is preferred to one that matches its user name. For example,
-if the URL is `https://user@example.com/foo/bar` a config key match of
-`https://example.com/foo` will be preferred over a config key match of
-`https://user@example.com`.
-+
-All URLs are normalized before attempting any matching (the password part,
-if embedded in the URL, is always ignored for matching purposes) so that
-equivalent URLs that are simply spelled differently will match properly.
-Environment variable settings always override any matches.  The URLs that are
-matched against are those given directly to Git commands.  This means any URLs
-visited as a result of a redirection do not participate in matching.
-
-ssh.variant::
-	By default, Git determines the command line arguments to use
-	based on the basename of the configured SSH command (configured
-	using the environment variable `GIT_SSH` or `GIT_SSH_COMMAND` or
-	the config setting `core.sshCommand`). If the basename is
-	unrecognized, Git will attempt to detect support of OpenSSH
-	options by first invoking the configured SSH command with the
-	`-G` (print configuration) option and will subsequently use
-	OpenSSH options (if that is successful) or no options besides
-	the host and remote command (if it fails).
-+
-The config variable `ssh.variant` can be set to override this detection.
-Valid values are `ssh` (to use OpenSSH options), `plink`, `putty`,
-`tortoiseplink`, `simple` (no options except the host and remote command).
-The default auto-detection can be explicitly requested using the value
-`auto`.  Any other value is treated as `ssh`.  This setting can also be
-overridden via the environment variable `GIT_SSH_VARIANT`.
-+
-The current command-line parameters used for each variant are as
-follows:
-+
---
+include::config/commit.txt[]
 
-* `ssh` - [-p port] [-4] [-6] [-o option] [username@]host command
+include::config/credential.txt[]
 
-* `simple` - [username@]host command
+include::config/completion.txt[]
 
-* `plink` or `putty` - [-P port] [-4] [-6] [username@]host command
+include::config/diff.txt[]
 
-* `tortoiseplink` - [-P port] [-4] [-6] -batch [username@]host command
+include::config/difftool.txt[]
 
---
-+
-Except for the `simple` variant, command-line parameters are likely to
-change as git gains new features.
+include::config/fastimport.txt[]
 
-i18n.commitEncoding::
-	Character encoding the commit messages are stored in; Git itself
-	does not care per se, but this information is necessary e.g. when
-	importing commits from emails or in the gitk graphical history
-	browser (and possibly at other places in the future or in other
-	porcelains). See e.g. linkgit:git-mailinfo[1]. Defaults to 'utf-8'.
-
-i18n.logOutputEncoding::
-	Character encoding the commit messages are converted to when
-	running 'git log' and friends.
-
-imap::
-	The configuration variables in the 'imap' section are described
-	in linkgit:git-imap-send[1].
-
-index.version::
-	Specify the version with which new index files should be
-	initialized.  This does not affect existing repositories.
-
-init.templateDir::
-	Specify the directory from which templates will be copied.
-	(See the "TEMPLATE DIRECTORY" section of linkgit:git-init[1].)
-
-instaweb.browser::
-	Specify the program that will be used to browse your working
-	repository in gitweb. See linkgit:git-instaweb[1].
-
-instaweb.httpd::
-	The HTTP daemon command-line to start gitweb on your working
-	repository. See linkgit:git-instaweb[1].
-
-instaweb.local::
-	If true the web server started by linkgit:git-instaweb[1] will
-	be bound to the local IP (127.0.0.1).
-
-instaweb.modulePath::
-	The default module path for linkgit:git-instaweb[1] to use
-	instead of /usr/lib/apache2/modules.  Only used if httpd
-	is Apache.
-
-instaweb.port::
-	The port number to bind the gitweb httpd to. See
-	linkgit:git-instaweb[1].
-
-interactive.singleKey::
-	In interactive commands, allow the user to provide one-letter
-	input with a single key (i.e., without hitting enter).
-	Currently this is used by the `--patch` mode of
-	linkgit:git-add[1], linkgit:git-checkout[1], linkgit:git-commit[1],
-	linkgit:git-reset[1], and linkgit:git-stash[1]. Note that this
-	setting is silently ignored if portable keystroke input
-	is not available; requires the Perl module Term::ReadKey.
-
-interactive.diffFilter::
-	When an interactive command (such as `git add --patch`) shows
-	a colorized diff, git will pipe the diff through the shell
-	command defined by this configuration variable. The command may
-	mark up the diff further for human consumption, provided that it
-	retains a one-to-one correspondence with the lines in the
-	original diff. Defaults to disabled (no filtering).
-
-log.abbrevCommit::
-	If true, makes linkgit:git-log[1], linkgit:git-show[1], and
-	linkgit:git-whatchanged[1] assume `--abbrev-commit`. You may
-	override this option with `--no-abbrev-commit`.
-
-log.date::
-	Set the default date-time mode for the 'log' command.
-	Setting a value for log.date is similar to using 'git log''s
-	`--date` option.  See linkgit:git-log[1] for details.
-
-log.decorate::
-	Print out the ref names of any commits that are shown by the log
-	command. If 'short' is specified, the ref name prefixes 'refs/heads/',
-	'refs/tags/' and 'refs/remotes/' will not be printed. If 'full' is
-	specified, the full ref name (including prefix) will be printed.
-	If 'auto' is specified, then if the output is going to a terminal,
-	the ref names are shown as if 'short' were given, otherwise no ref
-	names are shown. This is the same as the `--decorate` option
-	of the `git log`.
-
-log.follow::
-	If `true`, `git log` will act as if the `--follow` option was used when
-	a single <path> is given.  This has the same limitations as `--follow`,
-	i.e. it cannot be used to follow multiple files and does not work well
-	on non-linear history.
-
-log.graphColors::
-	A list of colors, separated by commas, that can be used to draw
-	history lines in `git log --graph`.
-
-log.showRoot::
-	If true, the initial commit will be shown as a big creation event.
-	This is equivalent to a diff against an empty tree.
-	Tools like linkgit:git-log[1] or linkgit:git-whatchanged[1], which
-	normally hide the root commit will now show it. True by default.
-
-log.showSignature::
-	If true, makes linkgit:git-log[1], linkgit:git-show[1], and
-	linkgit:git-whatchanged[1] assume `--show-signature`.
-
-log.mailmap::
-	If true, makes linkgit:git-log[1], linkgit:git-show[1], and
-	linkgit:git-whatchanged[1] assume `--use-mailmap`.
-
-mailinfo.scissors::
-	If true, makes linkgit:git-mailinfo[1] (and therefore
-	linkgit:git-am[1]) act by default as if the --scissors option
-	was provided on the command-line. When active, this features
-	removes everything from the message body before a scissors
-	line (i.e. consisting mainly of ">8", "8<" and "-").
-
-mailmap.file::
-	The location of an augmenting mailmap file. The default
-	mailmap, located in the root of the repository, is loaded
-	first, then the mailmap file pointed to by this variable.
-	The location of the mailmap file may be in a repository
-	subdirectory, or somewhere outside of the repository itself.
-	See linkgit:git-shortlog[1] and linkgit:git-blame[1].
-
-mailmap.blob::
-	Like `mailmap.file`, but consider the value as a reference to a
-	blob in the repository. If both `mailmap.file` and
-	`mailmap.blob` are given, both are parsed, with entries from
-	`mailmap.file` taking precedence. In a bare repository, this
-	defaults to `HEAD:.mailmap`. In a non-bare repository, it
-	defaults to empty.
-
-man.viewer::
-	Specify the programs that may be used to display help in the
-	'man' format. See linkgit:git-help[1].
-
-man.<tool>.cmd::
-	Specify the command to invoke the specified man viewer. The
-	specified command is evaluated in shell with the man page
-	passed as argument. (See linkgit:git-help[1].)
-
-man.<tool>.path::
-	Override the path for the given tool that may be used to
-	display help in the 'man' format. See linkgit:git-help[1].
-
-include::merge-config.txt[]
-
-mergetool.<tool>.path::
-	Override the path for the given tool.  This is useful in case
-	your tool is not in the PATH.
-
-mergetool.<tool>.cmd::
-	Specify the command to invoke the specified merge tool.  The
-	specified command is evaluated in shell with the following
-	variables available: 'BASE' is the name of a temporary file
-	containing the common base of the files to be merged, if available;
-	'LOCAL' is the name of a temporary file containing the contents of
-	the file on the current branch; 'REMOTE' is the name of a temporary
-	file containing the contents of the file from the branch being
-	merged; 'MERGED' contains the name of the file to which the merge
-	tool should write the results of a successful merge.
-
-mergetool.<tool>.trustExitCode::
-	For a custom merge command, specify whether the exit code of
-	the merge command can be used to determine whether the merge was
-	successful.  If this is not set to true then the merge target file
-	timestamp is checked and the merge assumed to have been successful
-	if the file has been updated, otherwise the user is prompted to
-	indicate the success of the merge.
-
-mergetool.meld.hasOutput::
-	Older versions of `meld` do not support the `--output` option.
-	Git will attempt to detect whether `meld` supports `--output`
-	by inspecting the output of `meld --help`.  Configuring
-	`mergetool.meld.hasOutput` will make Git skip these checks and
-	use the configured value instead.  Setting `mergetool.meld.hasOutput`
-	to `true` tells Git to unconditionally use the `--output` option,
-	and `false` avoids using `--output`.
-
-mergetool.keepBackup::
-	After performing a merge, the original file with conflict markers
-	can be saved as a file with a `.orig` extension.  If this variable
-	is set to `false` then this file is not preserved.  Defaults to
-	`true` (i.e. keep the backup files).
-
-mergetool.keepTemporaries::
-	When invoking a custom merge tool, Git uses a set of temporary
-	files to pass to the tool. If the tool returns an error and this
-	variable is set to `true`, then these temporary files will be
-	preserved, otherwise they will be removed after the tool has
-	exited. Defaults to `false`.
-
-mergetool.writeToTemp::
-	Git writes temporary 'BASE', 'LOCAL', and 'REMOTE' versions of
-	conflicting files in the worktree by default.  Git will attempt
-	to use a temporary directory for these files when set `true`.
-	Defaults to `false`.
-
-mergetool.prompt::
-	Prompt before each invocation of the merge resolution program.
-
-notes.mergeStrategy::
-	Which merge strategy to choose by default when resolving notes
-	conflicts.  Must be one of `manual`, `ours`, `theirs`, `union`, or
-	`cat_sort_uniq`.  Defaults to `manual`.  See "NOTES MERGE STRATEGIES"
-	section of linkgit:git-notes[1] for more information on each strategy.
-
-notes.<name>.mergeStrategy::
-	Which merge strategy to choose when doing a notes merge into
-	refs/notes/<name>.  This overrides the more general
-	"notes.mergeStrategy".  See the "NOTES MERGE STRATEGIES" section in
-	linkgit:git-notes[1] for more information on the available strategies.
-
-notes.displayRef::
-	The (fully qualified) refname from which to show notes when
-	showing commit messages.  The value of this variable can be set
-	to a glob, in which case notes from all matching refs will be
-	shown.  You may also specify this configuration variable
-	several times.  A warning will be issued for refs that do not
-	exist, but a glob that does not match any refs is silently
-	ignored.
-+
-This setting can be overridden with the `GIT_NOTES_DISPLAY_REF`
-environment variable, which must be a colon separated list of refs or
-globs.
-+
-The effective value of "core.notesRef" (possibly overridden by
-GIT_NOTES_REF) is also implicitly added to the list of refs to be
-displayed.
-
-notes.rewrite.<command>::
-	When rewriting commits with <command> (currently `amend` or
-	`rebase`) and this variable is set to `true`, Git
-	automatically copies your notes from the original to the
-	rewritten commit.  Defaults to `true`, but see
-	"notes.rewriteRef" below.
-
-notes.rewriteMode::
-	When copying notes during a rewrite (see the
-	"notes.rewrite.<command>" option), determines what to do if
-	the target commit already has a note.  Must be one of
-	`overwrite`, `concatenate`, `cat_sort_uniq`, or `ignore`.
-	Defaults to `concatenate`.
-+
-This setting can be overridden with the `GIT_NOTES_REWRITE_MODE`
-environment variable.
+include::config/feature.txt[]
 
-notes.rewriteRef::
-	When copying notes during a rewrite, specifies the (fully
-	qualified) ref whose notes should be copied.  The ref may be a
-	glob, in which case notes in all matching refs will be copied.
-	You may also specify this configuration several times.
-+
-Does not have a default value; you must configure this variable to
-enable note rewriting.  Set it to `refs/notes/commits` to enable
-rewriting for the default commit notes.
-+
-This setting can be overridden with the `GIT_NOTES_REWRITE_REF`
-environment variable, which must be a colon separated list of refs or
-globs.
-
-pack.window::
-	The size of the window used by linkgit:git-pack-objects[1] when no
-	window size is given on the command line. Defaults to 10.
-
-pack.depth::
-	The maximum delta depth used by linkgit:git-pack-objects[1] when no
-	maximum depth is given on the command line. Defaults to 50.
-	Maximum value is 4095.
-
-pack.windowMemory::
-	The maximum size of memory that is consumed by each thread
-	in linkgit:git-pack-objects[1] for pack window memory when
-	no limit is given on the command line.  The value can be
-	suffixed with "k", "m", or "g".  When left unconfigured (or
-	set explicitly to 0), there will be no limit.
-
-pack.compression::
-	An integer -1..9, indicating the compression level for objects
-	in a pack file. -1 is the zlib default. 0 means no
-	compression, and 1..9 are various speed/size tradeoffs, 9 being
-	slowest.  If not set,  defaults to core.compression.  If that is
-	not set,  defaults to -1, the zlib default, which is "a default
-	compromise between speed and compression (currently equivalent
-	to level 6)."
-+
-Note that changing the compression level will not automatically recompress
-all existing objects. You can force recompression by passing the -F option
-to linkgit:git-repack[1].
-
-pack.deltaCacheSize::
-	The maximum memory in bytes used for caching deltas in
-	linkgit:git-pack-objects[1] before writing them out to a pack.
-	This cache is used to speed up the writing object phase by not
-	having to recompute the final delta result once the best match
-	for all objects is found.  Repacking large repositories on machines
-	which are tight with memory might be badly impacted by this though,
-	especially if this cache pushes the system into swapping.
-	A value of 0 means no limit. The smallest size of 1 byte may be
-	used to virtually disable this cache. Defaults to 256 MiB.
-
-pack.deltaCacheLimit::
-	The maximum size of a delta, that is cached in
-	linkgit:git-pack-objects[1]. This cache is used to speed up the
-	writing object phase by not having to recompute the final delta
-	result once the best match for all objects is found.
-	Defaults to 1000. Maximum value is 65535.
-
-pack.threads::
-	Specifies the number of threads to spawn when searching for best
-	delta matches.  This requires that linkgit:git-pack-objects[1]
-	be compiled with pthreads otherwise this option is ignored with a
-	warning. This is meant to reduce packing time on multiprocessor
-	machines. The required amount of memory for the delta search window
-	is however multiplied by the number of threads.
-	Specifying 0 will cause Git to auto-detect the number of CPU's
-	and set the number of threads accordingly.
-
-pack.indexVersion::
-	Specify the default pack index version.  Valid values are 1 for
-	legacy pack index used by Git versions prior to 1.5.2, and 2 for
-	the new pack index with capabilities for packs larger than 4 GB
-	as well as proper protection against the repacking of corrupted
-	packs.  Version 2 is the default.  Note that version 2 is enforced
-	and this config option ignored whenever the corresponding pack is
-	larger than 2 GB.
-+
-If you have an old Git that does not understand the version 2 `*.idx` file,
-cloning or fetching over a non native protocol (e.g. "http")
-that will copy both `*.pack` file and corresponding `*.idx` file from the
-other side may give you a repository that cannot be accessed with your
-older version of Git. If the `*.pack` file is smaller than 2 GB, however,
-you can use linkgit:git-index-pack[1] on the *.pack file to regenerate
-the `*.idx` file.
-
-pack.packSizeLimit::
-	The maximum size of a pack.  This setting only affects
-	packing to a file when repacking, i.e. the git:// protocol
-	is unaffected.  It can be overridden by the `--max-pack-size`
-	option of linkgit:git-repack[1].  Reaching this limit results
-	in the creation of multiple packfiles; which in turn prevents
-	bitmaps from being created.
-	The minimum size allowed is limited to 1 MiB.
-	The default is unlimited.
-	Common unit suffixes of 'k', 'm', or 'g' are
-	supported.
-
-pack.useBitmaps::
-	When true, git will use pack bitmaps (if available) when packing
-	to stdout (e.g., during the server side of a fetch). Defaults to
-	true. You should not generally need to turn this off unless
-	you are debugging pack bitmaps.
-
-pack.writeBitmaps (deprecated)::
-	This is a deprecated synonym for `repack.writeBitmaps`.
-
-pack.writeBitmapHashCache::
-	When true, git will include a "hash cache" section in the bitmap
-	index (if one is written). This cache can be used to feed git's
-	delta heuristics, potentially leading to better deltas between
-	bitmapped and non-bitmapped objects (e.g., when serving a fetch
-	between an older, bitmapped pack and objects that have been
-	pushed since the last gc). The downside is that it consumes 4
-	bytes per object of disk space, and that JGit's bitmap
-	implementation does not understand it, causing it to complain if
-	Git and JGit are used on the same repository. Defaults to false.
-
-pager.<cmd>::
-	If the value is boolean, turns on or off pagination of the
-	output of a particular Git subcommand when writing to a tty.
-	Otherwise, turns on pagination for the subcommand using the
-	pager specified by the value of `pager.<cmd>`.  If `--paginate`
-	or `--no-pager` is specified on the command line, it takes
-	precedence over this option.  To disable pagination for all
-	commands, set `core.pager` or `GIT_PAGER` to `cat`.
-
-pretty.<name>::
-	Alias for a --pretty= format string, as specified in
-	linkgit:git-log[1]. Any aliases defined here can be used just
-	as the built-in pretty formats could. For example,
-	running `git config pretty.changelog "format:* %H %s"`
-	would cause the invocation `git log --pretty=changelog`
-	to be equivalent to running `git log "--pretty=format:* %H %s"`.
-	Note that an alias with the same name as a built-in format
-	will be silently ignored.
-
-protocol.allow::
-	If set, provide a user defined default policy for all protocols which
-	don't explicitly have a policy (`protocol.<name>.allow`).  By default,
-	if unset, known-safe protocols (http, https, git, ssh, file) have a
-	default policy of `always`, known-dangerous protocols (ext) have a
-	default policy of `never`, and all other protocols have a default
-	policy of `user`.  Supported policies:
-+
---
+include::config/fetch.txt[]
 
-* `always` - protocol is always able to be used.
+include::config/format.txt[]
 
-* `never` - protocol is never able to be used.
+include::config/filter.txt[]
 
-* `user` - protocol is only able to be used when `GIT_PROTOCOL_FROM_USER` is
-  either unset or has a value of 1.  This policy should be used when you want a
-  protocol to be directly usable by the user but don't want it used by commands which
-  execute clone/fetch/push commands without user input, e.g. recursive
-  submodule initialization.
+include::config/fsck.txt[]
 
---
+include::config/gc.txt[]
 
-protocol.<name>.allow::
-	Set a policy to be used by protocol `<name>` with clone/fetch/push
-	commands. See `protocol.allow` above for the available policies.
-+
-The protocol names currently used by git are:
-+
---
-  - `file`: any local file-based path (including `file://` URLs,
-    or local paths)
-
-  - `git`: the anonymous git protocol over a direct TCP
-    connection (or proxy, if configured)
-
-  - `ssh`: git over ssh (including `host:path` syntax,
-    `ssh://`, etc).
-
-  - `http`: git over http, both "smart http" and "dumb http".
-    Note that this does _not_ include `https`; if you want to configure
-    both, you must do so individually.
-
-  - any external helpers are named by their protocol (e.g., use
-    `hg` to allow the `git-remote-hg` helper)
---
-
-protocol.version::
-	Experimental. If set, clients will attempt to communicate with a
-	server using the specified protocol version.  If unset, no
-	attempt will be made by the client to communicate using a
-	particular protocol version, this results in protocol version 0
-	being used.
-	Supported versions:
-+
---
+include::config/gitcvs.txt[]
 
-* `0` - the original wire protocol.
+include::config/gitweb.txt[]
 
-* `1` - the original wire protocol with the addition of a version string
-  in the initial response from the server.
+include::config/grep.txt[]
 
---
+include::config/gpg.txt[]
 
-pull.ff::
-	By default, Git does not create an extra merge commit when merging
-	a commit that is a descendant of the current commit. Instead, the
-	tip of the current branch is fast-forwarded. When set to `false`,
-	this variable tells Git to create an extra merge commit in such
-	a case (equivalent to giving the `--no-ff` option from the command
-	line). When set to `only`, only such fast-forward merges are
-	allowed (equivalent to giving the `--ff-only` option from the
-	command line). This setting overrides `merge.ff` when pulling.
-
-pull.rebase::
-	When true, rebase branches on top of the fetched branch, instead
-	of merging the default branch from the default remote when "git
-	pull" is run. See "branch.<name>.rebase" for setting this on a
-	per-branch basis.
-+
-When `merges`, pass the `--rebase-merges` option to 'git rebase'
-so that the local merge commits are included in the rebase (see
-linkgit:git-rebase[1] for details).
-+
-When preserve, also pass `--preserve-merges` along to 'git rebase'
-so that locally committed merge commits will not be flattened
-by running 'git pull'.
-+
-When the value is `interactive`, the rebase is run in interactive mode.
-+
-*NOTE*: this is a possibly dangerous operation; do *not* use
-it unless you understand the implications (see linkgit:git-rebase[1]
-for details).
-
-pull.octopus::
-	The default merge strategy to use when pulling multiple branches
-	at once.
-
-pull.twohead::
-	The default merge strategy to use when pulling a single branch.
-
-push.default::
-	Defines the action `git push` should take if no refspec is
-	explicitly given.  Different values are well-suited for
-	specific workflows; for instance, in a purely central workflow
-	(i.e. the fetch source is equal to the push destination),
-	`upstream` is probably what you want.  Possible values are:
-+
---
+include::config/gui.txt[]
 
-* `nothing` - do not push anything (error out) unless a refspec is
-  explicitly given. This is primarily meant for people who want to
-  avoid mistakes by always being explicit.
-
-* `current` - push the current branch to update a branch with the same
-  name on the receiving end.  Works in both central and non-central
-  workflows.
-
-* `upstream` - push the current branch back to the branch whose
-  changes are usually integrated into the current branch (which is
-  called `@{upstream}`).  This mode only makes sense if you are
-  pushing to the same repository you would normally pull from
-  (i.e. central workflow).
-
-* `tracking` - This is a deprecated synonym for `upstream`.
-
-* `simple` - in centralized workflow, work like `upstream` with an
-  added safety to refuse to push if the upstream branch's name is
-  different from the local one.
-+
-When pushing to a remote that is different from the remote you normally
-pull from, work as `current`.  This is the safest option and is suited
-for beginners.
-+
-This mode has become the default in Git 2.0.
+include::config/guitool.txt[]
 
-* `matching` - push all branches having the same name on both ends.
-  This makes the repository you are pushing to remember the set of
-  branches that will be pushed out (e.g. if you always push 'maint'
-  and 'master' there and no other branches, the repository you push
-  to will have these two branches, and your local 'maint' and
-  'master' will be pushed there).
-+
-To use this mode effectively, you have to make sure _all_ the
-branches you would push out are ready to be pushed out before
-running 'git push', as the whole point of this mode is to allow you
-to push all of the branches in one go.  If you usually finish work
-on only one branch and push out the result, while other branches are
-unfinished, this mode is not for you.  Also this mode is not
-suitable for pushing into a shared central repository, as other
-people may add new branches there, or update the tip of existing
-branches outside your control.
-+
-This used to be the default, but not since Git 2.0 (`simple` is the
-new default).
+include::config/help.txt[]
 
---
+include::config/http.txt[]
 
-push.followTags::
-	If set to true enable `--follow-tags` option by default.  You
-	may override this configuration at time of push by specifying
-	`--no-follow-tags`.
-
-push.gpgSign::
-	May be set to a boolean value, or the string 'if-asked'. A true
-	value causes all pushes to be GPG signed, as if `--signed` is
-	passed to linkgit:git-push[1]. The string 'if-asked' causes
-	pushes to be signed if the server supports it, as if
-	`--signed=if-asked` is passed to 'git push'. A false value may
-	override a value from a lower-priority config file. An explicit
-	command-line flag always overrides this config option.
-
-push.pushOption::
-	When no `--push-option=<option>` argument is given from the
-	command line, `git push` behaves as if each <value> of
-	this variable is given as `--push-option=<value>`.
-+
-This is a multi-valued variable, and an empty value can be used in a
-higher priority configuration file (e.g. `.git/config` in a
-repository) to clear the values inherited from a lower priority
-configuration files (e.g. `$HOME/.gitconfig`).
-+
---
+include::config/i18n.txt[]
 
-Example:
+include::config/imap.txt[]
 
-/etc/gitconfig
-  push.pushoption = a
-  push.pushoption = b
-
-~/.gitconfig
-  push.pushoption = c
-
-repo/.git/config
-  push.pushoption =
-  push.pushoption = b
-
-This will result in only b (a and c are cleared).
-
---
-
-push.recurseSubmodules::
-	Make sure all submodule commits used by the revisions to be pushed
-	are available on a remote-tracking branch. If the value is 'check'
-	then Git will verify that all submodule commits that changed in the
-	revisions to be pushed are available on at least one remote of the
-	submodule. If any commits are missing, the push will be aborted and
-	exit with non-zero status. If the value is 'on-demand' then all
-	submodules that changed in the revisions to be pushed will be
-	pushed. If on-demand was not able to push all necessary revisions
-	it will also be aborted and exit with non-zero status. If the value
-	is 'no' then default behavior of ignoring submodules when pushing
-	is retained. You may override this configuration at time of push by
-	specifying '--recurse-submodules=check|on-demand|no'.
-
-include::rebase-config.txt[]
-
-receive.advertiseAtomic::
-	By default, git-receive-pack will advertise the atomic push
-	capability to its clients. If you don't want to advertise this
-	capability, set this variable to false.
-
-receive.advertisePushOptions::
-	When set to true, git-receive-pack will advertise the push options
-	capability to its clients. False by default.
-
-receive.autogc::
-	By default, git-receive-pack will run "git-gc --auto" after
-	receiving data from git-push and updating refs.  You can stop
-	it by setting this variable to false.
-
-receive.certNonceSeed::
-	By setting this variable to a string, `git receive-pack`
-	will accept a `git push --signed` and verifies it by using
-	a "nonce" protected by HMAC using this string as a secret
-	key.
-
-receive.certNonceSlop::
-	When a `git push --signed` sent a push certificate with a
-	"nonce" that was issued by a receive-pack serving the same
-	repository within this many seconds, export the "nonce"
-	found in the certificate to `GIT_PUSH_CERT_NONCE` to the
-	hooks (instead of what the receive-pack asked the sending
-	side to include).  This may allow writing checks in
-	`pre-receive` and `post-receive` a bit easier.  Instead of
-	checking `GIT_PUSH_CERT_NONCE_SLOP` environment variable
-	that records by how many seconds the nonce is stale to
-	decide if they want to accept the certificate, they only
-	can check `GIT_PUSH_CERT_NONCE_STATUS` is `OK`.
-
-receive.fsckObjects::
-	If it is set to true, git-receive-pack will check all received
-	objects. It will abort in the case of a malformed object or a
-	broken link. The result of an abort are only dangling objects.
-	Defaults to false. If not set, the value of `transfer.fsckObjects`
-	is used instead.
-
-receive.fsck.<msg-id>::
-	When `receive.fsckObjects` is set to true, errors can be switched
-	to warnings and vice versa by configuring the `receive.fsck.<msg-id>`
-	setting where the `<msg-id>` is the fsck message ID and the value
-	is one of `error`, `warn` or `ignore`. For convenience, fsck prefixes
-	the error/warning with the message ID, e.g. "missingEmail: invalid
-	author/committer line - missing email" means that setting
-	`receive.fsck.missingEmail = ignore` will hide that issue.
-+
-This feature is intended to support working with legacy repositories
-which would not pass pushing when `receive.fsckObjects = true`, allowing
-the host to accept repositories with certain known issues but still catch
-other issues.
-
-receive.fsck.skipList::
-	The path to a sorted list of object names (i.e. one SHA-1 per
-	line) that are known to be broken in a non-fatal way and should
-	be ignored. This feature is useful when an established project
-	should be accepted despite early commits containing errors that
-	can be safely ignored such as invalid committer email addresses.
-	Note: corrupt objects cannot be skipped with this setting.
-
-receive.keepAlive::
-	After receiving the pack from the client, `receive-pack` may
-	produce no output (if `--quiet` was specified) while processing
-	the pack, causing some networks to drop the TCP connection.
-	With this option set, if `receive-pack` does not transmit
-	any data in this phase for `receive.keepAlive` seconds, it will
-	send a short keepalive packet.  The default is 5 seconds; set
-	to 0 to disable keepalives entirely.
-
-receive.unpackLimit::
-	If the number of objects received in a push is below this
-	limit then the objects will be unpacked into loose object
-	files. However if the number of received objects equals or
-	exceeds this limit then the received pack will be stored as
-	a pack, after adding any missing delta bases.  Storing the
-	pack from a push can make the push operation complete faster,
-	especially on slow filesystems.  If not set, the value of
-	`transfer.unpackLimit` is used instead.
-
-receive.maxInputSize::
-	If the size of the incoming pack stream is larger than this
-	limit, then git-receive-pack will error out, instead of
-	accepting the pack file. If not set or set to 0, then the size
-	is unlimited.
-
-receive.denyDeletes::
-	If set to true, git-receive-pack will deny a ref update that deletes
-	the ref. Use this to prevent such a ref deletion via a push.
-
-receive.denyDeleteCurrent::
-	If set to true, git-receive-pack will deny a ref update that
-	deletes the currently checked out branch of a non-bare repository.
-
-receive.denyCurrentBranch::
-	If set to true or "refuse", git-receive-pack will deny a ref update
-	to the currently checked out branch of a non-bare repository.
-	Such a push is potentially dangerous because it brings the HEAD
-	out of sync with the index and working tree. If set to "warn",
-	print a warning of such a push to stderr, but allow the push to
-	proceed. If set to false or "ignore", allow such pushes with no
-	message. Defaults to "refuse".
-+
-Another option is "updateInstead" which will update the working
-tree if pushing into the current branch.  This option is
-intended for synchronizing working directories when one side is not easily
-accessible via interactive ssh (e.g. a live web site, hence the requirement
-that the working directory be clean). This mode also comes in handy when
-developing inside a VM to test and fix code on different Operating Systems.
-+
-By default, "updateInstead" will refuse the push if the working tree or
-the index have any difference from the HEAD, but the `push-to-checkout`
-hook can be used to customize this.  See linkgit:githooks[5].
-
-receive.denyNonFastForwards::
-	If set to true, git-receive-pack will deny a ref update which is
-	not a fast-forward. Use this to prevent such an update via a push,
-	even if that push is forced. This configuration variable is
-	set when initializing a shared repository.
-
-receive.hideRefs::
-	This variable is the same as `transfer.hideRefs`, but applies
-	only to `receive-pack` (and so affects pushes, but not fetches).
-	An attempt to update or delete a hidden ref by `git push` is
-	rejected.
-
-receive.updateServerInfo::
-	If set to true, git-receive-pack will run git-update-server-info
-	after receiving data from git-push and updating refs.
-
-receive.shallowUpdate::
-	If set to true, .git/shallow can be updated when new refs
-	require new shallow roots. Otherwise those refs are rejected.
-
-remote.pushDefault::
-	The remote to push to by default.  Overrides
-	`branch.<name>.remote` for all branches, and is overridden by
-	`branch.<name>.pushRemote` for specific branches.
-
-remote.<name>.url::
-	The URL of a remote repository.  See linkgit:git-fetch[1] or
-	linkgit:git-push[1].
-
-remote.<name>.pushurl::
-	The push URL of a remote repository.  See linkgit:git-push[1].
-
-remote.<name>.proxy::
-	For remotes that require curl (http, https and ftp), the URL to
-	the proxy to use for that remote.  Set to the empty string to
-	disable proxying for that remote.
-
-remote.<name>.proxyAuthMethod::
-	For remotes that require curl (http, https and ftp), the method to use for
-	authenticating against the proxy in use (probably set in
-	`remote.<name>.proxy`). See `http.proxyAuthMethod`.
-
-remote.<name>.fetch::
-	The default set of "refspec" for linkgit:git-fetch[1]. See
-	linkgit:git-fetch[1].
-
-remote.<name>.push::
-	The default set of "refspec" for linkgit:git-push[1]. See
-	linkgit:git-push[1].
-
-remote.<name>.mirror::
-	If true, pushing to this remote will automatically behave
-	as if the `--mirror` option was given on the command line.
-
-remote.<name>.skipDefaultUpdate::
-	If true, this remote will be skipped by default when updating
-	using linkgit:git-fetch[1] or the `update` subcommand of
-	linkgit:git-remote[1].
-
-remote.<name>.skipFetchAll::
-	If true, this remote will be skipped by default when updating
-	using linkgit:git-fetch[1] or the `update` subcommand of
-	linkgit:git-remote[1].
-
-remote.<name>.receivepack::
-	The default program to execute on the remote side when pushing.  See
-	option --receive-pack of linkgit:git-push[1].
-
-remote.<name>.uploadpack::
-	The default program to execute on the remote side when fetching.  See
-	option --upload-pack of linkgit:git-fetch-pack[1].
-
-remote.<name>.tagOpt::
-	Setting this value to --no-tags disables automatic tag following when
-	fetching from remote <name>. Setting it to --tags will fetch every
-	tag from remote <name>, even if they are not reachable from remote
-	branch heads. Passing these flags directly to linkgit:git-fetch[1] can
-	override this setting. See options --tags and --no-tags of
-	linkgit:git-fetch[1].
-
-remote.<name>.vcs::
-	Setting this to a value <vcs> will cause Git to interact with
-	the remote with the git-remote-<vcs> helper.
-
-remote.<name>.prune::
-	When set to true, fetching from this remote by default will also
-	remove any remote-tracking references that no longer exist on the
-	remote (as if the `--prune` option was given on the command line).
-	Overrides `fetch.prune` settings, if any.
-
-remote.<name>.pruneTags::
-	When set to true, fetching from this remote by default will also
-	remove any local tags that no longer exist on the remote if pruning
-	is activated in general via `remote.<name>.prune`, `fetch.prune` or
-	`--prune`. Overrides `fetch.pruneTags` settings, if any.
-+
-See also `remote.<name>.prune` and the PRUNING section of
-linkgit:git-fetch[1].
+include::config/index.txt[]
 
-remotes.<group>::
-	The list of remotes which are fetched by "git remote update
-	<group>".  See linkgit:git-remote[1].
-
-repack.useDeltaBaseOffset::
-	By default, linkgit:git-repack[1] creates packs that use
-	delta-base offset. If you need to share your repository with
-	Git older than version 1.4.4, either directly or via a dumb
-	protocol such as http, then you need to set this option to
-	"false" and repack. Access from old Git versions over the
-	native protocol are unaffected by this option.
-
-repack.packKeptObjects::
-	If set to true, makes `git repack` act as if
-	`--pack-kept-objects` was passed. See linkgit:git-repack[1] for
-	details. Defaults to `false` normally, but `true` if a bitmap
-	index is being written (either via `--write-bitmap-index` or
-	`repack.writeBitmaps`).
-
-repack.writeBitmaps::
-	When true, git will write a bitmap index when packing all
-	objects to disk (e.g., when `git repack -a` is run).  This
-	index can speed up the "counting objects" phase of subsequent
-	packs created for clones and fetches, at the cost of some disk
-	space and extra time spent on the initial repack.  This has
-	no effect if multiple packfiles are created.
-	Defaults to false.
-
-rerere.autoUpdate::
-	When set to true, `git-rerere` updates the index with the
-	resulting contents after it cleanly resolves conflicts using
-	previously recorded resolution.  Defaults to false.
-
-rerere.enabled::
-	Activate recording of resolved conflicts, so that identical
-	conflict hunks can be resolved automatically, should they be
-	encountered again.  By default, linkgit:git-rerere[1] is
-	enabled if there is an `rr-cache` directory under the
-	`$GIT_DIR`, e.g. if "rerere" was previously used in the
-	repository.
-
-sendemail.identity::
-	A configuration identity. When given, causes values in the
-	'sendemail.<identity>' subsection to take precedence over
-	values in the 'sendemail' section. The default identity is
-	the value of `sendemail.identity`.
-
-sendemail.smtpEncryption::
-	See linkgit:git-send-email[1] for description.  Note that this
-	setting is not subject to the 'identity' mechanism.
-
-sendemail.smtpssl (deprecated)::
-	Deprecated alias for 'sendemail.smtpEncryption = ssl'.
-
-sendemail.smtpsslcertpath::
-	Path to ca-certificates (either a directory or a single file).
-	Set it to an empty string to disable certificate verification.
-
-sendemail.<identity>.*::
-	Identity-specific versions of the 'sendemail.*' parameters
-	found below, taking precedence over those when this
-	identity is selected, through either the command-line or
-	`sendemail.identity`.
-
-sendemail.aliasesFile::
-sendemail.aliasFileType::
-sendemail.annotate::
-sendemail.bcc::
-sendemail.cc::
-sendemail.ccCmd::
-sendemail.chainReplyTo::
-sendemail.confirm::
-sendemail.envelopeSender::
-sendemail.from::
-sendemail.multiEdit::
-sendemail.signedoffbycc::
-sendemail.smtpPass::
-sendemail.suppresscc::
-sendemail.suppressFrom::
-sendemail.to::
-sendemail.tocmd::
-sendemail.smtpDomain::
-sendemail.smtpServer::
-sendemail.smtpServerPort::
-sendemail.smtpServerOption::
-sendemail.smtpUser::
-sendemail.thread::
-sendemail.transferEncoding::
-sendemail.validate::
-sendemail.xmailer::
-	See linkgit:git-send-email[1] for description.
-
-sendemail.signedoffcc (deprecated)::
-	Deprecated alias for `sendemail.signedoffbycc`.
-
-sendemail.smtpBatchSize::
-	Number of messages to be sent per connection, after that a relogin
-	will happen.  If the value is 0 or undefined, send all messages in
-	one connection.
-	See also the `--batch-size` option of linkgit:git-send-email[1].
-
-sendemail.smtpReloginDelay::
-	Seconds wait before reconnecting to smtp server.
-	See also the `--relogin-delay` option of linkgit:git-send-email[1].
-
-showbranch.default::
-	The default set of branches for linkgit:git-show-branch[1].
-	See linkgit:git-show-branch[1].
-
-splitIndex.maxPercentChange::
-	When the split index feature is used, this specifies the
-	percent of entries the split index can contain compared to the
-	total number of entries in both the split index and the shared
-	index before a new shared index is written.
-	The value should be between 0 and 100. If the value is 0 then
-	a new shared index is always written, if it is 100 a new
-	shared index is never written.
-	By default the value is 20, so a new shared index is written
-	if the number of entries in the split index would be greater
-	than 20 percent of the total number of entries.
-	See linkgit:git-update-index[1].
-
-splitIndex.sharedIndexExpire::
-	When the split index feature is used, shared index files that
-	were not modified since the time this variable specifies will
-	be removed when a new shared index file is created. The value
-	"now" expires all entries immediately, and "never" suppresses
-	expiration altogether.
-	The default value is "2.weeks.ago".
-	Note that a shared index file is considered modified (for the
-	purpose of expiration) each time a new split-index file is
-	either created based on it or read from it.
-	See linkgit:git-update-index[1].
-
-status.relativePaths::
-	By default, linkgit:git-status[1] shows paths relative to the
-	current directory. Setting this variable to `false` shows paths
-	relative to the repository root (this was the default for Git
-	prior to v1.5.4).
-
-status.short::
-	Set to true to enable --short by default in linkgit:git-status[1].
-	The option --no-short takes precedence over this variable.
-
-status.branch::
-	Set to true to enable --branch by default in linkgit:git-status[1].
-	The option --no-branch takes precedence over this variable.
-
-status.displayCommentPrefix::
-	If set to true, linkgit:git-status[1] will insert a comment
-	prefix before each output line (starting with
-	`core.commentChar`, i.e. `#` by default). This was the
-	behavior of linkgit:git-status[1] in Git 1.8.4 and previous.
-	Defaults to false.
-
-status.renameLimit::
-	The number of files to consider when performing rename detection
-	in linkgit:git-status[1] and linkgit:git-commit[1]. Defaults to
-	the value of diff.renameLimit.
-
-status.renames::
-	Whether and how Git detects renames in linkgit:git-status[1] and
-	linkgit:git-commit[1] .  If set to "false", rename detection is
-	disabled. If set to "true", basic rename detection is enabled.
-	If set to "copies" or "copy", Git will detect copies, as well.
-	Defaults to the value of diff.renames.
-
-status.showStash::
-	If set to true, linkgit:git-status[1] will display the number of
-	entries currently stashed away.
-	Defaults to false.
-
-status.showUntrackedFiles::
-	By default, linkgit:git-status[1] and linkgit:git-commit[1] show
-	files which are not currently tracked by Git. Directories which
-	contain only untracked files, are shown with the directory name
-	only. Showing untracked files means that Git needs to lstat() all
-	the files in the whole repository, which might be slow on some
-	systems. So, this variable controls how the commands displays
-	the untracked files. Possible values are:
-+
---
-* `no` - Show no untracked files.
-* `normal` - Show untracked files and directories.
-* `all` - Show also individual files in untracked directories.
---
-+
-If this variable is not specified, it defaults to 'normal'.
-This variable can be overridden with the -u|--untracked-files option
-of linkgit:git-status[1] and linkgit:git-commit[1].
-
-status.submoduleSummary::
-	Defaults to false.
-	If this is set to a non zero number or true (identical to -1 or an
-	unlimited number), the submodule summary will be enabled and a
-	summary of commits for modified submodules will be shown (see
-	--summary-limit option of linkgit:git-submodule[1]). Please note
-	that the summary output command will be suppressed for all
-	submodules when `diff.ignoreSubmodules` is set to 'all' or only
-	for those submodules where `submodule.<name>.ignore=all`. The only
-	exception to that rule is that status and commit will show staged
-	submodule changes. To
-	also view the summary for ignored submodules you can either use
-	the --ignore-submodules=dirty command-line option or the 'git
-	submodule summary' command, which shows a similar output but does
-	not honor these settings.
-
-stash.showPatch::
-	If this is set to true, the `git stash show` command without an
-	option will show the stash entry in patch form.  Defaults to false.
-	See description of 'show' command in linkgit:git-stash[1].
-
-stash.showStat::
-	If this is set to true, the `git stash show` command without an
-	option will show diffstat of the stash entry.  Defaults to true.
-	See description of 'show' command in linkgit:git-stash[1].
-
-submodule.<name>.url::
-	The URL for a submodule. This variable is copied from the .gitmodules
-	file to the git config via 'git submodule init'. The user can change
-	the configured URL before obtaining the submodule via 'git submodule
-	update'. If neither submodule.<name>.active or submodule.active are
-	set, the presence of this variable is used as a fallback to indicate
-	whether the submodule is of interest to git commands.
-	See linkgit:git-submodule[1] and linkgit:gitmodules[5] for details.
-
-submodule.<name>.update::
-	The method by which a submodule is updated by 'git submodule update',
-	which is the only affected command, others such as
-	'git checkout --recurse-submodules' are unaffected. It exists for
-	historical reasons, when 'git submodule' was the only command to
-	interact with submodules; settings like `submodule.active`
-	and `pull.rebase` are more specific. It is populated by
-	`git submodule init` from the linkgit:gitmodules[5] file.
-	See description of 'update' command in linkgit:git-submodule[1].
-
-submodule.<name>.branch::
-	The remote branch name for a submodule, used by `git submodule
-	update --remote`.  Set this option to override the value found in
-	the `.gitmodules` file.  See linkgit:git-submodule[1] and
-	linkgit:gitmodules[5] for details.
-
-submodule.<name>.fetchRecurseSubmodules::
-	This option can be used to control recursive fetching of this
-	submodule. It can be overridden by using the --[no-]recurse-submodules
-	command-line option to "git fetch" and "git pull".
-	This setting will override that from in the linkgit:gitmodules[5]
-	file.
-
-submodule.<name>.ignore::
-	Defines under what circumstances "git status" and the diff family show
-	a submodule as modified. When set to "all", it will never be considered
-	modified (but it will nonetheless show up in the output of status and
-	commit when it has been staged), "dirty" will ignore all changes
-	to the submodules work tree and
-	takes only differences between the HEAD of the submodule and the commit
-	recorded in the superproject into account. "untracked" will additionally
-	let submodules with modified tracked files in their work tree show up.
-	Using "none" (the default when this option is not set) also shows
-	submodules that have untracked files in their work tree as changed.
-	This setting overrides any setting made in .gitmodules for this submodule,
-	both settings can be overridden on the command line by using the
-	"--ignore-submodules" option. The 'git submodule' commands are not
-	affected by this setting.
-
-submodule.<name>.active::
-	Boolean value indicating if the submodule is of interest to git
-	commands.  This config option takes precedence over the
-	submodule.active config option.
-
-submodule.active::
-	A repeated field which contains a pathspec used to match against a
-	submodule's path to determine if the submodule is of interest to git
-	commands.
-
-submodule.recurse::
-	Specifies if commands recurse into submodules by default. This
-	applies to all commands that have a `--recurse-submodules` option,
-	except `clone`.
-	Defaults to false.
-
-submodule.fetchJobs::
-	Specifies how many submodules are fetched/cloned at the same time.
-	A positive integer allows up to that number of submodules fetched
-	in parallel. A value of 0 will give some reasonable default.
-	If unset, it defaults to 1.
-
-submodule.alternateLocation::
-	Specifies how the submodules obtain alternates when submodules are
-	cloned. Possible values are `no`, `superproject`.
-	By default `no` is assumed, which doesn't add references. When the
-	value is set to `superproject` the submodule to be cloned computes
-	its alternates location relative to the superprojects alternate.
-
-submodule.alternateErrorStrategy::
-	Specifies how to treat errors with the alternates for a submodule
-	as computed via `submodule.alternateLocation`. Possible values are
-	`ignore`, `info`, `die`. Default is `die`.
-
-tag.forceSignAnnotated::
-	A boolean to specify whether annotated tags created should be GPG signed.
-	If `--annotate` is specified on the command line, it takes
-	precedence over this option.
-
-tag.sort::
-	This variable controls the sort ordering of tags when displayed by
-	linkgit:git-tag[1]. Without the "--sort=<value>" option provided, the
-	value of this variable will be used as the default.
-
-tar.umask::
-	This variable can be used to restrict the permission bits of
-	tar archive entries.  The default is 0002, which turns off the
-	world write bit.  The special value "user" indicates that the
-	archiving user's umask will be used instead.  See umask(2) and
-	linkgit:git-archive[1].
-
-transfer.fsckObjects::
-	When `fetch.fsckObjects` or `receive.fsckObjects` are
-	not set, the value of this variable is used instead.
-	Defaults to false.
-
-transfer.hideRefs::
-	String(s) `receive-pack` and `upload-pack` use to decide which
-	refs to omit from their initial advertisements.  Use more than
-	one definition to specify multiple prefix strings. A ref that is
-	under the hierarchies listed in the value of this variable is
-	excluded, and is hidden when responding to `git push` or `git
-	fetch`.  See `receive.hideRefs` and `uploadpack.hideRefs` for
-	program-specific versions of this config.
-+
-You may also include a `!` in front of the ref name to negate the entry,
-explicitly exposing it, even if an earlier entry marked it as hidden.
-If you have multiple hideRefs values, later entries override earlier ones
-(and entries in more-specific config files override less-specific ones).
-+
-If a namespace is in use, the namespace prefix is stripped from each
-reference before it is matched against `transfer.hiderefs` patterns.
-For example, if `refs/heads/master` is specified in `transfer.hideRefs` and
-the current namespace is `foo`, then `refs/namespaces/foo/refs/heads/master`
-is omitted from the advertisements but `refs/heads/master` and
-`refs/namespaces/bar/refs/heads/master` are still advertised as so-called
-"have" lines. In order to match refs before stripping, add a `^` in front of
-the ref name. If you combine `!` and `^`, `!` must be specified first.
-+
-Even if you hide refs, a client may still be able to steal the target
-objects via the techniques described in the "SECURITY" section of the
-linkgit:gitnamespaces[7] man page; it's best to keep private data in a
-separate repository.
-
-transfer.unpackLimit::
-	When `fetch.unpackLimit` or `receive.unpackLimit` are
-	not set, the value of this variable is used instead.
-	The default value is 100.
-
-uploadarchive.allowUnreachable::
-	If true, allow clients to use `git archive --remote` to request
-	any tree, whether reachable from the ref tips or not. See the
-	discussion in the "SECURITY" section of
-	linkgit:git-upload-archive[1] for more details. Defaults to
-	`false`.
-
-uploadpack.hideRefs::
-	This variable is the same as `transfer.hideRefs`, but applies
-	only to `upload-pack` (and so affects only fetches, not pushes).
-	An attempt to fetch a hidden ref by `git fetch` will fail.  See
-	also `uploadpack.allowTipSHA1InWant`.
-
-uploadpack.allowTipSHA1InWant::
-	When `uploadpack.hideRefs` is in effect, allow `upload-pack`
-	to accept a fetch request that asks for an object at the tip
-	of a hidden ref (by default, such a request is rejected).
-	See also `uploadpack.hideRefs`.  Even if this is false, a client
-	may be able to steal objects via the techniques described in the
-	"SECURITY" section of the linkgit:gitnamespaces[7] man page; it's
-	best to keep private data in a separate repository.
-
-uploadpack.allowReachableSHA1InWant::
-	Allow `upload-pack` to accept a fetch request that asks for an
-	object that is reachable from any ref tip. However, note that
-	calculating object reachability is computationally expensive.
-	Defaults to `false`.  Even if this is false, a client may be able
-	to steal objects via the techniques described in the "SECURITY"
-	section of the linkgit:gitnamespaces[7] man page; it's best to
-	keep private data in a separate repository.
-
-uploadpack.allowAnySHA1InWant::
-	Allow `upload-pack` to accept a fetch request that asks for any
-	object at all.
-	Defaults to `false`.
-
-uploadpack.keepAlive::
-	When `upload-pack` has started `pack-objects`, there may be a
-	quiet period while `pack-objects` prepares the pack. Normally
-	it would output progress information, but if `--quiet` was used
-	for the fetch, `pack-objects` will output nothing at all until
-	the pack data begins. Some clients and networks may consider
-	the server to be hung and give up. Setting this option instructs
-	`upload-pack` to send an empty keepalive packet every
-	`uploadpack.keepAlive` seconds. Setting this option to 0
-	disables keepalive packets entirely. The default is 5 seconds.
-
-uploadpack.packObjectsHook::
-	If this option is set, when `upload-pack` would run
-	`git pack-objects` to create a packfile for a client, it will
-	run this shell command instead.  The `pack-objects` command and
-	arguments it _would_ have run (including the `git pack-objects`
-	at the beginning) are appended to the shell command. The stdin
-	and stdout of the hook are treated as if `pack-objects` itself
-	was run. I.e., `upload-pack` will feed input intended for
-	`pack-objects` to the hook, and expects a completed packfile on
-	stdout.
-
-uploadpack.allowFilter::
-	If this option is set, `upload-pack` will support partial
-	clone and partial fetch object filtering.
-+
-Note that this configuration variable is ignored if it is seen in the
-repository-level config (this is a safety measure against fetching from
-untrusted repositories).
-
-url.<base>.insteadOf::
-	Any URL that starts with this value will be rewritten to
-	start, instead, with <base>. In cases where some site serves a
-	large number of repositories, and serves them with multiple
-	access methods, and some users need to use different access
-	methods, this feature allows people to specify any of the
-	equivalent URLs and have Git automatically rewrite the URL to
-	the best alternative for the particular user, even for a
-	never-before-seen repository on the site.  When more than one
-	insteadOf strings match a given URL, the longest match is used.
-+
-Note that any protocol restrictions will be applied to the rewritten
-URL. If the rewrite changes the URL to use a custom protocol or remote
-helper, you may need to adjust the `protocol.*.allow` config to permit
-the request.  In particular, protocols you expect to use for submodules
-must be set to `always` rather than the default of `user`. See the
-description of `protocol.allow` above.
-
-url.<base>.pushInsteadOf::
-	Any URL that starts with this value will not be pushed to;
-	instead, it will be rewritten to start with <base>, and the
-	resulting URL will be pushed to. In cases where some site serves
-	a large number of repositories, and serves them with multiple
-	access methods, some of which do not allow push, this feature
-	allows people to specify a pull-only URL and have Git
-	automatically use an appropriate URL to push, even for a
-	never-before-seen repository on the site.  When more than one
-	pushInsteadOf strings match a given URL, the longest match is
-	used.  If a remote has an explicit pushurl, Git will ignore this
-	setting for that remote.
-
-user.email::
-	Your email address to be recorded in any newly created commits.
-	Can be overridden by the `GIT_AUTHOR_EMAIL`, `GIT_COMMITTER_EMAIL`, and
-	`EMAIL` environment variables.  See linkgit:git-commit-tree[1].
-
-user.name::
-	Your full name to be recorded in any newly created commits.
-	Can be overridden by the `GIT_AUTHOR_NAME` and `GIT_COMMITTER_NAME`
-	environment variables.  See linkgit:git-commit-tree[1].
-
-user.useConfigOnly::
-	Instruct Git to avoid trying to guess defaults for `user.email`
-	and `user.name`, and instead retrieve the values only from the
-	configuration. For example, if you have multiple email addresses
-	and would like to use a different one for each repository, then
-	with this configuration option set to `true` in the global config
-	along with a name, Git will prompt you to set up an email before
-	making new commits in a newly cloned repository.
-	Defaults to `false`.
-
-user.signingKey::
-	If linkgit:git-tag[1] or linkgit:git-commit[1] is not selecting the
-	key you want it to automatically when creating a signed tag or
-	commit, you can override the default selection with this variable.
-	This option is passed unchanged to gpg's --local-user parameter,
-	so you may specify a key using any method that gpg supports.
-
-versionsort.prereleaseSuffix (deprecated)::
-	Deprecated alias for `versionsort.suffix`.  Ignored if
-	`versionsort.suffix` is set.
-
-versionsort.suffix::
-	Even when version sort is used in linkgit:git-tag[1], tagnames
-	with the same base version but different suffixes are still sorted
-	lexicographically, resulting e.g. in prerelease tags appearing
-	after the main release (e.g. "1.0-rc1" after "1.0").  This
-	variable can be specified to determine the sorting order of tags
-	with different suffixes.
-+
-By specifying a single suffix in this variable, any tagname containing
-that suffix will appear before the corresponding main release.  E.g. if
-the variable is set to "-rc", then all "1.0-rcX" tags will appear before
-"1.0".  If specified multiple times, once per suffix, then the order of
-suffixes in the configuration will determine the sorting order of tagnames
-with those suffixes.  E.g. if "-pre" appears before "-rc" in the
-configuration, then all "1.0-preX" tags will be listed before any
-"1.0-rcX" tags.  The placement of the main release tag relative to tags
-with various suffixes can be determined by specifying the empty suffix
-among those other suffixes.  E.g. if the suffixes "-rc", "", "-ck" and
-"-bfs" appear in the configuration in this order, then all "v4.8-rcX" tags
-are listed first, followed by "v4.8", then "v4.8-ckX" and finally
-"v4.8-bfsX".
-+
-If more than one suffixes match the same tagname, then that tagname will
-be sorted according to the suffix which starts at the earliest position in
-the tagname.  If more than one different matching suffixes start at
-that earliest position, then that tagname will be sorted according to the
-longest of those suffixes.
-The sorting order between different suffixes is undefined if they are
-in multiple config files.
-
-web.browser::
-	Specify a web browser that may be used by some commands.
-	Currently only linkgit:git-instaweb[1] and linkgit:git-help[1]
-	may use it.
-
-worktree.guessRemote::
-	With `add`, if no branch argument, and neither of `-b` nor
-	`-B` nor `--detach` are given, the command defaults to
-	creating a new branch from HEAD.  If `worktree.guessRemote` is
-	set to true, `worktree add` tries to find a remote-tracking
-	branch whose name uniquely matches the new branch name.  If
-	such a branch exists, it is checked out and set as "upstream"
-	for the new branch.  If no such match can be found, it falls
-	back to creating a new branch from the current HEAD.
+include::config/init.txt[]
+
+include::config/instaweb.txt[]
+
+include::config/interactive.txt[]
+
+include::config/log.txt[]
+
+include::config/mailinfo.txt[]
+
+include::config/mailmap.txt[]
+
+include::config/man.txt[]
+
+include::config/merge.txt[]
+
+include::config/mergetool.txt[]
+
+include::config/notes.txt[]
+
+include::config/pack.txt[]
+
+include::config/pager.txt[]
+
+include::config/pretty.txt[]
+
+include::config/protocol.txt[]
+
+include::config/pull.txt[]
+
+include::config/push.txt[]
+
+include::config/rebase.txt[]
+
+include::config/receive.txt[]
+
+include::config/remote.txt[]
+
+include::config/remotes.txt[]
+
+include::config/repack.txt[]
+
+include::config/rerere.txt[]
+
+include::config/reset.txt[]
+
+include::config/sendemail.txt[]
+
+include::config/sequencer.txt[]
+
+include::config/showbranch.txt[]
+
+include::config/splitindex.txt[]
+
+include::config/ssh.txt[]
+
+include::config/status.txt[]
+
+include::config/stash.txt[]
+
+include::config/submodule.txt[]
+
+include::config/tag.txt[]
+
+include::config/trace2.txt[]
+
+include::config/transfer.txt[]
+
+include::config/uploadarchive.txt[]
+
+include::config/uploadpack.txt[]
+
+include::config/url.txt[]
+
+include::config/user.txt[]
+
+include::config/versionsort.txt[]
+
+include::config/web.txt[]
+
+include::config/worktree.txt[]
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/diff-config.txt 1.2.3+git2.25.1-1/git/Documentation/diff-config.txt
--- 1.2.1+git2.18.0-1/git/Documentation/diff-config.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/diff-config.txt	1970-01-01 00:00:00.000000000 +0000
@@ -1,210 +0,0 @@
-diff.autoRefreshIndex::
-	When using 'git diff' to compare with work tree
-	files, do not consider stat-only change as changed.
-	Instead, silently run `git update-index --refresh` to
-	update the cached stat information for paths whose
-	contents in the work tree match the contents in the
-	index.  This option defaults to true.  Note that this
-	affects only 'git diff' Porcelain, and not lower level
-	'diff' commands such as 'git diff-files'.
-
-diff.dirstat::
-	A comma separated list of `--dirstat` parameters specifying the
-	default behavior of the `--dirstat` option to linkgit:git-diff[1]`
-	and friends. The defaults can be overridden on the command line
-	(using `--dirstat=<param1,param2,...>`). The fallback defaults
-	(when not changed by `diff.dirstat`) are `changes,noncumulative,3`.
-	The following parameters are available:
-+
---
-`changes`;;
-	Compute the dirstat numbers by counting the lines that have been
-	removed from the source, or added to the destination. This ignores
-	the amount of pure code movements within a file.  In other words,
-	rearranging lines in a file is not counted as much as other changes.
-	This is the default behavior when no parameter is given.
-`lines`;;
-	Compute the dirstat numbers by doing the regular line-based diff
-	analysis, and summing the removed/added line counts. (For binary
-	files, count 64-byte chunks instead, since binary files have no
-	natural concept of lines). This is a more expensive `--dirstat`
-	behavior than the `changes` behavior, but it does count rearranged
-	lines within a file as much as other changes. The resulting output
-	is consistent with what you get from the other `--*stat` options.
-`files`;;
-	Compute the dirstat numbers by counting the number of files changed.
-	Each changed file counts equally in the dirstat analysis. This is
-	the computationally cheapest `--dirstat` behavior, since it does
-	not have to look at the file contents at all.
-`cumulative`;;
-	Count changes in a child directory for the parent directory as well.
-	Note that when using `cumulative`, the sum of the percentages
-	reported may exceed 100%. The default (non-cumulative) behavior can
-	be specified with the `noncumulative` parameter.
-<limit>;;
-	An integer parameter specifies a cut-off percent (3% by default).
-	Directories contributing less than this percentage of the changes
-	are not shown in the output.
---
-+
-Example: The following will count changed files, while ignoring
-directories with less than 10% of the total amount of changed files,
-and accumulating child directory counts in the parent directories:
-`files,10,cumulative`.
-
-diff.statGraphWidth::
-	Limit the width of the graph part in --stat output. If set, applies
-	to all commands generating --stat output except format-patch.
-
-diff.context::
-	Generate diffs with <n> lines of context instead of the default
-	of 3. This value is overridden by the -U option.
-
-diff.interHunkContext::
-	Show the context between diff hunks, up to the specified number
-	of lines, thereby fusing the hunks that are close to each other.
-	This value serves as the default for the `--inter-hunk-context`
-	command line option.
-
-diff.external::
-	If this config variable is set, diff generation is not
-	performed using the internal diff machinery, but using the
-	given command.  Can be overridden with the `GIT_EXTERNAL_DIFF'
-	environment variable.  The command is called with parameters
-	as described under "git Diffs" in linkgit:git[1].  Note: if
-	you want to use an external diff program only on a subset of
-	your files, you	might want to use linkgit:gitattributes[5] instead.
-
-diff.ignoreSubmodules::
-	Sets the default value of --ignore-submodules. Note that this
-	affects only 'git diff' Porcelain, and not lower level 'diff'
-	commands such as 'git diff-files'. 'git checkout' also honors
-	this setting when reporting uncommitted changes. Setting it to
-	'all' disables the submodule summary normally shown by 'git commit'
-	and 'git status' when `status.submoduleSummary` is set unless it is
-	overridden by using the --ignore-submodules command-line option.
-	The 'git submodule' commands are not affected by this setting.
-
-diff.mnemonicPrefix::
-	If set, 'git diff' uses a prefix pair that is different from the
-	standard "a/" and "b/" depending on what is being compared.  When
-	this configuration is in effect, reverse diff output also swaps
-	the order of the prefixes:
-`git diff`;;
-	compares the (i)ndex and the (w)ork tree;
-`git diff HEAD`;;
-	 compares a (c)ommit and the (w)ork tree;
-`git diff --cached`;;
-	compares a (c)ommit and the (i)ndex;
-`git diff HEAD:file1 file2`;;
-	compares an (o)bject and a (w)ork tree entity;
-`git diff --no-index a b`;;
-	compares two non-git things (1) and (2).
-
-diff.noprefix::
-	If set, 'git diff' does not show any source or destination prefix.
-
-diff.orderFile::
-	File indicating how to order files within a diff.
-	See the '-O' option to linkgit:git-diff[1] for details.
-	If `diff.orderFile` is a relative pathname, it is treated as
-	relative to the top of the working tree.
-
-diff.renameLimit::
-	The number of files to consider when performing the copy/rename
-	detection; equivalent to the 'git diff' option `-l`. This setting
-	has no effect if rename detection is turned off.
-
-diff.renames::
-	Whether and how Git detects renames.  If set to "false",
-	rename detection is disabled. If set to "true", basic rename
-	detection is enabled.  If set to "copies" or "copy", Git will
-	detect copies, as well.  Defaults to true.  Note that this
-	affects only 'git diff' Porcelain like linkgit:git-diff[1] and
-	linkgit:git-log[1], and not lower level commands such as
-	linkgit:git-diff-files[1].
-
-diff.suppressBlankEmpty::
-	A boolean to inhibit the standard behavior of printing a space
-	before each empty output line. Defaults to false.
-
-diff.submodule::
-	Specify the format in which differences in submodules are
-	shown.  The "short" format just shows the names of the commits
-	at the beginning and end of the range. The "log" format lists
-	the commits in the range like linkgit:git-submodule[1] `summary`
-	does. The "diff" format shows an inline diff of the changed
-	contents of the submodule. Defaults to "short".
-
-diff.wordRegex::
-	A POSIX Extended Regular Expression used to determine what is a "word"
-	when performing word-by-word difference calculations.  Character
-	sequences that match the regular expression are "words", all other
-	characters are *ignorable* whitespace.
-
-diff.<driver>.command::
-	The custom diff driver command.  See linkgit:gitattributes[5]
-	for details.
-
-diff.<driver>.xfuncname::
-	The regular expression that the diff driver should use to
-	recognize the hunk header.  A built-in pattern may also be used.
-	See linkgit:gitattributes[5] for details.
-
-diff.<driver>.binary::
-	Set this option to true to make the diff driver treat files as
-	binary.  See linkgit:gitattributes[5] for details.
-
-diff.<driver>.textconv::
-	The command that the diff driver should call to generate the
-	text-converted version of a file.  The result of the
-	conversion is used to generate a human-readable diff.  See
-	linkgit:gitattributes[5] for details.
-
-diff.<driver>.wordRegex::
-	The regular expression that the diff driver should use to
-	split words in a line.  See linkgit:gitattributes[5] for
-	details.
-
-diff.<driver>.cachetextconv::
-	Set this option to true to make the diff driver cache the text
-	conversion outputs.  See linkgit:gitattributes[5] for details.
-
-diff.tool::
-	Controls which diff tool is used by linkgit:git-difftool[1].
-	This variable overrides the value configured in `merge.tool`.
-	The list below shows the valid built-in values.
-	Any other value is treated as a custom diff tool and requires
-	that a corresponding difftool.<tool>.cmd variable is defined.
-
-include::mergetools-diff.txt[]
-
-diff.indentHeuristic::
-	Set this option to `true` to enable experimental heuristics
-	that shift diff hunk boundaries to make patches easier to read.
-
-diff.algorithm::
-	Choose a diff algorithm.  The variants are as follows:
-+
---
-`default`, `myers`;;
-	The basic greedy diff algorithm. Currently, this is the default.
-`minimal`;;
-	Spend extra time to make sure the smallest possible diff is
-	produced.
-`patience`;;
-	Use "patience diff" algorithm when generating patches.
-`histogram`;;
-	This algorithm extends the patience algorithm to "support
-	low-occurrence common elements".
---
-+
-
-diff.wsErrorHighlight::
-	Highlight whitespace errors in the `context`, `old` or `new`
-	lines of the diff.  Multiple values are separated by comma,
-	`none` resets previous values, `default` reset the list to
-	`new` and `all` is a shorthand for `old,new,context`.  The
-	whitespace errors are colored with `color.diff.whitespace`.
-	The command line option `--ws-error-highlight=<kind>`
-	overrides this setting.
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/diff-format.txt 1.2.3+git2.25.1-1/git/Documentation/diff-format.txt
--- 1.2.1+git2.18.0-1/git/Documentation/diff-format.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/diff-format.txt	2020-02-17 04:47:35.000000000 +0000
@@ -26,12 +26,12 @@ line per changed file.
 An output line is formatted this way:
 
 ------------------------------------------------
-in-place edit  :100644 100644 bcd1234... 0123456... M file0
-copy-edit      :100644 100644 abcd123... 1234567... C68 file1 file2
-rename-edit    :100644 100644 abcd123... 1234567... R86 file1 file3
-create         :000000 100644 0000000... 1234567... A file4
-delete         :100644 000000 1234567... 0000000... D file5
-unmerged       :000000 000000 0000000... 0000000... U file6
+in-place edit  :100644 100644 bcd1234 0123456 M file0
+copy-edit      :100644 100644 abcd123 1234567 C68 file1 file2
+rename-edit    :100644 100644 abcd123 1234567 R86 file1 file3
+create         :000000 100644 0000000 1234567 A file4
+delete         :100644 000000 1234567 0000000 D file5
+unmerged       :000000 000000 0000000 0000000 U file6
 ------------------------------------------------
 
 That is, from the left to the right:
@@ -61,7 +61,7 @@ Possible status letters are:
 - R: renaming of a file
 - T: change in the type of the file
 - U: file is unmerged (you must complete the merge before it can
-be committed)
+  be committed)
 - X: "unknown" change type (most probably a bug, please report it)
 
 Status letters C and R are always followed by a score (denoting the
@@ -75,7 +75,7 @@ and it is out of sync with the index.
 Example:
 
 ------------------------------------------------
-:100644 100644 5be4a4...... 000000...... M file.c
+:100644 100644 5be4a4a 0000000 M file.c
 ------------------------------------------------
 
 Without the `-z` option, pathnames with "unusual" characters are
@@ -95,12 +95,26 @@ from the format described above in the f
 . there are more "src" modes and "src" sha1
 . status is concatenated status characters for each parent
 . no optional "score" number
-. single path, only for "dst"
+. tab-separated pathname(s) of the file
 
-Example:
+For `-c` and `--cc`, only the destination or final path is shown even
+if the file was renamed on any side of history.  With
+`--combined-all-paths`, the name of the path in each parent is shown
+followed by the name of the path in the merge commit.
+
+Examples for `-c` and `--cc` without `--combined-all-paths`:
+------------------------------------------------
+::100644 100644 100644 fabadb8 cc95eb0 4866510 MM	desc.c
+::100755 100755 100755 52b7a2d 6d1ac04 d2ac7d7 RM	bar.sh
+::100644 100644 100644 e07d6c5 9042e82 ee91881 RR	phooey.c
+------------------------------------------------
+
+Examples when `--combined-all-paths` added to either `-c` or `--cc`:
 
 ------------------------------------------------
-::100644 100644 100644 fabadb8... cc95eb0... 4866510... MM	describe.c
+::100644 100644 100644 fabadb8 cc95eb0 4866510 MM	desc.c	desc.c	desc.c
+::100755 100755 100755 52b7a2d 6d1ac04 d2ac7d7 RM	foo.sh	bar.sh	bar.sh
+::100644 100644 100644 e07d6c5 9042e82 ee91881 RR	fooey.c	fuey.c	phooey.c
 ------------------------------------------------
 
 Note that 'combined diff' lists only files which were modified from
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/diff-generate-patch.txt 1.2.3+git2.25.1-1/git/Documentation/diff-generate-patch.txt
--- 1.2.1+git2.18.0-1/git/Documentation/diff-generate-patch.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/diff-generate-patch.txt	2020-02-17 04:47:35.000000000 +0000
@@ -1,11 +1,15 @@
-Generating patches with -p
---------------------------
+Generating patch text with -p
+-----------------------------
 
-When "git-diff-index", "git-diff-tree", or "git-diff-files" are run
-with a `-p` option, "git diff" without the `--raw` option, or
-"git log" with the "-p" option, they
-do not produce the output described above; instead they produce a
-patch file.  You can customize the creation of such patches via the
+Running
+linkgit:git-diff[1],
+linkgit:git-log[1],
+linkgit:git-show[1],
+linkgit:git-diff-index[1],
+linkgit:git-diff-tree[1], or
+linkgit:git-diff-files[1]
+with the `-p` option produces patch text.
+You can customize the creation of patch text via the
 `GIT_EXTERNAL_DIFF` and the `GIT_DIFF_OPTS` environment variables.
 
 What the -p option produces is slightly different from the traditional
@@ -49,7 +53,7 @@ similarity index value of 100% is thus r
 files, while 100% dissimilarity means that no line from the old
 file made it into the new one.
 +
-The index line includes the SHA-1 checksum before and after the change.
+The index line includes the blob object names before and after the change.
 The <mode> is included if the file mode does not change; otherwise,
 separate lines indicate the old and the new mode.
 
@@ -70,7 +74,7 @@ separate lines indicate the old and the
       rename to a
 
 
-combined diff format
+Combined diff format
 --------------------
 
 Any diff-generating command can take the `-c` or `--cc` option to
@@ -80,7 +84,7 @@ linkgit:git-show[1]. Note also that you
 of these commands to force generation of diffs with individual parents
 of a merge.
 
-A 'combined diff' format looks like this:
+A "combined diff" format looks like this:
 
 ------------
 diff --combined describe.c
@@ -113,11 +117,11 @@ index fabadb8,cc95eb0..4866510
 ------------
 
 1.   It is preceded with a "git diff" header, that looks like
-     this (when `-c` option is used):
+     this (when the `-c` option is used):
 
        diff --combined file
 +
-or like this (when `--cc` option is used):
+or like this (when the `--cc` option is used):
 
        diff --cc file
 
@@ -143,11 +147,24 @@ copying detection) are designed to work
 Similar to two-line header for traditional 'unified' diff
 format, `/dev/null` is used to signal created or deleted
 files.
++
+However, if the --combined-all-paths option is provided, instead of a
+two-line from-file/to-file you get a N+1 line from-file/to-file header,
+where N is the number of parents in the merge commit
+
+       --- a/file
+       --- a/file
+       --- a/file
+       +++ b/file
++
+This extended format can be useful if rename or copy detection is
+active, to allow you to see the original name of the file in different
+parents.
 
 4.   Chunk header format is modified to prevent people from
      accidentally feeding it to `patch -p1`. Combined diff format
      was created for review of merge commit changes, and was not
-     meant for apply. The change is similar to the change in the
+     meant to be applied. The change is similar to the change in the
      extended 'index' header:
 
        @@@ <from-file-range> <from-file-range> <to-file-range> @@@
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/diff-options.txt 1.2.3+git2.25.1-1/git/Documentation/diff-options.txt
--- 1.2.1+git2.18.0-1/git/Documentation/diff-options.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/diff-options.txt	2020-02-17 04:47:35.000000000 +0000
@@ -36,11 +36,21 @@ endif::git-format-patch[]
 -U<n>::
 --unified=<n>::
 	Generate diffs with <n> lines of context instead of
-	the usual three.
+	the usual three. Implies `--patch`.
 ifndef::git-format-patch[]
 	Implies `-p`.
 endif::git-format-patch[]
 
+--output=<file>::
+	Output to a specific file instead of stdout.
+
+--output-indicator-new=<char>::
+--output-indicator-old=<char>::
+--output-indicator-context=<char>::
+	Specify the character used to indicate new, old or context
+	lines in the generated patch. Normally they are '+', '-' and
+	' ' respectively.
+
 ifndef::git-format-patch[]
 --raw::
 ifndef::git-log[]
@@ -148,6 +158,7 @@ These parameters can also be set individ
 	number of modified files, as well as number of added and deleted
 	lines.
 
+-X[<param1,param2,...>]::
 --dirstat[=<param1,param2,...>]::
 	Output the distribution of relative amount of changes for each
 	sub-directory. The behavior of `--dirstat` can be customized by
@@ -192,6 +203,12 @@ directories with less than 10% of the to
 and accumulating child directory counts in the parent directories:
 `--dirstat=files,10,cumulative`.
 
+--cumulative::
+	Synonym for --dirstat=cumulative
+
+--dirstat-by-file[=<param1,param2>...]::
+	Synonym for --dirstat=files,param1,param2...
+
 --summary::
 	Output a condensed summary of extended header information
 	such as creations, renames and mode changes.
@@ -276,18 +293,59 @@ plain::
 	that are added somewhere else in the diff. This mode picks up any
 	moved line, but it is not very useful in a review to determine
 	if a block of code was moved without permutation.
-zebra::
+blocks::
 	Blocks of moved text of at least 20 alphanumeric characters
 	are detected greedily. The detected blocks are
-	painted using either the 'color.diff.{old,new}Moved' color or
+	painted using either the 'color.diff.{old,new}Moved' color.
+	Adjacent blocks cannot be told apart.
+zebra::
+	Blocks of moved text are detected as in 'blocks' mode. The blocks
+	are painted using either the 'color.diff.{old,new}Moved' color or
 	'color.diff.{old,new}MovedAlternative'. The change between
 	the two colors indicates that a new block was detected.
-dimmed_zebra::
+dimmed-zebra::
 	Similar to 'zebra', but additional dimming of uninteresting parts
 	of moved code is performed. The bordering lines of two adjacent
 	blocks are considered interesting, the rest is uninteresting.
+	`dimmed_zebra` is a deprecated synonym.
 --
 
+--no-color-moved::
+	Turn off move detection. This can be used to override configuration
+	settings. It is the same as `--color-moved=no`.
+
+--color-moved-ws=<modes>::
+	This configures how whitespace is ignored when performing the
+	move detection for `--color-moved`.
+ifdef::git-diff[]
+	It can be set by the `diff.colorMovedWS` configuration setting.
+endif::git-diff[]
+	These modes can be given as a comma separated list:
++
+--
+no::
+	Do not ignore whitespace when performing move detection.
+ignore-space-at-eol::
+	Ignore changes in whitespace at EOL.
+ignore-space-change::
+	Ignore changes in amount of whitespace.  This ignores whitespace
+	at line end, and considers all other sequences of one or
+	more whitespace characters to be equivalent.
+ignore-all-space::
+	Ignore whitespace when comparing lines. This ignores differences
+	even if one line has whitespace where the other line has none.
+allow-indentation-change::
+	Initially ignore any whitespace in the move detection, then
+	group the moved code blocks only into a block if the change in
+	whitespace is the same per line. This is incompatible with the
+	other modes.
+--
+
+--no-color-moved-ws::
+	Do not ignore whitespace when performing move detection. This can be
+	used to override configuration settings. It is the same as
+	`--color-moved-ws=no`.
+
 --word-diff[=<mode>]::
 	Show a word diff, using the <mode> to delimit changed words.
 	By default, words are delimited by whitespace; see
@@ -345,6 +403,9 @@ endif::git-format-patch[]
 	Turn off rename detection, even when the configuration
 	file gives the default to do so.
 
+--[no-]rename-empty::
+	Whether to use empty blobs as rename source.
+
 ifndef::git-format-patch[]
 --check::
 	Warn if changes introduce conflict markers or whitespace errors.
@@ -375,7 +436,7 @@ endif::git-format-patch[]
 
 --binary::
 	In addition to `--full-index`, output a binary diff that
-	can be applied with `git-apply`.
+	can be applied with `git-apply`. Implies `--patch`.
 
 --abbrev[=<n>]::
 	Instead of showing the full 40-byte hexadecimal object
@@ -494,6 +555,8 @@ struct), and want to know the history of
 came into being: use the feature iteratively to feed the interesting
 block in the preimage back into `-S`, and keep going until you get the
 very first version of the block.
++
+Binary files are searched as well.
 
 -G<regex>::
 	Look for differences whose patch text contains added/removed
@@ -504,15 +567,18 @@ To illustrate the difference between `-S
 file:
 +
 ----
-+    return !regexec(regexp, two->ptr, 1, &regmatch, 0);
++    return frotz(nitfol, two->ptr, 1, 0);
 ...
--    hit = !regexec(regexp, mf2.ptr, 1, &regmatch, 0);
+-    hit = frotz(nitfol, mf2.ptr, 1, 0);
 ----
 +
-While `git log -G"regexec\(regexp"` will show this commit, `git log
--S"regexec\(regexp" --pickaxe-regex` will not (because the number of
+While `git log -G"frotz\(nitfol"` will show this commit, `git log
+-S"frotz\(nitfol" --pickaxe-regex` will not (because the number of
 occurrences of that string did not change).
 +
+Unless `--text` is supplied patches of binary files without a textconv
+filter will be ignored.
++
 See the 'pickaxe' entry in linkgit:gitdiffcore[7] for more
 information.
 
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/doc-diff 1.2.3+git2.25.1-1/git/Documentation/doc-diff
--- 1.2.1+git2.18.0-1/git/Documentation/doc-diff	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/doc-diff	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,186 @@
+#!/bin/sh
+#
+# Build two documentation trees and diff the resulting formatted output.
+# Compared to a source diff, this can reveal mistakes in the formatting.
+# For example:
+#
+#   ./doc-diff origin/master HEAD
+#
+# would show the differences introduced by a branch based on master.
+
+OPTIONS_SPEC="\
+doc-diff [options] <from> <to> [-- <diff-options>]
+doc-diff (-c|--clean)
+--
+j=n			parallel argument to pass to make
+f			force rebuild; do not rely on cached results
+c,clean			cleanup temporary working files
+from-asciidoc		use asciidoc with the 'from'-commit
+from-asciidoctor	use asciidoctor with the 'from'-commit
+asciidoc		use asciidoc with both commits
+to-asciidoc		use asciidoc with the 'to'-commit
+to-asciidoctor		use asciidoctor with the 'to'-commit
+asciidoctor		use asciidoctor with both commits
+cut-footer		cut away footer
+"
+SUBDIRECTORY_OK=1
+. "$(git --exec-path)/git-sh-setup"
+
+parallel=
+force=
+clean=
+from_program=
+to_program=
+cut_footer=
+while test $# -gt 0
+do
+	case "$1" in
+	-j)
+		parallel=$2; shift ;;
+	-c|--clean)
+		clean=t ;;
+	-f)
+		force=t ;;
+	--from-asciidoctor)
+		from_program=-asciidoctor ;;
+	--to-asciidoctor)
+		to_program=-asciidoctor ;;
+	--asciidoctor)
+		from_program=-asciidoctor
+		to_program=-asciidoctor ;;
+	--from-asciidoc)
+		from_program=-asciidoc ;;
+	--to-asciidoc)
+		to_program=-asciidoc ;;
+	--asciidoc)
+		from_program=-asciidoc
+		to_program=-asciidoc ;;
+	--cut-footer)
+		cut_footer=-cut-footer ;;
+	--)
+		shift; break ;;
+	*)
+		usage ;;
+	esac
+	shift
+done
+
+tmp="$(git rev-parse --show-toplevel)/Documentation/tmp-doc-diff" || exit 1
+
+if test -n "$clean"
+then
+	test $# -eq 0 || usage
+	git worktree remove --force "$tmp/worktree" 2>/dev/null
+	rm -rf "$tmp"
+	exit 0
+fi
+
+if test -z "$parallel"
+then
+	parallel=$(getconf _NPROCESSORS_ONLN 2>/dev/null)
+	if test $? != 0 || test -z "$parallel"
+	then
+		parallel=1
+	fi
+fi
+
+test $# -gt 1 || usage
+from=$1; shift
+to=$1; shift
+
+from_oid=$(git rev-parse --verify "$from") || exit 1
+to_oid=$(git rev-parse --verify "$to") || exit 1
+
+if test -n "$force"
+then
+	rm -rf "$tmp"
+fi
+
+# We'll do both builds in a single worktree, which lets "make" reuse
+# results that don't differ between the two trees.
+if ! test -d "$tmp/worktree"
+then
+	git worktree add -f --detach "$tmp/worktree" "$from" &&
+	dots=$(echo "$tmp/worktree" | sed 's#[^/]*#..#g') &&
+	ln -s "$dots/config.mak" "$tmp/worktree/config.mak"
+fi
+
+construct_makemanflags () {
+	if test "$1" = "-asciidoc"
+	then
+		echo USE_ASCIIDOCTOR=
+	elif test "$1" = "-asciidoctor"
+	then
+		echo USE_ASCIIDOCTOR=YesPlease
+	fi
+}
+
+from_makemanflags=$(construct_makemanflags "$from_program") &&
+to_makemanflags=$(construct_makemanflags "$to_program") &&
+
+from_dir=$from_oid$from_program$cut_footer &&
+to_dir=$to_oid$to_program$cut_footer &&
+
+# generate_render_makefile <srcdir> <dstdir>
+generate_render_makefile () {
+	find "$1" -type f |
+	while read src
+	do
+		dst=$2/${src#$1/}
+		printf 'all:: %s\n' "$dst"
+		printf '%s: %s\n' "$dst" "$src"
+		printf '\t@echo >&2 "  RENDER $(notdir $@)" && \\\n'
+		printf '\tmkdir -p $(dir $@) && \\\n'
+		printf '\tMANWIDTH=80 man $< >$@+ && \\\n'
+		printf '\tmv $@+ $@\n'
+	done
+}
+
+# render_tree <committish_oid> <directory_name> <makemanflags>
+render_tree () {
+	# Skip install-man entirely if we already have an installed directory.
+	# We can't rely on make here, since "install-man" unconditionally
+	# copies the files (spending effort, but also updating timestamps that
+	# we then can't rely on during the render step). We use "mv" to make
+	# sure we don't get confused by a previous run that failed partway
+	# through.
+	oid=$1 &&
+	dname=$2 &&
+	makemanflags=$3 &&
+	if ! test -d "$tmp/installed/$dname"
+	then
+		git -C "$tmp/worktree" checkout --detach "$oid" &&
+		make -j$parallel -C "$tmp/worktree" \
+			$makemanflags \
+			GIT_VERSION=omitted \
+			SOURCE_DATE_EPOCH=0 \
+			DESTDIR="$tmp/installed/$dname+" \
+			install-man &&
+		mv "$tmp/installed/$dname+" "$tmp/installed/$dname"
+	fi &&
+
+	# As with "installed" above, we skip the render if it's already been
+	# done.  So using make here is primarily just about running in
+	# parallel.
+	if ! test -d "$tmp/rendered/$dname"
+	then
+		generate_render_makefile "$tmp/installed/$dname" \
+			"$tmp/rendered/$dname+" |
+		make -j$parallel -f - &&
+		mv "$tmp/rendered/$dname+" "$tmp/rendered/$dname"
+
+		if test "$cut_footer" = "-cut-footer"
+		then
+			for f in $(find "$tmp/rendered/$dname" -type f)
+			do
+				head -n -2 "$f" | sed -e '${/^$/d}' >"$f+" &&
+				mv "$f+" "$f" ||
+				return 1
+			done
+		fi
+	fi
+}
+
+render_tree $from_oid $from_dir $from_makemanflags &&
+render_tree $to_oid $to_dir $to_makemanflags &&
+git -C $tmp/rendered diff --no-index "$@" $from_dir $to_dir
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/fetch-options.txt 1.2.3+git2.25.1-1/git/Documentation/fetch-options.txt
--- 1.2.1+git2.18.0-1/git/Documentation/fetch-options.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/fetch-options.txt	2020-02-17 04:47:35.000000000 +0000
@@ -42,6 +42,25 @@ the current repository has the same hist
 	.git/shallow. This option updates .git/shallow and accept such
 	refs.
 
+--negotiation-tip=<commit|glob>::
+	By default, Git will report, to the server, commits reachable
+	from all local refs to find common commits in an attempt to
+	reduce the size of the to-be-received packfile. If specified,
+	Git will only report commits reachable from the given tips.
+	This is useful to speed up fetches when the user knows which
+	local ref is likely to have commits in common with the
+	upstream ref being fetched.
++
+This option may be specified more than once; if so, Git will report
+commits reachable from any of the given commits.
++
+The argument to this option may be a glob on ref names, a ref, or the (possibly
+abbreviated) SHA-1 of a commit. Specifying a glob is equivalent to specifying
+this option multiple times, one for each matching ref name.
++
+See also the `fetch.negotiationAlgorithm` configuration variable
+documented in linkgit:git-config[1].
+
 ifndef::git-pull[]
 --dry-run::
 	Show what would be done, without making any changes.
@@ -49,11 +68,16 @@ endif::git-pull[]
 
 -f::
 --force::
-	When 'git fetch' is used with `<rbranch>:<lbranch>`
-	refspec, it refuses to update the local branch
-	`<lbranch>` unless the remote branch `<rbranch>` it
-	fetches is a descendant of `<lbranch>`.  This option
-	overrides that check.
+	When 'git fetch' is used with `<src>:<dst>` refspec it may
+	refuse to update the local branch as discussed
+ifdef::git-pull[]
+	in the `<refspec>` part of the linkgit:git-fetch[1]
+	documentation.
+endif::git-pull[]
+ifndef::git-pull[]
+	in the `<refspec>` part below.
+endif::git-pull[]
+	This option overrides that check.
 
 -k::
 --keep::
@@ -64,6 +88,14 @@ ifndef::git-pull[]
 	Allow several <repository> and <group> arguments to be
 	specified. No <refspec>s may be specified.
 
+--[no-]auto-gc::
+	Run `git gc --auto` at the end to perform garbage collection
+	if needed. This is enabled by default.
+
+--[no-]write-commit-graph::
+	Write a commit-graph after fetching. This overrides the config
+	setting `fetch.writeCommitGraph`.
+
 -p::
 --prune::
 	Before fetching, remove any remote-tracking references that no
@@ -107,7 +139,10 @@ ifndef::git-pull[]
 	specified refspec (can be given more than once) to map the
 	refs to remote-tracking branches, instead of the values of
 	`remote.*.fetch` configuration variables for the remote
-	repository.  See section on "Configured Remote-tracking
+	repository.  Providing an empty `<refspec>` to the
+	`--refmap` option causes Git to ignore the configured
+	refspecs and rely entirely on the refspecs supplied as
+	command-line arguments. See section on "Configured Remote-tracking
 	Branches" for details.
 
 -t::
@@ -132,15 +167,27 @@ ifndef::git-pull[]
 
 -j::
 --jobs=<n>::
-	Number of parallel children to be used for fetching submodules.
-	Each will fetch from different submodules, such that fetching many
-	submodules will be faster. By default submodules will be fetched
-	one at a time.
+	Number of parallel children to be used for all forms of fetching.
++
+If the `--multiple` option was specified, the different remotes will be fetched
+in parallel. If multiple submodules are fetched, they will be fetched in
+parallel. To control them independently, use the config settings
+`fetch.parallel` and `submodule.fetchJobs` (see linkgit:git-config[1]).
++
+Typically, parallel recursive and multi-remote fetches will be faster. By
+default fetches are performed sequentially, not in parallel.
 
 --no-recurse-submodules::
 	Disable recursive fetching of submodules (this has the same effect as
 	using the `--recurse-submodules=no` option).
 
+--set-upstream::
+	If the remote is fetched successfully, pull and add upstream
+	(tracking) reference, used by argument-less
+	linkgit:git-pull[1] and other commands. For more information,
+	see `branch.<name>.merge` and `branch.<name>.remote` in
+	linkgit:git-config[1].
+
 --submodule-prefix=<path>::
 	Prepend <path> to paths printed in informative messages
 	such as "Fetching submodule foo".  This option is used
@@ -192,10 +239,24 @@ endif::git-pull[]
 --server-option=<option>::
 	Transmit the given string to the server when communicating using
 	protocol version 2.  The given string must not contain a NUL or LF
-	character.
+	character.  The server's handling of server options, including
+	unknown ones, is server-specific.
 	When multiple `--server-option=<option>` are given, they are all
 	sent to the other side in the order listed on the command line.
 
+--show-forced-updates::
+	By default, git checks if a branch is force-updated during
+	fetch. This can be disabled through fetch.showForcedUpdates, but
+	the --show-forced-updates option guarantees this check occurs.
+	See linkgit:git-config[1].
+
+--no-show-forced-updates::
+	By default, git checks if a branch is force-updated during
+	fetch. Pass --no-show-forced-updates or set fetch.showForcedUpdates
+	to false to skip this check for performance reasons. If used during
+	'git-pull' the --ff-only option will still check for forced updates
+	before attempting a fast-forward update. See linkgit:git-config[1].
+
 -4::
 --ipv4::
 	Use IPv4 addresses only, ignoring IPv6 addresses.
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/fmt-merge-msg-config.txt 1.2.3+git2.25.1-1/git/Documentation/fmt-merge-msg-config.txt
--- 1.2.1+git2.18.0-1/git/Documentation/fmt-merge-msg-config.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/fmt-merge-msg-config.txt	1970-01-01 00:00:00.000000000 +0000
@@ -1,10 +0,0 @@
-merge.branchdesc::
-	In addition to branch names, populate the log message with
-	the branch description text associated with them.  Defaults
-	to false.
-
-merge.log::
-	In addition to branch names, populate the log message with at
-	most the specified number of one-line descriptions from the
-	actual commits that are being merged.  Defaults to false, and
-	true is a synonym for 20.
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/git-add.txt 1.2.3+git2.25.1-1/git/Documentation/git-add.txt
--- 1.2.1+git2.18.0-1/git/Documentation/git-add.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/git-add.txt	2020-02-17 04:47:35.000000000 +0000
@@ -11,7 +11,8 @@ SYNOPSIS
 'git add' [--verbose | -v] [--dry-run | -n] [--force | -f] [--interactive | -i] [--patch | -p]
 	  [--edit | -e] [--[no-]all | --[no-]ignore-removal | [--update | -u]]
 	  [--intent-to-add | -N] [--refresh] [--ignore-errors] [--ignore-missing] [--renormalize]
-	  [--chmod=(+|-)x] [--] [<pathspec>...]
+	  [--chmod=(+|-)x] [--pathspec-from-file=<file> [--pathspec-file-nul]]
+	  [--] [<pathspec>...]
 
 DESCRIPTION
 -----------
@@ -58,9 +59,9 @@ OPTIONS
 	specifying `dir` will record not just a file `dir/file1`
 	modified in the working tree, a file `dir/file2` added to
 	the working tree, but also a file `dir/file3` removed from
-	the working tree.  Note that older versions of Git used
+	the working tree). Note that older versions of Git used
 	to ignore removed files; use `--no-all` option if you want
-	to add modified or new files but ignore removed	ones.
+	to add modified or new files but ignore removed ones.
 +
 For more details about the <pathspec> syntax, see the 'pathspec' entry
 in linkgit:gitglossary[7].
@@ -124,7 +125,7 @@ subdirectories).
 --no-ignore-removal::
 	Update the index not only where the working tree has a file
 	matching <pathspec> but also where the index already has an
-	entry.	This adds, modifies, and removes index entries to
+	entry. This adds, modifies, and removes index entries to
 	match the working tree.
 +
 If no <pathspec> is given when `-A` option is used, all
@@ -187,26 +188,30 @@ for "git add --no-all <pathspec>...", i.
 	bit is only changed in the index, the files on disk are left
 	unchanged.
 
+--pathspec-from-file=<file>::
+	Pathspec is passed in `<file>` instead of commandline args. If
+	`<file>` is exactly `-` then standard input is used. Pathspec
+	elements are separated by LF or CR/LF. Pathspec elements can be
+	quoted as explained for the configuration variable `core.quotePath`
+	(see linkgit:git-config[1]). See also `--pathspec-file-nul` and
+	global `--literal-pathspecs`.
+
+--pathspec-file-nul::
+	Only meaningful with `--pathspec-from-file`. Pathspec elements are
+	separated with NUL character and all other characters are taken
+	literally (including newlines and quotes).
+
 \--::
 	This option can be used to separate command-line options from
 	the list of files, (useful when filenames might be mistaken
 	for command-line options).
 
 
-CONFIGURATION
--------------
-
-The optional configuration variable `core.excludesFile` indicates a path to a
-file containing patterns of file names to exclude from git-add, similar to
-$GIT_DIR/info/exclude.  Patterns in the exclude file are used in addition to
-those in info/exclude.  See linkgit:gitignore[5].
-
-
 EXAMPLES
 --------
 
 * Adds content from all `*.txt` files under `Documentation` directory
-and its subdirectories:
+  and its subdirectories:
 +
 ------------
 $ git add Documentation/\*.txt
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/git-am.txt 1.2.3+git2.25.1-1/git/Documentation/git-am.txt
--- 1.2.1+git2.18.0-1/git/Documentation/git-am.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/git-am.txt	2020-02-17 04:47:35.000000000 +0000
@@ -99,6 +99,11 @@ default.   You can use `--no-utf8` to ov
 	am.threeWay configuration variable. For more information,
 	see am.threeWay in linkgit:git-config[1].
 
+--rerere-autoupdate::
+--no-rerere-autoupdate::
+	Allow the rerere mechanism to update the index with the
+	result of auto-conflict resolution if possible.
+
 --ignore-space-change::
 --ignore-whitespace::
 --whitespace=<option>::
@@ -172,7 +177,7 @@ default.   You can use `--no-utf8` to ov
 	untouched.
 
 --show-current-patch::
-	Show the patch being applied when "git am" is stopped because
+	Show the entire e-mail message "git am" has stopped at, because
 	of conflicts.
 
 DISCUSSION
@@ -185,8 +190,8 @@ the commit, after stripping common prefi
 The "Subject: " line is supposed to concisely describe what the
 commit is about in one line of text.
 
-"From: " and "Subject: " lines starting the body override the respective
-commit author name and title values taken from the headers.
+"From: ", "Date: ", and "Subject: " lines starting the body override the
+respective commit author name and title values taken from the headers.
 
 The commit message is formed by the title taken from the
 "Subject: ", a blank line and the body of the message up to
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/git-apply.txt 1.2.3+git2.25.1-1/git/Documentation/git-apply.txt
--- 1.2.1+git2.18.0-1/git/Documentation/git-apply.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/git-apply.txt	2020-02-17 04:47:35.000000000 +0000
@@ -9,7 +9,7 @@ git-apply - Apply a patch to files and/o
 SYNOPSIS
 --------
 [verse]
-'git apply' [--stat] [--numstat] [--summary] [--check] [--index] [--3way]
+'git apply' [--stat] [--numstat] [--summary] [--check] [--index | --intent-to-add] [--3way]
 	  [--apply] [--no-add] [--build-fake-ancestor=<file>] [-R | --reverse]
 	  [--allow-binary-replacement | --binary] [--reject] [-z]
 	  [-p<n>] [-C<n>] [--inaccurate-eof] [--recount] [--cached]
@@ -74,6 +74,14 @@ OPTIONS
 	cached data, apply the patch, and store the result in the index
 	without using the working tree. This implies `--index`.
 
+--intent-to-add::
+	When applying the patch only to the working tree, mark new
+	files to be added to the index later (see `--intent-to-add`
+	option in linkgit:git-add[1]). This option is ignored unless
+	running in a Git repository and `--index` is not specified.
+	Note that `--index` could be implied by other options such
+	as `--cached` or `--3way`.
+
 -3::
 --3way::
 	When the patch does not apply cleanly, fall back on 3-way merge if
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/git-archimport.txt 1.2.3+git2.25.1-1/git/Documentation/git-archimport.txt
--- 1.2.1+git2.18.0-1/git/Documentation/git-archimport.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/git-archimport.txt	2020-02-17 04:47:35.000000000 +0000
@@ -3,7 +3,7 @@ git-archimport(1)
 
 NAME
 ----
-git-archimport - Import an Arch repository into Git
+git-archimport - Import a GNU Arch repository into Git
 
 
 SYNOPSIS
@@ -14,7 +14,8 @@ SYNOPSIS
 
 DESCRIPTION
 -----------
-Imports a project from one or more Arch repositories. It will follow branches
+Imports a project from one or more GNU Arch repositories.
+It will follow branches
 and repositories within the namespaces defined by the <archive/branch>
 parameters supplied. If it cannot find the remote branch a merge comes from
 it will just import it as a regular commit. If it can find it, it will mark it
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/gitattributes.txt 1.2.3+git2.25.1-1/git/Documentation/gitattributes.txt
--- 1.2.1+git2.18.0-1/git/Documentation/gitattributes.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/gitattributes.txt	2020-02-17 04:47:35.000000000 +0000
@@ -18,7 +18,7 @@ A `gitattributes` file is a simple text
 
 Each line in `gitattributes` file is of form:
 
-	pattern	attr1 attr2 ...
+	pattern attr1 attr2 ...
 
 That is, a pattern followed by an attributes list,
 separated by whitespaces. Leading and trailing whitespaces are
@@ -112,7 +112,8 @@ Checking-out and checking-in
 
 These attributes affect how the contents stored in the
 repository are copied to the working tree files when commands
-such as 'git checkout' and 'git merge' run.  They also affect how
+such as 'git switch', 'git checkout'  and 'git merge' run.
+They also affect how
 Git stores the contents you prepare in the working tree in the
 repository upon 'git add' and 'git commit'.
 
@@ -124,7 +125,9 @@ text file is normalized, its line ending
 repository.  To control what line ending style is used in the working
 directory, use the `eol` attribute for a single file and the
 `core.eol` configuration variable for all text files.
-Note that `core.autocrlf` overrides `core.eol`
+Note that setting `core.autocrlf` to `true` or `input` overrides
+`core.eol` (see the definitions of those options in
+linkgit:git-config[1]).
 
 Set::
 
@@ -290,10 +293,10 @@ web front ends do not visualize the cont
 
 In these cases you can tell Git the encoding of a file in the working
 directory with the `working-tree-encoding` attribute. If a file with this
-attribute is added to Git, then Git reencodes the content from the
+attribute is added to Git, then Git re-encodes the content from the
 specified encoding to UTF-8. Finally, Git stores the UTF-8 encoded
 content in its internal data structure (called "the index"). On checkout
-the content is reencoded back to the specified encoding.
+the content is re-encoded back to the specified encoding.
 
 Please note that using the `working-tree-encoding` attribute may have a
 number of pitfalls:
@@ -303,21 +306,21 @@ number of pitfalls:
   attribute. If you decide to use the `working-tree-encoding` attribute
   in your repository, then it is strongly recommended to ensure that all
   clients working with the repository support it.
-
-  For example, Microsoft Visual Studio resources files (`*.rc`) or
-  PowerShell script files (`*.ps1`) are sometimes encoded in UTF-16.
-  If you declare `*.ps1` as files as UTF-16 and you add `foo.ps1` with
-  a `working-tree-encoding` enabled Git client, then `foo.ps1` will be
-  stored as UTF-8 internally. A client without `working-tree-encoding`
-  support will checkout `foo.ps1` as UTF-8 encoded file. This will
-  typically cause trouble for the users of this file.
-
-  If a Git client, that does not support the `working-tree-encoding`
-  attribute, adds a new file `bar.ps1`, then `bar.ps1` will be
-  stored "as-is" internally (in this example probably as UTF-16).
-  A client with `working-tree-encoding` support will interpret the
-  internal contents as UTF-8 and try to convert it to UTF-16 on checkout.
-  That operation will fail and cause an error.
++
+For example, Microsoft Visual Studio resources files (`*.rc`) or
+PowerShell script files (`*.ps1`) are sometimes encoded in UTF-16.
+If you declare `*.ps1` as files as UTF-16 and you add `foo.ps1` with
+a `working-tree-encoding` enabled Git client, then `foo.ps1` will be
+stored as UTF-8 internally. A client without `working-tree-encoding`
+support will checkout `foo.ps1` as UTF-8 encoded file. This will
+typically cause trouble for the users of this file.
++
+If a Git client that does not support the `working-tree-encoding`
+attribute adds a new file `bar.ps1`, then `bar.ps1` will be
+stored "as-is" internally (in this example probably as UTF-16).
+A client with `working-tree-encoding` support will interpret the
+internal contents as UTF-8 and try to convert it to UTF-16 on checkout.
+That operation will fail and cause an error.
 
 - Reencoding content to non-UTF encodings can cause errors as the
   conversion might not be UTF-8 round trip safe. If you suspect your
@@ -344,7 +347,9 @@ automatic line ending conversion based o
 
 Use the following attributes if your '*.ps1' files are UTF-16 little
 endian encoded without BOM and you want Git to use Windows line endings
-in the working directory. Please note, it is highly recommended to
+in the working directory (use `UTF-16LE-BOM` instead of `UTF-16LE` if
+you want UTF-16 little endian with BOM).
+Please note, it is highly recommended to
 explicitly define the line endings with `eol` if the `working-tree-encoding`
 attribute is used to avoid ambiguity.
 
@@ -493,7 +498,7 @@ command. This is achieved by using the l
 When Git encounters the first file that needs to be cleaned or smudged,
 it starts the filter and performs the handshake. In the handshake, the
 welcome message sent by Git is "git-filter-client", only version 2 is
-suppported, and the supported capabilities are "clean", "smudge", and
+supported, and the supported capabilities are "clean", "smudge", and
 "delay".
 
 Afterwards Git sends a list of "key=value" pairs terminated with
@@ -805,6 +810,10 @@ patterns are available:
 
 - `css` suitable for cascading style sheets.
 
+- `dts` suitable for devicetree (DTS) files.
+
+- `elixir` suitable for source code in the Elixir language.
+
 - `fortran` suitable for source code in the Fortran language.
 
 - `fountain` suitable for Fountain documents.
@@ -815,7 +824,7 @@ patterns are available:
 
 - `java` suitable for source code in the Java language.
 
-- `matlab` suitable for source code in the MATLAB language.
+- `matlab` suitable for source code in the MATLAB and Octave languages.
 
 - `objc` suitable for source code in the Objective-C language.
 
@@ -829,6 +838,8 @@ patterns are available:
 
 - `ruby` suitable for source code in the Ruby language.
 
+- `rust` suitable for source code in the Rust language.
+
 - `tex` suitable for source code for LaTeX documents.
 
 
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/git-bisect-lk2009.txt 1.2.3+git2.25.1-1/git/Documentation/git-bisect-lk2009.txt
--- 1.2.1+git2.18.0-1/git/Documentation/git-bisect-lk2009.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/git-bisect-lk2009.txt	2020-02-17 04:47:35.000000000 +0000
@@ -158,7 +158,7 @@ Test suites are very nice. But when they
 supposed to be used so that all the tests are checked after each
 commit. This means that they are not very efficient, because many
 tests are run for no interesting result, and they suffer from
-combinational explosion.
+combinatorial explosion.
 
 In fact the problem is that big software often has many different
 configuration options and that each test case should pass for each
@@ -633,11 +633,11 @@ and so at step 3) we compute f(X).
 Let's take the following graph as an example:
 
 -------------
-	    G-H-I-J
-	   /       \
+            G-H-I-J
+           /       \
 A-B-C-D-E-F         O
-	   \       /
-	    K-L-M-N
+           \       /
+            K-L-M-N
 -------------
 
 If we compute the following non optimal function on it:
@@ -649,25 +649,25 @@ g(X) = min(number_of_ancestors(X), numbe
 we get:
 
 -------------
-	    4 3 2 1
-	    G-H-I-J
+            4 3 2 1
+            G-H-I-J
 1 2 3 4 5 6/       \0
 A-B-C-D-E-F         O
-	   \       /
-	    K-L-M-N
-	    4 3 2 1
+           \       /
+            K-L-M-N
+            4 3 2 1
 -------------
 
 but with the algorithm used by git bisect we get:
 
 -------------
-	    7 7 6 5
-	    G-H-I-J
+            7 7 6 5
+            G-H-I-J
 1 2 3 4 5 6/       \0
 A-B-C-D-E-F         O
-	   \       /
-	    K-L-M-N
-	    7 7 6 5
+           \       /
+            K-L-M-N
+            7 7 6 5
 -------------
 
 So we chose G, H, K or L as the best bisection point, which is better
@@ -773,7 +773,7 @@ forked of the main branch at a commit na
 -------------
 A-B-C-D-E-F-G  <--main
        \
-	H-I-J  <--dev
+        H-I-J  <--dev
 -------------
 
 The commit "D" is called a "merge base" for branch "main" and "dev"
@@ -1103,7 +1103,7 @@ _____________
 Combining test suites, git bisect and other systems together
 ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 
-We have seen that test suites an git bisect are very powerful when
+We have seen that test suites and git bisect are very powerful when
 used together. It can be even more powerful if you can combine them
 with other systems.
 
@@ -1350,9 +1350,9 @@ References
 - [[[1]]] https://www.nist.gov/sites/default/files/documents/director/planning/report02-3.pdf['The Economic Impacts of Inadequate Infratructure for Software Testing'.  Nist Planning Report 02-3], see Executive Summary and Chapter 8.
 - [[[2]]] http://www.oracle.com/technetwork/java/codeconvtoc-136057.html['Code Conventions for the Java Programming Language'. Sun Microsystems.]
 - [[[3]]] https://en.wikipedia.org/wiki/Software_maintenance['Software maintenance'. Wikipedia.]
-- [[[4]]] https://public-inbox.org/git/7vps5xsbwp.fsf_-_@assigned-by-dhcp.cox.net/[Junio C Hamano. 'Automated bisect success story'.]
+- [[[4]]] https://lore.kernel.org/git/7vps5xsbwp.fsf_-_@assigned-by-dhcp.cox.net/[Junio C Hamano. 'Automated bisect success story'.]
 - [[[5]]] https://lwn.net/Articles/317154/[Christian Couder. 'Fully automated bisecting with "git bisect run"'. LWN.net.]
 - [[[6]]] https://lwn.net/Articles/277872/[Jonathan Corbet. 'Bisection divides users and developers'. LWN.net.]
-- [[[7]]] http://marc.info/?l=linux-kernel&m=119702753411680&w=2[Ingo Molnar. 'Re: BUG 2.6.23-rc3 can't see sd partitions on Alpha'. Linux-kernel mailing list.]
+- [[[7]]] https://lore.kernel.org/lkml/20071207113734.GA14598@elte.hu/[Ingo Molnar. 'Re: BUG 2.6.23-rc3 can't see sd partitions on Alpha'. Linux-kernel mailing list.]
 - [[[8]]] https://www.kernel.org/pub/software/scm/git/docs/git-bisect.html[Junio C Hamano and the git-list. 'git-bisect(1) Manual Page'. Linux Kernel Archives.]
 - [[[9]]] https://github.com/Ealdwulf/bbchop[Ealdwulf. 'bbchop'. GitHub.]
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/git-bisect.txt 1.2.3+git2.25.1-1/git/Documentation/git-bisect.txt
--- 1.2.1+git2.18.0-1/git/Documentation/git-bisect.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/git-bisect.txt	2020-02-17 04:47:35.000000000 +0000
@@ -413,7 +413,7 @@ $ cat ~/test.sh
 
 # tweak the working tree by merging the hot-fix branch
 # and then attempt a build
-if	git merge --no-commit hot-fix &&
+if	git merge --no-commit --no-ff hot-fix &&
 	make
 then
 	# run project specific test and report its status
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/git-blame.txt 1.2.3+git2.25.1-1/git/Documentation/git-blame.txt
--- 1.2.1+git2.18.0-1/git/Documentation/git-blame.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/git-blame.txt	2020-02-17 04:47:35.000000000 +0000
@@ -10,6 +10,7 @@ SYNOPSIS
 [verse]
 'git blame' [-c] [-b] [-l] [--root] [-t] [-f] [-n] [-s] [-e] [-p] [-w] [--incremental]
 	    [-L <range>] [-S <revs-file>] [-M] [-C] [-C] [-C] [--since=<date>]
+	    [--ignore-rev <rev>] [--ignore-revs-file <file>]
 	    [--progress] [--abbrev=<n>] [<rev> | --contents <file> | --reverse <rev>..<rev>]
 	    [--] <file>
 
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/git-branch.txt 1.2.3+git2.25.1-1/git/Documentation/git-branch.txt
--- 1.2.1+git2.18.0-1/git/Documentation/git-branch.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/git-branch.txt	2020-02-17 04:47:35.000000000 +0000
@@ -8,13 +8,15 @@ git-branch - List, create, or delete bra
 SYNOPSIS
 --------
 [verse]
-'git branch' [--color[=<when>] | --no-color] [-r | -a]
-	[--list] [-v [--abbrev=<length> | --no-abbrev]]
+'git branch' [--color[=<when>] | --no-color] [--show-current]
+	[-v [--abbrev=<length> | --no-abbrev]]
 	[--column[=<options>] | --no-column] [--sort=<key>]
 	[(--merged | --no-merged) [<commit>]]
 	[--contains [<commit]] [--no-contains [<commit>]]
-	[--points-at <object>] [--format=<format>] [<pattern>...]
-'git branch' [--track | --no-track] [-l] [-f] <branchname> [<start-point>]
+	[--points-at <object>] [--format=<format>]
+	[(-r | --remotes) | (-a | --all)]
+	[--list] [<pattern>...]
+'git branch' [--track | --no-track] [-f] <branchname> [<start-point>]
 'git branch' (--set-upstream-to=<upstream> | -u <upstream>) [<branchname>]
 'git branch' --unset-upstream [<branchname>]
 'git branch' (-m | -M) [<oldbranch>] <newbranch>
@@ -26,13 +28,19 @@ DESCRIPTION
 -----------
 
 If `--list` is given, or if there are no non-option arguments, existing
-branches are listed; the current branch will be highlighted with an
-asterisk.  Option `-r` causes the remote-tracking branches to be listed,
-and option `-a` shows both local and remote branches. If a `<pattern>`
+branches are listed; the current branch will be highlighted in green and
+marked with an asterisk.  Any branches checked out in linked worktrees will
+be highlighted in cyan and marked with a plus sign. Option `-r` causes the
+remote-tracking branches to be listed,
+and option `-a` shows both local and remote branches.
+
+If a `<pattern>`
 is given, it is used as a shell wildcard to restrict the output to
 matching branches. If multiple patterns are given, a branch is shown if
-it matches any of the patterns.  Note that when providing a
-`<pattern>`, you must use `--list`; otherwise the command is interpreted
+it matches any of the patterns.
+
+Note that when providing a
+`<pattern>`, you must use `--list`; otherwise the command may be interpreted
 as branch creation.
 
 With `--contains`, shows only the branches that contain the named commit
@@ -45,10 +53,14 @@ argument is missing it defaults to `HEAD
 branch).
 
 The command's second form creates a new branch head named <branchname>
-which points to the current `HEAD`, or <start-point> if given.
+which points to the current `HEAD`, or <start-point> if given. As a
+special case, for <start-point>, you may use `"A...B"` as a shortcut for
+the merge base of `A` and `B` if there is exactly one merge base. You
+can leave out at most one of `A` and `B`, in which case it defaults to
+`HEAD`.
 
 Note that this will create the new branch, but it will not switch the
-working tree to it; use "git checkout <newbranch>" to switch to the
+working tree to it; use "git switch <newbranch>" to switch to the
 new branch.
 
 When a local branch is started off a remote-tracking branch, Git sets up the
@@ -91,7 +103,6 @@ OPTIONS
 -D::
 	Shortcut for `--delete --force`.
 
--l::
 --create-reflog::
 	Create the branch's reflog.  This activates recording of
 	all changes made to the branch ref, enabling use of date
@@ -150,19 +161,22 @@ This option is only applicable in non-ve
 -r::
 --remotes::
 	List or delete (if used with -d) the remote-tracking branches.
+	Combine with `--list` to match the optional pattern(s).
 
 -a::
 --all::
 	List both remote-tracking branches and local branches.
+	Combine with `--list` to match optional pattern(s).
 
+-l::
 --list::
 	List branches.  With optional `<pattern>...`, e.g. `git
 	branch --list 'maint-*'`, list only the branches that match
 	the pattern(s).
-+
-This should not be confused with `git branch -l <branchname>`,
-which creates a branch named `<branchname>` with a reflog.
-See `--create-reflog` above for details.
+
+--show-current::
+	Print the name of the current branch. In detached HEAD state,
+	nothing is printed.
 
 -v::
 -vv::
@@ -170,8 +184,10 @@ See `--create-reflog` above for details.
 	When in list mode,
 	show sha1 and commit subject line for each head, along with
 	relationship to upstream branch (if any). If given twice, print
-	the name of the upstream branch, as well (see also `git remote
-	show <remote>`).
+	the path of the linked worktree (if any) and the name of the upstream
+	branch, as well (see also `git remote show <remote>`).  Note that the
+	current worktree's HEAD will not have its path printed (it will always
+	be your current directory).
 
 -q::
 --quiet::
@@ -198,7 +214,7 @@ See `--create-reflog` above for details.
 +
 This behavior is the default when the start point is a remote-tracking branch.
 Set the branch.autoSetupMerge configuration variable to `false` if you
-want `git checkout` and `git branch` to always behave as if `--no-track`
+want `git switch`, `git checkout` and `git branch` to always behave as if `--no-track`
 were given. Set it to `always` if you want this behavior when the
 start-point is either a local or remote-tracking branch.
 
@@ -267,10 +283,11 @@ start-point is either a local or remote-
 	order of the value. You may use the --sort=<key> option
 	multiple times, in which case the last key becomes the primary
 	key. The keys supported are the same as those in `git
-	for-each-ref`. Sort order defaults to sorting based on the
+	for-each-ref`. Sort order defaults to the value configured for the
+	`branch.sort` variable if exists, or to sorting based on the
 	full refname (including `refs/...` prefix). This lists
 	detached HEAD (if present) first, then local branches and
-	finally remote-tracking branches.
+	finally remote-tracking branches. See linkgit:git-config[1].
 
 
 --points-at <object>::
@@ -296,11 +313,11 @@ Start development from a known tag::
 $ git clone git://git.kernel.org/pub/scm/.../linux-2.6 my2.6
 $ cd my2.6
 $ git branch my2.6.14 v2.6.14   <1>
-$ git checkout my2.6.14
+$ git switch my2.6.14
 ------------
 +
 <1> This step and the next one could be combined into a single step with
-"checkout -b my2.6.14 v2.6.14".
+    "checkout -b my2.6.14 v2.6.14".
 
 Delete an unneeded branch::
 +
@@ -312,18 +329,30 @@ $ git branch -D test
 ------------
 +
 <1> Delete the remote-tracking branches "todo", "html" and "man". The next
-'fetch' or 'pull' will create them again unless you configure them not to.
-See linkgit:git-fetch[1].
+    'fetch' or 'pull' will create them again unless you configure them not to.
+    See linkgit:git-fetch[1].
 <2> Delete the "test" branch even if the "master" branch (or whichever branch
-is currently checked out) does not have all commits from the test branch.
+    is currently checked out) does not have all commits from the test branch.
+
+Listing branches from a specific remote::
++
+------------
+$ git branch -r -l '<remote>/<pattern>'                 <1>
+$ git for-each-ref 'refs/remotes/<remote>/<pattern>'    <2>
+------------
++
+<1> Using `-a` would conflate <remote> with any local branches you happen to
+    have been prefixed with the same <remote> pattern.
+<2> `for-each-ref` can take a wide range of options. See linkgit:git-for-each-ref[1]
 
+Patterns will normally need quoting.
 
 NOTES
 -----
 
-If you are creating a branch that you want to checkout immediately, it is
-easier to use the git checkout command with its `-b` option to create
-a branch and check it out with a single command.
+If you are creating a branch that you want to switch to immediately,
+it is easier to use the "git switch" command with its `-c` option to
+do the same thing with a single command.
 
 The options `--contains`, `--no-contains`, `--merged` and `--no-merged`
 serve four related but different purposes:
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/git-bundle.txt 1.2.3+git2.25.1-1/git/Documentation/git-bundle.txt
--- 1.2.1+git2.18.0-1/git/Documentation/git-bundle.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/git-bundle.txt	2020-02-17 04:47:35.000000000 +0000
@@ -9,8 +9,8 @@ git-bundle - Move objects and refs by ar
 SYNOPSIS
 --------
 [verse]
-'git bundle' create <file> <git-rev-list-args>
-'git bundle' verify <file>
+'git bundle' create [-q | --quiet | --progress | --all-progress] [--all-progress-implied] <file> <git-rev-list-args>
+'git bundle' verify [-q | --quiet] <file>
 'git bundle' list-heads <file> [<refname>...]
 'git bundle' unbundle <file> [<refname>...]
 
@@ -20,11 +20,14 @@ DESCRIPTION
 Some workflows require that one or more branches of development on one
 machine be replicated on another machine, but the two machines cannot
 be directly connected, and therefore the interactive Git protocols (git,
-ssh, http) cannot be used.  This command provides support for
-'git fetch' and 'git pull' to operate by packaging objects and references
-in an archive at the originating machine, then importing those into
-another repository using 'git fetch' and 'git pull'
-after moving the archive by some means (e.g., by sneakernet).  As no
+ssh, http) cannot be used.
+
+The 'git bundle' command packages objects and references in an archive
+at the originating machine, which can then be imported into another
+repository using 'git fetch', 'git pull', or 'git clone',
+after moving the archive by some means (e.g., by sneakernet).
+
+As no
 direct connection between the repositories exists, the user must specify a
 basis for the bundle that is held by the destination repository: the
 bundle assumes that all objects in the basis are already in the
@@ -33,9 +36,11 @@ destination repository.
 OPTIONS
 -------
 
-create <file>::
+create [options] <file> <git-rev-list-args>::
 	Used to create a bundle named 'file'.  This requires the
-	'git-rev-list-args' arguments to define the bundle contents.
+	'<git-rev-list-args>' arguments to define the bundle contents.
+	'options' contains the options specific to the 'git bundle create'
+	subcommand.
 
 verify <file>::
 	Used to check that a bundle file is valid and will apply
@@ -75,6 +80,33 @@ unbundle <file>::
 	necessarily everything in the pack (in this case, 'git bundle' acts
 	like 'git fetch-pack').
 
+--progress::
+	Progress status is reported on the standard error stream
+	by default when it is attached to a terminal, unless -q
+	is specified. This flag forces progress status even if
+	the standard error stream is not directed to a terminal.
+
+--all-progress::
+	When --stdout is specified then progress report is
+	displayed during the object count and compression phases
+	but inhibited during the write-out phase. The reason is
+	that in some cases the output stream is directly linked
+	to another command which may wish to display progress
+	status of its own as it processes incoming pack data.
+	This flag is like --progress except that it forces progress
+	report for the write-out phase as well even if --stdout is
+	used.
+
+--all-progress-implied::
+	This is used to imply --all-progress whenever progress display
+	is activated.  Unlike --all-progress this flag doesn't actually
+	force any progress display by itself.
+
+-q::
+--quiet::
+	This flag makes the command not to report its progress
+	on the standard error stream.
+
 SPECIFYING REFERENCES
 ---------------------
 
@@ -92,6 +124,14 @@ It is okay to err on the side of caution
 to contain objects already in the destination, as these are ignored
 when unpacking at the destination.
 
+`git clone` can use any bundle created without negative refspecs
+(e.g., `new`, but not `old..new`).
+If you want to match `git clone --mirror`, which would include your
+refs such as `refs/remotes/*`, use `--all`.
+If you want to provide the same set of refs that a clone directly
+from the source repository would get, use `--branches --tags` for
+the `<git-rev-list-args>`.
+
 EXAMPLES
 --------
 
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/git-cat-file.txt 1.2.3+git2.25.1-1/git/Documentation/git-cat-file.txt
--- 1.2.1+git2.18.0-1/git/Documentation/git-cat-file.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/git-cat-file.txt	2020-02-17 04:47:35.000000000 +0000
@@ -23,8 +23,8 @@ In the second form, a list of objects (s
 stdin, and the SHA-1, type, and size of each object is printed on stdout. The
 output format can be overridden using the optional `<format>` argument. If
 either `--textconv` or `--filters` was specified, the input is expected to
-list the object names followed by the path name, separated by a single white
-space, so that the appropriate drivers can be determined.
+list the object names followed by the path name, separated by a single
+whitespace, so that the appropriate drivers can be determined.
 
 OPTIONS
 -------
@@ -79,7 +79,7 @@ OPTIONS
 	Print object information and contents for each object provided
 	on stdin.  May not be combined with any other options or arguments
 	except `--textconv` or `--filters`, in which case the input lines
-	also need to specify the path, separated by white space.  See the
+	also need to specify the path, separated by whitespace.  See the
 	section `BATCH OUTPUT` below for details.
 
 --batch-check::
@@ -87,7 +87,7 @@ OPTIONS
 	Print object information for each object provided on stdin.  May
 	not be combined with any other options or arguments except
 	`--textconv` or `--filters`, in which case the input lines also
-	need to specify the path, separated by white space.  See the
+	need to specify the path, separated by whitespace.  See the
 	section `BATCH OUTPUT` below for details.
 
 --batch-all-objects::
@@ -104,6 +104,16 @@ OPTIONS
 	buffering; this is much more efficient when invoking
 	`--batch-check` on a large number of objects.
 
+--unordered::
+	When `--batch-all-objects` is in use, visit objects in an
+	order which may be more efficient for accessing the object
+	contents than hash order. The exact details of the order are
+	unspecified, but if you do not require a specific order, this
+	should generally result in faster output, especially with
+	`--batch`.  Note that `cat-file` will still show each object
+	only once, even if it is stored multiple times in the
+	repository.
+
 --allow-unknown-type::
 	Allow -s or -t to query broken/corrupt objects of unknown type.
 
@@ -242,6 +252,12 @@ the repository, then `cat-file` will ign
 <object> SP missing LF
 ------------
 
+If a name is specified that might refer to more than one object (an ambiguous short sha), then `cat-file` will ignore any custom format and print:
+
+------------
+<object> SP ambiguous LF
+------------
+
 If --follow-symlinks is used, and a symlink in the repository points
 outside the repository, then `cat-file` will ignore any custom format
 and print:
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/git-check-attr.txt 1.2.3+git2.25.1-1/git/Documentation/git-check-attr.txt
--- 1.2.1+git2.18.0-1/git/Documentation/git-check-attr.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/git-check-attr.txt	2020-02-17 04:47:35.000000000 +0000
@@ -32,7 +32,7 @@ OPTIONS
 	instead of from the command-line.
 
 -z::
-	The output format is modified to be machine-parseable.
+	The output format is modified to be machine-parsable.
 	If `--stdin` is also given, input paths are separated
 	with a NUL character instead of a linefeed character.
 
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/git-check-ignore.txt 1.2.3+git2.25.1-1/git/Documentation/git-check-ignore.txt
--- 1.2.1+git2.18.0-1/git/Documentation/git-check-ignore.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/git-check-ignore.txt	2020-02-17 04:47:35.000000000 +0000
@@ -39,7 +39,7 @@ OPTIONS
 	instead of from the command-line.
 
 -z::
-	The output format is modified to be machine-parseable (see
+	The output format is modified to be machine-parsable (see
 	below).  If `--stdin` is also given, input paths are separated
 	with a NUL character instead of a linefeed character.
 
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/git-checkout.txt 1.2.3+git2.25.1-1/git/Documentation/git-checkout.txt
--- 1.2.1+git2.18.0-1/git/Documentation/git-checkout.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/git-checkout.txt	2020-02-17 04:47:35.000000000 +0000
@@ -12,33 +12,33 @@ SYNOPSIS
 'git checkout' [-q] [-f] [-m] --detach [<branch>]
 'git checkout' [-q] [-f] [-m] [--detach] <commit>
 'git checkout' [-q] [-f] [-m] [[-b|-B|--orphan] <new_branch>] [<start_point>]
-'git checkout' [-f|--ours|--theirs|-m|--conflict=<style>] [<tree-ish>] [--] <paths>...
-'git checkout' [<tree-ish>] [--] <pathspec>...
-'git checkout' (-p|--patch) [<tree-ish>] [--] [<paths>...]
+'git checkout' [-f|--ours|--theirs|-m|--conflict=<style>] [<tree-ish>] [--] <pathspec>...
+'git checkout' [-f|--ours|--theirs|-m|--conflict=<style>] [<tree-ish>] --pathspec-from-file=<file> [--pathspec-file-nul]
+'git checkout' (-p|--patch) [<tree-ish>] [--] [<pathspec>...]
 
 DESCRIPTION
 -----------
 Updates files in the working tree to match the version in the index
-or the specified tree.  If no paths are given, 'git checkout' will
+or the specified tree.  If no pathspec was given, 'git checkout' will
 also update `HEAD` to set the specified branch as the current
 branch.
 
-'git checkout' <branch>::
-	To prepare for working on <branch>, switch to it by updating
+'git checkout' [<branch>]::
+	To prepare for working on `<branch>`, switch to it by updating
 	the index and the files in the working tree, and by pointing
-	HEAD at the branch. Local modifications to the files in the
+	`HEAD` at the branch. Local modifications to the files in the
 	working tree are kept, so that they can be committed to the
-	<branch>.
+	`<branch>`.
 +
-If <branch> is not found but there does exist a tracking branch in
-exactly one remote (call it <remote>) with a matching name, treat as
-equivalent to
+If `<branch>` is not found but there does exist a tracking branch in
+exactly one remote (call it `<remote>`) with a matching name and
+`--no-guess` is not specified, treat as equivalent to
 +
 ------------
 $ git checkout -b <branch> --track <remote>/<branch>
 ------------
 +
-You could omit <branch>, in which case the command degenerates to
+You could omit `<branch>`, in which case the command degenerates to
 "check out the current branch", which is a glorified no-op with
 rather expensive side-effects to show only the tracking information,
 if exists, for the current branch.
@@ -52,7 +52,7 @@ if exists, for the current branch.
 	`--track` without `-b` implies branch creation; see the
 	description of `--track` below.
 +
-If `-B` is given, <new_branch> is created if it doesn't exist; otherwise, it
+If `-B` is given, `<new_branch>` is created if it doesn't exist; otherwise, it
 is reset. This is the transactional equivalent of
 +
 ------------
@@ -66,26 +66,27 @@ successful.
 'git checkout' --detach [<branch>]::
 'git checkout' [--detach] <commit>::
 
-	Prepare to work on top of <commit>, by detaching HEAD at it
+	Prepare to work on top of `<commit>`, by detaching `HEAD` at it
 	(see "DETACHED HEAD" section), and updating the index and the
 	files in the working tree.  Local modifications to the files
 	in the working tree are kept, so that the resulting working
 	tree will be the state recorded in the commit plus the local
 	modifications.
 +
-When the <commit> argument is a branch name, the `--detach` option can
-be used to detach HEAD at the tip of the branch (`git checkout
-<branch>` would check out that branch without detaching HEAD).
-+
-Omitting <branch> detaches HEAD at the tip of the current branch.
-
-'git checkout' [<tree-ish>] [--] <pathspec>...::
-
-	Overwrite paths in the working tree by replacing with the
-	contents in the index or in the <tree-ish> (most often a
-	commit).  When a <tree-ish> is given, the paths that
-	match the <pathspec> are updated both in the index and in
-	the working tree.
+When the `<commit>` argument is a branch name, the `--detach` option can
+be used to detach `HEAD` at the tip of the branch (`git checkout
+<branch>` would check out that branch without detaching `HEAD`).
++
+Omitting `<branch>` detaches `HEAD` at the tip of the current branch.
+
+'git checkout' [-f|--ours|--theirs|-m|--conflict=<style>] [<tree-ish>] [--] <pathspec>...::
+'git checkout' [-f|--ours|--theirs|-m|--conflict=<style>] [<tree-ish>] --pathspec-from-file=<file> [--pathspec-file-nul]::
+
+	Overwrite the contents of the files that match the pathspec.
+	When the `<tree-ish>` (most often a commit) is not given,
+	overwrite working tree with the contents in the index.
+	When the `<tree-ish>` is given, overwrite both the index and
+	the working tree with the contents at the `<tree-ish>`.
 +
 The index may contain unmerged entries because of a previous failed merge.
 By default, if you try to check out such an entry from the index, the
@@ -96,12 +97,10 @@ using `--ours` or `--theirs`.  With `-m`
 file can be discarded to re-create the original conflicted merge result.
 
 'git checkout' (-p|--patch) [<tree-ish>] [--] [<pathspec>...]::
-	This is similar to the "check out paths to the working tree
-	from either the index or from a tree-ish" mode described
-	above, but lets you use the interactive interface to show
-	the "diff" output and choose which hunks to use in the
-	result.  See below for the description of `--patch` option.
-
+	This is similar to the previous mode, but lets you use the
+	interactive interface to show the "diff" output and choose which
+	hunks to use in the result.  See below for the description of
+	`--patch` option.
 
 OPTIONS
 -------
@@ -109,7 +108,8 @@ OPTIONS
 --quiet::
 	Quiet, suppress feedback messages.
 
---[no-]progress::
+--progress::
+--no-progress::
 	Progress status is reported on the standard error stream
 	by default when it is attached to a terminal, unless `--quiet`
 	is specified. This flag enables progress reporting even if not
@@ -118,7 +118,7 @@ OPTIONS
 -f::
 --force::
 	When switching branches, proceed even if the index or the
-	working tree differs from HEAD.  This is used to throw away
+	working tree differs from `HEAD`.  This is used to throw away
 	local changes.
 +
 When checking out paths from the index, do not fail upon unmerged
@@ -145,12 +145,12 @@ on your side branch as `theirs` (i.e. "o
 of it").
 
 -b <new_branch>::
-	Create a new branch named <new_branch> and start it at
-	<start_point>; see linkgit:git-branch[1] for details.
+	Create a new branch named `<new_branch>` and start it at
+	`<start_point>`; see linkgit:git-branch[1] for details.
 
 -B <new_branch>::
-	Creates the branch <new_branch> and start it at <start_point>;
-	if it already exists, then reset it to <start_point>. This is
+	Creates the branch `<new_branch>` and start it at `<start_point>`;
+	if it already exists, then reset it to `<start_point>`. This is
 	equivalent to running "git branch" with "-f"; see
 	linkgit:git-branch[1] for details.
 
@@ -163,15 +163,36 @@ If no `-b` option is given, the name of
 derived from the remote-tracking branch, by looking at the local part of
 the refspec configured for the corresponding remote, and then stripping
 the initial part up to the "*".
-This would tell us to use "hack" as the local branch when branching
-off of "origin/hack" (or "remotes/origin/hack", or even
-"refs/remotes/origin/hack").  If the given name has no slash, or the above
+This would tell us to use `hack` as the local branch when branching
+off of `origin/hack` (or `remotes/origin/hack`, or even
+`refs/remotes/origin/hack`).  If the given name has no slash, or the above
 guessing results in an empty name, the guessing is aborted.  You can
 explicitly give a name with `-b` in such a case.
 
 --no-track::
 	Do not set up "upstream" configuration, even if the
-	branch.autoSetupMerge configuration variable is true.
+	`branch.autoSetupMerge` configuration variable is true.
+
+--guess::
+--no-guess::
+	If `<branch>` is not found but there does exist a tracking
+	branch in exactly one remote (call it `<remote>`) with a
+	matching name, treat as equivalent to
++
+------------
+$ git checkout -b <branch> --track <remote>/<branch>
+------------
++
+If the branch exists in multiple remotes and one of them is named by
+the `checkout.defaultRemote` configuration variable, we'll use that
+one for the purposes of disambiguation, even if the `<branch>` isn't
+unique across all remotes. Set it to
+e.g. `checkout.defaultRemote=origin` to always checkout remote
+branches from there if `<branch>` is ambiguous but exists on the
+'origin' remote. See also `checkout.defaultRemote` in
+linkgit:git-config[1].
++
+Use `--no-guess` to disable this.
 
 -l::
 	Create the new branch's reflog; see linkgit:git-branch[1] for
@@ -180,21 +201,21 @@ explicitly give a name with `-b` in such
 --detach::
 	Rather than checking out a branch to work on it, check out a
 	commit for inspection and discardable experiments.
-	This is the default behavior of "git checkout <commit>" when
-	<commit> is not a branch name.  See the "DETACHED HEAD" section
+	This is the default behavior of `git checkout <commit>` when
+	`<commit>` is not a branch name.  See the "DETACHED HEAD" section
 	below for details.
 
 --orphan <new_branch>::
-	Create a new 'orphan' branch, named <new_branch>, started from
-	<start_point> and switch to it.  The first commit made on this
+	Create a new 'orphan' branch, named `<new_branch>`, started from
+	`<start_point>` and switch to it.  The first commit made on this
 	new branch will have no parents and it will be the root of a new
 	history totally disconnected from all the other branches and
 	commits.
 +
 The index and the working tree are adjusted as if you had previously run
-"git checkout <start_point>".  This allows you to start a new history
-that records a set of paths similar to <start_point> by easily running
-"git commit -a" to make the root commit.
+`git checkout <start_point>`.  This allows you to start a new history
+that records a set of paths similar to `<start_point>` by easily running
+`git commit -a` to make the root commit.
 +
 This can be useful when you want to publish the tree from a commit
 without exposing its full history. You might want to do this to publish
@@ -203,17 +224,17 @@ whose full history contains proprietary
 code.
 +
 If you want to start a disconnected history that records a set of paths
-that is totally different from the one of <start_point>, then you should
+that is totally different from the one of `<start_point>`, then you should
 clear the index and the working tree right after creating the orphan
-branch by running "git rm -rf ." from the top level of the working tree.
+branch by running `git rm -rf .` from the top level of the working tree.
 Afterwards you will be ready to prepare your new files, repopulating the
 working tree, by copying them from elsewhere, extracting a tarball, etc.
 
 --ignore-skip-worktree-bits::
 	In sparse checkout mode, `git checkout -- <paths>` would
-	update only entries matched by <paths> and sparse patterns
-	in $GIT_DIR/info/sparse-checkout. This option ignores
-	the sparse patterns and adds back any files in <paths>.
+	update only entries matched by `<paths>` and sparse patterns
+	in `$GIT_DIR/info/sparse-checkout`. This option ignores
+	the sparse patterns and adds back any files in `<paths>`.
 
 -m::
 --merge::
@@ -233,24 +254,29 @@ should result in deletion of the path).
 +
 When checking out paths from the index, this option lets you recreate
 the conflicted merge in the specified paths.
++
+When switching branches with `--merge`, staged changes may be lost.
 
 --conflict=<style>::
-	The same as --merge option above, but changes the way the
+	The same as `--merge` option above, but changes the way the
 	conflicting hunks are presented, overriding the
-	merge.conflictStyle configuration variable.  Possible values are
+	`merge.conflictStyle` configuration variable.  Possible values are
 	"merge" (default) and "diff3" (in addition to what is shown by
 	"merge" style, shows the original contents).
 
 -p::
 --patch::
 	Interactively select hunks in the difference between the
-	<tree-ish> (or the index, if unspecified) and the working
+	`<tree-ish>` (or the index, if unspecified) and the working
 	tree.  The chosen hunks are then applied in reverse to the
-	working tree (and if a <tree-ish> was specified, the index).
+	working tree (and if a `<tree-ish>` was specified, the index).
 +
 This means that you can use `git checkout -p` to selectively discard
 edits from your current working tree. See the ``Interactive Mode''
 section of linkgit:git-add[1] to learn how to operate the `--patch` mode.
++
+Note that this option uses the no overlay mode by default (see also
+`--overlay`), and currently doesn't support overlay mode.
 
 --ignore-other-worktrees::
 	`git checkout` refuses when the wanted ref is already checked
@@ -258,27 +284,55 @@ section of linkgit:git-add[1] to learn h
 	out anyway. In other words, the ref can be held by more than one
 	worktree.
 
---[no-]recurse-submodules::
-	Using --recurse-submodules will update the content of all initialized
+--overwrite-ignore::
+--no-overwrite-ignore::
+	Silently overwrite ignored files when switching branches. This
+	is the default behavior. Use `--no-overwrite-ignore` to abort
+	the operation when the new branch contains ignored files.
+
+--recurse-submodules::
+--no-recurse-submodules::
+	Using `--recurse-submodules` will update the content of all initialized
 	submodules according to the commit recorded in the superproject. If
 	local modifications in a submodule would be overwritten the checkout
-	will fail unless `-f` is used. If nothing (or --no-recurse-submodules)
+	will fail unless `-f` is used. If nothing (or `--no-recurse-submodules`)
 	is used, the work trees of submodules will not be updated.
-	Just like linkgit:git-submodule[1], this will detach the
-	submodules HEAD.
+	Just like linkgit:git-submodule[1], this will detach `HEAD` of the
+	submodule.
+
+--overlay::
+--no-overlay::
+	In the default overlay mode, `git checkout` never
+	removes files from the index or the working tree.  When
+	specifying `--no-overlay`, files that appear in the index and
+	working tree, but not in `<tree-ish>` are removed, to make them
+	match `<tree-ish>` exactly.
+
+--pathspec-from-file=<file>::
+	Pathspec is passed in `<file>` instead of commandline args. If
+	`<file>` is exactly `-` then standard input is used. Pathspec
+	elements are separated by LF or CR/LF. Pathspec elements can be
+	quoted as explained for the configuration variable `core.quotePath`
+	(see linkgit:git-config[1]). See also `--pathspec-file-nul` and
+	global `--literal-pathspecs`.
+
+--pathspec-file-nul::
+	Only meaningful with `--pathspec-from-file`. Pathspec elements are
+	separated with NUL character and all other characters are taken
+	literally (including newlines and quotes).
 
 <branch>::
 	Branch to checkout; if it refers to a branch (i.e., a name that,
 	when prepended with "refs/heads/", is a valid ref), then that
 	branch is checked out. Otherwise, if it refers to a valid
-	commit, your HEAD becomes "detached" and you are no longer on
+	commit, your `HEAD` becomes "detached" and you are no longer on
 	any branch (see below for details).
 +
-You can use the `"@{-N}"` syntax to refer to the N-th last
+You can use the `@{-N}` syntax to refer to the N-th last
 branch/commit checked out using "git checkout" operation. You may
-also specify `-` which is synonymous to `"@{-1}`.
+also specify `-` which is synonymous to `@{-1}`.
 +
-As a special case, you may use `"A...B"` as a shortcut for the
+As a special case, you may use `A...B` as a shortcut for the
 merge base of `A` and `B` if there is exactly one merge base. You can
 leave out at most one of `A` and `B`, in which case it defaults to `HEAD`.
 
@@ -287,24 +341,34 @@ leave out at most one of `A` and `B`, in
 
 <start_point>::
 	The name of a commit at which to start the new branch; see
-	linkgit:git-branch[1] for details. Defaults to HEAD.
+	linkgit:git-branch[1] for details. Defaults to `HEAD`.
++
+As a special case, you may use `"A...B"` as a shortcut for the
+merge base of `A` and `B` if there is exactly one merge base. You can
+leave out at most one of `A` and `B`, in which case it defaults to `HEAD`.
 
 <tree-ish>::
 	Tree to checkout from (when paths are given). If not specified,
 	the index will be used.
 
+\--::
+	Do not interpret any more arguments as options.
 
+<pathspec>...::
+	Limits the paths affected by the operation.
++
+For more details, see the 'pathspec' entry in linkgit:gitglossary[7].
 
 DETACHED HEAD
 -------------
-HEAD normally refers to a named branch (e.g. 'master'). Meanwhile, each
+`HEAD` normally refers to a named branch (e.g. `master`). Meanwhile, each
 branch refers to a specific commit. Let's look at a repo with three
-commits, one of them tagged, and with branch 'master' checked out:
+commits, one of them tagged, and with branch `master` checked out:
 
 ------------
-	   HEAD (refers to branch 'master')
-	    |
-	    v
+           HEAD (refers to branch 'master')
+            |
+            v
 a---b---c  branch 'master' (refers to commit 'c')
     ^
     |
@@ -312,17 +376,17 @@ a---b---c  branch 'master' (refers to co
 ------------
 
 When a commit is created in this state, the branch is updated to refer to
-the new commit. Specifically, 'git commit' creates a new commit 'd', whose
-parent is commit 'c', and then updates branch 'master' to refer to new
-commit 'd'. HEAD still refers to branch 'master' and so indirectly now refers
-to commit 'd':
+the new commit. Specifically, 'git commit' creates a new commit `d`, whose
+parent is commit `c`, and then updates branch `master` to refer to new
+commit `d`. `HEAD` still refers to branch `master` and so indirectly now refers
+to commit `d`:
 
 ------------
 $ edit; git add; git commit
 
-	       HEAD (refers to branch 'master')
-		|
-		v
+               HEAD (refers to branch 'master')
+                |
+                v
 a---b---c---d  branch 'master' (refers to commit 'd')
     ^
     |
@@ -332,7 +396,7 @@ a---b---c---d  branch 'master' (refers t
 It is sometimes useful to be able to checkout a commit that is not at
 the tip of any named branch, or even to create a new commit that is not
 referenced by a named branch. Let's look at what happens when we
-checkout commit 'b' (here we show two ways this may be done):
+checkout commit `b` (here we show two ways this may be done):
 
 ------------
 $ git checkout v2.0  # or
@@ -347,9 +411,9 @@ a---b---c---d  branch 'master' (refers t
   tag 'v2.0' (refers to commit 'b')
 ------------
 
-Notice that regardless of which checkout command we use, HEAD now refers
-directly to commit 'b'. This is known as being in detached HEAD state.
-It means simply that HEAD refers to a specific commit, as opposed to
+Notice that regardless of which checkout command we use, `HEAD` now refers
+directly to commit `b`. This is known as being in detached `HEAD` state.
+It means simply that `HEAD` refers to a specific commit, as opposed to
 referring to a named branch. Let's see what happens when we create a commit:
 
 ------------
@@ -366,7 +430,7 @@ a---b---c---d  branch 'master' (refers t
   tag 'v2.0' (refers to commit 'b')
 ------------
 
-There is now a new commit 'e', but it is referenced only by HEAD. We can
+There is now a new commit `e`, but it is referenced only by `HEAD`. We can
 of course add yet another commit in this state:
 
 ------------
@@ -384,12 +448,12 @@ a---b---c---d  branch 'master' (refers t
 ------------
 
 In fact, we can perform all the normal Git operations. But, let's look
-at what happens when we then checkout master:
+at what happens when we then checkout `master`:
 
 ------------
 $ git checkout master
 
-	       HEAD (refers to branch 'master')
+               HEAD (refers to branch 'master')
       e---f     |
      /          v
 a---b---c---d  branch 'master' (refers to commit 'd')
@@ -399,9 +463,9 @@ a---b---c---d  branch 'master' (refers t
 ------------
 
 It is important to realize that at this point nothing refers to commit
-'f'. Eventually commit 'f' (and by extension commit 'e') will be deleted
+`f`. Eventually commit `f` (and by extension commit `e`) will be deleted
 by the routine Git garbage collection process, unless we create a reference
-before that happens. If we have not yet moved away from commit 'f',
+before that happens. If we have not yet moved away from commit `f`,
 any of these will create a reference to it:
 
 ------------
@@ -410,19 +474,19 @@ $ git branch foo        <2>
 $ git tag foo           <3>
 ------------
 
-<1> creates a new branch 'foo', which refers to commit 'f', and then
-updates HEAD to refer to branch 'foo'. In other words, we'll no longer
-be in detached HEAD state after this command.
+<1> creates a new branch `foo`, which refers to commit `f`, and then
+    updates `HEAD` to refer to branch `foo`. In other words, we'll no longer
+    be in detached `HEAD` state after this command.
 
-<2> similarly creates a new branch 'foo', which refers to commit 'f',
-but leaves HEAD detached.
+<2> similarly creates a new branch `foo`, which refers to commit `f`,
+    but leaves `HEAD` detached.
 
-<3> creates a new tag 'foo', which refers to commit 'f',
-leaving HEAD detached.
+<3> creates a new tag `foo`, which refers to commit `f`,
+    leaving `HEAD` detached.
 
-If we have moved away from commit 'f', then we must first recover its object
+If we have moved away from commit `f`, then we must first recover its object
 name (typically by using git reflog), and then we can create a reference to
-it. For example, to see the last two commits to which HEAD referred, we
+it. For example, to see the last two commits to which `HEAD` referred, we
 can use either of these commands:
 
 ------------
@@ -433,12 +497,12 @@ $ git log -g -2 HEAD
 ARGUMENT DISAMBIGUATION
 -----------------------
 
-When there is only one argument given and it is not `--` (e.g. "git
-checkout abc"), and when the argument is both a valid `<tree-ish>`
-(e.g. a branch "abc" exists) and a valid `<pathspec>` (e.g. a file
+When there is only one argument given and it is not `--` (e.g. `git
+checkout abc`), and when the argument is both a valid `<tree-ish>`
+(e.g. a branch `abc` exists) and a valid `<pathspec>` (e.g. a file
 or a directory whose name is "abc" exists), Git would usually ask
 you to disambiguate.  Because checking out a branch is so common an
-operation, however, "git checkout abc" takes "abc" as a `<tree-ish>`
+operation, however, `git checkout abc` takes "abc" as a `<tree-ish>`
 in such a situation.  Use `git checkout -- <pathspec>` if you want
 to checkout these paths out of the index.
 
@@ -446,8 +510,8 @@ EXAMPLES
 --------
 
 . The following sequence checks out the `master` branch, reverts
-the `Makefile` to two revisions back, deletes hello.c by
-mistake, and gets it back from the index.
+  the `Makefile` to two revisions back, deletes `hello.c` by
+  mistake, and gets it back from the index.
 +
 ------------
 $ git checkout master             <1>
@@ -458,7 +522,7 @@ $ git checkout hello.c            <3>
 +
 <1> switch branch
 <2> take a file out of another commit
-<3> restore hello.c from the index
+<3> restore `hello.c` from the index
 +
 If you want to check out _all_ C source files out of the index,
 you can say
@@ -481,13 +545,13 @@ $ git checkout -- hello.c
 ------------
 
 . After working in the wrong branch, switching to the correct
-branch would be done using:
+  branch would be done using:
 +
 ------------
 $ git checkout mytopic
 ------------
 +
-However, your "wrong" branch and correct "mytopic" branch may
+However, your "wrong" branch and correct `mytopic` branch may
 differ in files that you have modified locally, in which case
 the above checkout would fail like this:
 +
@@ -509,7 +573,7 @@ registered in your index file, so `git d
 changes you made since the tip of the new branch.
 
 . When a merge conflict happens during switching branches with
-the `-m` option, you would see something like this:
+  the `-m` option, you would see something like this:
 +
 ------------
 $ git checkout -m mytopic
@@ -528,6 +592,11 @@ $ edit frotz
 $ git add frotz
 ------------
 
+SEE ALSO
+--------
+linkgit:git-switch[1],
+linkgit:git-restore[1]
+
 GIT
 ---
 Part of the linkgit:git[1] suite
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/git-check-ref-format.txt 1.2.3+git2.25.1-1/git/Documentation/git-check-ref-format.txt
--- 1.2.1+git2.18.0-1/git/Documentation/git-check-ref-format.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/git-check-ref-format.txt	2020-02-17 04:47:35.000000000 +0000
@@ -88,7 +88,8 @@ but it is explicitly forbidden at the be
 When run with `--branch` option in a repository, the input is first
 expanded for the ``previous checkout syntax''
 `@{-n}`.  For example, `@{-1}` is a way to refer the last thing that
-was checked out using "git checkout" operation. This option should be
+was checked out using "git switch" or "git checkout" operation.
+This option should be
 used by porcelains to accept this syntax anywhere a branch name is
 expected, so they can act as if you typed the branch name. As an
 exception note that, the ``previous checkout operation'' might result
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/git-cherry-pick.txt 1.2.3+git2.25.1-1/git/Documentation/git-cherry-pick.txt
--- 1.2.1+git2.18.0-1/git/Documentation/git-cherry-pick.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/git-cherry-pick.txt	2020-02-17 04:47:35.000000000 +0000
@@ -10,9 +10,7 @@ SYNOPSIS
 [verse]
 'git cherry-pick' [--edit] [-n] [-m parent-number] [-s] [-x] [--ff]
 		  [-S[<keyid>]] <commit>...
-'git cherry-pick' --continue
-'git cherry-pick' --quit
-'git cherry-pick' --abort
+'git cherry-pick' (--continue | --skip | --abort | --quit)
 
 DESCRIPTION
 -----------
@@ -57,6 +55,13 @@ OPTIONS
 	With this option, 'git cherry-pick' will let you edit the commit
 	message prior to committing.
 
+--cleanup=<mode>::
+	This option determines how the commit message will be cleaned up before
+	being passed on to the commit machinery. See linkgit:git-commit[1] for more
+	details. In particular, if the '<mode>' is given a value of `scissors`,
+	scissors will be appended to `MERGE_MSG` before being passed on in the case
+	of a conflict.
+
 -x::
 	When recording the commit, append a line that says
 	"(cherry picked from commit ...)" to the original commit
@@ -148,6 +153,11 @@ effect to your index in a row.
 	Pass the merge strategy-specific option through to the
 	merge strategy.  See linkgit:git-merge[1] for details.
 
+--rerere-autoupdate::
+--no-rerere-autoupdate::
+	Allow the rerere mechanism to update the index with the
+	result of auto-conflict resolution if possible.
+
 SEQUENCER SUBCOMMANDS
 ---------------------
 include::sequencer.txt[]
@@ -213,16 +223,16 @@ $ git reset --merge ORIG_HEAD        <3>
 $ git cherry-pick -Xpatience topic^  <4>
 ------------
 <1> apply the change that would be shown by `git show topic^`.
-In this example, the patch does not apply cleanly, so
-information about the conflict is written to the index and
-working tree and no new commit results.
+    In this example, the patch does not apply cleanly, so
+    information about the conflict is written to the index and
+    working tree and no new commit results.
 <2> summarize changes to be reconciled
 <3> cancel the cherry-pick.  In other words, return to the
-pre-cherry-pick state, preserving any local modifications you had in
-the working tree.
+    pre-cherry-pick state, preserving any local modifications
+    you had in the working tree.
 <4> try to apply the change introduced by `topic^` again,
-spending extra time to avoid mistakes based on incorrectly matching
-context lines.
+    spending extra time to avoid mistakes based on incorrectly
+    matching context lines.
 
 SEE ALSO
 --------
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/git-clean.txt 1.2.3+git2.25.1-1/git/Documentation/git-clean.txt
--- 1.2.1+git2.18.0-1/git/Documentation/git-clean.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/git-clean.txt	2020-02-17 04:47:35.000000000 +0000
@@ -26,18 +26,20 @@ are affected.
 OPTIONS
 -------
 -d::
-	Remove untracked directories in addition to untracked files.
-	If an untracked directory is managed by a different Git
-	repository, it is not removed by default.  Use -f option twice
-	if you really want to remove such a directory.
+	Normally, when no <path> is specified, git clean will not
+	recurse into untracked directories to avoid removing too much.
+	Specify -d to have it recurse into such directories as well.
+	If any paths are specified, -d is irrelevant; all untracked
+	files matching the specified paths (with exceptions for nested
+	git directories mentioned under `--force`) will be removed.
 
 -f::
 --force::
 	If the Git configuration variable clean.requireForce is not set
 	to false, 'git clean' will refuse to delete files or directories
-	unless given -f, -n or -i. Git will refuse to delete directories
-	with .git sub directory or file unless a second -f
-	is given.
+	unless given -f or -i.  Git will refuse to modify untracked
+	nested git repositories (directories with a .git subdirectory)
+	unless a second -f is given.
 
 -i::
 --interactive::
@@ -55,16 +57,15 @@ OPTIONS
 
 -e <pattern>::
 --exclude=<pattern>::
-	In addition to those found in .gitignore (per directory) and
-	$GIT_DIR/info/exclude, also consider these patterns to be in the
-	set of the ignore rules in effect.
+	Use the given exclude pattern in addition to the standard ignore rules
+	(see linkgit:gitignore[5]).
 
 -x::
-	Don't use the standard ignore rules read from .gitignore (per
-	directory) and $GIT_DIR/info/exclude, but do still use the ignore
-	rules given with `-e` options.  This allows removing all untracked
+	Don't use the standard ignore rules (see linkgit:gitignore[5]), but
+	still use the ignore rules given with `-e` options from the command
+	line.  This allows removing all untracked
 	files, including build products.  This can be used (possibly in
-	conjunction with 'git reset') to create a pristine
+	conjunction with 'git restore' or 'git reset') to create a pristine
 	working directory to test a clean build.
 
 -X::
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/gitcli.txt 1.2.3+git2.25.1-1/git/Documentation/gitcli.txt
--- 1.2.1+git2.18.0-1/git/Documentation/gitcli.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/gitcli.txt	2020-02-17 04:47:35.000000000 +0000
@@ -37,6 +37,12 @@ arguments.  Here are the rules:
    file called HEAD in your work tree, `git diff HEAD` is ambiguous, and
    you have to say either `git diff HEAD --` or `git diff -- HEAD` to
    disambiguate.
+
+ * Because `--` disambiguates revisions and paths in some commands, it
+   cannot be used for those commands to separate options and revisions.
+   You can use `--end-of-options` for this (it also works for commands
+   that do not distinguish between revisions in paths, in which case it
+   is simply an alias for `--`).
 +
 When writing a script that is expected to handle random user-input, it is
 a good practice to make it explicit which arguments are which by placing
@@ -47,8 +53,8 @@ disambiguating `--` at appropriate place
    things:
 +
 --------------------------------
-$ git checkout -- *.c
-$ git checkout -- \*.c
+$ git restore *.c
+$ git restore \*.c
 --------------------------------
 +
 The former lets your shell expand the fileglob, and you are asking
@@ -205,10 +211,22 @@ only affects the files in the working tr
 entries, and with `--cached`, it modifies only the index
 entries.
 
-See also http://marc.info/?l=git&m=116563135620359 and
-http://marc.info/?l=git&m=119150393620273 for further
+See also https://lore.kernel.org/git/7v64clg5u9.fsf@assigned-by-dhcp.cox.net/ and
+https://lore.kernel.org/git/7vy7ej9g38.fsf@gitster.siamese.dyndns.org/ for further
 information.
 
+Some other commands that also work on files in the working tree and/or
+in the index can take `--staged` and/or `--worktree`.
+
+* `--staged` is exactly like `--cached`, which is used to ask a
+  command to only work on the index, not the working tree.
+
+* `--worktree` is the opposite, to ask a command to work on the
+  working tree only, not the index.
+
+* The two options can be specified together to ask a command to work
+  on both the index and the working tree.
+
 GIT
 ---
 Part of the linkgit:git[1] suite
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/git-clone.txt 1.2.3+git2.25.1-1/git/Documentation/git-clone.txt
--- 1.2.1+git2.18.0-1/git/Documentation/git-clone.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/git-clone.txt	2020-02-17 04:47:35.000000000 +0000
@@ -15,14 +15,15 @@ SYNOPSIS
 	  [--dissociate] [--separate-git-dir <git dir>]
 	  [--depth <depth>] [--[no-]single-branch] [--no-tags]
 	  [--recurse-submodules[=<pathspec>]] [--[no-]shallow-submodules]
-	  [--jobs <n>] [--] <repository> [<directory>]
+	  [--[no-]remote-submodules] [--jobs <n>] [--sparse] [--] <repository>
+	  [<directory>]
 
 DESCRIPTION
 -----------
 
 Clones a repository into a newly created directory, creates
 remote-tracking branches for each branch in the cloned repository
-(visible using `git branch -r`), and creates and checks out an
+(visible using `git branch --remotes`), and creates and checks out an
 initial branch that is forked from the cloned repository's
 currently active branch.
 
@@ -40,8 +41,8 @@ configuration variables.
 
 OPTIONS
 -------
---local::
 -l::
+--local::
 	When the repository to clone from is on a local machine,
 	this flag bypasses the normal "Git aware" transport
 	mechanism and clones the repository by making a copy of
@@ -62,8 +63,8 @@ Git transport instead.
 	directory instead of using hardlinks. This may be desirable
 	if you are trying to make a back-up of your repository.
 
---shared::
 -s::
+--shared::
 	When the repository to clone is on the local machine,
 	instead of using hard links, automatically setup
 	`.git/objects/info/alternates` to share the objects
@@ -80,13 +81,13 @@ which automatically call `git gc --auto`
 If these objects are removed and were referenced by the cloned repository,
 then the cloned repository will become corrupt.
 +
-Note that running `git repack` without the `-l` option in a repository
-cloned with `-s` will copy objects from the source repository into a pack
-in the cloned repository, removing the disk space savings of `clone -s`.
-It is safe, however, to run `git gc`, which uses the `-l` option by
+Note that running `git repack` without the `--local` option in a repository
+cloned with `--shared` will copy objects from the source repository into a pack
+in the cloned repository, removing the disk space savings of `clone --shared`.
+It is safe, however, to run `git gc`, which uses the `--local` option by
 default.
 +
-If you want to break the dependency of a repository cloned with `-s` on
+If you want to break the dependency of a repository cloned with `--shared` on
 its source repository, you can simply run `git repack -a` to copy all
 objects from the source repository into a pack in the cloned repository.
 
@@ -115,31 +116,39 @@ objects from the source repository into
 	same repository, and this option can be used to stop the
 	borrowing.
 
---quiet::
 -q::
+--quiet::
 	Operate quietly.  Progress is not reported to the standard
 	error stream.
 
---verbose::
 -v::
+--verbose::
 	Run verbosely. Does not affect the reporting of progress status
 	to the standard error stream.
 
 --progress::
 	Progress status is reported on the standard error stream
-	by default when it is attached to a terminal, unless -q
+	by default when it is attached to a terminal, unless `--quiet`
 	is specified. This flag forces progress status even if the
 	standard error stream is not directed to a terminal.
 
---no-checkout::
+--server-option=<option>::
+	Transmit the given string to the server when communicating using
+	protocol version 2.  The given string must not contain a NUL or LF
+	character.  The server's handling of server options, including
+	unknown ones, is server-specific.
+	When multiple `--server-option=<option>` are given, they are all
+	sent to the other side in the order listed on the command line.
+
 -n::
+--no-checkout::
 	No checkout of HEAD is performed after the clone is complete.
 
 --bare::
 	Make a 'bare' Git repository.  That is, instead of
 	creating `<directory>` and placing the administrative
 	files in `<directory>/.git`, make the `<directory>`
-	itself the `$GIT_DIR`. This obviously implies the `-n`
+	itself the `$GIT_DIR`. This obviously implies the `--no-checkout`
 	because there is nowhere to check out the working tree.
 	Also the branch heads at the remote are copied directly
 	to corresponding local branch heads, without mapping
@@ -147,6 +156,12 @@ objects from the source repository into
 	used, neither remote-tracking branches nor the related
 	configuration variables are created.
 
+--sparse::
+	Initialize the sparse-checkout file so the working
+	directory starts with only the files in the root
+	of the repository. The sparse-checkout file can be
+	modified to grow the working directory as needed.
+
 --mirror::
 	Set up a mirror of the source repository.  This implies `--bare`.
 	Compared to `--bare`, `--mirror` not only maps local branches of the
@@ -155,13 +170,13 @@ objects from the source repository into
 	that all these refs are overwritten by a `git remote update` in the
 	target repository.
 
---origin <name>::
 -o <name>::
+--origin <name>::
 	Instead of using the remote name `origin` to keep track
 	of the upstream repository, use `<name>`.
 
---branch <name>::
 -b <name>::
+--branch <name>::
 	Instead of pointing the newly created HEAD to the branch pointed
 	to by the cloned repository's HEAD, point to `<name>` branch
 	instead. In a non-bare repository, this is the branch that will
@@ -169,8 +184,8 @@ objects from the source repository into
 	`--branch` can also take tags and detaches the HEAD at that commit
 	in the resulting repository.
 
---upload-pack <upload-pack>::
 -u <upload-pack>::
+--upload-pack <upload-pack>::
 	When given, and the repository to clone from is accessed
 	via ssh, this specifies a non-default path for the command
 	run on the other end.
@@ -179,8 +194,8 @@ objects from the source repository into
 	Specify the directory from which templates will be used;
 	(See the "TEMPLATE DIRECTORY" section of linkgit:git-init[1].)
 
---config <key>=<value>::
 -c <key>=<value>::
+--config <key>=<value>::
 	Set a configuration variable in the newly-created repository;
 	this takes effect immediately after the repository is
 	initialized, but before the remote history is fetched or any
@@ -189,6 +204,12 @@ objects from the source repository into
 	values are given for the same key, each value will be written to
 	the config file. This makes it safe, for example, to add
 	additional fetch refspecs to the origin remote.
++
+Due to limitations of the current implementation, some configuration
+variables do not take effect until after the initial fetch and checkout.
+Configuration variables known to not take effect are:
+`remote.<name>.mirror` and `remote.<name>.tagOpt`.  Use the
+corresponding `--mirror` and `--no-tags` options instead.
 
 --depth <depth>::
 	Create a 'shallow' clone with a history truncated to the
@@ -246,6 +267,12 @@ or `--mirror` is given)
 --[no-]shallow-submodules::
 	All submodules which are cloned will be shallow with a depth of 1.
 
+--[no-]remote-submodules::
+	All submodules which are cloned will use the status of the submodule's
+	remote-tracking branch to update the submodule, rather than the
+	superproject's recorded SHA-1. Equivalent to passing `--remote` to
+	`git submodule update`.
+
 --separate-git-dir=<git dir>::
 	Instead of placing the cloned repository where it is supposed
 	to be, place the cloned repository at the specified directory,
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/git-column.txt 1.2.3+git2.25.1-1/git/Documentation/git-column.txt
--- 1.2.1+git2.18.0-1/git/Documentation/git-column.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/git-column.txt	2020-02-17 04:47:35.000000000 +0000
@@ -13,7 +13,10 @@ SYNOPSIS
 
 DESCRIPTION
 -----------
-This command formats its input into multiple columns.
+This command formats the lines of its standard input into a table with
+multiple columns. Each input line occupies one cell of the table. It
+is used internally by other git commands to format output into
+columns.
 
 OPTIONS
 -------
@@ -23,7 +26,7 @@ OPTIONS
 
 --mode=<mode>::
 	Specify layout mode. See configuration variable column.ui for option
-	syntax.
+	syntax in linkgit:git-config[1].
 
 --raw-mode=<n>::
 	Same as --mode but take mode encoded as a number. This is mainly used
@@ -43,6 +46,34 @@ OPTIONS
 --padding=<N>::
 	The number of spaces between columns. One space by default.
 
+EXAMPLES
+--------
+
+Format data by columns:
+------------
+$ seq 1 24 | git column --mode=column --padding=5
+1      4      7      10     13     16     19     22
+2      5      8      11     14     17     20     23
+3      6      9      12     15     18     21     24
+------------
+
+Format data by rows:
+------------
+$ seq 1 21 | git column --mode=row --padding=5
+1      2      3      4      5      6      7
+8      9      10     11     12     13     14
+15     16     17     18     19     20     21
+------------
+
+List some tags in a table with unequal column widths:
+------------
+$ git tag --list 'v2.4.*' --column=row,dense
+v2.4.0  v2.4.0-rc0  v2.4.0-rc1  v2.4.0-rc2  v2.4.0-rc3
+v2.4.1  v2.4.10     v2.4.11     v2.4.12     v2.4.2
+v2.4.3  v2.4.4      v2.4.5      v2.4.6      v2.4.7
+v2.4.8  v2.4.9
+------------
+
 GIT
 ---
 Part of the linkgit:git[1] suite
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/git-commit-graph.txt 1.2.3+git2.25.1-1/git/Documentation/git-commit-graph.txt
--- 1.2.1+git2.18.0-1/git/Documentation/git-commit-graph.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/git-commit-graph.txt	2020-02-17 04:47:35.000000000 +0000
@@ -3,91 +3,115 @@ git-commit-graph(1)
 
 NAME
 ----
-git-commit-graph - Write and verify Git commit graph files
+git-commit-graph - Write and verify Git commit-graph files
 
 
 SYNOPSIS
 --------
 [verse]
-'git commit-graph read' [--object-dir <dir>]
-'git commit-graph write' <options> [--object-dir <dir>]
+'git commit-graph verify' [--object-dir <dir>] [--shallow] [--[no-]progress]
+'git commit-graph write' <options> [--object-dir <dir>] [--[no-]progress]
 
 
 DESCRIPTION
 -----------
 
-Manage the serialized commit graph file.
+Manage the serialized commit-graph file.
 
 
 OPTIONS
 -------
 --object-dir::
-	Use given directory for the location of packfiles and commit graph
+	Use given directory for the location of packfiles and commit-graph
 	file. This parameter exists to specify the location of an alternate
-	that only has the objects directory, not a full .git directory. The
-	commit graph file is expected to be at <dir>/info/commit-graph and
-	the packfiles are expected to be in <dir>/pack.
-
+	that only has the objects directory, not a full `.git` directory. The
+	commit-graph file is expected to be in the `<dir>/info` directory and
+	the packfiles are expected to be in `<dir>/pack`.
+
+--[no-]progress::
+	Turn progress on/off explicitly. If neither is specified, progress is
+	shown if standard error is connected to a terminal.
 
 COMMANDS
 --------
 'write'::
 
-Write a commit graph file based on the commits found in packfiles.
+Write a commit-graph file based on the commits found in packfiles.
 +
 With the `--stdin-packs` option, generate the new commit graph by
 walking objects only in the specified pack-indexes. (Cannot be combined
-with --stdin-commits.)
+with `--stdin-commits` or `--reachable`.)
 +
 With the `--stdin-commits` option, generate the new commit graph by
 walking commits starting at the commits specified in stdin as a list
 of OIDs in hex, one OID per line. (Cannot be combined with
---stdin-packs.)
+`--stdin-packs` or `--reachable`.)
++
+With the `--reachable` option, generate the new commit graph by walking
+commits starting at all refs. (Cannot be combined with `--stdin-commits`
+or `--stdin-packs`.)
 +
 With the `--append` option, include all commits that are present in the
 existing commit-graph file.
++
+With the `--split` option, write the commit-graph as a chain of multiple
+commit-graph files stored in `<dir>/info/commit-graphs`. The new commits
+not already in the commit-graph are added in a new "tip" file. This file
+is merged with the existing file if the following merge conditions are
+met:
++
+* If `--size-multiple=<X>` is not specified, let `X` equal 2. If the new
+tip file would have `N` commits and the previous tip has `M` commits and
+`X` times `N` is greater than  `M`, instead merge the two files into a
+single file.
++
+* If `--max-commits=<M>` is specified with `M` a positive integer, and the
+new tip file would have more than `M` commits, then instead merge the new
+tip with the previous tip.
++
+Finally, if `--expire-time=<datetime>` is not specified, let `datetime`
+be the current time. After writing the split commit-graph, delete all
+unused commit-graph whose modified times are older than `datetime`.
 
-'read'::
+'verify'::
 
-Read a graph file given by the commit-graph file and output basic
-details about the graph file. Used for debugging purposes.
+Read the commit-graph file and verify its contents against the object
+database. Used to check for corrupted data.
++
+With the `--shallow` option, only check the tip commit-graph file in
+a chain of split commit-graphs.
 
 
 EXAMPLES
 --------
 
-* Write a commit graph file for the packed commits in your local .git folder.
+* Write a commit-graph file for the packed commits in your local `.git`
+  directory.
 +
 ------------------------------------------------
 $ git commit-graph write
 ------------------------------------------------
 
-* Write a graph file, extending the current graph file using commits
-* in <pack-index>.
+* Write a commit-graph file, extending the current commit-graph file
+  using commits in `<pack-index>`.
 +
 ------------------------------------------------
 $ echo <pack-index> | git commit-graph write --stdin-packs
 ------------------------------------------------
 
-* Write a graph file containing all reachable commits.
+* Write a commit-graph file containing all reachable commits.
 +
 ------------------------------------------------
 $ git show-ref -s | git commit-graph write --stdin-commits
 ------------------------------------------------
 
-* Write a graph file containing all commits in the current
-* commit-graph file along with those reachable from HEAD.
+* Write a commit-graph file containing all commits in the current
+  commit-graph file along with those reachable from `HEAD`.
 +
 ------------------------------------------------
 $ git rev-parse HEAD | git commit-graph write --stdin-commits --append
 ------------------------------------------------
 
-* Read basic information from the commit-graph file.
-+
-------------------------------------------------
-$ git commit-graph read
-------------------------------------------------
-
 
 GIT
 ---
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/git-commit-tree.txt 1.2.3+git2.25.1-1/git/Documentation/git-commit-tree.txt
--- 1.2.1+git2.18.0-1/git/Documentation/git-commit-tree.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/git-commit-tree.txt	2020-02-17 04:47:35.000000000 +0000
@@ -23,6 +23,10 @@ Creates a new commit object based on the
 emits the new commit object id on stdout. The log message is read
 from the standard input, unless `-m` or `-F` options are given.
 
+The `-m` and `-F` options can be given any number of times, in any
+order. The commit log message will be composed in the order in which
+the options are given.
+
 A commit object may have any number of parents. With exactly one
 parent, it is an ordinary commit. Having more than one parent makes
 the commit a merge between several lines of history. Initial (root)
@@ -41,7 +45,7 @@ state was.
 OPTIONS
 -------
 <tree>::
-	An existing tree object
+	An existing tree object.
 
 -p <parent>::
 	Each `-p` indicates the id of a parent commit object.
@@ -52,7 +56,8 @@ OPTIONS
 
 -F <file>::
 	Read the commit log message from the given file. Use `-` to read
-	from the standard input.
+	from the standard input. This can be given more than once and the
+	content of each file becomes its own paragraph.
 
 -S[<keyid>]::
 --gpg-sign[=<keyid>]::
@@ -64,7 +69,6 @@ OPTIONS
 	Do not GPG-sign commit, to countermand a `--gpg-sign` option
 	given earlier on the command line.
 
-
 Commit Information
 ------------------
 
@@ -74,26 +78,6 @@ A commit encapsulates:
 - author name, email and date
 - committer name and email and the commit time.
 
-While parent object ids are provided on the command line, author and
-committer information is taken from the following environment variables,
-if set:
-
-	GIT_AUTHOR_NAME
-	GIT_AUTHOR_EMAIL
-	GIT_AUTHOR_DATE
-	GIT_COMMITTER_NAME
-	GIT_COMMITTER_EMAIL
-	GIT_COMMITTER_DATE
-
-(nb "<", ">" and "\n"s are stripped)
-
-In case (some of) these environment variables are not set, the information
-is taken from the configuration items user.name and user.email, or, if not
-present, the environment variable EMAIL, or, if that is not set,
-system user name and the hostname used for outgoing mail (taken
-from `/etc/mailname` and falling back to the fully qualified hostname when
-that file does not exist).
-
 A commit comment is read from stdin. If a changelog
 entry is not provided via "<" redirection, 'git commit-tree' will just wait
 for one to be entered and terminated with ^D.
@@ -112,6 +96,7 @@ FILES
 SEE ALSO
 --------
 linkgit:git-write-tree[1]
+linkgit:git-commit[1]
 
 GIT
 ---
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/git-commit.txt 1.2.3+git2.25.1-1/git/Documentation/git-commit.txt
--- 1.2.1+git2.18.0-1/git/Documentation/git-commit.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/git-commit.txt	2020-02-17 04:47:35.000000000 +0000
@@ -13,20 +13,25 @@ SYNOPSIS
 	   [-F <file> | -m <msg>] [--reset-author] [--allow-empty]
 	   [--allow-empty-message] [--no-verify] [-e] [--author=<author>]
 	   [--date=<date>] [--cleanup=<mode>] [--[no-]status]
-	   [-i | -o] [-S[<keyid>]] [--] [<file>...]
+	   [-i | -o] [--pathspec-from-file=<file> [--pathspec-file-nul]]
+	   [-S[<keyid>]] [--] [<pathspec>...]
 
 DESCRIPTION
 -----------
-Stores the current contents of the index in a new commit along
-with a log message from the user describing the changes.
+Create a new commit containing the current contents of the index and
+the given log message describing the changes. The new commit is a
+direct child of HEAD, usually the tip of the current branch, and the
+branch is updated to point to it (unless no branch is associated with
+the working tree, in which case HEAD is "detached" as described in
+linkgit:git-checkout[1]).
+
+The content to be committed can be specified in several ways:
+
+1. by using linkgit:git-add[1] to incrementally "add" changes to the
+   index before using the 'commit' command (Note: even modified files
+   must be "added");
 
-The content to be added can be specified in several ways:
-
-1. by using 'git add' to incrementally "add" changes to the
-   index before using the 'commit' command (Note: even modified
-   files must be "added");
-
-2. by using 'git rm' to remove files from the working tree
+2. by using linkgit:git-rm[1] to remove files from the working tree
    and the index, again before using the 'commit' command;
 
 3. by listing files as arguments to the 'commit' command
@@ -274,22 +279,37 @@ FROM UPSTREAM REBASE" section in linkgit
 	already been staged. If used together with `--allow-empty`
 	paths are also not required, and an empty commit will be created.
 
+--pathspec-from-file=<file>::
+	Pathspec is passed in `<file>` instead of commandline args. If
+	`<file>` is exactly `-` then standard input is used. Pathspec
+	elements are separated by LF or CR/LF. Pathspec elements can be
+	quoted as explained for the configuration variable `core.quotePath`
+	(see linkgit:git-config[1]). See also `--pathspec-file-nul` and
+	global `--literal-pathspecs`.
+
+--pathspec-file-nul::
+	Only meaningful with `--pathspec-from-file`. Pathspec elements are
+	separated with NUL character and all other characters are taken
+	literally (including newlines and quotes).
+
 -u[<mode>]::
 --untracked-files[=<mode>]::
 	Show untracked files.
 +
+--
 The mode parameter is optional (defaults to 'all'), and is used to
 specify the handling of untracked files; when -u is not used, the
 default is 'normal', i.e. show untracked files and directories.
-+
+
 The possible options are:
-+
+
 	- 'no'     - Show no untracked files
 	- 'normal' - Shows untracked files and directories
 	- 'all'    - Also shows individual files in untracked directories.
-+
+
 The default can be changed using the status.showUntrackedFiles
 configuration variable documented in linkgit:git-config[1].
+--
 
 -v::
 --verbose::
@@ -339,15 +359,13 @@ changes to tracked files.
 \--::
 	Do not interpret any more arguments as options.
 
-<file>...::
-	When files are given on the command line, the command
-	commits the contents of the named files, without
-	recording the changes already staged.  The contents of
-	these files are also staged for the next commit on top
-	of what have been staged before.
-
-:git-commit: 1
-include::date-formats.txt[]
+<pathspec>...::
+	When pathspec is given on the command line, commit the contents of
+	the files that match the pathspec without recording the changes
+	already added to the index. The contents of these files are also
+	staged for the next commit on top of what have been staged before.
++
+For more details, see the 'pathspec' entry in linkgit:gitglossary[7].
 
 EXAMPLES
 --------
@@ -355,7 +373,7 @@ When recording your own work, the conten
 your working tree are temporarily stored to a staging area
 called the "index" with 'git add'.  A file can be
 reverted back, only in the index but not in the working tree,
-to that of the last commit with `git reset HEAD -- <file>`,
+to that of the last commit with `git restore --staged <file>`,
 which effectively reverts 'git add' and prevents the changes to
 this file from participating in the next commit.  After building
 the state to be committed incrementally with these commands,
@@ -442,6 +460,43 @@ alter the order the changes are committe
 should be recorded as a single commit.  In fact, the command
 refuses to run when given pathnames (but see `-i` option).
 
+COMMIT INFORMATION
+------------------
+
+Author and committer information is taken from the following environment
+variables, if set:
+
+	GIT_AUTHOR_NAME
+	GIT_AUTHOR_EMAIL
+	GIT_AUTHOR_DATE
+	GIT_COMMITTER_NAME
+	GIT_COMMITTER_EMAIL
+	GIT_COMMITTER_DATE
+
+(nb "<", ">" and "\n"s are stripped)
+
+The author and committer names are by convention some form of a personal name
+(that is, the name by which other humans refer to you), although Git does not
+enforce or require any particular form. Arbitrary Unicode may be used, subject
+to the constraints listed above. This name has no effect on authentication; for
+that, see the `credential.username` variable in linkgit:git-config[1].
+
+In case (some of) these environment variables are not set, the information
+is taken from the configuration items `user.name` and `user.email`, or, if not
+present, the environment variable EMAIL, or, if that is not set,
+system user name and the hostname used for outgoing mail (taken
+from `/etc/mailname` and falling back to the fully qualified hostname when
+that file does not exist).
+
+The `author.name` and `committer.name` and their corresponding email options
+override `user.name` and `user.email` if set and are overridden themselves by
+the environment variables.
+
+The typical usage is to set just the `user.name` and `user.email` variables;
+the other options are provided for more complex use cases.
+
+:git-commit: 1
+include::date-formats.txt[]
 
 DISCUSSION
 ----------
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/git-config.txt 1.2.3+git2.25.1-1/git/Documentation/git-config.txt
--- 1.2.1+git2.18.0-1/git/Documentation/git-config.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/git-config.txt	2020-02-17 04:47:35.000000000 +0000
@@ -45,13 +45,15 @@ unset an existing `--type` specifier wit
 
 When reading, the values are read from the system, global and
 repository local configuration files by default, and options
-`--system`, `--global`, `--local` and `--file <filename>` can be
-used to tell the command to read from only that location (see <<FILES>>).
+`--system`, `--global`, `--local`, `--worktree` and
+`--file <filename>` can be used to tell the command to read from only
+that location (see <<FILES>>).
 
 When writing, the new value is written to the repository local
 configuration file by default, and options `--system`, `--global`,
-`--file <filename>` can be used to tell the command to write to
-that location (you can say `--local` but that is the default).
+`--worktree`, `--file <filename>` can be used to tell the command to
+write to that location (you can say `--local` but that is the
+default).
 
 This command will fail with non-zero status upon error.  Some exit
 codes are:
@@ -124,13 +126,18 @@ See also <<FILES>>.
 
 --local::
 	For writing options: write to the repository `.git/config` file.
-	This is	the default behavior.
+	This is the default behavior.
 +
 For reading options: read only from the repository `.git/config` rather than
 from all available files.
 +
 See also <<FILES>>.
 
+--worktree::
+	Similar to `--local` except that `.git/config.worktree` is
+	read from or written to if `extensions.worktreeConfig` is
+	present. If not it's the same as `--local`.
+
 -f config-file::
 --file config-file::
 	Use the given config file instead of the one specified by GIT_CONFIG.
@@ -188,8 +195,8 @@ Valid `<type>`'s include:
 --bool-or-int::
 --path::
 --expiry-date::
-  Historical options for selecting a type specifier. Prefer instead `--type`,
-  (see: above).
+  Historical options for selecting a type specifier. Prefer instead `--type`
+  (see above).
 
 --no-type::
   Un-sets the previously set type specifier (if one was previously set). This
@@ -233,7 +240,9 @@ Valid `<type>`'s include:
 	output.  The optional `default` parameter is used instead, if
 	there is no color configured for `name`.
 +
-`--type=color [--default=<default>]` is preferred over `--get-color`.
+`--type=color [--default=<default>]` is preferred over `--get-color`
+(but note that `--get-color` will omit the trailing newline printed by
+`--type=color`).
 
 -e::
 --edit::
@@ -281,6 +290,10 @@ $XDG_CONFIG_HOME/git/config::
 $GIT_DIR/config::
 	Repository specific configuration file.
 
+$GIT_DIR/config.worktree::
+	This is optional and is only searched when
+	`extensions.worktreeConfig` is present in $GIT_DIR/config.
+
 If no further options are given, all reading options will read all of these
 files that are available. If the global or the system-wide configuration
 file are not available they will be ignored. If the repository configuration
@@ -299,9 +312,10 @@ configuration file. Note that this also
 and `--unset`. *'git config' will only ever change one file at a time*.
 
 You can override these rules either by command-line options or by environment
-variables. The `--global` and the `--system` options will limit the file used
-to the global or system-wide file respectively. The `GIT_CONFIG` environment
-variable has a similar effect, but you can specify any filename you want.
+variables. The `--global`, `--system` and `--worktree` options will limit
+the file used to the global, system-wide or per-worktree file respectively.
+The `GIT_CONFIG` environment variable has a similar effect, but you
+can specify any filename you want.
 
 
 ENVIRONMENT
@@ -325,33 +339,35 @@ EXAMPLES
 
 Given a .git/config like this:
 
-	#
-	# This is the config file, and
-	# a '#' or ';' character indicates
-	# a comment
-	#
-
-	; core variables
-	[core]
-		; Don't trust file modes
-		filemode = false
-
-	; Our diff algorithm
-	[diff]
-		external = /usr/local/bin/diff-wrapper
-		renames = true
-
-	; Proxy settings
-	[core]
-		gitproxy=proxy-command for kernel.org
-		gitproxy=default-proxy ; for all the rest
-
-	; HTTP
-	[http]
-		sslVerify
-	[http "https://weak.example.com"]
-		sslVerify = false
-		cookieFile = /tmp/cookie.txt
+------------
+#
+# This is the config file, and
+# a '#' or ';' character indicates
+# a comment
+#
+
+; core variables
+[core]
+	; Don't trust file modes
+	filemode = false
+
+; Our diff algorithm
+[diff]
+	external = /usr/local/bin/diff-wrapper
+	renames = true
+
+; Proxy settings
+[core]
+	gitproxy=proxy-command for kernel.org
+	gitproxy=default-proxy ; for all the rest
+
+; HTTP
+[http]
+	sslVerify
+[http "https://weak.example.com"]
+	sslVerify = false
+	cookieFile = /tmp/cookie.txt
+------------
 
 you can set the filemode to true with
 
@@ -442,9 +458,9 @@ For URLs in `https://weak.example.com`,
 false, while it is set to `true` for all others:
 
 ------------
-% git config --bool --get-urlmatch http.sslverify https://good.example.com
+% git config --type=bool --get-urlmatch http.sslverify https://good.example.com
 true
-% git config --bool --get-urlmatch http.sslverify https://weak.example.com
+% git config --type=bool --get-urlmatch http.sslverify https://weak.example.com
 false
 % git config --get-urlmatch http https://weak.example.com
 http.cookieFile /tmp/cookie.txt
@@ -453,6 +469,27 @@ http.sslverify false
 
 include::config.txt[]
 
+BUGS
+----
+When using the deprecated `[section.subsection]` syntax, changing a value
+will result in adding a multi-line key instead of a change, if the subsection
+is given with at least one uppercase character. For example when the config
+looks like
+
+--------
+  [section.subsection]
+    key = value1
+--------
+
+and running `git config section.Subsection.key value2` will result in
+
+--------
+  [section.subsection]
+    key = value1
+    key = value2
+--------
+
+
 GIT
 ---
 Part of the linkgit:git[1] suite
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/gitcore-tutorial.txt 1.2.3+git2.25.1-1/git/Documentation/gitcore-tutorial.txt
--- 1.2.1+git2.18.0-1/git/Documentation/gitcore-tutorial.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/gitcore-tutorial.txt	2020-02-17 04:47:35.000000000 +0000
@@ -741,7 +741,7 @@ used earlier, and create a branch in it.
 saying that you want to check out a new branch:
 
 ------------
-$ git checkout -b mybranch
+$ git switch -c mybranch
 ------------
 
 will create a new branch based at the current `HEAD` position, and switch
@@ -751,11 +751,11 @@ to it.
 ================================================
 If you make the decision to start your new branch at some
 other point in the history than the current `HEAD`, you can do so by
-just telling 'git checkout' what the base of the checkout would be.
+just telling 'git switch' what the base of the checkout would be.
 In other words, if you have an earlier tag or branch, you'd just do
 
 ------------
-$ git checkout -b mybranch earlier-commit
+$ git switch -c mybranch earlier-commit
 ------------
 
 and it would create the new branch `mybranch` at the earlier commit,
@@ -765,7 +765,7 @@ and check out the state at that time.
 You can always just jump back to your original `master` branch by doing
 
 ------------
-$ git checkout master
+$ git switch master
 ------------
 
 (or any other branch-name, for that matter) and if you forget which
@@ -794,7 +794,7 @@ $ git branch <branchname> [startingpoint
 
 which will simply _create_ the branch, but will not do anything further.
 You can then later -- once you decide that you want to actually develop
-on that branch -- switch to that branch with a regular 'git checkout'
+on that branch -- switch to that branch with a regular 'git switch'
 with the branchname as the argument.
 
 
@@ -808,7 +808,7 @@ being the same as the original `master`
 that branch, and do some work there.
 
 ------------------------------------------------
-$ git checkout mybranch
+$ git switch mybranch
 $ echo "Work, work, work" >>hello
 $ git commit -m "Some work." -i hello
 ------------------------------------------------
@@ -825,7 +825,7 @@ does some work in the original branch, a
 to the master branch, and editing the same file differently there:
 
 ------------
-$ git checkout master
+$ git switch master
 ------------
 
 Here, take a moment to look at the contents of `hello`, and notice how they
@@ -958,7 +958,7 @@ to the `master` branch. Let's go back to
 'git merge' to get the "upstream changes" back to your branch.
 
 ------------
-$ git checkout mybranch
+$ git switch mybranch
 $ git merge -m "Merge upstream changes." master
 ------------
 
@@ -1133,9 +1133,8 @@ Remember, before running 'git merge', ou
 work." commit.
 
 ------------
-$ git checkout mybranch
-$ git reset --hard master^2
-$ git checkout master
+$ git switch -C mybranch master^2
+$ git switch master
 $ git reset --hard master^
 ------------
 
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/gitcredentials.txt 1.2.3+git2.25.1-1/git/Documentation/gitcredentials.txt
--- 1.2.1+git2.18.0-1/git/Documentation/gitcredentials.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/gitcredentials.txt	2020-02-17 04:47:35.000000000 +0000
@@ -133,6 +133,12 @@ compares hostnames exactly, without cons
 the same domain. Likewise, a config entry for `http://example.com` would not
 match: Git compares the protocols exactly.
 
+If the "pattern" URL does include a path component, then this too must match
+exactly: the context `https://example.com/bar/baz.git` will match a config
+entry for `https://example.com/bar/baz.git` (in addition to matching the config
+entry for `https://example.com`) but will not match a config entry for
+`https://example.com/bar`.
+
 
 CONFIGURATION OPTIONS
 ---------------------
@@ -180,8 +186,7 @@ CUSTOM HELPERS
 --------------
 
 You can write your own custom helpers to interface with any system in
-which you keep credentials. See the documentation for Git's
-link:technical/api-credentials.html[credentials API] for details.
+which you keep credentials. See credential.h for details.
 
 GIT
 ---
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/git-credential.txt 1.2.3+git2.25.1-1/git/Documentation/git-credential.txt
--- 1.2.1+git2.18.0-1/git/Documentation/git-credential.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/git-credential.txt	2020-02-17 04:47:35.000000000 +0000
@@ -19,8 +19,7 @@ from system-specific helpers, as well as
 usernames and passwords. The git-credential command exposes this
 interface to scripts which may want to retrieve, store, or prompt for
 credentials in the same manner as Git. The design of this scriptable
-interface models the internal C API; see
-link:technical/api-credentials.html[the Git credential API] for more
+interface models the internal C API; see credential.h for more
 background on the concepts.
 
 git-credential takes an "action" option on the command-line (one of
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/git-cvsserver.txt 1.2.3+git2.25.1-1/git/Documentation/git-cvsserver.txt
--- 1.2.1+git2.18.0-1/git/Documentation/git-cvsserver.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/git-cvsserver.txt	2020-02-17 04:47:35.000000000 +0000
@@ -232,7 +232,7 @@ write so it might not be enough to grant
 'git-cvsserver' write access to the database file without granting
 them write access to the directory, too.
 
-The database can not be reliably regenerated in a
+The database cannot be reliably regenerated in a
 consistent form after the branch it is tracking has changed.
 Example: For merged branches, 'git-cvsserver' only tracks
 one branch of development, and after a 'git merge' an
@@ -294,7 +294,7 @@ In `dbDriver` and `dbUser` you can use t
 	Git directory name
 %g::
 	Git directory name, where all characters except for
-	alpha-numeric ones, `.`, and `-` are replaced with
+	alphanumeric ones, `.`, and `-` are replaced with
 	`_` (this should make it easier to use the directory
 	name in a filename if wanted)
 %m::
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/git-daemon.txt 1.2.3+git2.25.1-1/git/Documentation/git-daemon.txt
--- 1.2.1+git2.18.0-1/git/Documentation/git-daemon.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/git-daemon.txt	2020-02-17 04:47:35.000000000 +0000
@@ -57,7 +57,7 @@ OPTIONS
 	This is sort of "Git root" - if you run 'git daemon' with
 	'--base-path=/srv/git' on example.com, then if you later try to pull
 	'git://example.com/hello.git', 'git daemon' will interpret the path
-	as '/srv/git/hello.git'.
+	as `/srv/git/hello.git`.
 
 --base-path-relaxed::
 	If --base-path is enabled and repo lookup fails, with this option
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/git-describe.txt 1.2.3+git2.25.1-1/git/Documentation/git-describe.txt
--- 1.2.1+git2.18.0-1/git/Documentation/git-describe.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/git-describe.txt	2020-02-17 04:47:35.000000000 +0000
@@ -18,7 +18,9 @@ The command finds the most recent tag th
 commit.  If the tag points to the commit, then only the tag is
 shown.  Otherwise, it suffixes the tag name with the number of
 additional commits on top of the tagged object and the
-abbreviated object name of the most recent commit.
+abbreviated object name of the most recent commit. The result
+is a "human-readable" object name which can also be used to
+identify the commit to other git commands.
 
 By default (without --all or --tags) `git describe` only shows
 annotated tags.  For more information about creating annotated tags
@@ -137,7 +139,7 @@ at the end.
 
 The number of additional commits is the number
 of commits which would be displayed by "git log v1.0.4..parent".
-The hash suffix is "-g" + 7-char abbreviation for the tip commit
+The hash suffix is "-g" + unambiguous abbreviation for the tip commit
 of parent (which was `2414721b194453f058079d897d13c4e377f92dc6`).
 The "g" prefix stands for "git" and is used to allow describing the version of
 a software depending on the SCM the software is managed with. This is useful
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/gitdiffcore.txt 1.2.3+git2.25.1-1/git/Documentation/gitdiffcore.txt
--- 1.2.1+git2.18.0-1/git/Documentation/gitdiffcore.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/gitdiffcore.txt	2020-02-17 04:47:35.000000000 +0000
@@ -242,7 +242,8 @@ textual diff has an added or a deleted l
 regular expression.  This means that it will detect in-file (or what
 rename-detection considers the same file) moves, which is noise.  The
 implementation runs diff twice and greps, and this can be quite
-expensive.
+expensive.  To speed things up binary files without textconv filters
+will be ignored.
 
 When `-S` or `-G` are used without `--pickaxe-all`, only filepairs
 that match their respective criterion are kept in the output.  When
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/git-difftool.txt 1.2.3+git2.25.1-1/git/Documentation/git-difftool.txt
--- 1.2.1+git2.18.0-1/git/Documentation/git-difftool.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/git-difftool.txt	2020-02-17 04:47:35.000000000 +0000
@@ -90,7 +90,9 @@ instead.  `--no-symlinks` is the default
 	When 'git-difftool' is invoked with the `-g` or `--gui` option
 	the default diff tool will be read from the configured
 	`diff.guitool` variable instead of `diff.tool`. The `--no-gui`
-	option can be used to override this setting.
+	option can be used to override this setting. If `diff.guitool`
+	is not set, we will fallback in the order of `merge.guitool`,
+	`diff.tool`, `merge.tool` until a tool is found.
 
 --[no-]trust-exit-code::
 	'git-difftool' invokes a diff tool individually on each file.
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/git-diff-tree.txt 1.2.3+git2.25.1-1/git/Documentation/git-diff-tree.txt
--- 1.2.1+git2.18.0-1/git/Documentation/git-diff-tree.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/git-diff-tree.txt	2020-02-17 04:47:35.000000000 +0000
@@ -10,8 +10,8 @@ SYNOPSIS
 --------
 [verse]
 'git diff-tree' [--stdin] [-m] [-s] [-v] [--no-commit-id] [--pretty]
-	      [-t] [-r] [-c | --cc] [--root] [<common diff options>]
-	      <tree-ish> [<tree-ish>] [<path>...]
+	      [-t] [-r] [-c | --cc] [--combined-all-paths] [--root]
+	      [<common diff options>] <tree-ish> [<tree-ish>] [<path>...]
 
 DESCRIPTION
 -----------
@@ -31,10 +31,7 @@ include::diff-options.txt[]
 
 <path>...::
 	If provided, the results are limited to a subset of files
-	matching one of these prefix strings.
-	i.e., file matches `/^<pattern1>|<pattern2>|.../`
-	Note that this parameter does not provide any wildcard or regexp
-	features.
+	matching one of the provided pathspecs.
 
 -r::
         recurse into sub-trees
@@ -108,6 +105,13 @@ include::pretty-options.txt[]
 	itself and the commit log message is not shown, just like in any other
 	"empty diff" case.
 
+--combined-all-paths::
+	This flag causes combined diffs (used for merge commits) to
+	list the name of the file from all parents.  It thus only has
+	effect when -c or --cc are specified, and is likely only
+	useful if filename changes are detected (i.e. when either
+	rename or copy detection have been requested).
+
 --always::
 	Show the commit itself and the commit log message even
 	if the diff itself is empty.
@@ -115,51 +119,6 @@ include::pretty-options.txt[]
 
 include::pretty-formats.txt[]
 
-
-LIMITING OUTPUT
----------------
-If you're only interested in differences in a subset of files, for
-example some architecture-specific files, you might do:
-
-	git diff-tree -r <tree-ish> <tree-ish> arch/ia64 include/asm-ia64
-
-and it will only show you what changed in those two directories.
-
-Or if you are searching for what changed in just `kernel/sched.c`, just do
-
-	git diff-tree -r <tree-ish> <tree-ish> kernel/sched.c
-
-and it will ignore all differences to other files.
-
-The pattern is always the prefix, and is matched exactly.  There are no
-wildcards.  Even stricter, it has to match a complete path component.
-I.e. "foo" does not pick up `foobar.h`.  "foo" does match `foo/bar.h`
-so it can be used to name subdirectories.
-
-An example of normal usage is:
-
-  torvalds@ppc970:~/git> git diff-tree --abbrev 5319e4
-  :100664 100664 ac348b... a01513...	git-fsck-objects.c
-
-which tells you that the last commit changed just one file (it's from
-this one:
-
------------------------------------------------------------------------------
-commit 3c6f7ca19ad4043e9e72fa94106f352897e651a8
-tree 5319e4d609cdd282069cc4dce33c1db559539b03
-parent b4e628ea30d5ab3606119d2ea5caeab141d38df7
-author Linus Torvalds <torvalds@ppc970.osdl.org> Sat Apr 9 12:02:30 2005
-committer Linus Torvalds <torvalds@ppc970.osdl.org> Sat Apr 9 12:02:30 2005
-
-Make "git-fsck-objects" print out all the root commits it finds.
-
-Once I do the reference tracking, I'll also make it print out all the
-HEAD commits it finds, which is even more interesting.
------------------------------------------------------------------------------
-
-in case you care).
-
-
 include::diff-format.txt[]
 
 GIT
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/git-diff.txt 1.2.3+git2.25.1-1/git/Documentation/git-diff.txt
--- 1.2.1+git2.18.0-1/git/Documentation/git-diff.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/git-diff.txt	2020-02-17 04:47:35.000000000 +0000
@@ -36,7 +36,7 @@ two blob objects, or changes between two
 	running the command in a working tree controlled by Git and
 	at least one of the paths points outside the working tree,
 	or when running the command outside a working tree
-	controlled by Git.
+	controlled by Git. This form implies `--exit-code`.
 
 'git diff' [<options>] --cached [<commit>] [--] [<path>...]::
 
@@ -72,10 +72,10 @@ two blob objects, or changes between two
 	This form is to view the changes on the branch containing
 	and up to the second <commit>, starting at a common ancestor
 	of both <commit>.  "git diff A\...B" is equivalent to
-	"git diff $(git-merge-base A B) B".  You can omit any one
+	"git diff $(git merge-base A B) B".  You can omit any one
 	of <commit>, which has the same effect as using HEAD instead.
 
-Just in case if you are doing something exotic, it should be
+Just in case you are doing something exotic, it should be
 noted that all of the <commit> in the above description, except
 in the last two forms that use ".." notations, can be any
 <tree>.
@@ -132,9 +132,9 @@ $ git diff HEAD       <3>
 +
 <1> Changes in the working tree not yet staged for the next commit.
 <2> Changes between the index and your last commit; what you
-would be committing if you run "git commit" without "-a" option.
+    would be committing if you run "git commit" without "-a" option.
 <3> Changes in the working tree since your last commit; what you
-would be committing if you run "git commit -a"
+    would be committing if you run "git commit -a"
 
 Comparing with arbitrary commits::
 +
@@ -145,10 +145,10 @@ $ git diff HEAD^ HEAD      <3>
 ------------
 +
 <1> Instead of using the tip of the current branch, compare with the
-tip of "test" branch.
+    tip of "test" branch.
 <2> Instead of comparing with the tip of "test" branch, compare with
-the tip of the current branch, but limit the comparison to the
-file "test".
+    the tip of the current branch, but limit the comparison to the
+    file "test".
 <3> Compare the version before the last commit and the last commit.
 
 Comparing branches::
@@ -162,7 +162,7 @@ $ git diff topic...master  <3>
 <1> Changes between the tips of the topic and the master branches.
 <2> Same as above.
 <3> Changes that occurred on the master branch since when the topic
-branch was started off it.
+    branch was started off it.
 
 Limiting the diff output::
 +
@@ -173,9 +173,9 @@ $ git diff arch/i386 include/asm-i386
 ------------
 +
 <1> Show only modification, rename, and copy, but not addition
-or deletion.
+    or deletion.
 <2> Show only names and the nature of change, but not actual
-diff output.
+    diff output.
 <3> Limit diff output to named subtrees.
 
 Munging the diff output::
@@ -186,7 +186,7 @@ $ git diff -R                          <
 ------------
 +
 <1> Spend extra cycles to find renames, copies and complete
-rewrites (very expensive).
+    rewrites (very expensive).
 <2> Output diff in reverse.
 
 SEE ALSO
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/giteveryday.txt 1.2.3+git2.25.1-1/git/Documentation/giteveryday.txt
--- 1.2.1+git2.18.0-1/git/Documentation/giteveryday.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/giteveryday.txt	2020-02-17 04:47:35.000000000 +0000
@@ -41,7 +41,7 @@ following commands.
 
   * linkgit:git-log[1] to see what happened.
 
-  * linkgit:git-checkout[1] and linkgit:git-branch[1] to switch
+  * linkgit:git-switch[1] and linkgit:git-branch[1] to switch
     branches.
 
   * linkgit:git-add[1] to manage the index file.
@@ -51,8 +51,7 @@ following commands.
 
   * linkgit:git-commit[1] to advance the current branch.
 
-  * linkgit:git-reset[1] and linkgit:git-checkout[1] (with
-    pathname parameters) to undo changes.
+  * linkgit:git-restore[1] to undo changes.
 
   * linkgit:git-merge[1] to merge between local branches.
 
@@ -80,9 +79,9 @@ $ git tag v2.43 <2>
 Create a topic branch and develop.::
 +
 ------------
-$ git checkout -b alsa-audio <1>
+$ git switch -c alsa-audio <1>
 $ edit/compile/test
-$ git checkout -- curses/ux_audio_oss.c <2>
+$ git restore curses/ux_audio_oss.c <2>
 $ git add curses/ux_audio_alsa.c <3>
 $ edit/compile/test
 $ git diff HEAD <4>
@@ -90,7 +89,7 @@ $ git commit -a -s <5>
 $ edit/compile/test
 $ git diff HEAD^ <6>
 $ git commit -a --amend <7>
-$ git checkout master <8>
+$ git switch master <8>
 $ git merge alsa-audio <9>
 $ git log --since='3 days ago' <10>
 $ git log v2.43.. curses/ <11>
@@ -148,11 +147,11 @@ Clone the upstream and work on it.  Feed
 ------------
 $ git clone git://git.kernel.org/pub/scm/.../torvalds/linux-2.6 my2.6
 $ cd my2.6
-$ git checkout -b mine master <1>
+$ git switch -c mine master <1>
 $ edit/compile/test; git commit -a -s <2>
 $ git format-patch master <3>
 $ git send-email --to="person <email@example.com>" 00*.patch <4>
-$ git checkout master <5>
+$ git switch master <5>
 $ git pull <6>
 $ git log -p ORIG_HEAD.. arch/i386 include/asm-i386 <7>
 $ git ls-remote --heads http://git.kernel.org/.../jgarzik/libata-dev.git <8>
@@ -194,7 +193,7 @@ satellite$ edit/compile/test/commit
 satellite$ git push origin <4>
 
 mothership$ cd frotz
-mothership$ git checkout master
+mothership$ git switch master
 mothership$ git merge satellite/master <5>
 ------------
 +
@@ -216,7 +215,7 @@ machine into the master branch.
 Branch off of a specific tag.::
 +
 ------------
-$ git checkout -b private2.6.14 v2.6.14 <1>
+$ git switch -c private2.6.14 v2.6.14 <1>
 $ edit/compile/test; git commit -a
 $ git checkout master
 $ git cherry-pick v2.6.14..private2.6.14 <2>
@@ -244,7 +243,7 @@ commands in addition to the ones needed
 
 This section can also be used by those who respond to `git
 request-pull` or pull-request on GitHub (www.github.com) to
-integrate the work of others into their history. An sub-area
+integrate the work of others into their history. A sub-area
 lieutenant for a repository will act both as a participant and
 as an integrator.
 
@@ -274,14 +273,14 @@ $ mailx <3>
 & s 2 3 4 5 ./+to-apply
 & s 7 8 ./+hold-linus
 & q
-$ git checkout -b topic/one master
+$ git switch -c topic/one master
 $ git am -3 -i -s ./+to-apply <4>
 $ compile/test
-$ git checkout -b hold/linus && git am -3 -i -s ./+hold-linus <5>
-$ git checkout topic/one && git rebase master <6>
-$ git checkout pu && git reset --hard next <7>
+$ git switch -c hold/linus && git am -3 -i -s ./+hold-linus <5>
+$ git switch topic/one && git rebase master <6>
+$ git switch -C pu next <7>
 $ git merge topic/one topic/two && git merge hold/linus <8>
-$ git checkout maint
+$ git switch maint
 $ git cherry-pick master~4 <9>
 $ compile/test
 $ git tag -s -m "GIT 0.99.9x" v0.99.9x <10>
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/git-fast-export.txt 1.2.3+git2.25.1-1/git/Documentation/git-fast-export.txt
--- 1.2.1+git2.18.0-1/git/Documentation/git-fast-export.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/git-fast-export.txt	2020-02-17 04:47:35.000000000 +0000
@@ -17,9 +17,9 @@ This program dumps the given revisions i
 into 'git fast-import'.
 
 You can use it as a human-readable bundle replacement (see
-linkgit:git-bundle[1]), or as a kind of an interactive
-'git filter-branch'.
-
+linkgit:git-bundle[1]), or as a format that can be edited before being
+fed to 'git fast-import' in order to do history rewrites (an ability
+relied on by tools like 'git filter-repo').
 
 OPTIONS
 -------
@@ -75,11 +75,20 @@ produced incorrect results if you gave t
 	Before processing any input, load the marks specified in
 	<file>.  The input file must exist, must be readable, and
 	must use the same format as produced by --export-marks.
+
+--mark-tags::
+	In addition to labelling blobs and commits with mark ids, also
+	label tags.  This is useful in conjunction with
+	`--export-marks` and `--import-marks`, and is also useful (and
+	necessary) for exporting of nested tags.  It does not hurt
+	other cases and would be the default, but many fast-import
+	frontends are not prepared to accept tags with mark
+	identifiers.
 +
-Any commits that have already been marked will not be exported again.
-If the backend uses a similar --import-marks file, this allows for
-incremental bidirectional exporting of the repository by keeping the
-marks the same across runs.
+Any commits (or tags) that have already been marked will not be
+exported again.  If the backend uses a similar --import-marks file,
+this allows for incremental bidirectional exporting of the repository
+by keeping the marks the same across runs.
 
 --fake-missing-tagger::
 	Some old repositories have tags without a tagger.  The
@@ -110,6 +119,32 @@ marks the same across runs.
 	the shape of the history and stored tree.  See the section on
 	`ANONYMIZING` below.
 
+--reference-excluded-parents::
+	By default, running a command such as `git fast-export
+	master~5..master` will not include the commit master{tilde}5
+	and will make master{tilde}4 no longer have master{tilde}5 as
+	a parent (though both the old master{tilde}4 and new
+	master{tilde}4 will have all the same files).  Use
+	--reference-excluded-parents to instead have the stream
+	refer to commits in the excluded range of history by their
+	sha1sum.  Note that the resulting stream can only be used by a
+	repository which already contains the necessary parent
+	commits.
+
+--show-original-ids::
+	Add an extra directive to the output for commits and blobs,
+	`original-oid <SHA1SUM>`.  While such directives will likely be
+	ignored by importers such as git-fast-import, it may be useful
+	for intermediary filters (e.g. for rewriting commit messages
+	which refer to older commits, or for stripping blobs by id).
+
+--reencode=(yes|no|abort)::
+	Specify how to handle `encoding` header in commit objects.  When
+	asking to 'abort' (which is the default), this program will die
+	when encountering such a commit object.  With 'yes', the commit
+	message will be re-encoded into UTF-8.  With 'no', the original
+	encoding will be preserved.
+
 --refspec::
 	Apply the specified refspec to each ref exported. Multiple of them can
 	be specified.
@@ -119,7 +154,9 @@ marks the same across runs.
 	'git rev-list', that specifies the specific objects and references
 	to export.  For example, `master~10..master` causes the
 	current master reference to be exported along with all objects
-	added since its 10th ancestor commit.
+	added since its 10th ancestor commit and (unless the
+	--reference-excluded-parents option is specified) all files
+	common to master{tilde}9 and master{tilde}10.
 
 EXAMPLES
 --------
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/git-fast-import.txt 1.2.3+git2.25.1-1/git/Documentation/git-fast-import.txt
--- 1.2.1+git2.18.0-1/git/Documentation/git-fast-import.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/git-fast-import.txt	2020-02-17 04:47:35.000000000 +0000
@@ -40,9 +40,10 @@ OPTIONS
 	not contain the old commit).
 
 --quiet::
-	Disable all non-fatal output, making fast-import silent when it
-	is successful.  This option disables the output shown by
-	--stats.
+	Disable the output shown by --stats, making fast-import usually
+	be silent when it is successful.  However, if the import stream
+	has directives intended to show user output (e.g. `progress`
+	directives), the corresponding messages will still be shown.
 
 --stats::
 	Display some basic statistics about the objects fast-import has
@@ -50,6 +51,21 @@ OPTIONS
 	memory used by fast-import during this run.  Showing this output
 	is currently the default, but can be disabled with --quiet.
 
+--allow-unsafe-features::
+	Many command-line options can be provided as part of the
+	fast-import stream itself by using the `feature` or `option`
+	commands. However, some of these options are unsafe (e.g.,
+	allowing fast-import to access the filesystem outside of the
+	repository). These options are disabled by default, but can be
+	allowed by providing this option on the command line.  This
+	currently impacts only the `export-marks`, `import-marks`, and
+	`import-marks-if-exists` feature commands.
++
+	Only enable this option if you trust the program generating the
+	fast-import stream! This option is enabled automatically for
+	remote-helpers that use the `import` capability, as they are
+	already trusted to run their own code.
+
 Options for Frontends
 ~~~~~~~~~~~~~~~~~~~~~
 
@@ -336,6 +352,13 @@ and control the current import process.
 	`commit` command.  This command is optional and is not
 	needed to perform an import.
 
+`alias`::
+	Record that a mark refers to a given object without first
+	creating any new object.  Using --import-marks and referring
+	to missing marks will cause fast-import to fail, so aliases
+	can provide a way to set otherwise pruned commits to a valid
+	value (e.g. the nearest non-pruned ancestor).
+
 `checkpoint`::
 	Forces fast-import to close the current packfile, generate its
 	unique SHA-1 checksum and index, and start a new packfile.
@@ -384,11 +407,13 @@ change to the project.
 ....
 	'commit' SP <ref> LF
 	mark?
+	original-oid?
 	('author' (SP <name>)? SP LT <email> GT SP <when> LF)?
 	'committer' (SP <name>)? SP LT <email> GT SP <when> LF
+	('encoding' SP <encoding>)?
 	data
 	('from' SP <commit-ish> LF)?
-	('merge' SP <commit-ish> LF)?
+	('merge' SP <commit-ish> LF)*
 	(filemodify | filedelete | filecopy | filerename | filedeleteall | notemodify)*
 	LF?
 ....
@@ -420,7 +445,12 @@ However it is recommended that a `filede
 all `filemodify`, `filecopy`, `filerename` and `notemodify` commands in
 the same commit, as `filedeleteall` wipes the branch clean (see below).
 
-The `LF` after the command is optional (it used to be required).
+The `LF` after the command is optional (it used to be required).  Note
+that for reasons of backward compatibility, if the commit ends with a
+`data` command (i.e. it has no `from`, `merge`, `filemodify`,
+`filedelete`, `filecopy`, `filerename`, `filedeleteall` or
+`notemodify` commands) then two `LF` commands may appear at the end of
+the command instead of just one.
 
 `author`
 ^^^^^^^^
@@ -448,6 +478,12 @@ that was selected by the --date-format=<
 See ``Date Formats'' above for the set of supported formats, and
 their syntax.
 
+`encoding`
+^^^^^^^^^^
+The optional `encoding` command indicates the encoding of the commit
+message.  Most commits are UTF-8 and the encoding is omitted, but this
+allows importing commit messages into git without first reencoding them.
+
 `from`
 ^^^^^^
 The `from` command is used to specify the commit to initialize
@@ -740,6 +776,19 @@ New marks are created automatically.  Ex
 to another object simply by reusing the same `<idnum>` in another
 `mark` command.
 
+`original-oid`
+~~~~~~~~~~~~~~
+Provides the name of the object in the original source control system.
+fast-import will simply ignore this directive, but filter processes
+which operate on and modify the stream before feeding to fast-import
+may have uses for this information
+
+....
+	'original-oid' SP <object-identifier> LF
+....
+
+where `<object-identifer>` is any string not containing LF.
+
 `tag`
 ~~~~~
 Creates an annotated tag referring to a specific commit.  To create
@@ -747,7 +796,9 @@ lightweight (non-annotated) tags see the
 
 ....
 	'tag' SP <name> LF
+	mark?
 	'from' SP <commit-ish> LF
+	original-oid?
 	'tagger' (SP <name>)? SP LT <email> GT SP <when> LF
 	data
 ....
@@ -822,6 +873,7 @@ assigned mark.
 ....
 	'blob' LF
 	mark?
+	original-oid?
 	data
 ....
 
@@ -884,6 +936,21 @@ a data chunk which does not have an LF a
 +
 The `LF` after `<delim> LF` is optional (it used to be required).
 
+`alias`
+~~~~~~~
+Record that a mark refers to a given object without first creating any
+new object.
+
+....
+	'alias' LF
+	mark
+	'to' SP <commit-ish> LF
+	LF?
+....
+
+For a detailed description of `<commit-ish>` see above under `from`.
+
+
 `checkpoint`
 ~~~~~~~~~~~~
 Forces fast-import to close the current packfile, start a new one, and to
@@ -949,10 +1016,6 @@ might want to refer to in their commit m
 	'get-mark' SP ':' <idnum> LF
 ....
 
-This command can be used anywhere in the stream that comments are
-accepted.  In particular, the `get-mark` command can be used in the
-middle of a commit but not in the middle of a `data` command.
-
 See ``Responses To Commands'' below for details about how to read
 this output safely.
 
@@ -979,9 +1042,10 @@ Output uses the same format as `git cat-
 	<contents> LF
 ====
 
-This command can be used anywhere in the stream that comments are
-accepted.  In particular, the `cat-blob` command can be used in the
-middle of a commit but not in the middle of a `data` command.
+This command can be used where a `filemodify` directive can appear,
+allowing it to be used in the middle of a commit.  For a `filemodify`
+using an inline directive, it can also appear right before the `data`
+directive.
 
 See ``Responses To Commands'' below for details about how to read
 this output safely.
@@ -994,8 +1058,8 @@ printing a blob from the active commit (
 blob or tree from a previous commit for use in the current one (with
 `filemodify`).
 
-The `ls` command can be used anywhere in the stream that comments are
-accepted, including the middle of a commit.
+The `ls` command can also be used where a `filemodify` directive can
+appear, allowing it to be used in the middle of a commit.
 
 Reading from the active commit::
 	This form can only be used in the middle of a `commit`.
@@ -1379,6 +1443,13 @@ deltas are suboptimal (see above) then a
 to force recomputation of all deltas can significantly reduce the
 final packfile size (30-50% smaller can be quite typical).
 
+Instead of running `git repack` you can also run `git gc
+--aggressive`, which will also optimize other things after an import
+(e.g. pack loose refs). As noted in the "AGGRESSIVE" section in
+linkgit:git-gc[1] the `--aggressive` option will find new deltas with
+the `-f` option to linkgit:git-repack[1]. For the reasons elaborated
+on above using `--aggressive` after a fast-import is one of the few
+cases where it's known to be worthwhile.
 
 MEMORY UTILIZATION
 ------------------
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/git-fetch.txt 1.2.3+git2.25.1-1/git/Documentation/git-fetch.txt
--- 1.2.1+git2.18.0-1/git/Documentation/git-fetch.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/git-fetch.txt	2020-02-17 04:47:35.000000000 +0000
@@ -262,11 +262,11 @@ This updates (or creates, as necessary)
 the local repository by fetching from the branches (respectively)
 `pu` and `maint` from the remote repository.
 +
-The `pu` branch will be updated even if it is does not fast-forward,
+The `pu` branch will be updated even if it does not fast-forward,
 because it is prefixed with a plus sign; `tmp` will not be.
 
 * Peek at a remote's branch, without configuring the remote in your local
-repository:
+  repository:
 +
 ------------------------------------------------
 $ git fetch git://git.kernel.org/pub/scm/git/git.git maint
@@ -285,7 +285,7 @@ BUGS
 ----
 Using --recurse-submodules can only fetch new commits in already checked
 out submodules right now. When e.g. upstream added a new submodule in the
-just fetched commits of the superproject the submodule itself can not be
+just fetched commits of the superproject the submodule itself cannot be
 fetched, making it impossible to check out that submodule later without
 having to do a fetch again. This is expected to be fixed in a future Git
 version.
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/git-filter-branch.txt 1.2.3+git2.25.1-1/git/Documentation/git-filter-branch.txt
--- 1.2.1+git2.18.0-1/git/Documentation/git-filter-branch.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/git-filter-branch.txt	2020-02-17 04:47:35.000000000 +0000
@@ -16,6 +16,19 @@ SYNOPSIS
 	[--original <namespace>] [-d <directory>] [-f | --force]
 	[--state-branch <branch>] [--] [<rev-list options>...]
 
+WARNING
+-------
+'git filter-branch' has a plethora of pitfalls that can produce non-obvious
+manglings of the intended history rewrite (and can leave you with little
+time to investigate such problems since it has such abysmal performance).
+These safety and performance issues cannot be backward compatibly fixed and
+as such, its use is not recommended.  Please use an alternative history
+filtering tool such as https://github.com/newren/git-filter-repo/[git
+filter-repo].  If you still need to use 'git filter-branch', please
+carefully read <<SAFETY>> (and <<PERFORMANCE>>) to learn about the land
+mines of filter-branch, and then vigilantly avoid as many of the hazards
+listed there as reasonably possible.
+
 DESCRIPTION
 -----------
 Lets you rewrite Git revision history by rewriting the branches mentioned
@@ -189,7 +202,7 @@ to other tags will be rewritten to point
 	rewriting.  When applying a tree filter, the command needs to
 	temporarily check out the tree to some directory, which may consume
 	considerable space in case of large projects.  By default it
-	does this in the '.git-rewrite/' directory but you can override
+	does this in the `.git-rewrite/` directory but you can override
 	that choice by this parameter.
 
 -f::
@@ -445,36 +458,245 @@ warned.
   (or if your git-gc is not new enough to support arguments to
   `--prune`, use `git repack -ad; git prune` instead).
 
-NOTES
------
+[[PERFORMANCE]]
+PERFORMANCE
+-----------
+
+The performance of git-filter-branch is glacially slow; its design makes it
+impossible for a backward-compatible implementation to ever be fast:
 
-git-filter-branch allows you to make complex shell-scripted rewrites
-of your Git history, but you probably don't need this flexibility if
-you're simply _removing unwanted data_ like large files or passwords.
-For those operations you may want to consider
-http://rtyley.github.io/bfg-repo-cleaner/[The BFG Repo-Cleaner],
-a JVM-based alternative to git-filter-branch, typically at least
-10-50x faster for those use-cases, and with quite different
-characteristics:
-
-* Any particular version of a file is cleaned exactly _once_. The BFG,
-  unlike git-filter-branch, does not give you the opportunity to
-  handle a file differently based on where or when it was committed
-  within your history. This constraint gives the core performance
-  benefit of The BFG, and is well-suited to the task of cleansing bad
-  data - you don't care _where_ the bad data is, you just want it
-  _gone_.
-
-* By default The BFG takes full advantage of multi-core machines,
-  cleansing commit file-trees in parallel. git-filter-branch cleans
-  commits sequentially (i.e. in a single-threaded manner), though it
-  _is_ possible to write filters that include their own parallelism,
-  in the scripts executed against each commit.
-
-* The http://rtyley.github.io/bfg-repo-cleaner/#examples[command options]
-  are much more restrictive than git-filter branch, and dedicated just
-  to the tasks of removing unwanted data- e.g:
-  `--strip-blobs-bigger-than 1M`.
+* In editing files, git-filter-branch by design checks out each and
+  every commit as it existed in the original repo.  If your repo has
+  `10^5` files and `10^5` commits, but each commit only modifies five
+  files, then git-filter-branch will make you do `10^10` modifications,
+  despite only having (at most) `5*10^5` unique blobs.
+
+* If you try and cheat and try to make git-filter-branch only work on
+  files modified in a commit, then two things happen
+
+  ** you run into problems with deletions whenever the user is simply
+     trying to rename files (because attempting to delete files that
+     don't exist looks like a no-op; it takes some chicanery to remap
+     deletes across file renames when the renames happen via arbitrary
+     user-provided shell)
+
+  ** even if you succeed at the map-deletes-for-renames chicanery, you
+     still technically violate backward compatibility because users
+     are allowed to filter files in ways that depend upon topology of
+     commits instead of filtering solely based on file contents or
+     names (though this has not been observed in the wild).
+
+* Even if you don't need to edit files but only want to e.g. rename or
+  remove some and thus can avoid checking out each file (i.e. you can
+  use --index-filter), you still are passing shell snippets for your
+  filters.  This means that for every commit, you have to have a
+  prepared git repo where those filters can be run.  That's a
+  significant setup.
+
+* Further, several additional files are created or updated per commit
+  by git-filter-branch.  Some of these are for supporting the
+  convenience functions provided by git-filter-branch (such as map()),
+  while others are for keeping track of internal state (but could have
+  also been accessed by user filters; one of git-filter-branch's
+  regression tests does so).  This essentially amounts to using the
+  filesystem as an IPC mechanism between git-filter-branch and the
+  user-provided filters.  Disks tend to be a slow IPC mechanism, and
+  writing these files also effectively represents a forced
+  synchronization point between separate processes that we hit with
+  every commit.
+
+* The user-provided shell commands will likely involve a pipeline of
+  commands, resulting in the creation of many processes per commit.
+  Creating and running another process takes a widely varying amount
+  of time between operating systems, but on any platform it is very
+  slow relative to invoking a function.
+
+* git-filter-branch itself is written in shell, which is kind of slow.
+  This is the one performance issue that could be backward-compatibly
+  fixed, but compared to the above problems that are intrinsic to the
+  design of git-filter-branch, the language of the tool itself is a
+  relatively minor issue.
+
+  ** Side note: Unfortunately, people tend to fixate on the
+     written-in-shell aspect and periodically ask if git-filter-branch
+     could be rewritten in another language to fix the performance
+     issues.  Not only does that ignore the bigger intrinsic problems
+     with the design, it'd help less than you'd expect: if
+     git-filter-branch itself were not shell, then the convenience
+     functions (map(), skip_commit(), etc) and the `--setup` argument
+     could no longer be executed once at the beginning of the program
+     but would instead need to be prepended to every user filter (and
+     thus re-executed with every commit).
+
+The https://github.com/newren/git-filter-repo/[git filter-repo] tool is
+an alternative to git-filter-branch which does not suffer from these
+performance problems or the safety problems (mentioned below). For those
+with existing tooling which relies upon git-filter-branch, 'git
+repo-filter' also provides
+https://github.com/newren/git-filter-repo/blob/master/contrib/filter-repo-demos/filter-lamely[filter-lamely],
+a drop-in git-filter-branch replacement (with a few caveats).  While
+filter-lamely suffers from all the same safety issues as
+git-filter-branch, it at least ameliorates the performance issues a
+little.
+
+[[SAFETY]]
+SAFETY
+------
+
+git-filter-branch is riddled with gotchas resulting in various ways to
+easily corrupt repos or end up with a mess worse than what you started
+with:
+
+* Someone can have a set of "working and tested filters" which they
+  document or provide to a coworker, who then runs them on a different
+  OS where the same commands are not working/tested (some examples in
+  the git-filter-branch manpage are also affected by this).
+  BSD vs. GNU userland differences can really bite.  If lucky, error
+  messages are spewed.  But just as likely, the commands either don't
+  do the filtering requested, or silently corrupt by making some
+  unwanted change.  The unwanted change may only affect a few commits,
+  so it's not necessarily obvious either.  (The fact that problems
+  won't necessarily be obvious means they are likely to go unnoticed
+  until the rewritten history is in use for quite a while, at which
+  point it's really hard to justify another flag-day for another
+  rewrite.)
+
+* Filenames with spaces are often mishandled by shell snippets since
+  they cause problems for shell pipelines.  Not everyone is familiar
+  with find -print0, xargs -0, git-ls-files -z, etc.  Even people who
+  are familiar with these may assume such flags are not relevant
+  because someone else renamed any such files in their repo back
+  before the person doing the filtering joined the project.  And
+  often, even those familiar with handling arguments with spaces may
+  not do so just because they aren't in the mindset of thinking about
+  everything that could possibly go wrong.
+
+* Non-ascii filenames can be silently removed despite being in a
+  desired directory.  Keeping only wanted paths is often done using
+  pipelines like `git ls-files | grep -v ^WANTED_DIR/ | xargs git rm`.
+  ls-files will only quote filenames if needed, so folks may not
+  notice that one of the files didn't match the regex (at least not
+  until it's much too late).  Yes, someone who knows about
+  core.quotePath can avoid this (unless they have other special
+  characters like \t, \n, or "), and people who use ls-files -z with
+  something other than grep can avoid this, but that doesn't mean they
+  will.
+
+* Similarly, when moving files around, one can find that filenames
+  with non-ascii or special characters end up in a different
+  directory, one that includes a double quote character.  (This is
+  technically the same issue as above with quoting, but perhaps an
+  interesting different way that it can and has manifested as a
+  problem.)
+
+* It's far too easy to accidentally mix up old and new history.  It's
+  still possible with any tool, but git-filter-branch almost
+  invites it.  If lucky, the only downside is users getting frustrated
+  that they don't know how to shrink their repo and remove the old
+  stuff.  If unlucky, they merge old and new history and end up with
+  multiple "copies" of each commit, some of which have unwanted or
+  sensitive files and others which don't.  This comes about in
+  multiple different ways:
+
+  ** the default to only doing a partial history rewrite ('--all' is not
+     the default and few examples show it)
+
+  ** the fact that there's no automatic post-run cleanup
+
+  ** the fact that --tag-name-filter (when used to rename tags) doesn't
+     remove the old tags but just adds new ones with the new name
+
+  ** the fact that little educational information is provided to inform
+     users of the ramifications of a rewrite and how to avoid mixing old
+     and new history.  For example, this man page discusses how users
+     need to understand that they need to rebase their changes for all
+     their branches on top of new history (or delete and reclone), but
+     that's only one of multiple concerns to consider.  See the
+     "DISCUSSION" section of the git filter-repo manual page for more
+     details.
+
+* Annotated tags can be accidentally converted to lightweight tags,
+  due to either of two issues:
+
+  ** Someone can do a history rewrite, realize they messed up, restore
+     from the backups in refs/original/, and then redo their
+     git-filter-branch command.  (The backup in refs/original/ is not a
+     real backup; it dereferences tags first.)
+
+  ** Running git-filter-branch with either --tags or --all in your
+     <rev-list options>.  In order to retain annotated tags as
+     annotated, you must use --tag-name-filter (and must not have
+     restored from refs/original/ in a previously botched rewrite).
+
+* Any commit messages that specify an encoding will become corrupted
+  by the rewrite; git-filter-branch ignores the encoding, takes the
+  original bytes, and feeds it to commit-tree without telling it the
+  proper encoding.  (This happens whether or not --msg-filter is
+  used.)
+
+* Commit messages (even if they are all UTF-8) by default become
+  corrupted due to not being updated -- any references to other commit
+  hashes in commit messages will now refer to no-longer-extant
+  commits.
+
+* There are no facilities for helping users find what unwanted crud
+  they should delete, which means they are much more likely to have
+  incomplete or partial cleanups that sometimes result in confusion
+  and people wasting time trying to understand.  (For example, folks
+  tend to just look for big files to delete instead of big directories
+  or extensions, and once they do so, then sometime later folks using
+  the new repository who are going through history will notice a build
+  artifact directory that has some files but not others, or a cache of
+  dependencies (node_modules or similar) which couldn't have ever been
+  functional since it's missing some files.)
+
+* If --prune-empty isn't specified, then the filtering process can
+  create hoards of confusing empty commits
+
+* If --prune-empty is specified, then intentionally placed empty
+  commits from before the filtering operation are also pruned instead
+  of just pruning commits that became empty due to filtering rules.
+
+* If --prune-empty is specified, sometimes empty commits are missed
+  and left around anyway (a somewhat rare bug, but it happens...)
+
+* A minor issue, but users who have a goal to update all names and
+  emails in a repository may be led to --env-filter which will only
+  update authors and committers, missing taggers.
+
+* If the user provides a --tag-name-filter that maps multiple tags to
+  the same name, no warning or error is provided; git-filter-branch
+  simply overwrites each tag in some undocumented pre-defined order
+  resulting in only one tag at the end.  (A git-filter-branch
+  regression test requires this surprising behavior.)
+
+Also, the poor performance of git-filter-branch often leads to safety
+issues:
+
+* Coming up with the correct shell snippet to do the filtering you
+  want is sometimes difficult unless you're just doing a trivial
+  modification such as deleting a couple files.  Unfortunately, people
+  often learn if the snippet is right or wrong by trying it out, but
+  the rightness or wrongness can vary depending on special
+  circumstances (spaces in filenames, non-ascii filenames, funny
+  author names or emails, invalid timezones, presence of grafts or
+  replace objects, etc.), meaning they may have to wait a long time,
+  hit an error, then restart.  The performance of git-filter-branch is
+  so bad that this cycle is painful, reducing the time available to
+  carefully re-check (to say nothing about what it does to the
+  patience of the person doing the rewrite even if they do technically
+  have more time available).  This problem is extra compounded because
+  errors from broken filters may not be shown for a long time and/or
+  get lost in a sea of output.  Even worse, broken filters often just
+  result in silent incorrect rewrites.
+
+* To top it all off, even when users finally find working commands,
+  they naturally want to share them.  But they may be unaware that
+  their repo didn't have some special cases that someone else's does.
+  So, when someone else with a different repository runs the same
+  commands, they get hit by the problems above.  Or, the user just
+  runs commands that really were vetted for special cases, but they
+  run it on a different OS where it doesn't work, as noted above.
 
 GIT
 ---
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/git-fmt-merge-msg.txt 1.2.3+git2.25.1-1/git/Documentation/git-fmt-merge-msg.txt
--- 1.2.1+git2.18.0-1/git/Documentation/git-fmt-merge-msg.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/git-fmt-merge-msg.txt	2020-02-17 04:47:35.000000000 +0000
@@ -51,7 +51,7 @@ OPTIONS
 
 CONFIGURATION
 -------------
-include::fmt-merge-msg-config.txt[]
+include::config/fmt-merge-msg.txt[]
 
 merge.summary::
 	Synonym to `merge.log`; this is deprecated and will be removed in
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/git-for-each-ref.txt 1.2.3+git2.25.1-1/git/Documentation/git-for-each-ref.txt
--- 1.2.1+git2.18.0-1/git/Documentation/git-for-each-ref.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/git-for-each-ref.txt	2020-02-17 04:47:35.000000000 +0000
@@ -57,7 +57,7 @@ OPTIONS
 	`xx`; for example `%00` interpolates to `\0` (NUL),
 	`%09` to `\t` (TAB) and `%0a` to `\n` (LF).
 
---color[=<when>]:
+--color[=<when>]::
 	Respect any colors specified in the `--format` option. The
 	`<when>` field must be one of `always`, `never`, or `auto` (if
 	`<when>` is absent, behave as if `always` was given).
@@ -128,13 +128,18 @@ objecttype::
 
 objectsize::
 	The size of the object (the same as 'git cat-file -s' reports).
-
+	Append `:disk` to get the size, in bytes, that the object takes up on
+	disk. See the note about on-disk sizes in the `CAVEATS` section below.
 objectname::
 	The object name (aka SHA-1).
 	For a non-ambiguous abbreviation of the object name append `:short`.
 	For an abbreviation of the object name with desired length append
 	`:short=<length>`, where the minimum length is MINIMUM_ABBREV. The
 	length may be exceeded to ensure unique object names.
+deltabase::
+	This expands to the object name of the delta base for the
+	given object, if it is stored as a delta.  Otherwise it
+	expands to the null object name (all zeroes).
 
 upstream::
 	The name of a local ref which can be considered ``upstream''
@@ -209,6 +214,11 @@ symref::
 	`:lstrip` and `:rstrip` options in the same way as `refname`
 	above.
 
+worktreepath::
+	The absolute path to the worktree in which the ref is checked
+	out, if it is checked out in any linked worktree. Empty string
+	otherwise.
+
 In addition to the above, for commit and tag objects, the header
 field names (`tree`, `parent`, `object`, `type`, and `tag`) can
 be used to specify the value in the header field.
@@ -361,6 +371,20 @@ This prints the authorname, if present.
 git for-each-ref --format="%(refname)%(if)%(authorname)%(then) Authored by: %(authorname)%(end)"
 ------------
 
+CAVEATS
+-------
+
+Note that the sizes of objects on disk are reported accurately, but care
+should be taken in drawing conclusions about which refs or objects are
+responsible for disk usage. The size of a packed non-delta object may be
+much larger than the size of objects which delta against it, but the
+choice of which object is the base and which is the delta is arbitrary
+and is subject to change during a repack.
+
+Note also that multiple copies of an object may be present in the object
+database; in this case, it is undefined which copy's size or delta base
+will be reported.
+
 SEE ALSO
 --------
 linkgit:git-show-ref[1]
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/git-format-patch.txt 1.2.3+git2.25.1-1/git/Documentation/git-format-patch.txt
--- 1.2.1+git2.18.0-1/git/Documentation/git-format-patch.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/git-format-patch.txt	2020-02-17 04:47:35.000000000 +0000
@@ -17,12 +17,16 @@ SYNOPSIS
 		   [--signature-file=<file>]
 		   [-n | --numbered | -N | --no-numbered]
 		   [--start-number <n>] [--numbered-files]
-		   [--in-reply-to=Message-Id] [--suffix=.<sfx>]
+		   [--in-reply-to=<message id>] [--suffix=.<sfx>]
 		   [--ignore-if-in-upstream]
-		   [--rfc] [--subject-prefix=Subject-Prefix]
+		   [--cover-from-description=<mode>]
+		   [--rfc] [--subject-prefix=<subject prefix>]
 		   [(--reroll-count|-v) <n>]
 		   [--to=<email>] [--cc=<email>]
-		   [--[no-]cover-letter] [--quiet] [--notes[=<ref>]]
+		   [--[no-]cover-letter] [--quiet]
+		   [--no-notes | --notes[=<ref>]]
+		   [--interdiff=<previous>]
+		   [--range-diff=<previous> [--creation-factor=<percent>]]
 		   [--progress]
 		   [<common diff options>]
 		   [ <since> | <revision range> ]
@@ -63,7 +67,8 @@ they are created in the current working
 can be set with the `format.outputDirectory` configuration option.
 The `-o` option takes precedence over `format.outputDirectory`.
 To store patches in the current working directory even when
-`format.outputDirectory` points elsewhere, use `-o .`.
+`format.outputDirectory` points elsewhere, use `-o .`. All directory
+components will be created.
 
 By default, the subject of a single patch is "[PATCH] " followed by
 the concatenation of lines from the commit message up to the first blank
@@ -156,9 +161,9 @@ Beware that the default for 'git send-em
 itself.  If you want `git format-patch` to take care of threading, you
 will want to ensure that threading is disabled for `git send-email`.
 
---in-reply-to=Message-Id::
+--in-reply-to=<message id>::
 	Make the first mail (or all the mails with `--no-thread`) appear as a
-	reply to the given Message-Id, which avoids breaking threads to
+	reply to the given <message id>, which avoids breaking threads to
 	provide a new patch series.
 
 --ignore-if-in-upstream::
@@ -168,9 +173,29 @@ will want to ensure that threading is di
 	patches being generated, and any patch that matches is
 	ignored.
 
---subject-prefix=<Subject-Prefix>::
+--cover-from-description=<mode>::
+	Controls which parts of the cover letter will be automatically
+	populated using the branch's description.
++
+If `<mode>` is `message` or `default`, the cover letter subject will be
+populated with placeholder text. The body of the cover letter will be
+populated with the branch's description. This is the default mode when
+no configuration nor command line option is specified.
++
+If `<mode>` is `subject`, the first paragraph of the branch description will
+populate the cover letter subject. The remainder of the description will
+populate the body of the cover letter.
++
+If `<mode>` is `auto`, if the first paragraph of the branch description
+is greater than 100 bytes, then the mode will be `message`, otherwise
+`subject` will be used.
++
+If `<mode>` is `none`, both the cover letter subject and body will be
+populated with placeholder text.
+
+--subject-prefix=<subject prefix>::
 	Instead of the standard '[PATCH]' prefix in the subject
-	line, instead use '[<Subject-Prefix>]'. This
+	line, instead use '[<subject prefix>]'. This
 	allows for useful naming of a patch series, and can be
 	combined with the `--numbered` option.
 
@@ -228,7 +253,40 @@ feeding the result to `git send-email`.
 	containing the branch description, shortlog and the overall diffstat.  You can
 	fill in a description in the file before sending it out.
 
+--interdiff=<previous>::
+	As a reviewer aid, insert an interdiff into the cover letter,
+	or as commentary of the lone patch of a 1-patch series, showing
+	the differences between the previous version of the patch series and
+	the series currently being formatted. `previous` is a single revision
+	naming the tip of the previous series which shares a common base with
+	the series being formatted (for example `git format-patch
+	--cover-letter --interdiff=feature/v1 -3 feature/v2`).
+
+--range-diff=<previous>::
+	As a reviewer aid, insert a range-diff (see linkgit:git-range-diff[1])
+	into the cover letter, or as commentary of the lone patch of a
+	1-patch series, showing the differences between the previous
+	version of the patch series and the series currently being formatted.
+	`previous` can be a single revision naming the tip of the previous
+	series if it shares a common base with the series being formatted (for
+	example `git format-patch --cover-letter --range-diff=feature/v1 -3
+	feature/v2`), or a revision range if the two versions of the series are
+	disjoint (for example `git format-patch --cover-letter
+	--range-diff=feature/v1~3..feature/v1 -3 feature/v2`).
++
+Note that diff options passed to the command affect how the primary
+product of `format-patch` is generated, and they are not passed to
+the underlying `range-diff` machinery used to generate the cover-letter
+material (this may change in the future).
+
+--creation-factor=<percent>::
+	Used with `--range-diff`, tweak the heuristic which matches up commits
+	between the previous and current series of patches by adjusting the
+	creation/deletion cost fudge factor. See linkgit:git-range-diff[1])
+	for details.
+
 --notes[=<ref>]::
+--no-notes::
 	Append the notes (see linkgit:git-notes[1]) for the commit
 	after the three-dash line.
 +
@@ -239,6 +297,9 @@ these explanations after `format-patch`
 keeping them as Git notes allows them to be maintained between versions
 of the patch series (but see the discussion of the `notes.rewrite`
 configuration options in linkgit:git-notes[1] to use this workflow).
++
+The default is `--no-notes`, unless the `format.notes` configuration is
+set.
 
 --[no-]signature=<signature>::
 	Add a signature to each message produced. Per RFC 3676 the signature
@@ -272,10 +333,12 @@ you can use `--suffix=-patch` to get `00
   Output an all-zero hash in each patch's From header instead
   of the hash of the commit.
 
---base=<commit>::
+--[no-]base[=<commit>]::
 	Record the base tree information to identify the state the
 	patch series applies to.  See the BASE TREE INFORMATION section
-	below for details.
+	below for details. If <commit> is "auto", a base commit is
+	automatically chosen. The `--no-base` option overrides a
+	`format.useAutoBase` configuration.
 
 --root::
 	Treat the revision argument as a <revision range>, even if it
@@ -291,8 +354,9 @@ CONFIGURATION
 -------------
 You can specify extra mail header lines to be added to each message,
 defaults for the subject prefix and file suffix, number patches when
-outputting more than one patch, add "To" or "Cc:" headers, configure
-attachments, and sign off patches with configuration variables.
+outputting more than one patch, add "To:" or "Cc:" headers, configure
+attachments, change the patch output directory, and sign off patches
+with configuration variables.
 
 ------------
 [format]
@@ -304,7 +368,9 @@ attachments, and sign off patches with c
 	cc = <email>
 	attach [ = mime-boundary-string ]
 	signOff = true
-	coverletter = auto
+	outputDirectory = <directory>
+	coverLetter = auto
+	coverFromDescription = auto
 ------------
 
 
@@ -387,8 +453,8 @@ One way to test if your MUA is set up co
 * Apply it:
 
     $ git fetch <project> master:test-apply
-    $ git checkout test-apply
-    $ git reset --hard
+    $ git switch test-apply
+    $ git restore --source=HEAD --staged --worktree :/
     $ git am a.patch
 
 If it does not apply correctly, there can be various reasons.
@@ -470,9 +536,9 @@ Toggle it to make sure it is set to `fal
 "mailnews.wraplength" and set the value to 0.
 
 3. Disable the use of format=flowed:
-Edit..Preferences..Advanced..Config Editor.  Search for
-"mailnews.send_plaintext_flowed".
-Toggle it to make sure it is set to `false`.
+   Edit..Preferences..Advanced..Config Editor.  Search for
+   "mailnews.send_plaintext_flowed".
+   Toggle it to make sure it is set to `false`.
 
 After that is done, you should be able to compose email as you
 otherwise would (cut + paste, 'git format-patch' | 'git imap-send', etc),
@@ -595,14 +661,14 @@ EXAMPLES
 --------
 
 * Extract commits between revisions R1 and R2, and apply them on top of
-the current branch using 'git am' to cherry-pick them:
+  the current branch using 'git am' to cherry-pick them:
 +
 ------------
 $ git format-patch -k --stdout R1..R2 | git am -3 -k
 ------------
 
 * Extract all commits which are in the current branch but not in the
-origin branch:
+  origin branch:
 +
 ------------
 $ git format-patch origin
@@ -611,7 +677,7 @@ $ git format-patch origin
 For each commit a separate file is created in the current directory.
 
 * Extract all commits that lead to 'origin' since the inception of the
-project:
+  project:
 +
 ------------
 $ git format-patch --root origin
@@ -630,7 +696,7 @@ Note that non-Git "patch" programs won't
 use it only when you know the recipient uses Git to apply your patch.
 
 * Extract three topmost commits from the current branch and format them
-as e-mailable patches:
+  as e-mailable patches:
 +
 ------------
 $ git format-patch -3
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/git-fsck.txt 1.2.3+git2.25.1-1/git/Documentation/git-fsck.txt
--- 1.2.1+git2.18.0-1/git/Documentation/git-fsck.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/git-fsck.txt	2020-02-17 04:47:35.000000000 +0000
@@ -62,9 +62,17 @@ index file, all SHA-1 references in `ref
 	with --no-full.
 
 --connectivity-only::
-	Check only the connectivity of tags, commits and tree objects. By
-	avoiding to unpack blobs, this speeds up the operation, at the
-	expense of missing corrupt objects or other problematic issues.
+	Check only the connectivity of reachable objects, making sure
+	that any objects referenced by a reachable tag, commit, or tree
+	is present. This speeds up the operation by avoiding reading
+	blobs entirely (though it does still check that referenced blobs
+	exist). This will detect corruption in commits and trees, but
+	not do any semantic checks (e.g., for format errors). Corruption
+	in blob objects will not be detected at all.
++
+Unreachable tags, commits, and trees will also be accessed to find the
+tips of dangling segments of history. Use `--no-dangling` if you don't
+care about this output and want to speed it up further.
 
 --strict::
 	Enable more strict checking, namely to catch a file mode
@@ -96,6 +104,11 @@ index file, all SHA-1 references in `ref
 	progress status even if the standard error stream is not
 	directed to a terminal.
 
+CONFIGURATION
+-------------
+
+include::config/fsck.txt[]
+
 DISCUSSION
 ----------
 
@@ -110,6 +123,9 @@ Any corrupt objects you will have to fin
 (i.e., you can just remove them and do an 'rsync' with some other site in
 the hopes that somebody else has the object you have corrupted).
 
+If core.commitGraph is true, the commit-graph file will also be inspected
+using 'git commit-graph verify'. See linkgit:git-commit-graph[1].
+
 Extracted Diagnostics
 ---------------------
 
@@ -137,9 +153,9 @@ dangling <type> <object>::
 	The <type> object <object>, is present in the database but never
 	'directly' used. A dangling commit could be a root node.
 
-sha1 mismatch <object>::
-	The database has an object who's sha1 doesn't match the
-	database value.
+hash mismatch <object>::
+	The database has an object whose hash doesn't match the
+	object database value.
 	This indicates a serious data integrity problem.
 
 Environment Variables
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/git-gc.txt 1.2.3+git2.25.1-1/git/Documentation/git-gc.txt
--- 1.2.1+git2.18.0-1/git/Documentation/git-gc.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/git-gc.txt	2020-02-17 04:47:35.000000000 +0000
@@ -17,19 +17,19 @@ Runs a number of housekeeping tasks with
 such as compressing file revisions (to reduce disk space and increase
 performance), removing unreachable objects which may have been
 created from prior invocations of 'git add', packing refs, pruning
-reflog, rerere metadata or stale working trees.
+reflog, rerere metadata or stale working trees. May also update ancillary
+indexes such as the commit-graph.
 
-Users are encouraged to run this task on a regular basis within
-each repository to maintain good disk space utilization and good
-operating performance.
-
-Some git commands may automatically run 'git gc'; see the `--auto` flag
-below for details. If you know what you're doing and all you want is to
-disable this behavior permanently without further considerations, just do:
-
-----------------------
-$ git config --global gc.auto 0
-----------------------
+When common porcelain operations that create objects are run, they
+will check whether the repository has grown substantially since the
+last maintenance, and if so run `git gc` automatically. See `gc.auto`
+below for how to disable this behavior.
+
+Running `git gc` manually should only be needed when adding objects to
+a repository without regularly running such porcelain commands, to do
+a one-off repository optimization, or e.g. to clean up a suboptimal
+mass-import. See the "PACKFILE OPTIMIZATION" section in
+linkgit:git-fast-import[1] for more details on the import case.
 
 OPTIONS
 -------
@@ -39,35 +39,17 @@ OPTIONS
 	space utilization and performance.  This option will cause
 	'git gc' to more aggressively optimize the repository at the expense
 	of taking much more time.  The effects of this optimization are
-	persistent, so this option only needs to be used occasionally; every
-	few hundred changesets or so.
+	mostly persistent. See the "AGGRESSIVE" section below for details.
 
 --auto::
 	With this option, 'git gc' checks whether any housekeeping is
 	required; if not, it exits without performing any work.
-	Some git commands run `git gc --auto` after performing
-	operations that could create many loose objects. Housekeeping
-	is required if there are too many loose objects or too many
-	packs in the repository.
 +
-If the number of loose objects exceeds the value of the `gc.auto`
-configuration variable, then all loose objects are combined into a
-single pack using `git repack -d -l`.  Setting the value of `gc.auto`
-to 0 disables automatic packing of loose objects.
+See the `gc.auto` option in the "CONFIGURATION" section below for how
+this heuristic works.
 +
-If the number of packs exceeds the value of `gc.autoPackLimit`,
-then existing packs (except those marked with a `.keep` file
-or over `gc.bigPackThreshold` limit)
-are consolidated into a single pack by using the `-A` option of
-'git repack'.
-If the amount of memory is estimated not enough for `git repack` to
-run smoothly and `gc.bigPackThreshold` is not set, the largest
-pack will also be excluded (this is the equivalent of running `git gc`
-with `--keep-base-pack`).
-Setting `gc.autoPackLimit` to 0 disables automatic consolidation of
-packs.
-+
-If houskeeping is required due to many loose objects or packs, all
+Once housekeeping is triggered by exceeding the limits of
+configuration options such as `gc.auto` and `gc.autoPackLimit`, all
 other housekeeping tasks (e.g. rerere, working trees, reflog...) will
 be performed as well.
 
@@ -75,7 +57,7 @@ be performed as well.
 --prune=<date>::
 	Prune loose objects older than date (default is 2 weeks ago,
 	overridable by the config variable `gc.pruneExpire`).
-	--prune=all prunes loose objects regardless of their age and
+	--prune=now prunes loose objects regardless of their age and
 	increases the risk of corruption if another process is writing to
 	the repository concurrently; see "NOTES" below. --prune is on by
 	default.
@@ -95,79 +77,52 @@ be performed as well.
 	`.keep` files are consolidated into a single pack. When this
 	option is used, `gc.bigPackThreshold` is ignored.
 
+AGGRESSIVE
+----------
+
+When the `--aggressive` option is supplied, linkgit:git-repack[1] will
+be invoked with the `-f` flag, which in turn will pass
+`--no-reuse-delta` to linkgit:git-pack-objects[1]. This will throw
+away any existing deltas and re-compute them, at the expense of
+spending much more time on the repacking.
+
+The effects of this are mostly persistent, e.g. when packs and loose
+objects are coalesced into one another pack the existing deltas in
+that pack might get re-used, but there are also various cases where we
+might pick a sub-optimal delta from a newer pack instead.
+
+Furthermore, supplying `--aggressive` will tweak the `--depth` and
+`--window` options passed to linkgit:git-repack[1]. See the
+`gc.aggressiveDepth` and `gc.aggressiveWindow` settings below. By
+using a larger window size we're more likely to find more optimal
+deltas.
+
+It's probably not worth it to use this option on a given repository
+without running tailored performance benchmarks on it. It takes a lot
+more time, and the resulting space/delta optimization may or may not
+be worth it. Not using this at all is the right trade-off for most
+users and their repositories.
+
 CONFIGURATION
 -------------
 
-The optional configuration variable `gc.reflogExpire` can be
-set to indicate how long historical entries within each branch's
-reflog should remain available in this repository.  The setting is
-expressed as a length of time, for example '90 days' or '3 months'.
-It defaults to '90 days'.
-
-The optional configuration variable `gc.reflogExpireUnreachable`
-can be set to indicate how long historical reflog entries which
-are not part of the current branch should remain available in
-this repository.  These types of entries are generally created as
-a result of using `git commit --amend` or `git rebase` and are the
-commits prior to the amend or rebase occurring.  Since these changes
-are not part of the current project most users will want to expire
-them sooner.  This option defaults to '30 days'.
-
-The above two configuration variables can be given to a pattern.  For
-example, this sets non-default expiry values only to remote-tracking
-branches:
-
-------------
-[gc "refs/remotes/*"]
-	reflogExpire = never
-	reflogExpireUnreachable = 3 days
-------------
-
-The optional configuration variable `gc.rerereResolved` indicates
-how long records of conflicted merge you resolved earlier are
-kept.  This defaults to 60 days.
-
-The optional configuration variable `gc.rerereUnresolved` indicates
-how long records of conflicted merge you have not resolved are
-kept.  This defaults to 15 days.
-
-The optional configuration variable `gc.packRefs` determines if
-'git gc' runs 'git pack-refs'. This can be set to "notbare" to enable
-it within all non-bare repos or it can be set to a boolean value.
-This defaults to true.
-
-The optional configuration variable `gc.aggressiveWindow` controls how
-much time is spent optimizing the delta compression of the objects in
-the repository when the --aggressive option is specified.  The larger
-the value, the more time is spent optimizing the delta compression.  See
-the documentation for the --window option in linkgit:git-repack[1] for
-more details.  This defaults to 250.
-
-Similarly, the optional configuration variable `gc.aggressiveDepth`
-controls --depth option in linkgit:git-repack[1]. This defaults to 50.
-
-The optional configuration variable `gc.pruneExpire` controls how old
-the unreferenced loose objects have to be before they are pruned.  The
-default is "2 weeks ago".
-
-Optional configuration variable `gc.worktreePruneExpire` controls how
-old a stale working tree should be before `git worktree prune` deletes
-it. Default is "3 months ago".
+The below documentation is the same as what's found in
+linkgit:git-config[1]:
 
+include::config/gc.txt[]
 
 NOTES
 -----
 
 'git gc' tries very hard not to delete objects that are referenced
-anywhere in your repository. In
-particular, it will keep not only objects referenced by your current set
-of branches and tags, but also objects referenced by the index,
-remote-tracking branches, refs saved by 'git filter-branch' in
-refs/original/, or reflogs (which may reference commits in branches
-that were later amended or rewound).
-If you are expecting some objects to be deleted and they aren't, check
-all of those locations and decide whether it makes sense in your case to
-remove those references.
+anywhere in your repository. In particular, it will keep not only
+objects referenced by your current set of branches and tags, but also
+objects referenced by the index, remote-tracking branches, notes saved
+by 'git notes' under refs/notes/, reflogs (which may reference commits
+in branches that were later amended or rewound), and anything else in
+the refs/* namespace.  If you are expecting some objects to be deleted
+and they aren't, check all of those locations and decide whether it
+makes sense in your case to remove those references.
 
 On the other hand, when 'git gc' runs concurrently with another process,
 there is a risk of it deleting an object that the other process is using
@@ -185,8 +140,7 @@ mitigate this problem:
 
 However, these features fall short of a complete solution, so users who
 run commands concurrently have to live with some risk of corruption (which
-seems to be low in practice) unless they turn off automatic garbage
-collection with 'git config gc.auto 0'.
+seems to be low in practice).
 
 HOOKS
 -----
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/git-grep.txt 1.2.3+git2.25.1-1/git/Documentation/git-grep.txt
--- 1.2.1+git2.18.0-1/git/Documentation/git-grep.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/git-grep.txt	2020-02-17 04:47:35.000000000 +0000
@@ -13,12 +13,12 @@ SYNOPSIS
 	   [-v | --invert-match] [-h|-H] [--full-name]
 	   [-E | --extended-regexp] [-G | --basic-regexp]
 	   [-P | --perl-regexp]
-	   [-F | --fixed-strings] [-n | --line-number]
+	   [-F | --fixed-strings] [-n | --line-number] [--column]
 	   [-l | --files-with-matches] [-L | --files-without-match]
 	   [(-O | --open-files-in-pager) [<pager>]]
 	   [-z | --null]
-	   [-c | --count] [--all-match] [-q | --quiet]
-	   [--max-depth <depth>]
+	   [ -o | --only-matching ] [-c | --count] [--all-match] [-q | --quiet]
+	   [--max-depth <depth>] [--[no-]recursive]
 	   [--color[=<when>] | --no-color]
 	   [--break] [--heading] [-p | --show-function]
 	   [-A <post-context>] [-B <pre-context>] [-C <context>]
@@ -44,6 +44,9 @@ CONFIGURATION
 grep.lineNumber::
 	If set to true, enable `-n` option by default.
 
+grep.column::
+	If set to true, enable the `--column` option by default.
+
 grep.patternType::
 	Set the default matching behavior. Using a value of 'basic', 'extended',
 	'fixed', or 'perl' will enable the `--basic-regexp`, `--extended-regexp`,
@@ -85,7 +88,7 @@ OPTIONS
 	mechanism. Only useful with `--untracked`.
 
 --exclude-standard::
-	Do not pay attention to ignored files specified via the	`.gitignore`
+	Do not pay attention to ignored files specified via the `.gitignore`
 	mechanism.  Only useful when searching files in the current directory
 	with `--no-index`.
 
@@ -93,7 +96,8 @@ OPTIONS
 	Recursively search in each submodule that has been initialized and
 	checked out in the repository.  When used in combination with the
 	<tree> option the prefix of all submodule output will be the name of
-	the parent project's <tree> object.
+	the parent project's <tree> object. This option has no effect
+	if `--no-index` is given.
 
 -a::
 --text::
@@ -116,11 +120,18 @@ OPTIONS
 
 --max-depth <depth>::
 	For each <pathspec> given on command line, descend at most <depth>
-	levels of directories. A negative value means no limit.
+	levels of directories. A value of -1 means no limit.
 	This option is ignored if <pathspec> contains active wildcards.
 	In other words if "a*" matches a directory named "a*",
 	"*" is matched literally so --max-depth is still effective.
 
+-r::
+--recursive::
+	Same as `--max-depth=-1`; this is the default.
+
+--no-recursive::
+	Same as `--max-depth=0`.
+
 -w::
 --word-regexp::
 	Match the pattern only at word boundary (either begin at the
@@ -169,6 +180,10 @@ providing this option will cause it to d
 --line-number::
 	Prefix the line number to matching lines.
 
+--column::
+	Prefix the 1-indexed byte-offset of the first match from the start of the
+	matching line.
+
 -l::
 --files-with-matches::
 --name-only::
@@ -194,6 +209,11 @@ providing this option will cause it to d
 	Output \0 instead of the character that normally follows a
 	file name.
 
+-o::
+--only-matching::
+	Print only the matched (non-empty) parts of a matching line, with each such
+	part on a separate output line.
+
 -c::
 --count::
 	Instead of showing every matched line, show the number of
@@ -252,6 +272,23 @@ providing this option will cause it to d
 
 -f <file>::
 	Read patterns from <file>, one per line.
++
+Passing the pattern via <file> allows for providing a search pattern
+containing a \0.
++
+Not all pattern types support patterns containing \0. Git will error
+out if a given pattern type can't support such a pattern. The
+`--perl-regexp` pattern type when compiled against the PCRE v2 backend
+has the widest support for these types of patterns.
++
+In versions of Git before 2.23.0 patterns containing \0 would be
+silently considered fixed. This was never documented, there were also
+odd and undocumented interactions between e.g. non-ASCII patterns
+containing \0 and `--ignore-case`.
++
+In future versions we may learn to support patterns containing \0 for
+more search backends, until then we'll die when the pattern type in
+question doesn't support them.
 
 -e::
 	The next parameter is the pattern. This option has to be
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/git-gui.txt 1.2.3+git2.25.1-1/git/Documentation/git-gui.txt
--- 1.2.1+git2.18.0-1/git/Documentation/git-gui.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/git-gui.txt	2020-02-17 04:47:35.000000000 +0000
@@ -112,15 +112,9 @@ Other
 versions are distributed as part of the Git suite for the convenience
 of end users.
 
-A 'git gui' development repository can be obtained from:
+The official repository of the 'git gui' project can be found at:
 
-  git clone git://repo.or.cz/git-gui.git
-
-or
-
-  git clone http://repo.or.cz/r/git-gui.git
-
-or browsed online at http://repo.or.cz/w/git-gui.git/[].
+  https://github.com/prati0100/git-gui.git/
 
 GIT
 ---
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/git-hash-object.txt 1.2.3+git2.25.1-1/git/Documentation/git-hash-object.txt
--- 1.2.1+git2.18.0-1/git/Documentation/git-hash-object.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/git-hash-object.txt	2020-02-17 04:47:35.000000000 +0000
@@ -18,9 +18,7 @@ Computes the object ID value for an obje
 with the contents of the named file (which can be outside of the
 work tree), and optionally writes the resulting object into the
 object database.  Reports its object ID to its standard output.
-This is used by 'git cvsimport' to update the index
-without modifying files in the work tree.  When <type> is not
-specified, it defaults to "blob".
+When <type> is not specified, it defaults to "blob".
 
 OPTIONS
 -------
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/git-help.txt 1.2.3+git2.25.1-1/git/Documentation/git-help.txt
--- 1.2.1+git2.18.0-1/git/Documentation/git-help.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/git-help.txt	2020-02-17 04:47:35.000000000 +0000
@@ -8,7 +8,7 @@ git-help - Display help information abou
 SYNOPSIS
 --------
 [verse]
-'git help' [-a|--all [--verbose]] [-g|--guide]
+'git help' [-a|--all [--[no-]verbose]] [-g|--guide]
 	   [-i|--info|-m|--man|-w|--web] [COMMAND|GUIDE]
 
 DESCRIPTION
@@ -29,6 +29,10 @@ guide is brought up. The 'man' program i
 purpose, but this can be overridden by other options or configuration
 variables.
 
+If an alias is given, git shows the definition of the alias on
+standard output. To get the manual page for the aliased command, use
+`git COMMAND --help`.
+
 Note that `git --help ...` is identical to `git help ...` because the
 former is internally converted into the latter.
 
@@ -42,8 +46,15 @@ OPTIONS
 --all::
 	Prints all the available commands on the standard output. This
 	option overrides any given command or guide name.
-	When used with `--verbose` print description for all recognized
-	commands.
+
+--verbose::
+	When used with `--all` print description for all recognized
+	commands. This is the default.
+
+-c::
+--config::
+	List all available configuration variables. This is a short
+	summary of the list in linkgit:git-config[1].
 
 -g::
 --guides::
@@ -107,9 +118,9 @@ format is chosen. The following values a
 
 * "man": use the 'man' program as usual,
 * "woman": use 'emacsclient' to launch the "woman" mode in emacs
-(this only works starting with emacsclient versions 22),
+  (this only works starting with emacsclient versions 22),
 * "konqueror": use 'kfmclient' to open the man page in a new konqueror
-tab (see 'Note about konqueror' below).
+  tab (see 'Note about konqueror' below).
 
 Values for other tools can be used if there is a corresponding
 `man.<tool>.cmd` configuration entry (see below).
@@ -160,8 +171,8 @@ variable, we launch 'kfmclient' to try t
 already opened konqueror in a new tab if possible.
 
 For consistency, we also try such a trick if 'man.konqueror.path' is
-set to something like 'A_PATH_TO/konqueror'. That means we will try to
-launch 'A_PATH_TO/kfmclient' instead.
+set to something like `A_PATH_TO/konqueror`. That means we will try to
+launch `A_PATH_TO/kfmclient` instead.
 
 If you really want to use 'konqueror', then you can use something like
 the following:
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/githooks.txt 1.2.3+git2.25.1-1/git/Documentation/githooks.txt
--- 1.2.1+git2.18.0-1/git/Documentation/githooks.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/githooks.txt	2020-02-17 04:47:35.000000000 +0000
@@ -99,6 +99,32 @@ All the `git commit` hooks are invoked w
 variable `GIT_EDITOR=:` if the command will not bring up an editor
 to modify the commit message.
 
+The default 'pre-commit' hook, when enabled--and with the
+`hooks.allownonascii` config option unset or set to false--prevents
+the use of non-ASCII filenames.
+
+pre-merge-commit
+~~~~~~~~~~~~~~~~
+
+This hook is invoked by linkgit:git-merge[1], and can be bypassed
+with the `--no-verify` option.  It takes no parameters, and is
+invoked after the merge has been carried out successfully and before
+obtaining the proposed commit log message to
+make a commit.  Exiting with a non-zero status from this script
+causes the `git merge` command to abort before creating a commit.
+
+The default 'pre-merge-commit' hook, when enabled, runs the
+'pre-commit' hook, if the latter is enabled.
+
+This hook is invoked with the environment variable
+`GIT_EDITOR=:` if the command will not bring up an editor
+to modify the commit message.
+
+If the merge cannot be carried out automatically, the conflicts
+need to be resolved and the result committed separately (see
+linkgit:git-merge[1]). At that point, this hook will not be executed,
+but the 'pre-commit' hook will, if it is enabled.
+
 prepare-commit-msg
 ~~~~~~~~~~~~~~~~~~
 
@@ -161,12 +187,13 @@ rebased, and is not set when rebasing th
 post-checkout
 ~~~~~~~~~~~~~
 
-This hook is invoked when a linkgit:git-checkout[1] is run after having updated the
+This hook is invoked when a linkgit:git-checkout[1] or
+linkgit:git-switch[1] is run after having updated the
 worktree.  The hook is given three parameters: the ref of the previous HEAD,
 the ref of the new HEAD (which may or may not have changed), and a flag
 indicating whether the checkout was a branch checkout (changing branches,
 flag=1) or a file checkout (retrieving a file from the index, flag=0).
-This hook cannot affect the outcome of `git checkout`.
+This hook cannot affect the outcome of `git switch` or `git checkout`.
 
 It is also run after linkgit:git-clone[1], unless the `--no-checkout` (`-n`) option is
 used. The first parameter given to the hook is the null-ref, the second the
@@ -402,7 +429,8 @@ exit with a zero status.
 For example, the hook can simply run `git read-tree -u -m HEAD "$1"`
 in order to emulate `git fetch` that is run in the reverse direction
 with `git push`, as the two-tree form of `git read-tree -u -m` is
-essentially the same as `git checkout` that switches branches while
+essentially the same as `git switch` or `git checkout`
+that switches branches while
 keeping the local changes in the working tree that do not interfere
 with the difference between the branches.
 
@@ -419,10 +447,12 @@ post-rewrite
 
 This hook is invoked by commands that rewrite commits
 (linkgit:git-commit[1] when called with `--amend` and
-linkgit:git-rebase[1]; currently `git filter-branch` does 'not' call
-it!).  Its first argument denotes the command it was invoked by:
-currently one of `amend` or `rebase`.  Further command-dependent
-arguments may be passed in the future.
+linkgit:git-rebase[1]; however, full-history (re)writing tools like
+linkgit:git-fast-import[1] or
+https://github.com/newren/git-filter-repo[git-filter-repo] typically
+do not call it!).  Its first argument denotes the command it was
+invoked by: currently one of `amend` or `rebase`.  Further
+command-dependent arguments may be passed in the future.
 
 The hook receives a list of the rewritten commits on stdin, in the
 format
@@ -485,6 +515,31 @@ The exit status determines whether git w
 hook to limit its search.  On error, it will fall back to verifying
 all files and folders.
 
+p4-pre-submit
+~~~~~~~~~~~~~
+
+This hook is invoked by `git-p4 submit`. It takes no parameters and nothing
+from standard input. Exiting with non-zero status from this script prevent
+`git-p4 submit` from launching. Run `git-p4 submit --help` for details.
+
+post-index-change
+~~~~~~~~~~~~~~~~~
+
+This hook is invoked when the index is written in read-cache.c
+do_write_locked_index.
+
+The first parameter passed to the hook is the indicator for the
+working directory being updated.  "1" meaning working directory
+was updated or "0" when the working directory was not updated.
+
+The second parameter passed to the hook is the indicator for whether
+or not the index was updated and the skip-worktree bit could have
+changed.  "1" meaning skip-worktree bits could have been updated
+and "0" meaning they were not.
+
+Only one parameter should be set to "1" when the hook runs.  The hook
+running passing "1", "1" should not be possible.
+
 GIT
 ---
 Part of the linkgit:git[1] suite
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/git-http-backend.txt 1.2.3+git2.25.1-1/git/Documentation/git-http-backend.txt
--- 1.2.1+git2.18.0-1/git/Documentation/git-http-backend.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/git-http-backend.txt	2020-02-17 04:47:35.000000000 +0000
@@ -162,7 +162,7 @@ ScriptAliasMatch ^/git/[^/]*(.*) /usr/li
 
 Accelerated static Apache 2.x::
 	Similar to the above, but Apache can be used to return static
-	files that are stored on disk.	On many systems this may
+	files that are stored on disk.  On many systems this may
 	be more efficient as Apache can ask the kernel to copy the
 	file contents from the file system directly to the network:
 +
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/.gitignore 1.2.3+git2.25.1-1/git/Documentation/.gitignore
--- 1.2.1+git2.18.0-1/git/Documentation/.gitignore	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/.gitignore	2020-02-17 04:47:35.000000000 +0000
@@ -12,3 +12,6 @@ cmds-*.txt
 mergetools-*.txt
 manpage-base-url.xsl
 SubmittingPatches.txt
+tmp-doc-diff/
+GIT-ASCIIDOCFLAGS
+/GIT-EXCLUDED-PROGRAMS
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/gitignore.txt 1.2.3+git2.25.1-1/git/Documentation/gitignore.txt
--- 1.2.1+git2.18.0-1/git/Documentation/gitignore.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/gitignore.txt	2020-02-17 04:47:35.000000000 +0000
@@ -7,7 +7,7 @@ gitignore - Specifies intentionally untr
 
 SYNOPSIS
 --------
-$HOME/.config/git/ignore, $GIT_DIR/info/exclude, .gitignore
+$XDG_CONFIG_HOME/git/ignore, $GIT_DIR/info/exclude, .gitignore
 
 DESCRIPTION
 -----------
@@ -89,28 +89,28 @@ PATTERN FORMAT
    Put a backslash ("`\`") in front of the first "`!`" for patterns
    that begin with a literal "`!`", for example, "`\!important!.txt`".
 
- - If the pattern ends with a slash, it is removed for the
-   purpose of the following description, but it would only find
-   a match with a directory.  In other words, `foo/` will match a
-   directory `foo` and paths underneath it, but will not match a
-   regular file or a symbolic link `foo` (this is consistent
-   with the way how pathspec works in general in Git).
-
- - If the pattern does not contain a slash '/', Git treats it as
-   a shell glob pattern and checks for a match against the
-   pathname relative to the location of the `.gitignore` file
-   (relative to the toplevel of the work tree if not from a
-   `.gitignore` file).
-
- - Otherwise, Git treats the pattern as a shell glob: "`*`" matches
-   anything except "`/`", "`?`" matches any one character except "`/`"
-   and "`[]`" matches one character in a selected range. See
-   fnmatch(3) and the FNM_PATHNAME flag for a more detailed
-   description.
-
- - A leading slash matches the beginning of the pathname.
-   For example, "/{asterisk}.c" matches "cat-file.c" but not
-   "mozilla-sha1/sha1.c".
+ - The slash '/' is used as the directory separator. Separators may
+   occur at the beginning, middle or end of the `.gitignore` search pattern.
+
+ - If there is a separator at the beginning or middle (or both) of the
+   pattern, then the pattern is relative to the directory level of the
+   particular `.gitignore` file itself. Otherwise the pattern may also
+   match at any level below the `.gitignore` level.
+
+ - If there is a separator at the end of the pattern then the pattern
+   will only match directories, otherwise the pattern can match both
+   files and directories.
+
+ - For example, a pattern `doc/frotz/` matches `doc/frotz` directory,
+   but not `a/doc/frotz` directory; however `frotz/` matches `frotz`
+   and `a/frotz` that is a directory (all paths are relative from
+   the `.gitignore` file).
+
+ - An asterisk "`*`" matches anything except a slash.
+   The character "`?`" matches any one character except "`/`".
+   The range notation, e.g. `[a-zA-Z]`, can be used to match
+   one of the characters in a range. See fnmatch(3) and the
+   FNM_PATHNAME flag for a more detailed description.
 
 Two consecutive asterisks ("`**`") in patterns matched against
 full pathname may have special meaning:
@@ -129,7 +129,16 @@ full pathname may have special meaning:
    matches zero or more directories. For example, "`a/**/b`"
    matches "`a/b`", "`a/x/b`", "`a/x/y/b`" and so on.
 
- - Other consecutive asterisks are considered invalid.
+ - Other consecutive asterisks are considered regular asterisks and
+   will match according to the previous rules.
+
+CONFIGURATION
+-------------
+
+The optional configuration variable `core.excludesFile` indicates a path to a
+file containing patterns of file names to exclude, similar to
+`$GIT_DIR/info/exclude`.  Patterns in the exclude file are used in addition to
+those in `$GIT_DIR/info/exclude`.
 
 NOTES
 -----
@@ -143,6 +152,28 @@ To stop tracking a file that is currentl
 EXAMPLES
 --------
 
+ - The pattern `hello.*` matches any file or folder
+   whose name begins with `hello`. If one wants to restrict
+   this only to the directory and not in its subdirectories,
+   one can prepend the pattern with a slash, i.e. `/hello.*`;
+   the pattern now matches `hello.txt`, `hello.c` but not
+   `a/hello.java`.
+
+ - The pattern `foo/` will match a directory `foo` and
+   paths underneath it, but will not match a regular file
+   or a symbolic link `foo` (this is consistent with the
+   way how pathspec works in general in Git)
+
+ - The pattern `doc/frotz` and `/doc/frotz` have the same effect
+   in any `.gitignore` file. In other words, a leading slash
+   is not relevant  if there is already a middle slash in
+   the pattern.
+
+ - The pattern "foo/*", matches "foo/test.json"
+   (a regular file), "foo/bar" (a directory), but it does not match
+   "foo/bar/hello.c" (a regular file), as the asterisk in the
+   pattern does not match "bar/hello.c" which has a slash in it.
+
 --------------------------------------------------------------
     $ git status
     [...]
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/git-imap-send.txt 1.2.3+git2.25.1-1/git/Documentation/git-imap-send.txt
--- 1.2.1+git2.18.0-1/git/Documentation/git-imap-send.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/git-imap-send.txt	2020-02-17 04:47:35.000000000 +0000
@@ -57,50 +57,7 @@ to appropriate values.
 Variables
 ~~~~~~~~~
 
-imap.folder::
-	The folder to drop the mails into, which is typically the Drafts
-	folder. For example: "INBOX.Drafts", "INBOX/Drafts" or
-	"[Gmail]/Drafts". Required.
-
-imap.tunnel::
-	Command used to setup a tunnel to the IMAP server through which
-	commands will be piped instead of using a direct network connection
-	to the server. Required when imap.host is not set.
-
-imap.host::
-	A URL identifying the server. Use a `imap://` prefix for non-secure
-	connections and a `imaps://` prefix for secure connections.
-	Ignored when imap.tunnel is set, but required otherwise.
-
-imap.user::
-	The username to use when logging in to the server.
-
-imap.pass::
-	The password to use when logging in to the server.
-
-imap.port::
-	An integer port number to connect to on the server.
-	Defaults to 143 for imap:// hosts and 993 for imaps:// hosts.
-	Ignored when imap.tunnel is set.
-
-imap.sslverify::
-	A boolean to enable/disable verification of the server certificate
-	used by the SSL/TLS connection. Default is `true`. Ignored when
-	imap.tunnel is set.
-
-imap.preformattedHTML::
-	A boolean to enable/disable the use of html encoding when sending
-	a patch.  An html encoded patch will be bracketed with <pre>
-	and have a content type of text/html.  Ironically, enabling this
-	option causes Thunderbird to send the patch as a plain/text,
-	format=fixed email.  Default is `false`.
-
-imap.authMethod::
-	Specify authenticate method for authentication with IMAP server.
-	If Git was built with the NO_CURL option, or if your curl version is older
-	than 7.34.0, or if you're running git-imap-send with the `--no-curl`
-	option, the only supported method is 'CRAM-MD5'. If this is not set
-	then 'git imap-send' uses the basic IMAP plaintext LOGIN command.
+include::config/imap.txt[]
 
 Examples
 ~~~~~~~~
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/git-init.txt 1.2.3+git2.25.1-1/git/Documentation/git-init.txt
--- 1.2.1+git2.18.0-1/git/Documentation/git-init.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/git-init.txt	2020-02-17 04:47:35.000000000 +0000
@@ -38,8 +38,6 @@ the repository to another place if --sep
 OPTIONS
 -------
 
---
-
 -q::
 --quiet::
 
@@ -111,8 +109,6 @@ into it.
 If you provide a 'directory', the command is run inside it. If this directory
 does not exist, it will be created.
 
---
-
 TEMPLATE DIRECTORY
 ------------------
 
@@ -132,7 +128,7 @@ The template directory will be one of th
 The default template directory includes some directory structure, suggested
 "exclude patterns" (see linkgit:gitignore[5]), and sample hook files.
 
-The sample hooks are all disabled by default, To enable one of the
+The sample hooks are all disabled by default. To enable one of the
 sample hooks rename it by removing its `.sample` suffix.
 
 See linkgit:githooks[5] for more general info on hook execution.
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/git-instaweb.txt 1.2.3+git2.25.1-1/git/Documentation/git-instaweb.txt
--- 1.2.1+git2.18.0-1/git/Documentation/git-instaweb.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/git-instaweb.txt	2020-02-17 04:47:35.000000000 +0000
@@ -29,7 +29,8 @@ OPTIONS
 	The HTTP daemon command-line that will be executed.
 	Command-line options may be specified here, and the
 	configuration file will be added at the end of the command-line.
-	Currently apache2, lighttpd, mongoose, plackup and webrick are supported.
+	Currently apache2, lighttpd, mongoose, plackup, python and
+	webrick are supported.
 	(Default: lighttpd)
 
 -m::
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/git-interpret-trailers.txt 1.2.3+git2.25.1-1/git/Documentation/git-interpret-trailers.txt
--- 1.2.1+git2.18.0-1/git/Documentation/git-interpret-trailers.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/git-interpret-trailers.txt	2020-02-17 04:47:35.000000000 +0000
@@ -3,7 +3,7 @@ git-interpret-trailers(1)
 
 NAME
 ----
-git-interpret-trailers - add or parse structured information in commit messages
+git-interpret-trailers - Add or parse structured information in commit messages
 
 SYNOPSIS
 --------
@@ -56,8 +56,9 @@ least one Git-generated or user-configur
 least 25% trailers.
 The group must be preceded by one or more empty (or whitespace-only) lines.
 The group must either be at the end of the message or be the last
-non-whitespace lines before a line that starts with '---'. Such three
-minus signs start the patch part of the message.
+non-whitespace lines before a line that starts with '---' (followed by a
+space or the end of the line). Such three minus signs start the patch
+part of the message. See also `--no-divider` below.
 
 When reading trailers, there can be whitespaces after the
 token, the separator and the value. There can also be whitespaces
@@ -88,7 +89,8 @@ OPTIONS
 	Specify where all new trailers will be added.  A setting
 	provided with '--where' overrides all configuration variables
 	and applies to all '--trailer' options until the next occurrence of
-	'--where' or '--no-where'.
+	'--where' or '--no-where'. Possible values are `after`, `before`,
+	`end` or `start`.
 
 --if-exists <action>::
 --no-if-exists::
@@ -96,7 +98,8 @@ OPTIONS
 	least one trailer with the same <token> in the message.  A setting
 	provided with '--if-exists' overrides all configuration variables
 	and applies to all '--trailer' options until the next occurrence of
-	'--if-exists' or '--no-if-exists'.
+	'--if-exists' or '--no-if-exists'. Possible actions are `addIfDifferent`,
+	`addIfDifferentNeighbor`, `add`, `replace` and `doNothing`.
 
 --if-missing <action>::
 --no-if-missing::
@@ -104,7 +107,8 @@ OPTIONS
 	trailer with the same <token> in the message.  A setting
 	provided with '--if-missing' overrides all configuration variables
 	and applies to all '--trailer' options until the next occurrence of
-	'--if-missing' or '--no-if-missing'.
+	'--if-missing' or '--no-if-missing'. Possible actions are `doNothing`
+	or `add`.
 
 --only-trailers::
 	Output only the trailers, not any other parts of the input.
@@ -122,6 +126,11 @@ OPTIONS
 	A convenience alias for `--only-trailers --only-input
 	--unfold`.
 
+--no-divider::
+	Do not treat `---` as the end of the commit message. Use this
+	when you know your input contains just the commit message itself
+	(and not an email or the output of `git format-patch`).
+
 CONFIGURATION VARIABLES
 -----------------------
 
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/gitk.txt 1.2.3+git2.25.1-1/git/Documentation/gitk.txt
--- 1.2.1+git2.18.0-1/git/Documentation/gitk.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/gitk.txt	2020-02-17 04:47:35.000000000 +0000
@@ -105,8 +105,12 @@ linkgit:git-rev-list[1] for a complete l
 	(or the function name regex <funcname>) within the <file>.  You may
 	not give any pathspec limiters.  This is currently limited to
 	a walk starting from a single revision, i.e., you may only
-	give zero or one positive revision arguments.
-	You can specify this option more than once.
+	give zero or one positive revision arguments, and
+	<start> and <end> (or <funcname>) must exist in the starting revision.
+	You can specify this option more than once. Implies `--patch`.
+	Patch output can be suppressed using `--no-patch`, but other diff formats
+	(namely `--raw`, `--numstat`, `--shortstat`, `--dirstat`, `--summary`,
+	`--name-only`, `--name-status`, `--check`) are not currently implemented.
 +
 *Note:* gitk (unlike linkgit:git-log[1]) currently only understands
 this option if you specify it "glued together" with its argument.  Do
@@ -168,12 +172,12 @@ Files
 -----
 User configuration and preferences are stored at:
 
-* '$XDG_CONFIG_HOME/git/gitk' if it exists, otherwise
-* '$HOME/.gitk' if it exists
+* `$XDG_CONFIG_HOME/git/gitk` if it exists, otherwise
+* `$HOME/.gitk` if it exists
 
-If neither of the above exist then '$XDG_CONFIG_HOME/git/gitk' is created and
+If neither of the above exist then `$XDG_CONFIG_HOME/git/gitk` is created and
 used by default. If '$XDG_CONFIG_HOME' is not set it defaults to
-'$HOME/.config' in all cases.
+`$HOME/.config` in all cases.
 
 History
 -------
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/git-log.txt 1.2.3+git2.25.1-1/git/Documentation/git-log.txt
--- 1.2.1+git2.18.0-1/git/Documentation/git-log.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/git-log.txt	2020-02-17 04:47:35.000000000 +0000
@@ -49,7 +49,7 @@ OPTIONS
 	Print out the ref name given on the command line by which each
 	commit was reached.
 
---use-mailmap::
+--[no-]use-mailmap::
 	Use mailmap file to map author and committer names and email
 	addresses to canonical real names and email addresses. See
 	linkgit:git-shortlog[1].
@@ -76,8 +76,12 @@ produced by `--stat`, etc.
 	(or the function name regex <funcname>) within the <file>.  You may
 	not give any pathspec limiters.  This is currently limited to
 	a walk starting from a single revision, i.e., you may only
-	give zero or one positive revision arguments.
-	You can specify this option more than once.
+	give zero or one positive revision arguments, and
+	<start> and <end> (or <funcname>) must exist in the starting revision.
+	You can specify this option more than once. Implies `--patch`.
+	Patch output can be suppressed using `--no-patch`, but other diff formats
+	(namely `--raw`, `--numstat`, `--shortstat`, `--dirstat`, `--summary`,
+	`--name-only`, `--name-status`, `--check`) are not currently implemented.
 +
 include::line-range-format.txt[]
 
@@ -192,6 +196,10 @@ log.date::
 	Default format for human-readable dates.  (Compare the
 	`--date` option.)  Defaults to "default", which means to write
 	dates like `Sat May 8 19:35:34 2010 -0500`.
++
+If the format is set to "auto:foo" and the pager is in use, format
+"foo" will be the used for the date format. Otherwise "default" will
+be used.
 
 log.follow::
 	If `true`, `git log` will act as if the `--follow` option was used when
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/git-ls-files.txt 1.2.3+git2.25.1-1/git/Documentation/git-ls-files.txt
--- 1.2.1+git2.18.0-1/git/Documentation/git-ls-files.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/git-ls-files.txt	2020-02-17 04:47:35.000000000 +0000
@@ -118,6 +118,7 @@ OPTIONS
 	linkgit:git-status[1] `--short` or linkgit:git-diff[1]
 	`--name-status` for more user-friendly alternatives.
 +
+--
 This option identifies the file status with the following tags (followed by
 a space) at the start of each line:
 
@@ -128,6 +129,7 @@ a space) at the start of each line:
 	C::	modified/changed
 	K::	to be killed
 	?::	other
+--
 
 -v::
 	Similar to `-t`, but use lowercase letters for files
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/git-ls-remote.txt 1.2.3+git2.25.1-1/git/Documentation/git-ls-remote.txt
--- 1.2.1+git2.18.0-1/git/Documentation/git-ls-remote.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/git-ls-remote.txt	2020-02-17 04:47:35.000000000 +0000
@@ -31,7 +31,7 @@ OPTIONS
 	displayed.
 
 --refs::
-	Do not show peeled tags or pseudorefs like HEAD	in the output.
+	Do not show peeled tags or pseudorefs like `HEAD` in the output.
 
 -q::
 --quiet::
@@ -92,21 +92,23 @@ OPTIONS
 EXAMPLES
 --------
 
-	$ git ls-remote --tags ./.
-	d6602ec5194c87b0fc87103ca4d67251c76f233a	refs/tags/v0.99
-	f25a265a342aed6041ab0cc484224d9ca54b6f41	refs/tags/v0.99.1
-	7ceca275d047c90c0c7d5afb13ab97efdf51bd6e	refs/tags/v0.99.3
-	c5db5456ae3b0873fc659c19fafdde22313cc441	refs/tags/v0.99.2
-	0918385dbd9656cab0d1d81ba7453d49bbc16250	refs/tags/junio-gpg-pub
-	$ git ls-remote http://www.kernel.org/pub/scm/git/git.git master pu rc
-	5fe978a5381f1fbad26a80e682ddd2a401966740	refs/heads/master
-	c781a84b5204fb294c9ccc79f8b3baceeb32c061	refs/heads/pu
-	$ git remote add korg http://www.kernel.org/pub/scm/git/git.git
-	$ git ls-remote --tags korg v\*
-	d6602ec5194c87b0fc87103ca4d67251c76f233a	refs/tags/v0.99
-	f25a265a342aed6041ab0cc484224d9ca54b6f41	refs/tags/v0.99.1
-	c5db5456ae3b0873fc659c19fafdde22313cc441	refs/tags/v0.99.2
-	7ceca275d047c90c0c7d5afb13ab97efdf51bd6e	refs/tags/v0.99.3
+----
+$ git ls-remote --tags ./.
+d6602ec5194c87b0fc87103ca4d67251c76f233a	refs/tags/v0.99
+f25a265a342aed6041ab0cc484224d9ca54b6f41	refs/tags/v0.99.1
+7ceca275d047c90c0c7d5afb13ab97efdf51bd6e	refs/tags/v0.99.3
+c5db5456ae3b0873fc659c19fafdde22313cc441	refs/tags/v0.99.2
+0918385dbd9656cab0d1d81ba7453d49bbc16250	refs/tags/junio-gpg-pub
+$ git ls-remote http://www.kernel.org/pub/scm/git/git.git master pu rc
+5fe978a5381f1fbad26a80e682ddd2a401966740	refs/heads/master
+c781a84b5204fb294c9ccc79f8b3baceeb32c061	refs/heads/pu
+$ git remote add korg http://www.kernel.org/pub/scm/git/git.git
+$ git ls-remote --tags korg v\*
+d6602ec5194c87b0fc87103ca4d67251c76f233a	refs/tags/v0.99
+f25a265a342aed6041ab0cc484224d9ca54b6f41	refs/tags/v0.99.1
+c5db5456ae3b0873fc659c19fafdde22313cc441	refs/tags/v0.99.2
+7ceca275d047c90c0c7d5afb13ab97efdf51bd6e	refs/tags/v0.99.3
+----
 
 SEE ALSO
 --------
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/git-ls-tree.txt 1.2.3+git2.25.1-1/git/Documentation/git-ls-tree.txt
--- 1.2.1+git2.18.0-1/git/Documentation/git-ls-tree.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/git-ls-tree.txt	2020-02-17 04:47:35.000000000 +0000
@@ -27,9 +27,9 @@ in the current working directory.  Note
    taken as relative to the current working directory.  E.g. when you are
    in a directory 'sub' that has a directory 'dir', you can run 'git
    ls-tree -r HEAD dir' to list the contents of the tree (that is
-   'sub/dir' in `HEAD`).  You don't want to give a tree that is not at the
+   `sub/dir` in `HEAD`).  You don't want to give a tree that is not at the
    root level (e.g. `git ls-tree -r HEAD:sub dir`) in this case, as that
-   would result in asking for 'sub/sub/dir' in the `HEAD` commit.
+   would result in asking for `sub/sub/dir` in the `HEAD` commit.
    However, the current working directory can be ignored by passing
    --full-tree option.
 
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/git-merge-base.txt 1.2.3+git2.25.1-1/git/Documentation/git-merge-base.txt
--- 1.2.1+git2.18.0-1/git/Documentation/git-merge-base.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/git-merge-base.txt	2020-02-17 04:47:35.000000000 +0000
@@ -80,9 +80,11 @@ which is reachable from both 'A' and 'B'
 
 For example, with this topology:
 
-	         o---o---o---B
-	        /
-	---o---1---o---o---o---A
+....
+	 o---o---o---B
+	/
+---o---1---o---o---o---A
+....
 
 the merge base between 'A' and 'B' is '1'.
 
@@ -90,21 +92,25 @@ Given three commits 'A', 'B' and 'C', `g
 merge base between 'A' and a hypothetical commit 'M', which is a merge
 between 'B' and 'C'.  For example, with this topology:
 
-	       o---o---o---o---C
-	      /
-	     /   o---o---o---B
-	    /   /
-	---2---1---o---o---o---A
+....
+       o---o---o---o---C
+      /
+     /   o---o---o---B
+    /   /
+---2---1---o---o---o---A
+....
 
 the result of `git merge-base A B C` is '1'.  This is because the
 equivalent topology with a merge commit 'M' between 'B' and 'C' is:
 
 
-	       o---o---o---o---o
-	      /                 \
-	     /   o---o---o---o---M
-	    /   /
-	---2---1---o---o---o---A
+....
+       o---o---o---o---o
+      /                 \
+     /   o---o---o---o---M
+    /   /
+---2---1---o---o---o---A
+....
 
 and the result of `git merge-base A M` is '1'.  Commit '2' is also a
 common ancestor between 'A' and 'M', but '1' is a better common ancestor,
@@ -116,11 +122,13 @@ the best common ancestor of all commits.
 When the history involves criss-cross merges, there can be more than one
 'best' common ancestor for two commits.  For example, with this topology:
 
-	---1---o---A
-	    \ /
-	     X
-	    / \
-	---2---o---o---B
+....
+---1---o---A
+    \ /
+     X
+    / \
+---2---o---o---B
+....
 
 both '1' and '2' are merge-bases of A and B.  Neither one is better than
 the other (both are 'best' merge bases).  When the `--all` option is not given,
@@ -131,36 +139,42 @@ and B is (or at least used to be) to com
 A and B, and check if it is the same as A, in which case, A is an
 ancestor of B.  You will see this idiom used often in older scripts.
 
-	A=$(git rev-parse --verify A)
-	if test "$A" = "$(git merge-base A B)"
-	then
-		... A is an ancestor of B ...
-	fi
+....
+A=$(git rev-parse --verify A)
+if test "$A" = "$(git merge-base A B)"
+then
+	... A is an ancestor of B ...
+fi
+....
 
 In modern git, you can say this in a more direct way:
 
-	if git merge-base --is-ancestor A B
-	then
-		... A is an ancestor of B ...
-	fi
+....
+if git merge-base --is-ancestor A B
+then
+	... A is an ancestor of B ...
+fi
+....
 
 instead.
 
 Discussion on fork-point mode
 -----------------------------
 
-After working on the `topic` branch created with `git checkout -b
+After working on the `topic` branch created with `git switch -c
 topic origin/master`, the history of remote-tracking branch
 `origin/master` may have been rewound and rebuilt, leading to a
 history of this shape:
 
-			 o---B2
-	                /
-	---o---o---B1--o---o---o---B (origin/master)
-	        \
-		 B0
-	          \
-		   D0---D1---D (topic)
+....
+		 o---B2
+		/
+---o---o---B1--o---o---o---B (origin/master)
+	\
+	 B0
+	  \
+	   D0---D1---D (topic)
+....
 
 where `origin/master` used to point at commits B0, B1, B2 and now it
 points at B, and your `topic` branch was started on top of it back
@@ -193,13 +207,15 @@ will find B0, and
 will replay D0, D1 and D on top of B to create a new history of this
 shape:
 
-			 o---B2
-			/
-	---o---o---B1--o---o---o---B (origin/master)
-		\                   \
-		 B0                  D0'--D1'--D' (topic - updated)
-		  \
-		   D0---D1---D (topic - old)
+....
+		 o---B2
+		/
+---o---o---B1--o---o---o---B (origin/master)
+	\                   \
+	 B0                  D0'--D1'--D' (topic - updated)
+	  \
+	   D0---D1---D (topic - old)
+....
 
 A caveat is that older reflog entries in your repository may be
 expired by `git gc`.  If B0 no longer appears in the reflog of the
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/git-merge-index.txt 1.2.3+git2.25.1-1/git/Documentation/git-merge-index.txt
--- 1.2.1+git2.18.0-1/git/Documentation/git-merge-index.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/git-merge-index.txt	2020-02-17 04:47:35.000000000 +0000
@@ -54,20 +54,24 @@ original is first. But the argument orde
 
 Examples:
 
-  torvalds@ppc970:~/merge-test> git merge-index cat MM
-  This is MM from the original tree.			# original
-  This is modified MM in the branch A.			# merge1
-  This is modified MM in the branch B.			# merge2
-  This is modified MM in the branch B.			# current contents
+----
+torvalds@ppc970:~/merge-test> git merge-index cat MM
+This is MM from the original tree.		# original
+This is modified MM in the branch A.		# merge1
+This is modified MM in the branch B.		# merge2
+This is modified MM in the branch B.		# current contents
+----
 
 or
 
-  torvalds@ppc970:~/merge-test> git merge-index cat AA MM
-  cat: : No such file or directory
-  This is added AA in the branch A.
-  This is added AA in the branch B.
-  This is added AA in the branch B.
-  fatal: merge program failed
+----
+torvalds@ppc970:~/merge-test> git merge-index cat AA MM
+cat: : No such file or directory
+This is added AA in the branch A.
+This is added AA in the branch B.
+This is added AA in the branch B.
+fatal: merge program failed
+----
 
 where the latter example shows how 'git merge-index' will stop trying to
 merge once anything has returned an error (i.e., `cat` returned an error
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/git-mergetool--lib.txt 1.2.3+git2.25.1-1/git/Documentation/git-mergetool--lib.txt
--- 1.2.1+git2.18.0-1/git/Documentation/git-mergetool--lib.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/git-mergetool--lib.txt	2020-02-17 04:47:35.000000000 +0000
@@ -28,7 +28,9 @@ to define the operation mode for the fun
 FUNCTIONS
 ---------
 get_merge_tool::
-	returns a merge tool.
+	returns a merge tool. the return code is 1 if we returned a guessed
+	merge tool, else 0. '$GIT_MERGETOOL_GUI' may be set to 'true' to
+	search for the appropriate guitool.
 
 get_merge_tool_cmd::
 	returns the custom command for a merge tool.
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/git-mergetool.txt 1.2.3+git2.25.1-1/git/Documentation/git-mergetool.txt
--- 1.2.1+git2.18.0-1/git/Documentation/git-mergetool.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/git-mergetool.txt	2020-02-17 04:47:35.000000000 +0000
@@ -79,6 +79,19 @@ success of the resolution after the cust
 	Prompt before each invocation of the merge resolution program
 	to give the user a chance to skip the path.
 
+-g::
+--gui::
+	When 'git-mergetool' is invoked with the `-g` or `--gui` option
+	the default merge tool will be read from the configured
+	`merge.guitool` variable instead of `merge.tool`. If
+	`merge.guitool` is not set, we will fallback to the tool
+	configured under `merge.tool`.
+
+--no-gui::
+	This overrides a previous `-g` or `--gui` setting and reads the
+	default merge tool will be read from the configured `merge.tool`
+	variable.
+
 -O<orderfile>::
 	Process files in the order specified in the
 	<orderfile>, which has one shell glob pattern per line.
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/git-merge.txt 1.2.3+git2.25.1-1/git/Documentation/git-merge.txt
--- 1.2.1+git2.18.0-1/git/Documentation/git-merge.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/git-merge.txt	2020-02-17 04:47:35.000000000 +0000
@@ -10,11 +10,10 @@ SYNOPSIS
 --------
 [verse]
 'git merge' [-n] [--stat] [--no-commit] [--squash] [--[no-]edit]
-	[-s <strategy>] [-X <strategy-option>] [-S[<keyid>]]
+	[--no-verify] [-s <strategy>] [-X <strategy-option>] [-S[<keyid>]]
 	[--[no-]allow-unrelated-histories]
-	[--[no-]rerere-autoupdate] [-m <msg>] [<commit>...]
-'git merge' --abort
-'git merge' --continue
+	[--[no-]rerere-autoupdate] [-m <msg>] [-F <file>] [<commit>...]
+'git merge' (--continue | --abort | --quit)
 
 DESCRIPTION
 -----------
@@ -75,10 +74,24 @@ The 'git fmt-merge-msg' command can be
 used to give a good default for automated 'git merge'
 invocations. The automated message can include the branch description.
 
---[no-]rerere-autoupdate::
+-F <file>::
+--file=<file>::
+	Read the commit message to be used for the merge commit (in
+	case one is created).
++
+If `--log` is specified, a shortlog of the commits being merged
+will be appended to the specified message.
+
+--rerere-autoupdate::
+--no-rerere-autoupdate::
 	Allow the rerere mechanism to update the index with the
 	result of auto-conflict resolution if possible.
 
+--overwrite-ignore::
+--no-overwrite-ignore::
+	Silently overwrite ignored files from the merge result. This
+	is the default behavior. Use `--no-overwrite-ignore` to abort.
+
 --abort::
 	Abort the current conflict resolution process, and
 	try to reconstruct the pre-merge state.
@@ -91,6 +104,10 @@ commit or stash your changes before runn
 'git merge --abort' is equivalent to 'git reset --merge' when
 `MERGE_HEAD` is present.
 
+--quit::
+	Forget about the current merge in progress. Leave the index
+	and the working tree as-is.
+
 --continue::
 	After a 'git merge' stops due to conflicts you can conclude the
 	merge by running 'git merge --continue' (see "HOW TO RESOLVE
@@ -122,9 +139,9 @@ merge' may need to update.
 
 To avoid recording unrelated changes in the merge commit,
 'git pull' and 'git merge' will also abort if there are any changes
-registered in the index relative to the `HEAD` commit.  (One
-exception is when the changed index entries are in the state that
-would result from the merge already.)
+registered in the index relative to the `HEAD` commit.  (Special
+narrow exceptions to this rule may exist depending on which merge
+strategy is in use, but generally, the index must match HEAD.)
 
 If all named commits are already ancestors of `HEAD`, 'git merge'
 will exit early with the message "Already up to date."
@@ -334,7 +351,7 @@ include::merge-strategies.txt[]
 
 CONFIGURATION
 -------------
-include::merge-config.txt[]
+include::config/merge.txt[]
 
 branch.<name>.mergeOptions::
 	Sets default options for merging into branch <name>. The syntax and
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/gitmodules.txt 1.2.3+git2.25.1-1/git/Documentation/gitmodules.txt
--- 1.2.1+git2.18.0-1/git/Documentation/gitmodules.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/gitmodules.txt	2020-02-17 04:47:35.000000000 +0000
@@ -44,9 +44,8 @@ submodule.<name>.update::
 	submodule init` to initialize the configuration variable of
 	the same name. Allowed values here are 'checkout', 'rebase',
 	'merge' or 'none'. See description of 'update' command in
-	linkgit:git-submodule[1] for their meaning. Note that the
-	'!command' form is intentionally ignored here for security
-	reasons.
+	linkgit:git-submodule[1] for their meaning. For security
+	reasons, the '!command' form is not accepted here.
 
 submodule.<name>.branch::
 	A remote branch name for tracking updates in the upstream submodule.
@@ -67,7 +66,8 @@ submodule.<name>.fetchRecurseSubmodules:
 submodule.<name>.ignore::
 	Defines under what circumstances "git status" and the diff family show
 	a submodule as modified. The following values are supported:
-
++
+--
 	all;; The submodule will never be considered modified (but will
 	    nonetheless show up in the output of status and commit when it has
 	    been staged).
@@ -80,16 +80,18 @@ submodule.<name>.ignore::
 	    Committed differences and modifications to tracked files will show
 	    up.
 
-	none;; No modifiations to submodules are ignored, all of committed
+	none;; No modifications to submodules are ignored, all of committed
 	    differences, and modifications to tracked and untracked files are
 	    shown. This is the default option.
 
-	If this option is also present in the submodules entry in .git/config
-	of the superproject, the setting there will override the one found in
-	.gitmodules.
-	Both settings can be overridden on the command line by using the
-	"--ignore-submodule" option. The 'git submodule' commands are not
-	affected by this setting.
+If this option is also present in the submodules entry in .git/config
+of the superproject, the setting there will override the one found in
+.gitmodules.
+
+Both settings can be overridden on the command line by using the
+"--ignore-submodules" option. The 'git submodule' commands are not
+affected by this setting.
+--
 
 submodule.<name>.shallow::
 	When set to true, a clone of this submodule will be performed as a
@@ -102,22 +104,23 @@ EXAMPLES
 
 Consider the following .gitmodules file:
 
-	[submodule "libfoo"]
-		path = include/foo
-		url = git://foo.com/git/lib.git
-
-	[submodule "libbar"]
-		path = include/bar
-		url = git://bar.com/git/lib.git
-
+----
+[submodule "libfoo"]
+	path = include/foo
+	url = git://foo.com/git/lib.git
+
+[submodule "libbar"]
+	path = include/bar
+	url = git://bar.com/git/lib.git
+----
 
 This defines two submodules, `libfoo` and `libbar`. These are expected to
-be checked out in the paths 'include/foo' and 'include/bar', and for both
+be checked out in the paths `include/foo` and `include/bar`, and for both
 submodules a URL is specified which can be used for cloning the submodules.
 
 SEE ALSO
 --------
-linkgit:git-submodule[1] linkgit:git-config[1]
+linkgit:git-submodule[1], linkgit:gitsubmodules[7], linkgit:git-config[1]
 
 GIT
 ---
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/git-multi-pack-index.txt 1.2.3+git2.25.1-1/git/Documentation/git-multi-pack-index.txt
--- 1.2.1+git2.18.0-1/git/Documentation/git-multi-pack-index.txt	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/git-multi-pack-index.txt	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,92 @@
+git-multi-pack-index(1)
+=======================
+
+NAME
+----
+git-multi-pack-index - Write and verify multi-pack-indexes
+
+
+SYNOPSIS
+--------
+[verse]
+'git multi-pack-index' [--object-dir=<dir>] [--[no-]progress] <subcommand>
+
+DESCRIPTION
+-----------
+Write or verify a multi-pack-index (MIDX) file.
+
+OPTIONS
+-------
+
+--object-dir=<dir>::
+	Use given directory for the location of Git objects. We check
+	`<dir>/packs/multi-pack-index` for the current MIDX file, and
+	`<dir>/packs` for the pack-files to index.
+
+--[no-]progress::
+	Turn progress on/off explicitly. If neither is specified, progress is
+	shown if standard error is connected to a terminal.
+
+The following subcommands are available:
+
+write::
+	Write a new MIDX file.
+
+verify::
+	Verify the contents of the MIDX file.
+
+expire::
+	Delete the pack-files that are tracked 	by the MIDX file, but
+	have no objects referenced by the MIDX. Rewrite the MIDX file
+	afterward to remove all references to these pack-files.
+
+repack::
+	Create a new pack-file containing objects in small pack-files
+	referenced by the multi-pack-index. If the size given by the
+	`--batch-size=<size>` argument is zero, then create a pack
+	containing all objects referenced by the multi-pack-index. For
+	a non-zero batch size, Select the pack-files by examining packs
+	from oldest-to-newest, computing the "expected size" by counting
+	the number of objects in the pack referenced by the
+	multi-pack-index, then divide by the total number of objects in
+	the pack and multiply by the pack size. We select packs with
+	expected size below the batch size until the set of packs have
+	total expected size at least the batch size. If the total size
+	does not reach the batch size, then do nothing. If a new pack-
+	file is created, rewrite the multi-pack-index to reference the
+	new pack-file. A later run of 'git multi-pack-index expire' will
+	delete the pack-files that were part of this batch.
+
+
+EXAMPLES
+--------
+
+* Write a MIDX file for the packfiles in the current .git folder.
++
+-----------------------------------------------
+$ git multi-pack-index write
+-----------------------------------------------
+
+* Write a MIDX file for the packfiles in an alternate object store.
++
+-----------------------------------------------
+$ git multi-pack-index --object-dir <alt> write
+-----------------------------------------------
+
+* Verify the MIDX file for the packfiles in the current .git folder.
++
+-----------------------------------------------
+$ git multi-pack-index verify
+-----------------------------------------------
+
+
+SEE ALSO
+--------
+See link:technical/multi-pack-index.html[The Multi-Pack-Index Design
+Document] and link:technical/pack-format.html[The Multi-Pack-Index
+Format] for more information on the multi-pack-index feature.
+
+
+GIT
+---
+Part of the linkgit:git[1] suite
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/git-notes.txt 1.2.3+git2.25.1-1/git/Documentation/git-notes.txt
--- 1.2.1+git2.18.0-1/git/Documentation/git-notes.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/git-notes.txt	2020-02-17 04:47:35.000000000 +0000
@@ -10,7 +10,7 @@ SYNOPSIS
 [verse]
 'git notes' [list [<object>]]
 'git notes' add [-f] [--allow-empty] [-F <file> | -m <msg> | (-c | -C) <object>] [<object>]
-'git notes' copy [-f] ( --stdin | <from-object> <to-object> )
+'git notes' copy [-f] ( --stdin | <from-object> [<to-object>] )
 'git notes' append [--allow-empty] [-F <file> | -m <msg> | (-c | -C) <object>] [<object>]
 'git notes' edit [--allow-empty] [<object>]
 'git notes' show [<object>]
@@ -68,8 +68,8 @@ add::
 	subcommand).
 
 copy::
-	Copy the notes for the first object onto the second object.
-	Abort if the second object already has notes, or if the first
+	Copy the notes for the first object onto the second object (defaults to
+	HEAD). Abort if the second object already has notes, or if the first
 	object has none (use -f to overwrite existing notes to the
 	second object). This subcommand is equivalent to:
 	`git notes add [-f] -C $(git notes list <from-object>) <to-object>`
@@ -146,7 +146,7 @@ OPTIONS
 
 -C <object>::
 --reuse-message=<object>::
-	Take the given blob object (for	example, another note) as the
+	Take the given blob object (for example, another note) as the
 	note message. (Use `git notes copy <object>` instead to
 	copy notes between objects.)
 
@@ -199,7 +199,7 @@ OPTIONS
 	.git/NOTES_MERGE_REF symref is updated to the resulting commit.
 
 --abort::
-	Abort/reset a in-progress 'git notes merge', i.e. a notes merge
+	Abort/reset an in-progress 'git notes merge', i.e. a notes merge
 	with conflicts. This simply removes all files related to the
 	notes merge.
 
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/git-p4.txt 1.2.3+git2.25.1-1/git/Documentation/git-p4.txt
--- 1.2.1+git2.18.0-1/git/Documentation/git-p4.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/git-p4.txt	2020-02-17 04:47:35.000000000 +0000
@@ -71,12 +71,12 @@ $ git p4 clone //depot/path/project
 ------------
 This:
 
-1.   Creates an empty Git repository in a subdirectory called 'project'.
+1. Creates an empty Git repository in a subdirectory called 'project'.
 +
-2.   Imports the full contents of the head revision from the given p4
-depot path into a single commit in the Git branch 'refs/remotes/p4/master'.
+2. Imports the full contents of the head revision from the given p4
+   depot path into a single commit in the Git branch 'refs/remotes/p4/master'.
 +
-3.   Creates a local branch, 'master' from this remote and checks it out.
+3. Creates a local branch, 'master' from this remote and checks it out.
 
 To reproduce the entire p4 history in Git, use the '@all' modifier on
 the depot path:
@@ -174,21 +174,21 @@ $ git p4 submit --update-shelve 1234 --u
 Unshelve
 ~~~~~~~~
 Unshelving will take a shelved P4 changelist, and produce the equivalent git commit
-in the branch refs/remotes/p4/unshelved/<changelist>.
+in the branch refs/remotes/p4-unshelved/<changelist>.
 
 The git commit is created relative to the current origin revision (HEAD by default).
-If the shelved changelist's parent revisions differ, git-p4 will refuse to unshelve;
-you need to be unshelving onto an equivalent tree.
+A parent commit is created based on the origin, and then the unshelve commit is
+created based on that.
 
 The origin revision can be changed with the "--origin" option.
 
-If the target branch in refs/remotes/p4/unshelved already exists, the old one will
+If the target branch in refs/remotes/p4-unshelved already exists, the old one will
 be renamed.
 
 ----
 $ git p4 sync
 $ git p4 unshelve 12345
-$ git show refs/remotes/p4/unshelved/12345
+$ git show p4-unshelved/12345
 <submit more changes via p4 to the same files>
 $ git p4 unshelve 12345
 <refuses to unshelve until git is in sync with p4 again>
@@ -374,6 +374,14 @@ These options can be used to modify 'git
     been submitted. Implies --disable-rebase. Can also be set with
     git-p4.disableP4Sync. Sync with origin/master still goes ahead if possible.
 
+Hook for submit
+~~~~~~~~~~~~~~~
+The `p4-pre-submit` hook is executed if it exists and is executable.
+The hook takes no parameters and nothing from standard input. Exiting with
+non-zero status from this script prevents `git-p4 submit` from launching.
+
+One usage scenario is to run unit tests in the hook.
+
 Rebase options
 ~~~~~~~~~~~~~~
 These options can be used to modify 'git p4 rebase' behavior.
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/git-pack-objects.txt 1.2.3+git2.25.1-1/git/Documentation/git-pack-objects.txt
--- 1.2.1+git2.18.0-1/git/Documentation/git-pack-objects.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/git-pack-objects.txt	2020-02-17 04:47:35.000000000 +0000
@@ -14,7 +14,7 @@ SYNOPSIS
 	[--local] [--incremental] [--window=<n>] [--depth=<n>]
 	[--revs [--unpacked | --all]] [--keep-pack=<pack-name>]
 	[--stdout [--filter=<filter-spec>] | base-name]
-	[--shallow] [--keep-true-parents] < object-list
+	[--shallow] [--keep-true-parents] [--sparse] < object-list
 
 
 DESCRIPTION
@@ -131,7 +131,7 @@ depth is 4095.
 --keep-pack=<pack-name>::
 	This flag causes an object already in the given pack to be
 	ignored, even if it would have otherwise been
-	packed. `<pack-name>` is the the pack file name without
+	packed. `<pack-name>` is the pack file name without
 	leading directory (e.g. `pack-123.pack`). The option could be
 	specified multiple times to keep multiple packs.
 
@@ -196,6 +196,15 @@ depth is 4095.
 	Add --no-reuse-object if you want to force a uniform compression
 	level on all data no matter the source.
 
+--sparse::
+	Use the "sparse" algorithm to determine which objects to include in
+	the pack, when combined with the "--revs" option. This algorithm
+	only walks trees that appear in paths that introduce new objects.
+	This can have significant performance benefits when computing
+	a pack to send a small change. However, it is possible that extra
+	objects are added to the pack-file if the included commits contain
+	certain types of direct renames.
+
 --thin::
 	Create a "thin" pack by omitting the common objects between a
 	sender and a receiver in order to reduce network transfer. This
@@ -289,6 +298,103 @@ Unexpected missing object will raise an
 --unpack-unreachable::
 	Keep unreachable objects in loose form. This implies `--revs`.
 
+--delta-islands::
+	Restrict delta matches based on "islands". See DELTA ISLANDS
+	below.
+
+
+DELTA ISLANDS
+-------------
+
+When possible, `pack-objects` tries to reuse existing on-disk deltas to
+avoid having to search for new ones on the fly. This is an important
+optimization for serving fetches, because it means the server can avoid
+inflating most objects at all and just send the bytes directly from
+disk. This optimization can't work when an object is stored as a delta
+against a base which the receiver does not have (and which we are not
+already sending). In that case the server "breaks" the delta and has to
+find a new one, which has a high CPU cost. Therefore it's important for
+performance that the set of objects in on-disk delta relationships match
+what a client would fetch.
+
+In a normal repository, this tends to work automatically. The objects
+are mostly reachable from the branches and tags, and that's what clients
+fetch. Any deltas we find on the server are likely to be between objects
+the client has or will have.
+
+But in some repository setups, you may have several related but separate
+groups of ref tips, with clients tending to fetch those groups
+independently. For example, imagine that you are hosting several "forks"
+of a repository in a single shared object store, and letting clients
+view them as separate repositories through `GIT_NAMESPACE` or separate
+repos using the alternates mechanism. A naive repack may find that the
+optimal delta for an object is against a base that is only found in
+another fork. But when a client fetches, they will not have the base
+object, and we'll have to find a new delta on the fly.
+
+A similar situation may exist if you have many refs outside of
+`refs/heads/` and `refs/tags/` that point to related objects (e.g.,
+`refs/pull` or `refs/changes` used by some hosting providers). By
+default, clients fetch only heads and tags, and deltas against objects
+found only in those other groups cannot be sent as-is.
+
+Delta islands solve this problem by allowing you to group your refs into
+distinct "islands". Pack-objects computes which objects are reachable
+from which islands, and refuses to make a delta from an object `A`
+against a base which is not present in all of `A`'s islands. This
+results in slightly larger packs (because we miss some delta
+opportunities), but guarantees that a fetch of one island will not have
+to recompute deltas on the fly due to crossing island boundaries.
+
+When repacking with delta islands the delta window tends to get
+clogged with candidates that are forbidden by the config. Repacking
+with a big --window helps (and doesn't take as long as it otherwise
+might because we can reject some object pairs based on islands before
+doing any computation on the content).
+
+Islands are configured via the `pack.island` option, which can be
+specified multiple times. Each value is a left-anchored regular
+expressions matching refnames. For example:
+
+-------------------------------------------
+[pack]
+island = refs/heads/
+island = refs/tags/
+-------------------------------------------
+
+puts heads and tags into an island (whose name is the empty string; see
+below for more on naming). Any refs which do not match those regular
+expressions (e.g., `refs/pull/123`) is not in any island. Any object
+which is reachable only from `refs/pull/` (but not heads or tags) is
+therefore not a candidate to be used as a base for `refs/heads/`.
+
+Refs are grouped into islands based on their "names", and two regexes
+that produce the same name are considered to be in the same
+island. The names are computed from the regexes by concatenating any
+capture groups from the regex, with a '-' dash in between. (And if
+there are no capture groups, then the name is the empty string, as in
+the above example.) This allows you to create arbitrary numbers of
+islands. Only up to 14 such capture groups are supported though.
+
+For example, imagine you store the refs for each fork in
+`refs/virtual/ID`, where `ID` is a numeric identifier. You might then
+configure:
+
+-------------------------------------------
+[pack]
+island = refs/virtual/([0-9]+)/heads/
+island = refs/virtual/([0-9]+)/tags/
+island = refs/virtual/([0-9]+)/(pull)/
+-------------------------------------------
+
+That puts the heads and tags for each fork in their own island (named
+"1234" or similar), and the pull refs for each go into their own
+"1234-pull".
+
+Note that we pick a single island for each regex to go into, using "last
+one wins" ordering (which allows repo-specific config to take precedence
+over user-wide config, and so forth).
+
 SEE ALSO
 --------
 linkgit:git-rev-list[1]
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/git-pull.txt 1.2.3+git2.25.1-1/git/Documentation/git-pull.txt
--- 1.2.1+git2.18.0-1/git/Documentation/git-pull.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/git-pull.txt	2020-02-17 04:47:35.000000000 +0000
@@ -112,8 +112,9 @@ When set to `merges`, rebase using `git
 the local merge commits are included in the rebase (see
 linkgit:git-rebase[1] for details).
 +
-When set to preserve, rebase with the `--preserve-merges` option passed
-to `git rebase` so that locally created merge commits will not be flattened.
+When set to `preserve` (deprecated in favor of `merges`), rebase with the
+`--preserve-merges` option passed to `git rebase` so that locally created
+merge commits will not be flattened.
 +
 When false, merge the current branch into the upstream branch.
 +
@@ -248,7 +249,7 @@ BUGS
 ----
 Using --recurse-submodules can only fetch new commits in already checked
 out submodules right now. When e.g. upstream added a new submodule in the
-just fetched commits of the superproject the submodule itself can not be
+just fetched commits of the superproject the submodule itself cannot be
 fetched, making it impossible to check out that submodule later without
 having to do a fetch again. This is expected to be fixed in a future Git
 version.
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/git-push.txt 1.2.3+git2.25.1-1/git/Documentation/git-push.txt
--- 1.2.1+git2.18.0-1/git/Documentation/git-push.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/git-push.txt	2020-02-17 04:47:35.000000000 +0000
@@ -73,23 +73,78 @@ be omitted--such a push will update a re
 without any `<refspec>` on the command line.  Otherwise, missing
 `:<dst>` means to update the same ref as the `<src>`.
 +
-The object referenced by <src> is used to update the <dst> reference
-on the remote side.  By default this is only allowed if <dst> is not
-a tag (annotated or lightweight), and then only if it can fast-forward
-<dst>.  By having the optional leading `+`, you can tell Git to update
-the <dst> ref even if it is not allowed by default (e.g., it is not a
-fast-forward.)  This does *not* attempt to merge <src> into <dst>.  See
-EXAMPLES below for details.
+If <dst> doesn't start with `refs/` (e.g. `refs/heads/master`) we will
+try to infer where in `refs/*` on the destination <repository> it
+belongs based on the type of <src> being pushed and whether <dst>
+is ambiguous.
 +
-`tag <tag>` means the same as `refs/tags/<tag>:refs/tags/<tag>`.
+--
+* If <dst> unambiguously refers to a ref on the <repository> remote,
+  then push to that ref.
+
+* If <src> resolves to a ref starting with refs/heads/ or refs/tags/,
+  then prepend that to <dst>.
+
+* Other ambiguity resolutions might be added in the future, but for
+  now any other cases will error out with an error indicating what we
+  tried, and depending on the `advice.pushUnqualifiedRefname`
+  configuration (see linkgit:git-config[1]) suggest what refs/
+  namespace you may have wanted to push to.
+
+--
 +
-Pushing an empty <src> allows you to delete the <dst> ref from
-the remote repository.
+The object referenced by <src> is used to update the <dst> reference
+on the remote side. Whether this is allowed depends on where in
+`refs/*` the <dst> reference lives as described in detail below, in
+those sections "update" means any modifications except deletes, which
+as noted after the next few sections are treated differently.
++
+The `refs/heads/*` namespace will only accept commit objects, and
+updates only if they can be fast-forwarded.
++
+The `refs/tags/*` namespace will accept any kind of object (as
+commits, trees and blobs can be tagged), and any updates to them will
+be rejected.
++
+It's possible to push any type of object to any namespace outside of
+`refs/{tags,heads}/*`. In the case of tags and commits, these will be
+treated as if they were the commits inside `refs/heads/*` for the
+purposes of whether the update is allowed.
++
+I.e. a fast-forward of commits and tags outside `refs/{tags,heads}/*`
+is allowed, even in cases where what's being fast-forwarded is not a
+commit, but a tag object which happens to point to a new commit which
+is a fast-forward of the commit the last tag (or commit) it's
+replacing. Replacing a tag with an entirely different tag is also
+allowed, if it points to the same commit, as well as pushing a peeled
+tag, i.e. pushing the commit that existing tag object points to, or a
+new tag object which an existing commit points to.
++
+Tree and blob objects outside of `refs/{tags,heads}/*` will be treated
+the same way as if they were inside `refs/tags/*`, any update of them
+will be rejected.
++
+All of the rules described above about what's not allowed as an update
+can be overridden by adding an the optional leading `+` to a refspec
+(or using `--force` command line option). The only exception to this
+is that no amount of forcing will make the `refs/heads/*` namespace
+accept a non-commit object. Hooks and configuration can also override
+or amend these rules, see e.g. `receive.denyNonFastForwards` in
+linkgit:git-config[1] and `pre-receive` and `update` in
+linkgit:githooks[5].
++
+Pushing an empty <src> allows you to delete the <dst> ref from the
+remote repository. Deletions are always accepted without a leading `+`
+in the refspec (or `--force`), except when forbidden by configuration
+or hooks. See `receive.denyDeletes` in linkgit:git-config[1] and
+`pre-receive` and `update` in linkgit:githooks[5].
 +
 The special refspec `:` (or `+:` to allow non-fast-forward updates)
 directs Git to push "matching" branches: for every branch that exists on
 the local side, the remote side is updated if a branch of the same name
 already exists on the remote side.
++
+`tag <tag>` means the same as `refs/tags/<tag>:refs/tags/<tag>`.
 
 --all::
 	Push all branches (i.e. refs under `refs/heads/`); cannot be
@@ -556,6 +611,9 @@ the ones in the examples below) can be c
 	`refs/remotes/satellite/master`) in the `mothership` repository;
 	do the same for `dev` and `satellite/dev`.
 +
+See the section describing `<refspec>...` above for a discussion of
+the matching semantics.
++
 This is to emulate `git fetch` run on the `mothership` using `git
 push` that is run in the opposite direction in order to integrate
 the work done on `satellite`, and is often necessary when you can
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/git-quiltimport.txt 1.2.3+git2.25.1-1/git/Documentation/git-quiltimport.txt
--- 1.2.1+git2.18.0-1/git/Documentation/git-quiltimport.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/git-quiltimport.txt	2020-02-17 04:47:35.000000000 +0000
@@ -10,7 +10,7 @@ SYNOPSIS
 --------
 [verse]
 'git quiltimport' [--dry-run | -n] [--author <author>] [--patches <dir>]
-		[--series <file>]
+		[--series <file>] [--keep-non-patch]
 
 
 DESCRIPTION
@@ -56,6 +56,9 @@ The default for the series file is <patc
 or the value of the `$QUILT_SERIES` environment
 variable.
 
+--keep-non-patch::
+	Pass `-b` flag to 'git mailinfo' (see linkgit:git-mailinfo[1]).
+
 GIT
 ---
 Part of the linkgit:git[1] suite
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/git-range-diff.txt 1.2.3+git2.25.1-1/git/Documentation/git-range-diff.txt
--- 1.2.1+git2.18.0-1/git/Documentation/git-range-diff.txt	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/git-range-diff.txt	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,273 @@
+git-range-diff(1)
+=================
+
+NAME
+----
+git-range-diff - Compare two commit ranges (e.g. two versions of a branch)
+
+SYNOPSIS
+--------
+[verse]
+'git range-diff' [--color=[<when>]] [--no-color] [<diff-options>]
+	[--no-dual-color] [--creation-factor=<factor>]
+	( <range1> <range2> | <rev1>...<rev2> | <base> <rev1> <rev2> )
+
+DESCRIPTION
+-----------
+
+This command shows the differences between two versions of a patch
+series, or more generally, two commit ranges (ignoring merge commits).
+
+To that end, it first finds pairs of commits from both commit ranges
+that correspond with each other. Two commits are said to correspond when
+the diff between their patches (i.e. the author information, the commit
+message and the commit diff) is reasonably small compared to the
+patches' size. See ``Algorithm`` below for details.
+
+Finally, the list of matching commits is shown in the order of the
+second commit range, with unmatched commits being inserted just after
+all of their ancestors have been shown.
+
+
+OPTIONS
+-------
+--no-dual-color::
+	When the commit diffs differ, `git range-diff` recreates the
+	original diffs' coloring, and adds outer -/+ diff markers with
+	the *background* being red/green to make it easier to see e.g.
+	when there was a change in what exact lines were added.
++
+Additionally, the commit diff lines that are only present in the first commit
+range are shown "dimmed" (this can be overridden using the `color.diff.<slot>`
+config setting where `<slot>` is one of `contextDimmed`, `oldDimmed` and
+`newDimmed`), and the commit diff lines that are only present in the second
+commit range are shown in bold (which can be overridden using the config
+settings `color.diff.<slot>` with `<slot>` being one of `contextBold`,
+`oldBold` or `newBold`).
++
+This is known to `range-diff` as "dual coloring". Use `--no-dual-color`
+to revert to color all lines according to the outer diff markers
+(and completely ignore the inner diff when it comes to color).
+
+--creation-factor=<percent>::
+	Set the creation/deletion cost fudge factor to `<percent>`.
+	Defaults to 60. Try a larger value if `git range-diff` erroneously
+	considers a large change a total rewrite (deletion of one commit
+	and addition of another), and a smaller one in the reverse case.
+	See the ``Algorithm`` section below for an explanation why this is
+	needed.
+
+--[no-]notes[=<ref>]::
+	This flag is passed to the `git log` program
+	(see linkgit:git-log[1]) that generates the patches.
+
+<range1> <range2>::
+	Compare the commits specified by the two ranges, where
+	`<range1>` is considered an older version of `<range2>`.
+
+<rev1>...<rev2>::
+	Equivalent to passing `<rev2>..<rev1>` and `<rev1>..<rev2>`.
+
+<base> <rev1> <rev2>::
+	Equivalent to passing `<base>..<rev1>` and `<base>..<rev2>`.
+	Note that `<base>` does not need to be the exact branch point
+	of the branches. Example: after rebasing a branch `my-topic`,
+	`git range-diff my-topic@{u} my-topic@{1} my-topic` would
+	show the differences introduced by the rebase.
+
+`git range-diff` also accepts the regular diff options (see
+linkgit:git-diff[1]), most notably the `--color=[<when>]` and
+`--no-color` options. These options are used when generating the "diff
+between patches", i.e. to compare the author, commit message and diff of
+corresponding old/new commits. There is currently no means to tweak most of the
+diff options passed to `git log` when generating those patches.
+
+OUTPUT STABILITY
+----------------
+
+The output of the `range-diff` command is subject to change. It is
+intended to be human-readable porcelain output, not something that can
+be used across versions of Git to get a textually stable `range-diff`
+(as opposed to something like the `--stable` option to
+linkgit:git-patch-id[1]). There's also no equivalent of
+linkgit:git-apply[1] for `range-diff`, the output is not intended to
+be machine-readable.
+
+This is particularly true when passing in diff options. Currently some
+options like `--stat` can, as an emergent effect, produce output
+that's quite useless in the context of `range-diff`. Future versions
+of `range-diff` may learn to interpret such options in a manner
+specific to `range-diff` (e.g. for `--stat` producing human-readable
+output which summarizes how the diffstat changed).
+
+CONFIGURATION
+-------------
+This command uses the `diff.color.*` and `pager.range-diff` settings
+(the latter is on by default).
+See linkgit:git-config[1].
+
+
+EXAMPLES
+--------
+
+When a rebase required merge conflicts to be resolved, compare the changes
+introduced by the rebase directly afterwards using:
+
+------------
+$ git range-diff @{u} @{1} @
+------------
+
+
+A typical output of `git range-diff` would look like this:
+
+------------
+-:  ------- > 1:  0ddba11 Prepare for the inevitable!
+1:  c0debee = 2:  cab005e Add a helpful message at the start
+2:  f00dbal ! 3:  decafe1 Describe a bug
+    @@ -1,3 +1,3 @@
+     Author: A U Thor <author@example.com>
+
+    -TODO: Describe a bug
+    +Describe a bug
+    @@ -324,5 +324,6
+      This is expected.
+
+    -+What is unexpected is that it will also crash.
+    ++Unexpectedly, it also crashes. This is a bug, and the jury is
+    ++still out there how to fix it best. See ticket #314 for details.
+
+      Contact
+3:  bedead < -:  ------- TO-UNDO
+------------
+
+In this example, there are 3 old and 3 new commits, where the developer
+removed the 3rd, added a new one before the first two, and modified the
+commit message of the 2nd commit as well its diff.
+
+When the output goes to a terminal, it is color-coded by default, just
+like regular `git diff`'s output. In addition, the first line (adding a
+commit) is green, the last line (deleting a commit) is red, the second
+line (with a perfect match) is yellow like the commit header of `git
+show`'s output, and the third line colors the old commit red, the new
+one green and the rest like `git show`'s commit header.
+
+A naive color-coded diff of diffs is actually a bit hard to read,
+though, as it colors the entire lines red or green. The line that added
+"What is unexpected" in the old commit, for example, is completely red,
+even if the intent of the old commit was to add something.
+
+To help with that, `range` uses the `--dual-color` mode by default. In
+this mode, the diff of diffs will retain the original diff colors, and
+prefix the lines with -/+ markers that have their *background* red or
+green, to make it more obvious that they describe how the diff itself
+changed.
+
+
+Algorithm
+---------
+
+The general idea is this: we generate a cost matrix between the commits
+in both commit ranges, then solve the least-cost assignment.
+
+The cost matrix is populated thusly: for each pair of commits, both
+diffs are generated and the "diff of diffs" is generated, with 3 context
+lines, then the number of lines in that diff is used as cost.
+
+To avoid false positives (e.g. when a patch has been removed, and an
+unrelated patch has been added between two iterations of the same patch
+series), the cost matrix is extended to allow for that, by adding
+fixed-cost entries for wholesale deletes/adds.
+
+Example: Let commits `1--2` be the first iteration of a patch series and
+`A--C` the second iteration. Let's assume that `A` is a cherry-pick of
+`2,` and `C` is a cherry-pick of `1` but with a small modification (say,
+a fixed typo). Visualize the commits as a bipartite graph:
+
+------------
+    1            A
+
+    2            B
+
+		 C
+------------
+
+We are looking for a "best" explanation of the new series in terms of
+the old one. We can represent an "explanation" as an edge in the graph:
+
+
+------------
+    1            A
+	       /
+    2 --------'  B
+
+		 C
+------------
+
+This explanation comes for "free" because there was no change. Similarly
+`C` could be explained using `1`, but that comes at some cost c>0
+because of the modification:
+
+------------
+    1 ----.      A
+	  |    /
+    2 ----+---'  B
+	  |
+	  `----- C
+	  c>0
+------------
+
+In mathematical terms, what we are looking for is some sort of a minimum
+cost bipartite matching; `1` is matched to `C` at some cost, etc. The
+underlying graph is in fact a complete bipartite graph; the cost we
+associate with every edge is the size of the diff between the two
+commits' patches. To explain also new commits, we introduce dummy nodes
+on both sides:
+
+------------
+    1 ----.      A
+	  |    /
+    2 ----+---'  B
+	  |
+    o     `----- C
+	  c>0
+    o            o
+
+    o            o
+------------
+
+The cost of an edge `o--C` is the size of `C`'s diff, modified by a
+fudge factor that should be smaller than 100%. The cost of an edge
+`o--o` is free. The fudge factor is necessary because even if `1` and
+`C` have nothing in common, they may still share a few empty lines and
+such, possibly making the assignment `1--C`, `o--o` slightly cheaper
+than `1--o`, `o--C` even if `1` and `C` have nothing in common. With the
+fudge factor we require a much larger common part to consider patches as
+corresponding.
+
+The overall time needed to compute this algorithm is the time needed to
+compute n+m commit diffs and then n*m diffs of patches, plus the time
+needed to compute the least-cost assignment between n and m diffs. Git
+uses an implementation of the Jonker-Volgenant algorithm to solve the
+assignment problem, which has cubic runtime complexity. The matching
+found in this case will look like this:
+
+------------
+    1 ----.      A
+	  |    /
+    2 ----+---'  B
+       .--+-----'
+    o -'  `----- C
+	  c>0
+    o ---------- o
+
+    o ---------- o
+------------
+
+
+SEE ALSO
+--------
+linkgit:git-log[1]
+
+GIT
+---
+Part of the linkgit:git[1] suite
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/git-read-tree.txt 1.2.3+git2.25.1-1/git/Documentation/git-read-tree.txt
--- 1.2.1+git2.18.0-1/git/Documentation/git-read-tree.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/git-read-tree.txt	2020-02-17 04:47:35.000000000 +0000
@@ -38,8 +38,9 @@ OPTIONS
 	started.
 
 --reset::
-        Same as -m, except that unmerged entries are discarded
-        instead of failing.
+	Same as -m, except that unmerged entries are discarded instead
+	of failing. When used with `-u`, updates leading to loss of
+	working tree changes will not abort the operation.
 
 -u::
 	After a successful merge, update the files in the work
@@ -128,6 +129,10 @@ OPTIONS
 	Instead of reading tree object(s) into the index, just empty
 	it.
 
+-q::
+--quiet::
+	Quiet, suppress feedback messages.
+
 <tree-ish#>::
 	The id of the tree object(s) to be read/merged.
 
@@ -431,7 +436,7 @@ support.
 SEE ALSO
 --------
 linkgit:git-write-tree[1]; linkgit:git-ls-files[1];
-linkgit:gitignore[5]
+linkgit:gitignore[5]; linkgit:git-sparse-checkout[1];
 
 GIT
 ---
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/git-rebase.txt 1.2.3+git2.25.1-1/git/Documentation/git-rebase.txt
--- 1.2.1+git2.18.0-1/git/Documentation/git-rebase.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/git-rebase.txt	2020-02-17 04:47:35.000000000 +0000
@@ -8,16 +8,16 @@ git-rebase - Reapply commits on top of a
 SYNOPSIS
 --------
 [verse]
-'git rebase' [-i | --interactive] [<options>] [--exec <cmd>] [--onto <newbase>]
-	[<upstream> [<branch>]]
+'git rebase' [-i | --interactive] [<options>] [--exec <cmd>]
+	[--onto <newbase> | --keep-base] [<upstream> [<branch>]]
 'git rebase' [-i | --interactive] [<options>] [--exec <cmd>] [--onto <newbase>]
 	--root [<branch>]
-'git rebase' --continue | --skip | --abort | --quit | --edit-todo | --show-current-patch
+'git rebase' (--continue | --skip | --abort | --quit | --edit-todo | --show-current-patch)
 
 DESCRIPTION
 -----------
 If <branch> is specified, 'git rebase' will perform an automatic
-`git checkout <branch>` before doing anything else.  Otherwise
+`git switch <branch>` before doing anything else.  Otherwise
 it remains on the current branch.
 
 If <upstream> is not specified, the upstream configured in
@@ -203,7 +203,7 @@ Alternatively, you can undo the 'git reb
 CONFIGURATION
 -------------
 
-include::rebase-config.txt[]
+include::config/rebase.txt[]
 
 OPTIONS
 -------
@@ -217,6 +217,24 @@ As a special case, you may use "A\...B"
 merge base of A and B if there is exactly one merge base. You can
 leave out at most one of A and B, in which case it defaults to HEAD.
 
+--keep-base::
+	Set the starting point at which to create the new commits to the
+	merge base of <upstream> <branch>. Running
+	'git rebase --keep-base <upstream> <branch>' is equivalent to
+	running 'git rebase --onto <upstream>... <upstream>'.
++
+This option is useful in the case where one is developing a feature on
+top of an upstream branch. While the feature is being worked on, the
+upstream branch may advance and it may not be the best idea to keep
+rebasing on top of the upstream but to keep the base commit as-is.
++
+Although both this option and --fork-point find the merge base between
+<upstream> and <branch>, this option uses the merge base as the _starting
+point_ on which new commits will be created, whereas --fork-point uses
+the merge base to determine the _set of commits_ which will be rebased.
++
+See also INCOMPATIBLE OPTIONS below.
+
 <upstream>::
 	Upstream branch to compare against.  May be any valid commit,
 	not just an existing branch name. Defaults to the configured
@@ -243,11 +261,15 @@ leave out at most one of A and B, in whi
 --keep-empty::
 	Keep the commits that do not change anything from its
 	parents in the result.
++
+See also INCOMPATIBLE OPTIONS below.
 
 --allow-empty-message::
 	By default, rebasing commits with an empty message will fail.
 	This option overrides that behavior, allowing commits with empty
 	messages to be rebased.
++
+See also INCOMPATIBLE OPTIONS below.
 
 --skip::
 	Restart the rebasing process by skipping the current patch.
@@ -271,6 +293,8 @@ branch on top of the <upstream> branch.
 conflict happens, the side reported as 'ours' is the so-far rebased
 series, starting with <upstream>, and 'theirs' is the working branch.  In
 other words, the sides are swapped.
++
+See also INCOMPATIBLE OPTIONS below.
 
 -s <strategy>::
 --strategy=<strategy>::
@@ -280,8 +304,10 @@ other words, the sides are swapped.
 +
 Because 'git rebase' replays each commit from the working branch
 on top of the <upstream> branch using the given strategy, using
-the 'ours' strategy simply discards all patches from the <branch>,
+the 'ours' strategy simply empties all patches from the <branch>,
 which makes little sense.
++
+See also INCOMPATIBLE OPTIONS below.
 
 -X <strategy-option>::
 --strategy-option=<strategy-option>::
@@ -289,6 +315,13 @@ which makes little sense.
 	This implies `--merge` and, if no strategy has been
 	specified, `-s recursive`.  Note the reversal of 'ours' and
 	'theirs' as noted above for the `-m` option.
++
+See also INCOMPATIBLE OPTIONS below.
+
+--rerere-autoupdate::
+--no-rerere-autoupdate::
+	Allow the rerere mechanism to update the index with the
+	result of auto-conflict resolution if possible.
 
 -S[<keyid>]::
 --gpg-sign[=<keyid>]::
@@ -324,17 +357,21 @@ which makes little sense.
 	and after each change.  When fewer lines of surrounding
 	context exist they all must match.  By default no context is
 	ever ignored.
++
+See also INCOMPATIBLE OPTIONS below.
 
--f::
+--no-ff::
 --force-rebase::
-	Force a rebase even if the current branch is up to date and
-	the command without `--force` would return without doing anything.
+-f::
+	Individually replay all rebased commits instead of fast-forwarding
+	over the unchanged ones.  This ensures that the entire history of
+	the rebased branch is composed of new commits.
 +
-You may find this (or --no-ff with an interactive rebase) helpful after
-reverting a topic branch merge, as this option recreates the topic branch with
-fresh commits so it can be remerged successfully without needing to "revert
-the reversion" (see the
-link:howto/revert-a-faulty-merge.html[revert-a-faulty-merge How-To] for details).
+You may find this helpful after reverting a topic branch merge, as this option
+recreates the topic branch with fresh commits so it can be remerged
+successfully without needing to "revert the reversion" (see the
+link:howto/revert-a-faulty-merge.html[revert-a-faulty-merge How-To] for
+details).
 
 --fork-point::
 --no-fork-point::
@@ -350,24 +387,31 @@ ends up being empty, the <upstream> will
 +
 If either <upstream> or --root is given on the command line, then the
 default is `--no-fork-point`, otherwise the default is `--fork-point`.
++
+If your branch was based on <upstream> but <upstream> was rewound and
+your branch contains commits which were dropped, this option can be used
+with `--keep-base` in order to drop those commits from your branch.
 
 --ignore-whitespace::
 --whitespace=<option>::
 	These flag are passed to the 'git apply' program
 	(see linkgit:git-apply[1]) that applies the patch.
-	Incompatible with the --interactive option.
++
+See also INCOMPATIBLE OPTIONS below.
 
 --committer-date-is-author-date::
 --ignore-date::
 	These flags are passed to 'git am' to easily change the dates
 	of the rebased commits (see linkgit:git-am[1]).
-	Incompatible with the --interactive option.
++
+See also INCOMPATIBLE OPTIONS below.
 
 --signoff::
 	Add a Signed-off-by: trailer to all the rebased commits. Note
 	that if `--interactive` is given then only commits marked to be
-	picked, edited or reworded will have the trailer added. Incompatible
-	with the `--preserve-merges` option.
+	picked, edited or reworded will have the trailer added.
++
+See also INCOMPATIBLE OPTIONS below.
 
 -i::
 --interactive::
@@ -378,6 +422,8 @@ default is `--no-fork-point`, otherwise
 The commit list format can be changed by setting the configuration option
 rebase.instructionFormat.  A customized instruction format will automatically
 have the long commit hash prepended to the format.
++
+See also INCOMPATIBLE OPTIONS below.
 
 -r::
 --rebase-merges[=(rebase-cousins|no-rebase-cousins)]::
@@ -391,36 +437,40 @@ have the long commit hash prepended to t
 +
 By default, or when `no-rebase-cousins` was specified, commits which do not
 have `<upstream>` as direct ancestor will keep their original branch point,
-i.e. commits that would be excluded by gitlink:git-log[1]'s
+i.e. commits that would be excluded by linkgit:git-log[1]'s
 `--ancestry-path` option will keep their original ancestry by default. If
 the `rebase-cousins` mode is turned on, such commits are instead rebased
 onto `<upstream>` (or `<onto>`, if specified).
 +
-The `--rebase-merges` mode is similar in spirit to `--preserve-merges`, but
-in contrast to that option works well in interactive rebases: commits can be
-reordered, inserted and dropped at will.
+The `--rebase-merges` mode is similar in spirit to the deprecated
+`--preserve-merges` but works with interactive rebases,
+where commits can be reordered, inserted and dropped at will.
 +
 It is currently only possible to recreate the merge commits using the
 `recursive` merge strategy; Different merge strategies can be used only via
 explicit `exec git merge -s <strategy> [...]` commands.
 +
-See also REBASING MERGES below.
+See also REBASING MERGES and INCOMPATIBLE OPTIONS below.
 
 -p::
 --preserve-merges::
-	Recreate merge commits instead of flattening the history by replaying
-	commits a merge commit introduces. Merge conflict resolutions or manual
-	amendments to merge commits are not preserved.
+	[DEPRECATED: use `--rebase-merges` instead] Recreate merge commits
+	instead of flattening the history by replaying commits a merge commit
+	introduces. Merge conflict resolutions or manual amendments to merge
+	commits are not preserved.
 +
 This uses the `--interactive` machinery internally, but combining it
 with the `--interactive` option explicitly is generally not a good
 idea unless you know what you are doing (see BUGS below).
++
+See also INCOMPATIBLE OPTIONS below.
 
 -x <cmd>::
 --exec <cmd>::
 	Append "exec <cmd>" after each line creating a commit in the
 	final history. <cmd> will be interpreted as one or more shell
-	commands.
+	commands. Any command that fails will interrupt the rebase,
+	with exit code 1.
 +
 You may execute several commands by either using one instance of `--exec`
 with several commands:
@@ -437,6 +487,8 @@ squash/fixup series.
 +
 This uses the `--interactive` machinery internally, but it can be run
 without an explicit `--interactive`.
++
+See also INCOMPATIBLE OPTIONS below.
 
 --root::
 	Rebase all commits reachable from <branch>, instead of
@@ -447,6 +499,8 @@ without an explicit `--interactive`.
 	When used together with both --onto and --preserve-merges,
 	'all' root commits will be rewritten to have <newbase> as parent
 	instead.
++
+See also INCOMPATIBLE OPTIONS below.
 
 --autosquash::
 --no-autosquash::
@@ -461,11 +515,11 @@ without an explicit `--interactive`.
 	too.  The recommended way to create fixup/squash commits is by using
 	the `--fixup`/`--squash` options of linkgit:git-commit[1].
 +
-This option is only valid when the `--interactive` option is used.
-+
 If the `--autosquash` option is enabled by default using the
 configuration variable `rebase.autoSquash`, this option can be
 used to override and disable this setting.
++
+See also INCOMPATIBLE OPTIONS below.
 
 --autostash::
 --no-autostash::
@@ -475,17 +529,69 @@ used to override and disable this settin
 	with care: the final stash application after a successful
 	rebase might result in non-trivial conflicts.
 
---no-ff::
-	With --interactive, cherry-pick all rebased commits instead of
-	fast-forwarding over the unchanged ones.  This ensures that the
-	entire history of the rebased branch is composed of new commits.
-+
-Without --interactive, this is a synonym for --force-rebase.
-+
-You may find this helpful after reverting a topic branch merge, as this option
-recreates the topic branch with fresh commits so it can be remerged
-successfully without needing to "revert the reversion" (see the
-link:howto/revert-a-faulty-merge.html[revert-a-faulty-merge How-To] for details).
+--reschedule-failed-exec::
+--no-reschedule-failed-exec::
+	Automatically reschedule `exec` commands that failed. This only makes
+	sense in interactive mode (or when an `--exec` option was provided).
+
+INCOMPATIBLE OPTIONS
+--------------------
+
+The following options:
+
+ * --committer-date-is-author-date
+ * --ignore-date
+ * --whitespace
+ * --ignore-whitespace
+ * -C
+
+are incompatible with the following options:
+
+ * --merge
+ * --strategy
+ * --strategy-option
+ * --allow-empty-message
+ * --[no-]autosquash
+ * --rebase-merges
+ * --preserve-merges
+ * --interactive
+ * --exec
+ * --keep-empty
+ * --edit-todo
+ * --root when used in combination with --onto
+
+In addition, the following pairs of options are incompatible:
+
+ * --preserve-merges and --interactive
+ * --preserve-merges and --signoff
+ * --preserve-merges and --rebase-merges
+ * --keep-base and --onto
+ * --keep-base and --root
+
+BEHAVIORAL DIFFERENCES
+-----------------------
+
+There are some subtle differences how the backends behave.
+
+Empty commits
+~~~~~~~~~~~~~
+
+The am backend drops any "empty" commits, regardless of whether the
+commit started empty (had no changes relative to its parent to
+start with) or ended empty (all changes were already applied
+upstream in other commits).
+
+The interactive backend drops commits by default that
+started empty and halts if it hits a commit that ended up empty.
+The `--keep-empty` option exists for the interactive backend to allow
+it to keep commits that started empty.
+
+Directory rename detection
+~~~~~~~~~~~~~~~~~~~~~~~~~~
+
+Directory rename heuristics are enabled in the merge and interactive
+backends.  Due to the lack of accurate tree information, directory
+rename detection is disabled in the am backend.
 
 include::merge-strategies.txt[]
 
@@ -560,6 +666,9 @@ By replacing the command "pick" with the
 the files and/or the commit message, amend the commit, and continue
 rebasing.
 
+To interrupt the rebase (just like an "edit" command would do, but without
+cherry-picking any commit first), use the "break" command.
+
 If you just want to edit the commit message for a commit, replace the
 command "pick" with the command "reword".
 
@@ -588,7 +697,8 @@ $ git rebase -i HEAD~5
 
 And move the first patch to the end of the list.
 
-You might want to preserve merges, if you have a history like this:
+You might want to recreate merge commits, e.g. if you have a history
+like this:
 
 ------------------
            X
@@ -602,7 +712,7 @@ Suppose you want to rebase the side bran
 sure that the current HEAD is "B", and call
 
 -----------------------------
-$ git rebase -i -p --onto Q O
+$ git rebase -i -r --onto Q O
 -----------------------------
 
 Reordering and editing commits usually creates untested intermediate
@@ -744,7 +854,8 @@ Hard case: The changes are not the same.
 	This happens if the 'subsystem' rebase had conflicts, or used
 	`--interactive` to omit, edit, squash, or fixup commits; or
 	if the upstream used one of `commit --amend`, `reset`, or
-	`filter-branch`.
+	a full history rewriting command like
+	https://github.com/newren/git-filter-repo[`filter-repo`].
 
 
 The easy case
@@ -782,7 +893,7 @@ NOTE: While an "easy case recovery" some
       --interactive` will be **resurrected**!
 
 The idea is to manually tell 'git rebase' "where the old 'subsystem'
-ended and your 'topic' began", that is, what the old merge-base
+ended and your 'topic' began", that is, what the old merge base
 between them was.  You will have to find a way to name the last commit
 of the old 'subsystem', for example:
 
@@ -804,7 +915,7 @@ The ripple effect of a "hard case" recov
 case" recovery too!
 
 REBASING MERGES
------------------
+---------------
 
 The interactive rebase command was originally designed to handle
 individual patch series. As such, it makes sense to exclude merge
@@ -873,14 +984,14 @@ command fails, it is rescheduled immedia
 to proceed.
 
 The `reset` command resets the HEAD, index and worktree to the specified
-revision. It is isimilar to an `exec git reset --hard <label>`, but
+revision. It is similar to an `exec git reset --hard <label>`, but
 refuses to overwrite untracked files. If the `reset` command fails, it is
 rescheduled immediately, with a helpful message how to edit the todo list
 (this typically happens when a `reset` command was inserted into the todo
 list manually and contains a typo).
 
-The `merge` command will merge the specified revision into whatever is
-HEAD at that time. With `-C <original-commit>`, the commit message of
+The `merge` command will merge the specified revision(s) into whatever
+is HEAD at that time. With `-C <original-commit>`, the commit message of
 the specified merge commit will be used. When the `-C` is changed to
 a lower-case `-c`, the message will be opened in an editor after a
 successful merge so that the user can edit the message.
@@ -889,7 +1000,8 @@ If a `merge` command fails for any reaso
 when the merge operation did not even start), it is rescheduled immediately.
 
 At this time, the `merge` command will *always* use the `recursive`
-merge strategy, with no way to choose a different one. To work around
+merge strategy for regular merges, and `octopus` for octopus merges,
+with no way to choose a different one. To work around
 this, an `exec` command can be used to call `git merge` explicitly,
 using the fact that the labels are worktree-local refs (the ref
 `refs/rewritten/onto` would correspond to the label `onto`, for example).
@@ -938,11 +1050,11 @@ merge cmake
 
 BUGS
 ----
-The todo list presented by `--preserve-merges --interactive` does not
-represent the topology of the revision graph.  Editing commits and
-rewording their commit messages should work fine, but attempts to
-reorder commits tend to produce counterintuitive results. Use
-`--rebase-merges` in such scenarios instead.
+The todo list presented by the deprecated `--preserve-merges --interactive`
+does not represent the topology of the revision graph (use `--rebase-merges`
+instead).  Editing commits and rewording their commit messages should work
+fine, but attempts to reorder commits tend to produce counterintuitive results.
+Use `--rebase-merges` in such scenarios instead.
 
 For example, an attempt to rearrange
 ------------
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/git-receive-pack.txt 1.2.3+git2.25.1-1/git/Documentation/git-receive-pack.txt
--- 1.2.1+git2.18.0-1/git/Documentation/git-receive-pack.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/git-receive-pack.txt	2020-02-17 04:47:35.000000000 +0000
@@ -165,29 +165,31 @@ ref listing the commits pushed to the re
 certificates of signed pushes with good signatures to a logger
 service:
 
-	#!/bin/sh
-	# mail out commit update information.
-	while read oval nval ref
-	do
-		if expr "$oval" : '0*$' >/dev/null
-		then
-			echo "Created a new ref, with the following commits:"
-			git rev-list --pretty "$nval"
-		else
-			echo "New commits:"
-			git rev-list --pretty "$nval" "^$oval"
-		fi |
-		mail -s "Changes to ref $ref" commit-list@mydomain
-	done
-	# log signed push certificate, if any
-	if test -n "${GIT_PUSH_CERT-}" && test ${GIT_PUSH_CERT_STATUS} = G
+----
+#!/bin/sh
+# mail out commit update information.
+while read oval nval ref
+do
+	if expr "$oval" : '0*$' >/dev/null
 	then
-		(
-			echo expected nonce is ${GIT_PUSH_NONCE}
-			git cat-file blob ${GIT_PUSH_CERT}
-		) | mail -s "push certificate from $GIT_PUSH_CERT_SIGNER" push-log@mydomain
-	fi
-	exit 0
+		echo "Created a new ref, with the following commits:"
+		git rev-list --pretty "$nval"
+	else
+		echo "New commits:"
+		git rev-list --pretty "$nval" "^$oval"
+	fi |
+	mail -s "Changes to ref $ref" commit-list@mydomain
+done
+# log signed push certificate, if any
+if test -n "${GIT_PUSH_CERT-}" && test ${GIT_PUSH_CERT_STATUS} = G
+then
+	(
+		echo expected nonce is ${GIT_PUSH_NONCE}
+		git cat-file blob ${GIT_PUSH_CERT}
+	) | mail -s "push certificate from $GIT_PUSH_CERT_SIGNER" push-log@mydomain
+fi
+exit 0
+----
 
 The exit code from this hook invocation is ignored, however a
 non-zero exit code will generate an error message.
@@ -212,8 +214,10 @@ anyway.
 This hook can be used, for example, to run `git update-server-info`
 if the repository is packed and is served via a dumb transport.
 
-	#!/bin/sh
-	exec git update-server-info
+----
+#!/bin/sh
+exec git update-server-info
+----
 
 
 QUARANTINE ENVIRONMENT
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/git-reflog.txt 1.2.3+git2.25.1-1/git/Documentation/git-reflog.txt
--- 1.2.1+git2.18.0-1/git/Documentation/git-reflog.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/git-reflog.txt	2020-02-17 04:47:35.000000000 +0000
@@ -20,7 +20,7 @@ depending on the subcommand:
 'git reflog' ['show'] [log-options] [<ref>]
 'git reflog expire' [--expire=<time>] [--expire-unreachable=<time>]
 	[--rewrite] [--updateref] [--stale-fix]
-	[--dry-run | -n] [--verbose] [--all | <refs>...]
+	[--dry-run | -n] [--verbose] [--all [--single-worktree] | <refs>...]
 'git reflog delete' [--rewrite] [--updateref]
 	[--dry-run | -n] [--verbose] ref@\{specifier\}...
 'git reflog exists' <ref>
@@ -72,6 +72,11 @@ Options for `expire`
 --all::
 	Process the reflogs of all references.
 
+--single-worktree::
+	By default when `--all` is specified, reflogs from all working
+	trees are processed. This option limits the processing to reflogs
+	from the current working tree only.
+
 --expire=<time>::
 	Prune entries older than the specified time. If this option is
 	not specified, the expiration time is taken from the
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/git-remote-ext.txt 1.2.3+git2.25.1-1/git/Documentation/git-remote-ext.txt
--- 1.2.1+git2.18.0-1/git/Documentation/git-remote-ext.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/git-remote-ext.txt	2020-02-17 04:47:35.000000000 +0000
@@ -104,7 +104,7 @@ begins with `ext::`.  Examples:
 	link-level address).
 
 "ext::git-server-alias foo %G/repo% with% spaces %Vfoo"::
-	Represents a repository with path '/repo with spaces' accessed
+	Represents a repository with path `/repo with spaces` accessed
 	using the helper program "git-server-alias foo".  The hostname for
 	the remote server passed in the protocol stream will be "foo"
 	(this allows multiple virtual Git servers to share a
@@ -118,7 +118,7 @@ begins with `ext::`.  Examples:
 
 SEE ALSO
 --------
-linkgit:gitremote-helpers[1]
+linkgit:gitremote-helpers[7]
 
 GIT
 ---
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/git-remote-fd.txt 1.2.3+git2.25.1-1/git/Documentation/git-remote-fd.txt
--- 1.2.1+git2.18.0-1/git/Documentation/git-remote-fd.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/git-remote-fd.txt	2020-02-17 04:47:35.000000000 +0000
@@ -52,7 +52,7 @@ EXAMPLES
 
 SEE ALSO
 --------
-linkgit:gitremote-helpers[1]
+linkgit:gitremote-helpers[7]
 
 GIT
 ---
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/gitremote-helpers.txt 1.2.3+git2.25.1-1/git/Documentation/gitremote-helpers.txt
--- 1.2.1+git2.18.0-1/git/Documentation/gitremote-helpers.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/gitremote-helpers.txt	2020-02-17 04:47:35.000000000 +0000
@@ -1,4 +1,4 @@
-gitremote-helpers(1)
+gitremote-helpers(7)
 ====================
 
 NAME
@@ -297,9 +297,13 @@ Supported if the helper has the "option"
 	same batch are complete. Only objects which were reported
 	in the output of 'list' with a sha1 may be fetched this way.
 +
-Optionally may output a 'lock <file>' line indicating a file under
-GIT_DIR/objects/pack which is keeping a pack until refs can be
-suitably updated.
+Optionally may output a 'lock <file>' line indicating the full path of
+a file under `$GIT_DIR/objects/pack` which is keeping a pack until
+refs can be suitably updated.  The path must end with `.keep`. This is
+a mechanism to name a <pack,idx,keep> tuple by giving only the keep
+component.  The kept pack will not be deleted by a concurrent repack,
+even though its objects may not be referenced until the fetch completes.
+The `.keep` file will be deleted at the conclusion of the fetch.
 +
 If option 'check-connectivity' is requested, the helper must output
 'connectivity-ok' if the clone is self-contained and connected.
@@ -468,7 +472,7 @@ set by Git if the remote helper has the
 
 'option dry-run' {'true'|'false'}:
 	If true, pretend the operation completed successfully,
-	but don't actually change any repository data.	For most
+	but don't actually change any repository data.  For most
 	helpers this only applies to the 'push', if supported.
 
 'option servpath <c-style-quoted-path>'::
@@ -505,6 +509,11 @@ set by Git if the remote helper has the
 	Indicate that only the objects wanted need to be fetched, not
 	their dependents.
 
+'option atomic' {'true'|'false'}::
+	When pushing, request the remote server to update refs in a single atomic
+	transaction.  If successful, all refs will be updated, or none will.  If the
+	remote side does not support this capability, the push will fail.
+
 SEE ALSO
 --------
 linkgit:git-remote[1]
@@ -513,8 +522,6 @@ linkgit:git-remote-ext[1]
 
 linkgit:git-remote-fd[1]
 
-linkgit:git-remote-testgit[1]
-
 linkgit:git-fast-import[1]
 
 GIT
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/git-remote-helpers.txto 1.2.3+git2.25.1-1/git/Documentation/git-remote-helpers.txto
--- 1.2.1+git2.18.0-1/git/Documentation/git-remote-helpers.txto	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/git-remote-helpers.txto	2020-02-17 04:47:35.000000000 +0000
@@ -1,7 +1,7 @@
 git-remote-helpers
 ==================
 
-This document has been moved to linkgit:gitremote-helpers[1].
+This document has been moved to linkgit:gitremote-helpers[7].
 
 Please let the owners of the referring site know so that they can update the
 link you clicked to get here.
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/git-remote-testgit.txt 1.2.3+git2.25.1-1/git/Documentation/git-remote-testgit.txt
--- 1.2.1+git2.18.0-1/git/Documentation/git-remote-testgit.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/git-remote-testgit.txt	1970-01-01 00:00:00.000000000 +0000
@@ -1,30 +0,0 @@
-git-remote-testgit(1)
-=====================
-
-NAME
-----
-git-remote-testgit - Example remote-helper
-
-
-SYNOPSIS
---------
-[verse]
-git clone testgit::<source-repo> [<destination>]
-
-DESCRIPTION
------------
-
-This command is a simple remote-helper, that is used both as a
-testcase for the remote-helper functionality, and as an example to
-show remote-helper authors one possible implementation.
-
-The best way to learn more is to read the comments and source code in
-'git-remote-testgit'.
-
-SEE ALSO
---------
-linkgit:gitremote-helpers[1]
-
-GIT
----
-Part of the linkgit:git[1] suite
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/git-remote.txt 1.2.3+git2.25.1-1/git/Documentation/git-remote.txt
--- 1.2.1+git2.18.0-1/git/Documentation/git-remote.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/git-remote.txt	2020-02-17 04:47:35.000000000 +0000
@@ -230,7 +230,7 @@ $ git branch -r
   staging/master
   staging/staging-linus
   staging/staging-next
-$ git checkout -b staging staging/master
+$ git switch -c staging staging/master
 ...
 ------------
 
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/git-repack.txt 1.2.3+git2.25.1-1/git/Documentation/git-repack.txt
--- 1.2.1+git2.18.0-1/git/Documentation/git-repack.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/git-repack.txt	2020-02-17 04:47:35.000000000 +0000
@@ -40,6 +40,11 @@ OPTIONS
 Note that users fetching over dumb protocols will have to fetch the
 whole new pack in order to get any contained object, no matter how many
 other objects in that pack they already have locally.
++
+Promisor packfiles are repacked separately: if there are packfiles that
+have an associated ".promisor" file, these packfiles will be repacked
+into another separate pack, and an empty ".promisor" file corresponding
+to the new separate pack will be written.
 
 -A::
 	Same as `-a`, unless `-d` is used.  Then any unreachable
@@ -137,7 +142,7 @@ depth is 4095.
 
 --keep-pack=<pack-name>::
 	Exclude the given pack from repacking. This is the equivalent
-	of having `.keep` file on the pack. `<pack-name>` is the the
+	of having `.keep` file on the pack. `<pack-name>` is the
 	pack file name without leading directory (e.g. `pack-123.pack`).
 	The option could be specified multiple times to keep multiple
 	packs.
@@ -155,6 +160,11 @@ depth is 4095.
 	being removed. In addition, any unreachable loose objects will
 	be packed (and their loose counterparts removed).
 
+-i::
+--delta-islands::
+	Pass the `--delta-islands` option to `git-pack-objects`, see
+	linkgit:git-pack-objects[1].
+
 Configuration
 -------------
 
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/git-replace.txt 1.2.3+git2.25.1-1/git/Documentation/git-replace.txt
--- 1.2.1+git2.18.0-1/git/Documentation/git-replace.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/git-replace.txt	2020-02-17 04:47:35.000000000 +0000
@@ -123,10 +123,10 @@ The following format are available:
 CREATING REPLACEMENT OBJECTS
 ----------------------------
 
-linkgit:git-filter-branch[1], linkgit:git-hash-object[1] and
-linkgit:git-rebase[1], among other git commands, can be used to create
-replacement objects from existing objects. The `--edit` option can
-also be used with 'git replace' to create a replacement object by
+linkgit:git-hash-object[1], linkgit:git-rebase[1], and
+https://github.com/newren/git-filter-repo[git-filter-repo], among other git commands, can be used to
+create replacement objects from existing objects. The `--edit` option
+can also be used with 'git replace' to create a replacement object by
 editing an existing object.
 
 If you want to replace many blobs, trees or commits that are part of a
@@ -148,13 +148,13 @@ pending objects.
 SEE ALSO
 --------
 linkgit:git-hash-object[1]
-linkgit:git-filter-branch[1]
 linkgit:git-rebase[1]
 linkgit:git-tag[1]
 linkgit:git-branch[1]
 linkgit:git-commit[1]
 linkgit:git-var[1]
 linkgit:git[1]
+https://github.com/newren/git-filter-repo[git-filter-repo]
 
 GIT
 ---
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/gitrepository-layout.txt 1.2.3+git2.25.1-1/git/Documentation/gitrepository-layout.txt
--- 1.2.1+git2.18.0-1/git/Documentation/gitrepository-layout.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/gitrepository-layout.txt	2020-02-17 04:47:35.000000000 +0000
@@ -59,7 +59,7 @@ objects/[0-9a-f][0-9a-f]::
 	here are often called 'unpacked' (or 'loose') objects.
 
 objects/pack::
-	Packs (files that store many object in compressed form,
+	Packs (files that store many objects in compressed form,
 	along with index files to allow them to be randomly
 	accessed) are found in this directory.
 
@@ -84,7 +84,7 @@ objects/info/alternates::
 	to the object database, not to the repository!) in your
 	alternates file, but it will not work if you use absolute
 	paths unless the absolute path in filesystem and web URL
-	is the same. See also 'objects/info/http-alternates'.
+	is the same. See also `objects/info/http-alternates`.
 
 objects/info/http-alternates::
 	This file records URLs to alternate object stores that
@@ -95,8 +95,10 @@ refs::
 	References are stored in subdirectories of this
 	directory.  The 'git prune' command knows to preserve
 	objects reachable from refs found in this directory and
-	its subdirectories. This directory is ignored if $GIT_COMMON_DIR
-	is set and "$GIT_COMMON_DIR/refs" will be used instead.
+	its subdirectories.
+	This directory is ignored (except refs/bisect,
+	refs/rewritten and refs/worktree) if $GIT_COMMON_DIR is
+	set and "$GIT_COMMON_DIR/refs" will be used instead.
 
 refs/heads/`name`::
 	records tip-of-the-tree commit objects of branch `name`
@@ -143,6 +145,11 @@ config::
 	if $GIT_COMMON_DIR is set and "$GIT_COMMON_DIR/config" will be
 	used instead.
 
+config.worktree::
+	Working directory specific configuration file for the main
+	working directory in multiple working directory setup (see
+	linkgit:git-worktree[1]).
+
 branches::
 	A slightly deprecated way to store shorthands to be used
 	to specify a URL to 'git fetch', 'git pull' and 'git push'.
@@ -165,6 +172,11 @@ hooks::
 	each hook. This directory is ignored if $GIT_COMMON_DIR is set
 	and "$GIT_COMMON_DIR/hooks" will be used instead.
 
+common::
+	When multiple working trees are used, most of files in
+	$GIT_DIR are per-worktree with a few known exceptions. All
+	files under 'common' however will be shared between all
+	working trees.
 
 index::
 	The current index file for the repository.  It is
@@ -228,8 +240,8 @@ remotes::
 logs::
 	Records of changes made to refs are stored in this directory.
 	See linkgit:git-update-ref[1] for more information. This
-	directory is ignored if $GIT_COMMON_DIR is set and
-	"$GIT_COMMON_DIR/logs" will be used instead.
+	directory is ignored (except logs/HEAD) if $GIT_COMMON_DIR is
+	set and "$GIT_COMMON_DIR/logs" will be used instead.
 
 logs/refs/heads/`name`::
 	Records all changes made to the branch tip named `name`.
@@ -275,6 +287,11 @@ worktrees/<id>/locked::
 	or manually by `git worktree prune`. The file may contain a string
 	explaining why the repository is locked.
 
+worktrees/<id>/config.worktree::
+	Working directory specific configuration file.
+
+include::technical/repository-version.txt[]
+
 SEE ALSO
 --------
 linkgit:git-init[1],
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/git-rerere.txt 1.2.3+git2.25.1-1/git/Documentation/git-rerere.txt
--- 1.2.1+git2.18.0-1/git/Documentation/git-rerere.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/git-rerere.txt	2020-02-17 04:47:35.000000000 +0000
@@ -24,7 +24,7 @@ on the initial manual merge, and applyin
 hand resolutions to their corresponding automerge results.
 
 [NOTE]
-You need to set the configuration variable rerere.enabled in order to
+You need to set the configuration variable `rerere.enabled` in order to
 enable this command.
 
 
@@ -91,7 +91,7 @@ For such a test, you need to merge maste
 One way to do it is to pull master into the topic branch:
 
 ------------
-	$ git checkout topic
+	$ git switch topic
 	$ git merge master
 
               o---*---o---+ topic
@@ -113,10 +113,10 @@ the upstream might have been advanced si
 in which case the final commit graph would look like this:
 
 ------------
-	$ git checkout topic
+	$ git switch topic
 	$ git merge master
 	$ ... work on both topic and master branches
-	$ git checkout master
+	$ git switch master
 	$ git merge topic
 
               o---*---o---+---o---o topic
@@ -136,11 +136,11 @@ merges, you could blow away the test mer
 top of the tip before the test merge:
 
 ------------
-	$ git checkout topic
+	$ git switch topic
 	$ git merge master
 	$ git reset --hard HEAD^ ;# rewind the test merge
 	$ ... work on both topic and master branches
-	$ git checkout master
+	$ git switch master
 	$ git merge topic
 
               o---*---o-------o---o topic
@@ -211,6 +211,12 @@ would conflict the same way as the test
 'git rerere' will be run by 'git rebase' to help you resolve this
 conflict.
 
+[NOTE] 'git rerere' relies on the conflict markers in the file to
+detect the conflict.  If the file already contains lines that look the
+same as lines with conflict markers, 'git rerere' may fail to record a
+conflict resolution.  To work around this, the `conflict-marker-size`
+setting in linkgit:gitattributes[5] can be used.
+
 GIT
 ---
 Part of the linkgit:git[1] suite
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/git-reset.txt 1.2.3+git2.25.1-1/git/Documentation/git-reset.txt
--- 1.2.1+git2.18.0-1/git/Documentation/git-reset.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/git-reset.txt	2020-02-17 04:47:35.000000000 +0000
@@ -8,35 +8,38 @@ git-reset - Reset current HEAD to the sp
 SYNOPSIS
 --------
 [verse]
-'git reset' [-q] [<tree-ish>] [--] <paths>...
-'git reset' (--patch | -p) [<tree-ish>] [--] [<paths>...]
+'git reset' [-q] [<tree-ish>] [--] <pathspec>...
+'git reset' [-q] [--pathspec-from-file=<file> [--pathspec-file-nul]] [<tree-ish>]
+'git reset' (--patch | -p) [<tree-ish>] [--] [<pathspec>...]
 'git reset' [--soft | --mixed [-N] | --hard | --merge | --keep] [-q] [<commit>]
 
 DESCRIPTION
 -----------
-In the first and second form, copy entries from <tree-ish> to the index.
-In the third form, set the current branch head (HEAD) to <commit>, optionally
-modifying index and working tree to match.  The <tree-ish>/<commit> defaults
-to HEAD in all forms.
-
-'git reset' [-q] [<tree-ish>] [--] <paths>...::
-	This form resets the index entries for all <paths> to their
-	state at <tree-ish>.  (It does not affect the working tree or
-	the current branch.)
-+
-This means that `git reset <paths>` is the opposite of `git add
-<paths>`.
-+
-After running `git reset <paths>` to update the index entry, you can
-use linkgit:git-checkout[1] to check the contents out of the index to
-the working tree.
-Alternatively, using linkgit:git-checkout[1] and specifying a commit, you
+In the first three forms, copy entries from `<tree-ish>` to the index.
+In the last form, set the current branch head (`HEAD`) to `<commit>`,
+optionally modifying index and working tree to match.
+The `<tree-ish>`/`<commit>` defaults to `HEAD` in all forms.
+
+'git reset' [-q] [<tree-ish>] [--] <pathspec>...::
+'git reset' [-q] [--pathspec-from-file=<file> [--pathspec-file-nul]] [<tree-ish>]::
+	These forms reset the index entries for all paths that match the
+	`<pathspec>` to their state at `<tree-ish>`.  (It does not affect
+	the working tree or the current branch.)
++
+This means that `git reset <pathspec>` is the opposite of `git add
+<pathspec>`. This command is equivalent to
+`git restore [--source=<tree-ish>] --staged <pathspec>...`.
++
+After running `git reset <pathspec>` to update the index entry, you can
+use linkgit:git-restore[1] to check the contents out of the index to
+the working tree. Alternatively, using linkgit:git-restore[1]
+and specifying a commit with `--source`, you
 can copy the contents of a path out of a commit to the index and to the
 working tree in one go.
 
-'git reset' (--patch | -p) [<tree-ish>] [--] [<paths>...]::
+'git reset' (--patch | -p) [<tree-ish>] [--] [<pathspec>...]::
 	Interactively select hunks in the difference between the index
-	and <tree-ish> (defaults to HEAD).  The chosen hunks are applied
+	and `<tree-ish>` (defaults to `HEAD`).  The chosen hunks are applied
 	in reverse to the index.
 +
 This means that `git reset -p` is the opposite of `git add -p`, i.e.
@@ -44,16 +47,16 @@ you can use it to selectively reset hunk
 section of linkgit:git-add[1] to learn how to operate the `--patch` mode.
 
 'git reset' [<mode>] [<commit>]::
-	This form resets the current branch head to <commit> and
-	possibly updates the index (resetting it to the tree of <commit>) and
-	the working tree depending on <mode>. If <mode> is omitted,
-	defaults to "--mixed". The <mode> must be one of the following:
+	This form resets the current branch head to `<commit>` and
+	possibly updates the index (resetting it to the tree of `<commit>`) and
+	the working tree depending on `<mode>`. If `<mode>` is omitted,
+	defaults to `--mixed`. The `<mode>` must be one of the following:
 +
 --
 --soft::
 	Does not touch the index file or the working tree at all (but
-	resets the head to <commit>, just like all modes do). This leaves
-	all your changed files "Changes to be committed", as 'git status'
+	resets the head to `<commit>`, just like all modes do). This leaves
+	all your changed files "Changes to be committed", as `git status`
 	would put it.
 
 --mixed::
@@ -66,28 +69,28 @@ linkgit:git-add[1]).
 
 --hard::
 	Resets the index and working tree. Any changes to tracked files in the
-	working tree since <commit> are discarded.
+	working tree since `<commit>` are discarded.
 
 --merge::
 	Resets the index and updates the files in the working tree that are
-	different between <commit> and HEAD, but keeps those which are
+	different between `<commit>` and `HEAD`, but keeps those which are
 	different between the index and working tree (i.e. which have changes
 	which have not been added).
-	If a file that is different between <commit> and the index has unstaged
-	changes, reset is aborted.
+	If a file that is different between `<commit>` and the index has
+	unstaged changes, reset is aborted.
 +
-In other words, --merge does something like a 'git read-tree -u -m <commit>',
+In other words, `--merge` does something like a `git read-tree -u -m <commit>`,
 but carries forward unmerged index entries.
 
 --keep::
 	Resets index entries and updates files in the working tree that are
-	different between <commit> and HEAD.
-	If a file that is different between <commit> and HEAD has local changes,
-	reset is aborted.
+	different between `<commit>` and `HEAD`.
+	If a file that is different between `<commit>` and `HEAD` has local
+	changes, reset is aborted.
 --
 
-If you want to undo a commit other than the latest on a branch,
-linkgit:git-revert[1] is your friend.
+See "Reset, restore and revert" in linkgit:git[1] for the differences
+between the three commands.
 
 
 OPTIONS
@@ -95,8 +98,31 @@ OPTIONS
 
 -q::
 --quiet::
-	Be quiet, only report errors.
+--no-quiet::
+	Be quiet, only report errors. The default behavior is set by the
+	`reset.quiet` config option. `--quiet` and `--no-quiet` will
+	override the default behavior.
+
+--pathspec-from-file=<file>::
+	Pathspec is passed in `<file>` instead of commandline args. If
+	`<file>` is exactly `-` then standard input is used. Pathspec
+	elements are separated by LF or CR/LF. Pathspec elements can be
+	quoted as explained for the configuration variable `core.quotePath`
+	(see linkgit:git-config[1]). See also `--pathspec-file-nul` and
+	global `--literal-pathspecs`.
+
+--pathspec-file-nul::
+	Only meaningful with `--pathspec-from-file`. Pathspec elements are
+	separated with NUL character and all other characters are taken
+	literally (including newlines and quotes).
 
+\--::
+	Do not interpret any more arguments as options.
+
+<pathspec>...::
+	Limits the paths affected by the operation.
++
+For more details, see the 'pathspec' entry in linkgit:gitglossary[7].
 
 EXAMPLES
 --------
@@ -112,17 +138,17 @@ $ git pull git://info.example.com/ nitfo
 ------------
 +
 <1> You are happily working on something, and find the changes
-in these files are in good order.  You do not want to see them
-when you run "git diff", because you plan to work on other files
-and changes with these files are distracting.
+    in these files are in good order.  You do not want to see them
+    when you run `git diff`, because you plan to work on other files
+    and changes with these files are distracting.
 <2> Somebody asks you to pull, and the changes sound worthy of merging.
 <3> However, you already dirtied the index (i.e. your index does
-not match the HEAD commit).  But you know the pull you are going
-to make does not affect frotz.c or filfre.c, so you revert the
-index changes for these two files.  Your changes in working tree
-remain there.
-<4> Then you can pull and merge, leaving frotz.c and filfre.c
-changes still in the working tree.
+    not match the `HEAD` commit).  But you know the pull you are going
+    to make does not affect `frotz.c` or `filfre.c`, so you revert the
+    index changes for these two files.  Your changes in working tree
+    remain there.
+<4> Then you can pull and merge, leaving `frotz.c` and `filfre.c`
+    changes still in the working tree.
 
 Undo a commit and redo::
 +
@@ -134,29 +160,29 @@ $ git commit -a -c ORIG_HEAD  <3>
 ------------
 +
 <1> This is most often done when you remembered what you
-just committed is incomplete, or you misspelled your commit
-message, or both.  Leaves working tree as it was before "reset".
+    just committed is incomplete, or you misspelled your commit
+    message, or both.  Leaves working tree as it was before "reset".
 <2> Make corrections to working tree files.
-<3> "reset" copies the old head to .git/ORIG_HEAD; redo the
-commit by starting with its log message.  If you do not need to
-edit the message further, you can give -C option instead.
+<3> "reset" copies the old head to `.git/ORIG_HEAD`; redo the
+    commit by starting with its log message.  If you do not need to
+    edit the message further, you can give `-C` option instead.
 +
-See also the --amend option to linkgit:git-commit[1].
+See also the `--amend` option to linkgit:git-commit[1].
 
 Undo a commit, making it a topic branch::
 +
 ------------
-$ git branch topic/wip     <1>
-$ git reset --hard HEAD~3  <2>
-$ git checkout topic/wip   <3>
+$ git branch topic/wip          <1>
+$ git reset --hard HEAD~3       <2>
+$ git switch topic/wip          <3>
 ------------
 +
 <1> You have made some commits, but realize they were premature
-to be in the "master" branch.  You want to continue polishing
-them in a topic branch, so create "topic/wip" branch off of the
-current HEAD.
+    to be in the `master` branch.  You want to continue polishing
+    them in a topic branch, so create `topic/wip` branch off of the
+    current `HEAD`.
 <2> Rewind the master branch to get rid of those three commits.
-<3> Switch to "topic/wip" branch and keep working.
+<3> Switch to `topic/wip` branch and keep working.
 
 Undo commits permanently::
 +
@@ -165,11 +191,11 @@ $ git commit ...
 $ git reset --hard HEAD~3   <1>
 ------------
 +
-<1> The last three commits (HEAD, HEAD^, and HEAD~2) were bad
-and you do not want to ever see them again.  Do *not* do this if
-you have already given these commits to somebody else.  (See the
-"RECOVERING FROM UPSTREAM REBASE" section in linkgit:git-rebase[1] for
-the implications of doing so.)
+<1> The last three commits (`HEAD`, `HEAD^`, and `HEAD~2`) were bad
+    and you do not want to ever see them again.  Do *not* do this if
+    you have already given these commits to somebody else.  (See the
+    "RECOVERING FROM UPSTREAM REBASE" section in linkgit:git-rebase[1]
+    for the implications of doing so.)
 
 Undo a merge or pull::
 +
@@ -186,18 +212,18 @@ $ git reset --hard ORIG_HEAD       <4>
 ------------
 +
 <1> Try to update from the upstream resulted in a lot of
-conflicts; you were not ready to spend a lot of time merging
-right now, so you decide to do that later.
-<2> "pull" has not made merge commit, so "git reset --hard"
-which is a synonym for "git reset --hard HEAD" clears the mess
-from the index file and the working tree.
+    conflicts; you were not ready to spend a lot of time merging
+    right now, so you decide to do that later.
+<2> "pull" has not made merge commit, so `git reset --hard`
+    which is a synonym for `git reset --hard HEAD` clears the mess
+    from the index file and the working tree.
 <3> Merge a topic branch into the current branch, which resulted
-in a fast-forward.
+    in a fast-forward.
 <4> But you decided that the topic branch is not ready for public
-consumption yet.  "pull" or "merge" always leaves the original
-tip of the current branch in ORIG_HEAD, so resetting hard to it
-brings your index file and the working tree back to that state,
-and resets the tip of the branch to that commit.
+    consumption yet.  "pull" or "merge" always leaves the original
+    tip of the current branch in `ORIG_HEAD`, so resetting hard to it
+    brings your index file and the working tree back to that state,
+    and resets the tip of the branch to that commit.
 
 Undo a merge or pull inside a dirty working tree::
 +
@@ -211,14 +237,14 @@ $ git reset --merge ORIG_HEAD      <2>
 ------------
 +
 <1> Even if you may have local modifications in your
-working tree, you can safely say "git pull" when you know
-that the change in the other branch does not overlap with
-them.
+    working tree, you can safely say `git pull` when you know
+    that the change in the other branch does not overlap with
+    them.
 <2> After inspecting the result of the merge, you may find
-that the change in the other branch is unsatisfactory.  Running
-"git reset --hard ORIG_HEAD" will let you go back to where you
-were, but it will discard your local changes, which you do not
-want.  "git reset --merge" keeps your local changes.
+    that the change in the other branch is unsatisfactory.  Running
+    `git reset --hard ORIG_HEAD` will let you go back to where you
+    were, but it will discard your local changes, which you do not
+    want.  `git reset --merge` keeps your local changes.
 
 
 Interrupted workflow::
@@ -229,13 +255,13 @@ working tree are not in any shape to be
 need to get to the other branch for a quick bugfix.
 +
 ------------
-$ git checkout feature ;# you were working in "feature" branch and
-$ work work work       ;# got interrupted
+$ git switch feature  ;# you were working in "feature" branch and
+$ work work work      ;# got interrupted
 $ git commit -a -m "snapshot WIP"                 <1>
-$ git checkout master
+$ git switch master
 $ fix fix fix
 $ git commit ;# commit with real log
-$ git checkout feature
+$ git switch feature
 $ git reset --soft HEAD^ ;# go back to WIP state  <2>
 $ git reset                                       <3>
 ------------
@@ -276,21 +302,21 @@ reset it while keeping the changes in yo
 +
 ------------
 $ git tag start
-$ git checkout -b branch1
+$ git switch -c branch1
 $ edit
 $ git commit ...                            <1>
 $ edit
-$ git checkout -b branch2                   <2>
+$ git switch -c branch2                     <2>
 $ git reset --keep start                    <3>
 ------------
 +
-<1> This commits your first edits in branch1.
+<1> This commits your first edits in `branch1`.
 <2> In the ideal world, you could have realized that the earlier
     commit did not belong to the new topic when you created and switched
-    to branch2 (i.e. "git checkout -b branch2 start"), but nobody is
+    to `branch2` (i.e. `git switch -c branch2 start`), but nobody is
     perfect.
-<3> But you can use "reset --keep" to remove the unwanted commit after
-    you switched to "branch2".
+<3> But you can use `reset --keep` to remove the unwanted commit after
+    you switched to `branch2`.
 
 Split a commit apart into a sequence of commits::
 +
@@ -314,26 +340,27 @@ $ git commit ...
 +
 <1> First, reset the history back one commit so that we remove the original
     commit, but leave the working tree with all the changes. The -N ensures
-    that any new files added with HEAD are still marked so that git add -p
+    that any new files added with `HEAD` are still marked so that `git add -p`
     will find them.
-<2> Next, we interactively select diff hunks to add using the git add -p
+<2> Next, we interactively select diff hunks to add using the `git add -p`
     facility. This will ask you about each diff hunk in sequence and you can
     use simple commands such as "yes, include this", "No don't include this"
     or even the very powerful "edit" facility.
 <3> Once satisfied with the hunks you want to include, you should verify what
-    has been prepared for the first commit by using git diff --cached. This
+    has been prepared for the first commit by using `git diff --cached`. This
     shows all the changes that have been moved into the index and are about
     to be committed.
-<4> Next, commit the changes stored in the index. The -c option specifies to
+<4> Next, commit the changes stored in the index. The `-c` option specifies to
     pre-populate the commit message from the original message that you started
-    with in the first commit. This is helpful to avoid retyping it. The HEAD@{1}
-    is a special notation for the commit that HEAD used to be at prior to the
-    original reset commit (1 change ago). See linkgit:git-reflog[1] for more
-    details. You may also use any other valid commit reference.
+    with in the first commit. This is helpful to avoid retyping it. The
+    `HEAD@{1}` is a special notation for the commit that `HEAD` used to be at
+    prior to the original reset commit (1 change ago).
+    See linkgit:git-reflog[1] for more details. You may also use any other
+    valid commit reference.
 <5> You can repeat steps 2-4 multiple times to break the original code into
     any number of commits.
 <6> Now you've split out many of the changes into their own commits, and might
-    no longer use the patch mode of git add, in order to select all remaining
+    no longer use the patch mode of `git add`, in order to select all remaining
     uncommitted changes.
 <7> Once again, check to verify that you've included what you want to. You may
     also wish to verify that git diff doesn't show any remaining changes to be
@@ -350,104 +377,120 @@ The tables below show what happens when
 git reset --option target
 ----------
 
-to reset the HEAD to another commit (`target`) with the different
+to reset the `HEAD` to another commit (`target`) with the different
 reset options depending on the state of the files.
 
-In these tables, A, B, C and D are some different states of a
+In these tables, `A`, `B`, `C` and `D` are some different states of a
 file. For example, the first line of the first table means that if a
-file is in state A in the working tree, in state B in the index, in
-state C in HEAD and in state D in the target, then "git reset --soft
-target" will leave the file in the working tree in state A and in the
-index in state B.  It resets (i.e. moves) the HEAD (i.e. the tip of
-the current branch, if you are on one) to "target" (which has the file
-in state D).
-
-      working index HEAD target         working index HEAD
-      ----------------------------------------------------
-       A       B     C    D     --soft   A       B     D
-				--mixed  A       D     D
-				--hard   D       D     D
-				--merge (disallowed)
-				--keep  (disallowed)
-
-      working index HEAD target         working index HEAD
-      ----------------------------------------------------
-       A       B     C    C     --soft   A       B     C
-				--mixed  A       C     C
-				--hard   C       C     C
-				--merge (disallowed)
-				--keep   A       C     C
-
-      working index HEAD target         working index HEAD
-      ----------------------------------------------------
-       B       B     C    D     --soft   B       B     D
-				--mixed  B       D     D
-				--hard   D       D     D
-				--merge  D       D     D
-				--keep  (disallowed)
-
-      working index HEAD target         working index HEAD
-      ----------------------------------------------------
-       B       B     C    C     --soft   B       B     C
-				--mixed  B       C     C
-				--hard   C       C     C
-				--merge  C       C     C
-				--keep   B       C     C
-
-      working index HEAD target         working index HEAD
-      ----------------------------------------------------
-       B       C     C    D     --soft   B       C     D
-				--mixed  B       D     D
-				--hard   D       D     D
-				--merge (disallowed)
-				--keep  (disallowed)
-
-      working index HEAD target         working index HEAD
-      ----------------------------------------------------
-       B       C     C    C     --soft   B       C     C
-				--mixed  B       C     C
-				--hard   C       C     C
-				--merge  B       C     C
-				--keep   B       C     C
+file is in state `A` in the working tree, in state `B` in the index, in
+state `C` in `HEAD` and in state `D` in the target, then `git reset --soft
+target` will leave the file in the working tree in state `A` and in the
+index in state `B`.  It resets (i.e. moves) the `HEAD` (i.e. the tip of
+the current branch, if you are on one) to `target` (which has the file
+in state `D`).
+
+....
+working index HEAD target         working index HEAD
+----------------------------------------------------
+ A       B     C    D     --soft   A       B     D
+			  --mixed  A       D     D
+			  --hard   D       D     D
+			  --merge (disallowed)
+			  --keep  (disallowed)
+....
+
+....
+working index HEAD target         working index HEAD
+----------------------------------------------------
+ A       B     C    C     --soft   A       B     C
+			  --mixed  A       C     C
+			  --hard   C       C     C
+			  --merge (disallowed)
+			  --keep   A       C     C
+....
+
+....
+working index HEAD target         working index HEAD
+----------------------------------------------------
+ B       B     C    D     --soft   B       B     D
+			  --mixed  B       D     D
+			  --hard   D       D     D
+			  --merge  D       D     D
+			  --keep  (disallowed)
+....
+
+....
+working index HEAD target         working index HEAD
+----------------------------------------------------
+ B       B     C    C     --soft   B       B     C
+			  --mixed  B       C     C
+			  --hard   C       C     C
+			  --merge  C       C     C
+			  --keep   B       C     C
+....
+
+....
+working index HEAD target         working index HEAD
+----------------------------------------------------
+ B       C     C    D     --soft   B       C     D
+			  --mixed  B       D     D
+			  --hard   D       D     D
+			  --merge (disallowed)
+			  --keep  (disallowed)
+....
+
+....
+working index HEAD target         working index HEAD
+----------------------------------------------------
+ B       C     C    C     --soft   B       C     C
+			  --mixed  B       C     C
+			  --hard   C       C     C
+			  --merge  B       C     C
+			  --keep   B       C     C
+....
 
-"reset --merge" is meant to be used when resetting out of a conflicted
+`reset --merge` is meant to be used when resetting out of a conflicted
 merge. Any mergy operation guarantees that the working tree file that is
-involved in the merge does not have local change wrt the index before
-it starts, and that it writes the result out to the working tree. So if
+involved in the merge does not have a local change with respect to the index
+before it starts, and that it writes the result out to the working tree. So if
 we see some difference between the index and the target and also
 between the index and the working tree, then it means that we are not
 resetting out from a state that a mergy operation left after failing
-with a conflict. That is why we disallow --merge option in this case.
+with a conflict. That is why we disallow `--merge` option in this case.
 
-"reset --keep" is meant to be used when removing some of the last
+`reset --keep` is meant to be used when removing some of the last
 commits in the current branch while keeping changes in the working
 tree. If there could be conflicts between the changes in the commit we
 want to remove and the changes in the working tree we want to keep,
 the reset is disallowed. That's why it is disallowed if there are both
-changes between the working tree and HEAD, and between HEAD and the
+changes between the working tree and `HEAD`, and between `HEAD` and the
 target. To be safe, it is also disallowed when there are unmerged
 entries.
 
 The following tables show what happens when there are unmerged
 entries:
 
-      working index HEAD target         working index HEAD
-      ----------------------------------------------------
-       X       U     A    B     --soft  (disallowed)
-				--mixed  X       B     B
-				--hard   B       B     B
-				--merge  B       B     B
-				--keep  (disallowed)
-
-      working index HEAD target         working index HEAD
-      ----------------------------------------------------
-       X       U     A    A     --soft  (disallowed)
-				--mixed  X       A     A
-				--hard   A       A     A
-				--merge  A       A     A
-				--keep  (disallowed)
+....
+working index HEAD target         working index HEAD
+----------------------------------------------------
+ X       U     A    B     --soft  (disallowed)
+			  --mixed  X       B     B
+			  --hard   B       B     B
+			  --merge  B       B     B
+			  --keep  (disallowed)
+....
+
+....
+working index HEAD target         working index HEAD
+----------------------------------------------------
+ X       U     A    A     --soft  (disallowed)
+			  --mixed  X       A     A
+			  --hard   A       A     A
+			  --merge  A       A     A
+			  --keep  (disallowed)
+....
 
-X means any state and U means an unmerged index.
+`X` means any state and `U` means an unmerged index.
 
 GIT
 ---
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/git-restore.txt 1.2.3+git2.25.1-1/git/Documentation/git-restore.txt
--- 1.2.1+git2.18.0-1/git/Documentation/git-restore.txt	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/git-restore.txt	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,207 @@
+git-restore(1)
+==============
+
+NAME
+----
+git-restore - Restore working tree files
+
+SYNOPSIS
+--------
+[verse]
+'git restore' [<options>] [--source=<tree>] [--staged] [--worktree] [--] <pathspec>...
+'git restore' [<options>] [--source=<tree>] [--staged] [--worktree] --pathspec-from-file=<file> [--pathspec-file-nul]
+'git restore' (-p|--patch) [<options>] [--source=<tree>] [--staged] [--worktree] [--] [<pathspec>...]
+
+DESCRIPTION
+-----------
+Restore specified paths in the working tree with some contents from a
+restore source. If a path is tracked but does not exist in the restore
+source, it will be removed to match the source.
+
+The command can also be used to restore the content in the index with
+`--staged`, or restore both the working tree and the index with
+`--staged --worktree`.
+
+By default, the restore sources for working tree and the index are the
+index and `HEAD` respectively. `--source` could be used to specify a
+commit as the restore source.
+
+See "Reset, restore and revert" in linkgit:git[1] for the differences
+between the three commands.
+
+THIS COMMAND IS EXPERIMENTAL. THE BEHAVIOR MAY CHANGE.
+
+OPTIONS
+-------
+-s <tree>::
+--source=<tree>::
+	Restore the working tree files with the content from the given
+	tree. It is common to specify the source tree by naming a
+	commit, branch or tag associated with it.
++
+If not specified, the default restore source for the working tree is
+the index, and the default restore source for the index is
+`HEAD`. When both `--staged` and `--worktree` are specified,
+`--source` must also be specified.
+
+-p::
+--patch::
+	Interactively select hunks in the difference between the
+	restore source and the restore location. See the ``Interactive
+	Mode'' section of linkgit:git-add[1] to learn how to operate
+	the `--patch` mode.
++
+Note that `--patch` can accept no pathspec and will prompt to restore
+all modified paths.
+
+-W::
+--worktree::
+-S::
+--staged::
+	Specify the restore location. If neither option is specified,
+	by default the working tree is restored. Specifying `--staged`
+	will only restore the index. Specifying both restores both.
+
+-q::
+--quiet::
+	Quiet, suppress feedback messages. Implies `--no-progress`.
+
+--progress::
+--no-progress::
+	Progress status is reported on the standard error stream
+	by default when it is attached to a terminal, unless `--quiet`
+	is specified. This flag enables progress reporting even if not
+	attached to a terminal, regardless of `--quiet`.
+
+--ours::
+--theirs::
+	When restoring files in the working tree from the index, use
+	stage #2 ('ours') or #3 ('theirs') for unmerged paths.
++
+Note that during `git rebase` and `git pull --rebase`, 'ours' and
+'theirs' may appear swapped. See the explanation of the same options
+in linkgit:git-checkout[1] for details.
+
+-m::
+--merge::
+	When restoring files on the working tree from the index,
+	recreate the conflicted merge in the unmerged paths.
+
+--conflict=<style>::
+	The same as `--merge` option above, but changes the way the
+	conflicting hunks are presented, overriding the
+	`merge.conflictStyle` configuration variable.  Possible values
+	are "merge" (default) and "diff3" (in addition to what is
+	shown by "merge" style, shows the original contents).
+
+--ignore-unmerged::
+	When restoring files on the working tree from the index, do
+	not abort the operation if there are unmerged entries and
+	neither `--ours`, `--theirs`, `--merge` or `--conflict` is
+	specified. Unmerged paths on the working tree are left alone.
+
+--ignore-skip-worktree-bits::
+	In sparse checkout mode, by default is to only update entries
+	matched by `<pathspec>` and sparse patterns in
+	$GIT_DIR/info/sparse-checkout. This option ignores the sparse
+	patterns and unconditionally restores any files in
+	`<pathspec>`.
+
+--overlay::
+--no-overlay::
+	In overlay mode, the command never removes files when
+	restoring. In no-overlay mode, tracked files that do not
+	appear in the `--source` tree are removed, to make them match
+	`<tree>` exactly. The default is no-overlay mode.
+
+--pathspec-from-file=<file>::
+	Pathspec is passed in `<file>` instead of commandline args. If
+	`<file>` is exactly `-` then standard input is used. Pathspec
+	elements are separated by LF or CR/LF. Pathspec elements can be
+	quoted as explained for the configuration variable `core.quotePath`
+	(see linkgit:git-config[1]). See also `--pathspec-file-nul` and
+	global `--literal-pathspecs`.
+
+--pathspec-file-nul::
+	Only meaningful with `--pathspec-from-file`. Pathspec elements are
+	separated with NUL character and all other characters are taken
+	literally (including newlines and quotes).
+
+\--::
+	Do not interpret any more arguments as options.
+
+<pathspec>...::
+	Limits the paths affected by the operation.
++
+For more details, see the 'pathspec' entry in linkgit:gitglossary[7].
+
+EXAMPLES
+--------
+
+The following sequence switches to the `master` branch, reverts the
+`Makefile` to two revisions back, deletes hello.c by mistake, and gets
+it back from the index.
+
+------------
+$ git switch master
+$ git restore --source master~2 Makefile  <1>
+$ rm -f hello.c
+$ git restore hello.c                     <2>
+------------
+
+<1> take a file out of another commit
+<2> restore hello.c from the index
+
+If you want to restore _all_ C source files to match the version in
+the index, you can say
+
+------------
+$ git restore '*.c'
+------------
+
+Note the quotes around `*.c`.  The file `hello.c` will also be
+restored, even though it is no longer in the working tree, because the
+file globbing is used to match entries in the index (not in the
+working tree by the shell).
+
+To restore all files in the current directory
+
+------------
+$ git restore .
+------------
+
+or to restore all working tree files with 'top' pathspec magic (see
+linkgit:gitglossary[7])
+
+------------
+$ git restore :/
+------------
+
+To restore a file in the index to match the version in `HEAD` (this is
+the same as using linkgit:git-reset[1])
+
+------------
+$ git restore --staged hello.c
+------------
+
+or you can restore both the index and the working tree (this the same
+as using linkgit:git-checkout[1])
+
+------------
+$ git restore --source=HEAD --staged --worktree hello.c
+------------
+
+or the short form which is more practical but less readable:
+
+------------
+$ git restore -s@ -SW hello.c
+------------
+
+SEE ALSO
+--------
+linkgit:git-checkout[1],
+linkgit:git-reset[1]
+
+GIT
+---
+Part of the linkgit:git[1] suite
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/git-revert.txt 1.2.3+git2.25.1-1/git/Documentation/git-revert.txt
--- 1.2.1+git2.18.0-1/git/Documentation/git-revert.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/git-revert.txt	2020-02-17 04:47:35.000000000 +0000
@@ -9,9 +9,7 @@ SYNOPSIS
 --------
 [verse]
 'git revert' [--[no-]edit] [-n] [-m parent-number] [-s] [-S[<keyid>]] <commit>...
-'git revert' --continue
-'git revert' --quit
-'git revert' --abort
+'git revert' (--continue | --skip | --abort | --quit)
 
 DESCRIPTION
 -----------
@@ -26,10 +24,13 @@ effect of some earlier commits (often on
 throw away all uncommitted changes in your working directory, you
 should see linkgit:git-reset[1], particularly the `--hard` option.  If
 you want to extract specific files as they were in another commit, you
-should see linkgit:git-checkout[1], specifically the `git checkout
-<commit> -- <filename>` syntax.  Take care with these alternatives as
+should see linkgit:git-restore[1], specifically the `--source`
+option. Take care with these alternatives as
 both will discard uncommitted changes in your working directory.
 
+See "Reset, restore and revert" in linkgit:git[1] for the differences
+between the three commands.
+
 OPTIONS
 -------
 <commit>...::
@@ -66,6 +67,13 @@ more details.
 	With this option, 'git revert' will not start the commit
 	message editor.
 
+--cleanup=<mode>::
+	This option determines how the commit message will be cleaned up before
+	being passed on to the commit machinery. See linkgit:git-commit[1] for more
+	details. In particular, if the '<mode>' is given a value of `scissors`,
+	scissors will be appended to `MERGE_MSG` before being passed on in the case
+	of a conflict.
+
 -n::
 --no-commit::
 	Usually the command automatically creates some commits with
@@ -101,6 +109,11 @@ effect to your index in a row.
 	Pass the merge strategy-specific option through to the
 	merge strategy.  See linkgit:git-merge[1] for details.
 
+--rerere-autoupdate::
+--no-rerere-autoupdate::
+	Allow the rerere mechanism to update the index with the
+	result of auto-conflict resolution if possible.
+
 SEQUENCER SUBCOMMANDS
 ---------------------
 include::sequencer.txt[]
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/gitrevisions.txt 1.2.3+git2.25.1-1/git/Documentation/gitrevisions.txt
--- 1.2.1+git2.18.0-1/git/Documentation/gitrevisions.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/gitrevisions.txt	2020-02-17 04:47:35.000000000 +0000
@@ -19,9 +19,10 @@ walk the revision graph (such as linkgit
 reachable from that commit. For commands that walk the revision graph one can
 also specify a range of revisions explicitly.
 
-In addition, some Git commands (such as linkgit:git-show[1]) also take
-revision parameters which denote other objects than commits, e.g. blobs
-("files") or trees ("directories of files").
+In addition, some Git commands (such as linkgit:git-show[1] and
+linkgit:git-push[1]) can also take revision parameters which denote
+other objects than commits, e.g. blobs ("files") or trees
+("directories of files").
 
 include::revisions.txt[]
 
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/git-rev-list.txt 1.2.3+git2.25.1-1/git/Documentation/git-rev-list.txt
--- 1.2.1+git2.18.0-1/git/Documentation/git-rev-list.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/git-rev-list.txt	2020-02-17 04:47:35.000000000 +0000
@@ -9,58 +9,7 @@ git-rev-list - Lists commit objects in r
 SYNOPSIS
 --------
 [verse]
-'git rev-list' [ --max-count=<number> ]
-	     [ --skip=<number> ]
-	     [ --max-age=<timestamp> ]
-	     [ --min-age=<timestamp> ]
-	     [ --sparse ]
-	     [ --merges ]
-	     [ --no-merges ]
-	     [ --min-parents=<number> ]
-	     [ --no-min-parents ]
-	     [ --max-parents=<number> ]
-	     [ --no-max-parents ]
-	     [ --first-parent ]
-	     [ --remove-empty ]
-	     [ --full-history ]
-	     [ --not ]
-	     [ --all ]
-	     [ --branches[=<pattern>] ]
-	     [ --tags[=<pattern>] ]
-	     [ --remotes[=<pattern>] ]
-	     [ --glob=<glob-pattern> ]
-	     [ --ignore-missing ]
-	     [ --stdin ]
-	     [ --quiet ]
-	     [ --topo-order ]
-	     [ --parents ]
-	     [ --timestamp ]
-	     [ --left-right ]
-	     [ --left-only ]
-	     [ --right-only ]
-	     [ --cherry-mark ]
-	     [ --cherry-pick ]
-	     [ --encoding=<encoding> ]
-	     [ --(author|committer|grep)=<pattern> ]
-	     [ --regexp-ignore-case | -i ]
-	     [ --extended-regexp | -E ]
-	     [ --fixed-strings | -F ]
-	     [ --date=<format>]
-	     [ [ --objects | --objects-edge | --objects-edge-aggressive ]
-	       [ --unpacked ]
-	       [ --filter=<filter-spec> [ --filter-print-omitted ] ] ]
-	     [ --missing=<missing-action> ]
-	     [ --pretty | --header ]
-	     [ --bisect ]
-	     [ --bisect-vars ]
-	     [ --bisect-all ]
-	     [ --merge ]
-	     [ --reverse ]
-	     [ --walk-reflogs ]
-	     [ --no-walk ] [ --do-walk ]
-	     [ --count ]
-	     [ --use-bitmap-index ]
-	     <commit>... [ \-- <paths>... ]
+'git rev-list' [<options>] <commit>... [[--] <path>...]
 
 DESCRIPTION
 -----------
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/git-rev-parse.txt 1.2.3+git2.25.1-1/git/Documentation/git-rev-parse.txt
--- 1.2.1+git2.18.0-1/git/Documentation/git-rev-parse.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/git-rev-parse.txt	2020-02-17 04:47:35.000000000 +0000
@@ -262,7 +262,8 @@ print a message to stderr and exit with
 	directory.
 
 --show-toplevel::
-	Show the absolute path of the top-level directory.
+	Show the absolute path of the top-level directory of the working
+	tree. If there is no working tree, report an error.
 
 --show-superproject-working-tree::
 	Show the absolute path of the root of the superproject's
@@ -274,6 +275,13 @@ print a message to stderr and exit with
 	Show the path to the shared index file in split index mode, or
 	empty if not in split-index mode.
 
+--show-object-format[=(storage|input|output)]::
+	Show the object format (hash algorithm) used for the repository
+	for storage inside the `.git` directory, input, or output. For
+	input, multiple algorithms may be printed, space-separated.
+	If not specified, the default is "storage".
+
+
 Other Options
 ~~~~~~~~~~~~~
 
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/git-send-email.txt 1.2.3+git2.25.1-1/git/Documentation/git-send-email.txt
--- 1.2.1+git2.18.0-1/git/Documentation/git-send-email.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/git-send-email.txt	2020-02-17 04:47:35.000000000 +0000
@@ -33,7 +33,7 @@ This is what linkgit:git-format-patch[1]
 formatting are ignored.
 
 2. The original format used by Greg Kroah-Hartman's 'send_lots_of_email.pl'
-script
+   script
 +
 This format expects the first line of the file to contain the "Cc:" value
 and the "Subject:" of the message as the second line.
@@ -137,15 +137,17 @@ Note that no attempts whatsoever are mad
 	Specify encoding of compose message. Default is the value of the
 	'sendemail.composeencoding'; if that is unspecified, UTF-8 is assumed.
 
---transfer-encoding=(7bit|8bit|quoted-printable|base64)::
+--transfer-encoding=(7bit|8bit|quoted-printable|base64|auto)::
 	Specify the transfer encoding to be used to send the message over SMTP.
 	7bit will fail upon encountering a non-ASCII message.  quoted-printable
 	can be useful when the repository contains files that contain carriage
 	returns, but makes the raw patch email file (as saved from a MUA) much
 	harder to inspect manually.  base64 is even more fool proof, but also
-	even more opaque.  Default is the value of the `sendemail.transferEncoding`
-	configuration value; if that is unspecified, git will use 8bit and not
-	add a Content-Transfer-Encoding header.
+	even more opaque.  auto will use 8bit when possible, and quoted-printable
+	otherwise.
++
+Default is the value of the `sendemail.transferEncoding` configuration
+value; if that is unspecified, default to `auto`.
 
 --xmailer::
 --no-xmailer::
@@ -188,7 +190,9 @@ $ git send-email --smtp-auth="PLAIN LOGI
 If at least one of the specified mechanisms matches the ones advertised by the
 SMTP server and if it is supported by the utilized SASL library, the mechanism
 is used for authentication. If neither 'sendemail.smtpAuth' nor `--smtp-auth`
-is specified, all mechanisms supported by the SASL library can be used.
+is specified, all mechanisms supported by the SASL library can be used. The
+special value 'none' maybe specified to completely disable authentication
+independently of `--smtp-user`
 
 --smtp-pass[=<password>]::
 	Password for SMTP-AUTH. The argument is optional: If no
@@ -202,6 +206,9 @@ or on the command line. If a username ha
 specified (with `--smtp-pass` or `sendemail.smtpPass`), then
 a password is obtained using 'git-credential'.
 
+--no-smtp-auth::
+	Disable SMTP authentication. Short hand for `--smtp-auth=none`
+
 --smtp-server=<host>::
 	If set, specifies the outgoing SMTP server to use (e.g.
 	`smtp.example.com` or a raw IP address).  Alternatively it can
@@ -271,6 +278,14 @@ must be used for each option.
 Automating
 ~~~~~~~~~~
 
+--no-[to|cc|bcc]::
+	Clears any list of "To:", "Cc:", "Bcc:" addresses previously
+	set via config.
+
+--no-identity::
+	Clears the previously read value of `sendemail.identity` set
+	via config, if any.
+
 --to-cmd=<command>::
 	Specify a command to execute once per patch file which
 	should generate patch file specific "To:" entries.
@@ -319,16 +334,19 @@ Automating
 	auto-cc of:
 +
 --
-- 'author' will avoid including the patch author
-- 'self' will avoid including the sender
+- 'author' will avoid including the patch author.
+- 'self' will avoid including the sender.
 - 'cc' will avoid including anyone mentioned in Cc lines in the patch header
   except for self (use 'self' for that).
 - 'bodycc' will avoid including anyone mentioned in Cc lines in the
   patch body (commit message) except for self (use 'self' for that).
 - 'sob' will avoid including anyone mentioned in Signed-off-by lines except
-   for self (use 'self' for that).
+  for self (use 'self' for that).
+- 'misc-by' will avoid including anyone mentioned in Acked-by,
+  Reviewed-by, Tested-by and other "-by" lines in the patch body,
+  except Signed-off-by (use 'sob' for that).
 - 'cccmd' will avoid running the --cc-cmd.
-- 'body' is equivalent to 'sob' + 'bodycc'
+- 'body' is equivalent to 'sob' + 'bodycc' + 'misc-by'.
 - 'all' will suppress all auto cc values.
 --
 +
@@ -398,8 +416,11 @@ have been specified, in which case defau
 +
 --
 		*	Invoke the sendemail-validate hook if present (see linkgit:githooks[5]).
-		*	Warn of patches that contain lines longer than 998 characters; this
-			is due to SMTP limits as described by http://www.ietf.org/rfc/rfc2821.txt.
+		*	Warn of patches that contain lines longer than
+			998 characters unless a suitable transfer encoding
+			('auto', 'base64', or 'quoted-printable') is used;
+			this is due to SMTP limits as described by
+			http://www.ietf.org/rfc/rfc5322.txt.
 --
 +
 Default is the value of `sendemail.validate`; if this is not set,
@@ -465,11 +486,13 @@ Use gmail as the smtp server
 To use 'git send-email' to send your patches through the GMail SMTP server,
 edit ~/.gitconfig to specify your account settings:
 
-	[sendemail]
-		smtpEncryption = tls
-		smtpServer = smtp.gmail.com
-		smtpUser = yourname@gmail.com
-		smtpServerPort = 587
+----
+[sendemail]
+	smtpEncryption = tls
+	smtpServer = smtp.gmail.com
+	smtpUser = yourname@gmail.com
+	smtpServerPort = 587
+----
 
 If you have multifactor authentication setup on your gmail account, you will
 need to generate an app-specific password for use with 'git send-email'. Visit
@@ -487,8 +510,12 @@ app-specific or your regular password as
 helper configured (see linkgit:git-credential[1]), the password will be saved in
 the credential store so you won't have to type it the next time.
 
-Note: the following perl modules are required
-      Net::SMTP::SSL, MIME::Base64 and Authen::SASL
+Note: the following core Perl modules that may be installed with your
+distribution of Perl are required:
+MIME::Base64, MIME::QuotedPrint, Net::Domain and Net::SMTP.
+These additional Perl modules are also required:
+Authen::SASL and Mail::Address.
+
 
 SEE ALSO
 --------
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/git-shortlog.txt 1.2.3+git2.25.1-1/git/Documentation/git-shortlog.txt
--- 1.2.1+git2.18.0-1/git/Documentation/git-shortlog.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/git-shortlog.txt	2020-02-17 04:47:35.000000000 +0000
@@ -76,6 +76,9 @@ them.
 Paths may need to be prefixed with `--` to separate them from
 options or the revision range, when confusion arises.
 
+:git-shortlog: 1
+include::rev-list-options.txt[]
+
 MAPPING AUTHORS
 ---------------
 
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/git-show-branch.txt 1.2.3+git2.25.1-1/git/Documentation/git-show-branch.txt
--- 1.2.1+git2.18.0-1/git/Documentation/git-show-branch.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/git-show-branch.txt	2020-02-17 04:47:35.000000000 +0000
@@ -19,7 +19,7 @@ DESCRIPTION
 -----------
 
 Shows the commit ancestry graph starting from the commits named
-with <rev>s or <globs>s (or all refs under refs/heads
+with <rev>s or <glob>s (or all refs under refs/heads
 and/or refs/tags) semi-visually.
 
 It cannot show more than 29 branches and commits at a time.
@@ -167,7 +167,7 @@ $ git show-branch master fixes mhf
 ------------------------------------------------
 
 These three branches all forked from a common commit, [master],
-whose commit message is "Add {apostrophe}git show-branch{apostrophe}".
+whose commit message is "Add \'git show-branch'".
 The "fixes" branch adds one commit "Introduce "reset type" flag to
 "git reset"". The "mhf" branch adds many other commits.
 The current branch is "master".
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/git-show-index.txt 1.2.3+git2.25.1-1/git/Documentation/git-show-index.txt
--- 1.2.1+git2.18.0-1/git/Documentation/git-show-index.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/git-show-index.txt	2020-02-17 04:47:35.000000000 +0000
@@ -14,13 +14,27 @@ SYNOPSIS
 
 DESCRIPTION
 -----------
-Read the idx file for a Git packfile created with
-'git pack-objects' command from the standard input, and
-dump its contents.
-
-The information it outputs is subset of what you can get from
-'git verify-pack -v'; this command only shows the packfile
-offset and SHA-1 of each object.
+Read the `.idx` file for a Git packfile (created with
+linkgit:git-pack-objects[1] or linkgit:git-index-pack[1]) from the
+standard input, and dump its contents. The output consists of one object
+per line, with each line containing two or three space-separated
+columns:
+
+  - the first column is the offset in bytes of the object within the
+    corresponding packfile
+
+  - the second column is the object id of the object
+
+  - if the index version is 2 or higher, the third column contains the
+    CRC32 of the object data
+
+The objects are output in the order in which they are found in the index
+file, which should be (in a correctly constructed file) sorted by object
+id.
+
+Note that you can get more information on a packfile by calling
+linkgit:git-verify-pack[1]. However, as this command considers only the
+index file itself, it's both faster and more flexible.
 
 GIT
 ---
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/git-show-ref.txt 1.2.3+git2.25.1-1/git/Documentation/git-show-ref.txt
--- 1.2.1+git2.18.0-1/git/Documentation/git-show-ref.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/git-show-ref.txt	2020-02-17 04:47:35.000000000 +0000
@@ -37,8 +37,8 @@ OPTIONS
 
 	Show the HEAD reference, even if it would normally be filtered out.
 
---tags::
 --heads::
+--tags::
 
 	Limit to "refs/heads" and "refs/tags", respectively.  These options
 	are not mutually exclusive; when given both, references stored in
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/git-sparse-checkout.txt 1.2.3+git2.25.1-1/git/Documentation/git-sparse-checkout.txt
--- 1.2.1+git2.18.0-1/git/Documentation/git-sparse-checkout.txt	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/git-sparse-checkout.txt	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,185 @@
+git-sparse-checkout(1)
+======================
+
+NAME
+----
+git-sparse-checkout - Initialize and modify the sparse-checkout
+configuration, which reduces the checkout to a set of paths
+given by a list of patterns.
+
+
+SYNOPSIS
+--------
+[verse]
+'git sparse-checkout <subcommand> [options]'
+
+
+DESCRIPTION
+-----------
+
+Initialize and modify the sparse-checkout configuration, which reduces
+the checkout to a set of paths given by a list of patterns.
+
+THIS COMMAND IS EXPERIMENTAL. ITS BEHAVIOR, AND THE BEHAVIOR OF OTHER
+COMMANDS IN THE PRESENCE OF SPARSE-CHECKOUTS, WILL LIKELY CHANGE IN
+THE FUTURE.
+
+
+COMMANDS
+--------
+'list'::
+	Describe the patterns in the sparse-checkout file.
+
+'init'::
+	Enable the `core.sparseCheckout` setting. If the
+	sparse-checkout file does not exist, then populate it with
+	patterns that match every file in the root directory and
+	no other directories, then will remove all directories tracked
+	by Git. Add patterns to the sparse-checkout file to
+	repopulate the working directory.
++
+To avoid interfering with other worktrees, it first enables the
+`extensions.worktreeConfig` setting and makes sure to set the
+`core.sparseCheckout` setting in the worktree-specific config file.
+
+'set'::
+	Write a set of patterns to the sparse-checkout file, as given as
+	a list of arguments following the 'set' subcommand. Update the
+	working directory to match the new patterns. Enable the
+	core.sparseCheckout config setting if it is not already enabled.
++
+When the `--stdin` option is provided, the patterns are read from
+standard in as a newline-delimited list instead of from the arguments.
+
+'disable'::
+	Disable the `core.sparseCheckout` config setting, and restore the
+	working directory to include all files. Leaves the sparse-checkout
+	file intact so a later 'git sparse-checkout init' command may
+	return the working directory to the same state.
+
+SPARSE CHECKOUT
+---------------
+
+"Sparse checkout" allows populating the working directory sparsely.
+It uses the skip-worktree bit (see linkgit:git-update-index[1]) to tell
+Git whether a file in the working directory is worth looking at. If
+the skip-worktree bit is set, then the file is ignored in the working
+directory. Git will not populate the contents of those files, which
+makes a sparse checkout helpful when working in a repository with many
+files, but only a few are important to the current user.
+
+The `$GIT_DIR/info/sparse-checkout` file is used to define the
+skip-worktree reference bitmap. When Git updates the working
+directory, it updates the skip-worktree bits in the index based
+on this file. The files matching the patterns in the file will
+appear in the working directory, and the rest will not.
+
+To enable the sparse-checkout feature, run `git sparse-checkout init` to
+initialize a simple sparse-checkout file and enable the `core.sparseCheckout`
+config setting. Then, run `git sparse-checkout set` to modify the patterns in
+the sparse-checkout file.
+
+To repopulate the working directory with all files, use the
+`git sparse-checkout disable` command.
+
+
+FULL PATTERN SET
+----------------
+
+By default, the sparse-checkout file uses the same syntax as `.gitignore`
+files.
+
+While `$GIT_DIR/info/sparse-checkout` is usually used to specify what
+files are included, you can also specify what files are _not_ included,
+using negative patterns. For example, to remove the file `unwanted`:
+
+----------------
+/*
+!unwanted
+----------------
+
+
+CONE PATTERN SET
+----------------
+
+The full pattern set allows for arbitrary pattern matches and complicated
+inclusion/exclusion rules. These can result in O(N*M) pattern matches when
+updating the index, where N is the number of patterns and M is the number
+of paths in the index. To combat this performance issue, a more restricted
+pattern set is allowed when `core.spareCheckoutCone` is enabled.
+
+The accepted patterns in the cone pattern set are:
+
+1. *Recursive:* All paths inside a directory are included.
+
+2. *Parent:* All files immediately inside a directory are included.
+
+In addition to the above two patterns, we also expect that all files in the
+root directory are included. If a recursive pattern is added, then all
+leading directories are added as parent patterns.
+
+By default, when running `git sparse-checkout init`, the root directory is
+added as a parent pattern. At this point, the sparse-checkout file contains
+the following patterns:
+
+----------------
+/*
+!/*/
+----------------
+
+This says "include everything in root, but nothing two levels below root."
+If we then add the folder `A/B/C` as a recursive pattern, the folders `A` and
+`A/B` are added as parent patterns. The resulting sparse-checkout file is
+now
+
+----------------
+/*
+!/*/
+/A/
+!/A/*/
+/A/B/
+!/A/B/*/
+/A/B/C/
+----------------
+
+Here, order matters, so the negative patterns are overridden by the positive
+patterns that appear lower in the file.
+
+If `core.sparseCheckoutCone=true`, then Git will parse the sparse-checkout file
+expecting patterns of these types. Git will warn if the patterns do not match.
+If the patterns do match the expected format, then Git will use faster hash-
+based algorithms to compute inclusion in the sparse-checkout.
+
+In the cone mode case, the `git sparse-checkout list` subcommand will list the
+directories that define the recursive patterns. For the example sparse-checkout
+file above, the output is as follows:
+
+--------------------------
+$ git sparse-checkout list
+A/B/C
+--------------------------
+
+If `core.ignoreCase=true`, then the pattern-matching algorithm will use a
+case-insensitive check. This corrects for case mismatched filenames in the
+'git sparse-checkout set' command to reflect the expected cone in the working
+directory.
+
+
+SUBMODULES
+----------
+
+If your repository contains one or more submodules, then those submodules will
+appear based on which you initialized with the `git submodule` command. If
+your sparse-checkout patterns exclude an initialized submodule, then that
+submodule will still appear in your working directory.
+
+
+SEE ALSO
+--------
+
+linkgit:git-read-tree[1]
+linkgit:gitignore[5]
+
+GIT
+---
+Part of the linkgit:git[1] suite
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/git-stash.txt 1.2.3+git2.25.1-1/git/Documentation/git-stash.txt
--- 1.2.1+git2.18.0-1/git/Documentation/git-stash.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/git-stash.txt	2020-02-17 04:47:35.000000000 +0000
@@ -9,7 +9,7 @@ SYNOPSIS
 --------
 [verse]
 'git stash' list [<options>]
-'git stash' show [<stash>]
+'git stash' show [<options>] [<stash>]
 'git stash' drop [-q|--quiet] [<stash>]
 'git stash' ( pop | apply ) [--index] [-q|--quiet] [<stash>]
 'git stash' branch <branchname> [<stash>]
@@ -87,8 +87,9 @@ The `--patch` option implies `--keep-ind
 save [-p|--patch] [-k|--[no-]keep-index] [-u|--include-untracked] [-a|--all] [-q|--quiet] [<message>]::
 
 	This option is deprecated in favour of 'git stash push'.  It
-	differs from "stash push" in that it cannot take pathspecs,
-	and any non-option arguments form the message.
+	differs from "stash push" in that it cannot take pathspecs.
+	Instead, all non-option arguments are concatenated to form the stash
+	message.
 
 list [<options>]::
 
@@ -106,7 +107,7 @@ stash@{1}: On master: 9cc0589... Add git
 The command takes options applicable to the 'git log'
 command to control what is shown and how. See linkgit:git-log[1].
 
-show [<stash>]::
+show [<options>] [<stash>]::
 
 	Show the changes recorded in the stash entry as a diff between the
 	stashed contents and the commit back when the stash entry was first
@@ -235,12 +236,12 @@ return to your original branch to make t
 +
 ----------------------------------------------------------------
 # ... hack hack hack ...
-$ git checkout -b my_wip
+$ git switch -c my_wip
 $ git commit -a -m "WIP"
-$ git checkout master
+$ git switch master
 $ edit emergency fix
 $ git commit -a -m "Fix in a hurry"
-$ git checkout my_wip
+$ git switch my_wip
 $ git reset --soft HEAD^
 # ... continue hacking ...
 ----------------------------------------------------------------
@@ -293,7 +294,8 @@ SEE ALSO
 linkgit:git-checkout[1],
 linkgit:git-commit[1],
 linkgit:git-reflog[1],
-linkgit:git-reset[1]
+linkgit:git-reset[1],
+linkgit:git-switch[1]
 
 GIT
 ---
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/git-status.txt 1.2.3+git2.25.1-1/git/Documentation/git-status.txt
--- 1.2.1+git2.18.0-1/git/Documentation/git-status.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/git-status.txt	2020-02-17 04:47:35.000000000 +0000
@@ -59,16 +59,17 @@ This is optional and defaults to the ori
 --untracked-files[=<mode>]::
 	Show untracked files.
 +
+--
 The mode parameter is used to specify the handling of untracked files.
 It is optional: it defaults to 'all', and if specified, it must be
 stuck to the option (e.g. `-uno`, but not `-u no`).
-+
+
 The possible options are:
-+
+
 	- 'no'     - Show no untracked files.
 	- 'normal' - Shows untracked files and directories.
 	- 'all'    - Also shows individual files in untracked directories.
-+
+
 When `-u` option is not used, untracked files and directories are
 shown (i.e. the same as specifying `normal`), to help you avoid
 forgetting to add newly created files.  Because it takes extra work
@@ -78,9 +79,10 @@ Consider enabling untracked cache and sp
 `git update-index --untracked-cache` and `git update-index
 --split-index`), Otherwise you can use `no` to have `git status`
 return more quickly without showing untracked files.
-+
+
 The default can be changed using the status.showUntrackedFiles
 configuration variable documented in linkgit:git-config[1].
+--
 
 --ignore-submodules[=<when>]::
 	Ignore changes to submodules when looking for changes. <when> can be
@@ -100,24 +102,26 @@ configuration variable documented in lin
 --ignored[=<mode>]::
 	Show ignored files as well.
 +
+--
 The mode parameter is used to specify the handling of ignored files.
 It is optional: it defaults to 'traditional'.
-+
+
 The possible options are:
-+
+
 	- 'traditional' - Shows ignored files and directories, unless
-			  --untracked-files=all is specifed, in which case
+			  --untracked-files=all is specified, in which case
 			  individual files in ignored directories are
 			  displayed.
 	- 'no'	        - Show no ignored files.
 	- 'matching'    - Shows ignored files and directories matching an
 			  ignore pattern.
-+
+
 When 'matching' mode is specified, paths that explicitly match an
 ignored pattern are shown. If a directory matches an ignore pattern,
 then it is shown, but not paths contained in the ignored directory. If
 a directory does not match an ignore pattern, but all contents are
 ignored, then the directory is not shown, but all contents are shown.
+--
 
 -z::
 	Terminate entries with NUL, instead of LF.  This implies
@@ -197,31 +201,33 @@ codes can be interpreted as follows:
 Ignored files are not listed, unless `--ignored` option is in effect,
 in which case `XY` are `!!`.
 
-    X          Y     Meaning
-    -------------------------------------------------
-	     [AMD]   not updated
-    M        [ MD]   updated in index
-    A        [ MD]   added to index
-    D                deleted from index
-    R        [ MD]   renamed in index
-    C        [ MD]   copied in index
-    [MARC]           index and work tree matches
-    [ MARC]     M    work tree changed since index
-    [ MARC]     D    deleted in work tree
-    [ D]        R    renamed in work tree
-    [ D]        C    copied in work tree
-    -------------------------------------------------
-    D           D    unmerged, both deleted
-    A           U    unmerged, added by us
-    U           D    unmerged, deleted by them
-    U           A    unmerged, added by them
-    D           U    unmerged, deleted by us
-    A           A    unmerged, both added
-    U           U    unmerged, both modified
-    -------------------------------------------------
-    ?           ?    untracked
-    !           !    ignored
-    -------------------------------------------------
+....
+X          Y     Meaning
+-------------------------------------------------
+	 [AMD]   not updated
+M        [ MD]   updated in index
+A        [ MD]   added to index
+D                deleted from index
+R        [ MD]   renamed in index
+C        [ MD]   copied in index
+[MARC]           index and work tree matches
+[ MARC]     M    work tree changed since index
+[ MARC]     D    deleted in work tree
+[ D]        R    renamed in work tree
+[ D]        C    copied in work tree
+-------------------------------------------------
+D           D    unmerged, both deleted
+A           U    unmerged, added by us
+U           D    unmerged, deleted by them
+U           A    unmerged, added by them
+D           U    unmerged, deleted by us
+A           A    unmerged, both added
+U           U    unmerged, both modified
+-------------------------------------------------
+?           ?    untracked
+!           !    ignored
+-------------------------------------------------
+....
 
 Submodules have more state and instead report
 		M    the submodule has a different HEAD than
@@ -276,21 +282,25 @@ Header lines start with "#" and are adde
 command line arguments.  Parsers should ignore headers they
 don't recognize.
 
-### Branch Headers
+Branch Headers
+^^^^^^^^^^^^^^
 
 If `--branch` is given, a series of header lines are printed with
 information about the current branch.
 
-    Line                                     Notes
-    ------------------------------------------------------------
-    # branch.oid <commit> | (initial)        Current commit.
-    # branch.head <branch> | (detached)      Current branch.
-    # branch.upstream <upstream_branch>      If upstream is set.
-    # branch.ab +<ahead> -<behind>           If upstream is set and
-					     the commit is present.
-    ------------------------------------------------------------
+....
+Line                                     Notes
+------------------------------------------------------------
+# branch.oid <commit> | (initial)        Current commit.
+# branch.head <branch> | (detached)      Current branch.
+# branch.upstream <upstream_branch>      If upstream is set.
+# branch.ab +<ahead> -<behind>           If upstream is set and
+					 the commit is present.
+------------------------------------------------------------
+....
 
-### Changed Tracked Entries
+Changed Tracked Entries
+^^^^^^^^^^^^^^^^^^^^^^^
 
 Following the headers, a series of lines are printed for tracked
 entries.  One of three different line formats may be used to describe
@@ -306,58 +316,63 @@ Renamed or copied entries have the follo
 
     2 <XY> <sub> <mH> <mI> <mW> <hH> <hI> <X><score> <path><sep><origPath>
 
-    Field       Meaning
-    --------------------------------------------------------
-    <XY>        A 2 character field containing the staged and
-		unstaged XY values described in the short format,
-		with unchanged indicated by a "." rather than
-		a space.
-    <sub>       A 4 character field describing the submodule state.
-		"N..." when the entry is not a submodule.
-		"S<c><m><u>" when the entry is a submodule.
-		<c> is "C" if the commit changed; otherwise ".".
-		<m> is "M" if it has tracked changes; otherwise ".".
-		<u> is "U" if there are untracked changes; otherwise ".".
-    <mH>        The octal file mode in HEAD.
-    <mI>        The octal file mode in the index.
-    <mW>        The octal file mode in the worktree.
-    <hH>        The object name in HEAD.
-    <hI>        The object name in the index.
-    <X><score>  The rename or copy score (denoting the percentage
-		of similarity between the source and target of the
-		move or copy). For example "R100" or "C75".
-    <path>      The pathname.  In a renamed/copied entry, this
-		is the target path.
-    <sep>       When the `-z` option is used, the 2 pathnames are separated
-		with a NUL (ASCII 0x00) byte; otherwise, a tab (ASCII 0x09)
-		byte separates them.
-    <origPath>  The pathname in the commit at HEAD or in the index.
-		This is only present in a renamed/copied entry, and
-		tells where the renamed/copied contents came from.
-    --------------------------------------------------------
+....
+Field       Meaning
+--------------------------------------------------------
+<XY>        A 2 character field containing the staged and
+	    unstaged XY values described in the short format,
+	    with unchanged indicated by a "." rather than
+	    a space.
+<sub>       A 4 character field describing the submodule state.
+	    "N..." when the entry is not a submodule.
+	    "S<c><m><u>" when the entry is a submodule.
+	    <c> is "C" if the commit changed; otherwise ".".
+	    <m> is "M" if it has tracked changes; otherwise ".".
+	    <u> is "U" if there are untracked changes; otherwise ".".
+<mH>        The octal file mode in HEAD.
+<mI>        The octal file mode in the index.
+<mW>        The octal file mode in the worktree.
+<hH>        The object name in HEAD.
+<hI>        The object name in the index.
+<X><score>  The rename or copy score (denoting the percentage
+	    of similarity between the source and target of the
+	    move or copy). For example "R100" or "C75".
+<path>      The pathname.  In a renamed/copied entry, this
+	    is the target path.
+<sep>       When the `-z` option is used, the 2 pathnames are separated
+	    with a NUL (ASCII 0x00) byte; otherwise, a tab (ASCII 0x09)
+	    byte separates them.
+<origPath>  The pathname in the commit at HEAD or in the index.
+	    This is only present in a renamed/copied entry, and
+	    tells where the renamed/copied contents came from.
+--------------------------------------------------------
+....
 
 Unmerged entries have the following format; the first character is
 a "u" to distinguish from ordinary changed entries.
 
     u <xy> <sub> <m1> <m2> <m3> <mW> <h1> <h2> <h3> <path>
 
-    Field       Meaning
-    --------------------------------------------------------
-    <XY>        A 2 character field describing the conflict type
-		as described in the short format.
-    <sub>       A 4 character field describing the submodule state
-		as described above.
-    <m1>        The octal file mode in stage 1.
-    <m2>        The octal file mode in stage 2.
-    <m3>        The octal file mode in stage 3.
-    <mW>        The octal file mode in the worktree.
-    <h1>        The object name in stage 1.
-    <h2>        The object name in stage 2.
-    <h3>        The object name in stage 3.
-    <path>      The pathname.
-    --------------------------------------------------------
+....
+Field       Meaning
+--------------------------------------------------------
+<XY>        A 2 character field describing the conflict type
+	    as described in the short format.
+<sub>       A 4 character field describing the submodule state
+	    as described above.
+<m1>        The octal file mode in stage 1.
+<m2>        The octal file mode in stage 2.
+<m3>        The octal file mode in stage 3.
+<mW>        The octal file mode in the worktree.
+<h1>        The object name in stage 1.
+<h2>        The object name in stage 2.
+<h3>        The object name in stage 3.
+<path>      The pathname.
+--------------------------------------------------------
+....
 
-### Other Items
+Other Items
+^^^^^^^^^^^
 
 Following the tracked entries (and if requested), a series of
 lines will be printed for untracked and then ignored items
@@ -371,7 +386,8 @@ Ignored items have the following format:
 
     ! <path>
 
-### Pathname Format Notes and -z
+Pathname Format Notes and -z
+^^^^^^^^^^^^^^^^^^^^^^^^^^^^
 
 When the `-z` option is given, pathnames are printed as is and
 without any quoting and lines are terminated with a NUL (ASCII 0x00)
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/gitsubmodules.txt 1.2.3+git2.25.1-1/git/Documentation/gitsubmodules.txt
--- 1.2.1+git2.18.0-1/git/Documentation/gitsubmodules.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/gitsubmodules.txt	2020-02-17 04:47:35.000000000 +0000
@@ -3,7 +3,7 @@ gitsubmodules(7)
 
 NAME
 ----
-gitsubmodules - mounting one repository inside another
+gitsubmodules - Mounting one repository inside another
 
 SYNOPSIS
 --------
@@ -169,11 +169,15 @@ ACTIVE SUBMODULES
 
 A submodule is considered active,
 
-  (a) if `submodule.<name>.active` is set to `true`
-     or
-  (b) if the submodule's path matches the pathspec in `submodule.active`
-     or
-  (c) if `submodule.<name>.url` is set.
+  1. if `submodule.<name>.active` is set to `true`
++
+or
+
+  2. if the submodule's path matches the pathspec in `submodule.active`
++
+or
+
+  3. if `submodule.<name>.url` is set.
 
 and these are evaluated in this order.
 
@@ -189,12 +193,12 @@ For example:
     url = https://example.org/baz
 
 In the above config only the submodule 'bar' and 'baz' are active,
-'bar' due to (a) and 'baz' due to (c). 'foo' is inactive because
-(a) takes precedence over (c)
+'bar' due to (1) and 'baz' due to (3). 'foo' is inactive because
+(1) takes precedence over (3)
 
-Note that (c) is a historical artefact and will be ignored if the
-(a) and (b) specify that the submodule is not active. In other words,
-if we have an `submodule.<name>.active` set to `false` or if the
+Note that (3) is a historical artefact and will be ignored if the
+(1) and (2) specify that the submodule is not active. In other words,
+if we have a `submodule.<name>.active` set to `false` or if the
 submodule's path is excluded in the pathspec in `submodule.active`, the
 url doesn't matter whether it is present or not. This is illustrated in
 the example that follows.
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/git-submodule.txt 1.2.3+git2.25.1-1/git/Documentation/git-submodule.txt
--- 1.2.1+git2.18.0-1/git/Documentation/git-submodule.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/git-submodule.txt	2020-02-17 04:47:35.000000000 +0000
@@ -9,11 +9,14 @@ git-submodule - Initialize, update or in
 SYNOPSIS
 --------
 [verse]
+'git submodule' [--quiet] [--cached]
 'git submodule' [--quiet] add [<options>] [--] <repository> [<path>]
 'git submodule' [--quiet] status [--cached] [--recursive] [--] [<path>...]
 'git submodule' [--quiet] init [--] [<path>...]
 'git submodule' [--quiet] deinit [-f|--force] (--all|[--] <path>...)
 'git submodule' [--quiet] update [<options>] [--] [<path>...]
+'git submodule' [--quiet] set-branch [<options>] [--] <path>
+'git submodule' [--quiet] set-url [--] <path> <newurl>
 'git submodule' [--quiet] summary [<options>] [--] [<path>...]
 'git submodule' [--quiet] foreach [--recursive] <command>
 'git submodule' [--quiet] sync [--recursive] [--] [<path>...]
@@ -28,6 +31,9 @@ For more information about submodules, s
 
 COMMANDS
 --------
+With no arguments, shows the status of existing submodules.  Several
+subcommands are available to perform operations on the submodules.
+
 add [-b <branch>] [-f|--force] [--name <name>] [--reference <repository>] [--depth <depth>] [--] <repository> [<path>]::
 	Add the given repository as a submodule at the given path
 	to the changeset to be committed next to the current
@@ -38,7 +44,7 @@ This may be either an absolute URL, or (
 or ../), the location relative to the superproject's default remote
 repository (Please note that to specify a repository 'foo.git'
 which is located right next to a superproject 'bar.git', you'll
-have to use '../foo.git' instead of './foo.git' - as one might expect
+have to use `../foo.git` instead of `./foo.git` - as one might expect
 when following the rules for relative URLs - because the evaluation
 of relative URLs in Git is identical to that of relative directories).
 +
@@ -75,6 +81,9 @@ status [--cached] [--recursive] [--] [<p
 	does not match the SHA-1 found in the index of the containing
 	repository and `U` if the submodule has merge conflicts.
 +
+If `--cached` is specified, this command will instead print the SHA-1
+recorded in the superproject for each submodule.
++
 If `--recursive` is specified, this command will recurse into nested
 submodules, and show their status as well.
 +
@@ -128,7 +137,8 @@ update [--init] [--remote] [-N|--no-fetc
 +
 --
 Update the registered submodules to match what the superproject
-expects by cloning missing submodules and updating the working tree of
+expects by cloning missing submodules, fetching missing commits
+in submodules and updating the working tree of
 the submodules. The "updating" can be done in several ways depending
 on command line options and the value of `submodule.<name>.update`
 configuration variable. The command line option takes precedence over
@@ -168,6 +178,18 @@ submodule with the `--init` option.
 If `--recursive` is specified, this command will recurse into the
 registered submodules, and update any nested submodules within.
 --
+set-branch (-b|--branch) <branch> [--] <path>::
+set-branch (-d|--default) [--] <path>::
+	Sets the default remote tracking branch for the submodule. The
+	`--branch` option allows the remote branch to be specified. The
+	`--default` option removes the submodule.<name>.branch configuration
+	key, which causes the tracking branch to default to 'master'.
+
+set-url [--] <path> <newurl>::
+	Sets the URL of the specified submodule to <newurl>. Then, it will
+	automatically synchronize the submodule's new remote URL
+	configuration.
+
 summary [--cached|--files] [(-n|--summary-limit) <n>] [commit] [--] [<path>...]::
 	Show commit summary between the given commit (defaults to HEAD) and
 	working tree/index. For a submodule in question, a series of commits
@@ -183,12 +205,17 @@ information too.
 
 foreach [--recursive] <command>::
 	Evaluates an arbitrary shell command in each checked out submodule.
-	The command has access to the variables $name, $path, $sha1 and
-	$toplevel:
+	The command has access to the variables $name, $sm_path, $displaypath,
+	$sha1 and $toplevel:
 	$name is the name of the relevant submodule section in `.gitmodules`,
-	$path is the name of the submodule directory relative to the
-	superproject, $sha1 is the commit as recorded in the superproject,
-	and $toplevel is the absolute path to the top-level of the superproject.
+	$sm_path is the path of the submodule as recorded in the immediate
+	superproject, $displaypath contains the relative path from the
+	current working directory to the submodules root directory,
+	$sha1 is the commit as recorded in the immediate
+	superproject, and $toplevel is the absolute path to the top-level
+	of the immediate superproject.
+	Note that to avoid conflicts with '$PATH' on Windows, the '$path'
+	variable is now a deprecated synonym of '$sm_path' variable.
 	Any submodules defined in the superproject but not checked out are
 	ignored by this command. Unless given `--quiet`, foreach prints the name
 	of each submodule before evaluating the command.
@@ -202,7 +229,7 @@ As an example, the command below will sh
 checked out commit for each submodule:
 +
 --------------
-git submodule foreach 'echo $path `git rev-parse HEAD`'
+git submodule foreach 'echo $sm_path `git rev-parse HEAD`'
 --------------
 
 sync [--recursive] [--] [<path>...]::
@@ -221,7 +248,7 @@ registered submodules, and sync any nest
 
 absorbgitdirs::
 	If a git directory of a submodule is inside the submodule,
-	move the git directory of the submodule into its superprojects
+	move the git directory of the submodule into its superproject's
 	`$GIT_DIR/modules` path and then connect the git directory and
 	its working directory by setting the `core.worktree` and adding
 	a .git file pointing to the git directory embedded in the
@@ -250,13 +277,14 @@ OPTIONS
 	This option is only valid for the deinit command. Unregister all
 	submodules in the working tree.
 
--b::
---branch::
+-b <branch>::
+--branch <branch>::
 	Branch of repository to add as submodule.
 	The name of the branch is recorded as `submodule.<name>.branch` in
 	`.gitmodules` for `update --remote`.  A special value of `.` is used to
 	indicate that the name of the branch in the submodule should be the
-	same name as the current branch in the current repository.
+	same name as the current branch in the current repository.  If the
+	option is not specified, it defaults to 'master'.
 
 -f::
 --force::
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/git-svn.txt 1.2.3+git2.25.1-1/git/Documentation/git-svn.txt
--- 1.2.1+git2.18.0-1/git/Documentation/git-svn.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/git-svn.txt	2020-02-17 04:47:35.000000000 +0000
@@ -126,7 +126,7 @@ your Perl's Getopt::Long is < v2.37).
 	command-line argument.
 +
 This automatically updates the rev_map if needed (see
-'$GIT_DIR/svn/\*\*/.rev_map.*' in the FILES section below for details).
+'$GIT_DIR/svn/\**/.rev_map.*' in the FILES section below for details).
 
 --localtime;;
 	Store Git commit times in the local time zone instead of UTC.  This
@@ -239,7 +239,7 @@ Like 'git rebase'; this requires that th
 and have no uncommitted changes.
 +
 This automatically updates the rev_map if needed (see
-'$GIT_DIR/svn/\*\*/.rev_map.*' in the FILES section below for details).
+'$GIT_DIR/svn/\**/.rev_map.*' in the FILES section below for details).
 
 -l;;
 --local;;
@@ -452,7 +452,7 @@ Any other arguments are passed directly
 
 'commit-diff'::
 	Commits the diff of two tree-ish arguments from the
-	command-line.  This command does not rely on being inside an `git svn
+	command-line.  This command does not rely on being inside a `git svn
 	init`-ed repository.  This command takes three arguments, (a) the
 	original tree to diff against, (b) the new tree result, (c) the
 	URL of the target Subversion repository.  The final argument
@@ -524,7 +524,7 @@ This will set the property 'svn:keywords
 	way to repair the repo is to use 'reset'.
 +
 Only the rev_map and refs/remotes/git-svn are changed (see
-'$GIT_DIR/svn/\*\*/.rev_map.*' in the FILES section below for details).
+'$GIT_DIR/svn/\**/.rev_map.*' in the FILES section below for details).
 Follow 'reset' with a 'fetch' and then 'git reset' or 'git rebase' to
 move local branches onto the new tree.
 
@@ -677,7 +677,8 @@ config key: svn.authorsProg
 -s<strategy>::
 --strategy=<strategy>::
 -p::
---preserve-merges::
+--rebase-merges::
+--preserve-merges (DEPRECATED)::
 	These are only used with the 'dcommit' and 'rebase' commands.
 +
 Passed directly to 'git rebase' when using 'dcommit' if a
@@ -760,7 +761,7 @@ svn-remote.<name>.noMetadata::
 +
 This option can only be used for one-shot imports as 'git svn'
 will not be able to fetch again without metadata. Additionally,
-if you lose your '$GIT_DIR/svn/\*\*/.rev_map.*' files, 'git svn' will not
+if you lose your '$GIT_DIR/svn/\**/.rev_map.*' files, 'git svn' will not
 be able to rebuild them.
 +
 The 'git svn log' command will not work on repositories using
@@ -769,11 +770,11 @@ option for (hopefully) obvious reasons.
 +
 This option is NOT recommended as it makes it difficult to track down
 old references to SVN revision numbers in existing documentation, bug
-reports and archives.  If you plan to eventually migrate from SVN to Git
-and are certain about dropping SVN history, consider
-linkgit:git-filter-branch[1] instead.  filter-branch also allows
-reformatting of metadata for ease-of-reading and rewriting authorship
-info for non-"svn.authorsFile" users.
+reports, and archives.  If you plan to eventually migrate from SVN to
+Git and are certain about dropping SVN history, consider
+https://github.com/newren/git-filter-repo[git-filter-repo] instead.
+filter-repo also allows reformatting of metadata for ease-of-reading
+and rewriting authorship info for non-"svn.authorsFile" users.
 
 svn.useSvmProps::
 svn-remote.<name>.useSvmProps::
@@ -1100,10 +1101,10 @@ listed below are allowed:
 	tags = tags/*/project-a:refs/remotes/project-a/tags/*
 ------------------------------------------------------------------------
 
-Keep in mind that the '\*' (asterisk) wildcard of the local ref
-(right of the ':') *must* be the farthest right path component;
+Keep in mind that the `*` (asterisk) wildcard of the local ref
+(right of the `:`) *must* be the farthest right path component;
 however the remote wildcard may be anywhere as long as it's an
-independent path component (surrounded by '/' or EOL).   This
+independent path component (surrounded by `/` or EOL).   This
 type of configuration is not automatically created by 'init' and
 should be manually entered with a text-editor or using 'git config'.
 
@@ -1154,7 +1155,7 @@ fetching, then $GIT_DIR/svn/.metadata mu
 
 FILES
 -----
-$GIT_DIR/svn/\*\*/.rev_map.*::
+$GIT_DIR/svn/\**/.rev_map.*::
 	Mapping between Subversion revision numbers and Git commit
 	names.  In a repository where the noMetadata option is not set,
 	this can be rebuilt from the git-svn-id: lines that are at the
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/git-switch.txt 1.2.3+git2.25.1-1/git/Documentation/git-switch.txt
--- 1.2.1+git2.18.0-1/git/Documentation/git-switch.txt	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/git-switch.txt	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,273 @@
+git-switch(1)
+=============
+
+NAME
+----
+git-switch - Switch branches
+
+SYNOPSIS
+--------
+[verse]
+'git switch' [<options>] [--no-guess] <branch>
+'git switch' [<options>] --detach [<start-point>]
+'git switch' [<options>] (-c|-C) <new-branch> [<start-point>]
+'git switch' [<options>] --orphan <new-branch>
+
+DESCRIPTION
+-----------
+Switch to a specified branch. The working tree and the index are
+updated to match the branch. All new commits will be added to the tip
+of this branch.
+
+Optionally a new branch could be created with either `-c`, `-C`,
+automatically from a remote branch of same name (see `--guess`), or
+detach the working tree from any branch with `--detach`, along with
+switching.
+
+Switching branches does not require a clean index and working tree
+(i.e. no differences compared to `HEAD`). The operation is aborted
+however if the operation leads to loss of local changes, unless told
+otherwise with `--discard-changes` or `--merge`.
+
+THIS COMMAND IS EXPERIMENTAL. THE BEHAVIOR MAY CHANGE.
+
+OPTIONS
+-------
+<branch>::
+	Branch to switch to.
+
+<new-branch>::
+	Name for the new branch.
+
+<start-point>::
+	The starting point for the new branch. Specifying a
+	`<start-point>` allows you to create a branch based on some
+	other point in history than where HEAD currently points. (Or,
+	in the case of `--detach`, allows you to inspect and detach
+	from some other point.)
++
+You can use the `@{-N}` syntax to refer to the N-th last
+branch/commit switched to using "git switch" or "git checkout"
+operation. You may also specify `-` which is synonymous to `@{-1}`.
+This is often used to switch quickly between two branches, or to undo
+a branch switch by mistake.
++
+As a special case, you may use `A...B` as a shortcut for the merge
+base of `A` and `B` if there is exactly one merge base. You can leave
+out at most one of `A` and `B`, in which case it defaults to `HEAD`.
+
+-c <new-branch>::
+--create <new-branch>::
+	Create a new branch named `<new-branch>` starting at
+	`<start-point>` before switching to the branch. This is a
+	convenient shortcut for:
++
+------------
+$ git branch <new-branch>
+$ git switch <new-branch>
+------------
+
+-C <new-branch>::
+--force-create <new-branch>::
+	Similar to `--create` except that if `<new-branch>` already
+	exists, it will be reset to `<start-point>`. This is a
+	convenient shortcut for:
++
+------------
+$ git branch -f <new-branch>
+$ git switch <new-branch>
+------------
+
+-d::
+--detach::
+	Switch to a commit for inspection and discardable
+	experiments. See the "DETACHED HEAD" section in
+	linkgit:git-checkout[1] for details.
+
+--guess::
+--no-guess::
+	If `<branch>` is not found but there does exist a tracking
+	branch in exactly one remote (call it `<remote>`) with a
+	matching name, treat as equivalent to
++
+------------
+$ git switch -c <branch> --track <remote>/<branch>
+------------
++
+If the branch exists in multiple remotes and one of them is named by
+the `checkout.defaultRemote` configuration variable, we'll use that
+one for the purposes of disambiguation, even if the `<branch>` isn't
+unique across all remotes. Set it to e.g. `checkout.defaultRemote=origin`
+to always checkout remote branches from there if `<branch>` is
+ambiguous but exists on the 'origin' remote. See also
+`checkout.defaultRemote` in linkgit:git-config[1].
++
+`--guess` is the default behavior. Use `--no-guess` to disable it.
+
+-f::
+--force::
+	An alias for `--discard-changes`.
+
+--discard-changes::
+	Proceed even if the index or the working tree differs from
+	`HEAD`. Both the index and working tree are restored to match
+	the switching target. If `--recurse-submodules` is specified,
+	submodule content is also restored to match the switching
+	target. This is used to throw away local changes.
+
+-m::
+--merge::
+	If you have local modifications to one or more files that are
+	different between the current branch and the branch to which
+	you are switching, the command refuses to switch branches in
+	order to preserve your modifications in context.  However,
+	with this option, a three-way merge between the current
+	branch, your working tree contents, and the new branch is
+	done, and you will be on the new branch.
++
+When a merge conflict happens, the index entries for conflicting
+paths are left unmerged, and you need to resolve the conflicts
+and mark the resolved paths with `git add` (or `git rm` if the merge
+should result in deletion of the path).
+
+--conflict=<style>::
+	The same as `--merge` option above, but changes the way the
+	conflicting hunks are presented, overriding the
+	`merge.conflictStyle` configuration variable.  Possible values are
+	"merge" (default) and "diff3" (in addition to what is shown by
+	"merge" style, shows the original contents).
+
+-q::
+--quiet::
+	Quiet, suppress feedback messages.
+
+--progress::
+--no-progress::
+	Progress status is reported on the standard error stream
+	by default when it is attached to a terminal, unless `--quiet`
+	is specified. This flag enables progress reporting even if not
+	attached to a terminal, regardless of `--quiet`.
+
+-t::
+--track::
+	When creating a new branch, set up "upstream" configuration.
+	`-c` is implied. See `--track` in linkgit:git-branch[1] for
+	details.
++
+If no `-c` option is given, the name of the new branch will be derived
+from the remote-tracking branch, by looking at the local part of the
+refspec configured for the corresponding remote, and then stripping
+the initial part up to the "*".  This would tell us to use `hack` as
+the local branch when branching off of `origin/hack` (or
+`remotes/origin/hack`, or even `refs/remotes/origin/hack`).  If the
+given name has no slash, or the above guessing results in an empty
+name, the guessing is aborted.  You can explicitly give a name with
+`-c` in such a case.
+
+--no-track::
+	Do not set up "upstream" configuration, even if the
+	`branch.autoSetupMerge` configuration variable is true.
+
+--orphan <new-branch>::
+	Create a new 'orphan' branch, named `<new-branch>`. All
+	tracked files are removed.
+
+--ignore-other-worktrees::
+	`git switch` refuses when the wanted ref is already
+	checked out by another worktree. This option makes it check
+	the ref out anyway. In other words, the ref can be held by
+	more than one worktree.
+
+--recurse-submodules::
+--no-recurse-submodules::
+	Using `--recurse-submodules` will update the content of all
+	initialized submodules according to the commit recorded in the
+	superproject. If nothing (or `--no-recurse-submodules`) is
+	used, the work trees of submodules will not be updated. Just
+	like linkgit:git-submodule[1], this will detach `HEAD` of the
+	submodules.
+
+EXAMPLES
+--------
+
+The following command switches to the "master" branch:
+
+------------
+$ git switch master
+------------
+
+After working in the wrong branch, switching to the correct branch
+would be done using:
+
+------------
+$ git switch mytopic
+------------
+
+However, your "wrong" branch and correct "mytopic" branch may differ
+in files that you have modified locally, in which case the above
+switch would fail like this:
+
+------------
+$ git switch mytopic
+error: You have local changes to 'frotz'; not switching branches.
+------------
+
+You can give the `-m` flag to the command, which would try a three-way
+merge:
+
+------------
+$ git switch -m mytopic
+Auto-merging frotz
+------------
+
+After this three-way merge, the local modifications are _not_
+registered in your index file, so `git diff` would show you what
+changes you made since the tip of the new branch.
+
+To switch back to the previous branch before we switched to mytopic
+(i.e. "master" branch):
+
+------------
+$ git switch -
+------------
+
+You can grow a new branch from any commit. For example, switch to
+"HEAD~3" and create branch "fixup":
+
+------------
+$ git switch -c fixup HEAD~3
+Switched to a new branch 'fixup'
+------------
+
+If you want to start a new branch from a remote branch of the same
+name:
+
+------------
+$ git switch new-topic
+Branch 'new-topic' set up to track remote branch 'new-topic' from 'origin'
+Switched to a new branch 'new-topic'
+------------
+
+To check out commit `HEAD~3` for temporary inspection or experiment
+without creating a new branch:
+
+------------
+$ git switch --detach HEAD~3
+HEAD is now at 9fc9555312 Merge branch 'cc/shared-index-permbits'
+------------
+
+If it turns out whatever you have done is worth keeping, you can
+always create a new name for it (without switching away):
+
+------------
+$ git switch -c good-surprises
+------------
+
+SEE ALSO
+--------
+linkgit:git-checkout[1],
+linkgit:git-branch[1]
+
+GIT
+---
+Part of the linkgit:git[1] suite
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/git-tag.txt 1.2.3+git2.25.1-1/git/Documentation/git-tag.txt
--- 1.2.1+git2.18.0-1/git/Documentation/git-tag.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/git-tag.txt	2020-02-17 04:47:35.000000000 +0000
@@ -64,6 +64,13 @@ OPTIONS
 -s::
 --sign::
 	Make a GPG-signed tag, using the default e-mail address's key.
+	The default behavior of tag GPG-signing is controlled by `tag.gpgSign`
+	configuration variable if it exists, or disabled otherwise.
+	See linkgit:git-config[1].
+
+--no-sign::
+	Override `tag.gpgSign` configuration variable that is
+	set to force each and every tag to be signed.
 
 -u <keyid>::
 --local-user=<keyid>::
@@ -115,7 +122,7 @@ options for details.
 	variable if it exists, or lexicographic order otherwise. See
 	linkgit:git-config[1].
 
---color[=<when>]:
+--color[=<when>]::
 	Respect any colors specified in the `--format` option. The
 	`<when>` field must be one of `always`, `never`, or `auto` (if
 	`<when>` is absent, behave as if `always` was given).
@@ -187,6 +194,12 @@ This option is only applicable when list
 	`--create-reflog`, but currently does not negate the setting of
 	`core.logAllRefUpdates`.
 
+--format=<format>::
+	A string that interpolates `%(fieldname)` from a tag ref being shown
+	and the object it points at.  The format is the same as
+	that of linkgit:git-for-each-ref[1].  When unspecified,
+	defaults to `%(refname:strip=2)`.
+
 <tagname>::
 	The name of the tag to create, delete, or describe.
 	The new tag name must pass all checks defined by
@@ -198,12 +211,6 @@ This option is only applicable when list
 	The object that the new tag will refer to, usually a commit.
 	Defaults to HEAD.
 
-<format>::
-	A string that interpolates `%(fieldname)` from a tag ref being shown
-	and the object it points at.  The format is the same as
-	that of linkgit:git-for-each-ref[1].  When unspecified,
-	defaults to `%(refname:strip=2)`.
-
 CONFIGURATION
 -------------
 By default, 'git tag' in sign-with-default mode (-s) will use your
@@ -237,16 +244,16 @@ your repository directly), then others w
 the old tag. In that case you can do one of two things:
 
 . The sane thing.
-Just admit you screwed up, and use a different name. Others have
-already seen one tag-name, and if you keep the same name, you
-may be in the situation that two people both have "version X",
-but they actually have 'different' "X"'s.  So just call it "X.1"
-and be done with it.
+  Just admit you screwed up, and use a different name. Others have
+  already seen one tag-name, and if you keep the same name, you
+  may be in the situation that two people both have "version X",
+  but they actually have 'different' "X"'s.  So just call it "X.1"
+  and be done with it.
 
 . The insane thing.
-You really want to call the new version "X" too, 'even though'
-others have already seen the old one. So just use 'git tag -f'
-again, as if you hadn't already published the old one.
+  You really want to call the new version "X" too, 'even though'
+  others have already seen the old one. So just use 'git tag -f'
+  again, as if you hadn't already published the old one.
 
 However, Git does *not* (and it should not) change tags behind
 users back. So if somebody already got the old tag, doing a
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/gittutorial-2.txt 1.2.3+git2.25.1-1/git/Documentation/gittutorial-2.txt
--- 1.2.1+git2.18.0-1/git/Documentation/gittutorial-2.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/gittutorial-2.txt	2020-02-17 04:47:35.000000000 +0000
@@ -370,13 +370,13 @@ situation:
 $ git status
 On branch master
 Changes to be committed:
-  (use "git reset HEAD <file>..." to unstage)
+  (use "git restore --staged <file>..." to unstage)
 
 	new file:   closing.txt
 
 Changes not staged for commit:
   (use "git add <file>..." to update what will be committed)
-  (use "git checkout -- <file>..." to discard changes in working directory)
+  (use "git restore <file>..." to discard changes in working directory)
 
 	modified:   file.txt
 
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/gittutorial.txt 1.2.3+git2.25.1-1/git/Documentation/gittutorial.txt
--- 1.2.1+git2.18.0-1/git/Documentation/gittutorial.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/gittutorial.txt	2020-02-17 04:47:35.000000000 +0000
@@ -110,7 +110,7 @@ $ git status
 On branch master
 Changes to be committed:
 Your branch is up to date with 'origin/master'.
-  (use "git reset HEAD <file>..." to unstage)
+  (use "git restore --staged <file>..." to unstage)
 
 	modified:   file1
 	modified:   file2
@@ -207,7 +207,7 @@ automatically.  The asterisk marks the b
 type
 
 ------------------------------------------------
-$ git checkout experimental
+$ git switch experimental
 ------------------------------------------------
 
 to switch to the experimental branch.  Now edit a file, commit the
@@ -216,7 +216,7 @@ change, and switch back to the master br
 ------------------------------------------------
 (edit file)
 $ git commit -a
-$ git checkout master
+$ git switch master
 ------------------------------------------------
 
 Check that the change you made is no longer visible, since it was
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/git.txt 1.2.3+git2.25.1-1/git/Documentation/git.txt
--- 1.2.1+git2.18.0-1/git/Documentation/git.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/git.txt	2020-02-17 04:47:35.000000000 +0000
@@ -33,7 +33,8 @@ individual Git commands with "git help c
 manual page gives you an overview of the command-line command syntax.
 
 A formatted and hyperlinked copy of the latest Git documentation
-can be viewed at `https://git.github.io/htmldocs/git.html`.
+can be viewed at https://git.github.io/htmldocs/git.html
+or https://git-scm.com/docs.
 
 
 OPTIONS
@@ -56,7 +57,8 @@ help ...`.
 	Run as if git was started in '<path>' instead of the current working
 	directory.  When multiple `-C` options are given, each subsequent
 	non-absolute `-C <path>` is interpreted relative to the preceding `-C
-	<path>`.
+	<path>`.  If '<path>' is present but empty, e.g. `-C ""`, then the
+	current working directory is left unchanged.
 +
 This option affects options that expect path name like `--git-dir` and
 `--work-tree` in that their interpretations of the path names would be
@@ -76,7 +78,7 @@ Note that omitting the `=` in `git -c fo
 `foo.bar` to the boolean true value (just like `[foo]bar` would in a
 config file). Including the equals but with an empty value (like `git -c
 foo.bar= ...`) sets `foo.bar` to the empty string which `git config
---bool` will convert to `false`.
+--type=bool` will convert to `false`.
 
 --exec-path[=<path>]::
 	Path to wherever your core Git programs are installed.
@@ -210,6 +212,26 @@ people via patch over e-mail.
 
 include::cmds-foreignscminterface.txt[]
 
+Reset, restore and revert
+~~~~~~~~~~~~~~~~~~~~~~~~~
+There are three commands with similar names: `git reset`,
+`git restore` and `git revert`.
+
+* linkgit:git-revert[1] is about making a new commit that reverts the
+  changes made by other commits.
+
+* linkgit:git-restore[1] is about restoring files in the working tree
+  from either the index or another commit. This command does not
+  update your branch. The command can also be used to restore files in
+  the index from another commit.
+
+* linkgit:git-reset[1] is about updating your branch, moving the tip
+  in order to add or remove commits from the branch. This operation
+  changes the commit history.
++
+`git reset` can also be used to restore the index, overlapping with
+`git restore`.
+
 
 Low-level commands (plumbing)
 -----------------------------
@@ -249,8 +271,8 @@ In general, the interrogate commands do
 the working tree.
 
 
-Synching repositories
-~~~~~~~~~~~~~~~~~~~~~
+Syncing repositories
+~~~~~~~~~~~~~~~~~~~~
 
 include::cmds-synchingrepositories.txt[]
 
@@ -402,11 +424,11 @@ Git so take care if using a foreign fron
 	of Git object directories which can be used to search for Git
 	objects. New objects will not be written to these directories.
 +
-	Entries that begin with `"` (double-quote) will be interpreted
-	as C-style quoted paths, removing leading and trailing
-	double-quotes and respecting backslash escapes. E.g., the value
-	`"path-with-\"-and-:-in-it":vanilla-path` has two paths:
-	`path-with-"-and-:-in-it` and `vanilla-path`.
+Entries that begin with `"` (double-quote) will be interpreted
+as C-style quoted paths, removing leading and trailing
+double-quotes and respecting backslash escapes. E.g., the value
+`"path-with-\"-and-:-in-it":vanilla-path` has two paths:
+`path-with-"-and-:-in-it` and `vanilla-path`.
 
 `GIT_DIR`::
 	If the `GIT_DIR` environment variable is set then it
@@ -460,13 +482,36 @@ Git so take care if using a foreign fron
 Git Commits
 ~~~~~~~~~~~
 `GIT_AUTHOR_NAME`::
+	The human-readable name used in the author identity when creating commit or
+	tag objects, or when writing reflogs. Overrides the `user.name` and
+	`author.name` configuration settings.
+
 `GIT_AUTHOR_EMAIL`::
+	The email address used in the author identity when creating commit or
+	tag objects, or when writing reflogs. Overrides the `user.email` and
+	`author.email` configuration settings.
+
 `GIT_AUTHOR_DATE`::
+	The date used for the author identity when creating commit or tag objects, or
+	when writing reflogs. See linkgit:git-commit[1] for valid formats.
+
 `GIT_COMMITTER_NAME`::
+	The human-readable name used in the committer identity when creating commit or
+	tag objects, or when writing reflogs. Overrides the `user.name` and
+	`committer.name` configuration settings.
+
 `GIT_COMMITTER_EMAIL`::
+	The email address used in the author identity when creating commit or
+	tag objects, or when writing reflogs. Overrides the `user.email` and
+	`committer.email` configuration settings.
+
 `GIT_COMMITTER_DATE`::
-'EMAIL'::
-	see linkgit:git-commit-tree[1]
+	The date used for the committer identity when creating commit or tag objects, or
+	when writing reflogs. See linkgit:git-commit[1] for valid formats.
+
+`EMAIL`::
+	The email address used in the author and committer identities if no other
+	relevant environment variable or configuration setting has been set.
 
 Git Diffs
 ~~~~~~~~~
@@ -522,6 +567,10 @@ other
 	a pager.  See also the `core.pager` option in
 	linkgit:git-config[1].
 
+`GIT_PROGRESS_DELAY`::
+	A number controlling how many seconds to delay before showing
+	optional progress indicators. Defaults to 2.
+
 `GIT_EDITOR`::
 	This environment variable overrides `$EDITOR` and `$VISUAL`.
 	It is used by several Git commands when, on interactive mode,
@@ -536,7 +585,6 @@ other
 	The command-line parameters passed to the configured command are
 	determined by the ssh variant.  See `ssh.variant` option in
 	linkgit:git-config[1] for details.
-
 +
 `$GIT_SSH_COMMAND` takes precedence over `$GIT_SSH`, and is interpreted
 by the shell, which allows additional arguments to be included.
@@ -599,8 +647,8 @@ trace messages into this file descriptor
 +
 Alternatively, if the variable is set to an absolute path
 (starting with a '/' character), Git will interpret this
-as a file path and will try to write the trace messages
-into it.
+as a file path and will try to append the trace messages
+to it.
 +
 Unsetting the variable, or setting it to empty, "0" or
 "false" (case insensitive) disables trace messages.
@@ -661,6 +709,54 @@ of clones and fetches.
 	When a curl trace is enabled (see `GIT_TRACE_CURL` above), do not dump
 	data (that is, only dump info lines and headers).
 
+`GIT_TRACE2`::
+	Enables more detailed trace messages from the "trace2" library.
+	Output from `GIT_TRACE2` is a simple text-based format for human
+	readability.
++
+If this variable is set to "1", "2" or "true" (comparison
+is case insensitive), trace messages will be printed to
+stderr.
++
+If the variable is set to an integer value greater than 2
+and lower than 10 (strictly) then Git will interpret this
+value as an open file descriptor and will try to write the
+trace messages into this file descriptor.
++
+Alternatively, if the variable is set to an absolute path
+(starting with a '/' character), Git will interpret this
+as a file path and will try to append the trace messages
+to it.  If the path already exists and is a directory, the
+trace messages will be written to files (one per process)
+in that directory, named according to the last component
+of the SID and an optional counter (to avoid filename
+collisions).
++
+In addition, if the variable is set to
+`af_unix:[<socket_type>:]<absolute-pathname>`, Git will try
+to open the path as a Unix Domain Socket.  The socket type
+can be either `stream` or `dgram`.
++
+Unsetting the variable, or setting it to empty, "0" or
+"false" (case insensitive) disables trace messages.
++
+See link:technical/api-trace2.html[Trace2 documentation]
+for full details.
+
+
+`GIT_TRACE2_EVENT`::
+	This setting writes a JSON-based format that is suited for machine
+	interpretation.
+	See `GIT_TRACE2` for available trace output options and
+	link:technical/api-trace2.html[Trace2 documentation] for full details.
+
+`GIT_TRACE2_PERF`::
+	In addition to the text-based messages available in `GIT_TRACE2`, this
+	setting writes a column-based format for understanding nesting
+	regions.
+	See `GIT_TRACE2` for available trace output options and
+	link:technical/api-trace2.html[Trace2 documentation] for full details.
+
 `GIT_REDACT_COOKIES`::
 	This can be set to a comma-separated list of strings. When a curl trace
 	is enabled (see `GIT_TRACE_CURL` above), whenever a "Cookies:" header
@@ -858,7 +954,9 @@ Reporting Bugs
 
 Report bugs to the Git mailing list <git@vger.kernel.org> where the
 development and maintenance is primarily done.  You do not have to be
-subscribed to the list to send a message there.
+subscribed to the list to send a message there.  See the list archive
+at https://lore.kernel.org/git for previous bug reports and other
+discussions.
 
 Issues which are security relevant should be disclosed privately to
 the Git Security mailing list <git-security@googlegroups.com>.
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/git-update-index.txt 1.2.3+git2.25.1-1/git/Documentation/git-update-index.txt
--- 1.2.1+git2.18.0-1/git/Documentation/git-update-index.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/git-update-index.txt	2020-02-17 04:47:35.000000000 +0000
@@ -16,6 +16,7 @@ SYNOPSIS
 	     [--chmod=(+|-)x]
 	     [--[no-]assume-unchanged]
 	     [--[no-]skip-worktree]
+	     [--[no-]ignore-skip-worktree-entries]
 	     [--[no-]fsmonitor-valid]
 	     [--ignore-submodules]
 	     [--[no-]split-index]
@@ -113,6 +114,11 @@ you will need to handle the situation ma
 	set and unset the "skip-worktree" bit for the paths. See
 	section "Skip-worktree bit" below for more information.
 
+
+--[no-]ignore-skip-worktree-entries::
+	Do not remove skip-worktree (AKA "index-only") entries even when
+	the `--remove` option was specified.
+
 --[no-]fsmonitor-valid::
 	When one of these flags is specified, the object name recorded
 	for the paths are not updated. Instead, these options
@@ -245,10 +251,10 @@ USING --CACHEINFO OR --INFO-ONLY
 current working directory.  This is useful for minimum-checkout
 merging.
 
-To pretend you have a file with mode and sha1 at path, say:
+To pretend you have a file at path with mode and sha1, say:
 
 ----------------
-$ git update-index --cacheinfo <mode>,<sha1>,<path>
+$ git update-index --add --cacheinfo <mode>,<sha1>,<path>
 ----------------
 
 `--info-only` is used to register files without placing them in the object
@@ -268,23 +274,20 @@ USING --INDEX-INFO
 multiple entry definitions from the standard input, and designed
 specifically for scripts.  It can take inputs of three formats:
 
-    . mode         SP sha1          TAB path
-+
-The first format is what "git-apply --index-info"
-reports, and used to reconstruct a partial tree
-that is used for phony merge base tree when falling
-back on 3-way merge.
-
     . mode SP type SP sha1          TAB path
 +
-The second format is to stuff 'git ls-tree' output
-into the index file.
+This format is to stuff `git ls-tree` output into the index.
 
     . mode         SP sha1 SP stage TAB path
 +
 This format is to put higher order stages into the
 index file and matches 'git ls-files --stage' output.
 
+    . mode         SP sha1          TAB path
++
+This format is no longer produced by any Git command, but is
+and will continue to be supported by `update-index --index-info`.
+
 To place a higher stage entry to the index, the path should
 first be removed by feeding a mode=0 entry for the path, and
 then feeding necessary input lines in the third format.
@@ -429,7 +432,7 @@ specified by the splitIndex.sharedIndexE
 linkgit:git-config[1]).
 
 To avoid deleting a shared index file that is still used, its
-modification time is updated to the current time everytime a new split
+modification time is updated to the current time every time a new split
 index based on the shared index file is either created or read from.
 
 UNTRACKED CACHE
@@ -546,6 +549,22 @@ The untracked cache extension can be ena
 `core.untrackedCache` configuration variable (see
 linkgit:git-config[1]).
 
+NOTES
+-----
+
+Users often try to use the assume-unchanged and skip-worktree bits
+to tell Git to ignore changes to files that are tracked.  This does not
+work as expected, since Git may still check working tree files against
+the index when performing certain operations.  In general, Git does not
+provide a way to ignore changes to tracked files, so alternate solutions
+are recommended.
+
+For example, if the file you want to change is some sort of config file,
+the repository can include a sample config file that can then be copied
+into the ignored name and modified.  The repository can even include a
+script to treat the sample file as a template, modifying and copying it
+automatically.
+
 SEE ALSO
 --------
 linkgit:git-config[1],
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/git-update-ref.txt 1.2.3+git2.25.1-1/git/Documentation/git-update-ref.txt
--- 1.2.1+git2.18.0-1/git/Documentation/git-update-ref.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/git-update-ref.txt	2020-02-17 04:47:35.000000000 +0000
@@ -8,7 +8,7 @@ git-update-ref - Update the object name
 SYNOPSIS
 --------
 [verse]
-'git update-ref' [-m <reason>] (-d <ref> [<oldvalue>] | [--no-deref] [--create-reflog] <ref> <newvalue> [<oldvalue>] | --stdin [-z])
+'git update-ref' [-m <reason>] [--no-deref] (-d <ref> [<oldvalue>] | [--create-reflog] <ref> <newvalue> [<oldvalue>] | --stdin [-z])
 
 DESCRIPTION
 -----------
@@ -129,8 +129,8 @@ a line to the log file "$GIT_DIR/logs/<r
 symbolic refs before creating the log name) describing the change
 in ref value.  Log lines are formatted as:
 
-    . oldsha1 SP newsha1 SP committer LF
-+
+    oldsha1 SP newsha1 SP committer LF
+
 Where "oldsha1" is the 40 character hexadecimal value previously
 stored in <ref>, "newsha1" is the 40 character hexadecimal value of
 <newvalue> and "committer" is the committer's name, email address
@@ -138,8 +138,8 @@ and date in the standard Git committer i
 
 Optionally with -m:
 
-    . oldsha1 SP newsha1 SP committer TAB message LF
-+
+    oldsha1 SP newsha1 SP committer TAB message LF
+
 Where all fields are as described above and "message" is the
 value supplied to the -m option.
 
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/git-update-server-info.txt 1.2.3+git2.25.1-1/git/Documentation/git-update-server-info.txt
--- 1.2.1+git2.18.0-1/git/Documentation/git-update-server-info.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/git-update-server-info.txt	2020-02-17 04:47:35.000000000 +0000
@@ -9,7 +9,7 @@ git-update-server-info - Update auxiliar
 SYNOPSIS
 --------
 [verse]
-'git update-server-info' [--force]
+'git update-server-info'
 
 DESCRIPTION
 -----------
@@ -19,15 +19,6 @@ $GIT_OBJECT_DIRECTORY/info directories t
 what references and packs the server has.  This command
 generates such auxiliary files.
 
-
-OPTIONS
--------
-
--f::
---force::
-	Update the info files from scratch.
-
-
 OUTPUT
 ------
 
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/git-upload-pack.txt 1.2.3+git2.25.1-1/git/Documentation/git-upload-pack.txt
--- 1.2.1+git2.18.0-1/git/Documentation/git-upload-pack.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/git-upload-pack.txt	2020-02-17 04:47:35.000000000 +0000
@@ -11,6 +11,7 @@ SYNOPSIS
 [verse]
 'git-upload-pack' [--[no-]strict] [--timeout=<n>] [--stateless-rpc]
 		  [--advertise-refs] <directory>
+
 DESCRIPTION
 -----------
 Invoked by 'git fetch-pack', learns what
@@ -21,7 +22,6 @@ The UI for the protocol is on the 'git f
 program pair is meant to be used to pull updates from a remote
 repository.  For push operations, see 'git send-pack'.
 
-
 OPTIONS
 -------
 
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/git-web--browse.txt 1.2.3+git2.25.1-1/git/Documentation/git-web--browse.txt
--- 1.2.1+git2.18.0-1/git/Documentation/git-web--browse.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/git-web--browse.txt	2020-02-17 04:47:35.000000000 +0000
@@ -92,8 +92,8 @@ configuration variable, we launch 'kfmcl
 man page on an already opened konqueror in a new tab if possible.
 
 For consistency, we also try such a trick if 'browser.konqueror.path' is
-set to something like 'A_PATH_TO/konqueror'. That means we will try to
-launch 'A_PATH_TO/kfmclient' instead.
+set to something like `A_PATH_TO/konqueror`. That means we will try to
+launch `A_PATH_TO/kfmclient` instead.
 
 If you really want to use 'konqueror', then you can use something like
 the following:
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/gitweb.conf.txt 1.2.3+git2.25.1-1/git/Documentation/gitweb.conf.txt
--- 1.2.1+git2.18.0-1/git/Documentation/gitweb.conf.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/gitweb.conf.txt	2020-02-17 04:47:35.000000000 +0000
@@ -19,10 +19,12 @@ end of a line is ignored.  See *perlsyn*
 
 An example:
 
-    # gitweb configuration file for http://git.example.org
-    #
-    our $projectroot = "/srv/git"; # FHS recommendation
-    our $site_name = 'Example.org >> Repos';
+------------------------------------------------
+# gitweb configuration file for http://git.example.org
+#
+our $projectroot = "/srv/git"; # FHS recommendation
+our $site_name = 'Example.org >> Repos';
+------------------------------------------------
 
 
 The configuration file is used to override the default settings that
@@ -48,11 +50,11 @@ following order:
  * built-in values (some set during build stage),
 
  * common system-wide configuration file (defaults to
-   '/etc/gitweb-common.conf'),
+   `/etc/gitweb-common.conf`),
 
  * either per-instance configuration file (defaults to 'gitweb_config.perl'
    in the same directory as the installed gitweb), or if it does not exists
-   then fallback system-wide configuration file (defaults to '/etc/gitweb.conf').
+   then fallback system-wide configuration file (defaults to `/etc/gitweb.conf`).
 
 Values obtained in later configuration files override values obtained earlier
 in the above sequence.
@@ -80,7 +82,7 @@ You can include other configuration file
 subroutine.  For example, one might want to put gitweb configuration
 related to access control for viewing repositories via Gitolite (one
 of Git repository management tools) in a separate file, e.g. in
-'/etc/gitweb-gitolite.conf'.  To include it, put
+`/etc/gitweb-gitolite.conf`.  To include it, put
 
 --------------------------------------------------
 read_config_file("/etc/gitweb-gitolite.conf");
@@ -140,7 +142,7 @@ and its path_info based equivalent
 http://git.example.com/gitweb.cgi/foo/bar.git
 ------------------------------------------------
 +
-will map to the path '/srv/git/foo/bar.git' on the filesystem.
+will map to the path `/srv/git/foo/bar.git` on the filesystem.
 
 $projects_list::
 	Name of a plain text file listing projects, or a name of directory
@@ -205,8 +207,8 @@ subsection on linkgit:gitweb[1] manpage.
 
 $strict_export::
 	Only allow viewing of repositories also shown on the overview page.
-	This for example makes `$gitweb_export_ok` file decide if repository is
-	available and not only if it is shown.  If `$gitweb_list` points to
+	This for example makes `$export_ok` file decide if repository is
+	available and not only if it is shown.  If `$projects_list` points to
 	file with list of project, only those repositories listed would be
 	available for gitweb.  Can be set during building gitweb via
 	`GITWEB_STRICT_EXPORT`.  By default this variable is not set, which
@@ -232,9 +234,9 @@ $GIT::
 
 $mimetypes_file::
 	File to use for (filename extension based) guessing of MIME types before
-	trying '/etc/mime.types'.  *NOTE* that this path, if relative, is taken
+	trying `/etc/mime.types`.  *NOTE* that this path, if relative, is taken
 	as relative to the current Git repository, not to CGI script.  If unset,
-	only '/etc/mime.types' is used (if present on filesystem).  If no mimetypes
+	only `/etc/mime.types` is used (if present on filesystem).  If no mimetypes
 	file is found, mimetype guessing based on extension of file is disabled.
 	Unset by default.
 
@@ -295,8 +297,8 @@ relative to base URI of gitweb.
 +
 This list should contain the URI of gitweb's standard stylesheet.  The default
 URI of gitweb stylesheet can be set at build time using the `GITWEB_CSS`
-makefile variable.  Its default value is 'static/gitweb.css'
-(or 'static/gitweb.min.css' if the `CSSMIN` variable is defined,
+makefile variable.  Its default value is `static/gitweb.css`
+(or `static/gitweb.min.css` if the `CSSMIN` variable is defined,
 i.e. if CSS minifier is used during build).
 +
 *Note*: there is also a legacy `$stylesheet` configuration variable, which was
@@ -309,7 +311,7 @@ $logo::
 	is displayed in the top right corner of each gitweb page and used as
 	a logo for the Atom feed.  Relative to the base URI of gitweb (as a path).
 	Can be adjusted when building gitweb using `GITWEB_LOGO` variable
-	By default set to 'static/git-logo.png'.
+	By default set to `static/git-logo.png`.
 
 $favicon::
 	Points to the location where you put 'git-favicon.png' on your web
@@ -318,7 +320,7 @@ $favicon::
 	may display them in the browser's URL bar and next to the site name in
 	bookmarks.  Relative to the base URI of gitweb.  Can be adjusted at
 	build time using `GITWEB_FAVICON` variable.
-	By default set to 'static/git-favicon.png'.
+	By default set to `static/git-favicon.png`.
 
 $javascript::
 	Points to the location where you put 'gitweb.js' on your web server,
@@ -326,7 +328,7 @@ $javascript::
 	Relative to the base URI of gitweb.  Can be set at build time using
 	the `GITWEB_JS` build-time configuration variable.
 +
-The default value is either 'static/gitweb.js', or 'static/gitweb.min.js' if
+The default value is either `static/gitweb.js`, or `static/gitweb.min.js` if
 the `JSMIN` build variable was defined, i.e. if JavaScript minifier was used
 at build time.  *Note* that this single file is generated from multiple
 individual JavaScript "modules".
@@ -357,6 +359,7 @@ $home_link_str::
 +
 For example, the following setting produces a breadcrumb trail like
 "home / dev / projects / ..." where "projects" is the home link.
++
 ----------------------------------------------------------------------------
     our @extra_breadcrumbs = (
       [ 'home' => 'https://www.example.org/' ],
@@ -441,7 +444,7 @@ $default_blob_plain_mimetype::
 	doesn't result in some other type; by default "text/plain".
 	Gitweb guesses mimetype of a file to display based on extension
 	of its filename, using `$mimetypes_file` (if set and file exists)
-	and '/etc/mime.types' files (see *mime.types*(5) manpage; only
+	and `/etc/mime.types` files (see *mime.types*(5) manpage; only
 	filename extension rules are supported by gitweb).
 
 $default_text_plain_charset::
@@ -483,7 +486,7 @@ affects how "summary" pages look like, o
 	(for example one for `git://` protocol, and one for `http://`
 	protocol).
 +
-Note that per repository configuration can be set in '$GIT_DIR/cloneurl'
+Note that per repository configuration can be set in `$GIT_DIR/cloneurl`
 file, or as values of multi-value `gitweb.url` configuration variable in
 project config.  Per-repository configuration takes precedence over value
 composed from `@git_base_url_list` elements and project name.
@@ -517,7 +520,7 @@ $maxload::
 	If the server load exceeds this value then gitweb will return
 	"503 Service Unavailable" error.  The server load is taken to be 0
 	if gitweb cannot determine its value.  Currently it works only on Linux,
-	where it uses '/proc/loadavg'; the load there is the number of active
+	where it uses `/proc/loadavg`; the load there is the number of active
 	tasks on the system -- processes that are actually running -- averaged
 	over the last minute.
 +
@@ -533,7 +536,7 @@ $omit_owner::
 
 $per_request_config::
 	If this is set to code reference, it will be run once for each request.
-	You can	set parts of configuration that change per session this way.
+	You can set parts of configuration that change per session this way.
 	For example, one might use the following code in a gitweb configuration
 	file
 +
@@ -681,7 +684,7 @@ compressed tar archive) and "zip"; pleas
 a definitive list.  By default only "tgz" is offered.
 +
 This feature can be configured on a per-repository basis via
-repository's `gitweb.blame` configuration variable, which contains
+repository's `gitweb.snapshot` configuration variable, which contains
 a comma separated list of formats or "none" to disable snapshots.
 Unknown values are ignored.
 
@@ -736,7 +739,7 @@ Currently available providers are *"grav
 Only one provider at a time can be selected ('default' is one element list).
 If an unknown provider is specified, the feature is disabled.
 *Note* that some providers might require extra Perl packages to be
-installed; see 'gitweb/INSTALL' for more details.
+installed; see `gitweb/INSTALL` for more details.
 +
 This feature can be configured on a per-repository basis via
 repository's `gitweb.avatar` configuration variable.
@@ -783,9 +786,9 @@ forks::
 	subdirectories of project root (basename) to be forks of existing
 	projects.  For each project +$projname.git+, projects in the
 	+$projname/+ directory and its subdirectories will not be
-	shown in the main projects list.  Instead, a \'\+' mark is shown
-	next to +$projname+, which links to a "forks" view that lists all
-	the forks (all projects in +$projname/+ subdirectory).  Additionally
+	shown in the main projects list.  Instead, a \'+' mark is shown
+	next to `$projname`, which links to a "forks" view that lists all
+	the forks (all projects in `$projname/` subdirectory).  Additionally
 	a "forks" view for a project is linked from project summary page.
 +
 If the project list is taken from a file (+$projects_list+ points to a
@@ -901,14 +904,16 @@ To enable blame, pickaxe search, and sna
 "zip" snapshots), while allowing individual projects to turn them off, put
 the following in your GITWEB_CONFIG file:
 
-	$feature{'blame'}{'default'} = [1];
-	$feature{'blame'}{'override'} = 1;
+--------------------------------------------------------------------------------
+$feature{'blame'}{'default'} = [1];
+$feature{'blame'}{'override'} = 1;
 
-	$feature{'pickaxe'}{'default'} = [1];
-	$feature{'pickaxe'}{'override'} = 1;
+$feature{'pickaxe'}{'default'} = [1];
+$feature{'pickaxe'}{'override'} = 1;
 
-	$feature{'snapshot'}{'default'} = ['zip', 'tgz'];
-	$feature{'snapshot'}{'override'} = 1;
+$feature{'snapshot'}{'default'} = ['zip', 'tgz'];
+$feature{'snapshot'}{'override'} = 1;
+--------------------------------------------------------------------------------
 
 If you allow overriding for the snapshot feature, you can specify which
 snapshot formats are globally disabled. You can also add any command-line
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/gitweb.txt 1.2.3+git2.25.1-1/git/Documentation/gitweb.txt
--- 1.2.1+git2.18.0-1/git/Documentation/gitweb.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/gitweb.txt	2020-02-17 04:47:35.000000000 +0000
@@ -28,15 +28,14 @@ Gitweb provides a web interface to Git r
   revisions one at a time, viewing the history of the repository.
 * Finding commits which commit messages matches given search term.
 
-See http://git.kernel.org/?p=git/git.git;a=tree;f=gitweb[] or
-http://repo.or.cz/w/git.git/tree/HEAD:/gitweb/[] for gitweb source code,
+See http://repo.or.cz/w/git.git/tree/HEAD:/gitweb/[] for gitweb source code,
 browsed using gitweb itself.
 
 
 CONFIGURATION
 -------------
 Various aspects of gitweb's behavior can be controlled through the configuration
-file 'gitweb_config.perl' or '/etc/gitweb.conf'.  See the linkgit:gitweb.conf[5]
+file `gitweb_config.perl` or `/etc/gitweb.conf`.  See the linkgit:gitweb.conf[5]
 for details.
 
 Repositories
@@ -51,7 +50,7 @@ projects' root" subsection).
 our $projectroot = '/path/to/parent/directory';
 -----------------------------------------------------------------------
 
-The default value for `$projectroot` is '/pub/git'.  You can change it during
+The default value for `$projectroot` is `/pub/git`.  You can change it during
 building gitweb via `GITWEB_PROJECTROOT` build configuration variable.
 
 By default all Git repositories under `$projectroot` are visible and available
@@ -231,7 +230,7 @@ Unnamed repository; edit this file to na
 -------------------------------------------------------------------------------
 +
 from the template during repository creation, usually installed in
-'/usr/share/git-core/templates/'.  You can use the `gitweb.description` repo
+`/usr/share/git-core/templates/`.  You can use the `gitweb.description` repo
 configuration variable, but the file takes precedence.
 
 category (or `gitweb.category`)::
@@ -407,7 +406,7 @@ in the instructions so they can be inclu
 Apache as CGI
 ~~~~~~~~~~~~~
 Apache must be configured to support CGI scripts in the directory in
-which gitweb is installed.  Let's assume that it is '/var/www/cgi-bin'
+which gitweb is installed.  Let's assume that it is `/var/www/cgi-bin`
 directory.
 
 -----------------------------------------------------------------------
@@ -431,7 +430,7 @@ You can use mod_perl with gitweb.  You m
 (for mod_perl 1.x) or ModPerl::Registry (for mod_perl 2.x) to enable
 this support.
 
-Assuming that gitweb is installed to '/var/www/perl', the following
+Assuming that gitweb is installed to `/var/www/perl`, the following
 Apache configuration (for mod_perl 2.x) is suitable.
 
 -----------------------------------------------------------------------
@@ -456,7 +455,7 @@ Apache with FastCGI
 ~~~~~~~~~~~~~~~~~~~
 Gitweb works with Apache and FastCGI.  First you need to rename, copy
 or symlink gitweb.cgi to gitweb.fcgi.  Let's assume that gitweb is
-installed in '/usr/share/gitweb' directory.  The following Apache
+installed in `/usr/share/gitweb` directory.  The following Apache
 configuration is suitable (UNTESTED!)
 
 -----------------------------------------------------------------------
@@ -503,22 +502,22 @@ repositories, you can configure Apache l
 -----------------------------------------------------------------------
 
 The above configuration expects your public repositories to live under
-'/pub/git' and will serve them as `http://git.domain.org/dir-under-pub-git`,
+`/pub/git` and will serve them as `http://git.domain.org/dir-under-pub-git`,
 both as clonable Git URL and as browseable gitweb interface.  If you then
 start your linkgit:git-daemon[1] with `--base-path=/pub/git --export-all`
 then you can even use the `git://` URL with exactly the same path.
 
 Setting the environment variable `GITWEB_CONFIG` will tell gitweb to use the
-named file (i.e. in this example '/etc/gitweb.conf') as a configuration for
+named file (i.e. in this example `/etc/gitweb.conf`) as a configuration for
 gitweb.  You don't really need it in above example; it is required only if
 your configuration file is in different place than built-in (during
-compiling gitweb) 'gitweb_config.perl' or '/etc/gitweb.conf'.  See
+compiling gitweb) 'gitweb_config.perl' or `/etc/gitweb.conf`.  See
 linkgit:gitweb.conf[5] for details, especially information about precedence
 rules.
 
 If you use the rewrite rules from the example you *might* also need
 something like the following in your gitweb configuration file
-('/etc/gitweb.conf' following example):
+(`/etc/gitweb.conf` following example):
 ----------------------------------------------------------------------------
 @stylesheets = ("/some/absolute/path/gitweb.css");
 $my_uri    = "/";
@@ -575,7 +574,7 @@ like this:
 
 Here actual project root is passed to gitweb via `GITWEB_PROJECT_ROOT`
 environment variable from a web server, so you need to put the following
-line in gitweb configuration file ('/etc/gitweb.conf' in above example):
+line in gitweb configuration file (`/etc/gitweb.conf` in above example):
 --------------------------------------------------------------------------
 $projectroot = $ENV{'GITWEB_PROJECTROOT'} || "/pub/git";
 --------------------------------------------------------------------------
@@ -585,7 +584,7 @@ referenced by `$per_request_config`;
 
 These configurations enable two things. First, each unix user (`<user>`) of
 the server will be able to browse through gitweb Git repositories found in
-'~/public_git/' with the following url:
+`~/public_git/` with the following url:
 
   http://git.example.org/~<user>/
 
@@ -596,7 +595,7 @@ If you already use `mod_userdir` in your
 use the \'~' as first character, just comment or remove the second rewrite
 rule, and uncomment one of the following according to what you want.
 
-Second, repositories found in '/pub/scm/' and '/var/git/' will be accessible
+Second, repositories found in `/pub/scm/` and `/var/git/` will be accessible
 through `http://git.example.org/scm/` and `http://git.example.org/var/`.
 You can add as many project roots as you want by adding rewrite rules like
 the third and the fourth.
@@ -614,7 +613,7 @@ that it consumes and produces URLs in th
   http://git.example.com/project.git/shortlog/sometag
 
 i.e. without 'gitweb.cgi' part, by using a configuration such as the
-following.  This configuration assumes that '/var/www/gitweb' is the
+following.  This configuration assumes that `/var/www/gitweb` is the
 DocumentRoot of your webserver, contains the gitweb.cgi script and
 complementary static files (stylesheet, favicon, JavaScript):
 
@@ -645,9 +644,9 @@ parameter.
 `@stylesheets`, `$my_uri` and `$home_link`, but you lose "dumb client"
 access to your project .git dirs (described in "Single URL for gitweb and
 for fetching" section).  A possible workaround for the latter is the
-following: in your project root dir (e.g. '/pub/git') have the projects
-named *without* a .git extension (e.g. '/pub/git/project' instead of
-'/pub/git/project.git') and configure Apache as follows:
+following: in your project root dir (e.g. `/pub/git`) have the projects
+named *without* a .git extension (e.g. `/pub/git/project` instead of
+`/pub/git/project.git`) and configure Apache as follows:
 ----------------------------------------------------------------------------
 <VirtualHost *:80>
 	ServerAlias git.example.com
@@ -681,7 +680,7 @@ cloned), while
 will provide human-friendly gitweb access.
 
 This solution is not 100% bulletproof, in the sense that if some project has
-a named ref (branch, tag) starting with 'git/', then paths such as
+a named ref (branch, tag) starting with `git/`, then paths such as
 
   http://git.example.com/project/command/abranch..git/abranch
 
@@ -697,7 +696,7 @@ SEE ALSO
 --------
 linkgit:gitweb.conf[5], linkgit:git-instaweb[1]
 
-'gitweb/README', 'gitweb/INSTALL'
+`gitweb/README`, `gitweb/INSTALL`
 
 GIT
 ---
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/gitworkflows.txt 1.2.3+git2.25.1-1/git/Documentation/gitworkflows.txt
--- 1.2.1+git2.18.0-1/git/Documentation/gitworkflows.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/gitworkflows.txt	2020-02-17 04:47:35.000000000 +0000
@@ -301,8 +301,7 @@ topics on 'next':
 .Rewind and rebuild next
 [caption="Recipe: "]
 =====================================
-* `git checkout next`
-* `git reset --hard master`
+* `git switch -C next master`
 * `git merge ai/topic_in_next1`
 * `git merge ai/topic_in_next2`
 * ...
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/git-worktree.txt 1.2.3+git2.25.1-1/git/Documentation/git-worktree.txt
--- 1.2.1+git2.18.0-1/git/Documentation/git-worktree.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/git-worktree.txt	2020-02-17 04:47:35.000000000 +0000
@@ -60,6 +60,15 @@ with a matching name, treat as equivalen
 $ git worktree add --track -b <branch> <path> <remote>/<branch>
 ------------
 +
+If the branch exists in multiple remotes and one of them is named by
+the `checkout.defaultRemote` configuration variable, we'll use that
+one for the purposes of disambiguation, even if the `<branch>` isn't
+unique across all remotes. Set it to
+e.g. `checkout.defaultRemote=origin` to always checkout remote
+branches from there if `<branch>` is ambiguous but exists on the
+'origin' remote. See also `checkout.defaultRemote` in
+linkgit:git-config[1].
++
 If `<commit-ish>` is omitted and neither `-b` nor `-B` nor `--detach` used,
 then, as a convenience, the new worktree is associated with a branch
 (call it `<branch>`) named after `$(basename <path>)`.  If `<branch>`
@@ -111,8 +120,16 @@ OPTIONS
 --force::
 	By default, `add` refuses to create a new working tree when
 	`<commit-ish>` is a branch name and is already checked out by
-	another working tree and `remove` refuses to remove an unclean
-	working tree. This option overrides these safeguards.
+	another working tree, or if `<path>` is already assigned to some
+	working tree but is missing (for instance, if `<path>` was deleted
+	manually). This option overrides these safeguards. To add a missing but
+	locked working tree path, specify `--force` twice.
++
+`move` refuses to move a locked working tree unless `--force` is specified
+twice.
++
+`remove` refuses to remove an unclean working tree unless `--force` is used.
+To remove a locked working tree, specify `--force` twice.
 
 -b <new-branch>::
 -B <new-branch>::
@@ -164,6 +181,10 @@ This can also be set up as the default b
 	This format will remain stable across Git versions and regardless of user
 	configuration.  See below for details.
 
+-q::
+--quiet::
+	With 'add', suppress feedback messages.
+
 -v::
 --verbose::
 	With `prune`, report all removals.
@@ -183,6 +204,65 @@ working trees, it can be used to identif
 you only have two working trees, at "/abc/def/ghi" and "/abc/def/ggg",
 then "ghi" or "def/ghi" is enough to point to the former working tree.
 
+REFS
+----
+In multiple working trees, some refs may be shared between all working
+trees, some refs are local. One example is HEAD is different for all
+working trees. This section is about the sharing rules and how to access
+refs of one working tree from another.
+
+In general, all pseudo refs are per working tree and all refs starting
+with "refs/" are shared. Pseudo refs are ones like HEAD which are
+directly under GIT_DIR instead of inside GIT_DIR/refs. There is one
+exception to this: refs inside refs/bisect and refs/worktree is not
+shared.
+
+Refs that are per working tree can still be accessed from another
+working tree via two special paths, main-worktree and worktrees. The
+former gives access to per-worktree refs of the main working tree,
+while the latter to all linked working trees.
+
+For example, main-worktree/HEAD or main-worktree/refs/bisect/good
+resolve to the same value as the main working tree's HEAD and
+refs/bisect/good respectively. Similarly, worktrees/foo/HEAD or
+worktrees/bar/refs/bisect/bad are the same as
+GIT_COMMON_DIR/worktrees/foo/HEAD and
+GIT_COMMON_DIR/worktrees/bar/refs/bisect/bad.
+
+To access refs, it's best not to look inside GIT_DIR directly. Instead
+use commands such as linkgit:git-rev-parse[1] or linkgit:git-update-ref[1]
+which will handle refs correctly.
+
+CONFIGURATION FILE
+------------------
+By default, the repository "config" file is shared across all working
+trees. If the config variables `core.bare` or `core.worktree` are
+already present in the config file, they will be applied to the main
+working trees only.
+
+In order to have configuration specific to working trees, you can turn
+on "worktreeConfig" extension, e.g.:
+
+------------
+$ git config extensions.worktreeConfig true
+------------
+
+In this mode, specific configuration stays in the path pointed by `git
+rev-parse --git-path config.worktree`. You can add or update
+configuration in this file with `git config --worktree`. Older Git
+versions will refuse to access repositories with this extension.
+
+Note that in this file, the exception for `core.bare` and `core.worktree`
+is gone. If you have them in $GIT_DIR/config before, you must move
+them to the `config.worktree` of the main working tree. You may also
+take this opportunity to review and move other configuration that you
+do not want to share to all working trees:
+
+ - `core.worktree` and `core.bare` should never be shared
+
+ - `core.sparseCheckout` is recommended per working tree, unless you
+   are sure you always use sparse checkout for all working trees.
+
 DETAILS
 -------
 Each linked working tree has a private sub-directory in the repository's
@@ -207,7 +287,8 @@ linked working tree `git rev-parse --git
 `/path/other/test-next/.git/HEAD` or `/path/main/.git/HEAD`) while `git
 rev-parse --git-path refs/heads/master` uses
 $GIT_COMMON_DIR and returns `/path/main/.git/refs/heads/master`,
-since refs are shared across all working trees.
+since refs are shared across all working trees, except refs/bisect and
+refs/worktree.
 
 See linkgit:gitrepository-layout[5] for more information. The rule of
 thumb is do not make any assumption about whether a path belongs to
@@ -232,6 +313,9 @@ to `/path/main/.git/worktrees/test-next`
 `test-next` entry from being pruned.  See
 linkgit:gitrepository-layout[5] for details.
 
+When extensions.worktreeConfig is enabled, the config file
+`.git/worktrees/<id>/config.worktree` is read after `.git/config` is.
+
 LIST OUTPUT FORMAT
 ------------------
 The worktree list command has two output formats.  The default format shows the
@@ -249,8 +333,8 @@ Porcelain Format
 The porcelain format has a line per attribute.  Attributes are listed with a
 label and value separated by a single space.  Boolean attributes (like 'bare'
 and 'detached') are listed as a label only, and are only present if and only
-if the value is true.  An empty line indicates the end of a worktree.  For
-example:
+if the value is true.  The first attribute of a worktree is always `worktree`,
+an empty line indicates the end of the record.  For example:
 
 ------------
 $ git worktree list --porcelain
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/glossary-content.txt 1.2.3+git2.25.1-1/git/Documentation/glossary-content.txt
--- 1.2.1+git2.18.0-1/git/Documentation/glossary-content.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/glossary-content.txt	2020-02-17 04:47:35.000000000 +0000
@@ -255,7 +255,7 @@ This commit is referred to as a "merge c
 [[def_object]]object::
 	The unit of storage in Git. It is uniquely identified by the
 	<<def_SHA1,SHA-1>> of its contents. Consequently, an
-	object can not be changed.
+	object cannot be changed.
 
 [[def_object_database]]object database::
 	Stores a set of "objects", and an individual <<def_object,object>> is
@@ -287,6 +287,15 @@ This commit is referred to as a "merge c
 	origin/name-of-upstream-branch, which you can see using
 	`git branch -r`.
 
+[[def_overlay]]overlay::
+	Only update and add files to the working directory, but don't
+	delete them, similar to how 'cp -R' would update the contents
+	in the destination directory.  This is the default mode in a
+	<<def_checkout,checkout>> when checking out files from the
+	<<def_index,index>> or a <<def_tree-ish,tree-ish>>.  In
+	contrast, no-overlay mode also deletes tracked files not
+	present in the source, similar to 'rsync --delete'.
+
 [[def_pack]]pack::
 	A set of objects which have been compressed into one file (to save space
 	or to transmit them efficiently).
@@ -334,7 +343,7 @@ The optional colon that terminates the "
 omitted if the pattern begins with a character that does not belong to
 "magic signature" symbol set and is not a colon.
 +
-In the long form, the leading colon `:` is followed by a open
+In the long form, the leading colon `:` is followed by an open
 parenthesis `(`, a comma-separated list of zero or more "magic words",
 and a close parentheses `)`, and the remainder is the pattern to match
 against the path.
@@ -404,6 +413,8 @@ these forms:
 - "`!ATTR`" requires that the attribute `ATTR` be
   unspecified.
 +
+Note that when matching against a tree object, attributes are still
+obtained from working tree, not from the given tree object.
 
 exclude;;
 	After a path matches any non-exclude pathspec, it will be run
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/howto/separating-topic-branches.txt 1.2.3+git2.25.1-1/git/Documentation/howto/separating-topic-branches.txt
--- 1.2.1+git2.18.0-1/git/Documentation/howto/separating-topic-branches.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/howto/separating-topic-branches.txt	2020-02-17 04:47:35.000000000 +0000
@@ -81,7 +81,7 @@ After I am done, I'd try a pretend-merge
               o---o---o---o---o---o
 
 The last diff better not to show anything other than cleanups
-for crufts.  Then I can finally clean things up:
+for cruft.  Then I can finally clean things up:
 
         $ git branch -D topic
         $ git reset --hard HEAD^ ;# nuke pretend merge
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/howto/setup-git-server-over-http.txt 1.2.3+git2.25.1-1/git/Documentation/howto/setup-git-server-over-http.txt
--- 1.2.1+git2.18.0-1/git/Documentation/howto/setup-git-server-over-http.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/howto/setup-git-server-over-http.txt	2020-02-17 04:47:35.000000000 +0000
@@ -244,8 +244,8 @@ Using a proxy:
 --------------
 
 If you have to access the WebDAV server from behind an HTTP(S) proxy,
-set the variable 'all_proxy' to 'http://proxy-host.com:port', or
-'http://login-on-proxy:passwd-on-proxy@proxy-host.com:port'. See 'man
+set the variable 'all_proxy' to `http://proxy-host.com:port`, or
+`http://login-on-proxy:passwd-on-proxy@proxy-host.com:port`. See 'man
 curl' for details.
 
 
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/howto/update-hook-example.txt 1.2.3+git2.25.1-1/git/Documentation/howto/update-hook-example.txt
--- 1.2.1+git2.18.0-1/git/Documentation/howto/update-hook-example.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/howto/update-hook-example.txt	2020-02-17 04:47:35.000000000 +0000
@@ -80,7 +80,7 @@ case "$1" in
       info "The branch '$1' is new..."
     else
       # updating -- make sure it is a fast-forward
-      mb=$(git-merge-base "$2" "$3")
+      mb=$(git merge-base "$2" "$3")
       case "$mb,$2" in
         "$2,$mb") info "Update is fast-forward" ;;
 	*)	  noff=y; info "This is not a fast-forward update.";;
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/howto/using-merge-subtree.txt 1.2.3+git2.25.1-1/git/Documentation/howto/using-merge-subtree.txt
--- 1.2.1+git2.18.0-1/git/Documentation/howto/using-merge-subtree.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/howto/using-merge-subtree.txt	2020-02-17 04:47:35.000000000 +0000
@@ -33,7 +33,7 @@ Here is the command sequence you need:
 
 ----------------
 $ git remote add -f Bproject /path/to/B <1>
-$ git merge -s ours --no-commit Bproject/master <2>
+$ git merge -s ours --no-commit --allow-unrelated-histories Bproject/master <2>
 $ git read-tree --prefix=dir-B/ -u Bproject/master <3>
 $ git commit -m "Merge B project as our subdirectory" <4>
 
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/Makefile 1.2.3+git2.25.1-1/git/Documentation/Makefile
--- 1.2.1+git2.18.0-1/git/Documentation/Makefile	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/Makefile	2020-02-17 04:47:35.000000000 +0000
@@ -7,12 +7,14 @@ ARTICLES =
 SP_ARTICLES =
 OBSOLETE_HTML =
 
+-include GIT-EXCLUDED-PROGRAMS
+
 MAN1_TXT += $(filter-out \
+		$(patsubst %,%.txt,$(EXCLUDED_PROGRAMS)) \
 		$(addsuffix .txt, $(ARTICLES) $(SP_ARTICLES)), \
 		$(wildcard git-*.txt))
 MAN1_TXT += git.txt
 MAN1_TXT += gitk.txt
-MAN1_TXT += gitremote-helpers.txt
 MAN1_TXT += gitweb.txt
 
 MAN5_TXT += gitattributes.txt
@@ -30,20 +32,26 @@ MAN7_TXT += gitdiffcore.txt
 MAN7_TXT += giteveryday.txt
 MAN7_TXT += gitglossary.txt
 MAN7_TXT += gitnamespaces.txt
+MAN7_TXT += gitremote-helpers.txt
 MAN7_TXT += gitrevisions.txt
 MAN7_TXT += gitsubmodules.txt
 MAN7_TXT += gittutorial-2.txt
 MAN7_TXT += gittutorial.txt
 MAN7_TXT += gitworkflows.txt
 
+ifdef MAN_FILTER
+MAN_TXT = $(filter $(MAN_FILTER),$(MAN1_TXT) $(MAN5_TXT) $(MAN7_TXT))
+else
 MAN_TXT = $(MAN1_TXT) $(MAN5_TXT) $(MAN7_TXT)
+MAN_FILTER = $(MAN_TXT)
+endif
+
 MAN_XML = $(patsubst %.txt,%.xml,$(MAN_TXT))
 MAN_HTML = $(patsubst %.txt,%.html,$(MAN_TXT))
 GIT_MAN_REF = master
 
 OBSOLETE_HTML += everyday.html
 OBSOLETE_HTML += git-remote-helpers.html
-DOC_HTML = $(MAN_HTML) $(OBSOLETE_HTML)
 
 ARTICLES += howto-index
 ARTICLES += git-tools
@@ -68,14 +76,18 @@ SP_ARTICLES += howto/maintain-git
 API_DOCS = $(patsubst %.txt,%,$(filter-out technical/api-index-skel.txt technical/api-index.txt, $(wildcard technical/api-*.txt)))
 SP_ARTICLES += $(API_DOCS)
 
+TECH_DOCS += MyFirstContribution
+TECH_DOCS += MyFirstObjectWalk
 TECH_DOCS += SubmittingPatches
 TECH_DOCS += technical/hash-function-transition
 TECH_DOCS += technical/http-protocol
 TECH_DOCS += technical/index-format
 TECH_DOCS += technical/long-running-process-protocol
+TECH_DOCS += technical/multi-pack-index
 TECH_DOCS += technical/pack-format
 TECH_DOCS += technical/pack-heuristics
 TECH_DOCS += technical/pack-protocol
+TECH_DOCS += technical/partial-clone
 TECH_DOCS += technical/protocol-capabilities
 TECH_DOCS += technical/protocol-common
 TECH_DOCS += technical/protocol-v2
@@ -87,11 +99,13 @@ TECH_DOCS += technical/trivial-merge
 SP_ARTICLES += $(TECH_DOCS)
 SP_ARTICLES += technical/api-index
 
-DOC_HTML += $(patsubst %,%.html,$(ARTICLES) $(SP_ARTICLES))
-
-DOC_MAN1 = $(patsubst %.txt,%.1,$(MAN1_TXT))
-DOC_MAN5 = $(patsubst %.txt,%.5,$(MAN5_TXT))
-DOC_MAN7 = $(patsubst %.txt,%.7,$(MAN7_TXT))
+ARTICLES_HTML += $(patsubst %,%.html,$(ARTICLES) $(SP_ARTICLES))
+HTML_FILTER ?= $(ARTICLES_HTML) $(OBSOLETE_HTML)
+DOC_HTML = $(MAN_HTML) $(filter $(HTML_FILTER),$(ARTICLES_HTML) $(OBSOLETE_HTML))
+
+DOC_MAN1 = $(patsubst %.txt,%.1,$(filter $(MAN_FILTER),$(MAN1_TXT)))
+DOC_MAN5 = $(patsubst %.txt,%.5,$(filter $(MAN_FILTER),$(MAN5_TXT)))
+DOC_MAN7 = $(patsubst %.txt,%.7,$(filter $(MAN_FILTER),$(MAN7_TXT)))
 
 prefix ?= $(HOME)
 bindir ?= $(prefix)/bin
@@ -110,7 +124,8 @@ ASCIIDOC_HTML = xhtml11
 ASCIIDOC_DOCBOOK = docbook
 ASCIIDOC_CONF = -f asciidoc.conf
 ASCIIDOC_COMMON = $(ASCIIDOC) $(ASCIIDOC_EXTRA) $(ASCIIDOC_CONF) \
-		-agit_version=$(GIT_VERSION)
+		-amanversion=$(GIT_VERSION) \
+		-amanmanual='Git Manual' -amansource='Git'
 TXT_TO_HTML = $(ASCIIDOC_COMMON) -b $(ASCIIDOC_HTML)
 TXT_TO_XML = $(ASCIIDOC_COMMON) -b $(ASCIIDOC_DOCBOOK)
 MANPAGE_XSL = manpage-normal.xsl
@@ -184,11 +199,13 @@ ifdef USE_ASCIIDOCTOR
 ASCIIDOC = asciidoctor
 ASCIIDOC_CONF =
 ASCIIDOC_HTML = xhtml5
-ASCIIDOC_DOCBOOK = docbook45
+ASCIIDOC_DOCBOOK = docbook5
 ASCIIDOC_EXTRA += -acompat-mode -atabsize=8
 ASCIIDOC_EXTRA += -I. -rasciidoctor-extensions
 ASCIIDOC_EXTRA += -alitdd='&\#x2d;&\#x2d;'
 DBLATEX_COMMON =
+XMLTO_EXTRA += --skip-validation
+XMLTO_EXTRA += -x manpage.xsl
 endif
 
 SHELL_PATH ?= $(SHELL)
@@ -284,7 +301,7 @@ docdep_prereqs = \
 	mergetools-list.made $(mergetools_txt) \
 	cmd-list.made $(cmds_txt)
 
-doc.dep : $(docdep_prereqs) $(wildcard *.txt) build-docdep.perl
+doc.dep : $(docdep_prereqs) $(wildcard *.txt) $(wildcard config/*.txt) build-docdep.perl
 	$(QUIET_GEN)$(RM) $@+ $@ && \
 	$(PERL_PATH) ./build-docdep.perl >$@+ $(QUIET_STDERR) && \
 	mv $@+ $@
@@ -322,6 +339,15 @@ mergetools-list.made: ../git-mergetool--
 		show_tool_names can_merge "* " || :' >mergetools-merge.txt && \
 	date >$@
 
+TRACK_ASCIIDOCFLAGS = $(subst ','\'',$(ASCIIDOC_COMMON):$(ASCIIDOC_HTML):$(ASCIIDOC_DOCBOOK))
+
+GIT-ASCIIDOCFLAGS: FORCE
+	@FLAGS='$(TRACK_ASCIIDOCFLAGS)'; \
+	    if test x"$$FLAGS" != x"`cat GIT-ASCIIDOCFLAGS 2>/dev/null`" ; then \
+		echo >&2 "    * new asciidoc flags"; \
+		echo "$$FLAGS" >GIT-ASCIIDOCFLAGS; \
+            fi
+
 clean:
 	$(RM) *.xml *.xml+ *.html *.html+ *.1 *.5 *.7
 	$(RM) *.texi *.texi+ *.texi++ git.info gitman.info
@@ -331,30 +357,31 @@ clean:
 	$(RM) SubmittingPatches.txt
 	$(RM) $(cmds_txt) $(mergetools_txt) *.made
 	$(RM) manpage-base-url.xsl
+	$(RM) GIT-ASCIIDOCFLAGS
 
-$(MAN_HTML): %.html : %.txt asciidoc.conf
+$(MAN_HTML): %.html : %.txt asciidoc.conf asciidoctor-extensions.rb GIT-ASCIIDOCFLAGS
 	$(QUIET_ASCIIDOC)$(RM) $@+ $@ && \
 	$(TXT_TO_HTML) -d manpage -o $@+ $< && \
 	mv $@+ $@
 
-$(OBSOLETE_HTML): %.html : %.txto asciidoc.conf
+$(OBSOLETE_HTML): %.html : %.txto asciidoc.conf asciidoctor-extensions.rb GIT-ASCIIDOCFLAGS
 	$(QUIET_ASCIIDOC)$(RM) $@+ $@ && \
 	$(TXT_TO_HTML) -o $@+ $< && \
 	mv $@+ $@
 
 manpage-base-url.xsl: manpage-base-url.xsl.in
-	sed "s|@@MAN_BASE_URL@@|$(MAN_BASE_URL)|" $< > $@
+	$(QUIET_GEN)sed "s|@@MAN_BASE_URL@@|$(MAN_BASE_URL)|" $< > $@
 
-%.1 %.5 %.7 : %.xml manpage-base-url.xsl
+%.1 %.5 %.7 : %.xml manpage-base-url.xsl $(wildcard manpage*.xsl)
 	$(QUIET_XMLTO)$(RM) $@ && \
 	$(XMLTO) -m $(MANPAGE_XSL) $(XMLTO_EXTRA) man $<
 
-%.xml : %.txt asciidoc.conf
+%.xml : %.txt asciidoc.conf asciidoctor-extensions.rb GIT-ASCIIDOCFLAGS
 	$(QUIET_ASCIIDOC)$(RM) $@+ $@ && \
 	$(TXT_TO_XML) -d manpage -o $@+ $< && \
 	mv $@+ $@
 
-user-manual.xml: user-manual.txt user-manual.conf
+user-manual.xml: user-manual.txt user-manual.conf asciidoctor-extensions.rb GIT-ASCIIDOCFLAGS
 	$(QUIET_ASCIIDOC)$(RM) $@+ $@ && \
 	$(TXT_TO_XML) -d book -o $@+ $< && \
 	mv $@+ $@
@@ -364,7 +391,8 @@ technical/api-index.txt: technical/api-i
 	$(QUIET_GEN)cd technical && '$(SHELL_PATH_SQ)' ./api-index.sh
 
 technical/%.html: ASCIIDOC_EXTRA += -a git-relative-html-prefix=../
-$(patsubst %,%.html,$(API_DOCS) technical/api-index $(TECH_DOCS)): %.html : %.txt asciidoc.conf
+$(patsubst %,%.html,$(API_DOCS) technical/api-index $(TECH_DOCS)): %.html : %.txt \
+	asciidoc.conf GIT-ASCIIDOCFLAGS
 	$(QUIET_ASCIIDOC)$(TXT_TO_HTML) $*.txt
 
 SubmittingPatches.txt: SubmittingPatches
@@ -421,7 +449,7 @@ $(patsubst %,%.html,$(ARTICLES)) : %.htm
 WEBDOC_DEST = /pub/software/scm/git/docs
 
 howto/%.html: ASCIIDOC_EXTRA += -a git-relative-html-prefix=../
-$(patsubst %.txt,%.html,$(wildcard howto/*.txt)): %.html : %.txt
+$(patsubst %.txt,%.html,$(wildcard howto/*.txt)): %.html : %.txt GIT-ASCIIDOCFLAGS
 	$(QUIET_ASCIIDOC)$(RM) $@+ $@ && \
 	sed -e '1,/^$$/d' $< | \
 	$(TXT_TO_HTML) - >$@+ && \
@@ -455,4 +483,9 @@ print-man1:
 lint-docs::
 	$(QUIET_LINT)$(PERL_PATH) lint-gitlink.perl
 
+ifeq ($(wildcard po/Makefile),po/Makefile)
+doc-l10n install-l10n::
+	$(MAKE) -C po $@
+endif
+
 .PHONY: FORCE
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/manpage-bold-literal.xsl 1.2.3+git2.25.1-1/git/Documentation/manpage-bold-literal.xsl
--- 1.2.1+git2.18.0-1/git/Documentation/manpage-bold-literal.xsl	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/manpage-bold-literal.xsl	2020-02-17 04:47:35.000000000 +0000
@@ -1,12 +1,13 @@
 <!-- manpage-bold-literal.xsl:
      special formatting for manpages rendered from asciidoc+docbook -->
 <xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
+		xmlns:d="http://docbook.org/ns/docbook"
 		version="1.0">
 
 <!-- render literal text as bold (instead of plain or monospace);
      this makes literal text easier to distinguish in manpages
      viewed on a tty -->
-<xsl:template match="literal">
+<xsl:template match="literal|d:literal">
 	<xsl:value-of select="$git.docbook.backslash"/>
 	<xsl:text>fB</xsl:text>
 	<xsl:apply-templates/>
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/manpage.xsl 1.2.3+git2.25.1-1/git/Documentation/manpage.xsl
--- 1.2.1+git2.18.0-1/git/Documentation/manpage.xsl	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/manpage.xsl	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,3 @@
+<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">
+	<xsl:import href="http://docbook.sourceforge.net/release/xsl-ns/current/manpages/docbook.xsl" />
+</xsl:stylesheet>
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/merge-config.txt 1.2.3+git2.25.1-1/git/Documentation/merge-config.txt
--- 1.2.1+git2.18.0-1/git/Documentation/merge-config.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/merge-config.txt	1970-01-01 00:00:00.000000000 +0000
@@ -1,87 +0,0 @@
-merge.conflictStyle::
-	Specify the style in which conflicted hunks are written out to
-	working tree files upon merge.  The default is "merge", which
-	shows a `<<<<<<<` conflict marker, changes made by one side,
-	a `=======` marker, changes made by the other side, and then
-	a `>>>>>>>` marker.  An alternate style, "diff3", adds a `|||||||`
-	marker and the original text before the `=======` marker.
-
-merge.defaultToUpstream::
-	If merge is called without any commit argument, merge the upstream
-	branches configured for the current branch by using their last
-	observed values stored in their remote-tracking branches.
-	The values of the `branch.<current branch>.merge` that name the
-	branches at the remote named by `branch.<current branch>.remote`
-	are consulted, and then they are mapped via `remote.<remote>.fetch`
-	to their corresponding remote-tracking branches, and the tips of
-	these tracking branches are merged.
-
-merge.ff::
-	By default, Git does not create an extra merge commit when merging
-	a commit that is a descendant of the current commit. Instead, the
-	tip of the current branch is fast-forwarded. When set to `false`,
-	this variable tells Git to create an extra merge commit in such
-	a case (equivalent to giving the `--no-ff` option from the command
-	line). When set to `only`, only such fast-forward merges are
-	allowed (equivalent to giving the `--ff-only` option from the
-	command line).
-
-merge.verifySignatures::
-	If true, this is equivalent to the --verify-signatures command
-	line option. See linkgit:git-merge[1] for details.
-
-include::fmt-merge-msg-config.txt[]
-
-merge.renameLimit::
-	The number of files to consider when performing rename detection
-	during a merge; if not specified, defaults to the value of
-	diff.renameLimit. This setting has no effect if rename detection
-	is turned off.
-
-merge.renames::
-	Whether and how Git detects renames.  If set to "false",
-	rename detection is disabled. If set to "true", basic rename
-	detection is enabled.  Defaults to the value of diff.renames.
-
-merge.renormalize::
-	Tell Git that canonical representation of files in the
-	repository has changed over time (e.g. earlier commits record
-	text files with CRLF line endings, but recent ones use LF line
-	endings).  In such a repository, Git can convert the data
-	recorded in commits to a canonical form before performing a
-	merge to reduce unnecessary conflicts.  For more information,
-	see section "Merging branches with differing checkin/checkout
-	attributes" in linkgit:gitattributes[5].
-
-merge.stat::
-	Whether to print the diffstat between ORIG_HEAD and the merge result
-	at the end of the merge.  True by default.
-
-merge.tool::
-	Controls which merge tool is used by linkgit:git-mergetool[1].
-	The list below shows the valid built-in values.
-	Any other value is treated as a custom merge tool and requires
-	that a corresponding mergetool.<tool>.cmd variable is defined.
-
-include::mergetools-merge.txt[]
-
-merge.verbosity::
-	Controls the amount of output shown by the recursive merge
-	strategy.  Level 0 outputs nothing except a final error
-	message if conflicts were detected. Level 1 outputs only
-	conflicts, 2 outputs conflicts and file changes.  Level 5 and
-	above outputs debugging information.  The default is level 2.
-	Can be overridden by the `GIT_MERGE_VERBOSITY` environment variable.
-
-merge.<driver>.name::
-	Defines a human-readable name for a custom low-level
-	merge driver.  See linkgit:gitattributes[5] for details.
-
-merge.<driver>.driver::
-	Defines the command that implements a custom low-level
-	merge driver.  See linkgit:gitattributes[5] for details.
-
-merge.<driver>.recursive::
-	Names a low-level merge driver to be used when
-	performing an internal merge between common ancestors.
-	See linkgit:gitattributes[5] for details.
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/merge-options.txt 1.2.3+git2.25.1-1/git/Documentation/merge-options.txt
--- 1.2.1+git2.18.0-1/git/Documentation/merge-options.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/merge-options.txt	2020-02-17 04:47:35.000000000 +0000
@@ -3,9 +3,14 @@
 	Perform the merge and commit the result. This option can
 	be used to override --no-commit.
 +
-With --no-commit perform the merge but pretend the merge
-failed and do not autocommit, to give the user a chance to
-inspect and further tweak the merge result before committing.
+With --no-commit perform the merge and stop just before creating
+a merge commit, to give the user a chance to inspect and further
+tweak the merge result before committing.
++
+Note that fast-forward updates do not create a merge commit and
+therefore there is no way to stop those merges with --no-commit.
+Thus, if you want to ensure your branch is not changed or updated
+by the merge command, use --no-ff with --no-commit.
 
 --edit::
 -e::
@@ -27,21 +32,32 @@ they run `git merge`. To make it easier
 updated behaviour, the environment variable `GIT_MERGE_AUTOEDIT` can be
 set to `no` at the beginning of them.
 
---ff::
-	When the merge resolves as a fast-forward, only update the branch
-	pointer, without creating a merge commit.  This is the default
-	behavior.
+--cleanup=<mode>::
+	This option determines how the merge message will be cleaned up before
+	committing. See linkgit:git-commit[1] for more details. In addition, if
+	the '<mode>' is given a value of `scissors`, scissors will be appended
+	to `MERGE_MSG` before being passed on to the commit machinery in the
+	case of a merge conflict.
 
+--ff::
 --no-ff::
-	Create a merge commit even when the merge resolves as a
-	fast-forward.  This is the default behaviour when merging an
-	annotated (and possibly signed) tag that is not stored in
-	its natural place in 'refs/tags/' hierarchy.
-
 --ff-only::
-	Refuse to merge and exit with a non-zero status unless the
-	current `HEAD` is already up to date or the merge can be
-	resolved as a fast-forward.
+	Specifies how a merge is handled when the merged-in history is
+	already a descendant of the current history.  `--ff` is the
+	default unless merging an annotated (and possibly signed) tag
+	that is not stored in its natural place in the `refs/tags/`
+	hierarchy, in which case `--no-ff` is assumed.
++
+With `--ff`, when possible resolve the merge as a fast-forward (only
+update the branch pointer to match the merged branch; do not create a
+merge commit).  When not possible (when the merged-in history is not a
+descendant of the current history), create a merge commit.
++
+With `--no-ff`, create a merge commit in all cases, even when the merge
+could instead be resolved as a fast-forward.
++
+With `--ff-only`, resolve the merge as a fast-forward when possible.
+When not possible, refuse to merge and exit with a non-zero status.
 
 -S[<keyid>]::
 --gpg-sign[=<keyid>]::
@@ -90,6 +106,12 @@ merge.
 +
 With --no-squash perform the merge and commit the result. This
 option can be used to override --squash.
++
+With --squash, --commit is not allowed, and will fail.
+
+--no-verify::
+	This option bypasses the pre-merge and commit-msg hooks.
+	See also linkgit:githooks[5].
 
 -s <strategy>::
 --strategy=<strategy>::
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/merge-strategies.txt 1.2.3+git2.25.1-1/git/Documentation/merge-strategies.txt
--- 1.2.1+git2.18.0-1/git/Documentation/merge-strategies.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/merge-strategies.txt	2020-02-17 04:47:35.000000000 +0000
@@ -32,7 +32,7 @@ The 'recursive' strategy can take the fo
 ours;;
 	This option forces conflicting hunks to be auto-resolved cleanly by
 	favoring 'our' version.  Changes from the other tree that do not
-	conflict with our side are reflected to the merge result.
+	conflict with our side are reflected in the merge result.
 	For a binary file, the entire contents are taken from our side.
 +
 This should not be confused with the 'ours' merge strategy, which does not
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/MyFirstContribution.txt 1.2.3+git2.25.1-1/git/Documentation/MyFirstContribution.txt
--- 1.2.1+git2.18.0-1/git/Documentation/MyFirstContribution.txt	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/MyFirstContribution.txt	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,1181 @@
+My First Contribution to the Git Project
+========================================
+:sectanchors:
+
+[[summary]]
+== Summary
+
+This is a tutorial demonstrating the end-to-end workflow of creating a change to
+the Git tree, sending it for review, and making changes based on comments.
+
+[[prerequisites]]
+=== Prerequisites
+
+This tutorial assumes you're already fairly familiar with using Git to manage
+source code.  The Git workflow steps will largely remain unexplained.
+
+[[related-reading]]
+=== Related Reading
+
+This tutorial aims to summarize the following documents, but the reader may find
+useful additional context:
+
+- `Documentation/SubmittingPatches`
+- `Documentation/howto/new-command.txt`
+
+[[getting-started]]
+== Getting Started
+
+[[cloning]]
+=== Clone the Git Repository
+
+Git is mirrored in a number of locations. Clone the repository from one of them;
+https://git-scm.com/downloads suggests one of the best places to clone from is
+the mirror on GitHub.
+
+----
+$ git clone https://github.com/git/git git
+$ cd git
+----
+
+[[dependencies]]
+=== Installing Dependencies
+
+To build Git from source, you need to have a handful of dependencies installed
+on your system. For a hint of what's needed, you can take a look at
+`INSTALL`, paying close attention to the section about Git's dependencies on
+external programs and libraries. That document mentions a way to "test-drive"
+our freshly built Git without installing; that's the method we'll be using in
+this tutorial.
+
+Make sure that your environment has everything you need by building your brand
+new clone of Git from the above step:
+
+----
+$ make
+----
+
+NOTE: The Git build is parallelizable. `-j#` is not included above but you can
+use it as you prefer, here and elsewhere.
+
+[[identify-problem]]
+=== Identify Problem to Solve
+
+////
+Use + to indicate fixed-width here; couldn't get ` to work nicely with the
+quotes around "Pony Saying 'Um, Hello'".
+////
+In this tutorial, we will add a new command, +git psuh+, short for ``Pony Saying
+`Um, Hello''' - a feature which has gone unimplemented despite a high frequency
+of invocation during users' typical daily workflow.
+
+(We've seen some other effort in this space with the implementation of popular
+commands such as `sl`.)
+
+[[setup-workspace]]
+=== Set Up Your Workspace
+
+Let's start by making a development branch to work on our changes. Per
+`Documentation/SubmittingPatches`, since a brand new command is a new feature,
+it's fine to base your work on `master`. However, in the future for bugfixes,
+etc., you should check that document and base it on the appropriate branch.
+
+For the purposes of this document, we will base all our work on the `master`
+branch of the upstream project. Create the `psuh` branch you will use for
+development like so:
+
+----
+$ git checkout -b psuh origin/master
+----
+
+We'll make a number of commits here in order to demonstrate how to send a topic
+with multiple patches up for review simultaneously.
+
+[[code-it-up]]
+== Code It Up!
+
+NOTE: A reference implementation can be found at
+https://github.com/nasamuffin/git/tree/psuh.
+
+[[add-new-command]]
+=== Adding a New Command
+
+Lots of the subcommands are written as builtins, which means they are
+implemented in C and compiled into the main `git` executable. Implementing the
+very simple `psuh` command as a built-in will demonstrate the structure of the
+codebase, the internal API, and the process of working together as a contributor
+with the reviewers and maintainer to integrate this change into the system.
+
+Built-in subcommands are typically implemented in a function named "cmd_"
+followed by the name of the subcommand, in a source file named after the
+subcommand and contained within `builtin/`. So it makes sense to implement your
+command in `builtin/psuh.c`. Create that file, and within it, write the entry
+point for your command in a function matching the style and signature:
+
+----
+int cmd_psuh(int argc, const char **argv, const char *prefix)
+----
+
+We'll also need to add the declaration of psuh; open up `builtin.h`, find the
+declaration for `cmd_pull`, and add a new line for `psuh` immediately before it,
+in order to keep the declarations alphabetically sorted:
+
+----
+int cmd_psuh(int argc, const char **argv, const char *prefix);
+----
+
+Be sure to `#include "builtin.h"` in your `psuh.c`.
+
+Go ahead and add some throwaway printf to that function. This is a decent
+starting point as we can now add build rules and register the command.
+
+NOTE: Your throwaway text, as well as much of the text you will be adding over
+the course of this tutorial, is user-facing. That means it needs to be
+localizable. Take a look at `po/README` under "Marking strings for translation".
+Throughout the tutorial, we will mark strings for translation as necessary; you
+should also do so when writing your user-facing commands in the future.
+
+----
+int cmd_psuh(int argc, const char **argv, const char *prefix)
+{
+	printf(_("Pony saying hello goes here.\n"));
+	return 0;
+}
+----
+
+Let's try to build it.  Open `Makefile`, find where `builtin/pull.o` is added
+to `BUILTIN_OBJS`, and add `builtin/psuh.o` in the same way next to it in
+alphabetical order. Once you've done so, move to the top-level directory and
+build simply with `make`. Also add the `DEVELOPER=1` variable to turn on
+some additional warnings:
+
+----
+$ echo DEVELOPER=1 >config.mak
+$ make
+----
+
+NOTE: When you are developing the Git project, it's preferred that you use the
+`DEVELOPER` flag; if there's some reason it doesn't work for you, you can turn
+it off, but it's a good idea to mention the problem to the mailing list.
+
+Great, now your new command builds happily on its own. But nobody invokes it.
+Let's change that.
+
+The list of commands lives in `git.c`. We can register a new command by adding
+a `cmd_struct` to the `commands[]` array. `struct cmd_struct` takes a string
+with the command name, a function pointer to the command implementation, and a
+setup option flag. For now, let's keep mimicking `push`. Find the line where
+`cmd_push` is registered, copy it, and modify it for `cmd_psuh`, placing the new
+line in alphabetical order (immediately before `cmd_pull`).
+
+The options are documented in `builtin.h` under "Adding a new built-in." Since
+we hope to print some data about the user's current workspace context later,
+we need a Git directory, so choose `RUN_SETUP` as your only option.
+
+Go ahead and build again. You should see a clean build, so let's kick the tires
+and see if it works. There's a binary you can use to test with in the
+`bin-wrappers` directory.
+
+----
+$ ./bin-wrappers/git psuh
+----
+
+Check it out! You've got a command! Nice work! Let's commit this.
+
+`git status` reveals modified `Makefile`, `builtin.h`, and `git.c` as well as
+untracked `builtin/psuh.c` and `git-psuh`. First, let's take care of the binary,
+which should be ignored. Open `.gitignore` in your editor, find `/git-pull`, and
+add an entry for your new command in alphabetical order:
+
+----
+...
+/git-prune-packed
+/git-psuh
+/git-pull
+/git-push
+/git-quiltimport
+/git-range-diff
+...
+----
+
+Checking `git status` again should show that `git-psuh` has been removed from
+the untracked list and `.gitignore` has been added to the modified list. Now we
+can stage and commit:
+
+----
+$ git add Makefile builtin.h builtin/psuh.c git.c .gitignore
+$ git commit -s
+----
+
+You will be presented with your editor in order to write a commit message. Start
+the commit with a 50-column or less subject line, including the name of the
+component you're working on, followed by a blank line (always required) and then
+the body of your commit message, which should provide the bulk of the context.
+Remember to be explicit and provide the "Why" of your change, especially if it
+couldn't easily be understood from your diff. When editing your commit message,
+don't remove the Signed-off-by line which was added by `-s` above.
+
+----
+psuh: add a built-in by popular demand
+
+Internal metrics indicate this is a command many users expect to be
+present. So here's an implementation to help drive customer
+satisfaction and engagement: a pony which doubtfully greets the user,
+or, a Pony Saying "Um, Hello" (PSUH).
+
+This commit message is intentionally formatted to 72 columns per line,
+starts with a single line as "commit message subject" that is written as
+if to command the codebase to do something (add this, teach a command
+that). The body of the message is designed to add information about the
+commit that is not readily deduced from reading the associated diff,
+such as answering the question "why?".
+
+Signed-off-by: A U Thor <author@example.com>
+----
+
+Go ahead and inspect your new commit with `git show`. "psuh:" indicates you
+have modified mainly the `psuh` command. The subject line gives readers an idea
+of what you've changed. The sign-off line (`-s`) indicates that you agree to
+the Developer's Certificate of Origin 1.1 (see the
+`Documentation/SubmittingPatches` +++[[dco]]+++ header).
+
+For the remainder of the tutorial, the subject line only will be listed for the
+sake of brevity. However, fully-fleshed example commit messages are available
+on the reference implementation linked at the top of this document.
+
+[[implementation]]
+=== Implementation
+
+It's probably useful to do at least something besides printing out a string.
+Let's start by having a look at everything we get.
+
+Modify your `cmd_psuh` implementation to dump the args you're passed, keeping
+existing `printf()` calls in place:
+
+----
+	int i;
+
+	...
+
+	printf(Q_("Your args (there is %d):\n",
+		  "Your args (there are %d):\n",
+		  argc),
+	       argc);
+	for (i = 0; i < argc; i++)
+		printf("%d: %s\n", i, argv[i]);
+
+	printf(_("Your current working directory:\n<top-level>%s%s\n"),
+	       prefix ? "/" : "", prefix ? prefix : "");
+
+----
+
+Build and try it. As you may expect, there's pretty much just whatever we give
+on the command line, including the name of our command. (If `prefix` is empty
+for you, try `cd Documentation/ && ../bin-wrappers/git psuh`). That's not so
+helpful. So what other context can we get?
+
+Add a line to `#include "config.h"`. Then, add the following bits to the
+function body:
+
+----
+	const char *cfg_name;
+
+...
+
+	git_config(git_default_config, NULL);
+	if (git_config_get_string_const("user.name", &cfg_name) > 0)
+		printf(_("No name is found in config\n"));
+	else
+		printf(_("Your name: %s\n"), cfg_name);
+----
+
+`git_config()` will grab the configuration from config files known to Git and
+apply standard precedence rules. `git_config_get_string_const()` will look up
+a specific key ("user.name") and give you the value. There are a number of
+single-key lookup functions like this one; you can see them all (and more info
+about how to use `git_config()`) in `Documentation/technical/api-config.txt`.
+
+You should see that the name printed matches the one you see when you run:
+
+----
+$ git config --get user.name
+----
+
+Great! Now we know how to check for values in the Git config. Let's commit this
+too, so we don't lose our progress.
+
+----
+$ git add builtin/psuh.c
+$ git commit -sm "psuh: show parameters & config opts"
+----
+
+NOTE: Again, the above is for sake of brevity in this tutorial. In a real change
+you should not use `-m` but instead use the editor to write a meaningful
+message.
+
+Still, it'd be nice to know what the user's working context is like. Let's see
+if we can print the name of the user's current branch. We can mimic the
+`git status` implementation; the printer is located in `wt-status.c` and we can
+see that the branch is held in a `struct wt_status`.
+
+`wt_status_print()` gets invoked by `cmd_status()` in `builtin/commit.c`.
+Looking at that implementation we see the status config being populated like so:
+
+----
+status_init_config(&s, git_status_config);
+----
+
+But as we drill down, we can find that `status_init_config()` wraps a call
+to `git_config()`. Let's modify the code we wrote in the previous commit.
+
+Be sure to include the header to allow you to use `struct wt_status`:
+----
+#include "wt-status.h"
+----
+
+Then modify your `cmd_psuh` implementation to declare your `struct wt_status`,
+prepare it, and print its contents:
+
+----
+	struct wt_status status;
+
+...
+
+	wt_status_prepare(the_repository, &status);
+	git_config(git_default_config, &status);
+
+...
+
+	printf(_("Your current branch: %s\n"), status.branch);
+----
+
+Run it again. Check it out - here's the (verbose) name of your current branch!
+
+Let's commit this as well.
+
+----
+$ git add builtin/psuh.c
+$ git commit -sm "psuh: print the current branch"
+----
+
+Now let's see if we can get some info about a specific commit.
+
+Luckily, there are some helpers for us here. `commit.h` has a function called
+`lookup_commit_reference_by_name` to which we can simply provide a hardcoded
+string; `pretty.h` has an extremely handy `pp_commit_easy()` call which doesn't
+require a full format object to be passed.
+
+Add the following includes:
+
+----
+#include "commit.h"
+#include "pretty.h"
+----
+
+Then, add the following lines within your implementation of `cmd_psuh()` near
+the declarations and the logic, respectively.
+
+----
+	struct commit *c = NULL;
+	struct strbuf commitline = STRBUF_INIT;
+
+...
+
+	c = lookup_commit_reference_by_name("origin/master");
+
+	if (c != NULL) {
+		pp_commit_easy(CMIT_FMT_ONELINE, c, &commitline);
+		printf(_("Current commit: %s\n"), commitline.buf);
+	}
+----
+
+The `struct strbuf` provides some safety belts to your basic `char*`, one of
+which is a length member to prevent buffer overruns. It needs to be initialized
+nicely with `STRBUF_INIT`. Keep it in mind when you need to pass around `char*`.
+
+`lookup_commit_reference_by_name` resolves the name you pass it, so you can play
+with the value there and see what kind of things you can come up with.
+
+`pp_commit_easy` is a convenience wrapper in `pretty.h` that takes a single
+format enum shorthand, rather than an entire format struct. It then
+pretty-prints the commit according to that shorthand. These are similar to the
+formats available with `--pretty=FOO` in many Git commands.
+
+Build it and run, and if you're using the same name in the example, you should
+see the subject line of the most recent commit in `origin/master` that you know
+about. Neat! Let's commit that as well.
+
+----
+$ git add builtin/psuh.c
+$ git commit -sm "psuh: display the top of origin/master"
+----
+
+[[add-documentation]]
+=== Adding Documentation
+
+Awesome! You've got a fantastic new command that you're ready to share with the
+community. But hang on just a minute - this isn't very user-friendly. Run the
+following:
+
+----
+$ ./bin-wrappers/git help psuh
+----
+
+Your new command is undocumented! Let's fix that.
+
+Take a look at `Documentation/git-*.txt`. These are the manpages for the
+subcommands that Git knows about. You can open these up and take a look to get
+acquainted with the format, but then go ahead and make a new file
+`Documentation/git-psuh.txt`. Like with most of the documentation in the Git
+project, help pages are written with AsciiDoc (see CodingGuidelines, "Writing
+Documentation" section). Use the following template to fill out your own
+manpage:
+
+// Surprisingly difficult to embed AsciiDoc source within AsciiDoc.
+[listing]
+....
+git-psuh(1)
+===========
+
+NAME
+----
+git-psuh - Delight users' typo with a shy horse
+
+
+SYNOPSIS
+--------
+[verse]
+'git-psuh [<arg>...]'
+
+DESCRIPTION
+-----------
+...
+
+OPTIONS[[OPTIONS]]
+------------------
+...
+
+OUTPUT
+------
+...
+
+GIT
+---
+Part of the linkgit:git[1] suite
+....
+
+The most important pieces of this to note are the file header, underlined by =,
+the NAME section, and the SYNOPSIS, which would normally contain the grammar if
+your command took arguments. Try to use well-established manpage headers so your
+documentation is consistent with other Git and UNIX manpages; this makes life
+easier for your user, who can skip to the section they know contains the
+information they need.
+
+Now that you've written your manpage, you'll need to build it explicitly. We
+convert your AsciiDoc to troff which is man-readable like so:
+
+----
+$ make all doc
+$ man Documentation/git-psuh.1
+----
+
+or
+
+----
+$ make -C Documentation/ git-psuh.1
+$ man Documentation/git-psuh.1
+----
+
+NOTE: You may need to install the package `asciidoc` to get this to work.
+
+While this isn't as satisfying as running through `git help`, you can at least
+check that your help page looks right.
+
+You can also check that the documentation coverage is good (that is, the project
+sees that your command has been implemented as well as documented) by running
+`make check-docs` from the top-level.
+
+Go ahead and commit your new documentation change.
+
+[[add-usage]]
+=== Adding Usage Text
+
+Try and run `./bin-wrappers/git psuh -h`. Your command should crash at the end.
+That's because `-h` is a special case which your command should handle by
+printing usage.
+
+Take a look at `Documentation/technical/api-parse-options.txt`. This is a handy
+tool for pulling out options you need to be able to handle, and it takes a
+usage string.
+
+In order to use it, we'll need to prepare a NULL-terminated array of usage
+strings and a `builtin_psuh_options` array.
+
+Add a line to `#include "parse-options.h"`.
+
+At global scope, add your array of usage strings:
+
+----
+static const char * const psuh_usage[] = {
+	N_("git psuh [<arg>...]"),
+	NULL,
+};
+----
+
+Then, within your `cmd_psuh()` implementation, we can declare and populate our
+`option` struct. Ours is pretty boring but you can add more to it if you want to
+explore `parse_options()` in more detail:
+
+----
+	struct option options[] = {
+		OPT_END()
+	};
+----
+
+Finally, before you print your args and prefix, add the call to
+`parse-options()`:
+
+----
+	argc = parse_options(argc, argv, prefix, options, psuh_usage, 0);
+----
+
+This call will modify your `argv` parameter. It will strip the options you
+specified in `options` from `argv` and the locations pointed to from `options`
+entries will be updated. Be sure to replace your `argc` with the result from
+`parse_options()`, or you will be confused if you try to parse `argv` later.
+
+It's worth noting the special argument `--`. As you may be aware, many Unix
+commands use `--` to indicate "end of named parameters" - all parameters after
+the `--` are interpreted merely as positional arguments. (This can be handy if
+you want to pass as a parameter something which would usually be interpreted as
+a flag.) `parse_options()` will terminate parsing when it reaches `--` and give
+you the rest of the options afterwards, untouched.
+
+Now that you have a usage hint, you can teach Git how to show it in the general
+command list shown by `git help git` or `git help -a`, which is generated from
+`command-list.txt`. Find the line for 'git-pull' so you can add your 'git-psuh'
+line above it in alphabetical order. Now, we can add some attributes about the
+command which impacts where it shows up in the aforementioned help commands. The
+top of `command-list.txt` shares some information about what each attribute
+means; in those help pages, the commands are sorted according to these
+attributes. `git psuh` is user-facing, or porcelain - so we will mark it as
+"mainporcelain". For "mainporcelain" commands, the comments at the top of
+`command-list.txt` indicate we can also optionally add an attribute from another
+list; since `git psuh` shows some information about the user's workspace but
+doesn't modify anything, let's mark it as "info". Make sure to keep your
+attributes in the same style as the rest of `command-list.txt` using spaces to
+align and delineate them:
+
+----
+git-prune-packed                        plumbingmanipulators
+git-psuh                                mainporcelain		info
+git-pull                                mainporcelain           remote
+git-push                                mainporcelain           remote
+----
+
+Build again. Now, when you run with `-h`, you should see your usage printed and
+your command terminated before anything else interesting happens. Great!
+
+Go ahead and commit this one, too.
+
+[[testing]]
+== Testing
+
+It's important to test your code - even for a little toy command like this one.
+Moreover, your patch won't be accepted into the Git tree without tests. Your
+tests should:
+
+* Illustrate the current behavior of the feature
+* Prove the current behavior matches the expected behavior
+* Ensure the externally-visible behavior isn't broken in later changes
+
+So let's write some tests.
+
+Related reading: `t/README`
+
+[[overview-test-structure]]
+=== Overview of Testing Structure
+
+The tests in Git live in `t/` and are named with a 4-digit decimal number using
+the schema shown in the Naming Tests section of `t/README`.
+
+[[write-new-test]]
+=== Writing Your Test
+
+Since this a toy command, let's go ahead and name the test with t9999. However,
+as many of the family/subcmd combinations are full, best practice seems to be
+to find a command close enough to the one you've added and share its naming
+space.
+
+Create a new file `t/t9999-psuh-tutorial.sh`. Begin with the header as so (see
+"Writing Tests" and "Source 'test-lib.sh'" in `t/README`):
+
+----
+#!/bin/sh
+
+test_description='git-psuh test
+
+This test runs git-psuh and makes sure it does not crash.'
+
+. ./test-lib.sh
+----
+
+Tests are framed inside of a `test_expect_success` in order to output TAP
+formatted results. Let's make sure that `git psuh` doesn't exit poorly and does
+mention the right animal somewhere:
+
+----
+test_expect_success 'runs correctly with no args and good output' '
+	git psuh >actual &&
+	test_i18ngrep Pony actual
+'
+----
+
+Indicate that you've run everything you wanted by adding the following at the
+bottom of your script:
+
+----
+test_done
+----
+
+Make sure you mark your test script executable:
+
+----
+$ chmod +x t/t9999-psuh-tutorial.sh
+----
+
+You can get an idea of whether you created your new test script successfully
+by running `make -C t test-lint`, which will check for things like test number
+uniqueness, executable bit, and so on.
+
+[[local-test]]
+=== Running Locally
+
+Let's try and run locally:
+
+----
+$ make
+$ cd t/ && prove t9999-psuh-tutorial.sh
+----
+
+You can run the full test suite and ensure `git-psuh` didn't break anything:
+
+----
+$ cd t/
+$ prove -j$(nproc) --shuffle t[0-9]*.sh
+----
+
+NOTE: You can also do this with `make test` or use any testing harness which can
+speak TAP. `prove` can run concurrently. `shuffle` randomizes the order the
+tests are run in, which makes them resilient against unwanted inter-test
+dependencies. `prove` also makes the output nicer.
+
+Go ahead and commit this change, as well.
+
+[[ready-to-share]]
+== Getting Ready to Share
+
+You may have noticed already that the Git project performs its code reviews via
+emailed patches, which are then applied by the maintainer when they are ready
+and approved by the community. The Git project does not accept patches from
+pull requests, and the patches emailed for review need to be formatted a
+specific way. At this point the tutorial diverges, in order to demonstrate two
+different methods of formatting your patchset and getting it reviewed.
+
+The first method to be covered is GitGitGadget, which is useful for those
+already familiar with GitHub's common pull request workflow. This method
+requires a GitHub account.
+
+The second method to be covered is `git send-email`, which can give slightly
+more fine-grained control over the emails to be sent. This method requires some
+setup which can change depending on your system and will not be covered in this
+tutorial.
+
+Regardless of which method you choose, your engagement with reviewers will be
+the same; the review process will be covered after the sections on GitGitGadget
+and `git send-email`.
+
+[[howto-ggg]]
+== Sending Patches via GitGitGadget
+
+One option for sending patches is to follow a typical pull request workflow and
+send your patches out via GitGitGadget. GitGitGadget is a tool created by
+Johannes Schindelin to make life as a Git contributor easier for those used to
+the GitHub PR workflow. It allows contributors to open pull requests against its
+mirror of the Git project, and does some magic to turn the PR into a set of
+emails and send them out for you. It also runs the Git continuous integration
+suite for you. It's documented at http://gitgitgadget.github.io.
+
+[[create-fork]]
+=== Forking `git/git` on GitHub
+
+Before you can send your patch off to be reviewed using GitGitGadget, you will
+need to fork the Git project and upload your changes. First thing - make sure
+you have a GitHub account.
+
+Head to the https://github.com/git/git[GitHub mirror] and look for the Fork
+button. Place your fork wherever you deem appropriate and create it.
+
+[[upload-to-fork]]
+=== Uploading to Your Own Fork
+
+To upload your branch to your own fork, you'll need to add the new fork as a
+remote. You can use `git remote -v` to show the remotes you have added already.
+From your new fork's page on GitHub, you can press "Clone or download" to get
+the URL; then you need to run the following to add, replacing your own URL and
+remote name for the examples provided:
+
+----
+$ git remote add remotename git@github.com:remotename/git.git
+----
+
+or to use the HTTPS URL:
+
+----
+$ git remote add remotename https://github.com/remotename/git/.git
+----
+
+Run `git remote -v` again and you should see the new remote showing up.
+`git fetch remotename` (with the real name of your remote replaced) in order to
+get ready to push.
+
+Next, double-check that you've been doing all your development in a new branch
+by running `git branch`. If you didn't, now is a good time to move your new
+commits to their own branch.
+
+As mentioned briefly at the beginning of this document, we are basing our work
+on `master`, so go ahead and update as shown below, or using your preferred
+workflow.
+
+----
+$ git checkout master
+$ git pull -r
+$ git rebase master psuh
+----
+
+Finally, you're ready to push your new topic branch! (Due to our branch and
+command name choices, be careful when you type the command below.)
+
+----
+$ git push remotename psuh
+----
+
+Now you should be able to go and check out your newly created branch on GitHub.
+
+[[send-pr-ggg]]
+=== Sending a PR to GitGitGadget
+
+In order to have your code tested and formatted for review, you need to start by
+opening a Pull Request against `gitgitgadget/git`. Head to
+https://github.com/gitgitgadget/git and open a PR either with the "New pull
+request" button or the convenient "Compare & pull request" button that may
+appear with the name of your newly pushed branch.
+
+Review the PR's title and description, as it's used by GitGitGadget as the cover
+letter for your change. When you're happy, submit your pull request.
+
+[[run-ci-ggg]]
+=== Running CI and Getting Ready to Send
+
+If it's your first time using GitGitGadget (which is likely, as you're using
+this tutorial) then someone will need to give you permission to use the tool.
+As mentioned in the GitGitGadget documentation, you just need someone who
+already uses it to comment on your PR with `/allow <username>`. GitGitGadget
+will automatically run your PRs through the CI even without the permission given
+but you will not be able to `/submit` your changes until someone allows you to
+use the tool.
+
+NOTE: You can typically find someone who can `/allow` you on GitGitGadget by
+either examining recent pull requests where someone has been granted `/allow`
+(https://github.com/gitgitgadget/git/pulls?utf8=%E2%9C%93&q=is%3Apr+is%3Aopen+%22%2Fallow%22[Search:
+is:pr is:open "/allow"]), in which case both the author and the person who
+granted the `/allow` can now `/allow` you, or by inquiring on the
+https://webchat.freenode.net/#git-devel[#git-devel] IRC channel on Freenode
+linking your pull request and asking for someone to `/allow` you.
+
+If the CI fails, you can update your changes with `git rebase -i` and push your
+branch again:
+
+----
+$ git push -f remotename psuh
+----
+
+In fact, you should continue to make changes this way up until the point when
+your patch is accepted into `next`.
+
+////
+TODO https://github.com/gitgitgadget/gitgitgadget/issues/83
+It'd be nice to be able to verify that the patch looks good before sending it
+to everyone on Git mailing list.
+[[check-work-ggg]]
+=== Check Your Work
+////
+
+[[send-mail-ggg]]
+=== Sending Your Patches
+
+Now that your CI is passing and someone has granted you permission to use
+GitGitGadget with the `/allow` command, sending out for review is as simple as
+commenting on your PR with `/submit`.
+
+[[responding-ggg]]
+=== Updating With Comments
+
+Skip ahead to <<reviewing,Responding to Reviews>> for information on how to
+reply to review comments you will receive on the mailing list.
+
+Once you have your branch again in the shape you want following all review
+comments, you can submit again:
+
+----
+$ git push -f remotename psuh
+----
+
+Next, go look at your pull request against GitGitGadget; you should see the CI
+has been kicked off again. Now while the CI is running is a good time for you
+to modify your description at the top of the pull request thread; it will be
+used again as the cover letter. You should use this space to describe what
+has changed since your previous version, so that your reviewers have some idea
+of what they're looking at. When the CI is done running, you can comment once
+more with `/submit` - GitGitGadget will automatically add a v2 mark to your
+changes.
+
+[[howto-git-send-email]]
+== Sending Patches with `git send-email`
+
+If you don't want to use GitGitGadget, you can also use Git itself to mail your
+patches. Some benefits of using Git this way include finer grained control of
+subject line (for example, being able to use the tag [RFC PATCH] in the subject)
+and being able to send a ``dry run'' mail to yourself to ensure it all looks
+good before going out to the list.
+
+[[setup-git-send-email]]
+=== Prerequisite: Setting Up `git send-email`
+
+Configuration for `send-email` can vary based on your operating system and email
+provider, and so will not be covered in this tutorial, beyond stating that in
+many distributions of Linux, `git-send-email` is not packaged alongside the
+typical `git` install. You may need to install this additional package; there
+are a number of resources online to help you do so. You will also need to
+determine the right way to configure it to use your SMTP server; again, as this
+configuration can change significantly based on your system and email setup, it
+is out of scope for the context of this tutorial.
+
+[[format-patch]]
+=== Preparing Initial Patchset
+
+Sending emails with Git is a two-part process; before you can prepare the emails
+themselves, you'll need to prepare the patches. Luckily, this is pretty simple:
+
+----
+$ git format-patch --cover-letter -o psuh/ master..psuh
+----
+
+The `--cover-letter` parameter tells `format-patch` to create a cover letter
+template for you. You will need to fill in the template before you're ready
+to send - but for now, the template will be next to your other patches.
+
+The `-o psuh/` parameter tells `format-patch` to place the patch files into a
+directory. This is useful because `git send-email` can take a directory and
+send out all the patches from there.
+
+`master..psuh` tells `format-patch` to generate patches for the difference
+between `master` and `psuh`. It will make one patch file per commit. After you
+run, you can go have a look at each of the patches with your favorite text
+editor and make sure everything looks alright; however, it's not recommended to
+make code fixups via the patch file. It's a better idea to make the change the
+normal way using `git rebase -i` or by adding a new commit than by modifying a
+patch.
+
+NOTE: Optionally, you can also use the `--rfc` flag to prefix your patch subject
+with ``[RFC PATCH]'' instead of ``[PATCH]''. RFC stands for ``request for
+comments'' and indicates that while your code isn't quite ready for submission,
+you'd like to begin the code review process. This can also be used when your
+patch is a proposal, but you aren't sure whether the community wants to solve
+the problem with that approach or not - to conduct a sort of design review. You
+may also see on the list patches marked ``WIP'' - this means they are incomplete
+but want reviewers to look at what they have so far. You can add this flag with
+`--subject-prefix=WIP`.
+
+Check and make sure that your patches and cover letter template exist in the
+directory you specified - you're nearly ready to send out your review!
+
+[[cover-letter]]
+=== Preparing Email
+
+In addition to an email per patch, the Git community also expects your patches
+to come with a cover letter, typically with a subject line [PATCH 0/x] (where
+x is the number of patches you're sending). Since you invoked `format-patch`
+with `--cover-letter`, you've already got a template ready. Open it up in your
+favorite editor.
+
+You should see a number of headers present already. Check that your `From:`
+header is correct. Then modify your `Subject:` to something which succinctly
+covers the purpose of your entire topic branch, for example:
+
+----
+Subject: [PATCH 0/7] adding the 'psuh' command
+----
+
+Make sure you retain the ``[PATCH 0/X]'' part; that's what indicates to the Git
+community that this email is the beginning of a review, and many reviewers
+filter their email for this type of flag.
+
+You'll need to add some extra parameters when you invoke `git send-email` to add
+the cover letter.
+
+Next you'll have to fill out the body of your cover letter. This is an important
+component of change submission as it explains to the community from a high level
+what you're trying to do, and why, in a way that's more apparent than just
+looking at your diff. Be sure to explain anything your diff doesn't make clear
+on its own.
+
+Here's an example body for `psuh`:
+
+----
+Our internal metrics indicate widespread interest in the command
+git-psuh - that is, many users are trying to use it, but finding it is
+unavailable, using some unknown workaround instead.
+
+The following handful of patches add the psuh command and implement some
+handy features on top of it.
+
+This patchset is part of the MyFirstContribution tutorial and should not
+be merged.
+----
+
+The template created by `git format-patch --cover-letter` includes a diffstat.
+This gives reviewers a summary of what they're in for when reviewing your topic.
+The one generated for `psuh` from the sample implementation looks like this:
+
+----
+ Documentation/git-psuh.txt | 40 +++++++++++++++++++++
+ Makefile                   |  1 +
+ builtin.h                  |  1 +
+ builtin/psuh.c             | 73 ++++++++++++++++++++++++++++++++++++++
+ git.c                      |  1 +
+ t/t9999-psuh-tutorial.sh   | 12 +++++++
+ 6 files changed, 128 insertions(+)
+ create mode 100644 Documentation/git-psuh.txt
+ create mode 100644 builtin/psuh.c
+ create mode 100755 t/t9999-psuh-tutorial.sh
+----
+
+Finally, the letter will include the version of Git used to generate the
+patches. You can leave that string alone.
+
+[[sending-git-send-email]]
+=== Sending Email
+
+At this point you should have a directory `psuh/` which is filled with your
+patches and a cover letter. Time to mail it out! You can send it like this:
+
+----
+$ git send-email --to=target@example.com psuh/*.patch
+----
+
+NOTE: Check `git help send-email` for some other options which you may find
+valuable, such as changing the Reply-to address or adding more CC and BCC lines.
+
+NOTE: When you are sending a real patch, it will go to git@vger.kernel.org - but
+please don't send your patchset from the tutorial to the real mailing list! For
+now, you can send it to yourself, to make sure you understand how it will look.
+
+After you run the command above, you will be presented with an interactive
+prompt for each patch that's about to go out. This gives you one last chance to
+edit or quit sending something (but again, don't edit code this way). Once you
+press `y` or `a` at these prompts your emails will be sent! Congratulations!
+
+Awesome, now the community will drop everything and review your changes. (Just
+kidding - be patient!)
+
+[[v2-git-send-email]]
+=== Sending v2
+
+Skip ahead to <<reviewing,Responding to Reviews>> for information on how to
+handle comments from reviewers. Continue this section when your topic branch is
+shaped the way you want it to look for your patchset v2.
+
+When you're ready with the next iteration of your patch, the process is fairly
+similar.
+
+First, generate your v2 patches again:
+
+----
+$ git format-patch -v2 --cover-letter -o psuh/ master..psuh
+----
+
+This will add your v2 patches, all named like `v2-000n-my-commit-subject.patch`,
+to the `psuh/` directory. You may notice that they are sitting alongside the v1
+patches; that's fine, but be careful when you are ready to send them.
+
+Edit your cover letter again. Now is a good time to mention what's different
+between your last version and now, if it's something significant. You do not
+need the exact same body in your second cover letter; focus on explaining to
+reviewers the changes you've made that may not be as visible.
+
+You will also need to go and find the Message-Id of your previous cover letter.
+You can either note it when you send the first series, from the output of `git
+send-email`, or you can look it up on the
+https://lore.kernel.org/git[mailing list]. Find your cover letter in the
+archives, click on it, then click "permalink" or "raw" to reveal the Message-Id
+header. It should match:
+
+----
+Message-Id: <foo.12345.author@example.com>
+----
+
+Your Message-Id is `<foo.12345.author@example.com>`. This example will be used
+below as well; make sure to replace it with the correct Message-Id for your
+**previous cover letter** - that is, if you're sending v2, use the Message-Id
+from v1; if you're sending v3, use the Message-Id from v2.
+
+While you're looking at the email, you should also note who is CC'd, as it's
+common practice in the mailing list to keep all CCs on a thread. You can add
+these CC lines directly to your cover letter with a line like so in the header
+(before the Subject line):
+
+----
+CC: author@example.com, Othe R <other@example.com>
+----
+
+Now send the emails again, paying close attention to which messages you pass in
+to the command:
+
+----
+$ git send-email --to=target@example.com
+		 --in-reply-to="<foo.12345.author@example.com>"
+		 psuh/v2*
+----
+
+[[single-patch]]
+=== Bonus Chapter: One-Patch Changes
+
+In some cases, your very small change may consist of only one patch. When that
+happens, you only need to send one email. Your commit message should already be
+meaningful and explain at a high level the purpose (what is happening and why)
+of your patch, but if you need to supply even more context, you can do so below
+the `---` in your patch. Take the example below, which was generated with `git
+format-patch` on a single commit, and then edited to add the content between
+the `---` and the diffstat.
+
+----
+From 1345bbb3f7ac74abde040c12e737204689a72723 Mon Sep 17 00:00:00 2001
+From: A U Thor <author@example.com>
+Date: Thu, 18 Apr 2019 15:11:02 -0700
+Subject: [PATCH] README: change the grammar
+
+I think it looks better this way. This part of the commit message will
+end up in the commit-log.
+
+Signed-off-by: A U Thor <author@example.com>
+---
+Let's have a wild discussion about grammar on the mailing list. This
+part of my email will never end up in the commit log. Here is where I
+can add additional context to the mailing list about my intent, outside
+of the context of the commit log. This section was added after `git
+format-patch` was run, by editing the patch file in a text editor.
+
+ README.md | 2 +-
+ 1 file changed, 1 insertion(+), 1 deletion(-)
+
+diff --git a/README.md b/README.md
+index 88f126184c..38da593a60 100644
+--- a/README.md
++++ b/README.md
+@@ -3,7 +3,7 @@
+ Git - fast, scalable, distributed revision control system
+ =========================================================
+
+-Git is a fast, scalable, distributed revision control system with an
++Git is a fast, scalable, and distributed revision control system with an
+ unusually rich command set that provides both high-level operations
+ and full access to internals.
+
+--
+2.21.0.392.gf8f6787159e-goog
+----
+
+[[now-what]]
+== My Patch Got Emailed - Now What?
+
+[[reviewing]]
+=== Responding to Reviews
+
+After a few days, you will hopefully receive a reply to your patchset with some
+comments. Woohoo! Now you can get back to work.
+
+It's good manners to reply to each comment, notifying the reviewer that you have
+made the change requested, feel the original is better, or that the comment
+inspired you to do something a new way which is superior to both the original
+and the suggested change. This way reviewers don't need to inspect your v2 to
+figure out whether you implemented their comment or not.
+
+If you are going to push back on a comment, be polite and explain why you feel
+your original is better; be prepared that the reviewer may still disagree with
+you, and the rest of the community may weigh in on one side or the other. As
+with all code reviews, it's important to keep an open mind to doing something a
+different way than you originally planned; other reviewers have a different
+perspective on the project than you do, and may be thinking of a valid side
+effect which had not occurred to you. It is always okay to ask for clarification
+if you aren't sure why a change was suggested, or what the reviewer is asking
+you to do.
+
+Make sure your email client has a plaintext email mode and it is turned on; the
+Git list rejects HTML email. Please also follow the mailing list etiquette
+outlined in the
+https://kernel.googlesource.com/pub/scm/git/git/+/todo/MaintNotes[Maintainer's
+Note], which are similar to etiquette rules in most open source communities
+surrounding bottom-posting and inline replies.
+
+When you're making changes to your code, it is cleanest - that is, the resulting
+commits are easiest to look at - if you use `git rebase -i` (interactive
+rebase). Take a look at this
+https://www.oreilly.com/library/view/git-pocket-guide/9781449327507/ch10.html[overview]
+from O'Reilly. The general idea is to modify each commit which requires changes;
+this way, instead of having a patch A with a mistake, a patch B which was fine
+and required no upstream reviews in v1, and a patch C which fixes patch A for
+v2, you can just ship a v2 with a correct patch A and correct patch B. This is
+changing history, but since it's local history which you haven't shared with
+anyone, that is okay for now! (Later, it may not make sense to do this; take a
+look at the section below this one for some context.)
+
+[[after-approval]]
+=== After Review Approval
+
+The Git project has four integration branches: `pu`, `next`, `master`, and
+`maint`. Your change will be placed into `pu` fairly early on by the maintainer
+while it is still in the review process; from there, when it is ready for wider
+testing, it will be merged into `next`. Plenty of early testers use `next` and
+may report issues. Eventually, changes in `next` will make it to `master`,
+which is typically considered stable. Finally, when a new release is cut,
+`maint` is used to base bugfixes onto. As mentioned at the beginning of this
+document, you can read `Documents/SubmittingPatches` for some more info about
+the use of the various integration branches.
+
+Back to now: your code has been lauded by the upstream reviewers. It is perfect.
+It is ready to be accepted. You don't need to do anything else; the maintainer
+will merge your topic branch to `next` and life is good.
+
+However, if you discover it isn't so perfect after this point, you may need to
+take some special steps depending on where you are in the process.
+
+If the maintainer has announced in the "What's cooking in git.git" email that
+your topic is marked for `next` - that is, that they plan to merge it to `next`
+but have not yet done so - you should send an email asking the maintainer to
+wait a little longer: "I've sent v4 of my series and you marked it for `next`,
+but I need to change this and that - please wait for v5 before you merge it."
+
+If the topic has already been merged to `next`, rather than modifying your
+patches with `git rebase -i`, you should make further changes incrementally -
+that is, with another commit, based on top of the maintainer's topic branch as
+detailed in https://github.com/gitster/git. Your work is still in the same topic
+but is now incremental, rather than a wholesale rewrite of the topic branch.
+
+The topic branches in the maintainer's GitHub are mirrored in GitGitGadget, so
+if you're sending your reviews out that way, you should be sure to open your PR
+against the appropriate GitGitGadget/Git branch.
+
+If you're using `git send-email`, you can use it the same way as before, but you
+should generate your diffs from `<topic>..<mybranch>` and base your work on
+`<topic>` instead of `master`.
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/MyFirstObjectWalk.txt 1.2.3+git2.25.1-1/git/Documentation/MyFirstObjectWalk.txt
--- 1.2.1+git2.18.0-1/git/Documentation/MyFirstObjectWalk.txt	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/MyFirstObjectWalk.txt	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,905 @@
+= My First Object Walk
+
+== What's an Object Walk?
+
+The object walk is a key concept in Git - this is the process that underpins
+operations like object transfer and fsck. Beginning from a given commit, the
+list of objects is found by walking parent relationships between commits (commit
+X based on commit W) and containment relationships between objects (tree Y is
+contained within commit X, and blob Z is located within tree Y, giving our
+working tree for commit X something like `y/z.txt`).
+
+A related concept is the revision walk, which is focused on commit objects and
+their parent relationships and does not delve into other object types. The
+revision walk is used for operations like `git log`.
+
+=== Related Reading
+
+- `Documentation/user-manual.txt` under "Hacking Git" contains some coverage of
+  the revision walker in its various incarnations.
+- `revision.h`
+- https://eagain.net/articles/git-for-computer-scientists/[Git for Computer Scientists]
+  gives a good overview of the types of objects in Git and what your object
+  walk is really describing.
+
+== Setting Up
+
+Create a new branch from `master`.
+
+----
+git checkout -b revwalk origin/master
+----
+
+We'll put our fiddling into a new command. For fun, let's name it `git walken`.
+Open up a new file `builtin/walken.c` and set up the command handler:
+
+----
+/*
+ * "git walken"
+ *
+ * Part of the "My First Object Walk" tutorial.
+ */
+
+#include "builtin.h"
+
+int cmd_walken(int argc, const char **argv, const char *prefix)
+{
+	trace_printf(_("cmd_walken incoming...\n"));
+	return 0;
+}
+----
+
+NOTE: `trace_printf()` differs from `printf()` in that it can be turned on or
+off at runtime. For the purposes of this tutorial, we will write `walken` as
+though it is intended for use as a "plumbing" command: that is, a command which
+is used primarily in scripts, rather than interactively by humans (a "porcelain"
+command). So we will send our debug output to `trace_printf()` instead. When
+running, enable trace output by setting the environment variable `GIT_TRACE`.
+
+Add usage text and `-h` handling, like all subcommands should consistently do
+(our test suite will notice and complain if you fail to do so).
+
+----
+int cmd_walken(int argc, const char **argv, const char *prefix)
+{
+	const char * const walken_usage[] = {
+		N_("git walken"),
+		NULL,
+	}
+	struct option options[] = {
+		OPT_END()
+	};
+
+	argc = parse_options(argc, argv, prefix, options, walken_usage, 0);
+
+	...
+}
+----
+
+Also add the relevant line in `builtin.h` near `cmd_whatchanged()`:
+
+----
+int cmd_walken(int argc, const char **argv, const char *prefix);
+----
+
+Include the command in `git.c` in `commands[]` near the entry for `whatchanged`,
+maintaining alphabetical ordering:
+
+----
+{ "walken", cmd_walken, RUN_SETUP },
+----
+
+Add it to the `Makefile` near the line for `builtin/worktree.o`:
+
+----
+BUILTIN_OBJS += builtin/walken.o
+----
+
+Build and test out your command, without forgetting to ensure the `DEVELOPER`
+flag is set, and with `GIT_TRACE` enabled so the debug output can be seen:
+
+----
+$ echo DEVELOPER=1 >>config.mak
+$ make
+$ GIT_TRACE=1 ./bin-wrappers/git walken
+----
+
+NOTE: For a more exhaustive overview of the new command process, take a look at
+`Documentation/MyFirstContribution.txt`.
+
+NOTE: A reference implementation can be found at
+https://github.com/nasamuffin/git/tree/revwalk.
+
+=== `struct rev_cmdline_info`
+
+The definition of `struct rev_cmdline_info` can be found in `revision.h`.
+
+This struct is contained within the `rev_info` struct and is used to reflect
+parameters provided by the user over the CLI.
+
+`nr` represents the number of `rev_cmdline_entry` present in the array.
+
+`alloc` is used by the `ALLOC_GROW` macro. Check `cache.h` - this variable is
+used to track the allocated size of the list.
+
+Per entry, we find:
+
+`item` is the object provided upon which to base the object walk. Items in Git
+can be blobs, trees, commits, or tags. (See `Documentation/gittutorial-2.txt`.)
+
+`name` is the object ID (OID) of the object - a hex string you may be familiar
+with from using Git to organize your source in the past. Check the tutorial
+mentioned above towards the top for a discussion of where the OID can come
+from.
+
+`whence` indicates some information about what to do with the parents of the
+specified object. We'll explore this flag more later on; take a look at
+`Documentation/revisions.txt` to get an idea of what could set the `whence`
+value.
+
+`flags` are used to hint the beginning of the revision walk and are the first
+block under the `#include`s in `revision.h`. The most likely ones to be set in
+the `rev_cmdline_info` are `UNINTERESTING` and `BOTTOM`, but these same flags
+can be used during the walk, as well.
+
+=== `struct rev_info`
+
+This one is quite a bit longer, and many fields are only used during the walk
+by `revision.c` - not configuration options. Most of the configurable flags in
+`struct rev_info` have a mirror in `Documentation/rev-list-options.txt`. It's a
+good idea to take some time and read through that document.
+
+== Basic Commit Walk
+
+First, let's see if we can replicate the output of `git log --oneline`. We'll
+refer back to the implementation frequently to discover norms when performing
+an object walk of our own.
+
+To do so, we'll first find all the commits, in order, which preceded the current
+commit. We'll extract the name and subject of the commit from each.
+
+Ideally, we will also be able to find out which ones are currently at the tip of
+various branches.
+
+=== Setting Up
+
+Preparing for your object walk has some distinct stages.
+
+1. Perform default setup for this mode, and others which may be invoked.
+2. Check configuration files for relevant settings.
+3. Set up the `rev_info` struct.
+4. Tweak the initialized `rev_info` to suit the current walk.
+5. Prepare the `rev_info` for the walk.
+6. Iterate over the objects, processing each one.
+
+==== Default Setups
+
+Before examining configuration files which may modify command behavior, set up
+default state for switches or options your command may have. If your command
+utilizes other Git components, ask them to set up their default states as well.
+For instance, `git log` takes advantage of `grep` and `diff` functionality, so
+its `init_log_defaults()` sets its own state (`decoration_style`) and asks
+`grep` and `diff` to initialize themselves by calling each of their
+initialization functions.
+
+For our first example within `git walken`, we don't intend to use any other
+components within Git, and we don't have any configuration to do.  However, we
+may want to add some later, so for now, we can add an empty placeholder. Create
+a new function in `builtin/walken.c`:
+
+----
+static void init_walken_defaults(void)
+{
+	/*
+	 * We don't actually need the same components `git log` does; leave this
+	 * empty for now.
+	 */
+}
+----
+
+Make sure to add a line invoking it inside of `cmd_walken()`.
+
+----
+int cmd_walken(int argc, const char **argv, const char *prefix)
+{
+	init_walken_defaults();
+}
+----
+
+==== Configuring From `.gitconfig`
+
+Next, we should have a look at any relevant configuration settings (i.e.,
+settings readable and settable from `git config`). This is done by providing a
+callback to `git_config()`; within that callback, you can also invoke methods
+from other components you may need that need to intercept these options. Your
+callback will be invoked once per each configuration value which Git knows about
+(global, local, worktree, etc.).
+
+Similarly to the default values, we don't have anything to do here yet
+ourselves; however, we should call `git_default_config()` if we aren't calling
+any other existing config callbacks.
+
+Add a new function to `builtin/walken.c`:
+
+----
+static int git_walken_config(const char *var, const char *value, void *cb)
+{
+	/*
+	 * For now, we don't have any custom configuration, so fall back to
+	 * the default config.
+	 */
+	return git_default_config(var, value, cb);
+}
+----
+
+Make sure to invoke `git_config()` with it in your `cmd_walken()`:
+
+----
+int cmd_walken(int argc, const char **argv, const char *prefix)
+{
+	...
+
+	git_config(git_walken_config, NULL);
+
+	...
+}
+----
+
+==== Setting Up `rev_info`
+
+Now that we've gathered external configuration and options, it's time to
+initialize the `rev_info` object which we will use to perform the walk. This is
+typically done by calling `repo_init_revisions()` with the repository you intend
+to target, as well as the `prefix` argument of `cmd_walken` and your `rev_info`
+struct.
+
+Add the `struct rev_info` and the `repo_init_revisions()` call:
+----
+int cmd_walken(int argc, const char **argv, const char *prefix)
+{
+	/* This can go wherever you like in your declarations.*/
+	struct rev_info rev;
+	...
+
+	/* This should go after the git_config() call. */
+	repo_init_revisions(the_repository, &rev, prefix);
+
+	...
+}
+----
+
+==== Tweaking `rev_info` For the Walk
+
+We're getting close, but we're still not quite ready to go. Now that `rev` is
+initialized, we can modify it to fit our needs. This is usually done within a
+helper for clarity, so let's add one:
+
+----
+static void final_rev_info_setup(struct rev_info *rev)
+{
+	/*
+	 * We want to mimic the appearance of `git log --oneline`, so let's
+	 * force oneline format.
+	 */
+	get_commit_format("oneline", rev);
+
+	/* Start our object walk at HEAD. */
+	add_head_to_pending(rev);
+}
+----
+
+[NOTE]
+====
+Instead of using the shorthand `add_head_to_pending()`, you could do
+something like this:
+----
+	struct setup_revision_opt opt;
+
+	memset(&opt, 0, sizeof(opt));
+	opt.def = "HEAD";
+	opt.revarg_opt = REVARG_COMMITTISH;
+	setup_revisions(argc, argv, rev, &opt);
+----
+Using a `setup_revision_opt` gives you finer control over your walk's starting
+point.
+====
+
+Then let's invoke `final_rev_info_setup()` after the call to
+`repo_init_revisions()`:
+
+----
+int cmd_walken(int argc, const char **argv, const char *prefix)
+{
+	...
+
+	final_rev_info_setup(&rev);
+
+	...
+}
+----
+
+Later, we may wish to add more arguments to `final_rev_info_setup()`. But for
+now, this is all we need.
+
+==== Preparing `rev_info` For the Walk
+
+Now that `rev` is all initialized and configured, we've got one more setup step
+before we get rolling. We can do this in a helper, which will both prepare the
+`rev_info` for the walk, and perform the walk itself. Let's start the helper
+with the call to `prepare_revision_walk()`, which can return an error without
+dying on its own:
+
+----
+static void walken_commit_walk(struct rev_info *rev)
+{
+	if (prepare_revision_walk(rev))
+		die(_("revision walk setup failed"));
+}
+----
+
+NOTE: `die()` prints to `stderr` and exits the program. Since it will print to
+`stderr` it's likely to be seen by a human, so we will localize it.
+
+==== Performing the Walk!
+
+Finally! We are ready to begin the walk itself. Now we can see that `rev_info`
+can also be used as an iterator; we move to the next item in the walk by using
+`get_revision()` repeatedly. Add the listed variable declarations at the top and
+the walk loop below the `prepare_revision_walk()` call within your
+`walken_commit_walk()`:
+
+----
+static void walken_commit_walk(struct rev_info *rev)
+{
+	struct commit *commit;
+	struct strbuf prettybuf = STRBUF_INIT;
+
+	...
+
+	while ((commit = get_revision(rev))) {
+		if (!commit)
+			continue;
+
+		strbuf_reset(&prettybuf);
+		pp_commit_easy(CMIT_FMT_ONELINE, commit, &prettybuf);
+		puts(prettybuf.buf);
+	}
+	strbuf_release(&prettybuf);
+}
+----
+
+NOTE: `puts()` prints a `char*` to `stdout`. Since this is the part of the
+command we expect to be machine-parsed, we're sending it directly to stdout.
+
+Give it a shot.
+
+----
+$ make
+$ ./bin-wrappers/git walken
+----
+
+You should see all of the subject lines of all the commits in
+your tree's history, in order, ending with the initial commit, "Initial revision
+of "git", the information manager from hell". Congratulations! You've written
+your first revision walk. You can play with printing some additional fields
+from each commit if you're curious; have a look at the functions available in
+`commit.h`.
+
+=== Adding a Filter
+
+Next, let's try to filter the commits we see based on their author. This is
+equivalent to running `git log --author=<pattern>`. We can add a filter by
+modifying `rev_info.grep_filter`, which is a `struct grep_opt`.
+
+First some setup. Add `init_grep_defaults()` to `init_walken_defaults()` and add
+`grep_config()` to `git_walken_config()`:
+
+----
+static void init_walken_defaults(void)
+{
+	init_grep_defaults(the_repository);
+}
+
+...
+
+static int git_walken_config(const char *var, const char *value, void *cb)
+{
+	grep_config(var, value, cb);
+	return git_default_config(var, value, cb);
+}
+----
+
+Next, we can modify the `grep_filter`. This is done with convenience functions
+found in `grep.h`. For fun, we're filtering to only commits from folks using a
+`gmail.com` email address - a not-very-precise guess at who may be working on
+Git as a hobby. Since we're checking the author, which is a specific line in the
+header, we'll use the `append_header_grep_pattern()` helper. We can use
+the `enum grep_header_field` to indicate which part of the commit header we want
+to search.
+
+In `final_rev_info_setup()`, add your filter line:
+
+----
+static void final_rev_info_setup(int argc, const char **argv,
+		const char *prefix, struct rev_info *rev)
+{
+	...
+
+	append_header_grep_pattern(&rev->grep_filter, GREP_HEADER_AUTHOR,
+		"gmail");
+	compile_grep_patterns(&rev->grep_filter);
+
+	...
+}
+----
+
+`append_header_grep_pattern()` adds your new "gmail" pattern to `rev_info`, but
+it won't work unless we compile it with `compile_grep_patterns()`.
+
+NOTE: If you are using `setup_revisions()` (for example, if you are passing a
+`setup_revision_opt` instead of using `add_head_to_pending()`), you don't need
+to call `compile_grep_patterns()` because `setup_revisions()` calls it for you.
+
+NOTE: We could add the same filter via the `append_grep_pattern()` helper if we
+wanted to, but `append_header_grep_pattern()` adds the `enum grep_context` and
+`enum grep_pat_token` for us.
+
+=== Changing the Order
+
+There are a few ways that we can change the order of the commits during a
+revision walk. Firstly, we can use the `enum rev_sort_order` to choose from some
+typical orderings.
+
+`topo_order` is the same as `git log --topo-order`: we avoid showing a parent
+before all of its children have been shown, and we avoid mixing commits which
+are in different lines of history. (`git help log`'s section on `--topo-order`
+has a very nice diagram to illustrate this.)
+
+Let's see what happens when we run with `REV_SORT_BY_COMMIT_DATE` as opposed to
+`REV_SORT_BY_AUTHOR_DATE`. Add the following:
+
+----
+static void final_rev_info_setup(int argc, const char **argv,
+		const char *prefix, struct rev_info *rev)
+{
+	...
+
+	rev->topo_order = 1;
+	rev->sort_order = REV_SORT_BY_COMMIT_DATE;
+
+	...
+}
+----
+
+Let's output this into a file so we can easily diff it with the walk sorted by
+author date.
+
+----
+$ make
+$ ./bin-wrappers/git walken > commit-date.txt
+----
+
+Then, let's sort by author date and run it again.
+
+----
+static void final_rev_info_setup(int argc, const char **argv,
+		const char *prefix, struct rev_info *rev)
+{
+	...
+
+	rev->topo_order = 1;
+	rev->sort_order = REV_SORT_BY_AUTHOR_DATE;
+
+	...
+}
+----
+
+----
+$ make
+$ ./bin-wrappers/git walken > author-date.txt
+----
+
+Finally, compare the two. This is a little less helpful without object names or
+dates, but hopefully we get the idea.
+
+----
+$ diff -u commit-date.txt author-date.txt
+----
+
+This display indicates that commits can be reordered after they're written, for
+example with `git rebase`.
+
+Let's try one more reordering of commits. `rev_info` exposes a `reverse` flag.
+Set that flag somewhere inside of `final_rev_info_setup()`:
+
+----
+static void final_rev_info_setup(int argc, const char **argv, const char *prefix,
+		struct rev_info *rev)
+{
+	...
+
+	rev->reverse = 1;
+
+	...
+}
+----
+
+Run your walk again and note the difference in order. (If you remove the grep
+pattern, you should see the last commit this call gives you as your current
+HEAD.)
+
+== Basic Object Walk
+
+So far we've been walking only commits. But Git has more types of objects than
+that! Let's see if we can walk _all_ objects, and find out some information
+about each one.
+
+We can base our work on an example. `git pack-objects` prepares all kinds of
+objects for packing into a bitmap or packfile. The work we are interested in
+resides in `builtins/pack-objects.c:get_object_list()`; examination of that
+function shows that the all-object walk is being performed by
+`traverse_commit_list()` or `traverse_commit_list_filtered()`. Those two
+functions reside in `list-objects.c`; examining the source shows that, despite
+the name, these functions traverse all kinds of objects. Let's have a look at
+the arguments to `traverse_commit_list_filtered()`, which are a superset of the
+arguments to the unfiltered version.
+
+- `struct list_objects_filter_options *filter_options`: This is a struct which
+  stores a filter-spec as outlined in `Documentation/rev-list-options.txt`.
+- `struct rev_info *revs`: This is the `rev_info` used for the walk.
+- `show_commit_fn show_commit`: A callback which will be used to handle each
+  individual commit object.
+- `show_object_fn show_object`: A callback which will be used to handle each
+  non-commit object (so each blob, tree, or tag).
+- `void *show_data`: A context buffer which is passed in turn to `show_commit`
+  and `show_object`.
+- `struct oidset *omitted`: A linked-list of object IDs which the provided
+  filter caused to be omitted.
+
+It looks like this `traverse_commit_list_filtered()` uses callbacks we provide
+instead of needing us to call it repeatedly ourselves. Cool! Let's add the
+callbacks first.
+
+For the sake of this tutorial, we'll simply keep track of how many of each kind
+of object we find. At file scope in `builtin/walken.c` add the following
+tracking variables:
+
+----
+static int commit_count;
+static int tag_count;
+static int blob_count;
+static int tree_count;
+----
+
+Commits are handled by a different callback than other objects; let's do that
+one first:
+
+----
+static void walken_show_commit(struct commit *cmt, void *buf)
+{
+	commit_count++;
+}
+----
+
+The `cmt` argument is fairly self-explanatory. But it's worth mentioning that
+the `buf` argument is actually the context buffer that we can provide to the
+traversal calls - `show_data`, which we mentioned a moment ago.
+
+Since we have the `struct commit` object, we can look at all the same parts that
+we looked at in our earlier commit-only walk. For the sake of this tutorial,
+though, we'll just increment the commit counter and move on.
+
+The callback for non-commits is a little different, as we'll need to check
+which kind of object we're dealing with:
+
+----
+static void walken_show_object(struct object *obj, const char *str, void *buf)
+{
+	switch (obj->type) {
+	case OBJ_TREE:
+		tree_count++;
+		break;
+	case OBJ_BLOB:
+		blob_count++;
+		break;
+	case OBJ_TAG:
+		tag_count++;
+		break;
+	case OBJ_COMMIT:
+		BUG("unexpected commit object in walken_show_object\n");
+	default:
+		BUG("unexpected object type %s in walken_show_object\n",
+			type_name(obj->type));
+	}
+}
+----
+
+Again, `obj` is fairly self-explanatory, and we can guess that `buf` is the same
+context pointer that `walken_show_commit()` receives: the `show_data` argument
+to `traverse_commit_list()` and `traverse_commit_list_filtered()`. Finally,
+`str` contains the name of the object, which ends up being something like
+`foo.txt` (blob), `bar/baz` (tree), or `v1.2.3` (tag).
+
+To help assure us that we aren't double-counting commits, we'll include some
+complaining if a commit object is routed through our non-commit callback; we'll
+also complain if we see an invalid object type. Since those two cases should be
+unreachable, and would only change in the event of a semantic change to the Git
+codebase, we complain by using `BUG()` - which is a signal to a developer that
+the change they made caused unintended consequences, and the rest of the
+codebase needs to be updated to understand that change. `BUG()` is not intended
+to be seen by the public, so it is not localized.
+
+Our main object walk implementation is substantially different from our commit
+walk implementation, so let's make a new function to perform the object walk. We
+can perform setup which is applicable to all objects here, too, to keep separate
+from setup which is applicable to commit-only walks.
+
+We'll start by enabling all types of objects in the `struct rev_info`.  We'll
+also turn on `tree_blobs_in_commit_order`, which means that we will walk a
+commit's tree and everything it points to immediately after we find each commit,
+as opposed to waiting for the end and walking through all trees after the commit
+history has been discovered. With the appropriate settings configured, we are
+ready to call `prepare_revision_walk()`.
+
+----
+static void walken_object_walk(struct rev_info *rev)
+{
+	rev->tree_objects = 1;
+	rev->blob_objects = 1;
+	rev->tag_objects = 1;
+	rev->tree_blobs_in_commit_order = 1;
+
+	if (prepare_revision_walk(rev))
+		die(_("revision walk setup failed"));
+
+	commit_count = 0;
+	tag_count = 0;
+	blob_count = 0;
+	tree_count = 0;
+----
+
+Let's start by calling just the unfiltered walk and reporting our counts.
+Complete your implementation of `walken_object_walk()`:
+
+----
+	traverse_commit_list(rev, walken_show_commit, walken_show_object, NULL);
+
+	printf("commits %d\nblobs %d\ntags %d\ntrees %d\n", commit_count,
+		blob_count, tag_count, tree_count);
+}
+----
+
+NOTE: This output is intended to be machine-parsed. Therefore, we are not
+sending it to `trace_printf()`, and we are not localizing it - we need scripts
+to be able to count on the formatting to be exactly the way it is shown here.
+If we were intending this output to be read by humans, we would need to localize
+it with `_()`.
+
+Finally, we'll ask `cmd_walken()` to use the object walk instead. Discussing
+command line options is out of scope for this tutorial, so we'll just hardcode
+a branch we can change at compile time. Where you call `final_rev_info_setup()`
+and `walken_commit_walk()`, instead branch like so:
+
+----
+	if (1) {
+		add_head_to_pending(&rev);
+		walken_object_walk(&rev);
+	} else {
+		final_rev_info_setup(argc, argv, prefix, &rev);
+		walken_commit_walk(&rev);
+	}
+----
+
+NOTE: For simplicity, we've avoided all the filters and sorts we applied in
+`final_rev_info_setup()` and simply added `HEAD` to our pending queue. If you
+want, you can certainly use the filters we added before by moving
+`final_rev_info_setup()` out of the conditional and removing the call to
+`add_head_to_pending()`.
+
+Now we can try to run our command! It should take noticeably longer than the
+commit walk, but an examination of the output will give you an idea why. Your
+output should look similar to this example, but with different counts:
+
+----
+Object walk completed. Found 55733 commits, 100274 blobs, 0 tags, and 104210 trees.
+----
+
+This makes sense. We have more trees than commits because the Git project has
+lots of subdirectories which can change, plus at least one tree per commit. We
+have no tags because we started on a commit (`HEAD`) and while tags can point to
+commits, commits can't point to tags.
+
+NOTE: You will have different counts when you run this yourself! The number of
+objects grows along with the Git project.
+
+=== Adding a Filter
+
+There are a handful of filters that we can apply to the object walk laid out in
+`Documentation/rev-list-options.txt`. These filters are typically useful for
+operations such as creating packfiles or performing a partial clone. They are
+defined in `list-objects-filter-options.h`. For the purposes of this tutorial we
+will use the "tree:1" filter, which causes the walk to omit all trees and blobs
+which are not directly referenced by commits reachable from the commit in
+`pending` when the walk begins. (`pending` is the list of objects which need to
+be traversed during a walk; you can imagine a breadth-first tree traversal to
+help understand. In our case, that means we omit trees and blobs not directly
+referenced by `HEAD` or `HEAD`'s history, because we begin the walk with only
+`HEAD` in the `pending` list.)
+
+First, we'll need to `#include "list-objects-filter-options.h`" and set up the
+`struct list_objects_filter_options` at the top of the function.
+
+----
+static void walken_object_walk(struct rev_info *rev)
+{
+	struct list_objects_filter_options filter_options = {};
+
+	...
+----
+
+For now, we are not going to track the omitted objects, so we'll replace those
+parameters with `NULL`. For the sake of simplicity, we'll add a simple
+build-time branch to use our filter or not. Replace the line calling
+`traverse_commit_list()` with the following, which will remind us which kind of
+walk we've just performed:
+
+----
+	if (0) {
+		/* Unfiltered: */
+		trace_printf(_("Unfiltered object walk.\n"));
+		traverse_commit_list(rev, walken_show_commit,
+				walken_show_object, NULL);
+	} else {
+		trace_printf(
+			_("Filtered object walk with filterspec 'tree:1'.\n"));
+		parse_list_objects_filter(&filter_options, "tree:1");
+
+		traverse_commit_list_filtered(&filter_options, rev,
+			walken_show_commit, walken_show_object, NULL, NULL);
+	}
+----
+
+`struct list_objects_filter_options` is usually built directly from a command
+line argument, so the module provides an easy way to build one from a string.
+Even though we aren't taking user input right now, we can still build one with
+a hardcoded string using `parse_list_objects_filter()`.
+
+With the filter spec "tree:1", we are expecting to see _only_ the root tree for
+each commit; therefore, the tree object count should be less than or equal to
+the number of commits. (For an example of why that's true: `git commit --revert`
+points to the same tree object as its grandparent.)
+
+=== Counting Omitted Objects
+
+We also have the capability to enumerate all objects which were omitted by a
+filter, like with `git log --filter=<spec> --filter-print-omitted`. Asking
+`traverse_commit_list_filtered()` to populate the `omitted` list means that our
+object walk does not perform any better than an unfiltered object walk; all
+reachable objects are walked in order to populate the list.
+
+First, add the `struct oidset` and related items we will use to iterate it:
+
+----
+static void walken_object_walk(
+	...
+
+	struct oidset omitted;
+	struct oidset_iter oit;
+	struct object_id *oid = NULL;
+	int omitted_count = 0;
+	oidset_init(&omitted, 0);
+
+	...
+----
+
+Modify the call to `traverse_commit_list_filtered()` to include your `omitted`
+object:
+
+----
+	...
+
+		traverse_commit_list_filtered(&filter_options, rev,
+			walken_show_commit, walken_show_object, NULL, &omitted);
+
+	...
+----
+
+Then, after your traversal, the `oidset` traversal is pretty straightforward.
+Count all the objects within and modify the print statement:
+
+----
+	/* Count the omitted objects. */
+	oidset_iter_init(&omitted, &oit);
+
+	while ((oid = oidset_iter_next(&oit)))
+		omitted_count++;
+
+	printf("commits %d\nblobs %d\ntags %d\ntrees%d\nomitted %d\n",
+		commit_count, blob_count, tag_count, tree_count, omitted_count);
+----
+
+By running your walk with and without the filter, you should find that the total
+object count in each case is identical. You can also time each invocation of
+the `walken` subcommand, with and without `omitted` being passed in, to confirm
+to yourself the runtime impact of tracking all omitted objects.
+
+=== Changing the Order
+
+Finally, let's demonstrate that you can also reorder walks of all objects, not
+just walks of commits. First, we'll make our handlers chattier - modify
+`walken_show_commit()` and `walken_show_object()` to print the object as they
+go:
+
+----
+static void walken_show_commit(struct commit *cmt, void *buf)
+{
+	trace_printf("commit: %s\n", oid_to_hex(&cmt->object.oid));
+	commit_count++;
+}
+
+static void walken_show_object(struct object *obj, const char *str, void *buf)
+{
+	trace_printf("%s: %s\n", type_name(obj->type), oid_to_hex(&obj->oid));
+
+	...
+}
+----
+
+NOTE: Since we will be examining this output directly as humans, we'll use
+`trace_printf()` here. Additionally, since this change introduces a significant
+number of printed lines, using `trace_printf()` will allow us to easily silence
+those lines without having to recompile.
+
+(Leave the counter increment logic in place.)
+
+With only that change, run again (but save yourself some scrollback):
+
+----
+$ GIT_TRACE=1 ./bin-wrappers/git walken | head -n 10
+----
+
+Take a look at the top commit with `git show` and the object ID you printed; it
+should be the same as the output of `git show HEAD`.
+
+Next, let's change a setting on our `struct rev_info` within
+`walken_object_walk()`. Find where you're changing the other settings on `rev`,
+such as `rev->tree_objects` and `rev->tree_blobs_in_commit_order`, and add the
+`reverse` setting at the bottom:
+
+----
+	...
+
+	rev->tree_objects = 1;
+	rev->blob_objects = 1;
+	rev->tag_objects = 1;
+	rev->tree_blobs_in_commit_order = 1;
+	rev->reverse = 1;
+
+	...
+----
+
+Now, run again, but this time, let's grab the last handful of objects instead
+of the first handful:
+
+----
+$ make
+$ GIT_TRACE=1 ./bin-wrappers git walken | tail -n 10
+----
+
+The last commit object given should have the same OID as the one we saw at the
+top before, and running `git show <oid>` with that OID should give you again
+the same results as `git show HEAD`. Furthermore, if you run and examine the
+first ten lines again (with `head` instead of `tail` like we did before applying
+the `reverse` setting), you should see that now the first commit printed is the
+initial commit, `e83c5163`.
+
+== Wrapping Up
+
+Let's review. In this tutorial, we:
+
+- Built a commit walk from the ground up
+- Enabled a grep filter for that commit walk
+- Changed the sort order of that filtered commit walk
+- Built an object walk (tags, commits, trees, and blobs) from the ground up
+- Learned how to add a filter-spec to an object walk
+- Changed the display order of the filtered object walk
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/pretty-formats.txt 1.2.3+git2.25.1-1/git/Documentation/pretty-formats.txt
--- 1.2.1+git2.18.0-1/git/Documentation/pretty-formats.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/pretty-formats.txt	2020-02-17 04:47:35.000000000 +0000
@@ -4,7 +4,7 @@ PRETTY FORMATS
 If the commit is a merge, and if the pretty-format
 is not 'oneline', 'email' or 'raw', an additional line is
 inserted before the 'Author:' line.  This line begins with
-"Merge: " and the sha1s of ancestral commits are printed,
+"Merge: " and the hashes of ancestral commits are printed,
 separated by spaces.  Note that the listed commits may not
 necessarily be the list of the *direct* parent commits if you
 have limited your view of history: for example, if you are
@@ -20,20 +20,20 @@ built-in formats:
 
 * 'oneline'
 
-	  <sha1> <title line>
+	  <hash> <title line>
 +
 This is designed to be as compact as possible.
 
 * 'short'
 
-	  commit <sha1>
+	  commit <hash>
 	  Author: <author>
 
 	      <title line>
 
 * 'medium'
 
-	  commit <sha1>
+	  commit <hash>
 	  Author: <author>
 	  Date:   <author date>
 
@@ -43,7 +43,7 @@ This is designed to be as compact as pos
 
 * 'full'
 
-	  commit <sha1>
+	  commit <hash>
 	  Author: <author>
 	  Commit: <committer>
 
@@ -53,7 +53,7 @@ This is designed to be as compact as pos
 
 * 'fuller'
 
-	  commit <sha1>
+	  commit <hash>
 	  Author:     <author>
 	  AuthorDate: <author date>
 	  Commit:     <committer>
@@ -63,9 +63,20 @@ This is designed to be as compact as pos
 
 	       <full commit message>
 
+* 'reference'
+
+	  <abbrev hash> (<title line>, <short author date>)
++
+This format is used to refer to another commit in a commit message and
+is the same as `--pretty='format:%C(auto)%h (%s, %ad)'`.  By default,
+the date is formatted with `--date=short` unless another `--date` option
+is explicitly specified.  As with any `format:` with format
+placeholders, its output is not affected by other options like
+`--decorate` and `--walk-reflogs`.
+
 * 'email'
 
-	  From <sha1> <date>
+	  From <hash> <date>
 	  From: <author>
 	  Date: <author date>
 	  Subject: [PATCH] <title line>
@@ -75,7 +86,7 @@ This is designed to be as compact as pos
 * 'raw'
 +
 The 'raw' format shows the entire commit exactly as
-stored in the commit object.  Notably, the SHA-1s are
+stored in the commit object.  Notably, the hashes are
 displayed in full, regardless of whether --abbrev or
 --no-abbrev are used, and 'parents' information show the
 true parent commits, without taking grafts or history
@@ -102,115 +113,168 @@ The title was >>t4119: test autocomputin
 +
 The placeholders are:
 
-- '%H': commit hash
-- '%h': abbreviated commit hash
-- '%T': tree hash
-- '%t': abbreviated tree hash
-- '%P': parent hashes
-- '%p': abbreviated parent hashes
-- '%an': author name
-- '%aN': author name (respecting .mailmap, see linkgit:git-shortlog[1]
-  or linkgit:git-blame[1])
-- '%ae': author email
-- '%aE': author email (respecting .mailmap, see
-  linkgit:git-shortlog[1] or linkgit:git-blame[1])
-- '%ad': author date (format respects --date= option)
-- '%aD': author date, RFC2822 style
-- '%ar': author date, relative
-- '%at': author date, UNIX timestamp
-- '%ai': author date, ISO 8601-like format
-- '%aI': author date, strict ISO 8601 format
-- '%cn': committer name
-- '%cN': committer name (respecting .mailmap, see
-  linkgit:git-shortlog[1] or linkgit:git-blame[1])
-- '%ce': committer email
-- '%cE': committer email (respecting .mailmap, see
-  linkgit:git-shortlog[1] or linkgit:git-blame[1])
-- '%cd': committer date (format respects --date= option)
-- '%cD': committer date, RFC2822 style
-- '%cr': committer date, relative
-- '%ct': committer date, UNIX timestamp
-- '%ci': committer date, ISO 8601-like format
-- '%cI': committer date, strict ISO 8601 format
-- '%d': ref names, like the --decorate option of linkgit:git-log[1]
-- '%D': ref names without the " (", ")" wrapping.
-- '%e': encoding
-- '%s': subject
-- '%f': sanitized subject line, suitable for a filename
-- '%b': body
-- '%B': raw body (unwrapped subject and body)
+- Placeholders that expand to a single literal character:
+'%n':: newline
+'%%':: a raw '%'
+'%x00':: print a byte from a hex code
+
+- Placeholders that affect formatting of later placeholders:
+'%Cred':: switch color to red
+'%Cgreen':: switch color to green
+'%Cblue':: switch color to blue
+'%Creset':: reset color
+'%C(...)':: color specification, as described under Values in the
+	    "CONFIGURATION FILE" section of linkgit:git-config[1].  By
+	    default, colors are shown only when enabled for log output
+	    (by `color.diff`, `color.ui`, or `--color`, and respecting
+	    the `auto` settings of the former if we are going to a
+	    terminal). `%C(auto,...)` is accepted as a historical
+	    synonym for the default (e.g., `%C(auto,red)`). Specifying
+	    `%C(always,...)` will show the colors even when color is
+	    not otherwise enabled (though consider just using
+	    `--color=always` to enable color for the whole output,
+	    including this format and anything else git might color).
+	    `auto` alone (i.e. `%C(auto)`) will turn on auto coloring
+	    on the next placeholders until the color is switched
+	    again.
+'%m':: left (`<`), right (`>`) or boundary (`-`) mark
+'%w([<w>[,<i1>[,<i2>]]])':: switch line wrapping, like the -w option of
+			    linkgit:git-shortlog[1].
+'%<(<N>[,trunc|ltrunc|mtrunc])':: make the next placeholder take at
+				  least N columns, padding spaces on
+				  the right if necessary.  Optionally
+				  truncate at the beginning (ltrunc),
+				  the middle (mtrunc) or the end
+				  (trunc) if the output is longer than
+				  N columns.  Note that truncating
+				  only works correctly with N >= 2.
+'%<|(<N>)':: make the next placeholder take at least until Nth
+	     columns, padding spaces on the right if necessary
+'%>(<N>)', '%>|(<N>)':: similar to '%<(<N>)', '%<|(<N>)' respectively,
+			but padding spaces on the left
+'%>>(<N>)', '%>>|(<N>)':: similar to '%>(<N>)', '%>|(<N>)'
+			  respectively, except that if the next
+			  placeholder takes more spaces than given and
+			  there are spaces on its left, use those
+			  spaces
+'%><(<N>)', '%><|(<N>)':: similar to '%<(<N>)', '%<|(<N>)'
+			  respectively, but padding both sides
+			  (i.e. the text is centered)
+
+- Placeholders that expand to information extracted from the commit:
+'%H':: commit hash
+'%h':: abbreviated commit hash
+'%T':: tree hash
+'%t':: abbreviated tree hash
+'%P':: parent hashes
+'%p':: abbreviated parent hashes
+'%an':: author name
+'%aN':: author name (respecting .mailmap, see linkgit:git-shortlog[1]
+	or linkgit:git-blame[1])
+'%ae':: author email
+'%aE':: author email (respecting .mailmap, see linkgit:git-shortlog[1]
+	or linkgit:git-blame[1])
+'%al':: author email local-part (the part before the '@' sign)
+'%aL':: author local-part (see '%al') respecting .mailmap, see
+	linkgit:git-shortlog[1] or linkgit:git-blame[1])
+'%ad':: author date (format respects --date= option)
+'%aD':: author date, RFC2822 style
+'%ar':: author date, relative
+'%at':: author date, UNIX timestamp
+'%ai':: author date, ISO 8601-like format
+'%aI':: author date, strict ISO 8601 format
+'%as':: author date, short format (`YYYY-MM-DD`)
+'%cn':: committer name
+'%cN':: committer name (respecting .mailmap, see
+	linkgit:git-shortlog[1] or linkgit:git-blame[1])
+'%ce':: committer email
+'%cE':: committer email (respecting .mailmap, see
+	linkgit:git-shortlog[1] or linkgit:git-blame[1])
+'%cl':: author email local-part (the part before the '@' sign)
+'%cL':: author local-part (see '%cl') respecting .mailmap, see
+	linkgit:git-shortlog[1] or linkgit:git-blame[1])
+'%cd':: committer date (format respects --date= option)
+'%cD':: committer date, RFC2822 style
+'%cr':: committer date, relative
+'%ct':: committer date, UNIX timestamp
+'%ci':: committer date, ISO 8601-like format
+'%cI':: committer date, strict ISO 8601 format
+'%cs':: committer date, short format (`YYYY-MM-DD`)
+'%d':: ref names, like the --decorate option of linkgit:git-log[1]
+'%D':: ref names without the " (", ")" wrapping.
+'%S':: ref name given on the command line by which the commit was reached
+       (like `git log --source`), only works with `git log`
+'%e':: encoding
+'%s':: subject
+'%f':: sanitized subject line, suitable for a filename
+'%b':: body
+'%B':: raw body (unwrapped subject and body)
 ifndef::git-rev-list[]
-- '%N': commit notes
+'%N':: commit notes
 endif::git-rev-list[]
-- '%GG': raw verification message from GPG for a signed commit
-- '%G?': show "G" for a good (valid) signature,
-  "B" for a bad signature,
-  "U" for a good signature with unknown validity,
-  "X" for a good signature that has expired,
-  "Y" for a good signature made by an expired key,
-  "R" for a good signature made by a revoked key,
-  "E" if the signature cannot be checked (e.g. missing key)
-  and "N" for no signature
-- '%GS': show the name of the signer for a signed commit
-- '%GK': show the key used to sign a signed commit
-- '%gD': reflog selector, e.g., `refs/stash@{1}` or
-  `refs/stash@{2 minutes ago`}; the format follows the rules described
-  for the `-g` option. The portion before the `@` is the refname as
-  given on the command line (so `git log -g refs/heads/master` would
-  yield `refs/heads/master@{0}`).
-- '%gd': shortened reflog selector; same as `%gD`, but the refname
-  portion is shortened for human readability (so `refs/heads/master`
-  becomes just `master`).
-- '%gn': reflog identity name
-- '%gN': reflog identity name (respecting .mailmap, see
-  linkgit:git-shortlog[1] or linkgit:git-blame[1])
-- '%ge': reflog identity email
-- '%gE': reflog identity email (respecting .mailmap, see
-  linkgit:git-shortlog[1] or linkgit:git-blame[1])
-- '%gs': reflog subject
-- '%Cred': switch color to red
-- '%Cgreen': switch color to green
-- '%Cblue': switch color to blue
-- '%Creset': reset color
-- '%C(...)': color specification, as described under Values in the
-  "CONFIGURATION FILE" section of linkgit:git-config[1].
-  By default, colors are shown only when enabled for log output (by
-  `color.diff`, `color.ui`, or `--color`, and respecting the `auto`
-  settings of the former if we are going to a terminal). `%C(auto,...)`
-  is accepted as a historical synonym for the default (e.g.,
-  `%C(auto,red)`). Specifying `%C(always,...) will show the colors
-  even when color is not otherwise enabled (though consider
-  just using `--color=always` to enable color for the whole output,
-  including this format and anything else git might color).  `auto`
-  alone (i.e. `%C(auto)`) will turn on auto coloring on the next
-  placeholders until the color is switched again.
-- '%m': left (`<`), right (`>`) or boundary (`-`) mark
-- '%n': newline
-- '%%': a raw '%'
-- '%x00': print a byte from a hex code
-- '%w([<w>[,<i1>[,<i2>]]])': switch line wrapping, like the -w option of
-  linkgit:git-shortlog[1].
-- '%<(<N>[,trunc|ltrunc|mtrunc])': make the next placeholder take at
-  least N columns, padding spaces on the right if necessary.
-  Optionally truncate at the beginning (ltrunc), the middle (mtrunc)
-  or the end (trunc) if the output is longer than N columns.
-  Note that truncating only works correctly with N >= 2.
-- '%<|(<N>)': make the next placeholder take at least until Nth
-  columns, padding spaces on the right if necessary
-- '%>(<N>)', '%>|(<N>)': similar to '%<(<N>)', '%<|(<N>)'
-  respectively, but padding spaces on the left
-- '%>>(<N>)', '%>>|(<N>)': similar to '%>(<N>)', '%>|(<N>)'
-  respectively, except that if the next placeholder takes more spaces
-  than given and there are spaces on its left, use those spaces
-- '%><(<N>)', '%><|(<N>)': similar to '%<(<N>)', '%<|(<N>)'
-  respectively, but padding both sides (i.e. the text is centered)
-- %(trailers[:options]): display the trailers of the body as interpreted
-  by linkgit:git-interpret-trailers[1]. The `trailers` string may be
-  followed by a colon and zero or more comma-separated options. If the
-  `only` option is given, omit non-trailer lines from the trailer block.
-  If the `unfold` option is given, behave as if interpret-trailer's
-  `--unfold` option was given.  E.g., `%(trailers:only,unfold)` to do
-  both.
+'%GG':: raw verification message from GPG for a signed commit
+'%G?':: show "G" for a good (valid) signature,
+	"B" for a bad signature,
+	"U" for a good signature with unknown validity,
+	"X" for a good signature that has expired,
+	"Y" for a good signature made by an expired key,
+	"R" for a good signature made by a revoked key,
+	"E" if the signature cannot be checked (e.g. missing key)
+	and "N" for no signature
+'%GS':: show the name of the signer for a signed commit
+'%GK':: show the key used to sign a signed commit
+'%GF':: show the fingerprint of the key used to sign a signed commit
+'%GP':: show the fingerprint of the primary key whose subkey was used
+	to sign a signed commit
+'%gD':: reflog selector, e.g., `refs/stash@{1}` or `refs/stash@{2
+	minutes ago}`; the format follows the rules described for the
+	`-g` option. The portion before the `@` is the refname as
+	given on the command line (so `git log -g refs/heads/master`
+	would yield `refs/heads/master@{0}`).
+'%gd':: shortened reflog selector; same as `%gD`, but the refname
+	portion is shortened for human readability (so
+	`refs/heads/master` becomes just `master`).
+'%gn':: reflog identity name
+'%gN':: reflog identity name (respecting .mailmap, see
+	linkgit:git-shortlog[1] or linkgit:git-blame[1])
+'%ge':: reflog identity email
+'%gE':: reflog identity email (respecting .mailmap, see
+	linkgit:git-shortlog[1] or linkgit:git-blame[1])
+'%gs':: reflog subject
+'%(trailers[:options])':: display the trailers of the body as
+			  interpreted by
+			  linkgit:git-interpret-trailers[1]. The
+			  `trailers` string may be followed by a colon
+			  and zero or more comma-separated options:
+** 'key=<K>': only show trailers with specified key. Matching is done
+   case-insensitively and trailing colon is optional. If option is
+   given multiple times trailer lines matching any of the keys are
+   shown. This option automatically enables the `only` option so that
+   non-trailer lines in the trailer block are hidden. If that is not
+   desired it can be disabled with `only=false`.  E.g.,
+   `%(trailers:key=Reviewed-by)` shows trailer lines with key
+   `Reviewed-by`.
+** 'only[=val]': select whether non-trailer lines from the trailer
+   block should be included. The `only` keyword may optionally be
+   followed by an equal sign and one of `true`, `on`, `yes` to omit or
+   `false`, `off`, `no` to show the non-trailer lines. If option is
+   given without value it is enabled. If given multiple times the last
+   value is used.
+** 'separator=<SEP>': specify a separator inserted between trailer
+   lines. When this option is not given each trailer line is
+   terminated with a line feed character. The string SEP may contain
+   the literal formatting codes described above. To use comma as
+   separator one must use `%x2C` as it would otherwise be parsed as
+   next option. If separator option is given multiple times only the
+   last one is used. E.g., `%(trailers:key=Ticket,separator=%x2C )`
+   shows all trailer lines whose key is "Ticket" separated by a comma
+   and a space.
+** 'unfold[=val]': make it behave as if interpret-trailer's `--unfold`
+   option was given. In same way as to for `only` it can be followed
+   by an equal sign and explicit value. E.g.,
+   `%(trailers:only,unfold=true)` unfolds and shows all trailer lines.
+** 'valueonly[=val]': skip over the key part of the trailer line and only
+   show the value part. Also this optionally allows explicit value.
 
 NOTE: Some placeholders may depend on other options given to the
 revision traversal engine. For example, the `%g*` reflog options will
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/pretty-options.txt 1.2.3+git2.25.1-1/git/Documentation/pretty-options.txt
--- 1.2.1+git2.18.0-1/git/Documentation/pretty-options.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/pretty-options.txt	2020-02-17 04:47:35.000000000 +0000
@@ -3,7 +3,7 @@
 
 	Pretty-print the contents of the commit logs in a given format,
 	where '<format>' can be one of 'oneline', 'short', 'medium',
-	'full', 'fuller', 'email', 'raw', 'format:<string>'
+	'full', 'fuller', 'reference', 'email', 'raw', 'format:<string>'
 	and 'tformat:<string>'.  When '<format>' is none of the above,
 	and has '%placeholder' in it, it acts as if
 	'--pretty=tformat:<format>' were given.
@@ -57,7 +57,7 @@ message by 4 spaces (i.e.  'medium', whi
 and 'fuller').
 
 ifndef::git-rev-list[]
---notes[=<treeish>]::
+--notes[=<ref>]::
 	Show the notes (see linkgit:git-notes[1]) that annotate the
 	commit, when showing the commit log message.  This is the default
 	for `git log`, `git show` and `git whatchanged` commands when
@@ -68,8 +68,8 @@ By default, the notes shown are from the
 `core.notesRef` and `notes.displayRef` variables (or corresponding
 environment overrides). See linkgit:git-config[1] for more details.
 +
-With an optional '<treeish>' argument, use the treeish to find the notes
-to display.  The treeish can specify the full refname when it begins
+With an optional '<ref>' argument, use the ref to find the notes
+to display.  The ref can specify the full refname when it begins
 with `refs/notes/`; when it begins with `notes/`, `refs/` and otherwise
 `refs/notes/` is prefixed to form a full name of the ref.
 +
@@ -85,7 +85,7 @@ being displayed. Examples: "--notes=foo"
 	"--notes --notes=foo --no-notes --notes=bar" will only show notes
 	from "refs/notes/bar".
 
---show-notes[=<treeish>]::
+--show-notes[=<ref>]::
 --[no-]standard-notes::
 	These options are deprecated. Use the above --notes/--no-notes
 	options instead.
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/pull-fetch-param.txt 1.2.3+git2.25.1-1/git/Documentation/pull-fetch-param.txt
--- 1.2.1+git2.18.0-1/git/Documentation/pull-fetch-param.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/pull-fetch-param.txt	2020-02-17 04:47:35.000000000 +0000
@@ -33,11 +33,40 @@ name.
 it requests fetching everything up to the given tag.
 +
 The remote ref that matches <src>
-is fetched, and if <dst> is not empty string, the local
-ref that matches it is fast-forwarded using <src>.
-If the optional plus `+` is used, the local ref
-is updated even if it does not result in a fast-forward
-update.
+is fetched, and if <dst> is not an empty string, an attempt
+is made to update the local ref that matches it.
++
+Whether that update is allowed without `--force` depends on the ref
+namespace it's being fetched to, the type of object being fetched, and
+whether the update is considered to be a fast-forward. Generally, the
+same rules apply for fetching as when pushing, see the `<refspec>...`
+section of linkgit:git-push[1] for what those are. Exceptions to those
+rules particular to 'git fetch' are noted below.
++
+Until Git version 2.20, and unlike when pushing with
+linkgit:git-push[1], any updates to `refs/tags/*` would be accepted
+without `+` in the refspec (or `--force`). When fetching, we promiscuously
+considered all tag updates from a remote to be forced fetches.  Since
+Git version 2.20, fetching to update `refs/tags/*` works the same way
+as when pushing. I.e. any updates will be rejected without `+` in the
+refspec (or `--force`).
++
+Unlike when pushing with linkgit:git-push[1], any updates outside of
+`refs/{tags,heads}/*` will be accepted without `+` in the refspec (or
+`--force`), whether that's swapping e.g. a tree object for a blob, or
+a commit for another commit that's doesn't have the previous commit as
+an ancestor etc.
++
+Unlike when pushing with linkgit:git-push[1], there is no
+configuration which'll amend these rules, and nothing like a
+`pre-fetch` hook analogous to the `pre-receive` hook.
++
+As with pushing with linkgit:git-push[1], all of the rules described
+above about what's not allowed as an update can be overridden by
+adding an the optional leading `+` to a refspec (or using `--force`
+command line option). The only exception to this is that no amount of
+forcing will make the `refs/heads/*` namespace accept a non-commit
+object.
 +
 [NOTE]
 When the remote branch you want to fetch is known to
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/rebase-config.txt 1.2.3+git2.25.1-1/git/Documentation/rebase-config.txt
--- 1.2.1+git2.18.0-1/git/Documentation/rebase-config.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/rebase-config.txt	1970-01-01 00:00:00.000000000 +0000
@@ -1,52 +0,0 @@
-rebase.stat::
-	Whether to show a diffstat of what changed upstream since the last
-	rebase. False by default.
-
-rebase.autoSquash::
-	If set to true enable `--autosquash` option by default.
-
-rebase.autoStash::
-	When set to true, automatically create a temporary stash entry
-	before the operation begins, and apply it after the operation
-	ends.  This means that you can run rebase on a dirty worktree.
-	However, use with care: the final stash application after a
-	successful rebase might result in non-trivial conflicts.
-	This option can be overridden by the `--no-autostash` and
-	`--autostash` options of linkgit:git-rebase[1].
-	Defaults to false.
-
-rebase.missingCommitsCheck::
-	If set to "warn", git rebase -i will print a warning if some
-	commits are removed (e.g. a line was deleted), however the
-	rebase will still proceed. If set to "error", it will print
-	the previous warning and stop the rebase, 'git rebase
-	--edit-todo' can then be used to correct the error. If set to
-	"ignore", no checking is done.
-	To drop a commit without warning or error, use the `drop`
-	command in the todo list.
-	Defaults to "ignore".
-
-rebase.instructionFormat::
-	A format string, as specified in linkgit:git-log[1], to be used for the
-	todo list during an interactive rebase.  The format will
-	automatically have the long commit hash prepended to the format.
-
-rebase.abbreviateCommands::
-	If set to true, `git rebase` will use abbreviated command names in the
-	todo list resulting in something like this:
-+
--------------------------------------------
-	p deadbee The oneline of the commit
-	p fa1afe1 The oneline of the next commit
-	...
--------------------------------------------
-+
-instead of:
-+
--------------------------------------------
-	pick deadbee The oneline of the commit
-	pick fa1afe1 The oneline of the next commit
-	...
--------------------------------------------
-+
-Defaults to false.
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/RelNotes/1.5.0.txt 1.2.3+git2.25.1-1/git/Documentation/RelNotes/1.5.0.txt
--- 1.2.1+git2.18.0-1/git/Documentation/RelNotes/1.5.0.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/RelNotes/1.5.0.txt	2020-02-17 04:47:35.000000000 +0000
@@ -251,7 +251,7 @@ Updates in v1.5.0 since v1.4.4 series
    the repository when that happens.
 
 
-* Crufts removal
+* Cruft removal
 
  - We used to say "old commits are retrievable using reflog and
    'master@{yesterday}' syntax as long as you haven't run
@@ -379,7 +379,7 @@ Updates in v1.5.0 since v1.4.4 series
  - The value of i18n.commitencoding in the originating
    repository is recorded in the commit object on the "encoding"
    header, if it is not UTF-8.  git-log and friends notice this,
-   and reencodes the message to the log output encoding when
+   and re-encodes the message to the log output encoding when
    displaying, if they are different.  The log output encoding
    is determined by "git log --encoding=<encoding>",
    i18n.logoutputencoding configuration, or i18n.commitencoding
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/RelNotes/1.6.2.txt 1.2.3+git2.25.1-1/git/Documentation/RelNotes/1.6.2.txt
--- 1.2.1+git2.18.0-1/git/Documentation/RelNotes/1.6.2.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/RelNotes/1.6.2.txt	2020-02-17 04:47:35.000000000 +0000
@@ -11,7 +11,7 @@ push running this release will issue a b
 configuration variable is missing.  Please refer to:
 
   http://git.or.cz/gitwiki/GitFaq#non-bare
-  http://thread.gmane.org/gmane.comp.version-control.git/107758/focus=108007
+  https://lore.kernel.org/git/7vbptlsuyv.fsf@gitster.siamese.dyndns.org/
 
 for more details on the reason why this change is needed and the
 transition plan.
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/RelNotes/1.6.3.txt 1.2.3+git2.25.1-1/git/Documentation/RelNotes/1.6.3.txt
--- 1.2.1+git2.18.0-1/git/Documentation/RelNotes/1.6.3.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/RelNotes/1.6.3.txt	2020-02-17 04:47:35.000000000 +0000
@@ -11,7 +11,7 @@ push running this release will issue a b
 configuration variable is missing.  Please refer to:
 
   http://git.or.cz/gitwiki/GitFaq#non-bare
-  http://thread.gmane.org/gmane.comp.version-control.git/107758/focus=108007
+  https://lore.kernel.org/git/7vbptlsuyv.fsf@gitster.siamese.dyndns.org/
 
 for more details on the reason why this change is needed and the
 transition plan.
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/RelNotes/1.6.4.txt 1.2.3+git2.25.1-1/git/Documentation/RelNotes/1.6.4.txt
--- 1.2.1+git2.18.0-1/git/Documentation/RelNotes/1.6.4.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/RelNotes/1.6.4.txt	2020-02-17 04:47:35.000000000 +0000
@@ -11,7 +11,7 @@ push running this release will issue a b
 configuration variable is missing.  Please refer to:
 
   http://git.or.cz/gitwiki/GitFaq#non-bare
-  http://thread.gmane.org/gmane.comp.version-control.git/107758/focus=108007
+  https://lore.kernel.org/git/7vbptlsuyv.fsf@gitster.siamese.dyndns.org/
 
 for more details on the reason why this change is needed and the
 transition plan.
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/RelNotes/1.6.5.4.txt 1.2.3+git2.25.1-1/git/Documentation/RelNotes/1.6.5.4.txt
--- 1.2.1+git2.18.0-1/git/Documentation/RelNotes/1.6.5.4.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/RelNotes/1.6.5.4.txt	2020-02-17 04:47:35.000000000 +0000
@@ -10,7 +10,7 @@ Fixes since v1.6.5.3
 
  * "git prune-packed" gave progress output even when its standard error is
    not connected to a terminal; this caused cron jobs that run it to
-   produce crufts.
+   produce cruft.
 
  * "git pack-objects --all-progress" is an option to ask progress output
    from write-object phase _if_ progress output were to be produced, and
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/RelNotes/1.6.5.txt 1.2.3+git2.25.1-1/git/Documentation/RelNotes/1.6.5.txt
--- 1.2.1+git2.18.0-1/git/Documentation/RelNotes/1.6.5.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/RelNotes/1.6.5.txt	2020-02-17 04:47:35.000000000 +0000
@@ -22,7 +22,7 @@ push running this release will issue a b
 configuration variable is missing.  Please refer to:
 
   http://git.or.cz/gitwiki/GitFaq#non-bare
-  http://thread.gmane.org/gmane.comp.version-control.git/107758/focus=108007
+  https://lore.kernel.org/git/7vbptlsuyv.fsf@gitster.siamese.dyndns.org/
 
 for more details on the reason why this change is needed and the
 transition plan.
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/RelNotes/1.6.6.txt 1.2.3+git2.25.1-1/git/Documentation/RelNotes/1.6.6.txt
--- 1.2.1+git2.18.0-1/git/Documentation/RelNotes/1.6.6.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/RelNotes/1.6.6.txt	2020-02-17 04:47:35.000000000 +0000
@@ -64,7 +64,7 @@ users will fare this time.
    Please refer to:
 
    http://git.or.cz/gitwiki/GitFaq#non-bare
-   http://thread.gmane.org/gmane.comp.version-control.git/107758/focus=108007
+   https://lore.kernel.org/git/7vbptlsuyv.fsf@gitster.siamese.dyndns.org/
 
    for more details on the reason why this change is needed and the
    transition process that already took place so far.
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/RelNotes/1.7.0.2.txt 1.2.3+git2.25.1-1/git/Documentation/RelNotes/1.7.0.2.txt
--- 1.2.1+git2.18.0-1/git/Documentation/RelNotes/1.7.0.2.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/RelNotes/1.7.0.2.txt	2020-02-17 04:47:35.000000000 +0000
@@ -34,7 +34,7 @@ Fixes since v1.7.0.1
  * "git status" in 1.7.0 lacked the optimization we used to have in 1.6.X series
    to speed up scanning of large working tree.
 
- * "gitweb" did not diagnose parsing errors properly while reading tis configuration
+ * "gitweb" did not diagnose parsing errors properly while reading its configuration
    file.
 
 And other minor fixes and documentation updates.
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/RelNotes/1.7.10.4.txt 1.2.3+git2.25.1-1/git/Documentation/RelNotes/1.7.10.4.txt
--- 1.2.1+git2.18.0-1/git/Documentation/RelNotes/1.7.10.4.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/RelNotes/1.7.10.4.txt	2020-02-17 04:47:35.000000000 +0000
@@ -7,7 +7,7 @@ Fixes since v1.7.10.3
  * The message file for Swedish translation has been updated a bit.
 
  * A name taken from mailmap was copied into an internal buffer
-   incorrectly and could overun the buffer if it is too long.
+   incorrectly and could overrun the buffer if it is too long.
 
  * A malformed commit object that has a header line chomped in the
    middle could kill git with a NULL pointer dereference.
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/RelNotes/1.7.12.3.txt 1.2.3+git2.25.1-1/git/Documentation/RelNotes/1.7.12.3.txt
--- 1.2.1+git2.18.0-1/git/Documentation/RelNotes/1.7.12.3.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/RelNotes/1.7.12.3.txt	2020-02-17 04:47:35.000000000 +0000
@@ -25,7 +25,7 @@ Fixes since v1.7.12.2
    its Accept-Encoding header.
 
  * "git receive-pack" (the counterpart to "git push") did not give
-   progress output while processing objects it received to the puser
+   progress output while processing objects it received to the user
    when run over the smart-http protocol.
 
  * "git status" honored the ignore=dirty settings in .gitmodules but
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/RelNotes/1.7.5.3.txt 1.2.3+git2.25.1-1/git/Documentation/RelNotes/1.7.5.3.txt
--- 1.2.1+git2.18.0-1/git/Documentation/RelNotes/1.7.5.3.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/RelNotes/1.7.5.3.txt	2020-02-17 04:47:35.000000000 +0000
@@ -22,7 +22,7 @@ Fixes since v1.7.5.2
  * "git log --stdin path" with an input that has additional pathspec
    used to corrupt memory.
 
- * "git send-pack" (hence "git push") over smalt-HTTP protocol could
+ * "git send-pack" (hence "git push") over smart-HTTP protocol could
    deadlock when the client side pack-object died early.
 
  * Compressed tarball gitweb generates used to be made with the timestamp
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/RelNotes/1.8.0.txt 1.2.3+git2.25.1-1/git/Documentation/RelNotes/1.8.0.txt
--- 1.2.1+git2.18.0-1/git/Documentation/RelNotes/1.8.0.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/RelNotes/1.8.0.txt	2020-02-17 04:47:35.000000000 +0000
@@ -233,7 +233,7 @@ to them for details).
    together, misdetected branches.
 
  * "git receive-pack" (the counterpart to "git push") did not give
-   progress output while processing objects it received to the puser
+   progress output while processing objects it received to the user
    when run over the smart-http protocol.
 
  * When you misspell the command name you give to the "exec" action in
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/RelNotes/1.8.4.1.txt 1.2.3+git2.25.1-1/git/Documentation/RelNotes/1.8.4.1.txt
--- 1.2.1+git2.18.0-1/git/Documentation/RelNotes/1.8.4.1.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/RelNotes/1.8.4.1.txt	2020-02-17 04:47:35.000000000 +0000
@@ -15,7 +15,7 @@ Fixes since v1.8.4
    in 1.8.4-rc1).
 
  * "git rebase -i" and other scripted commands were feeding a
-   random, data dependant error message to 'echo' and expecting it
+   random, data dependent error message to 'echo' and expecting it
    to come out literally.
 
  * Setting the "submodule.<name>.path" variable to the empty
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/RelNotes/1.8.4.txt 1.2.3+git2.25.1-1/git/Documentation/RelNotes/1.8.4.txt
--- 1.2.1+git2.18.0-1/git/Documentation/RelNotes/1.8.4.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/RelNotes/1.8.4.txt	2020-02-17 04:47:35.000000000 +0000
@@ -58,7 +58,7 @@ Foreign interfaces, subsystems and ports
    credential helper interface from Git.pm.
 
  * Update build for Cygwin 1.[57].  Torsten Bögershausen reports that
-   this is fine with Cygwin 1.7 ($gmane/225824) so let's try moving it
+   this is fine with Cygwin 1.7 (cf. <51A606A0.5060101@web.de>) so let's try moving it
    ahead.
 
  * The credential helper to talk to keychain on OS X (in contrib/) has
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/RelNotes/2.10.0.txt 1.2.3+git2.25.1-1/git/Documentation/RelNotes/2.10.0.txt
--- 1.2.1+git2.18.0-1/git/Documentation/RelNotes/2.10.0.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/RelNotes/2.10.0.txt	2020-02-17 04:47:35.000000000 +0000
@@ -478,7 +478,7 @@ notes for details).
  * One part of "git am" had an oddball helper function that called
    stuff from outside "his" as opposed to calling what we have "ours",
    which was not gender-neutral and also inconsistent with the rest of
-   the system where outside stuff is usuall called "theirs" in
+   the system where outside stuff is usually called "theirs" in
    contrast to "ours".
 
  * "git blame file" allowed the lineage of lines in the uncommitted,
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/RelNotes/2.10.2.txt 1.2.3+git2.25.1-1/git/Documentation/RelNotes/2.10.2.txt
--- 1.2.1+git2.18.0-1/git/Documentation/RelNotes/2.10.2.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/RelNotes/2.10.2.txt	2020-02-17 04:47:35.000000000 +0000
@@ -86,7 +86,7 @@ Fixes since v2.10.1
    by refusing to check out a branch that is already checked out in
    another worktree.  However, this also prevented checking out a
    branch, which is designated as the primary branch of a bare
-   reopsitory, in a worktree that is connected to the bare
+   repository, in a worktree that is connected to the bare
    repository.  The check has been corrected to allow it.
 
  * "git rebase" immediately after "git clone" failed to find the fork
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/RelNotes/2.11.1.txt 1.2.3+git2.25.1-1/git/Documentation/RelNotes/2.11.1.txt
--- 1.2.1+git2.18.0-1/git/Documentation/RelNotes/2.11.1.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/RelNotes/2.11.1.txt	2020-02-17 04:47:35.000000000 +0000
@@ -104,7 +104,7 @@ Fixes since v2.11
    "git difftool --dir-diff" from a subdirectory never worked. This
    has been fixed.
 
- * "git p4" that tracks multile p4 paths imported a single changelist
+ * "git p4" that tracks multiple p4 paths imported a single changelist
    that touches files in these multiple paths as one commit, followed
    by many empty commits.  This has been fixed.
 
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/RelNotes/2.12.0.txt 1.2.3+git2.25.1-1/git/Documentation/RelNotes/2.12.0.txt
--- 1.2.1+git2.18.0-1/git/Documentation/RelNotes/2.12.0.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/RelNotes/2.12.0.txt	2020-02-17 04:47:35.000000000 +0000
@@ -315,7 +315,7 @@ notes for details).
    "git difftool --dir-diff" from a subdirectory never worked. This
    has been fixed.
 
- * "git p4" that tracks multile p4 paths imported a single changelist
+ * "git p4" that tracks multiple p4 paths imported a single changelist
    that touches files in these multiple paths as one commit, followed
    by many empty commits.  This has been fixed.
 
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/RelNotes/2.13.0.txt 1.2.3+git2.25.1-1/git/Documentation/RelNotes/2.13.0.txt
--- 1.2.1+git2.18.0-1/git/Documentation/RelNotes/2.13.0.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/RelNotes/2.13.0.txt	2020-02-17 04:47:35.000000000 +0000
@@ -177,7 +177,7 @@ UI, Workflows & Features
    been changed to enable "--decorate".
 
  * The output from "git status --short" has been extended to show
-   various kinds of dirtyness in submodules differently; instead of to
+   various kinds of dirtiness in submodules differently; instead of to
    "M" for modified, 'm' and '?' can be shown to signal changes only
    to the working tree of the submodule but not the commit that is
    checked out.
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/RelNotes/2.13.3.txt 1.2.3+git2.25.1-1/git/Documentation/RelNotes/2.13.3.txt
--- 1.2.1+git2.18.0-1/git/Documentation/RelNotes/2.13.3.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/RelNotes/2.13.3.txt	2020-02-17 04:47:35.000000000 +0000
@@ -25,7 +25,7 @@ Fixes since v2.13.2
  * The code to pick up and execute command alias definition from the
    configuration used to switch to the top of the working tree and
    then come back when the expanded alias was executed, which was
-   unnecessarilyl complex.  Attempt to simplify the logic by using the
+   unnecessarily complex.  Attempt to simplify the logic by using the
    early-config mechanism that does not chdir around.
 
  * "git add -p" were updated in 2.12 timeframe to cope with custom
@@ -35,7 +35,7 @@ Fixes since v2.13.2
  * Fix a recent regression to "git rebase -i" and add tests that would
    have caught it and others.
 
- * An unaligned 32-bit access in pack-bitmap code ahs been corrected.
+ * An unaligned 32-bit access in pack-bitmap code has been corrected.
 
  * Tighten error checks for invalid "git apply" input.
 
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/RelNotes/2.1.3.txt 1.2.3+git2.25.1-1/git/Documentation/RelNotes/2.1.3.txt
--- 1.2.1+git2.18.0-1/git/Documentation/RelNotes/2.1.3.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/RelNotes/2.1.3.txt	2020-02-17 04:47:35.000000000 +0000
@@ -13,7 +13,7 @@ Git v2.1.3 Release Notes
    they are new enough to support the `--output` option.
 
  * "git pack-objects" forgot to disable the codepath to generate
-   object recheability bitmap when it needs to split the resulting
+   object reachability bitmap when it needs to split the resulting
    pack.
 
  * "gitweb" used deprecated CGI::startfrom, which was removed from
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/RelNotes/2.14.0.txt 1.2.3+git2.25.1-1/git/Documentation/RelNotes/2.14.0.txt
--- 1.2.1+git2.18.0-1/git/Documentation/RelNotes/2.14.0.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/RelNotes/2.14.0.txt	2020-02-17 04:47:35.000000000 +0000
@@ -141,7 +141,7 @@ Performance, Internal Implementation, De
  * Some platforms have ulong that is smaller than time_t, and our
    historical use of ulong for timestamp would mean they cannot
    represent some timestamp that the platform allows.  Invent a
-   separate and dedicated timestamp_t (so that we can distingiuish
+   separate and dedicated timestamp_t (so that we can distinguish
    timestamps and a vanilla ulongs, which along is already a good
    move), and then declare uintmax_t is the type to be used as the
    timestamp_t.
@@ -442,7 +442,7 @@ notes for details).
  * The code to pick up and execute command alias definition from the
    configuration used to switch to the top of the working tree and
    then come back when the expanded alias was executed, which was
-   unnecessarilyl complex.  Attempt to simplify the logic by using the
+   unnecessarily complex.  Attempt to simplify the logic by using the
    early-config mechanism that does not chdir around.
 
  * Fix configuration codepath to pay proper attention to commondir
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/RelNotes/2.14.5.txt 1.2.3+git2.25.1-1/git/Documentation/RelNotes/2.14.5.txt
--- 1.2.1+git2.18.0-1/git/Documentation/RelNotes/2.14.5.txt	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/RelNotes/2.14.5.txt	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,16 @@
+Git v2.14.5 Release Notes
+=========================
+
+This release is to address the recently reported CVE-2018-17456.
+
+Fixes since v2.14.4
+-------------------
+
+ * Submodules' "URL"s come from the untrusted .gitmodules file, but
+   we blindly gave it to "git clone" to clone submodules when "git
+   clone --recurse-submodules" was used to clone a project that has
+   such a submodule.  The code has been hardened to reject such
+   malformed URLs (e.g. one that begins with a dash).
+
+Credit for finding and fixing this vulnerability goes to joernchen
+and Jeff King, respectively.
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/RelNotes/2.14.6.txt 1.2.3+git2.25.1-1/git/Documentation/RelNotes/2.14.6.txt
--- 1.2.1+git2.18.0-1/git/Documentation/RelNotes/2.14.6.txt	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/RelNotes/2.14.6.txt	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,54 @@
+Git v2.14.6 Release Notes
+=========================
+
+This release addresses the security issues CVE-2019-1348,
+CVE-2019-1349, CVE-2019-1350, CVE-2019-1351, CVE-2019-1352,
+CVE-2019-1353, CVE-2019-1354, and CVE-2019-1387.
+
+Fixes since v2.14.5
+-------------------
+
+ * CVE-2019-1348:
+   The --export-marks option of git fast-import is exposed also via
+   the in-stream command feature export-marks=... and it allows
+   overwriting arbitrary paths.
+
+ * CVE-2019-1349:
+   When submodules are cloned recursively, under certain circumstances
+   Git could be fooled into using the same Git directory twice. We now
+   require the directory to be empty.
+
+ * CVE-2019-1350:
+   Incorrect quoting of command-line arguments allowed remote code
+   execution during a recursive clone in conjunction with SSH URLs.
+
+ * CVE-2019-1351:
+   While the only permitted drive letters for physical drives on
+   Windows are letters of the US-English alphabet, this restriction
+   does not apply to virtual drives assigned via subst <letter>:
+   <path>. Git mistook such paths for relative paths, allowing writing
+   outside of the worktree while cloning.
+
+ * CVE-2019-1352:
+   Git was unaware of NTFS Alternate Data Streams, allowing files
+   inside the .git/ directory to be overwritten during a clone.
+
+ * CVE-2019-1353:
+   When running Git in the Windows Subsystem for Linux (also known as
+   "WSL") while accessing a working directory on a regular Windows
+   drive, none of the NTFS protections were active.
+
+ * CVE-2019-1354:
+   Filenames on Linux/Unix can contain backslashes. On Windows,
+   backslashes are directory separators. Git did not use to refuse to
+   write out tracked files with such filenames.
+
+ * CVE-2019-1387:
+   Recursive clones are currently affected by a vulnerability that is
+   caused by too-lax validation of submodule names, allowing very
+   targeted attacks via remote code execution in recursive clones.
+
+Credit for finding these vulnerabilities goes to Microsoft Security
+Response Center, in particular to Nicolas Joly. The `fast-import`
+fixes were provided by Jeff King, the other fixes by Johannes
+Schindelin with help from Garima Singh.
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/RelNotes/2.15.3.txt 1.2.3+git2.25.1-1/git/Documentation/RelNotes/2.15.3.txt
--- 1.2.1+git2.18.0-1/git/Documentation/RelNotes/2.15.3.txt	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/RelNotes/2.15.3.txt	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,6 @@
+Git v2.15.3 Release Notes
+=========================
+
+This release merges up the fixes that appear in v2.14.5 to address
+the recently reported CVE-2018-17456; see the release notes for that
+version for details.
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/RelNotes/2.15.4.txt 1.2.3+git2.25.1-1/git/Documentation/RelNotes/2.15.4.txt
--- 1.2.1+git2.18.0-1/git/Documentation/RelNotes/2.15.4.txt	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/RelNotes/2.15.4.txt	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,11 @@
+Git v2.15.4 Release Notes
+=========================
+
+This release merges up the fixes that appear in v2.14.6 to address
+the security issues CVE-2019-1348, CVE-2019-1349, CVE-2019-1350,
+CVE-2019-1351, CVE-2019-1352, CVE-2019-1353, CVE-2019-1354, and
+CVE-2019-1387; see the release notes for that version for details.
+
+In conjunction with a vulnerability that was fixed in v2.20.2,
+`.gitmodules` is no longer allowed to contain entries of the form
+`submodule.<name>.update=!command`.
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/RelNotes/2.16.0.txt 1.2.3+git2.25.1-1/git/Documentation/RelNotes/2.16.0.txt
--- 1.2.1+git2.18.0-1/git/Documentation/RelNotes/2.16.0.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/RelNotes/2.16.0.txt	2020-02-17 04:47:35.000000000 +0000
@@ -407,7 +407,7 @@ Fixes since v2.15
    (merge eef3df5a93 bw/pathspec-match-submodule-boundary later to maint).
 
  * Amending commits in git-gui broke the author name that is non-ascii
-   due to incorrect enconding conversion.
+   due to incorrect encoding conversion.
 
  * Recent update to the submodule configuration code broke "diff-tree"
    by accidentally stopping to read from the index upfront.
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/RelNotes/2.16.3.txt 1.2.3+git2.25.1-1/git/Documentation/RelNotes/2.16.3.txt
--- 1.2.1+git2.18.0-1/git/Documentation/RelNotes/2.16.3.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/RelNotes/2.16.3.txt	2020-02-17 04:47:35.000000000 +0000
@@ -24,7 +24,7 @@ Fixes since v2.16.2
 
  * The http tracing code, often used to debug connection issues,
    learned to redact potentially sensitive information from its output
-   so that it can be more safely sharable.
+   so that it can be more safely shareable.
 
  * Crash fix for a corner case where an error codepath tried to unlock
    what it did not acquire lock on.
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/RelNotes/2.16.5.txt 1.2.3+git2.25.1-1/git/Documentation/RelNotes/2.16.5.txt
--- 1.2.1+git2.18.0-1/git/Documentation/RelNotes/2.16.5.txt	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/RelNotes/2.16.5.txt	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,6 @@
+Git v2.16.5 Release Notes
+=========================
+
+This release merges up the fixes that appear in v2.14.5 to address
+the recently reported CVE-2018-17456; see the release notes for that
+version for details.
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/RelNotes/2.16.6.txt 1.2.3+git2.25.1-1/git/Documentation/RelNotes/2.16.6.txt
--- 1.2.1+git2.18.0-1/git/Documentation/RelNotes/2.16.6.txt	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/RelNotes/2.16.6.txt	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,8 @@
+Git v2.16.6 Release Notes
+=========================
+
+This release merges up the fixes that appear in v2.14.6 and in
+v2.15.4 addressing the security issues CVE-2019-1348, CVE-2019-1349,
+CVE-2019-1350, CVE-2019-1351, CVE-2019-1352, CVE-2019-1353,
+CVE-2019-1354, and CVE-2019-1387; see the release notes for those
+versions for details.
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/RelNotes/2.17.0.txt 1.2.3+git2.25.1-1/git/Documentation/RelNotes/2.17.0.txt
--- 1.2.1+git2.18.0-1/git/Documentation/RelNotes/2.17.0.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/RelNotes/2.17.0.txt	2020-02-17 04:47:35.000000000 +0000
@@ -216,7 +216,7 @@ Fixes since v2.16
 
  * The http tracing code, often used to debug connection issues,
    learned to redact potentially sensitive information from its output
-   so that it can be more safely sharable.
+   so that it can be more safely shareable.
    (merge 8ba18e6fa4 jt/http-redact-cookies later to maint).
 
  * Crash fix for a corner case where an error codepath tried to unlock
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/RelNotes/2.17.2.txt 1.2.3+git2.25.1-1/git/Documentation/RelNotes/2.17.2.txt
--- 1.2.1+git2.18.0-1/git/Documentation/RelNotes/2.17.2.txt	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/RelNotes/2.17.2.txt	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,12 @@
+Git v2.17.2 Release Notes
+=========================
+
+This release merges up the fixes that appear in v2.14.5 to address
+the recently reported CVE-2018-17456; see the release notes for that
+version for details.
+
+In addition, this release also teaches "fsck" and the server side
+logic to reject pushes to repositories that attempt to create such a
+problematic ".gitmodules" file as tracked contents, to help hosting
+sites protect their customers by preventing malicious contents from
+spreading.
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/RelNotes/2.17.3.txt 1.2.3+git2.25.1-1/git/Documentation/RelNotes/2.17.3.txt
--- 1.2.1+git2.18.0-1/git/Documentation/RelNotes/2.17.3.txt	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/RelNotes/2.17.3.txt	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,12 @@
+Git v2.17.3 Release Notes
+=========================
+
+This release merges up the fixes that appear in v2.14.6 and in
+v2.15.4 addressing the security issues CVE-2019-1348, CVE-2019-1349,
+CVE-2019-1350, CVE-2019-1351, CVE-2019-1352, CVE-2019-1353,
+CVE-2019-1354, and CVE-2019-1387; see the release notes for those
+versions for details.
+
+In addition, `git fsck` was taught to identify `.gitmodules` entries
+of the form `submodule.<name>.update=!command`, which have been
+disallowed in v2.15.4.
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/RelNotes/2.18.0.txt 1.2.3+git2.25.1-1/git/Documentation/RelNotes/2.18.0.txt
--- 1.2.1+git2.18.0-1/git/Documentation/RelNotes/2.18.0.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/RelNotes/2.18.0.txt	2020-02-17 04:47:35.000000000 +0000
@@ -179,7 +179,7 @@ Performance, Internal Implementation, De
    (merge 00a3da2a13 nd/remove-ignore-env-field later to maint).
 
  * Code to find the length to uniquely abbreviate object names based
-   on packfile content, which is a relatively recent addtion, has been
+   on packfile content, which is a relatively recent addition, has been
    optimized to use the same fan-out table.
 
  * The mechanism to use parse-options API to automate the command line
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/RelNotes/2.18.1.txt 1.2.3+git2.25.1-1/git/Documentation/RelNotes/2.18.1.txt
--- 1.2.1+git2.18.0-1/git/Documentation/RelNotes/2.18.1.txt	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/RelNotes/2.18.1.txt	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,6 @@
+Git v2.18.1 Release Notes
+=========================
+
+This release merges up the fixes that appear in v2.14.5 and in
+v2.17.2 to address the recently reported CVE-2018-17456; see the
+release notes for those versions for details.
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/RelNotes/2.18.2.txt 1.2.3+git2.25.1-1/git/Documentation/RelNotes/2.18.2.txt
--- 1.2.1+git2.18.0-1/git/Documentation/RelNotes/2.18.2.txt	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/RelNotes/2.18.2.txt	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,8 @@
+Git v2.18.2 Release Notes
+=========================
+
+This release merges up the fixes that appear in v2.14.6, v2.15.4
+and in v2.17.3, addressing the security issues CVE-2019-1348,
+CVE-2019-1349, CVE-2019-1350, CVE-2019-1351, CVE-2019-1352,
+CVE-2019-1353, CVE-2019-1354, and CVE-2019-1387; see the release notes
+for those versions for details.
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/RelNotes/2.19.0.txt 1.2.3+git2.25.1-1/git/Documentation/RelNotes/2.19.0.txt
--- 1.2.1+git2.18.0-1/git/Documentation/RelNotes/2.19.0.txt	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/RelNotes/2.19.0.txt	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,615 @@
+Git 2.19 Release Notes
+======================
+
+Updates since v2.18
+-------------------
+
+UI, Workflows & Features
+
+ * "git diff" compares the index and the working tree.  For paths
+   added with intent-to-add bit, the command shows the full contents
+   of them as added, but the paths themselves were not marked as new
+   files.  They are now shown as new by default.
+
+   "git apply" learned the "--intent-to-add" option so that an
+   otherwise working-tree-only application of a patch will add new
+   paths to the index marked with the "intent-to-add" bit.
+
+ * "git grep" learned the "--column" option that gives not just the
+   line number but the column number of the hit.
+
+ * The "-l" option in "git branch -l" is an unfortunate short-hand for
+   "--create-reflog", but many users, both old and new, somehow expect
+   it to be something else, perhaps "--list".  This step warns when "-l"
+   is used as a short-hand for "--create-reflog" and warns about the
+   future repurposing of the it when it is used.
+
+ * The userdiff pattern for .php has been updated.
+
+ * The content-transfer-encoding of the message "git send-email" sends
+   out by default was 8bit, which can cause trouble when there is an
+   overlong line to bust RFC 5322/2822 limit.  A new option 'auto' to
+   automatically switch to quoted-printable when there is such a line
+   in the payload has been introduced and is made the default.
+
+ * "git checkout" and "git worktree add" learned to honor
+   checkout.defaultRemote when auto-vivifying a local branch out of a
+   remote tracking branch in a repository with multiple remotes that
+   have tracking branches that share the same names.
+   (merge 8d7b558bae ab/checkout-default-remote later to maint).
+
+ * "git grep" learned the "--only-matching" option.
+
+ * "git rebase --rebase-merges" mode now handles octopus merges as
+   well.
+
+ * Add a server-side knob to skip commits in exponential/fibbonacci
+   stride in an attempt to cover wider swath of history with a smaller
+   number of iterations, potentially accepting a larger packfile
+   transfer, instead of going back one commit a time during common
+   ancestor discovery during the "git fetch" transaction.
+   (merge 42cc7485a2 jt/fetch-negotiator-skipping later to maint).
+
+ * A new configuration variable core.usereplacerefs has been added,
+   primarily to help server installations that want to ignore the
+   replace mechanism altogether.
+
+ * Teach "git tag -s" etc. a few configuration variables (gpg.format
+   that can be set to "openpgp" or "x509", and gpg.<format>.program
+   that is used to specify what program to use to deal with the format)
+   to allow x.509 certs with CMS via "gpgsm" to be used instead of
+   openpgp via "gnupg".
+
+ * Many more strings are prepared for l10n.
+
+ * "git p4 submit" learns to ask its own pre-submit hook if it should
+   continue with submitting.
+
+ * The test performed at the receiving end of "git push" to prevent
+   bad objects from entering repository can be customized via
+   receive.fsck.* configuration variables; we now have gained a
+   counterpart to do the same on the "git fetch" side, with
+   fetch.fsck.* configuration variables.
+
+ * "git pull --rebase=interactive" learned "i" as a short-hand for
+   "interactive".
+
+ * "git instaweb" has been adjusted to run better with newer Apache on
+   RedHat based distros.
+
+ * "git range-diff" is a reimplementation of "git tbdiff" that lets us
+   compare individual patches in two iterations of a topic.
+
+ * The sideband code learned to optionally paint selected keywords at
+   the beginning of incoming lines on the receiving end.
+
+ * "git branch --list" learned to take the default sort order from the
+   'branch.sort' configuration variable, just like "git tag --list"
+   pays attention to 'tag.sort'.
+
+ * "git worktree" command learned "--quiet" option to make it less
+   verbose.
+
+
+Performance, Internal Implementation, Development Support etc.
+
+ * The bulk of "git submodule foreach" has been rewritten in C.
+
+ * The in-core "commit" object had an all-purpose "void *util" field,
+   which was tricky to use especially in library-ish part of the
+   code.  All of the existing uses of the field has been migrated to a
+   more dedicated "commit-slab" mechanism and the field is eliminated.
+
+ * A less often used command "git show-index" has been modernized.
+   (merge fb3010c31f jk/show-index later to maint).
+
+ * The conversion to pass "the_repository" and then "a_repository"
+   throughout the object access API continues.
+
+ * Continuing with the idea to programmatically enumerate various
+   pieces of data required for command line completion, teach the
+   codebase to report the list of configuration variables
+   subcommands care about to help complete them.
+
+ * Separate "rebase -p" codepath out of "rebase -i" implementation to
+   slim down the latter and make it easier to manage.
+
+ * Make refspec parsing codepath more robust.
+
+ * Some flaky tests have been fixed.
+
+ * Continuing with the idea to programmatically enumerate various
+   pieces of data required for command line completion, the codebase
+   has been taught to enumerate options prefixed with "--no-" to
+   negate them.
+
+ * Build and test procedure for netrc credential helper (in contrib/)
+   has been updated.
+
+ * Remove unused function definitions and declarations from ewah
+   bitmap subsystem.
+
+ * Code preparation to make "git p4" closer to be usable with Python 3.
+
+ * Tighten the API to make it harder to misuse in-tree .gitmodules
+   file, even though it shares the same syntax with configuration
+   files, to read random configuration items from it.
+
+ * "git fast-import" has been updated to avoid attempting to create
+   delta against a zero-byte-long string, which is pointless.
+
+ * The codebase has been updated to compile cleanly with -pedantic
+   option.
+   (merge 2b647a05d7 bb/pedantic later to maint).
+
+ * The character display width table has been updated to match the
+   latest Unicode standard.
+   (merge 570951eea2 bb/unicode-11-width later to maint).
+
+ * test-lint now looks for broken use of "VAR=VAL shell_func" in test
+   scripts.
+
+ * Conversion from uchar[40] to struct object_id continues.
+
+ * Recent "security fix" to pay attention to contents of ".gitmodules"
+   while accepting "git push" was a bit overly strict than necessary,
+   which has been adjusted.
+
+ * "git fsck" learns to make sure the optional commit-graph file is in
+   a sane state.
+
+ * "git diff --color-moved" feature has further been tweaked.
+
+ * Code restructuring and a small fix to transport protocol v2 during
+   fetching.
+
+ * Parsing of -L[<N>][,[<M>]] parameters "git blame" and "git log"
+   take has been tweaked.
+
+ * lookup_commit_reference() and friends have been updated to find
+   in-core object for a specific in-core repository instance.
+
+ * Various glitches in the heuristics of merge-recursive strategy have
+   been documented in new tests.
+
+ * "git fetch" learned a new option "--negotiation-tip" to limit the
+   set of commits it tells the other end as "have", to reduce wasted
+   bandwidth and cycles, which would be helpful when the receiving
+   repository has a lot of refs that have little to do with the
+   history at the remote it is fetching from.
+
+ * For a large tree, the index needs to hold many cache entries
+   allocated on heap.  These cache entries are now allocated out of a
+   dedicated memory pool to amortize malloc(3) overhead.
+
+ * Tests to cover various conflicting cases have been added for
+   merge-recursive.
+
+ * Tests to cover conflict cases that involve submodules have been
+   added for merge-recursive.
+
+ * Look for broken "&&" chains that are hidden in subshell, many of
+   which have been found and corrected.
+
+ * The singleton commit-graph in-core instance is made per in-core
+   repository instance.
+
+ * "make DEVELOPER=1 DEVOPTS=pedantic" allows developers to compile
+   with -pedantic option, which may catch more problematic program
+   constructs and potential bugs.
+
+ * Preparatory code to later add json output for telemetry data has
+   been added.
+
+ * Update the way we use Coccinelle to find out-of-style code that
+   need to be modernised.
+
+ * It is too easy to misuse system API functions such as strcat();
+   these selected functions are now forbidden in this codebase and
+   will cause a compilation failure.
+
+ * Add a script (in contrib/) to help users of VSCode work better with
+   our codebase.
+
+ * The Travis CI scripts were taught to ship back the test data from
+   failed tests.
+   (merge aea8879a6a sg/travis-retrieve-trash-upon-failure later to maint).
+
+ * The parse-options machinery learned to refrain from enclosing
+   placeholder string inside a "<bra" and "ket>" pair automatically
+   without PARSE_OPT_LITERAL_ARGHELP.  Existing help text for option
+   arguments that are not formatted correctly have been identified and
+   fixed.
+   (merge 5f0df44cd7 rs/parse-opt-lithelp later to maint).
+
+ * Noiseword "extern" has been removed from function decls in the
+   header files.
+
+ * A few atoms like %(objecttype) and %(objectsize) in the format
+   specifier of "for-each-ref --format=<format>" can be filled without
+   getting the full contents of the object, but just with the object
+   header.  These cases have been optimized by calling
+   oid_object_info() API (instead of reading and inspecting the data).
+
+ * The end result of documentation update has been made to be
+   inspected more easily to help developers.
+
+ * The API to iterate over all objects learned to optionally list
+   objects in the order they appear in packfiles, which helps locality
+   of access if the caller accesses these objects while as objects are
+   enumerated.
+
+ * Improve built-in facility to catch broken &&-chain in the tests.
+
+ * The more library-ish parts of the codebase learned to work on the
+   in-core index-state instance that is passed in by their callers,
+   instead of always working on the singleton "the_index" instance.
+
+ * A test prerequisite defined by various test scripts with slightly
+   different semantics has been consolidated into a single copy and
+   made into a lazily defined one.
+   (merge 6ec633059a wc/make-funnynames-shared-lazy-prereq later to maint).
+
+ * After a partial clone, repeated fetches from promisor remote would
+   have accumulated many packfiles marked with .promisor bit without
+   getting them coalesced into fewer packfiles, hurting performance.
+   "git repack" now learned to repack them.
+
+ * Partially revert the support for multiple hash functions to regain
+   hash comparison performance; we'd think of a way to do this better
+   in the next cycle.
+
+ * "git help --config" (which is used in command line completion)
+   missed the configuration variables not described in the main
+   config.txt file but are described in another file that is included
+   by it, which has been corrected.
+
+ * The test linter code has learned that the end of here-doc mark
+   "EOF" can be quoted in a double-quote pair, not just in a
+   single-quote pair.
+
+
+Fixes since v2.18
+-----------------
+
+ * "git remote update" can take both a single remote nickname and a
+   nickname for remote groups, and the completion script (in contrib/)
+   has been taught about it.
+   (merge 9cd4382ad5 ls/complete-remote-update-names later to maint).
+
+ * "git fetch --shallow-since=<cutoff>" that specifies the cut-off
+   point that is newer than the existing history used to end up
+   grabbing the entire history.  Such a request now errors out.
+   (merge e34de73c56 nd/reject-empty-shallow-request later to maint).
+
+ * Fix for 2.17-era regression around `core.safecrlf`.
+   (merge 6cb09125be as/safecrlf-quiet-fix later to maint).
+
+ * The recent addition of "partial clone" experimental feature kicked
+   in when it shouldn't, namely, when there is no partial-clone filter
+   defined even if extensions.partialclone is set.
+   (merge cac1137dc4 jh/partial-clone later to maint).
+
+ * "git send-pack --signed" (hence "git push --signed" over the http
+   transport) did not read user ident from the config mechanism to
+   determine whom to sign the push certificate as, which has been
+   corrected.
+   (merge d067d98887 ms/send-pack-honor-config later to maint).
+
+ * "git fetch-pack --all" used to unnecessarily fail upon seeing an
+   annotated tag that points at an object other than a commit.
+   (merge c12c9df527 jk/fetch-all-peeled-fix later to maint).
+
+ * When user edits the patch in "git add -p" and the user's editor is
+   set to strip trailing whitespaces indiscriminately, an empty line
+   that is unchanged in the patch would become completely empty
+   (instead of a line with a sole SP on it).  The code introduced in
+   Git 2.17 timeframe failed to parse such a patch, but now it learned
+   to notice the situation and cope with it.
+   (merge f4d35a6b49 pw/add-p-recount later to maint).
+
+ * The code to try seeing if a fetch is necessary in a submodule
+   during a fetch with --recurse-submodules got confused when the path
+   to the submodule was changed in the range of commits in the
+   superproject, sometimes showing "(null)".  This has been corrected.
+
+ * Bugfix for "rebase -i" corner case regression.
+   (merge a9279c6785 pw/rebase-i-keep-reword-after-conflict later to maint).
+
+ * Recently added "--base" option to "git format-patch" command did
+   not correctly generate prereq patch ids.
+   (merge 15b76c1fb3 xy/format-patch-prereq-patch-id-fix later to maint).
+
+ * POSIX portability fix in Makefile to fix a glitch introduced a few
+   releases ago.
+   (merge 6600054e9b dj/runtime-prefix later to maint).
+
+ * "git filter-branch" when used with the "--state-branch" option
+   still attempted to rewrite the commits whose filtered result is
+   known from the previous attempt (which is recorded on the state
+   branch); the command has been corrected not to waste cycles doing
+   so.
+   (merge 709cfe848a mb/filter-branch-optim later to maint).
+
+ * Clarify that setting core.ignoreCase to deviate from reality would
+   not turn a case-incapable filesystem into a case-capable one.
+   (merge 48294b512a ms/core-icase-doc later to maint).
+
+ * "fsck.skipList" did not prevent a blob object listed there from
+   being inspected for is contents (e.g. we recently started to
+   inspect the contents of ".gitmodules" for certain malicious
+   patterns), which has been corrected.
+   (merge fb16287719 rj/submodule-fsck-skip later to maint).
+
+ * "git checkout --recurse-submodules another-branch" did not report
+   in which submodule it failed to update the working tree, which
+   resulted in an unhelpful error message.
+   (merge ba95d4e4bd sb/submodule-move-head-error-msg later to maint).
+
+ * "git rebase" behaved slightly differently depending on which one of
+   the three backends gets used; this has been documented and an
+   effort to make them more uniform has begun.
+   (merge b00bf1c9a8 en/rebase-consistency later to maint).
+
+ * The "--ignore-case" option of "git for-each-ref" (and its friends)
+   did not work correctly, which has been fixed.
+   (merge e674eb2528 jk/for-each-ref-icase later to maint).
+
+ * "git fetch" failed to correctly validate the set of objects it
+   received when making a shallow history deeper, which has been
+   corrected.
+   (merge cf1e7c0770 jt/connectivity-check-after-unshallow later to maint).
+
+ * Partial clone support of "git clone" has been updated to correctly
+   validate the objects it receives from the other side.  The server
+   side has been corrected to send objects that are directly
+   requested, even if they may match the filtering criteria (e.g. when
+   doing a "lazy blob" partial clone).
+   (merge a7e67c11b8 jt/partial-clone-fsck-connectivity later to maint).
+
+ * Handling of an empty range by "git cherry-pick" was inconsistent
+   depending on how the range ended up to be empty, which has been
+   corrected.
+   (merge c5e358d073 jk/empty-pick-fix later to maint).
+
+ * "git reset --merge" (hence "git merge ---abort") and "git reset --hard"
+   had trouble working correctly in a sparsely checked out working
+   tree after a conflict, which has been corrected.
+   (merge b33fdfc34c mk/merge-in-sparse-checkout later to maint).
+
+ * Correct a broken use of "VAR=VAL shell_func" in a test.
+   (merge 650161a277 jc/t3404-one-shot-export-fix later to maint).
+
+ * "git rev-parse ':/substring'" did not consider the history leading
+   only to HEAD when looking for a commit with the given substring,
+   when the HEAD is detached.  This has been fixed.
+   (merge 6b3351e799 wc/find-commit-with-pattern-on-detached-head later to maint).
+
+ * Build doc update for Windows.
+   (merge ede8d89bb1 nd/command-list later to maint).
+
+ * core.commentchar is now honored when preparing the list of commits
+   to replay in "rebase -i".
+
+ * "git pull --rebase" on a corrupt HEAD caused a segfault.  In
+   general we substitute an empty tree object when running the in-core
+   equivalent of the diff-index command, and the codepath has been
+   corrected to do so as well to fix this issue.
+   (merge 3506dc9445 jk/has-uncommitted-changes-fix later to maint).
+
+ * httpd tests saw occasional breakage due to the way its access log
+   gets inspected by the tests, which has been updated to make them
+   less flaky.
+   (merge e8b3b2e275 sg/httpd-test-unflake later to maint).
+
+ * Tests to cover more D/F conflict cases have been added for
+   merge-recursive.
+
+ * "git gc --auto" opens file descriptors for the packfiles before
+   spawning "git repack/prune", which would upset Windows that does
+   not want a process to work on a file that is open by another
+   process.  The issue has been worked around.
+   (merge 12e73a3ce4 kg/gc-auto-windows-workaround later to maint).
+
+ * The recursive merge strategy did not properly ensure there was no
+   change between HEAD and the index before performing its operation,
+   which has been corrected.
+   (merge 55f39cf755 en/dirty-merge-fixes later to maint).
+
+ * "git rebase" started exporting GIT_DIR environment variable and
+   exposing it to hook scripts when part of it got rewritten in C.
+   Instead of matching the old scripted Porcelains' behaviour,
+   compensate by also exporting GIT_WORK_TREE environment as well to
+   lessen the damage.  This can harm existing hooks that want to
+   operate on different repository, but the current behaviour is
+   already broken for them anyway.
+   (merge ab5e67d751 bc/sequencer-export-work-tree-as-well later to maint).
+
+ * "git send-email" when using in a batched mode that limits the
+   number of messages sent in a single SMTP session lost the contents
+   of the variable used to choose between tls/ssl, unable to send the
+   second and later batches, which has been fixed.
+   (merge 636f3d7ac5 jm/send-email-tls-auth-on-batch later to maint).
+
+ * The lazy clone support had a few places where missing but promised
+   objects were not correctly tolerated, which have been fixed.
+
+ * One of the "diff --color-moved" mode "dimmed_zebra" that was named
+   in an unusual way has been deprecated and replaced by
+   "dimmed-zebra".
+   (merge e3f2f5f9cd es/diff-color-moved-fix later to maint).
+
+ * The wire-protocol v2 relies on the client to send "ref prefixes" to
+   limit the bandwidth spent on the initial ref advertisement.  "git
+   clone" when learned to speak v2 forgot to do so, which has been
+   corrected.
+   (merge 402c47d939 bw/clone-ref-prefixes later to maint).
+
+ * "git diff --histogram" had a bad memory usage pattern, which has
+   been rearranged to reduce the peak usage.
+   (merge 79cb2ebb92 sb/histogram-less-memory later to maint).
+
+ * Code clean-up to use size_t/ssize_t when they are the right type.
+   (merge 7726d360b5 jk/size-t later to maint).
+
+ * The wire-protocol v2 relies on the client to send "ref prefixes" to
+   limit the bandwidth spent on the initial ref advertisement.  "git
+   fetch $remote branch:branch" that asks tags that point into the
+   history leading to the "branch" automatically followed sent to
+   narrow prefix and broke the tag following, which has been fixed.
+   (merge 2b554353a5 jt/tag-following-with-proto-v2-fix later to maint).
+
+ * When the sparse checkout feature is in use, "git cherry-pick" and
+   other mergy operations lost the skip_worktree bit when a path that
+   is excluded from checkout requires content level merge, which is
+   resolved as the same as the HEAD version, without materializing the
+   merge result in the working tree, which made the path appear as
+   deleted.  This has been corrected by preserving the skip_worktree
+   bit (and not materializing the file in the working tree).
+   (merge 2b75fb601c en/merge-recursive-skip-fix later to maint).
+
+ * The "author-script" file "git rebase -i" creates got broken when
+   we started to move the command away from shell script, which is
+   getting fixed now.
+   (merge 5522bbac20 es/rebase-i-author-script-fix later to maint).
+
+ * The automatic tree-matching in "git merge -s subtree" was broken 5
+   years ago and nobody has noticed since then, which is now fixed.
+   (merge 2ec4150713 jk/merge-subtree-heuristics later to maint).
+
+ * "git fetch $there refs/heads/s" ought to fetch the tip of the
+   branch 's', but when "refs/heads/refs/heads/s", i.e. a branch whose
+   name is "refs/heads/s" exists at the same time, fetched that one
+   instead by mistake.  This has been corrected to honor the usual
+   disambiguation rules for abbreviated refnames.
+   (merge 60650a48c0 jt/refspec-dwim-precedence-fix later to maint).
+
+ * Futureproofing a helper function that can easily be misused.
+   (merge 65bb21e77e es/want-color-fd-defensive later to maint).
+
+ * The http-backend (used for smart-http transport) used to slurp the
+   whole input until EOF, without paying attention to CONTENT_LENGTH
+   that is supplied in the environment and instead expecting the Web
+   server to close the input stream.  This has been fixed.
+   (merge eebfe40962 mk/http-backend-content-length later to maint).
+
+ * "git merge --abort" etc. did not clean things up properly when
+   there were conflicted entries in the index in certain order that
+   are involved in D/F conflicts.  This has been corrected.
+   (merge ad3762042a en/abort-df-conflict-fixes later to maint).
+
+ * "git diff --indent-heuristic" had a bad corner case performance.
+   (merge 301ef85401 sb/indent-heuristic-optim later to maint).
+
+ * The "--exec" option to "git rebase --rebase-merges" placed the exec
+   commands at wrong places, which has been corrected.
+
+ * "git verify-tag" and "git verify-commit" have been taught to use
+   the exit status of underlying "gpg --verify" to signal bad or
+   untrusted signature they found.
+   (merge 4e5dc9ca17 jc/gpg-status later to maint).
+
+ * "git mergetool" stopped and gave an extra prompt to continue after
+   the last path has been handled, which did not make much sense.
+   (merge d651a54b8a ng/mergetool-lose-final-prompt later to maint).
+
+ * Among the three codepaths we use O_APPEND to open a file for
+   appending, one used for writing GIT_TRACE output requires O_APPEND
+   implementation that behaves sensibly when multiple processes are
+   writing to the same file.  POSIX emulation used in the Windows port
+   has been updated to improve in this area.
+   (merge d641097589 js/mingw-o-append later to maint).
+
+ * "git pull --rebase -v" in a repository with a submodule barfed as
+   an intermediate process did not understand what "-v(erbose)" flag
+   meant, which has been fixed.
+   (merge e84c3cf3dc sb/pull-rebase-submodule later to maint).
+
+ * Recent update to "git config" broke updating variable in a
+   subsection, which has been corrected.
+   (merge bff7df7a87 sb/config-write-fix later to maint).
+
+ * When "git rebase -i" is told to squash two or more commits into
+   one, it labeled the log message for each commit with its number.
+   It correctly called the first one "1st commit", but the next one
+   was "commit #1", which was off-by-one.  This has been corrected.
+   (merge dd2e36ebac pw/rebase-i-squash-number-fix later to maint).
+
+ * "git rebase -i", when a 'merge <branch>' insn in its todo list
+   fails, segfaulted, which has been (minimally) corrected.
+   (merge bc9238bb09 pw/rebase-i-merge-segv-fix later to maint).
+
+ * "git cherry-pick --quit" failed to remove CHERRY_PICK_HEAD even
+   though we won't be in a cherry-pick session after it returns, which
+   has been corrected.
+   (merge 3e7dd99208 nd/cherry-pick-quit-fix later to maint).
+
+ * In a recent update in 2.18 era, "git pack-objects" started
+   producing a larger than necessary packfiles by missing
+   opportunities to use large deltas.  This has been corrected.
+
+ * The meaning of the possible values the "core.checkStat"
+   configuration variable can take were not adequately documented,
+   which has been fixed.
+   (merge 9bf5d4c4e2 nd/config-core-checkstat-doc later to maint).
+
+ * Recent "git rebase -i" update started to write bogusly formatted
+   author-script, with a matching broken reading code.  These are
+   fixed.
+
+ * Recent addition of "directory rename" heuristics to the
+   merge-recursive backend makes the command susceptible to false
+   positives and false negatives.  In the context of "git am -3",
+   which does not know about surrounding unmodified paths and thus
+   cannot inform the merge machinery about the full trees involved,
+   this risk is particularly severe.  As such, the heuristic is
+   disabled for "git am -3" to keep the machinery "more stupid but
+   predictable".
+
+ * "git merge-base" in 2.19-rc1 has performance regression when the
+   (experimental) commit-graph feature is in use, which has been
+   mitigated.
+
+ * Code cleanup, docfix, build fix, etc.
+   (merge aee9be2ebe sg/update-ref-stdin-cleanup later to maint).
+   (merge 037714252f jc/clean-after-sanity-tests later to maint).
+   (merge 5b26c3c941 en/merge-recursive-cleanup later to maint).
+   (merge 0dcbc0392e bw/config-refer-to-gitsubmodules-doc later to maint).
+   (merge bb4d000e87 bw/protocol-v2 later to maint).
+   (merge 928f0ab4ba vs/typofixes later to maint).
+   (merge d7f590be84 en/rebase-i-microfixes later to maint).
+   (merge 81d395cc85 js/rebase-recreate-merge later to maint).
+   (merge 51d1863168 tz/exclude-doc-smallfixes later to maint).
+   (merge a9aa3c0927 ds/commit-graph later to maint).
+   (merge 5cf8e06474 js/enhanced-version-info later to maint).
+   (merge 6aaded5509 tb/config-default later to maint).
+   (merge 022d2ac1f3 sb/blame-color later to maint).
+   (merge 5a06a20e0c bp/test-drop-caches-for-windows later to maint).
+   (merge dd61cc1c2e jk/ui-color-always-to-auto later to maint).
+   (merge 1e83b9bfdd sb/trailers-docfix later to maint).
+   (merge ab29f1b329 sg/fast-import-dump-refs-on-checkpoint-fix later to maint).
+   (merge 6a8ad880f0 jn/subtree-test-fixes later to maint).
+   (merge ffbd51cc60 nd/pack-objects-threading-doc later to maint).
+   (merge e9dac7be60 es/mw-to-git-chain-fix later to maint).
+   (merge fe583c6c7a rs/remote-mv-leakfix later to maint).
+   (merge 69885ab015 en/t3031-title-fix later to maint).
+   (merge 8578037bed nd/config-blame-sort later to maint).
+   (merge 8ad169c4ba hn/config-in-code-comment later to maint).
+   (merge b7446fcfdf ar/t4150-am-scissors-test-fix later to maint).
+   (merge a8132410ee js/typofixes later to maint).
+   (merge 388d0ff6e5 en/update-index-doc later to maint).
+   (merge e05aa688dd jc/update-index-doc later to maint).
+   (merge 10c600172c sg/t5310-empty-input-fix later to maint).
+   (merge 5641eb9465 jh/partial-clone-doc later to maint).
+   (merge 2711b1ad5e ab/submodule-relative-url-tests later to maint).
+   (merge ce528de023 ab/unconditional-free-and-null later to maint).
+   (merge bbc072f5d8 rs/opt-updates later to maint).
+   (merge 69d846f053 jk/use-compat-util-in-test-tool later to maint).
+   (merge 1820703045 js/larger-timestamps later to maint).
+   (merge c8b35b95e1 sg/t4051-fix later to maint).
+   (merge 30612cb670 sg/t0020-conversion-fix later to maint).
+   (merge 15da753709 sg/t7501-thinkofix later to maint).
+   (merge 79b04f9b60 sg/t3903-missing-fix later to maint).
+   (merge 2745817028 sg/t3420-autostash-fix later to maint).
+   (merge 7afb0d6777 sg/test-rebase-editor-fix later to maint).
+   (merge 6c6ce21baa es/freebsd-iconv-portability later to maint).
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/RelNotes/2.19.1.txt 1.2.3+git2.25.1-1/git/Documentation/RelNotes/2.19.1.txt
--- 1.2.1+git2.18.0-1/git/Documentation/RelNotes/2.19.1.txt	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/RelNotes/2.19.1.txt	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,6 @@
+Git v2.19.1 Release Notes
+=========================
+
+This release merges up the fixes that appear in v2.14.5 and in
+v2.17.2 to address the recently reported CVE-2018-17456; see the
+release notes for those versions for details.
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/RelNotes/2.19.2.txt 1.2.3+git2.25.1-1/git/Documentation/RelNotes/2.19.2.txt
--- 1.2.1+git2.18.0-1/git/Documentation/RelNotes/2.19.2.txt	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/RelNotes/2.19.2.txt	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,108 @@
+Git v2.19.2 Release Notes
+=========================
+
+Fixes since v2.19.1
+-------------------
+
+ * "git interpret-trailers" and its underlying machinery had a buggy
+   code that attempted to ignore patch text after commit log message,
+   which triggered in various codepaths that will always get the log
+   message alone and never get such an input.
+
+ * "git rebase -i" did not clear the state files correctly when a run
+   of "squash/fixup" is aborted and then the user manually amended the
+   commit instead, which has been corrected.
+
+ * When fsmonitor is in use, after operation on submodules updates
+   .gitmodules, we lost track of the fact that we did so and relied on
+   stale fsmonitor data.
+
+ * Fix for a long-standing bug that leaves the index file corrupt when
+   it shrinks during a partial commit.
+
+ * Further fix for O_APPEND emulation on Windows
+
+ * A corner case bugfix in "git rerere" code.
+
+ * "git add ':(attr:foo)'" is not supported and is supposed to be
+   rejected while the command line arguments are parsed, but we fail
+   to reject such a command line upfront.
+
+ * "git rebase" etc. in Git 2.19 fails to abort when given an empty
+   commit log message as result of editing, which has been corrected.
+
+ * The code to backfill objects in lazily cloned repository did not
+   work correctly, which has been corrected.
+
+ * Update error messages given by "git remote" and make them consistent.
+
+ * "git update-ref" learned to make both "--no-deref" and "--stdin"
+   work at the same time.
+
+ * Recently added "range-diff" had a corner-case bug to cause it
+   segfault, which has been corrected.
+
+ * The recently introduced commit-graph auxiliary data is incompatible
+   with mechanisms such as replace & grafts that "breaks" immutable
+   nature of the object reference relationship.  Disable optimizations
+   based on its use (and updating existing commit-graph) when these
+   incompatible features are in use in the repository.
+
+ * The mailmap file update.
+
+ * The code in "git status" sometimes hit an assertion failure.  This
+   was caused by a structure that was reused without cleaning the data
+   used for the first run, which has been corrected.
+
+ * A corner-case bugfix.
+
+ * A partial clone that is configured to lazily fetch missing objects
+   will on-demand issue a "git fetch" request to the originating
+   repository to fill not-yet-obtained objects.  The request has been
+   optimized for requesting a tree object (and not the leaf blob
+   objects contained in it) by telling the originating repository that
+   no blobs are needed.
+
+ * The codepath to support the experimental split-index mode had
+   remaining "racily clean" issues fixed.
+
+ * "git log --graph" showing an octopus merge sometimes miscounted the
+   number of display columns it is consuming to show the merge and its
+   parent commits, which has been corrected.
+
+ * The implementation of run_command() API on the UNIX platforms had a
+   bug that caused a command not on $PATH to be found in the current
+   directory.
+
+ * A mutex used in "git pack-objects" were not correctly initialized
+   and this caused "git repack" to dump core on Windows.
+
+ * Under certain circumstances, "git diff D:/a/b/c D:/a/b/d" on
+   Windows would strip initial parts from the paths because they
+   were not recognized as absolute, which has been corrected.
+
+ * The receive.denyCurrentBranch=updateInstead codepath kicked in even
+   when the push should have been rejected due to other reasons, such
+   as it does not fast-forward or the update-hook rejects it, which
+   has been corrected.
+
+ * "git repack" in a shallow clone did not correctly update the
+   shallow points in the repository, leading to a repository that
+   does not pass fsck.
+
+ * Operations on promisor objects make sense in the context of only a
+   small subset of the commands that internally use the revisions
+   machinery, but the "--exclude-promisor-objects" option were taken
+   and led to nonsense results by commands like "log", to which it
+   didn't make much sense.  This has been corrected.
+
+ * The "container" mode of TravisCI is going away.  Our .travis.yml
+   file is getting prepared for the transition.
+
+ * Our test scripts can now take the '-V' option as a synonym for the
+   '--verbose-log' option.
+
+ * A regression in Git 2.12 era made "git fsck" fall into an infinite
+   loop while processing truncated loose objects.
+
+Also contains various documentation updates and code clean-ups.
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/RelNotes/2.19.3.txt 1.2.3+git2.25.1-1/git/Documentation/RelNotes/2.19.3.txt
--- 1.2.1+git2.18.0-1/git/Documentation/RelNotes/2.19.3.txt	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/RelNotes/2.19.3.txt	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,8 @@
+Git v2.19.3 Release Notes
+=========================
+
+This release merges up the fixes that appear in v2.14.6, v2.15.4
+and in v2.17.3, addressing the security issues CVE-2019-1348,
+CVE-2019-1349, CVE-2019-1350, CVE-2019-1351, CVE-2019-1352,
+CVE-2019-1353, CVE-2019-1354, and CVE-2019-1387; see the release notes
+for those versions for details.
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/RelNotes/2.20.0.txt 1.2.3+git2.25.1-1/git/Documentation/RelNotes/2.20.0.txt
--- 1.2.1+git2.18.0-1/git/Documentation/RelNotes/2.20.0.txt	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/RelNotes/2.20.0.txt	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,700 @@
+Git 2.20 Release Notes
+======================
+
+Backward Compatibility Notes
+----------------------------
+
+ * "git branch -l <foo>" used to be a way to ask a reflog to be
+   created while creating a new branch, but that is no longer the
+   case.  It is a short-hand for "git branch --list <foo>" now.
+
+ * "git push" into refs/tags/* hierarchy is rejected without getting
+   forced, but "git fetch" (misguidedly) used the "fast forwarding"
+   rule used for the refs/heads/* hierarchy; this has been corrected,
+   which means some fetches of tags that did not fail with older
+   version of Git will fail without "--force" with this version.
+
+ * "git help -a" now gives verbose output (same as "git help -av").
+   Those who want the old output may say "git help --no-verbose -a"..
+
+ * "git cpn --help", when "cpn" is an alias to, say, "cherry-pick -n",
+   reported only the alias expansion of "cpn" in earlier versions of
+   Git.  It now runs "git cherry-pick --help" to show the manual page
+   of the command, while sending the alias expansion to the standard
+   error stream.
+
+ * "git send-email" learned to grab address-looking string on any
+   trailer whose name ends with "-by". This is a backward-incompatible
+   change.  Adding "--suppress-cc=misc-by" on the command line, or
+   setting sendemail.suppresscc configuration variable to "misc-by",
+   can be used to disable this behaviour.
+
+
+Updates since v2.19
+-------------------
+
+UI, Workflows & Features
+
+ * Running "git clone" against a project that contain two files with
+   pathnames that differ only in cases on a case insensitive
+   filesystem would result in one of the files lost because the
+   underlying filesystem is incapable of holding both at the same
+   time.  An attempt is made to detect such a case and warn.
+
+ * "git checkout -b newbranch [HEAD]" should not have to do as much as
+   checking out a commit different from HEAD.  An attempt is made to
+   optimize this special case.
+
+ * "git rev-list --stdin </dev/null" used to be an error; it now shows
+   no output without an error.  "git rev-list --stdin --default HEAD"
+   still falls back to the given default when nothing is given on the
+   standard input.
+
+ * Lift code from GitHub to restrict delta computation so that an
+   object that exists in one fork is not made into a delta against
+   another object that does not appear in the same forked repository.
+
+ * "git format-patch" learned new "--interdiff" and "--range-diff"
+   options to explain the difference between this version and the
+   previous attempt in the cover letter (or after the three-dashes as
+   a comment).
+
+ * "git mailinfo" used in "git am" learned to make a best-effort
+   recovery of a patch corrupted by MUA that sends text/plain with
+   format=flawed option.
+   (merge 3aa4d81f88 rs/mailinfo-format-flowed later to maint).
+
+ * The rules used by "git push" and "git fetch" to determine if a ref
+   can or cannot be updated were inconsistent; specifically, fetching
+   to update existing tags were allowed even though tags are supposed
+   to be unmoving anchoring points.  "git fetch" was taught to forbid
+   updates to existing tags without the "--force" option.
+
+ * "git multi-pack-index" learned to detect corruption in the .midx
+   file it uses, and this feature has been integrated into "git fsck".
+
+ * Generation of (experimental) commit-graph files have so far been
+   fairly silent, even though it takes noticeable amount of time in a
+   meaningfully large repository.  The users will now see progress
+   output.
+
+ * The minimum version of Windows supported by Windows port of Git is
+   now set to Vista.
+
+ * The completion script (in contrib/) learned to complete a handful of
+   options "git stash list" command takes.
+
+ * The completion script (in contrib/) learned that "git fetch
+   --multiple" only takes remote names as arguments and no refspecs.
+
+ * "git status" learns to show progress bar when refreshing the index
+   takes a long time.
+   (merge ae9af12287 nd/status-refresh-progress later to maint).
+
+ * "git help -a" and "git help -av" give different pieces of
+   information, and generally the "verbose" version is more friendly
+   to the new users.  "git help -a" by default now uses the more
+   verbose output (with "--no-verbose", you can go back to the
+   original).  Also "git help -av" now lists aliases and external
+   commands, which it did not used to.
+
+ * Unlike "grep", "git grep" by default recurses to the whole tree.
+   The command learned "git grep --recursive" option, so that "git
+   grep --no-recursive" can serve as a synonym to setting the
+   max-depth to 0.
+
+ * When pushing into a repository that borrows its objects from an
+   alternate object store, "git receive-pack" that responds to the
+   push request on the other side lists the tips of refs in the
+   alternate to reduce the amount of objects transferred.  This
+   sometimes is detrimental when the number of refs in the alternate
+   is absurdly large, in which case the bandwidth saved in potentially
+   fewer objects transferred is wasted in excessively large ref
+   advertisement.  The alternate refs that are advertised are now
+   configurable with a pair of configuration variables.
+
+ * "git cmd --help" when "cmd" is aliased used to only say "cmd is
+   aliased to ...".  Now it shows that to the standard error stream
+   and runs "git $cmd --help" where $cmd is the first word of the
+   alias expansion.
+
+ * The documentation of "git gc" has been updated to mention that it
+   is no longer limited to "pruning away cruft" but also updates
+   ancillary files like commit-graph as a part of repository
+   optimization.
+
+ * "git p4 unshelve" improvements.
+
+ * The logic to select the default user name and e-mail on Windows has
+   been improved.
+   (merge 501afcb8b0 js/mingw-default-ident later to maint).
+
+ * The "rev-list --filter" feature learned to exclude all trees via
+   "tree:0" filter.
+
+ * "git send-email" learned to grab address-looking string on any
+   trailer whose name ends with "-by"; --suppress-cc=misc-by on the
+   command line, or setting sendemail.suppresscc configuration
+   variable to "misc-by", can be used to disable this behaviour.
+
+ * "git mergetool" learned to take the "--[no-]gui" option, just like
+   "git difftool" does.
+
+ * "git rebase -i" learned a new insn, 'break', that the user can
+   insert in the to-do list.  Upon hitting it, the command returns
+   control back to the user.
+
+ * New "--pretty=format:" placeholders %GF and %GP that show the GPG
+   key fingerprints have been invented.
+
+ * On platforms with recent cURL library, http.sslBackend configuration
+   variable can be used to choose a different SSL backend at runtime.
+   The Windows port uses this mechanism to switch between OpenSSL and
+   Secure Channel while talking over the HTTPS protocol.
+
+ * "git send-email" learned to disable SMTP authentication via the
+   "--smtp-auth=none" option, even when the smtp username is given
+   (which turns the authentication on by default).
+
+ * A fourth class of configuration files (in addition to the
+   traditional "system wide", "per user in the $HOME directory" and
+   "per repository in the $GIT_DIR/config") has been introduced so
+   that different worktrees that share the same repository (hence the
+   same $GIT_DIR/config file) can use different customization.
+
+ * A pattern with '**' that does not have a slash on either side used
+   to be an invalid one, but the code now treats such double-asterisks
+   the same way as two normal asterisks that happen to be adjacent to
+   each other.
+   (merge e5bbe09e88 nd/wildmatch-double-asterisk later to maint).
+
+ * The "--no-patch" option, which can be used to get a high-level
+   overview without the actual line-by-line patch difference shown, of
+   the "range-diff" command was earlier broken, which has been
+   corrected.
+
+ * The recently merged "rebase in C" has an escape hatch to use the
+   scripted version when necessary, but it hasn't been documented,
+   which has been corrected.
+
+
+Performance, Internal Implementation, Development Support etc.
+
+ * Developer builds now use -Wunused-function compilation option.
+
+ * One of our CI tests to run with "unusual/experimental/random"
+   settings now also uses commit-graph and midx.
+
+ * When there are too many packfiles in a repository (which is not
+   recommended), looking up an object in these would require
+   consulting many pack .idx files; a new mechanism to have a single
+   file that consolidates all of these .idx files is introduced.
+
+ * "git submodule update" is getting rewritten piece-by-piece into C.
+
+ * The code for computing history reachability has been shuffled,
+   obtained a bunch of new tests to cover them, and then being
+   improved.
+
+ * The unpack_trees() API used in checking out a branch and merging
+   walks one or more trees along with the index.  When the cache-tree
+   in the index tells us that we are walking a tree whose flattened
+   contents is known (i.e. matches a span in the index), as linearly
+   scanning a span in the index is much more efficient than having to
+   open tree objects recursively and listing their entries, the walk
+   can be optimized, which has been done.
+
+ * When creating a thin pack, which allows objects to be made into a
+   delta against another object that is not in the resulting pack but
+   is known to be present on the receiving end, the code learned to
+   take advantage of the reachability bitmap; this allows the server
+   to send a delta against a base beyond the "boundary" commit.
+
+ * spatch transformation to replace boolean uses of !hashcmp() to
+   newly introduced oideq() is added, and applied, to regain
+   performance lost due to support of multiple hash algorithms.
+
+ * Fix a bug in which the same path could be registered under multiple
+   worktree entries if the path was missing (for instance, was removed
+   manually).  Also, as a convenience, expand the number of cases in
+   which --force is applicable.
+
+ * Split Documentation/config.txt for easier maintenance.
+   (merge 6014363f0b nd/config-split later to maint).
+
+ * Test helper binaries clean-up.
+   (merge c9a1f4161f nd/test-tool later to maint).
+
+ * Various tests have been updated to make it easier to swap the
+   hash function used for object identification.
+   (merge ae0c89d41b bc/hash-independent-tests later to maint).
+
+ * Update fsck.skipList implementation and documentation.
+   (merge 371a655074 ab/fsck-skiplist later to maint).
+
+ * An alias that expands to another alias has so far been forbidden,
+   but now it is allowed to create such an alias.
+
+ * Various test scripts have been updated for style and also correct
+   handling of exit status of various commands.
+
+ * "gc --auto" ended up calling exit(-1) upon error, which has been
+   corrected to use exit(1).  Also the error reporting behaviour when
+   daemonized has been updated to exit with zero status when stopping
+   due to a previously discovered error (which implies there is no
+   point running gc to improve the situation); we used to exit with
+   failure in such a case.
+
+ * Various codepaths in the core-ish part learned to work on an
+   arbitrary in-core index structure, not necessarily the default
+   instance "the_index".
+   (merge b3c7eef9b0 nd/the-index later to maint).
+
+ * Code clean-up in the internal machinery used by "git status" and
+   "git commit --dry-run".
+   (merge 73ba5d78b4 ss/wt-status-committable later to maint).
+
+ * Some environment variables that control the runtime options of Git
+   used during tests are getting renamed for consistency.
+   (merge 4231d1ba99 bp/rename-test-env-var later to maint).
+
+ * A pair of new extensions to the index file have been introduced.
+   They allow the index file to be read in parallel for performance.
+
+ * The oidset API was built on top of the oidmap API which in turn is
+   on the hashmap API.  Replace the implementation to build on top of
+   the khash API and gain performance.
+
+ * Over some transports, fetching objects with an exact commit object
+   name can be done without first seeing the ref advertisements.  The
+   code has been optimized to exploit this.
+
+ * In a partial clone that will lazily be hydrated from the
+   originating repository, we generally want to avoid "does this
+   object exist (locally)?" on objects that we deliberately omitted
+   when we created the clone.  The cache-tree codepath (which is used
+   to write a tree object out of the index) however insisted that the
+   object exists, even for paths that are outside of the partial
+   checkout area.  The code has been updated to avoid such a check.
+
+ * To help developers, an EditorConfig file that attempts to follow
+   the project convention has been added.
+   (merge b548d698a0 bc/editorconfig later to maint).
+
+ * The result of coverage test can be combined with "git blame" to
+   check the test coverage of code introduced recently with a new
+   'coverage-diff' tool (in contrib/).
+   (merge 783faedd65 ds/coverage-diff later to maint).
+
+ * An experiment to fuzz test a few areas, hopefully we can gain more
+   coverage to various areas.
+
+ * More codepaths are moving away from hardcoded hash sizes.
+
+ * The way the Windows port figures out the current directory has been
+   improved.
+
+ * The way DLLs are loaded on the Windows port has been improved.
+
+ * Some tests have been reorganized and renamed; "ls t/" now gives a
+   better overview of what is tested for these scripts than before.
+
+ * "git rebase" and "git rebase -i" have been reimplemented in C.
+
+ * Windows port learned to use nano-second resolution file timestamps.
+
+ * The overly large Documentation/config.txt file have been split into
+   million little pieces.  This potentially allows each individual piece
+   to be included into the manual page of the command it affects more easily.
+
+ * Replace three string-list instances used as look-up tables in "git
+   fetch" with hashmaps.
+
+ * Unify code to read the author-script used in "git am" and the
+   commands that use the sequencer machinery, e.g. "git rebase -i".
+
+ * In preparation to the day when we can deprecate and remove the
+   "rebase -p", make sure we can skip and later remove tests for
+   it.
+
+ * The history traversal used to implement the tag-following has been
+   optimized by introducing a new helper.
+
+ * The helper function to refresh the cached stat information in the
+   in-core index has learned to perform the lstat() part of the
+   operation in parallel on multi-core platforms.
+
+ * The code to traverse objects for reachability, used to decide what
+   objects are unreferenced and expendable, have been taught to also
+   consider per-worktree refs of other worktrees as starting points to
+   prevent data loss.
+
+ * "git add" needs to internally run "diff-files" equivalent, and the
+   codepath learned the same optimization as "diff-files" has to run
+   lstat(2) in parallel to find which paths have been updated in the
+   working tree.
+
+ * The procedure to install dependencies before testing at Travis CI
+   is getting revamped for both simplicity and flexibility, taking
+   advantage of the recent move to the vm-based environment.
+
+ * The support for format-patch (and send-email) by the command-line
+   completion script (in contrib/) has been simplified a bit.
+
+ * The revision walker machinery learned to take advantage of the
+   commit generation numbers stored in the commit-graph file.
+
+ * The codebase has been cleaned up to reduce "#ifndef NO_PTHREADS".
+
+ * The way -lcurl library gets linked has been simplified by taking
+   advantage of the fact that we can just ask curl-config command how.
+
+ * Various functions have been audited for "-Wunused-parameter" warnings
+   and bugs in them got fixed.
+
+ * A sanity check for start-up sequence has been added in the config
+   API codepath.
+
+ * The build procedure to link for fuzzing test has been made
+   customizable with a new Makefile variable.
+
+ * The way "git rebase" parses and forwards the command line options
+   meant for underlying "git am" has been revamped, which fixed for
+   options with parameters that were not passed correctly.
+
+ * Our testing framework uses a special i18n "poisoned localization"
+   feature to find messages that ought to stay constant but are
+   incorrectly marked to be translated.  This feature has been made
+   into a runtime option (it used to be a compile-time option).
+
+ * "git push" used to check ambiguities between object-names and
+   refnames while processing the list of refs' old and new values,
+   which was unnecessary (as it knew that it is feeding raw object
+   names).  This has been optimized out.
+
+ * The xcurl_off_t() helper function is used to cast size_t to
+   curl_off_t, but some compilers gave warnings against the code to
+   ensure the casting is done without wraparound, when size_t is
+   narrower than curl_off_t.  This warning has been squelched.
+
+ * Code preparation to replace ulong vars with size_t vars where
+   appropriate continues.
+
+ * The "test installed Git" mode of our test suite has been updated to
+   work better.
+
+ * A coding convention around the Coccinelle semantic patches to have
+   two classes to ease code migration process has been proposed and
+   its support has been added to the Makefile.
+
+ * The "container" mode of TravisCI is going away.  Our .travis.yml
+   file is getting prepared for the transition.
+   (merge 32ee384be8 ss/travis-ci-force-vm-mode later to maint).
+
+ * Our test scripts can now take the '-V' option as a synonym for the
+   '--verbose-log' option.
+   (merge a5f52c6dab sg/test-verbose-log later to maint).
+
+
+Fixes since v2.19
+-----------------
+
+ * "git interpret-trailers" and its underlying machinery had a buggy
+   code that attempted to ignore patch text after commit log message,
+   which triggered in various codepaths that will always get the log
+   message alone and never get such an input.
+   (merge 66e83d9b41 jk/trailer-fixes later to maint).
+
+ * Malformed or crafted data in packstream can make our code attempt
+   to read or write past the allocated buffer and abort, instead of
+   reporting an error, which has been fixed.
+
+ * "git rebase -i" did not clear the state files correctly when a run
+   of "squash/fixup" is aborted and then the user manually amended the
+   commit instead, which has been corrected.
+   (merge 10d2f35436 js/rebase-i-autosquash-fix later to maint).
+
+ * When fsmonitor is in use, after operation on submodules updates
+   .gitmodules, we lost track of the fact that we did so and relied on
+   stale fsmonitor data.
+   (merge 43f1180814 bp/mv-submodules-with-fsmonitor later to maint).
+
+ * Fix for a long-standing bug that leaves the index file corrupt when
+   it shrinks during a partial commit.
+   (merge 6c003d6ffb jk/reopen-tempfile-truncate later to maint).
+
+ * Further fix for O_APPEND emulation on Windows
+   (merge eeaf7ddac7 js/mingw-o-append later to maint).
+
+ * A corner case bugfix in "git rerere" code.
+   (merge ad2bf0d9b4 en/rerere-multi-stage-1-fix later to maint).
+
+ * "git add ':(attr:foo)'" is not supported and is supposed to be
+   rejected while the command line arguments are parsed, but we fail
+   to reject such a command line upfront.
+   (merge 84d938b732 nd/attr-pathspec-fix later to maint).
+
+ * Recent update broke the reachability algorithm when refs (e.g.
+   tags) that point at objects that are not commit were involved,
+   which has been fixed.
+
+ * "git rebase" etc. in Git 2.19 fails to abort when given an empty
+   commit log message as result of editing, which has been corrected.
+   (merge a3ec9eaf38 en/sequencer-empty-edit-result-aborts later to maint).
+
+ * The code to backfill objects in lazily cloned repository did not
+   work correctly, which has been corrected.
+   (merge e68302011c jt/lazy-object-fetch-fix later to maint).
+
+ * Update error messages given by "git remote" and make them consistent.
+   (merge 5025425dff ms/remote-error-message-update later to maint).
+
+ * "git update-ref" learned to make both "--no-deref" and "--stdin"
+   work at the same time.
+   (merge d345e9fbe7 en/update-ref-no-deref-stdin later to maint).
+
+ * Recently added "range-diff" had a corner-case bug to cause it
+   segfault, which has been corrected.
+   (merge e467a90c7a tg/range-diff-corner-case-fix later to maint).
+
+ * The recently introduced commit-graph auxiliary data is incompatible
+   with mechanisms such as replace & grafts that "breaks" immutable
+   nature of the object reference relationship.  Disable optimizations
+   based on its use (and updating existing commit-graph) when these
+   incompatible features are in use in the repository.
+   (merge 829a321569 ds/commit-graph-with-grafts later to maint).
+
+ * The mailmap file update.
+   (merge 255eb03edf jn/mailmap-update later to maint).
+
+ * The code in "git status" sometimes hit an assertion failure.  This
+   was caused by a structure that was reused without cleaning the data
+   used for the first run, which has been corrected.
+   (merge 3e73cc62c0 en/status-multiple-renames-to-the-same-target-fix later to maint).
+
+ * "git fetch $repo $object" in a partial clone did not correctly
+   fetch the asked-for object that is referenced by an object in
+   promisor packfile, which has been fixed.
+
+ * A corner-case bugfix.
+   (merge c5cbb27cb5 sm/show-superproject-while-conflicted later to maint).
+
+ * Various fixes to "diff --color-moved-ws".
+
+ * A partial clone that is configured to lazily fetch missing objects
+   will on-demand issue a "git fetch" request to the originating
+   repository to fill not-yet-obtained objects.  The request has been
+   optimized for requesting a tree object (and not the leaf blob
+   objects contained in it) by telling the originating repository that
+   no blobs are needed.
+   (merge 4c7f9567ea jt/non-blob-lazy-fetch later to maint).
+
+ * The codepath to support the experimental split-index mode had
+   remaining "racily clean" issues fixed.
+   (merge 4c490f3d32 sg/split-index-racefix later to maint).
+
+ * "git log --graph" showing an octopus merge sometimes miscounted the
+   number of display columns it is consuming to show the merge and its
+   parent commits, which has been corrected.
+   (merge 04005834ed np/log-graph-octopus-fix later to maint).
+
+ * "git range-diff" did not work well when the compared ranges had
+   changes in submodules and the "--submodule=log" was used.
+
+ * The implementation of run_command() API on the UNIX platforms had a
+   bug that caused a command not on $PATH to be found in the current
+   directory.
+   (merge f67b980771 jk/run-command-notdot later to maint).
+
+ * A mutex used in "git pack-objects" were not correctly initialized
+   and this caused "git repack" to dump core on Windows.
+   (merge 34204c8166 js/pack-objects-mutex-init-fix later to maint).
+
+ * Under certain circumstances, "git diff D:/a/b/c D:/a/b/d" on
+   Windows would strip initial parts from the paths because they
+   were not recognized as absolute, which has been corrected.
+   (merge ffd04e92e2 js/diff-notice-has-drive-prefix later to maint).
+
+ * The receive.denyCurrentBranch=updateInstead codepath kicked in even
+   when the push should have been rejected due to other reasons, such
+   as it does not fast-forward or the update-hook rejects it, which
+   has been corrected.
+   (merge b072a25fad jc/receive-deny-current-branch-fix later to maint).
+
+ * The logic to determine the archive type "git archive" uses did not
+   correctly kick in for "git archive --remote", which has been
+   corrected.
+
+ * "git repack" in a shallow clone did not correctly update the
+   shallow points in the repository, leading to a repository that
+   does not pass fsck.
+   (merge 5dcfbf564c js/shallow-and-fetch-prune later to maint).
+
+ * Some codepaths failed to form a proper URL when .gitmodules record
+   the URL to a submodule repository as relative to the repository of
+   superproject, which has been corrected.
+   (merge e0a862fdaf sb/submodule-url-to-absolute later to maint).
+
+ * "git fetch" over protocol v2 into a shallow repository failed to
+   fetch full history behind a new tip of history that was diverged
+   before the cut-off point of the history that was previously fetched
+   shallowly.
+
+ * The command line completion machinery (in contrib/) has been
+   updated to allow the completion script to tweak the list of options
+   that are reported by the parse-options machinery correctly.
+   (merge 276b49ff34 nd/completion-negation later to maint).
+
+ * Operations on promisor objects make sense in the context of only a
+   small subset of the commands that internally use the revisions
+   machinery, but the "--exclude-promisor-objects" option were taken
+   and led to nonsense results by commands like "log", to which it
+   didn't make much sense.  This has been corrected.
+   (merge 669b1d2aae md/exclude-promisor-objects-fix later to maint).
+
+ * A regression in Git 2.12 era made "git fsck" fall into an infinite
+   loop while processing truncated loose objects.
+   (merge 18ad13e5b2 jk/detect-truncated-zlib-input later to maint).
+
+ * "git ls-remote $there foo" was broken by recent update for the
+   protocol v2 and stopped showing refs that match 'foo' that are not
+   refs/{heads,tags}/foo, which has been fixed.
+   (merge 6a139cdd74 jk/proto-v2-ref-prefix-fix later to maint).
+
+ * Additional comment on a tricky piece of code to help developers.
+   (merge 0afbe3e806 jk/stream-pack-non-delta-clarification later to maint).
+
+ * A couple of tests used to leave the repository in a state that is
+   deliberately corrupt, which have been corrected.
+   (merge aa984dbe5e ab/pack-tests-cleanup later to maint).
+
+ * The submodule support has been updated to read from the blob at
+   HEAD:.gitmodules when the .gitmodules file is missing from the
+   working tree.
+   (merge 2b1257e463 ao/submodule-wo-gitmodules-checked-out later to maint).
+
+ * "git fetch" was a bit loose in parsing responses from the other side
+   when talking over the protocol v2.
+
+ * "git rev-parse --exclude=* --branches --branches"  (i.e. first
+   saying "add only things that do not match '*' out of all branches"
+   and then adding all branches, without any exclusion this time)
+   worked as expected, but "--exclude=* --all --all" did not work the
+   same way, which has been fixed.
+   (merge 5221048092 ag/rev-parse-all-exclude-fix later to maint).
+
+ * "git send-email --transfer-encoding=..." in recent versions of Git
+   sometimes produced an empty "Content-Transfer-Encoding:" header,
+   which has been corrected.
+   (merge 3c88e46f1a al/send-email-auto-cte-fixup later to maint).
+
+ * The interface into "xdiff" library used to discover the offset and
+   size of a generated patch hunk by first formatting it into the
+   textual hunk header "@@ -n,m +k,l @@" and then parsing the numbers
+   out.  A new interface has been introduced to allow callers a more
+   direct access to them.
+   (merge 5eade0746e jk/xdiff-interface later to maint).
+
+ * Pathspec matching against a tree object were buggy when negative
+   pathspec elements were involved, which has been fixed.
+   (merge b7845cebc0 nd/tree-walk-path-exclusion later to maint).
+
+ * "git merge" and "git pull" that merges into an unborn branch used
+   to completely ignore "--verify-signatures", which has been
+   corrected.
+   (merge 01a31f3bca jk/verify-sig-merge-into-void later to maint).
+
+ * "git rebase --autostash" did not correctly re-attach the HEAD at times.
+
+ * "rev-parse --exclude=<pattern> --branches=<pattern>" etc. did not
+   quite work, which has been corrected.
+   (merge 9ab9b5df0e ra/rev-parse-exclude-glob later to maint).
+
+ * When editing a patch in a "git add -i" session, a hunk could be
+   made to no-op.  The "git apply" program used to reject a patch with
+   such a no-op hunk to catch user mistakes, but it is now updated to
+   explicitly allow a no-op hunk in an edited patch.
+   (merge 22cb3835b9 js/apply-recount-allow-noop later to maint).
+
+ * The URL to an MSDN page in a comment has been updated.
+   (merge 2ef2ae2917 js/mingw-msdn-url later to maint).
+
+ * "git ls-remote --sort=<thing>" can feed an object that is not yet
+   available into the comparison machinery and segfault, which has
+   been corrected to check such a request upfront and reject it.
+
+ * When "git bundle" aborts due to an empty commit ranges
+   (i.e. resulting in an empty pack), it left a file descriptor to an
+   lockfile open, which resulted in leftover lockfile on Windows where
+   you cannot remove a file with an open file descriptor.  This has
+   been corrected.
+   (merge 2c8ee1f53c jk/close-duped-fd-before-unlock-for-bundle later to maint).
+
+ * "git format-patch --stat=<width>" can be used to specify the width
+   used by the diffstat (shown in the cover letter).
+   (merge 284aeb7e60 nd/format-patch-cover-letter-stat-width later to maint).
+
+ * The way .git/index and .git/sharedindex* files were initially
+   created gave these files different perm bits until they were
+   adjusted for shared repository settings.  This was made consistent.
+   (merge c9d6c78870 cc/shared-index-permbits later to maint).
+
+ * "git rebase --stat" to transplant a piece of history onto a totally
+   unrelated history were not working before and silently showed wrong
+   result.  With the recent reimplementation in C, it started to instead
+   die with an error message, as the original logic was not prepared
+   to cope with this case.  This has now been fixed.
+
+ * The advice message to tell the user to migrate an existing graft
+   file to the replace system when a graft file was read was shown
+   even when "git replace --convert-graft-file" command, which is the
+   way the message suggests to use, was running, which made little
+   sense.
+   (merge 8821e90a09 ab/replace-graft-with-replace-advice later to maint).
+
+ * "git diff --raw" lost ellipses to adjust the output columns for
+   some time now, but the documentation still showed them.
+
+ * Code cleanup, docfix, build fix, etc.
+   (merge 96a7501aad ts/doc-build-manpage-xsl-quietly later to maint).
+   (merge b9b07efdb2 tg/conflict-marker-size later to maint).
+   (merge fa0aeea770 sg/doc-trace-appends later to maint).
+   (merge d64324cb60 tb/void-check-attr later to maint).
+   (merge c3b9bc94b9 en/double-semicolon-fix later to maint).
+   (merge 79336116f5 sg/t3701-tighten-trace later to maint).
+   (merge 801fa63a90 jk/dev-build-format-security later to maint).
+   (merge 0597dd62ba sb/string-list-remove-unused later to maint).
+   (merge db2d36fad8 bw/protocol-v2 later to maint).
+   (merge 456d7cd3a9 sg/split-index-test later to maint).
+   (merge 7b6057c852 tq/refs-internal-comment-fix later to maint).
+   (merge 29e8dc50ad tg/t5551-with-curl-7.61.1 later to maint).
+   (merge 55f6bce2c9 fe/doc-updates later to maint).
+   (merge 7987d2232d jk/check-everything-connected-is-long-gone later to maint).
+   (merge 4ba3c9be47 dz/credential-doc-url-matching-rules later to maint).
+   (merge 4c399442f7 ma/commit-graph-docs later to maint).
+   (merge fc0503b04e ma/t1400-undebug-test later to maint).
+   (merge e56b53553a nd/packobjectshook-doc-fix later to maint).
+   (merge c56170a0c4 ma/mailing-list-address-in-git-help later to maint).
+   (merge 6e8fc70fce rs/sequencer-oidset-insert-avoids-dups later to maint).
+   (merge ad0b8f9575 mw/doc-typofixes later to maint).
+   (merge d9f079ad1a jc/how-to-document-api later to maint).
+   (merge b1492bf315 ma/t7005-bash-workaround later to maint).
+   (merge ac1f98a0df du/rev-parse-is-plumbing later to maint).
+   (merge ca8ed443a5 mm/doc-no-dashed-git later to maint).
+   (merge ce366a8144 du/get-tar-commit-id-is-plumbing later to maint).
+   (merge 61018fe9e0 du/cherry-is-plumbing later to maint).
+   (merge c7e5fe79b9 sb/strbuf-h-update later to maint).
+   (merge 8d2008196b tq/branch-create-wo-branch-get later to maint).
+   (merge 2e3c894f4b tq/branch-style-fix later to maint).
+   (merge c5d844af9c sg/doc-show-branch-typofix later to maint).
+   (merge 081d91618b ah/doc-updates later to maint).
+   (merge b84c783882 jc/cocci-preincr later to maint).
+   (merge 5e495f8122 uk/merge-subtree-doc-update later to maint).
+   (merge aaaa881822 jk/uploadpack-packobjectshook-fix later to maint).
+   (merge 3063477445 tb/char-may-be-unsigned later to maint).
+   (merge 8c64bc9420 sg/test-rebase-editor-fix later to maint).
+   (merge 71571cd7d6 ma/sequencer-do-reset-saner-loop-termination later to maint).
+   (merge 9a4cb8781e cb/notes-freeing-always-null-fix later to maint).
+   (merge 3006f5ee16 ma/reset-doc-rendering-fix later to maint).
+   (merge 4c2eb06419 sg/daemon-test-signal-fix later to maint).
+   (merge d27525e519 ss/msvc-strcasecmp later to maint).
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/RelNotes/2.20.1.txt 1.2.3+git2.25.1-1/git/Documentation/RelNotes/2.20.1.txt
--- 1.2.1+git2.18.0-1/git/Documentation/RelNotes/2.20.1.txt	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/RelNotes/2.20.1.txt	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,20 @@
+Git v2.20.1 Release Notes
+=========================
+
+This release is primarily to fix brown-paper-bag breakages in the
+2.20.0 release.
+
+Fixes since v2.20
+-----------------
+
+ * A few newly added tests were not portable and caused minority
+   platforms to report false breakages, which have been fixed.
+
+ * Portability fix for a recent update to parse-options API.
+
+ * "git help -a" did not work well when an overly long alias is
+   defined, which has been corrected.
+
+ * A recent update accidentally squelched an error message when the
+   run_command API failed to run a missing command, which has been
+   corrected.
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/RelNotes/2.20.2.txt 1.2.3+git2.25.1-1/git/Documentation/RelNotes/2.20.2.txt
--- 1.2.1+git2.18.0-1/git/Documentation/RelNotes/2.20.2.txt	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/RelNotes/2.20.2.txt	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,18 @@
+Git v2.20.2 Release Notes
+=========================
+
+This release merges up the fixes that appear in v2.14.6, v2.15.4
+and in v2.17.3, addressing the security issues CVE-2019-1348,
+CVE-2019-1349, CVE-2019-1350, CVE-2019-1351, CVE-2019-1352,
+CVE-2019-1353, CVE-2019-1354, and CVE-2019-1387; see the release notes
+for those versions for details.
+
+The change to disallow `submodule.<name>.update=!command` entries in
+`.gitmodules` which was introduced v2.15.4 (and for which v2.17.3
+added explicit fsck checks) fixes the vulnerability in v2.20.x where a
+recursive clone followed by a submodule update could execute code
+contained within the repository without the user explicitly having
+asked for that (CVE-2019-19604).
+
+Credit for finding this vulnerability goes to Joern Schneeweisz,
+credit for the fixes goes to Jonathan Nieder.
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/RelNotes/2.21.0.txt 1.2.3+git2.25.1-1/git/Documentation/RelNotes/2.21.0.txt
--- 1.2.1+git2.18.0-1/git/Documentation/RelNotes/2.21.0.txt	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/RelNotes/2.21.0.txt	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,451 @@
+Git 2.21 Release Notes
+======================
+
+Backward Compatibility Notes
+----------------------------
+
+ * Historically, the "-m" (mainline) option can only be used for "git
+   cherry-pick" and "git revert" when working with a merge commit.
+   This version of Git no longer warns or errors out when working with
+   a single-parent commit, as long as the argument to the "-m" option
+   is 1 (i.e. it has only one parent, and the request is to pick or
+   revert relative to that first parent).  Scripts that relied on the
+   behaviour may get broken with this change.
+
+
+Updates since v2.20
+-------------------
+
+UI, Workflows & Features
+
+ * The "http.version" configuration variable can be used with recent
+   enough versions of cURL library to force the version of HTTP used
+   to talk when fetching and pushing.
+
+ * Small fixes and features for fast-export and fast-import, mostly on
+   the fast-export side has been made.
+
+ * "git push $there $src:$dst" rejects when $dst is not a fully
+   qualified refname and it is not clear what the end user meant.  The
+   codepath has been taught to give a clearer error message, and also
+   guess where the push should go by taking the type of the pushed
+   object into account (e.g. a tag object would want to go under
+   refs/tags/).
+
+ * "git checkout [<tree-ish>] path..." learned to report the number of
+   paths that have been checked out of the index or the tree-ish,
+   which gives it the same degree of noisy-ness as the case in which
+   the command checks out a branch.  "git checkout -m <pathspec>" to
+   undo conflict resolution gives a similar message.
+
+ * "git quiltimport" learned "--keep-non-patch" option.
+
+ * "git worktree remove" and "git worktree move" refused to work when
+   there is a submodule involved.  This has been loosened to ignore
+   uninitialized submodules.
+
+ * "git cherry-pick -m1" was forbidden when picking a non-merge
+   commit, even though there _is_ parent number 1 for such a commit.
+   This was done to avoid mistakes back when "cherry-pick" was about
+   picking a single commit, but is no longer useful with "cherry-pick"
+   that can pick a range of commits.  Now the "-m$num" option is
+   allowed when picking any commit, as long as $num names an existing
+   parent of the commit.
+
+ * Update "git multimail" from the upstream.
+
+ * "git p4" update.
+
+ * The "--format=<placeholder>" option of for-each-ref, branch and tag
+   learned to show a few more traits of objects that can be learned by
+   the object_info API.
+
+ * "git rebase -i" learned to re-execute a command given with 'exec'
+   to run after it failed the last time.
+
+ * "git diff --color-moved-ws" updates.
+
+ * Custom userformat "log --format" learned %S atom that stands for
+   the tip the traversal reached the commit from, i.e. --source.
+
+ * "git instaweb" learned to drive http.server that comes with
+   "batteries included" Python installation (both Python2 & 3).
+
+ * A new encoding UTF-16LE-BOM has been invented to force encoding to
+   UTF-16 with BOM in little endian byte order, which cannot be directly
+   generated by using iconv.
+
+ * A new date format "--date=human" that morphs its output depending
+   on how far the time is from the current time has been introduced.
+   "--date=auto:human" can be used to use this new format (or any
+   existing format) when the output is going to the pager or to the
+   terminal, and otherwise the default format.
+
+
+Performance, Internal Implementation, Development Support etc.
+
+ * Code clean-up with optimization for the codepath that checks
+   (non-)existence of loose objects.
+
+ * More codepaths have become aware of working with in-core repository
+   instances other than the default "the_repository".
+
+ * The "strncat()" function is now among the banned functions.
+
+ * Portability updates for the HPE NonStop platform.
+
+ * Earlier we added "-Wformat-security" to developer builds, assuming
+   that "-Wall" (which includes "-Wformat" which in turn is required
+   to use "-Wformat-security") is always in effect.  This is not true
+   when config.mak.autogen is in use, unfortunately.  This has been
+   fixed by unconditionally adding "-Wall" to developer builds.
+
+ * The loose object cache used to optimize existence look-up has been
+   updated.
+
+ * Flaky tests can now be repeatedly run under load with the
+   "--stress" option.
+
+ * Documentation/Makefile is getting prepared for manpage
+   localization.
+
+ * "git fetch-pack" now can talk the version 2 protocol.
+
+ * sha-256 hash has been added and plumbed through the code to allow
+   building Git with the "NewHash".
+
+ * Debugging help for http transport.
+
+ * "git fetch --deepen=<more>" has been corrected to work over v2
+   protocol.
+
+ * The code to walk tree objects has been taught that we may be
+   working with object names that are not computed with SHA-1.
+
+ * The in-core repository instances are passed through more codepaths.
+
+ * Update the protocol message specification to allow only the limited
+   use of scaled quantities.  This is to ensure potential compatibility
+   issues will not get out of hand.
+
+ * Micro-optimize the code that prepares commit objects to be walked
+   by "git rev-list" when the commit-graph is available.
+
+ * "git fetch" and "git upload-pack" learned to send all exchanges over
+   the sideband channel while talking the v2 protocol.
+
+ * The codepath to write out commit-graph has been optimized by
+   following the usual pattern of visiting objects in in-pack order.
+
+ * The codepath to show progress meter while writing out commit-graph
+   file has been improved.
+
+ * Cocci rules have been updated to encourage use of strbuf_addbuf().
+
+ * "git rebase --merge" has been reimplemented by reusing the internal
+   machinery used for "git rebase -i".
+
+ * More code in "git bisect" has been rewritten in C.
+
+ * Instead of going through "git-rebase--am" scriptlet to use the "am"
+   backend, the built-in version of "git rebase" learned to drive the
+   "am" backend directly.
+
+ * The assumption to work on the single "in-core index" instance has
+   been reduced from the library-ish part of the codebase.
+
+ * The test lint learned to catch non-portable "sed" options.
+
+ * "git pack-objects" learned another algorithm to compute the set of
+   objects to send, that trades the resulting packfile off to save
+   traversal cost to favor small pushes.
+
+ * The travis CI scripts have been corrected to build Git with the
+   compiler(s) of our choice.
+
+ * "git submodule update" learned to abort early when core.worktree
+   for the submodule is not set correctly to prevent spreading damage.
+
+ * Test suite has been adjusted to run on Azure Pipeline.
+
+ * Running "Documentation/doc-diff x" from anywhere other than the
+   top-level of the working tree did not show the usage string
+   correctly, which has been fixed.
+
+ * Use of the sparse tool got easier to customize from the command
+   line to help developers.
+
+ * A new target "coverage-prove" to run the coverage test under
+   "prove" has been added.
+
+ * A flakey "p4" test has been removed.
+
+ * The code and tests assume that the system supplied iconv() would
+   always use BOM in its output when asked to encode to UTF-16 (or
+   UTF-32), but apparently some implementations output big-endian
+   without BOM.  A compile-time knob has been added to help such
+   systems (e.g. NonStop) to add BOM to the output to increase
+   portability.
+
+
+Fixes since v2.20
+-----------------
+
+ * Updates for corner cases in merge-recursive.
+   (merge cc4cb0902c en/merge-path-collision later to maint).
+
+ * "git checkout frotz" (without any double-dash) avoids ambiguity by
+   making sure 'frotz' cannot be interpreted as a revision and as a
+   path at the same time.  This safety has been updated to check also
+   a unique remote-tracking branch 'frotz' in a remote, when dwimming
+   to create a local branch 'frotz' out of a remote-tracking branch
+   'frotz' from a remote.
+   (merge be4908f103 nd/checkout-dwim-fix later to maint).
+
+ * Refspecs configured with "git -c var=val clone" did not propagate
+   to the resulting repository, which has been corrected.
+   (merge 7eae4a3ac4 sg/clone-initial-fetch-configuration later to maint).
+
+ * A properly configured username/email is required under
+   user.useConfigOnly in order to create commits; now "git stash"
+   (even though it creates commit objects to represent stash entries)
+   command is exempt from the requirement.
+   (merge 3bc2111fc2 sd/stash-wo-user-name later to maint).
+
+ * The http-backend CGI process did not correctly clean up the child
+   processes it spawns to run upload-pack etc. when it dies itself,
+   which has been corrected.
+   (merge 02818a98d7 mk/http-backend-kill-children-before-exit later to maint).
+
+ * "git rev-list --exclude-promisor-objects" had to take an object
+   that does not exist locally (and is lazily available) from the
+   command line without barfing, but the code dereferenced NULL.
+   (merge 4cf67869b2 md/list-lazy-objects-fix later to maint).
+
+ * The traversal over tree objects has learned to honor
+   ":(attr:label)" pathspec match, which has been implemented only for
+   enumerating paths on the filesystem.
+   (merge 5a0b97b34c nd/attr-pathspec-in-tree-walk later to maint).
+
+ * BSD port updates.
+   (merge 4e3ecbd439 cb/openbsd-allows-reading-directory later to maint).
+   (merge b6bdc2a0f5 cb/t5004-empty-tar-archive-fix later to maint).
+   (merge 82cbc8cde2 cb/test-lint-cp-a later to maint).
+
+ * Lines that begin with a certain keyword that come over the wire, as
+   well as lines that consist only of one of these keywords, ought to
+   be painted in color for easier eyeballing, but the latter was
+   broken ever since the feature was introduced in 2.19, which has
+   been corrected.
+   (merge 1f67290450 hn/highlight-sideband-keywords later to maint).
+
+ * "git log -G<regex>" looked for a hunk in the "git log -p" patch
+   output that contained a string that matches the given pattern.
+   Optimize this code to ignore binary files, which by default will
+   not show any hunk that would match any pattern (unless textconv or
+   the --text option is in effect, that is).
+   (merge e0e7cb8080 tb/log-G-binary later to maint).
+
+ * "git submodule update" ought to use a single job unless asked, but
+   by mistake used multiple jobs, which has been fixed.
+   (merge e3a9d1aca9 sb/submodule-fetchjobs-default-to-one later to maint).
+
+ * "git stripspace" should be usable outside a git repository, but
+   under the "-s" or "-c" mode, it didn't.
+   (merge 957da75802 jn/stripspace-wo-repository later to maint).
+
+ * Some of the documentation pages formatted incorrectly with
+   Asciidoctor, which have been fixed.
+   (merge b62eb1d2f4 ma/asciidoctor later to maint).
+
+ * The core.worktree setting in a submodule repository should not be
+   pointing at a directory when the submodule loses its working tree
+   (e.g. getting deinit'ed), but the code did not properly maintain
+   this invariant.
+
+ * With zsh, "git cmd path<TAB>" was completed to "git cmd path name"
+   when the completed path has a special character like SP in it,
+   without any attempt to keep "path name" a single filename.  This
+   has been fixed to complete it to "git cmd path\ name" just like
+   Bash completion does.
+
+ * The test suite tried to see if it is run under bash, but the check
+   itself failed under some other implementations of shell (notably
+   under NetBSD).  This has been corrected.
+   (merge 54ea72f09c sg/test-bash-version-fix later to maint).
+
+ * "git gc" and "git repack" did not close the open packfiles that
+   they found unneeded before removing them, which didn't work on a
+   platform incapable of removing an open file.  This has been
+   corrected.
+   (merge 5bdece0d70 js/gc-repack-close-before-remove later to maint).
+
+ * The code to drive GIT_EXTERNAL_DIFF command relied on the string
+   returned from getenv() to be non-volatile, which is not true, that
+   has been corrected.
+   (merge 6776a84dae kg/external-diff-save-env later to maint).
+
+ * There were many places the code relied on the string returned from
+   getenv() to be non-volatile, which is not true, that have been
+   corrected.
+   (merge 0da0e9268b jk/save-getenv-result later to maint).
+
+ * The v2 upload-pack protocol implementation failed to honor
+   hidden-ref configuration, which has been corrected.
+   (merge e20b4192a3 jk/proto-v2-hidden-refs-fix later to maint).
+
+ * "git fetch --recurse-submodules" may not fetch the necessary commit
+   that is bound to the superproject, which is getting corrected.
+   (merge be76c21282 sb/submodule-recursive-fetch-gets-the-tip later to maint).
+
+ * "git rebase" internally runs "checkout" to switch between branches,
+   and the command used to call the post-checkout hook, but the
+   reimplementation stopped doing so, which is getting fixed.
+
+ * "git add -e" got confused when the change it wants to let the user
+   edit is smaller than the previous change that was left over in a
+   temporary file.
+   (merge fa6f225e01 js/add-e-clear-patch-before-stating later to maint).
+
+ * "git p4" failed to update a shelved change when there were moved
+   files, which has been corrected.
+   (merge 7a10946ab9 ld/git-p4-shelve-update-fix later to maint).
+
+ * The codepath to read from the commit-graph file attempted to read
+   past the end of it when the file's table-of-contents was corrupt.
+
+ * The compat/obstack code had casts that -Wcast-function-type
+   compilation option found questionable.
+   (merge 764473d257 sg/obstack-cast-function-type-fix later to maint).
+
+ * An obvious typo in an assertion error message has been fixed.
+   (merge 3c27e2e059 cc/test-ref-store-typofix later to maint).
+
+ * In Git for Windows, "git clone \\server\share\path" etc. that uses
+   UNC paths from command line had bad interaction with its shell
+   emulation.
+
+ * "git add --ignore-errors" did not work as advertised and instead
+   worked as an unintended synonym for "git add --renormalize", which
+   has been fixed.
+   (merge e2c2a37545 jk/add-ignore-errors-bit-assignment-fix later to maint).
+
+ * On a case-insensitive filesystem, we failed to compare the part of
+   the path that is above the worktree directory in an absolute
+   pathname, which has been corrected.
+
+ * Asking "git check-attr" about a macro (e.g. "binary") on a specific
+   path did not work correctly, even though "git check-attr -a" listed
+   such a macro correctly.  This has been corrected.
+   (merge 7b95849be4 jk/attr-macro-fix later to maint).
+
+ * "git pack-objects" incorrectly used uninitialized mutex, which has
+   been corrected.
+   (merge edb673cf10 ph/pack-objects-mutex-fix later to maint).
+
+ * "git checkout -b <new> [HEAD]" to create a new branch from the
+   current commit and check it out ought to be a no-op in the index
+   and the working tree in normal cases, but there are corner cases
+   that do require updates to the index and the working tree.  Running
+   it immediately after "git clone --no-checkout" is one of these
+   cases that an earlier optimization kicked in incorrectly, which has
+   been fixed.
+   (merge 8424bfd45b bp/checkout-new-branch-optim later to maint).
+
+ * "git diff --color-moved --cc --stat -p" did not work well due to
+   funny interaction between a bug in color-moved and the rest, which
+   has been fixed.
+   (merge dac03b5518 jk/diff-cc-stat-fixes later to maint).
+
+ * When GIT_SEQUENCE_EDITOR is set, the command was incorrectly
+   started when modes of "git rebase" that implicitly uses the
+   machinery for the interactive rebase are run, which has been
+   corrected.
+   (merge 891d4a0313 pw/no-editor-in-rebase-i-implicit later to maint).
+
+ * The commit-graph facility did not work when in-core objects that
+   are promoted from unknown type to commit (e.g. a commit that is
+   accessed via a tag that refers to it) were involved, which has been
+   corrected.
+   (merge 4468d4435c sg/object-as-type-commit-graph-fix later to maint).
+
+ * "git fetch" output cleanup.
+   (merge dc40b24df4 nd/fetch-compact-update later to maint).
+
+ * "git cat-file --batch" reported a dangling symbolic link by
+   mistake, when it wanted to report that a given name is ambiguous.
+
+ * Documentation around core.crlf has been updated.
+   (merge c9446f0504 jk/autocrlf-overrides-eol-doc later to maint).
+
+ * The documentation of "git commit-tree" said that the command
+   understands "--gpg-sign" in addition to "-S", but the command line
+   parser did not know about the longhand, which has been corrected.
+
+ * "git rebase -x $cmd" did not reject multi-line command, even though
+   the command is incapable of handling such a command.  It now is
+   rejected upfront.
+   (merge c762aada1a pw/rebase-x-sanity-check later to maint).
+
+ * Output from "git help" was not correctly aligned, which has been
+   fixed.
+   (merge 6195a76da4 nd/help-align-command-desc later to maint).
+
+ * The "git submodule summary" subcommand showed shortened commit
+   object names by mechanically truncating them at 7-hexdigit, which
+   has been improved to let "rev-parse --short" scale the length of
+   the abbreviation with the size of the repository.
+   (merge 0586a438f6 sh/submodule-summary-abbrev-fix later to maint).
+
+ * The way the OSX build jobs updates its build environment used the
+   "--quiet" option to "brew update" command, but it wasn't all that
+   quiet to be useful.  The use of the option has been replaced with
+   an explicit redirection to the /dev/null (which incidentally would
+   have worked around a breakage by recent updates to homebrew, which
+   has fixed itself already).
+   (merge a1ccaedd62 sg/travis-osx-brew-breakage-workaround later to maint).
+
+ * "git --work-tree=$there --git-dir=$here describe --dirty" did not
+   work correctly as it did not pay attention to the location of the
+   worktree specified by the user by mistake, which has been
+   corrected.
+   (merge c801170b0c ss/describe-dirty-in-the-right-directory later to maint).
+
+ * "git fetch" over protocol v2 that needs to make a second connection
+   to backfill tags did not clear a variable that holds shallow
+   repository information correctly, leading to an access of freed
+   piece of memory.
+
+ * Some errors from the other side coming over smart HTTP transport
+   were not noticed, which has been corrected.
+
+ * Code cleanup, docfix, build fix, etc.
+   (merge 89ba9a79ae hb/t0061-dot-in-path-fix later to maint).
+   (merge d173e799ea sb/diff-color-moved-config-option-fixup later to maint).
+   (merge a8f5a59067 en/directory-renames-nothanks-doc-update later to maint).
+   (merge ec36c42a63 nd/indentation-fix later to maint).
+   (merge f116ee21cd do/gitweb-strict-export-conf-doc later to maint).
+   (merge 112ea42663 fd/gitweb-snapshot-conf-doc-fix later to maint).
+   (merge 1cadad6f65 tb/use-common-win32-pathfuncs-on-cygwin later to maint).
+   (merge 57e9dcaa65 km/rebase-doc-typofix later to maint).
+   (merge b8b4cb27e6 ds/gc-doc-typofix later to maint).
+   (merge 3b3357626e nd/style-opening-brace later to maint).
+   (merge b4583d5595 es/doc-worktree-guessremote-config later to maint).
+   (merge cce99cd8c6 ds/commit-graph-assert-missing-parents later to maint).
+   (merge 0650614982 cy/completion-typofix later to maint).
+   (merge 6881925ef5 rs/sha1-file-close-mapped-file-on-error later to maint).
+   (merge bd8d6f0def en/show-ref-doc-fix later to maint).
+   (merge 1747125e2c cc/partial-clone-doc-typofix later to maint).
+   (merge e01378753d cc/fetch-error-message-fix later to maint).
+   (merge 54e8c11215 jk/remote-insteadof-cleanup later to maint).
+   (merge d609615f48 js/test-git-installed later to maint).
+   (merge ba170517be ja/doc-style-fix later to maint).
+   (merge 86fb1c4e77 km/init-doc-typofix later to maint).
+   (merge 5cfd4a9d10 nd/commit-doc later to maint).
+   (merge 9fce19a431 ab/diff-tree-doc-fix later to maint).
+   (merge 2e285e7803 tz/gpg-test-fix later to maint).
+   (merge 5427de960b kl/pretty-doc-markup-fix later to maint).
+   (merge 3815f64b0d js/mingw-host-cpu later to maint).
+   (merge 5fe81438b5 rj/sequencer-sign-off-header-static later to maint).
+   (merge 18a4f6be6b nd/fileno-may-be-macro later to maint).
+   (merge 99e9ab54ab kd/t0028-octal-del-is-377-not-777 later to maint).
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/RelNotes/2.21.1.txt 1.2.3+git2.25.1-1/git/Documentation/RelNotes/2.21.1.txt
--- 1.2.1+git2.18.0-1/git/Documentation/RelNotes/2.21.1.txt	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/RelNotes/2.21.1.txt	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,12 @@
+Git v2.21.1 Release Notes
+=========================
+
+This release merges up the fixes that appear in v2.14.6, v2.15.4,
+v2.17.3 and in v2.20.2, addressing the security issues CVE-2019-1348,
+CVE-2019-1349, CVE-2019-1350, CVE-2019-1351, CVE-2019-1352,
+CVE-2019-1353, CVE-2019-1354, CVE-2019-1387, and CVE-2019-19604;
+see the release notes for those versions for details.
+
+Additionally, this version also includes a couple of fixes for the
+Windows-specific quoting of command-line arguments when Git executes
+a Unix shell on Windows.
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/RelNotes/2.22.0.txt 1.2.3+git2.25.1-1/git/Documentation/RelNotes/2.22.0.txt
--- 1.2.1+git2.18.0-1/git/Documentation/RelNotes/2.22.0.txt	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/RelNotes/2.22.0.txt	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,597 @@
+Git 2.22 Release Notes
+======================
+
+Updates since v2.21
+-------------------
+
+Backward compatibility note
+
+ * The filter specification "--filter=sparse:path=<path>" used to
+   create a lazy/partial clone has been removed.  Using a blob that is
+   part of the project as sparse specification is still supported with
+   the "--filter=sparse:oid=<blob>" option.
+
+UI, Workflows & Features
+
+ * "git checkout --no-overlay" can be used to trigger a new mode of
+   checking out paths out of the tree-ish, that allows paths that
+   match the pathspec that are in the current index and working tree
+   and are not in the tree-ish.
+
+ * The %(trailers) formatter in "git log --format=..."  now allows to
+   optionally pick trailers selectively by keyword, show only values,
+   etc.
+
+ * Four new configuration variables {author,committer}.{name,email}
+   have been introduced to override user.{name,email} in more specific
+   cases.
+
+ * Command-line completion (in contrib/) learned to tab-complete the
+   "git submodule absorbgitdirs" subcommand.
+
+ * "git branch" learned a new subcommand "--show-current".
+
+ * Output from "diff --cc" did not show the original paths when the
+   merge involved renames.  A new option adds the paths in the
+   original trees to the output.
+
+ * The command line completion (in contrib/) has been taught to
+   complete more subcommand parameters.
+
+ * The final report from "git bisect" used to show the suspected
+   culprit using a raw "diff-tree", with which there is no output for
+   a merge commit.  This has been updated to use a more modern and
+   human readable output that still is concise enough.
+
+ * "git rebase --rebase-merges" replaces its old "--preserve-merges"
+   option; the latter is now marked as deprecated.
+
+ * Error message given while cloning with --recurse-submodules has
+   been updated.
+
+ * The completion helper code now pays attention to repository-local
+   configuration (when available), which allows --list-cmds to honour
+   a repository specific setting of completion.commands, for example.
+
+ * "git mergetool" learned to offer Sublime Merge (smerge) as one of
+   its backends.
+
+ * A new hook "post-index-change" is called when the on-disk index
+   file changes, which can help e.g. a virtualized working tree
+   implementation.
+
+ * "git difftool" can now run outside a repository.
+
+ * "git checkout -m <other>" was about carrying the differences
+   between HEAD and the working-tree files forward while checking out
+   another branch, and ignored the differences between HEAD and the
+   index.  The command has been taught to abort when the index and the
+   HEAD are different.
+
+ * A progress indicator has been added to the "index-pack" step, which
+   often makes users wait for completion during "git clone".
+
+ * "git submodule" learns "set-branch" subcommand that allows the
+   submodule.*.branch settings to be modified.
+
+ * "git merge-recursive" backend recently learned a new heuristics to
+   infer file movement based on how other files in the same directory
+   moved.  As this is inherently less robust heuristics than the one
+   based on the content similarity of the file itself (rather than
+   based on what its neighbours are doing), it sometimes gives an
+   outcome unexpected by the end users.  This has been toned down to
+   leave the renamed paths in higher/conflicted stages in the index so
+   that the user can examine and confirm the result.
+
+ * "git tag" learned to give an advice suggesting it might be a
+   mistake when creating an annotated or signed tag that points at
+   another tag.
+
+ * The "git pack-objects" command learned to report the number of
+   objects it packed via the trace2 mechanism.
+
+ * The list of conflicted paths shown in the editor while concluding a
+   conflicted merge was shown above the scissors line when the
+   clean-up mode is set to "scissors", even though it was commented
+   out just like the list of updated paths and other information to
+   help the user explain the merge better.
+
+ * The trace2 tracing facility learned to auto-generate a filename
+   when told to log to a directory.
+
+ * "git clone" learned a new --server-option option when talking over
+   the protocol version 2.
+
+ * The connectivity bitmaps are created by default in bare
+   repositories now; also the pathname hash-cache is created by
+   default to avoid making crappy deltas when repacking.
+
+ * "git branch new A...B" and "git checkout -b new A...B" have been
+   taught that in their contexts, the notation A...B means "the merge
+   base between these two commits", just like "git checkout A...B"
+   detaches HEAD at that commit.
+
+ * Update "git difftool" and "git mergetool" so that the combinations
+   of {diff,merge}.{tool,guitool} configuration variables serve as
+   fallback settings of each other in a sensible order.
+
+ * The "--dir-diff" mode of "git difftool" is not useful in "--no-index"
+   mode; they are now explicitly marked as mutually incompatible.
+
+
+Performance, Internal Implementation, Development Support etc.
+
+ * The diff machinery, one of the oldest parts of the system, which
+   long predates the parse-options API, uses fairly long and complex
+   handcrafted option parser.  This is being rewritten to use the
+   parse-options API.
+
+ * The implementation of pack-redundant has been updated for
+   performance in a repository with many packfiles.
+
+ * A more structured way to obtain execution trace has been added.
+
+ * "git prune" has been taught to take advantage of reachability
+   bitmap when able.
+
+ * The command line parser of "git commit-tree" has been rewritten to
+   use the parse-options API.
+
+ * Suggest GitGitGadget instead of submitGit as a way to submit
+   patches based on GitHub PR to us.
+
+ * The test framework has been updated to help developers by making it
+   easier to run most of the tests under different versions of
+   over-the-wire protocols.
+
+ * Dev support update to make it easier to compare two formatted
+   results from our documentation.
+
+ * The scripted "git rebase" implementation has been retired.
+
+ * "git multi-pack-index verify" did not scale well with the number of
+   packfiles, which is being improved.
+
+ * "git stash" has been rewritten in C.
+
+ * The "check-docs" Makefile target to support developers has been
+   updated.
+
+ * The tests have been updated not to rely on the abbreviated option
+   names the parse-options API offers, to protect us from an
+   abbreviated form of an option that used to be unique within the
+   command getting non-unique when a new option that share the same
+   prefix is added.
+
+ * The scripted version of "git rebase -i" wrote and rewrote the todo
+   list many times during a single step of its operation, and the
+   recent C-rewrite made a faithful conversion of the logic to C.  The
+   implementation has been updated to carry necessary information
+   around in-core to avoid rewriting the same file over and over
+   unnecessarily.
+
+ * Test framework update to more robustly clean up leftover files and
+   processes after tests are done.
+
+ * Conversion from unsigned char[20] to struct object_id continues.
+
+ * While running "git diff" in a lazy clone, we can upfront know which
+   missing blobs we will need, instead of waiting for the on-demand
+   machinery to discover them one by one.  The code learned to aim to
+   achieve better performance by batching the request for these
+   promised blobs.
+
+ * During an initial "git clone --depth=..." partial clone, it is
+   pointless to spend cycles for a large portion of the connectivity
+   check that enumerates and skips promisor objects (which by
+   definition is all objects fetched from the other side).  This has
+   been optimized out.
+
+ * Mechanically and systematically drop "extern" from function
+   declaration.
+
+ * The script to aggregate perf result unconditionally depended on
+   libjson-perl even though it did not have to, which has been
+   corrected.
+
+ * The internal implementation of "git rebase -i" has been updated to
+   avoid forking a separate "rebase--interactive" process.
+
+ * Allow DEP and ASLR for Windows build to for security hardening.
+
+ * Performance test framework has been broken and measured the version
+   of Git that happens to be on $PATH, not the specified one to
+   measure, for a while, which has been corrected.
+
+ * Optionally "make coccicheck" can feed multiple source files to
+   spatch, gaining performance while spending more memory.
+
+ * Attempt to use an abbreviated option in "git clone --recurs" is
+   responded by a request to disambiguate between --recursive and
+   --recurse-submodules, which is bad because these two are synonyms.
+   The parse-options API has been extended to define such synonyms
+   more easily and not produce an unnecessary failure.
+
+ * A pair of private functions in http.c that had names similar to
+   fread/fwrite did not return the number of elements, which was found
+   to be confusing.
+
+ * Update collision-detecting SHA-1 code to build properly on HP-UX.
+
+
+Fixes since v2.21
+-----------------
+
+ * "git prune-packed" did not notice and complain against excess
+   arguments given from the command line, which now it does.
+   (merge 9b0bd87ed2 rj/prune-packed-excess-args later to maint).
+
+ * Split-index fix.
+   (merge 6e37c8ed3c nd/split-index-null-base-fix later to maint).
+
+ * "git diff --no-index" may still want to access Git goodies like
+   --ext-diff and --textconv, but so far these have been ignored,
+   which has been corrected.
+   (merge 287ab28bfa jk/diff-no-index-initialize later to maint).
+
+ * Unify RPC code for smart http in protocol v0/v1 and v2, which fixes
+   a bug in the latter (lack of authentication retry) and generally
+   improves the code base.
+   (merge a97d00799a jt/http-auth-proto-v2-fix later to maint).
+
+ * The include file compat/bswap.h has been updated so that it is safe
+   to (accidentally) include it more than once.
+   (merge 33aa579a55 jk/guard-bswap-header later to maint).
+
+ * The set of header files used by "make hdr-check" unconditionally
+   included sha256/gcrypt.h, even when it is not used, causing the
+   make target to fail.  We now skip it when GCRYPT_SHA256 is not in
+   use.
+   (merge f23aa18e7f rj/hdr-check-gcrypt-fix later to maint).
+
+ * The Makefile uses 'find' utility to enumerate all the *.h header
+   files, which is expensive on platforms with slow filesystems; it
+   now optionally uses "ls-files" if working within a repository,
+   which is a trick similar to how all sources are enumerated to run
+   ETAGS on.
+   (merge 92b88eba9f js/find-lib-h-with-ls-files-when-possible later to maint).
+
+ * "git rebase" that was reimplemented in C did not set ORIG_HEAD
+   correctly, which has been corrected.
+   (merge cbd29ead92 js/rebase-orig-head-fix later to maint).
+
+ * Dev support.
+   (merge f545737144 js/stress-test-ui-tweak later to maint).
+
+ * CFLAGS now can be tweaked when invoking Make while using
+   DEVELOPER=YesPlease; this did not work well before.
+   (merge 6d5d4b4e93 ab/makefile-help-devs-more later to maint).
+
+ * "git fsck --connectivity-only" omits computation necessary to sift
+   the objects that are not reachable from any of the refs into
+   unreachable and dangling.  This is now enabled when dangling
+   objects are requested (which is done by default, but can be
+   overridden with the "--no-dangling" option).
+   (merge 8d8c2a5aef jk/fsck-doc later to maint).
+
+ * On platforms where "git fetch" is killed with SIGPIPE (e.g. OSX),
+   the upload-pack that runs on the other end that hangs up after
+   detecting an error could cause "git fetch" to die with a signal,
+   which led to a flaky test.  "git fetch" now ignores SIGPIPE during
+   the network portion of its operation (this is not a problem as we
+   check the return status from our write(2)s).
+   (merge 143588949c jk/no-sigpipe-during-network-transport later to maint).
+
+ * A recent update broke "is this object available to us?" check for
+   well-known objects like an empty tree (which should yield "yes",
+   even when there is no on-disk object for an empty tree), which has
+   been corrected.
+   (merge f06ab027ef jk/virtual-objects-do-exist later to maint).
+
+ * The setup code has been cleaned up to avoid leaks around the
+   repository_format structure.
+   (merge e8805af1c3 ma/clear-repository-format later to maint).
+
+ * "git config --type=color ..." is meant to replace "git config --get-color"
+   but there is a slight difference that wasn't documented, which is
+   now fixed.
+   (merge cd8e7593b9 jk/config-type-color-ends-with-lf later to maint).
+
+ * When the "clean" filter can reduce the size of a huge file in the
+   working tree down to a small "token" (a la Git LFS), there is no
+   point in allocating a huge scratch area upfront, but the buffer is
+   sized based on the original file size.  The convert mechanism now
+   allocates very minimum and reallocates as it receives the output
+   from the clean filter process.
+   (merge 02156ab031 jh/resize-convert-scratch-buffer later to maint).
+
+ * "git rebase" uses the refs/rewritten/ hierarchy to store its
+   intermediate states, which inherently makes the hierarchy per
+   worktree, but it didn't quite work well.
+   (merge b9317d55a3 nd/rewritten-ref-is-per-worktree later to maint).
+
+ * "git log -L<from>,<to>:<path>" with "-s" did not suppress the patch
+   output as it should.  This has been corrected.
+   (merge 05314efaea jk/line-log-with-patch later to maint).
+
+ * "git worktree add" used to do a "find an available name with stat
+   and then mkdir", which is race-prone.  This has been fixed by using
+   mkdir and reacting to EEXIST in a loop.
+   (merge 7af01f2367 ms/worktree-add-atomic-mkdir later to maint).
+
+ * Build update for SHA-1 with collision detection.
+   (merge 07a20f569b jk/sha1dc later to maint).
+
+ * Build procedure has been fixed around use of asciidoctor instead of
+   asciidoc.
+   (merge 185f9a0ea0 ma/asciidoctor-fixes later to maint).
+
+ * remote-http transport did not anonymize URLs reported in its error
+   messages at places.
+   (merge c1284b21f2 js/anonymize-remote-curl-diag later to maint).
+
+ * Error messages given from the http transport have been updated so
+   that they can be localized.
+   (merge ed8b4132c8 js/remote-curl-i18n later to maint).
+
+ * "git init" forgot to read platform-specific repository
+   configuration, which made Windows port to ignore settings of
+   core.hidedotfiles, for example.
+
+ * A corner-case object name ambiguity while the sequencer machinery
+   is working (e.g. "rebase -i -x") has been fixed.
+
+ * "git format-patch" did not diagnose an error while opening the
+   output file for the cover-letter, which has been corrected.
+   (merge 2fe95f494c jc/format-patch-error-check later to maint).
+
+ * "git checkout -f <branch>" while the index has an unmerged path
+   incorrectly left some paths in an unmerged state, which has been
+   corrected.
+
+ * A corner case bug in the refs API has been corrected.
+   (merge d3322eb28b jk/refs-double-abort later to maint).
+
+ * Unicode update.
+   (merge 584b62c37b bb/unicode-12 later to maint).
+
+ * dumb-http walker has been updated to share more error recovery
+   strategy with the normal codepath.
+
+ * A buglet in configuration parser has been fixed.
+   (merge 19e7fdaa58 nd/include-if-wildmatch later to maint).
+
+ * The documentation for "git read-tree --reset -u" has been updated.
+   (merge b5a0bd694c nd/read-tree-reset-doc later to maint).
+
+ * Code clean-up around a much-less-important-than-it-used-to-be
+   update_server_info() function.
+   (merge b3223761c8 jk/server-info-rabbit-hole later to maint).
+
+ * The message given when "git commit -a <paths>" errors out has been
+   updated.
+   (merge 5a1dbd48bc nd/commit-a-with-paths-msg-update later to maint).
+
+ * "git cherry-pick --options A..B", after giving control back to the
+   user to ask help resolving a conflicted step, did not honor the
+   options it originally received, which has been corrected.
+
+ * Various glitches in "git gc" around reflog handling have been fixed.
+
+ * The code to read from commit-graph file has been cleanup with more
+   careful error checking before using data read from it.
+
+ * Performance fix around "git fetch" that grabs many refs.
+   (merge b764300912 jt/fetch-pack-wanted-refs-optim later to maint).
+
+ * Protocol v2 support in "git fetch-pack" of shallow clones has been
+   corrected.
+
+ * Performance fix around "git blame", especially in a linear history
+   (which is the norm we should optimize for).
+   (merge f892014943 dk/blame-keep-origin-blob later to maint).
+
+ * Performance fix for "rev-list --parents -- pathspec".
+   (merge 8320b1dbe7 jk/revision-rewritten-parents-in-prio-queue later to maint).
+
+ * Updating the display with progress message has been cleaned up to
+   deal better with overlong messages.
+   (merge 545dc345eb sg/overlong-progress-fix later to maint).
+
+ * "git blame -- path" in a non-bare repository starts blaming from
+   the working tree, and the same command in a bare repository errors
+   out because there is no working tree by definition.  The command
+   has been taught to instead start blaming from the commit at HEAD,
+   which is more useful.
+   (merge a544fb08f8 sg/blame-in-bare-start-at-head later to maint).
+
+ * An underallocation in the code to read the untracked cache
+   extension has been corrected.
+   (merge 3a7b45a623 js/untracked-cache-allocfix later to maint).
+
+ * The code is updated to check the result of memory allocation before
+   it is used in more places, by using xmalloc and/or xcalloc calls.
+   (merge 999b951b28 jk/xmalloc later to maint).
+
+ * The GETTEXT_POISON test option has been quite broken ever since it
+   was made runtime-tunable, which has been fixed.
+   (merge f88b9cb603 jc/gettext-test-fix later to maint).
+
+ * Test fix on APFS that is incapable of store paths in Latin-1.
+   (merge 3889149619 js/iso8895-test-on-apfs later to maint).
+
+ * "git submodule foreach <command> --quiet" did not pass the option
+   down correctly, which has been corrected.
+   (merge a282f5a906 nd/submodule-foreach-quiet later to maint).
+
+ * "git send-email" has been taught to use quoted-printable when the
+   payload contains carriage-return.  The use of the mechanism is in
+   line with the design originally added the codepath that chooses QP
+   when the payload has overly long lines.
+   (merge 74d76a1701 bc/send-email-qp-cr later to maint).
+
+ * The recently added feature to add addresses that are on
+   anything-by: trailers in 'git send-email' was found to be way too
+   eager and considered nonsense strings as if they can be legitimate
+   beginning of *-by: trailer.  This has been tightened.
+
+ * Builds with gettext broke on recent macOS w/ Homebrew, which
+   seems to have stopped including from /usr/local/include; this
+   has been corrected.
+   (merge 92a1377a2a js/macos-gettext-build later to maint).
+
+ * Running "git add" on a repository created inside the current
+   repository is an explicit indication that the user wants to add it
+   as a submodule, but when the HEAD of the inner repository is on an
+   unborn branch, it cannot be added as a submodule.  Worse, the files
+   in its working tree can be added as if they are a part of the outer
+   repository, which is not what the user wants.  These problems are
+   being addressed.
+   (merge f937bc2f86 km/empty-repo-is-still-a-repo later to maint).
+
+ * "git cherry-pick" run with the "-x" or the "--signoff" option used
+   to (and more importantly, ought to) clean up the commit log message
+   with the --cleanup=space option by default, but this has been
+   broken since late 2017.  This has been fixed.
+
+ * When given a tag that points at a commit-ish, "git replace --graft"
+   failed to peel the tag before writing a replace ref, which did not
+   make sense because the old graft mechanism the feature wants to
+   mimic only allowed to replace one commit object with another.
+   This has been fixed.
+   (merge ee521ec4cb cc/replace-graft-peel-tags later to maint).
+
+ * Code tightening against a "wrong" object appearing where an object
+   of a different type is expected, instead of blindly assuming that
+   the connection between objects are correctly made.
+   (merge 97dd512af7 tb/unexpected later to maint).
+
+ * An earlier update for MinGW and Cygwin accidentally broke MSVC build,
+   which has been fixed.
+   (merge 22c3634c0f ss/msvc-path-utils-fix later to maint).
+
+ * %(push:track) token used in the --format option to "git
+   for-each-ref" and friends was not showing the right branch, which
+   has been fixed.
+   (merge c646d0934e dr/ref-filter-push-track-fix later to maint).
+
+ * "make check-docs", "git help -a", etc. did not account for cases
+   where a particular build may deliberately omit some subcommands,
+   which has been corrected.
+
+ * The logic to tell if a Git repository has a working tree protects
+   "git branch -D" from removing the branch that is currently checked
+   out by mistake.  The implementation of this logic was broken for
+   repositories with unusual name, which unfortunately is the norm for
+   submodules these days.  This has been fixed.
+   (merge f3534c98e4 jt/submodule-repo-is-with-worktree later to maint).
+
+ * AIX shared the same build issues with other BSDs around fileno(fp),
+   which has been corrected.
+   (merge ee662bf5c6 cc/aix-has-fileno-as-a-macro later to maint).
+
+ * The autoconf generated configure script failed to use the right
+   gettext() implementations from -libintl by ignoring useless stub
+   implementations shipped in some C library, which has been
+   corrected.
+   (merge b71e56a683 vk/autoconf-gettext later to maint).
+
+ * Fix index-pack perf test so that the repeated invocations always
+   run in an empty repository, which emulates the initial clone
+   situation better.
+   (merge 775c71e16d jk/p5302-avoid-collision-check-cost later to maint).
+
+ * A "ls-files" that emulates "find" to enumerate files in the working
+   tree resulted in duplicated Makefile rules that caused the build to
+   issue an unnecessary warning during a trial build after merge
+   conflicts are resolved in working tree *.h files but before the
+   resolved results are added to the index.  This has been corrected.
+
+ * "git cherry-pick" (and "revert" that shares the same runtime engine)
+   that deals with multiple commits got confused when the final step
+   gets stopped with a conflict and the user concluded the sequence
+   with "git commit".  Attempt to fix it by cleaning up the state
+   files used by these commands in such a situation.
+   (merge 4a72486de9 pw/clean-sequencer-state-upon-final-commit later to maint).
+
+ * On a filesystem like HFS+, the names of the refs stored as filesystem
+   entities may become different from what the end-user expects, just
+   like files in the working tree get "renamed".  Work around the
+   mismatch by paying attention to the core.precomposeUnicode
+   configuration.
+   (merge 8e712ef6fc en/unicode-in-refnames later to maint).
+
+ * The code to generate the multi-pack idx file was not prepared to
+   see too many packfiles and ran out of open file descriptor, which
+   has been corrected.
+
+ * To run tests for Git SVN, our scripts for CI used to install the
+   git-svn package (in the hope that it would bring in the right
+   dependencies).  This has been updated to install the more direct
+   dependency, namely, libsvn-perl.
+   (merge db864306cf sg/ci-libsvn-perl later to maint).
+
+ * "git cvsexportcommit" running on msys did not expect cvsnt showed
+   "cvs status" output with CRLF line endings.
+
+ * The fsmonitor interface got out of sync after the in-core index
+   file gets discarded, which has been corrected.
+   (merge 398a3b0899 js/fsmonitor-refresh-after-discarding-index later to maint).
+
+ * "git status" did not know that the "label" instruction in the
+   todo-list "rebase -i -r" uses should not be shown as a hex object
+   name.
+
+ * A prerequisite check in the test suite to see if a working jgit is
+   available was made more robust.
+   (merge abd0f28983 tz/test-lib-check-working-jgit later to maint).
+
+ * The codepath to parse :<path> that obtains the object name for an
+   indexed object has been made more robust.
+
+ * Code cleanup, docfix, build fix, etc.
+   (merge 11f470aee7 jc/test-yes-doc later to maint).
+   (merge 90503a240b js/doc-symref-in-proto-v1 later to maint).
+   (merge 5c326d1252 jk/unused-params later to maint).
+   (merge 68cabbfda3 dl/doc-submodule-wo-subcommand later to maint).
+   (merge 9903623761 ab/receive-pack-use-after-free-fix later to maint).
+   (merge 1ede45e44b en/merge-options-doc later to maint).
+   (merge 3e14dd2c8e rd/doc-hook-used-in-sample later to maint).
+   (merge c271dc28fd nd/no-more-check-racy later to maint).
+   (merge e6e15194a8 yb/utf-16le-bom-spellfix later to maint).
+   (merge bb101aaf0c rd/attr.c-comment-typofix later to maint).
+   (merge 716a5af812 rd/gc-prune-doc-fix later to maint).
+   (merge 50b206371d js/untravis-windows later to maint).
+   (merge dbf47215e3 js/rebase-recreate-merge later to maint).
+   (merge 56cb2d30f8 dl/reset-doc-no-wrt-abbrev later to maint).
+   (merge 64eca306a2 ja/dir-rename-doc-markup-fix later to maint).
+   (merge af91b0230c dl/ignore-docs later to maint).
+   (merge 59a06e947b ra/t3600-test-path-funcs later to maint).
+   (merge e041d0781b ar/t4150-remove-cruft later to maint).
+   (merge 8d75a1d183 ma/asciidoctor-fixes-more later to maint).
+   (merge 74cc547b0f mh/pack-protocol-doc-fix later to maint).
+   (merge ed31851fa6 ab/doc-misc-typofixes later to maint).
+   (merge a7256debd4 nd/checkout-m-doc-update later to maint).
+   (merge 3a9e1ad78d jt/t5551-protocol-v2-does-not-have-half-auth later to maint).
+   (merge 0b918b75af sg/t5318-cleanup later to maint).
+   (merge 68ed71b53c cb/doco-mono later to maint).
+   (merge a34dca2451 nd/interpret-trailers-docfix later to maint).
+   (merge cf7b857a77 en/fast-import-parsing-fix later to maint).
+   (merge fe61ccbc35 po/rerere-doc-fmt later to maint).
+   (merge ffea0248bf po/describe-not-necessarily-7 later to maint).
+   (merge 7cb7283adb tg/ls-files-debug-format-fix later to maint).
+   (merge f64a21bd82 tz/doc-apostrophe-no-longer-needed later to maint).
+   (merge dbe7b41019 js/t3301-unbreak-notes-test later to maint).
+   (merge d8083e4180 km/t3000-retitle later to maint).
+   (merge 9e4cbccbd7 tz/git-svn-doc-markup-fix later to maint).
+   (merge da9ca955a7 jk/ls-files-doc-markup-fix later to maint).
+   (merge 6804ba3a58 cw/diff-highlight later to maint).
+   (merge 1a8787144d nd/submodule-helper-incomplete-line-fix later to maint).
+   (merge d9ef573837 jk/apache-lsan later to maint).
+   (merge c871fbee2b js/t6500-use-windows-pid-on-mingw later to maint).
+   (merge ce4c7bfc90 bl/t4253-exit-code-from-format-patch later to maint).
+   (merge 397a46db78 js/t5580-unc-alternate-test later to maint).
+   (merge d4907720a2 cm/notes-comment-fix later to maint).
+   (merge 9dde06de13 cb/http-push-null-in-message-fix later to maint).
+   (merge 4c785c0edc js/rebase-config-bitfix later to maint).
+   (merge 8e9fe16c87 es/doc-gitsubmodules-markup later to maint).
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/RelNotes/2.22.1.txt 1.2.3+git2.25.1-1/git/Documentation/RelNotes/2.22.1.txt
--- 1.2.1+git2.18.0-1/git/Documentation/RelNotes/2.22.1.txt	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/RelNotes/2.22.1.txt	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,150 @@
+Git 2.22.1 Release Notes
+========================
+
+Fixes since v2.22
+-----------------
+
+ * A relative pathname given to "git init --template=<path> <repo>"
+   ought to be relative to the directory "git init" gets invoked in,
+   but it instead was made relative to the repository, which has been
+   corrected.
+
+ * "git worktree add" used to fail when another worktree connected to
+   the same repository was corrupt, which has been corrected.
+
+ * The ownership rule for the file descriptor to fast-import remote
+   backend was mixed up, leading to unrelated file descriptor getting
+   closed, which has been fixed.
+
+ * "git update-server-info" used to leave stale packfiles in its
+   output, which has been corrected.
+
+ * The server side support for "git fetch" used to show incorrect
+   value for the HEAD symbolic ref when the namespace feature is in
+   use, which has been corrected.
+
+ * "git am -i --resolved" segfaulted after trying to see a commit as
+   if it were a tree, which has been corrected.
+
+ * "git bundle verify" needs to see if prerequisite objects exist in
+   the receiving repository, but the command did not check if we are
+   in a repository upfront, which has been corrected.
+
+ * "git merge --squash" is designed to update the working tree and the
+   index without creating the commit, and this cannot be countermanded
+   by adding the "--commit" option; the command now refuses to work
+   when both options are given.
+
+ * The data collected by fsmonitor was not properly written back to
+   the on-disk index file, breaking t7519 tests occasionally, which
+   has been corrected.
+
+ * Update to Unicode 12.1 width table.
+
+ * The command line to invoke a "git cat-file" command from inside
+   "git p4" was not properly quoted to protect a caret and running a
+   broken command on Windows, which has been corrected.
+
+ * "git request-pull" learned to warn when the ref we ask them to pull
+   from in the local repository and in the published repository are
+   different.
+
+ * When creating a partial clone, the object filtering criteria is
+   recorded for the origin of the clone, but this incorrectly used a
+   hardcoded name "origin" to name that remote; it has been corrected
+   to honor the "--origin <name>" option.
+
+ * "git fetch" into a lazy clone forgot to fetch base objects that are
+   necessary to complete delta in a thin packfile, which has been
+   corrected.
+
+ * The filter_data used in the list-objects-filter (which manages a
+   lazily sparse clone repository) did not use the dynamic array API
+   correctly---'nr' is supposed to point at one past the last element
+   of the array in use.  This has been corrected.
+
+ * The description about slashes in gitignore patterns (used to
+   indicate things like "anchored to this level only" and "only
+   matches directories") has been revamped.
+
+ * The URL decoding code has been updated to avoid going past the end
+   of the string while parsing %-<hex>-<hex> sequence.
+
+ * The list of for-each like macros used by clang-format has been
+   updated.
+
+ * "git push --atomic" that goes over the transport-helper (namely,
+   the smart http transport) failed to prevent refs to be pushed when
+   it can locally tell that one of the ref update will fail without
+   having to consult the other end, which has been corrected.
+
+ * "git clean" silently skipped a path when it cannot lstat() it; now
+   it gives a warning.
+
+ * A codepath that reads from GPG for signed object verification read
+   past the end of allocated buffer, which has been fixed.
+
+ * "git rm" to resolve a conflicted path leaked an internal message
+   "needs merge" before actually removing the path, which was
+   confusing.  This has been corrected.
+
+ * The "git clone" documentation refers to command line options in its
+   description in the short form; they have been replaced with long
+   forms to make them more recognisable.
+
+ * The configuration variable rebase.rescheduleFailedExec should be
+   effective only while running an interactive rebase and should not
+   affect anything when running a non-interactive one, which was not
+   the case.  This has been corrected.
+
+ * "git submodule foreach" did not protect command line options passed
+   to the command to be run in each submodule correctly, when the
+   "--recursive" option was in use.
+
+ * Use "Erase in Line" CSI sequence that is already used in the editor
+   support to clear cruft in the progress output.
+
+ * The codepath to compute delta islands used to spew progress output
+   without giving the callers any way to squelch it, which has been
+   fixed.
+
+ * The code to parse scaled numbers out of configuration files has
+   been made more robust and also easier to follow.
+
+ * An incorrect list of options was cached after command line
+   completion failed (e.g. trying to complete a command that requires
+   a repository outside one), which has been corrected.
+
+ * "git rebase --abort" used to leave refs/rewritten/ when concluding
+   "git rebase -r", which has been corrected.
+
+ * "git stash show 23" used to work, but no more after getting
+   rewritten in C; this regression has been corrected.
+
+ * "git interpret-trailers" always treated '#' as the comment
+   character, regardless of core.commentChar setting, which has been
+   corrected.
+
+ * Code clean-up to avoid signed integer overlaps during binary search.
+
+ * "git checkout -p" needs to selectively apply a patch in reverse,
+   which did not work well.
+
+ * The commit-graph file is now part of the "files that the runtime
+   may keep open file descriptors on, all of which would need to be
+   closed when done with the object store", and the file descriptor to
+   an existing commit-graph file now is closed before "gc" finalizes a
+   new instance to replace it.
+
+ * Code restructuring during 2.20 period broke fetching tags via
+   "import" based transports.
+
+ * We have been trying out a few language features outside c89; the
+   coding guidelines document did not talk about them and instead had
+   a blanket ban against them.
+
+ * The internal diff machinery can be made to read out of bounds while
+   looking for --funcion-context line in a corner case, which has been
+   corrected.
+
+Also contains various documentation updates, code clean-ups and minor fixups.
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/RelNotes/2.22.2.txt 1.2.3+git2.25.1-1/git/Documentation/RelNotes/2.22.2.txt
--- 1.2.1+git2.18.0-1/git/Documentation/RelNotes/2.22.2.txt	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/RelNotes/2.22.2.txt	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,8 @@
+Git v2.22.2 Release Notes
+=========================
+
+This release merges up the fixes that appear in v2.14.6, v2.15.4,
+v2.17.3, v2.20.2 and in v2.21.1, addressing the security issues
+CVE-2019-1348, CVE-2019-1349, CVE-2019-1350, CVE-2019-1351,
+CVE-2019-1352, CVE-2019-1353, CVE-2019-1354, CVE-2019-1387, and
+CVE-2019-19604; see the release notes for those versions for details.
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/RelNotes/2.23.0.txt 1.2.3+git2.25.1-1/git/Documentation/RelNotes/2.23.0.txt
--- 1.2.1+git2.18.0-1/git/Documentation/RelNotes/2.23.0.txt	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/RelNotes/2.23.0.txt	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,348 @@
+Git 2.23 Release Notes
+======================
+
+Updates since v2.22
+-------------------
+
+Backward compatibility note
+
+ * The "--base" option of "format-patch" computed the patch-ids for
+   prerequisite patches in an unstable way, which has been updated to
+   compute in a way that is compatible with "git patch-id --stable".
+
+ * The "git log" command by default behaves as if the --mailmap option
+   was given.
+
+
+UI, Workflows & Features
+
+ * The "git fast-export/import" pair has been taught to handle commits
+   with log messages in encoding other than UTF-8 better.
+
+ * In recent versions of Git, per-worktree refs are exposed in
+   refs/worktrees/<wtname>/ hierarchy, which means that worktree names
+   must be a valid refname component.  The code now sanitizes the names
+   given to worktrees, to make sure these refs are well-formed.
+
+ * "git merge" learned "--quit" option that cleans up the in-progress
+   merge while leaving the working tree and the index still in a mess.
+
+ * "git format-patch" learns a configuration to set the default for
+   its --notes=<ref> option.
+
+ * The code to show args with potential typo that cannot be
+   interpreted as a commit-ish has been improved.
+
+ * "git clone --recurse-submodules" learned to set up the submodules
+   to ignore commit object names recorded in the superproject gitlink
+   and instead use the commits that happen to be at the tip of the
+   remote-tracking branches from the get-go, by passing the new
+   "--remote-submodules" option.
+
+ * The pattern "git diff/grep" use to extract funcname and words
+   boundary for Matlab has been extend to cover Octave, which is more
+   or less equivalent.
+
+ * "git help git" was hard to discover (well, at least for some
+   people).
+
+ * The pattern "git diff/grep" use to extract funcname and words
+   boundary for Rust has been added.
+
+ * "git status" can be told a non-standard default value for the
+   "--[no-]ahead-behind" option with a new configuration variable
+   status.aheadBehind.
+
+ * "git fetch" and "git pull" reports when a fetch results in
+   non-fast-forward updates to let the user notice unusual situation.
+   The commands learned "--no-show-forced-updates" option to disable
+   this safety feature.
+
+ * Two new commands "git switch" and "git restore" are introduced to
+   split "checking out a branch to work on advancing its history" and
+   "checking out paths out of the index and/or a tree-ish to work on
+   advancing the current history" out of the single "git checkout"
+   command.
+
+ * "git branch --list" learned to always output the detached HEAD as
+   the first item (when the HEAD is detached, of course), regardless
+   of the locale.
+
+ * The conditional inclusion mechanism learned to base the choice on
+   the branch the HEAD currently is on.
+
+ * "git rev-list --objects" learned the "--no-object-names" option to
+   squelch the path to the object that is used as a grouping hint for
+   pack-objects.
+
+ * A new tag.gpgSign configuration variable turns "git tag -a" into
+   "git tag -s".
+
+ * "git multi-pack-index" learned expire and repack subcommands.
+
+ * "git blame" learned to "ignore" commits in the history, whose
+   effects (as well as their presence) get ignored.
+
+ * "git cherry-pick/revert" learned a new "--skip" action.
+
+ * The tips of refs from the alternate object store can be used as
+   starting point for reachability computation now.
+
+ * Extra blank lines in "git status" output have been reduced.
+
+ * The commits in a repository can be described by multiple
+   commit-graph files now, which allows the commit-graph files to be
+   updated incrementally.
+
+ * "git range-diff" output has been tweaked for easier identification
+   of which part of what file the patch shown is about.
+
+
+Performance, Internal Implementation, Development Support etc.
+
+ * Update supporting parts of "git rebase" to remove code that should
+   no longer be used.
+
+ * Developer support to emulate unsatisfied prerequisites in tests to
+   ensure that the remainder of the tests still succeeds when tests
+   with prerequisites are skipped.
+
+ * "git update-server-info" learned not to rewrite the file with the
+   same contents.
+
+ * The way of specifying the path to find dynamic libraries at runtime
+   has been simplified.  The old default to pass -R/path/to/dir has been
+   replaced with the new default to pass -Wl,-rpath,/path/to/dir,
+   which is the more recent GCC uses.  Those who need to build with an
+   old GCC can still use "CC_LD_DYNPATH=-R"
+
+ * Prepare use of reachability index in topological walker that works
+   on a range (A..B).
+
+ * A new tutorial targeting specifically aspiring git-core
+   developers has been added.
+
+ * Auto-detect how to tell HP-UX aCC where to use dynamically linked
+   libraries from at runtime.
+
+ * "git mergetool" and its tests now spawn fewer subprocesses.
+
+ * Dev support update to help tracing out tests.
+
+ * Support to build with MSVC has been updated.
+
+ * "git fetch" that grabs from a group of remotes learned to run the
+   auto-gc only once at the very end.
+
+ * A handful of Windows build patches have been upstreamed.
+
+ * The code to read state files used by the sequencer machinery for
+   "git status" has been made more robust against a corrupt or stale
+   state files.
+
+ * "git for-each-ref" with multiple patterns have been optimized.
+
+ * The tree-walk API learned to pass an in-core repository
+   instance throughout more codepaths.
+
+ * When one step in multi step cherry-pick or revert is reset or
+   committed, the command line prompt script failed to notice the
+   current status, which has been improved.
+
+ * Many GIT_TEST_* environment variables control various aspects of
+   how our tests are run, but a few followed "non-empty is true, empty
+   or unset is false" while others followed the usual "there are a few
+   ways to spell true, like yes, on, etc., and also ways to spell
+   false, like no, off, etc." convention.
+
+ * Adjust the dir-iterator API and apply it to the local clone
+   optimization codepath.
+
+ * We have been trying out a few language features outside c89; the
+   coding guidelines document did not talk about them and instead had
+   a blanket ban against them.
+
+ * A test helper has been introduced to optimize preparation of test
+   repositories with many simple commits, and a handful of test
+   scripts have been updated to use it.
+
+
+Fixes since v2.22
+-----------------
+
+ * A relative pathname given to "git init --template=<path> <repo>"
+   ought to be relative to the directory "git init" gets invoked in,
+   but it instead was made relative to the repository, which has been
+   corrected.
+
+ * "git worktree add" used to fail when another worktree connected to
+   the same repository was corrupt, which has been corrected.
+
+ * The ownership rule for the file descriptor to fast-import remote
+   backend was mixed up, leading to an unrelated file descriptor getting
+   closed, which has been fixed.
+
+ * A "merge -c" instruction during "git rebase --rebase-merges" should
+   give the user a chance to edit the log message, even when there is
+   otherwise no need to create a new merge and replace the existing
+   one (i.e. fast-forward instead), but did not.  Which has been
+   corrected.
+
+ * Code cleanup and futureproof.
+
+ * More parameter validation.
+
+ * "git update-server-info" used to leave stale packfiles in its
+   output, which has been corrected.
+
+ * The server side support for "git fetch" used to show incorrect
+   value for the HEAD symbolic ref when the namespace feature is in
+   use, which has been corrected.
+
+ * "git am -i --resolved" segfaulted after trying to see a commit as
+   if it were a tree, which has been corrected.
+
+ * "git bundle verify" needs to see if prerequisite objects exist in
+   the receiving repository, but the command did not check if we are
+   in a repository upfront, which has been corrected.
+
+ * "git merge --squash" is designed to update the working tree and the
+   index without creating the commit, and this cannot be countermanded
+   by adding the "--commit" option; the command now refuses to work
+   when both options are given.
+
+ * The data collected by fsmonitor was not properly written back to
+   the on-disk index file, breaking t7519 tests occasionally, which
+   has been corrected.
+
+ * Update to Unicode 12.1 width table.
+
+ * The command line to invoke a "git cat-file" command from inside
+   "git p4" was not properly quoted to protect a caret and running a
+   broken command on Windows, which has been corrected.
+
+ * "git request-pull" learned to warn when the ref we ask them to pull
+   from in the local repository and in the published repository are
+   different.
+
+ * When creating a partial clone, the object filtering criteria is
+   recorded for the origin of the clone, but this incorrectly used a
+   hardcoded name "origin" to name that remote; it has been corrected
+   to honor the "--origin <name>" option.
+
+ * "git fetch" into a lazy clone forgot to fetch base objects that are
+   necessary to complete delta in a thin packfile, which has been
+   corrected.
+
+ * The filter_data used in the list-objects-filter (which manages a
+   lazily sparse clone repository) did not use the dynamic array API
+   correctly---'nr' is supposed to point at one past the last element
+   of the array in use.  This has been corrected.
+
+ * The description about slashes in gitignore patterns (used to
+   indicate things like "anchored to this level only" and "only
+   matches directories") has been revamped.
+
+ * The URL decoding code has been updated to avoid going past the end
+   of the string while parsing %-<hex>-<hex> sequence.
+
+ * The list of for-each like macros used by clang-format has been
+   updated.
+
+ * "git branch --list" learned to show branches that are checked out
+   in other worktrees connected to the same repository prefixed with
+   '+', similar to the way the currently checked out branch is shown
+   with '*' in front.
+   (merge 6e9381469e nb/branch-show-other-worktrees-head later to maint).
+
+ * Code restructuring during 2.20 period broke fetching tags via
+   "import" based transports.
+
+ * The commit-graph file is now part of the "files that the runtime
+   may keep open file descriptors on, all of which would need to be
+   closed when done with the object store", and the file descriptor to
+   an existing commit-graph file now is closed before "gc" finalizes a
+   new instance to replace it.
+
+ * "git checkout -p" needs to selectively apply a patch in reverse,
+   which did not work well.
+
+ * Code clean-up to avoid signed integer wraparounds during binary search.
+
+ * "git interpret-trailers" always treated '#' as the comment
+   character, regardless of core.commentChar setting, which has been
+   corrected.
+
+ * "git stash show 23" used to work, but no more after getting
+   rewritten in C; this regression has been corrected.
+
+ * "git rebase --abort" used to leave refs/rewritten/ when concluding
+   "git rebase -r", which has been corrected.
+
+ * An incorrect list of options was cached after command line
+   completion failed (e.g. trying to complete a command that requires
+   a repository outside one), which has been corrected.
+
+ * The code to parse scaled numbers out of configuration files has
+   been made more robust and also easier to follow.
+
+ * The codepath to compute delta islands used to spew progress output
+   without giving the callers any way to squelch it, which has been
+   fixed.
+
+ * Protocol capabilities that go over wire should never be translated,
+   but it was incorrectly marked for translation, which has been
+   corrected.  The output of protocol capabilities for debugging has
+   been tweaked a bit.
+
+ * Use "Erase in Line" CSI sequence that is already used in the editor
+   support to clear cruft in the progress output.
+
+ * "git submodule foreach" did not protect command line options passed
+   to the command to be run in each submodule correctly, when the
+   "--recursive" option was in use.
+
+ * The configuration variable rebase.rescheduleFailedExec should be
+   effective only while running an interactive rebase and should not
+   affect anything when running a non-interactive one, which was not
+   the case.  This has been corrected.
+
+ * The "git clone" documentation refers to command line options in its
+   description in the short form; they have been replaced with long
+   forms to make them more recognisable.
+
+ * Generation of pack bitmaps are now disabled when .keep files exist,
+   as these are mutually exclusive features.
+   (merge 7328482253 ew/repack-with-bitmaps-by-default later to maint).
+
+ * "git rm" to resolve a conflicted path leaked an internal message
+   "needs merge" before actually removing the path, which was
+   confusing.  This has been corrected.
+
+ * "git stash --keep-index" did not work correctly on paths that have
+   been removed, which has been fixed.
+   (merge b932f6a5e8 tg/stash-keep-index-with-removed-paths later to maint).
+
+ * Window 7 update ;-)
+
+ * A codepath that reads from GPG for signed object verification read
+   past the end of allocated buffer, which has been fixed.
+
+ * "git clean" silently skipped a path when it cannot lstat() it; now
+   it gives a warning.
+
+ * "git push --atomic" that goes over the transport-helper (namely,
+   the smart http transport) failed to prevent refs to be pushed when
+   it can locally tell that one of the ref update will fail without
+   having to consult the other end, which has been corrected.
+
+ * The internal diff machinery can be made to read out of bounds while
+   looking for --function-context line in a corner case, which has been
+   corrected.
+   (merge b777f3fd61 jk/xdiff-clamp-funcname-context-index later to maint).
+
+ * Other code cleanup, docfix, build fix, etc.
+   (merge fbec05c210 cc/test-oidmap later to maint).
+   (merge 7a06fb038c jk/no-system-includes-in-dot-c later to maint).
+   (merge 81ed2b405c cb/xdiff-no-system-includes-in-dot-c later to maint).
+   (merge d61e6ce1dd sg/fsck-config-in-doc later to maint).
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/RelNotes/2.23.1.txt 1.2.3+git2.25.1-1/git/Documentation/RelNotes/2.23.1.txt
--- 1.2.1+git2.18.0-1/git/Documentation/RelNotes/2.23.1.txt	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/RelNotes/2.23.1.txt	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,8 @@
+Git v2.23.1 Release Notes
+=========================
+
+This release merges up the fixes that appear in v2.14.6, v2.15.4,
+v2.17.3, v2.20.2 and in v2.21.1, addressing the security issues
+CVE-2019-1348, CVE-2019-1349, CVE-2019-1350, CVE-2019-1351,
+CVE-2019-1352, CVE-2019-1353, CVE-2019-1354, CVE-2019-1387, and
+CVE-2019-19604; see the release notes for those versions for details.
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/RelNotes/2.24.0.txt 1.2.3+git2.25.1-1/git/Documentation/RelNotes/2.24.0.txt
--- 1.2.1+git2.18.0-1/git/Documentation/RelNotes/2.24.0.txt	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/RelNotes/2.24.0.txt	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,398 @@
+Git 2.24 Release Notes
+======================
+
+Updates since v2.23
+-------------------
+
+Backward compatibility note
+
+ * "filter-branch" is showing its age and alternatives are available.
+   From this release, we started to discourage its use and hint
+   people about filter-repo.
+
+UI, Workflows & Features
+
+ * We now have an active interim maintainer for the Git-Gui part of
+   the system.  Praise and thank Pratyush Yadav for volunteering.
+
+ * The command line parser learned "--end-of-options" notation; the
+   standard convention for scripters to have hardcoded set of options
+   first on the command line, and force the command to treat end-user
+   input as non-options, has been to use "--" as the delimiter, but
+   that would not work for commands that use "--" as a delimiter
+   between revs and pathspec.
+
+ * A mechanism to affect the default setting for a (related) group of
+   configuration variables is introduced.
+
+ * "git fetch" learned "--set-upstream" option to help those who first
+   clone from their private fork they intend to push to, add the true
+   upstream via "git remote add" and then "git fetch" from it.
+
+ * Device-tree files learned their own userdiff patterns.
+   (merge 3c81760bc6 sb/userdiff-dts later to maint).
+
+ * "git rebase --rebase-merges" learned to drive different merge
+   strategies and pass strategy specific options to them.
+
+ * A new "pre-merge-commit" hook has been introduced.
+
+ * Command line completion updates for "git -c var.name=val" have been
+   added.
+
+ * The lazy clone machinery has been taught that there can be more
+   than one promisor remote and consult them in order when downloading
+   missing objects on demand.
+
+ * The list-objects-filter API (used to create a sparse/lazy clone)
+   learned to take a combined filter specification.
+
+ * The documentation and tests for "git format-patch" have been
+   cleaned up.
+
+ * On Windows, the root level of UNC share is now allowed to be used
+   just like any other directory.
+
+ * The command line completion support (in contrib/) learned about the
+   "--skip" option of "git revert" and "git cherry-pick".
+
+ * "git rebase --keep-base <upstream>" tries to find the original base
+   of the topic being rebased and rebase on top of that same base,
+   which is useful when running the "git rebase -i" (and its limited
+   variant "git rebase -x").
+
+   The command also has learned to fast-forward in more cases where it
+   can instead of replaying to recreate identical commits.
+
+ * A configuration variable tells "git fetch" to write the commit
+   graph after finishing.
+
+ * "git add -i" has been taught to show the total number of hunks and
+   the hunks that has been processed so far when showing prompts.
+
+ * "git fetch --jobs=<n>" allowed <n> parallel jobs when fetching
+   submodules, but this did not apply to "git fetch --multiple" that
+   fetches from multiple remote repositories.  It now does.
+
+ * The installation instruction for zsh completion script (in
+   contrib/) has been a bit improved.
+
+
+Performance, Internal Implementation, Development Support etc.
+
+ * The code to write commit-graph over given commit object names has
+   been made a bit more robust.
+
+ * The first line of verbose output from each test piece now carries
+   the test name and number to help scanning with eyeballs.
+
+ * Further clean-up of the initialization code.
+
+ * xmalloc() used to have a mechanism to ditch memory and address
+   space resources as the last resort upon seeing an allocation
+   failure from the underlying malloc(), which made the code complex
+   and thread-unsafe with dubious benefit, as major memory resource
+   users already do limit their uses with various other mechanisms.
+   It has been simplified away.
+
+ * Unnecessary full-tree diff in "git log -L" machinery has been
+   optimized away.
+
+ * The http transport lacked some optimization the native transports
+   learned to avoid unnecessary ref advertisement, which has been
+   corrected.
+
+ * Preparation for SHA-256 upgrade continues in the test department.
+   (merge 0c37c41d13 bc/hash-independent-tests-part-5 later to maint).
+
+ * The memory ownership model of the "git fast-import" got
+   straightened out.
+
+ * Output from trace2 subsystem is formatted more prettily now.
+
+ * The internal code originally invented for ".gitignore" processing
+   got reshuffled and renamed to make it less tied to "excluding" and
+   stress more that it is about "matching", as it has been reused for
+   things like sparse checkout specification that want to check if a
+   path is "included".
+
+ * "git stash" learned to write refreshed index back to disk.
+
+ * Coccinelle checks are done on more source files than before now.
+
+ * The cache-tree code has been taught to be less aggressive in
+   attempting to see if a tree object it computed already exists in
+   the repository.
+
+ * The code to parse and use the commit-graph file has been made more
+   robust against corrupted input.
+
+ * The hg-to-git script (in contrib/) has been updated to work with
+   Python 3.
+
+ * Update the way build artifacts in t/helper/ directory are ignored.
+
+ * Preparation for SHA-256 upgrade continues.
+
+ * "git log --graph" for an octopus merge is sometimes colored
+   incorrectly, which is demonstrated and documented but not yet
+   fixed.
+
+ * The trace2 output, when sending them to files in a designated
+   directory, can populate the directory with too many files; a
+   mechanism is introduced to set the maximum number of files and
+   discard further logs when the maximum is reached.
+
+ * We have adopted a Code-of-conduct document.
+   (merge 3f9ef874a7 jk/coc later to maint).
+
+
+Fixes since v2.23
+-----------------
+
+ * "git grep --recurse-submodules" that looks at the working tree
+   files looked at the contents in the index in submodules, instead of
+   files in the working tree.
+   (merge 6a289d45c0 mt/grep-submodules-working-tree later to maint).
+
+ * Codepaths to walk tree objects have been audited for integer
+   overflows and hardened.
+   (merge 5aa02f9868 jk/tree-walk-overflow later to maint).
+
+ * "git pack-refs" can lose refs that are created while running, which
+   is getting corrected.
+   (merge a613d4f817 sc/pack-refs-deletion-racefix later to maint).
+
+ * "git checkout" and "git restore" to re-populate the index from a
+   tree-ish (typically HEAD) did not work correctly for a path that
+   was removed and then added again with the intent-to-add bit, when
+   the corresponding working tree file was empty.  This has been
+   corrected.
+
+ * Compilation fix.
+   (merge 70597e8386 rs/nedalloc-fixlets later to maint).
+
+ * "git gui" learned to call the clean-up procedure before exiting.
+   (merge 0d88f3d2c5 py/git-gui-do-quit later to maint).
+
+ * We promoted the "indent heuristics" that decides where to split
+   diff hunks from experimental to the default a few years ago, but
+   some stale documentation still marked it as experimental, which has
+   been corrected.
+   (merge 64e5e1fba1 sg/diff-indent-heuristic-non-experimental later to maint).
+
+ * Fix a mismerge that happened in 2.22 timeframe.
+   (merge acb7da05ac en/checkout-mismerge-fix later to maint).
+
+ * "git archive" recorded incorrect length in extended pax header in
+   some corner cases, which has been corrected.
+   (merge 71d41ff651 rs/pax-extended-header-length-fix later to maint).
+
+ * On-demand object fetching in lazy clone incorrectly tried to fetch
+   commits from submodule projects, while still working in the
+   superproject, which has been corrected.
+   (merge a63694f523 jt/diff-lazy-fetch-submodule-fix later to maint).
+
+ * Prepare get_short_oid() codepath to be thread-safe.
+   (merge 7cfcb16b0e rs/sort-oid-array-thread-safe later to maint).
+
+ * "for-each-ref" and friends that show refs did not protect themselves
+   against ancient tags that did not record tagger names when asked to
+   show "%(taggername)", which have been corrected.
+   (merge 8b3f33ef11 mp/for-each-ref-missing-name-or-email later to maint).
+
+ * The "git am" based backend of "git rebase" ignored the result of
+   updating ".gitattributes" done in one step when replaying
+   subsequent steps.
+   (merge 2c65d90f75 bc/reread-attributes-during-rebase later to maint).
+
+ * Tell cURL library to use the same malloc() implementation, with the
+   xmalloc() wrapper, as the rest of the system, for consistency.
+   (merge 93b980e58f cb/curl-use-xmalloc later to maint).
+
+ * Build fix to adjust .gitignore to unignore a path that we started to track.
+   (merge aac6ff7b5b js/visual-studio later to maint).
+
+ * A few implementation fixes in the notes API.
+   (merge 60fe477a0b mh/notes-duplicate-entries later to maint).
+
+ * Fix an earlier regression to "git push --all" which should have
+   been forbidden when the target remote repository is set to be a
+   mirror.
+   (merge 8e4c8af058 tg/push-all-in-mirror-forbidden later to maint).
+
+ * Fix an earlier regression in the test suite, which mistakenly
+   stopped running HTTPD tests.
+   (merge 3960290675 sg/git-test-boolean later to maint).
+
+ * "git rebase --autostash <upstream> <branch>", when <branch> is
+   different from the current branch, incorrectly moved the tip of the
+   current branch, which has been corrected.
+   (merge bf1e28e0ad bw/rebase-autostash-keep-current-branch later to maint).
+
+ * Update support for Asciidoctor documentation toolchain.
+   (merge 83b0b8953e ma/asciidoctor-refmiscinfo later to maint).
+
+ * Start using DocBook 5 (instead of DocBook 4.5) as Asciidoctor 2.0
+   no longer works with the older one.
+   (merge f6461b82b9 bc/doc-use-docbook-5 later to maint).
+
+ * The markup used in user-manual has been updated to work better with
+   asciidoctor.
+   (merge c4d2f6143a ma/user-manual-markup-update later to maint).
+
+ * Make sure the grep machinery does not abort when seeing a payload
+   that is not UTF-8 even when JIT is not in use with PCRE1.
+   (merge ad7c543e3b cb/skip-utf8-check-with-pcre1 later to maint).
+
+ * The name of the blob object that stores the filter specification
+   for sparse cloning/fetching was interpreted in a wrong place in the
+   code, causing Git to abort.
+
+ * "git log --decorate-refs-exclude=<pattern>" was incorrectly
+   overruled when the "--simplify-by-decoration" option is used, which
+   has been corrected.
+   (merge 0cc7380d88 rs/simplify-by-deco-with-deco-refs-exclude later to maint).
+
+ * The "upload-pack" (the counterpart of "git fetch") needs to disable
+   commit-graph when responding to a shallow clone/fetch request, but
+   the way this was done made Git panic, which has been corrected.
+
+ * The object traversal machinery has been optimized not to load tree
+   objects when we are only interested in commit history.
+   (merge 72ed80c784 jk/list-objects-optim-wo-trees later to maint).
+
+ * The object name parser for "Nth parent" syntax has been made more
+   robust against integer overflows.
+   (merge 59fa5f5a25 rs/nth-parent-parse later to maint).
+
+ * The code used in following tags in "git fetch" has been optimized.
+   (merge b7e2d8bca5 ms/fetch-follow-tag-optim later to maint).
+
+ * Regression fix for progress output.
+   (merge 2bb74b53a4 sg/progress-fix later to maint).
+
+ * A bug in merge-recursive code that triggers when a branch with a
+   symbolic link is merged with a branch that replaces it with a
+   directory has been fixed.
+   (merge 83e3ad3b12 jt/merge-recursive-symlink-is-not-a-dir-in-way later to maint).
+
+ * The rename detection logic sorts a list of rename source candidates
+   by similarity to pick the best candidate, which means that a tie
+   between sources with the same similarity is broken by the original
+   location in the original candidate list (which is sorted by path).
+   Force the sorting by similarity done with a stable sort, which is
+   not promised by system supplied qsort(3), to ensure consistent
+   results across platforms.
+   (merge 2049b8dc65 js/diff-rename-force-stable-sort later to maint).
+
+ * The code to skip "UTF" and "UTF-" prefix, when computing an advice
+   message, did not work correctly when the prefix was "UTF", which
+   has been fixed.
+   (merge b181676ce9 rs/convert-fix-utf-without-dash later to maint).
+
+ * The author names taken from SVN repositories may have extra leading
+   or trailing whitespaces, which are now munged away.
+   (merge 4ddd4bddb1 tk/git-svn-trim-author-name later to maint).
+
+ * "git rebase -i" showed a wrong HEAD while "reword" open the editor.
+   (merge b0a3186140 pw/rebase-i-show-HEAD-to-reword later to maint).
+
+ * A few simplification and bugfixes to PCRE interface.
+   (merge c581e4a749 ab/pcre-jit-fixes later to maint).
+
+ * PCRE fixes.
+   (merge ff61681b46 cb/pcre1-cleanup later to maint).
+
+ * "git range-diff" segfaulted when diff.noprefix configuration was
+   used, as it blindly expected the patch it internally generates to
+   have the standard a/ and b/ prefixes.  The command now forces the
+   internal patch to be built without any prefix, not to be affected
+   by any end-user configuration.
+   (merge 937b76ed49 js/range-diff-noprefix later to maint).
+
+ * "git stash apply" in a subdirectory of a secondary worktree failed
+   to access the worktree correctly, which has been corrected.
+   (merge dfd557c978 js/stash-apply-in-secondary-worktree later to maint).
+
+ * The merge-recursive machinery is one of the most complex parts of
+   the system that accumulated cruft over time.  This large series
+   cleans up the implementation quite a bit.
+   (merge b657047719 en/merge-recursive-cleanup later to maint).
+
+ * Pretty-printed command line formatter (used in e.g. reporting the
+   command being run by the tracing API) had a bug that lost an
+   argument that is an empty string, which has been corrected.
+   (merge ce2d7ed2fd gs/sq-quote-buf-pretty later to maint).
+
+ * "git range-diff" failed to handle mode-only change, which has been
+   corrected.
+   (merge 2b6a9b13ca tg/range-diff-output-update later to maint).
+
+ * Dev support update.
+   (merge 4f3c1dc5d6 dl/allow-running-cocci-verbosely later to maint).
+
+ * "git format-patch -o <outdir>" did an equivalent of "mkdir <outdir>"
+   not "mkdir -p <outdir>", which was corrected.
+
+ * "git stash save" lost local changes to submodules, which has been
+   corrected.
+   (merge 556895d0c8 jj/stash-reset-only-toplevel later to maint).
+
+ * The atomic push over smart HTTP transport did not work, which has
+   been corrected.
+   (merge 6f1194246a bc/smart-http-atomic-push later to maint).
+
+ * Other code cleanup, docfix, build fix, etc.
+   (merge d1387d3895 en/fast-import-merge-doc later to maint).
+   (merge 1c24a54ea4 bm/repository-layout-typofix later to maint).
+   (merge 415b770b88 ds/midx-expire-repack later to maint).
+   (merge 19800bdc3f nd/diff-parseopt later to maint).
+   (merge 58166c2e9d tg/t0021-racefix later to maint).
+   (merge 7027f508c7 dl/compat-cleanup later to maint).
+   (merge e770fbfeff jc/test-cleanup later to maint).
+   (merge 1fd881d404 rs/trace2-dst-warning later to maint).
+   (merge 7e92756751 mh/http-urlmatch-cleanup later to maint).
+   (merge 9784f97321 mh/release-commit-memory-fix later to maint).
+   (merge 60d198d022 tb/banned-vsprintf-namefix later to maint).
+   (merge 80e3658647 rs/help-unknown-ref-does-not-return later to maint).
+   (merge 0a8bc7068f dt/remote-helper-doc-re-lock-option later to maint).
+   (merge 27fd1e4ea7 en/merge-options-ff-and-friends later to maint).
+   (merge 502c386ff9 sg/clean-nested-repo-with-ignored later to maint).
+   (merge 26e3d1cbea am/mailmap-andrey-mazo later to maint).
+   (merge 47b27c96fa ss/get-time-cleanup later to maint).
+   (merge dd2e50a84e jk/commit-graph-cleanup later to maint).
+   (merge 4fd39c76e6 cs/pretty-formats-doc-typofix later to maint).
+   (merge 40e747e89d dl/submodule-set-branch later to maint).
+   (merge 689a146c91 rs/commit-graph-use-list-count later to maint).
+   (merge 0eb7c37a8a js/doc-patch-text later to maint).
+   (merge 4b3aa170d1 rs/nth-switch-code-simplification later to maint).
+   (merge 0d4304c124 ah/doc-submodule-ignore-submodules later to maint).
+   (merge af78249463 cc/svn-fe-py-shebang later to maint).
+   (merge 7bd97d6dff rs/alias-use-copy-array later to maint).
+   (merge c46ebc2496 sg/travis-help-debug later to maint).
+   (merge 24c681794f ps/my-first-contribution-alphasort later to maint).
+   (merge 75b2c15435 cb/do-not-use-test-cmp-with-a later to maint).
+   (merge cda0d497e3 bw/submodule-helper-usage-fix later to maint).
+   (merge fe0ed5d5e9 am/visual-studio-config-fix later to maint).
+   (merge 2e09c01232 sg/name-rev-cutoff-underflow-fix later to maint).
+   (merge ddb3c856f3 as/shallow-slab-use-fix later to maint).
+   (merge 71f4960b91 js/mingw-spawn-with-spaces-in-path later to maint).
+   (merge 53d687bf5f ah/cleanups later to maint).
+   (merge f537485fa5 rs/test-remove-useless-debugging-cat later to maint).
+   (merge 11a3d3aadd dl/rev-list-doc-cleanup later to maint).
+   (merge d928a8388a am/t0028-utf16-tests later to maint).
+   (merge b05b40930e dl/t0000-skip-test-test later to maint).
+   (merge 03d3b1297c js/xdiffi-comment-updates later to maint).
+   (merge 57d8f4b4c7 js/doc-stash-save later to maint).
+   (merge 8c1cfd58e3 ta/t1308-typofix later to maint).
+   (merge fa364ad790 bb/utf8-wcwidth-cleanup later to maint).
+   (merge 68b69211b2 bb/compat-util-comment-fix later to maint).
+   (merge 5cc6a4be11 rs/http-push-simplify later to maint).
+   (merge a81e42d235 rs/column-use-utf8-strnwidth later to maint).
+   (merge 062a309d36 rs/remote-curl-use-argv-array later to maint).
+   (merge 3b3c79f6c9 nr/diff-highlight-indent-fix later to maint).
+   (merge 3444ec2eb2 wb/fsmonitor-bitmap-fix later to maint).
+   (merge 10da030ab7 cb/pcre2-chartables-leakfix later to maint).
+   (merge 60e6569a12 js/mingw-needs-hiding-fix later to maint).
+   (merge 52bd3e4657 rl/gitweb-blame-prev-fix later to maint).
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/RelNotes/2.24.1.txt 1.2.3+git2.25.1-1/git/Documentation/RelNotes/2.24.1.txt
--- 1.2.1+git2.18.0-1/git/Documentation/RelNotes/2.24.1.txt	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/RelNotes/2.24.1.txt	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,8 @@
+Git v2.24.1 Release Notes
+=========================
+
+This release merges up the fixes that appear in v2.14.6, v2.15.4,
+v2.17.3, v2.20.2 and in v2.21.1, addressing the security issues
+CVE-2019-1348, CVE-2019-1349, CVE-2019-1350, CVE-2019-1351,
+CVE-2019-1352, CVE-2019-1353, CVE-2019-1354, CVE-2019-1387, and
+CVE-2019-19604; see the release notes for those versions for details.
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/RelNotes/2.25.0.txt 1.2.3+git2.25.1-1/git/Documentation/RelNotes/2.25.0.txt
--- 1.2.1+git2.18.0-1/git/Documentation/RelNotes/2.25.0.txt	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/RelNotes/2.25.0.txt	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,370 @@
+Git 2.25 Release Notes
+======================
+
+Updates since v2.24
+-------------------
+
+Backward compatibility notes
+
+
+UI, Workflows & Features
+
+ * A tutorial on object enumeration has been added.
+
+ * The branch description ("git branch --edit-description") has been
+   used to fill the body of the cover letters by the format-patch
+   command; this has been enhanced so that the subject can also be
+   filled.
+
+ * "git rebase --preserve-merges" has been marked as deprecated; this
+   release stops advertising it in the "git rebase -h" output.
+
+ * The code to generate multi-pack index learned to show (or not to
+   show) progress indicators.
+
+ * "git apply --3way" learned to honor merge.conflictStyle
+   configuration variable, like merges would.
+
+ * The custom format for "git log --format=<format>" learned the l/L
+   placeholder that is similar to e/E that fills in the e-mail
+   address, but only the local part on the left side of '@'.
+
+ * Documentation pages for "git shortlog" now list commit limiting
+   options explicitly.
+
+ * The patterns to detect function boundary for Elixir language has
+   been added.
+
+ * The completion script (in contrib/) learned that the "--onto"
+   option of "git rebase" can take its argument as the value of the
+   option.
+
+ * The userdiff machinery has been taught that "async def" is another
+   way to begin a "function" in Python.
+
+ * "git range-diff" learned to take the "--notes=<ref>" and the
+   "--no-notes" options to control the commit notes included in the
+   log message that gets compared.
+
+ * "git rev-parse --show-toplevel" run outside of any working tree did
+   not error out, which has been corrected.
+
+ * A few commands learned to take the pathspec from the standard input
+   or a named file, instead of taking it as the command line
+   arguments, with the "--pathspec-from-file" option.
+
+ * "git submodule" learned a subcommand "set-url".
+
+ * "git log" family learned "--pretty=reference" that gives the name
+   of a commit in the format that is often used to refer to it in log
+   messages.
+
+ * The interaction between "git clone --recurse-submodules" and
+   alternate object store was ill-designed.  The documentation and
+   code have been taught to make more clear recommendations when the
+   users see failures.
+
+ * Management of sparsely checked-out working tree has gained a
+   dedicated "sparse-checkout" command.
+
+ * Miscellaneous small UX improvements on "git-p4".
+
+ * "git sparse-checkout list" subcommand learned to give its output in
+   a more concise form when the "cone" mode is in effect.
+
+
+Performance, Internal Implementation, Development Support etc.
+
+ * Debugging support for lazy cloning has been a bit improved.
+
+ * Move the definition of a set of bitmask constants from 0ctal
+   literal to (1U<<count) notation.
+
+ * Test updates to prepare for SHA-2 transition continues.
+
+ * Crufty code and logic accumulated over time around the object
+   parsing and low-level object access used in "git fsck" have been
+   cleaned up.
+
+ * The implementation of "git log --graph" got refactored and then its
+   output got simplified.
+
+ * Follow recent push to move API docs from Documentation/ to header
+   files and update config.h
+
+ * "git bundle" has been taught to use the parse options API.  "git
+   bundle verify" learned "--quiet" and "git bundle create" learned
+   options to control the progress output.
+
+ * Handling of commit objects that use non UTF-8 encoding during
+   "rebase -i" has been improved.
+
+ * The beginning of rewriting "git add -i" in C.
+
+ * A label used in the todo list that are generated by "git rebase
+   --rebase-merges" is used as a part of a refname; the logic to come
+   up with the label has been tightened to avoid names that cannot be
+   used as such.
+
+ * The logic to avoid duplicate label names generated by "git rebase
+   --rebase-merges" forgot that the machinery itself uses "onto" as a
+   label name, which must be avoided by auto-generated labels, which
+   has been corrected.
+
+ * We have had compatibility fallback macro definitions for "PRIuMAX",
+   "PRIu32", etc. but did not for "PRIdMAX", while the code used the
+   last one apparently without any hiccup reported recently.  The
+   fallback macro definitions for these <inttypes.h> macros that must
+   appear in C99 systems have been removed.
+
+ * Recently we have declared that GIT_TEST_* variables take the
+   usual boolean values (it used to be that some used "non-empty
+   means true" and taking GIT_TEST_VAR=YesPlease as true); make
+   sure we notice and fail when non-bool strings are given to
+   these variables.
+
+ * Users of oneway_merge() (like "reset --hard") learned to take
+   advantage of fsmonitor to avoid unnecessary lstat(2) calls.
+
+ * Performance tweak on "git push" into a repository with many refs
+   that point at objects we have never heard of.
+
+ * PerfTest fix to avoid stale result mixed up with the latest round
+   of test results.
+
+ * Hide lower-level verify_signed-buffer() API as a pure helper to
+   implement the public check_signature() function, in order to
+   encourage new callers to use the correct and more strict
+   validation.
+
+ * Unnecessary reading of state variables back from the disk during
+   sequencer operation has been reduced.
+
+ * The code has been made to avoid gmtime() and localtime() and prefer
+   their reentrant counterparts.
+
+ * In a repository with many packfiles, the cost of the procedure that
+   avoids registering the same packfile twice was unnecessarily high
+   by using an inefficient search algorithm, which has been corrected.
+
+ * Redo "git name-rev" to avoid recursive calls.
+
+ * FreeBSD CI support via Cirrus-CI has been added.
+
+
+Fixes since v2.24
+-----------------
+
+ * "rebase -i" ceased to run post-commit hook by mistake in an earlier
+   update, which has been corrected.
+
+ * "git notes copy $original" ought to copy the notes attached to the
+   original object to HEAD, but a mistaken tightening to command line
+   parameter validation made earlier disabled that feature by mistake.
+
+ * When all files from some subdirectory were renamed to the root
+   directory, the directory rename heuristics would fail to detect that
+   as a rename/merge of the subdirectory to the root directory, which has
+   been corrected.
+
+ * Code clean-up and a bugfix in the logic used to tell worktree local
+   and repository global refs apart.
+   (merge f45f88b2e4 sg/dir-trie-fixes later to maint).
+
+ * "git stash save" in a working tree that is sparsely checked out
+   mistakenly removed paths that are outside the area of interest.
+   (merge 4a58c3d7f7 js/update-index-ignore-removal-for-skip-worktree later to maint).
+
+ * "git rev-parse --git-path HEAD.lock" did not give the right path
+   when run in a secondary worktree.
+   (merge 76a53d640f js/git-path-head-dot-lock-fix later to maint).
+
+ * "git merge --no-commit" needs "--no-ff" if you do not want to move
+   HEAD, which has been corrected in the manual page for "git bisect".
+   (merge 8dd327b246 ma/bisect-doc-sample-update later to maint).
+
+ * "git worktree add" internally calls "reset --hard" that should not
+   descend into submodules, even when submodule.recurse configuration
+   is set, but it was affected.  This has been corrected.
+   (merge 4782cf2ab6 pb/no-recursive-reset-hard-in-worktree-add later to maint).
+
+ * Messages from die() etc. can be mixed up from multiple processes
+   without even line buffering on Windows, which has been worked
+   around.
+   (merge 116d1fa6c6 js/vreportf-wo-buffering later to maint).
+
+ * HTTP transport had possible allocator/deallocator mismatch, which
+   has been corrected.
+
+ * The watchman integration for fsmonitor was racy, which has been
+   corrected to be more conservative.
+   (merge dd0b61f577 kw/fsmonitor-watchman-fix later to maint).
+
+ * Fetching from multiple remotes into the same repository in parallel
+   had a bad interaction with the recent change to (optionally) update
+   the commit-graph after a fetch job finishes, as these parallel
+   fetches compete with each other.  Which has been corrected.
+
+ * Recent update to "git stash pop" made the command empty the index
+   when run with the "--quiet" option, which has been corrected.
+
+ * "git fetch" codepath had a big "do not lazily fetch missing objects
+   when I ask if something exists" switch.  This has been corrected by
+   marking the "does this thing exist?" calls with "if not please do not
+   lazily fetch it" flag.
+
+ * Test update to avoid wasted cycles.
+   (merge e0316695ec sg/skip-skipped-prereq later to maint).
+
+ * Error handling after "git push" finishes sending the packdata and
+   waits for the response to the remote side has been improved.
+   (merge ad7a403268 jk/send-pack-remote-failure later to maint).
+
+ * Some codepaths in "gitweb" that forgot to escape URLs generated
+   based on end-user input have been corrected.
+   (merge a376e37b2c jk/gitweb-anti-xss later to maint).
+
+ * CI jobs for macOS has been made less chatty when updating perforce
+   package used during testing.
+   (merge 0dbc4a0edf jc/azure-ci-osx-fix-fix later to maint).
+
+ * "git unpack-objects" used to show progress based only on the number
+   of received and unpacked objects, which stalled when it has to
+   handle an unusually large object.  It now shows the throughput as
+   well.
+   (merge bae60ba7e9 sg/unpack-progress-throughput later to maint).
+
+ * The sequencer machinery compared the HEAD and the state it is
+   attempting to commit to decide if the result would be a no-op
+   commit, even when amending a commit, which was incorrect, and
+   has been corrected.
+
+ * The code to parse GPG output used to assume incorrectly that the
+   finterprint for the primary key would always be present for a valid
+   signature, which has been corrected.
+   (merge 67a6ea6300 hi/gpg-optional-pkfp-fix later to maint).
+
+ * "git submodule status" and "git submodule status --cached" show
+   different things, but the documentation did not cover them
+   correctly, which has been corrected.
+   (merge 8d483c8408 mg/doc-submodule-status-cached later to maint).
+
+ * "git reset --patch $object" without any pathspec should allow a
+   tree object to be given, but incorrectly required a committish,
+   which has been corrected.
+
+ * "git submodule status" that is run from a subdirectory of the
+   superproject did not work well, which has been corrected.
+   (merge 1f3aea22c7 mg/submodule-status-from-a-subdirectory later to maint).
+
+ * The revision walking machinery uses resources like per-object flag
+   bits that need to be reset before a new iteration of walking
+   begins, but the resources related to topological walk were not
+   cleared correctly, which has been corrected.
+   (merge 0aa0c2b2ec mh/clear-topo-walk-upon-reset later to maint).
+
+ * TravisCI update.
+   (merge 176441bfb5 sg/osx-force-gcc-9 later to maint).
+
+ * While running "revert" or "cherry-pick --edit" for multiple
+   commits, a recent regression incorrectly detected "nothing to
+   commit, working tree clean", instead of replaying the commits,
+   which has been corrected.
+   (merge befd4f6a81 sg/assume-no-todo-update-in-cherry-pick later to maint).
+
+ * Work around a issue where a FD that is left open when spawning a
+   child process and is kept open in the child can interfere with the
+   operation in the parent process on Windows.
+
+ * One kind of progress messages were always given during commit-graph
+   generation, instead of following the "if it takes more than two
+   seconds, show progress" pattern, which has been corrected.
+
+ * "git rebase" did not work well when format.useAutoBase
+   configuration variable is set, which has been corrected.
+
+ * The "diff" machinery learned not to lose added/removed blank lines
+   in the context when --ignore-blank-lines and --function-context are
+   used at the same time.
+   (merge 0bb313a552 rs/xdiff-ignore-ws-w-func-context later to maint).
+
+ * The test on "fast-import" used to get stuck when "fast-import" died
+   in the middle.
+   (merge 0d9b0d7885 sg/t9300-robustify later to maint).
+
+ * "git format-patch" can take a set of configured format.notes values
+   to specify which notes refs to use in the log message part of the
+   output.  The behaviour of this was not consistent with multiple
+   --notes command line options, which has been corrected.
+   (merge e0f9095aaa dl/format-patch-notes-config-fixup later to maint).
+
+ * "git p4" used to ignore lfs.storage configuration variable, which
+   has been corrected.
+   (merge ea94b16fb8 rb/p4-lfs later to maint).
+
+ * Assorted fixes to the directory traversal API.
+   (merge 6836d2fe06 en/fill-directory-fixes later to maint).
+
+ * Forbid pathnames that the platform's filesystem cannot represent on
+   MinGW.
+   (merge 4dc42c6c18 js/mingw-reserved-filenames later to maint).
+
+ * "git rebase --signoff" stopped working when the command was written
+   in C, which has been corrected.
+   (merge 4fe7e43c53 en/rebase-signoff-fix later to maint).
+
+ * An earlier update to Git for Windows declared that a tree object is
+   invalid if it has a path component with backslash in it, which was
+   overly strict, which has been corrected.  The only protection the
+   Windows users need is to prevent such path (or any path that their
+   filesystem cannot check out) from entering the index.
+   (merge 224c7d70fa js/mingw-loosen-overstrict-tree-entry-checks later to maint).
+
+ * The code to write split commit-graph file(s) upon fetching computed
+   bogus value for the parameter used in splitting the resulting
+   files, which has been corrected.
+   (merge 63020f175f ds/commit-graph-set-size-mult later to maint).
+
+ * Other code cleanup, docfix, build fix, etc.
+   (merge 80736d7c5e jc/am-show-current-patch-docfix later to maint).
+   (merge 8b656572ca sg/commit-graph-usage-fix later to maint).
+   (merge 6c02042139 mr/clone-dir-exists-to-path-exists later to maint).
+   (merge 44ae131e38 sg/blame-indent-heuristics-is-now-the-default later to maint).
+   (merge 0115e5d929 dl/doc-diff-no-index-implies-exit-code later to maint).
+   (merge 270de6acbe en/t6024-style later to maint).
+   (merge 14c4776d75 ns/test-desc-typofix later to maint).
+   (merge 68d40f30c4 dj/typofix-merge-strat later to maint).
+   (merge f66e0401ab jk/optim-in-pack-idx-conversion later to maint).
+   (merge 169bed7421 rs/parse-options-dup-null-fix later to maint).
+   (merge 51bd6be32d rs/use-copy-array-in-mingw-shell-command-preparation later to maint).
+   (merge b018719927 ma/t7004 later to maint).
+   (merge 932757b0cc ar/install-doc-update-cmds-needing-the-shell later to maint).
+   (merge 46efd28be1 ep/guard-kset-tar-headers later to maint).
+   (merge 9e5afdf997 ec/fetch-mark-common-refs-trace2 later to maint).
+   (merge f0e58b3fe8 pb/submodule-update-fetches later to maint).
+   (merge 2a02262078 dl/t5520-cleanup later to maint).
+   (merge a4fb016ba1 js/pkt-line-h-typofix later to maint).
+   (merge 54a7a64613 rs/simplify-prepare-cmd later to maint).
+   (merge 3eae30e464 jk/lore-is-the-archive later to maint).
+   (merge 14b7664df8 dl/lore-is-the-archive later to maint).
+   (merge 0e40a73a4c po/bundle-doc-clonable later to maint).
+   (merge e714b898c6 as/t7812-missing-redirects-fix later to maint).
+   (merge 528d9e6d01 jk/perf-wo-git-dot-pm later to maint).
+   (merge fc42f20e24 sg/test-squelch-noise-in-commit-bulk later to maint).
+   (merge c64368e3a2 bc/t9001-zsh-in-posix-emulation-mode later to maint).
+   (merge 11de8dd7ef dr/branch-usage-casefix later to maint).
+   (merge e05e8cf074 rs/archive-zip-code-cleanup later to maint).
+   (merge 147ee35558 rs/commit-export-env-simplify later to maint).
+   (merge 4507ecc771 rs/patch-id-use-oid-to-hex later to maint).
+   (merge 51a0a4ed95 mr/bisect-use-after-free later to maint).
+   (merge cc2bd5c45d pb/submodule-doc-xref later to maint).
+   (merge df5be01669 ja/doc-markup-cleanup later to maint).
+   (merge 7c5cea7242 mr/bisect-save-pointer-to-const-string later to maint).
+   (merge 20a67e8ce9 js/use-test-tool-on-path later to maint).
+   (merge 4e61b2214d ew/packfile-syscall-optim later to maint).
+   (merge ace0f86c7f pb/clarify-line-log-doc later to maint).
+   (merge 763a59e71c en/merge-recursive-oid-eq-simplify later to maint).
+   (merge 4e2c4c0d4f do/gitweb-typofix-in-comments later to maint).
+   (merge 421c0ffb02 jb/doc-multi-pack-idx-fix later to maint).
+   (merge f8740c586b pm/am-in-body-header-doc-update later to maint).
+   (merge 5814d44d9b tm/doc-submodule-absorb-fix later to maint).
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/RelNotes/2.25.1.txt 1.2.3+git2.25.1-1/git/Documentation/RelNotes/2.25.1.txt
--- 1.2.1+git2.18.0-1/git/Documentation/RelNotes/2.25.1.txt	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/RelNotes/2.25.1.txt	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,55 @@
+Git 2.25.1 Release Notes
+========================
+
+Fixes since v2.25
+-----------------
+
+ * "git commit" gives output similar to "git status" when there is
+   nothing to commit, but without honoring the advise.statusHints
+   configuration variable, which has been corrected.
+
+ * has_object_file() said "no" given an object registered to the
+   system via pretend_object_file(), making it inconsistent with
+   read_object_file(), causing lazy fetch to attempt fetching an
+   empty tree from promisor remotes.
+
+ * The code that tries to skip over the entries for the paths in a
+   single directory using the cache-tree was not careful enough
+   against corrupt index file.
+
+ * Complete an update to tutorial that encourages "git switch" over
+   "git checkout" that was done only half-way.
+
+ * Reduce unnecessary round-trip when running "ls-remote" over the
+   stateless RPC mechanism.
+
+ * "git restore --staged" did not correctly update the cache-tree
+   structure, resulting in bogus trees to be written afterwards, which
+   has been corrected.
+
+ * The code recently added to move to the entry beyond the ones in the
+   same directory in the index in the sparse-cone mode did not count
+   the number of entries to skip over incorrectly, which has been
+   corrected.
+
+ * Work around test breakages caused by custom regex engine used in
+   libasan, when address sanitizer is used with more recent versions
+   of gcc and clang.
+
+ * "git fetch --refmap=" option has got a better documentation.
+
+ * Corner case bugs in "git clean" that stems from a (necessarily for
+   performance reasons) awkward calling convention in the directory
+   enumeration API has been corrected.
+
+ * "git grep --no-index" should not get affected by the contents of
+   the .gitmodules file but when "--recurse-submodules" is given or
+   the "submodule.recurse" variable is set, it did.  Now these
+   settings are ignored in the "--no-index" mode.
+
+ * Technical details of the bundle format has been documented.
+
+ * Unhelpful warning messages during documentation build have been
+   squelched.
+
+Also contains various documentation updates, code clean-ups and minor fixups.
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/RelNotes/2.3.3.txt 1.2.3+git2.25.1-1/git/Documentation/RelNotes/2.3.3.txt
--- 1.2.1+git2.18.0-1/git/Documentation/RelNotes/2.3.3.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/RelNotes/2.3.3.txt	2020-02-17 04:47:35.000000000 +0000
@@ -12,7 +12,7 @@ Fixes since v2.3.2
  * Description given by "grep -h" for its --exclude-standard option
    was phrased poorly.
 
- * Documentaton for "git remote add" mentioned "--tags" and
+ * Documentation for "git remote add" mentioned "--tags" and
    "--no-tags" and it was not clear that fetch from the remote in
    the future will use the default behaviour when neither is given
    to override it.
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/RelNotes/2.3.7.txt 1.2.3+git2.25.1-1/git/Documentation/RelNotes/2.3.7.txt
--- 1.2.1+git2.18.0-1/git/Documentation/RelNotes/2.3.7.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/RelNotes/2.3.7.txt	2020-02-17 04:47:35.000000000 +0000
@@ -4,7 +4,7 @@ Git v2.3.7 Release Notes
 Fixes since v2.3.6
 ------------------
 
- * An earlier update to the parser that disects a URL broke an
+ * An earlier update to the parser that dissects a URL broke an
    address, followed by a colon, followed by an empty string (instead
    of the port number), e.g. ssh://example.com:/path/to/repo.
 
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/RelNotes/2.4.3.txt 1.2.3+git2.25.1-1/git/Documentation/RelNotes/2.4.3.txt
--- 1.2.1+git2.18.0-1/git/Documentation/RelNotes/2.4.3.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/RelNotes/2.4.3.txt	2020-02-17 04:47:35.000000000 +0000
@@ -66,7 +66,7 @@ Fixes since v2.4.3
  * Some time ago, "git blame" (incorrectly) lost the convert_to_git()
    call when synthesizing a fake "tip" commit that represents the
    state in the working tree, which broke folks who record the history
-   with LF line ending to make their project portabile across
+   with LF line ending to make their project portable across
    platforms while terminating lines in their working tree files with
    CRLF for their platform.
 
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/RelNotes/2.5.0.txt 1.2.3+git2.25.1-1/git/Documentation/RelNotes/2.5.0.txt
--- 1.2.1+git2.18.0-1/git/Documentation/RelNotes/2.5.0.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/RelNotes/2.5.0.txt	2020-02-17 04:47:35.000000000 +0000
@@ -172,7 +172,8 @@ Performance, Internal Implementation, De
    incorrect patch text to "git apply".  Add tests to demonstrate
    this.
 
-   I have a slight suspicion that this may be $gmane/87202 coming back
+   I have a slight suspicion that this may be
+   cf. <7vtzf77wjp.fsf@gitster.siamese.dyndns.org> coming back
    and biting us (I seem to have said "let's run with this and see
    what happens" back then).
 
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/RelNotes/2.7.0.txt 1.2.3+git2.25.1-1/git/Documentation/RelNotes/2.7.0.txt
--- 1.2.1+git2.18.0-1/git/Documentation/RelNotes/2.7.0.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/RelNotes/2.7.0.txt	2020-02-17 04:47:35.000000000 +0000
@@ -40,7 +40,7 @@ UI, Workflows & Features
 
  * "git interpret-trailers" can now run outside of a Git repository.
 
- * "git p4" learned to reencode the pathname it uses to communicate
+ * "git p4" learned to re-encode the pathname it uses to communicate
    with the p4 depot with a new option.
 
  * Give progress meter to "git filter-branch".
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/RelNotes/2.7.1.txt 1.2.3+git2.25.1-1/git/Documentation/RelNotes/2.7.1.txt
--- 1.2.1+git2.18.0-1/git/Documentation/RelNotes/2.7.1.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/RelNotes/2.7.1.txt	2020-02-17 04:47:35.000000000 +0000
@@ -10,7 +10,7 @@ Fixes since v2.7
    setting GIT_WORK_TREE environment themselves.
 
  * The "exclude_list" structure has the usual "alloc, nr" pair of
-   fields to be used by ALLOC_GROW(), but clear_exclude_list() forgot
+   fields to be used by ALLOC_GROW(), but clear_pattern_list() forgot
    to reset 'alloc' to 0 when it cleared 'nr' to discard the managed
    array.
 
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/RelNotes/2.7.3.txt 1.2.3+git2.25.1-1/git/Documentation/RelNotes/2.7.3.txt
--- 1.2.1+git2.18.0-1/git/Documentation/RelNotes/2.7.3.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/RelNotes/2.7.3.txt	2020-02-17 04:47:35.000000000 +0000
@@ -20,7 +20,7 @@ Fixes since v2.7.2
    tests.
 
  * "git show 'HEAD:Foo[BAR]Baz'" did not interpret the argument as a
-   rev, i.e. the object named by the the pathname with wildcard
+   rev, i.e. the object named by the pathname with wildcard
    characters in a tree object.
 
  * "git rev-parse --git-common-dir" used in the worktree feature
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/RelNotes/2.8.0.txt 1.2.3+git2.25.1-1/git/Documentation/RelNotes/2.8.0.txt
--- 1.2.1+git2.18.0-1/git/Documentation/RelNotes/2.8.0.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/RelNotes/2.8.0.txt	2020-02-17 04:47:35.000000000 +0000
@@ -189,7 +189,7 @@ Performance, Internal Implementation, De
  * Some calls to strcpy(3) triggers a false warning from static
    analyzers that are less intelligent than humans, and reducing the
    number of these false hits helps us notice real issues.  A few
-   calls to strcpy(3) in a couple of protrams that are already safe
+   calls to strcpy(3) in a couple of programs that are already safe
    has been rewritten to avoid false warnings.
 
  * The "name_path" API was an attempt to reduce the need to construct
@@ -270,7 +270,7 @@ notes for details).
    setting GIT_WORK_TREE environment themselves.
 
  * The "exclude_list" structure has the usual "alloc, nr" pair of
-   fields to be used by ALLOC_GROW(), but clear_exclude_list() forgot
+   fields to be used by ALLOC_GROW(), but clear_pattern_list() forgot
    to reset 'alloc' to 0 when it cleared 'nr' to discard the managed
    array.
 
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/RelNotes/2.8.3.txt 1.2.3+git2.25.1-1/git/Documentation/RelNotes/2.8.3.txt
--- 1.2.1+git2.18.0-1/git/Documentation/RelNotes/2.8.3.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/RelNotes/2.8.3.txt	2020-02-17 04:47:35.000000000 +0000
@@ -55,8 +55,8 @@ Fixes since v2.8.2
    This is necessary to use Git on Windows shared directories, and is
    already enabled for the MinGW and plain Windows builds.  It also
    has been used in Cygwin packaged versions of Git for quite a while.
-   See http://thread.gmane.org/gmane.comp.version-control.git/291853
-   and http://thread.gmane.org/gmane.comp.version-control.git/275680.
+   See https://lore.kernel.org/git/20160419091055.GF2345@dinwoodie.org/
+   and https://lore.kernel.org/git/20150811100527.GW14466@dinwoodie.org/.
 
  * "git replace -e" did not honour "core.editor" configuration.
 
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/RelNotes/2.9.0.txt 1.2.3+git2.25.1-1/git/Documentation/RelNotes/2.9.0.txt
--- 1.2.1+git2.18.0-1/git/Documentation/RelNotes/2.9.0.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/RelNotes/2.9.0.txt	2020-02-17 04:47:35.000000000 +0000
@@ -368,7 +368,7 @@ notes for details).
    This is necessary to use Git on Windows shared directories, and is
    already enabled for the MinGW and plain Windows builds.  It also
    has been used in Cygwin packaged versions of Git for quite a while.
-   See http://thread.gmane.org/gmane.comp.version-control.git/291853
+   See https://lore.kernel.org/git/20160419091055.GF2345@dinwoodie.org/
 
  * "merge-octopus" strategy did not ensure that the index is clean
    when merge begins.
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/RelNotes/2.9.3.txt 1.2.3+git2.25.1-1/git/Documentation/RelNotes/2.9.3.txt
--- 1.2.1+git2.18.0-1/git/Documentation/RelNotes/2.9.3.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/RelNotes/2.9.3.txt	2020-02-17 04:47:35.000000000 +0000
@@ -36,7 +36,7 @@ Fixes since v2.9.2
  * One part of "git am" had an oddball helper function that called
    stuff from outside "his" as opposed to calling what we have "ours",
    which was not gender-neutral and also inconsistent with the rest of
-   the system where outside stuff is usuall called "theirs" in
+   the system where outside stuff is usually called "theirs" in
    contrast to "ours".
 
  * The test framework learned a new helper test_match_signal to
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/revisions.txt 1.2.3+git2.25.1-1/git/Documentation/revisions.txt
--- 1.2.1+git2.18.0-1/git/Documentation/revisions.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/revisions.txt	2020-02-17 04:47:35.000000000 +0000
@@ -58,14 +58,14 @@ when you run `git merge`.
 when you run `git cherry-pick`.
 +
 Note that any of the 'refs/*' cases above may come either from
-the '$GIT_DIR/refs' directory or from the '$GIT_DIR/packed-refs' file.
+the `$GIT_DIR/refs` directory or from the `$GIT_DIR/packed-refs` file.
 While the ref name encoding is unspecified, UTF-8 is preferred as
 some output processing may assume ref names in UTF-8.
 
 '@'::
   '@' alone is a shortcut for `HEAD`.
 
-'<refname>@{<date>}', e.g. 'master@\{yesterday\}', 'HEAD@{5 minutes ago}'::
+'[<refname>]@{<date>}', e.g. 'master@\{yesterday\}', 'HEAD@{5 minutes ago}'::
   A ref followed by the suffix '@' with a date specification
   enclosed in a brace
   pair (e.g. '\{yesterday\}', '{1 month 2 weeks 3 days 1 hour 1
@@ -95,7 +95,7 @@ some output processing may assume ref na
   The construct '@{-<n>}' means the <n>th branch/commit checked out
   before the current one.
 
-'<branchname>@\{upstream\}', e.g. 'master@\{upstream\}', '@\{u\}'::
+'[<branchname>]@\{upstream\}', e.g. 'master@\{upstream\}', '@\{u\}'::
   The suffix '@\{upstream\}' to a branchname (short form '<branchname>@\{u\}')
   refers to the branch that the branch specified by branchname is set to build on
   top of (configured with `branch.<name>.remote` and
@@ -103,19 +103,19 @@ some output processing may assume ref na
   current one. These suffixes are also accepted when spelled in uppercase, and
   they mean the same thing no matter the case.
 
-'<branchname>@\{push\}', e.g. 'master@\{push\}', '@\{push\}'::
+'[<branchname>]@\{push\}', e.g. 'master@\{push\}', '@\{push\}'::
   The suffix '@\{push}' reports the branch "where we would push to" if
   `git push` were run while `branchname` was checked out (or the current
   `HEAD` if no branchname is specified). Since our push destination is
   in a remote repository, of course, we report the local tracking branch
-  that corresponds to that branch (i.e., something in 'refs/remotes/').
+  that corresponds to that branch (i.e., something in `refs/remotes/`).
 +
 Here's an example to make it more clear:
 +
 ------------------------------
 $ git config push.default current
 $ git config remote.pushdefault myfork
-$ git checkout -b mybranch origin/master
+$ git switch -c mybranch origin/master
 
 $ git rev-parse --symbolic-full-name @{upstream}
 refs/remotes/origin/master
@@ -131,7 +131,7 @@ from one location and push to another. I
 This suffix is also accepted when spelled in uppercase, and means the same
 thing no matter the case.
 
-'<rev>{caret}', e.g. 'HEAD{caret}, v1.5.1{caret}0'::
+'<rev>{caret}[<n>]', e.g. 'HEAD{caret}, v1.5.1{caret}0'::
   A suffix '{caret}' to a revision parameter means the first parent of
   that commit object.  '{caret}<n>' means the <n>th parent (i.e.
   '<rev>{caret}'
@@ -139,7 +139,9 @@ thing no matter the case.
   '<rev>{caret}0' means the commit itself and is used when '<rev>' is the
   object name of a tag object that refers to a commit object.
 
-'<rev>{tilde}<n>', e.g. 'master{tilde}3'::
+'<rev>{tilde}[<n>]', e.g. 'HEAD{tilde}, master{tilde}3'::
+  A suffix '{tilde}' to a revision parameter means the first parent of
+  that commit object.
   A suffix '{tilde}<n>' to a revision parameter means the commit
   object that is the <n>th generation ancestor of the named
   commit object, following only the first parents.  I.e. '<rev>{tilde}3' is
@@ -159,12 +161,12 @@ thing no matter the case.
   '<rev>{caret}0'
   is a short-hand for '<rev>{caret}\{commit\}'.
 +
-'rev{caret}\{object\}' can be used to make sure 'rev' names an
-object that exists, without requiring 'rev' to be a tag, and
-without dereferencing 'rev'; because a tag is already an object,
+'<rev>{caret}\{object\}' can be used to make sure '<rev>' names an
+object that exists, without requiring '<rev>' to be a tag, and
+without dereferencing '<rev>'; because a tag is already an object,
 it does not have to be dereferenced even once to get to an object.
 +
-'rev{caret}\{tag\}' can be used to ensure that 'rev' identifies an
+'<rev>{caret}\{tag\}' can be used to ensure that '<rev>' identifies an
 existing tag object.
 
 '<rev>{caret}{}', e.g. 'v0.99.8{caret}{}'::
@@ -184,7 +186,8 @@ existing tag object.
   A colon, followed by a slash, followed by a text, names
   a commit whose commit message matches the specified regular expression.
   This name returns the youngest matching commit which is
-  reachable from any ref. The regular expression can match any part of the
+  reachable from any ref, including HEAD.
+  The regular expression can match any part of the
   commit message. To match messages starting with a string, one can use
   e.g. ':/^foo'. The special sequence ':/!' is reserved for modifiers to what
   is matched. ':/!-foo' performs a negative match, while ':/!!foo' matches a
@@ -193,19 +196,16 @@ existing tag object.
   Depending on the given text, the shell's word splitting rules might
   require additional quoting.
 
-'<rev>:<path>', e.g. 'HEAD:README', ':README', 'master:./README'::
+'<rev>:<path>', e.g. 'HEAD:README', 'master:./README'::
   A suffix ':' followed by a path names the blob or tree
   at the given path in the tree-ish object named by the part
   before the colon.
-  ':path' (with an empty part before the colon)
-  is a special case of the syntax described next: content
-  recorded in the index at the given path.
   A path starting with './' or '../' is relative to the current working directory.
   The given path will be converted to be relative to the working tree's root directory.
   This is most useful to address a blob or tree from a commit or tree that has
   the same tree structure as the working tree.
 
-':<n>:<path>', e.g. ':0:README', ':README'::
+':[<n>:]<path>', e.g. ':0:README', ':README'::
   A colon, optionally followed by a stage number (0 to 3) and a
   colon, followed by a path, names a blob object in the
   index at the given path. A missing stage number (and the colon
@@ -301,7 +301,7 @@ The 'r1{caret}@' notation means all pare
 The 'r1{caret}!' notation includes commit 'r1' but excludes all of its parents.
 By itself, this notation denotes the single commit 'r1'.
 
-The '<rev>{caret}-<n>' notation includes '<rev>' but excludes the <n>th
+The '<rev>{caret}-[<n>]' notation includes '<rev>' but excludes the <n>th
 parent (i.e. a shorthand for '<rev>{caret}<n>..<rev>'), with '<n>' = 1 if
 not given. This is typically useful for merge commits where you
 can just pass '<commit>{caret}-' to get all the commits in the branch
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/rev-list-options.txt 1.2.3+git2.25.1-1/git/Documentation/rev-list-options.txt
--- 1.2.1+git2.18.0-1/git/Documentation/rev-list-options.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/rev-list-options.txt	2020-02-17 04:47:35.000000000 +0000
@@ -13,8 +13,6 @@ has a line that matches `<pattern>`), un
 Note that these are applied before commit
 ordering and formatting options, such as `--reverse`.
 
---
-
 -<number>::
 -n <number>::
 --max-count=<number>::
@@ -60,7 +58,7 @@ endif::git-rev-list[]
 	`--all-match`).
 ifndef::git-rev-list[]
 +
-When `--show-notes` is in effect, the message from the notes is
+When `--notes` is in effect, the message from the notes is
 matched as if it were part of the log message.
 endif::git-rev-list[]
 
@@ -184,6 +182,14 @@ explicitly.
 	Pretend as if all objects mentioned by reflogs are listed on the
 	command line as `<commit>`.
 
+--alternate-refs::
+	Pretend as if all objects mentioned as ref tips of alternate
+	repositories were listed on the command line. An alternate
+	repository is any repository whose object directory is specified
+	in `objects/info/alternates`.  The set of included objects may
+	be modified by `core.alternateRefsCommand`, etc. See
+	linkgit:git-config[1].
+
 --single-worktree::
 	By default, all working trees will be examined by the
 	following options when there are more than one (see
@@ -263,7 +269,7 @@ list.
 	exclude (that is, '{caret}commit', 'commit1..commit2',
 	and 'commit1\...commit2' notations cannot be used).
 +
-With `--pretty` format other than `oneline` (for obvious reasons),
+With `--pretty` format other than `oneline` and `reference` (for obvious reasons),
 this causes the output to have two extra lines of information
 taken from the reflog.  The reflog designator in the output may be shown
 as `ref@{Nth}` (where `Nth` is the reverse-chronological index in the
@@ -272,13 +278,13 @@ depending on a few rules:
 +
 --
 1. If the starting point is specified as `ref@{Nth}`, show the index
-format.
+   format.
 +
 2. If the starting point was specified as `ref@{now}`, show the
-timestamp format.
+   timestamp format.
 +
 3. If neither was used, but `--date` was given on the command line, show
-the timestamp in the format requested by `--date`.
+   the timestamp in the format requested by `--date`.
 +
 4. Otherwise, show the index format.
 --
@@ -287,6 +293,8 @@ Under `--pretty=oneline`, the commit mes
 prefixed with this information on the same line.
 This option cannot be combined with `--reverse`.
 See also linkgit:git-reflog[1].
++
+Under `--pretty=reference`, this information will not be shown at all.
 
 --merge::
 	After a failed merge, show refs that touch files having a
@@ -308,8 +316,6 @@ ifdef::git-rev-list[]
 	`<header>` text will be printed with each progress update.
 endif::git-rev-list[]
 
---
-
 History Simplification
 ~~~~~~~~~~~~~~~~~~~~~~
 
@@ -575,6 +581,7 @@ above) if (1) they are referenced by tag
 contents of the paths given on the command line.  All other
 commits are marked as TREESAME (subject to be simplified away).
 
+ifndef::git-shortlog[]
 ifdef::git-rev-list[]
 Bisection Helpers
 ~~~~~~~~~~~~~~~~~
@@ -630,8 +637,9 @@ This option can be used along with `--bi
 after all the sorted commit objects, there will be the same text as if
 `--bisect-vars` had been used alone.
 endif::git-rev-list[]
+endif::git-shortlog[]
 
-
+ifndef::git-shortlog[]
 Commit Ordering
 ~~~~~~~~~~~~~~~
 
@@ -673,7 +681,9 @@ together.
 	Output the commits chosen to be shown (see Commit Limiting
 	section above) in reverse order. Cannot be combined with
 	`--walk-reflogs`.
+endif::git-shortlog[]
 
+ifndef::git-shortlog[]
 Object Traversal
 ~~~~~~~~~~~~~~~~
 
@@ -712,6 +722,16 @@ ifdef::git-rev-list[]
 	Only useful with `--objects`; print the object IDs that are not
 	in packs.
 
+--object-names::
+	Only useful with `--objects`; print the names of the object IDs
+	that are found. This is the default behavior.
+
+--no-object-names::
+	Only useful with `--objects`; does not print the names of the object
+	IDs that are found. This inverts `--object-names`. This flag allows
+	the output to be more easily parsed by commands such as
+	linkgit:git-cat-file[1].
+
 --filter=<filter-spec>::
 	Only useful with one of the `--objects*`; omits objects (usually
 	blobs) from the list of printed objects.  The '<filter-spec>'
@@ -729,15 +749,42 @@ specification contained in the blob (or
 to omit blobs that would not be not required for a sparse checkout on
 the requested refs.
 +
-The form '--filter=sparse:path=<path>' similarly uses a sparse-checkout
-specification contained in <path>.
+The form '--filter=tree:<depth>' omits all blobs and trees whose depth
+from the root tree is >= <depth> (minimum depth if an object is located
+at multiple depths in the commits traversed). <depth>=0 will not include
+any trees or blobs unless included explicitly in the command-line (or
+standard input when --stdin is used). <depth>=1 will include only the
+tree and blobs which are referenced directly by a commit reachable from
+<commit> or an explicitly-given object. <depth>=2 is like <depth>=1
+while also including trees and blobs one more level removed from an
+explicitly-given commit or tree.
++
+Note that the form '--filter=sparse:path=<path>' that wants to read
+from an arbitrary path on the filesystem has been dropped for security
+reasons.
++
+Multiple '--filter=' flags can be specified to combine filters. Only
+objects which are accepted by every filter are included.
++
+The form '--filter=combine:<filter1>+<filter2>+...<filterN>' can also be
+used to combined several filters, but this is harder than just repeating
+the '--filter' flag and is usually not necessary. Filters are joined by
+'{plus}' and individual filters are %-encoded (i.e. URL-encoded).
+Besides the '{plus}' and '%' characters, the following characters are
+reserved and also must be encoded: `~!@#$^&*()[]{}\;",<>?`+&#39;&#96;+
+as well as all characters with ASCII code &lt;= `0x20`, which includes
+space and newline.
++
+Other arbitrary characters can also be encoded. For instance,
+'combine:tree:3+blob:none' and 'combine:tree%3A3+blob%3Anone' are
+equivalent.
 
 --no-filter::
 	Turn off any previous `--filter=` argument.
 
 --filter-print-omitted::
 	Only useful with `--filter=`; prints a list of the objects omitted
-	by the filter.	Object IDs are prefixed with a ``~'' character.
+	by the filter.  Object IDs are prefixed with a ``~'' character.
 
 --missing=<missing-action>::
 	A debug option to help with future "partial clone" development.
@@ -756,7 +803,6 @@ Unexpected missing objects will raise an
 +
 The form '--missing=print' is like 'allow-any', but will also print a
 list of the missing objects.  Object IDs are prefixed with a ``?'' character.
-endif::git-rev-list[]
 
 --exclude-promisor-objects::
 	(For internal use only.)  Prefilter object traversal at
@@ -764,6 +810,7 @@ endif::git-rev-list[]
 	stronger than `--missing=allow-promisor` because it limits the
 	traversal, rather than just silencing errors about missing
 	objects.
+endif::git-rev-list[]
 
 --no-walk[=(sorted|unsorted)]::
 	Only show the given commits, but do not traverse their ancestors.
@@ -776,7 +823,9 @@ endif::git-rev-list[]
 
 --do-walk::
 	Overrides a previous `--no-walk`.
+endif::git-shortlog[]
 
+ifndef::git-shortlog[]
 Commit Formatting
 ~~~~~~~~~~~~~~~~~
 
@@ -799,12 +848,13 @@ include::pretty-options.txt[]
 	author's). If `-local` is appended to the format (e.g.,
 	`iso-local`), the user's local time zone is used instead.
 +
+--
 `--date=relative` shows dates relative to the current time,
 e.g. ``2 hours ago''. The `-local` option has no effect for
 `--date=relative`.
-+
+
 `--date=local` is an alias for `--date=default-local`.
-+
+
 `--date=iso` (or `--date=iso8601`) shows timestamps in a ISO 8601-like format.
 The differences to the strict ISO 8601 format are:
 
@@ -812,15 +862,14 @@ The differences to the strict ISO 8601 f
 	- a space between time and time zone
 	- no colon between hours and minutes of the time zone
 
-+
 `--date=iso-strict` (or `--date=iso8601-strict`) shows timestamps in strict
 ISO 8601 format.
-+
+
 `--date=rfc` (or `--date=rfc2822`) shows timestamps in RFC 2822
 format, often found in email messages.
-+
+
 `--date=short` shows only the date, but not the time, in `YYYY-MM-DD` format.
-+
+
 `--date=raw` shows the date as seconds since the epoch (1970-01-01
 00:00:00 UTC), followed by a space, and then the timezone as an offset
 from UTC (a `+` or `-` with four digits; the first two are hours, and
@@ -829,21 +878,28 @@ with `strftime("%s %z")`).
 Note that the `-local` option does not affect the seconds-since-epoch
 value (which is always measured in UTC), but does switch the accompanying
 timezone value.
-+
+
+`--date=human` shows the timezone if the timezone does not match the
+current time-zone, and doesn't print the whole date if that matches
+(ie skip printing year for dates that are "this year", but also skip
+the whole date itself if it's in the last few days and we can just say
+what weekday it was).  For older dates the hour and minute is also
+omitted.
+
 `--date=unix` shows the date as a Unix epoch timestamp (seconds since
 1970).  As with `--raw`, this is always in UTC and therefore `-local`
 has no effect.
-+
+
 `--date=format:...` feeds the format `...` to your system `strftime`,
 except for %z and %Z, which are handled internally.
 Use `--date=format:%c` to show the date in your system locale's
 preferred format.  See the `strftime` manual for a complete list of
 format placeholders. When using `-local`, the correct syntax is
 `--date=format-local:...`.
-+
+
 `--date=default` is the default format, and is similar to
 `--date=rfc2822`, with a few exceptions:
-
+--
 	- there is no comma after the day-of-week
 
 	- the time zone is omitted when the local time zone is used
@@ -925,7 +981,9 @@ ifdef::git-rev-list[]
 	counts and print the count for equivalent commits separated
 	by a tab.
 endif::git-rev-list[]
+endif::git-shortlog[]
 
+ifndef::git-shortlog[]
 ifndef::git-rev-list[]
 Diff Formatting
 ~~~~~~~~~~~~~~~
@@ -947,6 +1005,13 @@ options may be given. See linkgit:git-di
 	the parents have only two variants and the merge result picks
 	one of them without modification.
 
+--combined-all-paths::
+	This flag causes combined diffs (used for merge commits) to
+	list the name of the file from all parents.  It thus only has
+	effect when -c or --cc are specified, and is likely only
+	useful if filename changes are detected (i.e. when either
+	rename or copy detection have been requested).
+
 -m::
 	This flag makes the merge commits show the full diff like
 	regular commits; for each merge parent, a separate log entry
@@ -961,3 +1026,4 @@ options may be given. See linkgit:git-di
 -t::
 	Show the tree objects in the diff output. This implies `-r`.
 endif::git-rev-list[]
+endif::git-shortlog[]
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/sequencer.txt 1.2.3+git2.25.1-1/git/Documentation/sequencer.txt
--- 1.2.1+git2.18.0-1/git/Documentation/sequencer.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/sequencer.txt	2020-02-17 04:47:35.000000000 +0000
@@ -1,8 +1,12 @@
 --continue::
 	Continue the operation in progress using the information in
-	'.git/sequencer'.  Can be used to continue after resolving
+	`.git/sequencer`.  Can be used to continue after resolving
 	conflicts in a failed cherry-pick or revert.
 
+--skip::
+	Skip the current commit and continue with the rest of the
+	sequence.
+
 --quit::
 	Forget about the current operation in progress.  Can be used
 	to clear the sequencer state after a failed cherry-pick or
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/SubmittingPatches 1.2.3+git2.25.1-1/git/Documentation/SubmittingPatches
--- 1.2.1+git2.18.0-1/git/Documentation/SubmittingPatches	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/SubmittingPatches	2020-02-17 04:47:35.000000000 +0000
@@ -80,7 +80,9 @@ GitHub-Travis CI hints section for detai
 
 Do not forget to update the documentation to describe the updated
 behavior and make sure that the resulting documentation set formats
-well. It is currently a liberal mixture of US and UK English norms for
+well (try the Documentation/doc-diff script).
+
+We currently have a liberal mixture of US and UK English norms for
 spelling and grammar, which is somewhat unfortunate.  A huge patch that
 touches the files all over the place only to correct the inconsistency
 is not welcome, though.  Potential clashes with other changes that can
@@ -140,19 +142,25 @@ archive, summarize the relevant points o
 
 [[commit-reference]]
 If you want to reference a previous commit in the history of a stable
-branch, use the format "abbreviated sha1 (subject, date)",
-with the subject enclosed in a pair of double-quotes, like this:
+branch, use the format "abbreviated hash (subject, date)", like this:
 
 ....
-	Commit f86a374 ("pack-bitmap.c: fix a memleak", 2015-03-30)
+	Commit f86a374 (pack-bitmap.c: fix a memleak, 2015-03-30)
 	noticed that ...
 ....
 
 The "Copy commit summary" command of gitk can be used to obtain this
-format, or this invocation of `git show`:
+format (with the subject enclosed in a pair of double-quotes), or this
+invocation of `git show`:
+
+....
+	git show -s --pretty=reference <commit>
+....
+
+or, on an older version of Git without support for --pretty=reference:
 
 ....
-	git show -s --date=short --pretty='format:%h ("%s", %ad)' <commit>
+	git show -s --date=short --pretty='format:%h (%s, %ad)' <commit>
 ....
 
 [[git-tools]]
@@ -298,7 +306,7 @@ smaller project it is a good discipline
 
 The sign-off is a simple line at the end of the explanation for
 the patch, which certifies that you wrote it or otherwise have
-the right to pass it on as a open-source patch.  The rules are
+the right to pass it on as an open-source patch.  The rules are
 pretty simple: if you can certify the below D-C-O:
 
 [[dco]]
@@ -370,15 +378,15 @@ such as "Thanks-to:", "Based-on-patch-by
 Some parts of the system have dedicated maintainers with their own
 repositories.
 
-- 'git-gui/' comes from git-gui project, maintained by Pat Thoyts:
+- `git-gui/` comes from git-gui project, maintained by Pratyush Yadav:
 
-	git://repo.or.cz/git-gui.git
+	https://github.com/prati0100/git-gui.git
 
-- 'gitk-git/' comes from Paul Mackerras's gitk project:
+- `gitk-git/` comes from Paul Mackerras's gitk project:
 
 	git://ozlabs.org/~paulus/gitk
 
-- 'po/' comes from the localization coordinator, Jiang Xin:
+- `po/` comes from the localization coordinator, Jiang Xin:
 
 	https://github.com/git-l10n/git-po/
 
@@ -403,7 +411,7 @@ don't demand).  +git log -p {litdd} _$ar
 help you find out who they are.
 
 . You get comments and suggestions for improvements.  You may
-  even get them in a "on top of your change" patch form.
+  even get them in an "on top of your change" patch form.
 
 . Polish, refine, and re-send to the list and the people who
   spend their time to improve your patch.  Go back to step (2).
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/technical/api-allocation-growing.txt 1.2.3+git2.25.1-1/git/Documentation/technical/api-allocation-growing.txt
--- 1.2.1+git2.18.0-1/git/Documentation/technical/api-allocation-growing.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/technical/api-allocation-growing.txt	1970-01-01 00:00:00.000000000 +0000
@@ -1,39 +0,0 @@
-allocation growing API
-======================
-
-Dynamically growing an array using realloc() is error prone and boring.
-
-Define your array with:
-
-* a pointer (`item`) that points at the array, initialized to `NULL`
-  (although please name the variable based on its contents, not on its
-  type);
-
-* an integer variable (`alloc`) that keeps track of how big the current
-  allocation is, initialized to `0`;
-
-* another integer variable (`nr`) to keep track of how many elements the
-  array currently has, initialized to `0`.
-
-Then before adding `n`th element to the item, call `ALLOC_GROW(item, n,
-alloc)`.  This ensures that the array can hold at least `n` elements by
-calling `realloc(3)` and adjusting `alloc` variable.
-
-------------
-sometype *item;
-size_t nr;
-size_t alloc
-
-for (i = 0; i < nr; i++)
-	if (we like item[i] already)
-		return;
-
-/* we did not like any existing one, so add one */
-ALLOC_GROW(item, nr + 1, alloc);
-item[nr++] = value you like;
-------------
-
-You are responsible for updating the `nr` variable.
-
-If you need to specify the number of elements to allocate explicitly
-then use the macro `REALLOC_ARRAY(item, alloc)` instead of `ALLOC_GROW`.
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/technical/api-argv-array.txt 1.2.3+git2.25.1-1/git/Documentation/technical/api-argv-array.txt
--- 1.2.1+git2.18.0-1/git/Documentation/technical/api-argv-array.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/technical/api-argv-array.txt	1970-01-01 00:00:00.000000000 +0000
@@ -1,65 +0,0 @@
-argv-array API
-==============
-
-The argv-array API allows one to dynamically build and store
-NULL-terminated lists.  An argv-array maintains the invariant that the
-`argv` member always points to a non-NULL array, and that the array is
-always NULL-terminated at the element pointed to by `argv[argc]`. This
-makes the result suitable for passing to functions expecting to receive
-argv from main(), or the link:api-run-command.html[run-command API].
-
-The string-list API (documented in string-list.h) is similar, but cannot be
-used for these purposes; instead of storing a straight string pointer,
-it contains an item structure with a `util` field that is not compatible
-with the traditional argv interface.
-
-Each `argv_array` manages its own memory. Any strings pushed into the
-array are duplicated, and all memory is freed by argv_array_clear().
-
-Data Structures
----------------
-
-`struct argv_array`::
-
-	A single array. This should be initialized by assignment from
-	`ARGV_ARRAY_INIT`, or by calling `argv_array_init`. The `argv`
-	member contains the actual array; the `argc` member contains the
-	number of elements in the array, not including the terminating
-	NULL.
-
-Functions
----------
-
-`argv_array_init`::
-	Initialize an array. This is no different than assigning from
-	`ARGV_ARRAY_INIT`.
-
-`argv_array_push`::
-	Push a copy of a string onto the end of the array.
-
-`argv_array_pushl`::
-	Push a list of strings onto the end of the array. The arguments
-	should be a list of `const char *` strings, terminated by a NULL
-	argument.
-
-`argv_array_pushf`::
-	Format a string and push it onto the end of the array. This is a
-	convenience wrapper combining `strbuf_addf` and `argv_array_push`.
-
-`argv_array_pushv`::
-	Push a null-terminated array of strings onto the end of the array.
-
-`argv_array_pop`::
-	Remove the final element from the array. If there are no
-	elements in the array, do nothing.
-
-`argv_array_clear`::
-	Free all memory associated with the array and return it to the
-	initial, empty state.
-
-`argv_array_detach`::
-	Disconnect the `argv` member from the `argv_array` struct and
-	return it. The caller is responsible for freeing the memory used
-	by the array, and by the strings it references. After detaching,
-	the `argv_array` is in a reinitialized state and can be pushed
-	into again.
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/technical/api-config.txt 1.2.3+git2.25.1-1/git/Documentation/technical/api-config.txt
--- 1.2.1+git2.18.0-1/git/Documentation/technical/api-config.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/technical/api-config.txt	1970-01-01 00:00:00.000000000 +0000
@@ -1,319 +0,0 @@
-config API
-==========
-
-The config API gives callers a way to access Git configuration files
-(and files which have the same syntax). See linkgit:git-config[1] for a
-discussion of the config file syntax.
-
-General Usage
--------------
-
-Config files are parsed linearly, and each variable found is passed to a
-caller-provided callback function. The callback function is responsible
-for any actions to be taken on the config option, and is free to ignore
-some options. It is not uncommon for the configuration to be parsed
-several times during the run of a Git program, with different callbacks
-picking out different variables useful to themselves.
-
-A config callback function takes three parameters:
-
-- the name of the parsed variable. This is in canonical "flat" form: the
-  section, subsection, and variable segments will be separated by dots,
-  and the section and variable segments will be all lowercase. E.g.,
-  `core.ignorecase`, `diff.SomeType.textconv`.
-
-- the value of the found variable, as a string. If the variable had no
-  value specified, the value will be NULL (typically this means it
-  should be interpreted as boolean true).
-
-- a void pointer passed in by the caller of the config API; this can
-  contain callback-specific data
-
-A config callback should return 0 for success, or -1 if the variable
-could not be parsed properly.
-
-Basic Config Querying
----------------------
-
-Most programs will simply want to look up variables in all config files
-that Git knows about, using the normal precedence rules. To do this,
-call `git_config` with a callback function and void data pointer.
-
-`git_config` will read all config sources in order of increasing
-priority. Thus a callback should typically overwrite previously-seen
-entries with new ones (e.g., if both the user-wide `~/.gitconfig` and
-repo-specific `.git/config` contain `color.ui`, the config machinery
-will first feed the user-wide one to the callback, and then the
-repo-specific one; by overwriting, the higher-priority repo-specific
-value is left at the end).
-
-The `config_with_options` function lets the caller examine config
-while adjusting some of the default behavior of `git_config`. It should
-almost never be used by "regular" Git code that is looking up
-configuration variables. It is intended for advanced callers like
-`git-config`, which are intentionally tweaking the normal config-lookup
-process. It takes two extra parameters:
-
-`config_source`::
-If this parameter is non-NULL, it specifies the source to parse for
-configuration, rather than looking in the usual files. See `struct
-git_config_source` in `config.h` for details. Regular `git_config` defaults
-to `NULL`.
-
-`opts`::
-Specify options to adjust the behavior of parsing config files. See `struct
-config_options` in `config.h` for details. As an example: regular `git_config`
-sets `opts.respect_includes` to `1` by default.
-
-Reading Specific Files
-----------------------
-
-To read a specific file in git-config format, use
-`git_config_from_file`. This takes the same callback and data parameters
-as `git_config`.
-
-Querying For Specific Variables
--------------------------------
-
-For programs wanting to query for specific variables in a non-callback
-manner, the config API provides two functions `git_config_get_value`
-and `git_config_get_value_multi`. They both read values from an internal
-cache generated previously from reading the config files.
-
-`int git_config_get_value(const char *key, const char **value)`::
-
-	Finds the highest-priority value for the configuration variable `key`,
-	stores the pointer to it in `value` and returns 0. When the
-	configuration variable `key` is not found, returns 1 without touching
-	`value`. The caller should not free or modify `value`, as it is owned
-	by the cache.
-
-`const struct string_list *git_config_get_value_multi(const char *key)`::
-
-	Finds and returns the value list, sorted in order of increasing priority
-	for the configuration variable `key`. When the configuration variable
-	`key` is not found, returns NULL. The caller should not free or modify
-	the returned pointer, as it is owned by the cache.
-
-`void git_config_clear(void)`::
-
-	Resets and invalidates the config cache.
-
-The config API also provides type specific API functions which do conversion
-as well as retrieval for the queried variable, including:
-
-`int git_config_get_int(const char *key, int *dest)`::
-
-	Finds and parses the value to an integer for the configuration variable
-	`key`. Dies on error; otherwise, stores the value of the parsed integer in
-	`dest` and returns 0. When the configuration variable `key` is not found,
-	returns 1 without touching `dest`.
-
-`int git_config_get_ulong(const char *key, unsigned long *dest)`::
-
-	Similar to `git_config_get_int` but for unsigned longs.
-
-`int git_config_get_bool(const char *key, int *dest)`::
-
-	Finds and parses the value into a boolean value, for the configuration
-	variable `key` respecting keywords like "true" and "false". Integer
-	values are converted into true/false values (when they are non-zero or
-	zero, respectively). Other values cause a die(). If parsing is successful,
-	stores the value of the parsed result in `dest` and returns 0. When the
-	configuration variable `key` is not found, returns 1 without touching
-	`dest`.
-
-`int git_config_get_bool_or_int(const char *key, int *is_bool, int *dest)`::
-
-	Similar to `git_config_get_bool`, except that integers are copied as-is,
-	and `is_bool` flag is unset.
-
-`int git_config_get_maybe_bool(const char *key, int *dest)`::
-
-	Similar to `git_config_get_bool`, except that it returns -1 on error
-	rather than dying.
-
-`int git_config_get_string_const(const char *key, const char **dest)`::
-
-	Allocates and copies the retrieved string into the `dest` parameter for
-	the configuration variable `key`; if NULL string is given, prints an
-	error message and returns -1. When the configuration variable `key` is
-	not found, returns 1 without touching `dest`.
-
-`int git_config_get_string(const char *key, char **dest)`::
-
-	Similar to `git_config_get_string_const`, except that retrieved value
-	copied into the `dest` parameter is a mutable string.
-
-`int git_config_get_pathname(const char *key, const char **dest)`::
-
-	Similar to `git_config_get_string`, but expands `~` or `~user` into
-	the user's home directory when found at the beginning of the path.
-
-`git_die_config(const char *key, const char *err, ...)`::
-
-	First prints the error message specified by the caller in `err` and then
-	dies printing the line number and the file name of the highest priority
-	value for the configuration variable `key`.
-
-`void git_die_config_linenr(const char *key, const char *filename, int linenr)`::
-
-	Helper function which formats the die error message according to the
-	parameters entered. Used by `git_die_config()`. It can be used by callers
-	handling `git_config_get_value_multi()` to print the correct error message
-	for the desired value.
-
-See test-config.c for usage examples.
-
-Value Parsing Helpers
----------------------
-
-To aid in parsing string values, the config API provides callbacks with
-a number of helper functions, including:
-
-`git_config_int`::
-Parse the string to an integer, including unit factors. Dies on error;
-otherwise, returns the parsed result.
-
-`git_config_ulong`::
-Identical to `git_config_int`, but for unsigned longs.
-
-`git_config_bool`::
-Parse a string into a boolean value, respecting keywords like "true" and
-"false". Integer values are converted into true/false values (when they
-are non-zero or zero, respectively). Other values cause a die(). If
-parsing is successful, the return value is the result.
-
-`git_config_bool_or_int`::
-Same as `git_config_bool`, except that integers are returned as-is, and
-an `is_bool` flag is unset.
-
-`git_parse_maybe_bool`::
-Same as `git_config_bool`, except that it returns -1 on error rather
-than dying.
-
-`git_config_string`::
-Allocates and copies the value string into the `dest` parameter; if no
-string is given, prints an error message and returns -1.
-
-`git_config_pathname`::
-Similar to `git_config_string`, but expands `~` or `~user` into the
-user's home directory when found at the beginning of the path.
-
-Include Directives
-------------------
-
-By default, the config parser does not respect include directives.
-However, a caller can use the special `git_config_include` wrapper
-callback to support them. To do so, you simply wrap your "real" callback
-function and data pointer in a `struct config_include_data`, and pass
-the wrapper to the regular config-reading functions. For example:
-
--------------------------------------------
-int read_file_with_include(const char *file, config_fn_t fn, void *data)
-{
-	struct config_include_data inc = CONFIG_INCLUDE_INIT;
-	inc.fn = fn;
-	inc.data = data;
-	return git_config_from_file(git_config_include, file, &inc);
-}
--------------------------------------------
-
-`git_config` respects includes automatically. The lower-level
-`git_config_from_file` does not.
-
-Custom Configsets
------------------
-
-A `config_set` can be used to construct an in-memory cache for
-config-like files that the caller specifies (i.e., files like `.gitmodules`,
-`~/.gitconfig` etc.). For example,
-
----------------------------------------
-struct config_set gm_config;
-git_configset_init(&gm_config);
-int b;
-/* we add config files to the config_set */
-git_configset_add_file(&gm_config, ".gitmodules");
-git_configset_add_file(&gm_config, ".gitmodules_alt");
-
-if (!git_configset_get_bool(gm_config, "submodule.frotz.ignore", &b)) {
-	/* hack hack hack */
-}
-
-/* when we are done with the configset */
-git_configset_clear(&gm_config);
-----------------------------------------
-
-Configset API provides functions for the above mentioned work flow, including:
-
-`void git_configset_init(struct config_set *cs)`::
-
-	Initializes the config_set `cs`.
-
-`int git_configset_add_file(struct config_set *cs, const char *filename)`::
-
-	Parses the file and adds the variable-value pairs to the `config_set`,
-	dies if there is an error in parsing the file. Returns 0 on success, or
-	-1 if the file does not exist or is inaccessible. The user has to decide
-	if he wants to free the incomplete configset or continue using it when
-	the function returns -1.
-
-`int git_configset_get_value(struct config_set *cs, const char *key, const char **value)`::
-
-	Finds the highest-priority value for the configuration variable `key`
-	and config set `cs`, stores the pointer to it in `value` and returns 0.
-	When the configuration variable `key` is not found, returns 1 without
-	touching `value`. The caller should not free or modify `value`, as it
-	is owned by the cache.
-
-`const struct string_list *git_configset_get_value_multi(struct config_set *cs, const char *key)`::
-
-	Finds and returns the value list, sorted in order of increasing priority
-	for the configuration variable `key` and config set `cs`. When the
-	configuration variable `key` is not found, returns NULL. The caller
-	should not free or modify the returned pointer, as it is owned by the cache.
-
-`void git_configset_clear(struct config_set *cs)`::
-
-	Clears `config_set` structure, removes all saved variable-value pairs.
-
-In addition to above functions, the `config_set` API provides type specific
-functions in the vein of `git_config_get_int` and family but with an extra
-parameter, pointer to struct `config_set`.
-They all behave similarly to the `git_config_get*()` family described in
-"Querying For Specific Variables" above.
-
-Writing Config Files
---------------------
-
-Git gives multiple entry points in the Config API to write config values to
-files namely `git_config_set_in_file` and `git_config_set`, which write to
-a specific config file or to `.git/config` respectively. They both take a
-key/value pair as parameter.
-In the end they both call `git_config_set_multivar_in_file` which takes four
-parameters:
-
-- the name of the file, as a string, to which key/value pairs will be written.
-
-- the name of key, as a string. This is in canonical "flat" form: the section,
-  subsection, and variable segments will be separated by dots, and the section
-  and variable segments will be all lowercase.
-  E.g., `core.ignorecase`, `diff.SomeType.textconv`.
-
-- the value of the variable, as a string. If value is equal to NULL, it will
-  remove the matching key from the config file.
-
-- the value regex, as a string. It will disregard key/value pairs where value
-  does not match.
-
-- a multi_replace value, as an int. If value is equal to zero, nothing or only
-  one matching key/value is replaced, else all matching key/values (regardless
-  how many) are removed, before the new pair is written.
-
-It returns 0 on success.
-
-Also, there are functions `git_config_rename_section` and
-`git_config_rename_section_in_file` with parameters `old_name` and `new_name`
-for renaming or removing sections in the config files. If NULL is passed
-through `new_name` parameter, the section will be removed from the config file.
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/technical/api-credentials.txt 1.2.3+git2.25.1-1/git/Documentation/technical/api-credentials.txt
--- 1.2.1+git2.18.0-1/git/Documentation/technical/api-credentials.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/technical/api-credentials.txt	1970-01-01 00:00:00.000000000 +0000
@@ -1,271 +0,0 @@
-credentials API
-===============
-
-The credentials API provides an abstracted way of gathering username and
-password credentials from the user (even though credentials in the wider
-world can take many forms, in this document the word "credential" always
-refers to a username and password pair).
-
-This document describes two interfaces: the C API that the credential
-subsystem provides to the rest of Git, and the protocol that Git uses to
-communicate with system-specific "credential helpers". If you are
-writing Git code that wants to look up or prompt for credentials, see
-the section "C API" below. If you want to write your own helper, see
-the section on "Credential Helpers" below.
-
-Typical setup
--------------
-
-------------
-+-----------------------+
-| Git code (C)          |--- to server requiring --->
-|                       |        authentication
-|.......................|
-| C credential API      |--- prompt ---> User
-+-----------------------+
-	^      |
-	| pipe |
-	|      v
-+-----------------------+
-| Git credential helper |
-+-----------------------+
-------------
-
-The Git code (typically a remote-helper) will call the C API to obtain
-credential data like a login/password pair (credential_fill). The
-API will itself call a remote helper (e.g. "git credential-cache" or
-"git credential-store") that may retrieve credential data from a
-store. If the credential helper cannot find the information, the C API
-will prompt the user. Then, the caller of the API takes care of
-contacting the server, and does the actual authentication.
-
-C API
------
-
-The credential C API is meant to be called by Git code which needs to
-acquire or store a credential. It is centered around an object
-representing a single credential and provides three basic operations:
-fill (acquire credentials by calling helpers and/or prompting the user),
-approve (mark a credential as successfully used so that it can be stored
-for later use), and reject (mark a credential as unsuccessful so that it
-can be erased from any persistent storage).
-
-Data Structures
-~~~~~~~~~~~~~~~
-
-`struct credential`::
-
-	This struct represents a single username/password combination
-	along with any associated context. All string fields should be
-	heap-allocated (or NULL if they are not known or not applicable).
-	The meaning of the individual context fields is the same as
-	their counterparts in the helper protocol; see the section below
-	for a description of each field.
-+
-The `helpers` member of the struct is a `string_list` of helpers.  Each
-string specifies an external helper which will be run, in order, to
-either acquire or store credentials. See the section on credential
-helpers below. This list is filled-in by the API functions
-according to the corresponding configuration variables before
-consulting helpers, so there usually is no need for a caller to
-modify the helpers field at all.
-+
-This struct should always be initialized with `CREDENTIAL_INIT` or
-`credential_init`.
-
-
-Functions
-~~~~~~~~~
-
-`credential_init`::
-
-	Initialize a credential structure, setting all fields to empty.
-
-`credential_clear`::
-
-	Free any resources associated with the credential structure,
-	returning it to a pristine initialized state.
-
-`credential_fill`::
-
-	Instruct the credential subsystem to fill the username and
-	password fields of the passed credential struct by first
-	consulting helpers, then asking the user. After this function
-	returns, the username and password fields of the credential are
-	guaranteed to be non-NULL. If an error occurs, the function will
-	die().
-
-`credential_reject`::
-
-	Inform the credential subsystem that the provided credentials
-	have been rejected. This will cause the credential subsystem to
-	notify any helpers of the rejection (which allows them, for
-	example, to purge the invalid credentials from storage).  It
-	will also free() the username and password fields of the
-	credential and set them to NULL (readying the credential for
-	another call to `credential_fill`). Any errors from helpers are
-	ignored.
-
-`credential_approve`::
-
-	Inform the credential subsystem that the provided credentials
-	were successfully used for authentication.  This will cause the
-	credential subsystem to notify any helpers of the approval, so
-	that they may store the result to be used again.  Any errors
-	from helpers are ignored.
-
-`credential_from_url`::
-
-	Parse a URL into broken-down credential fields.
-
-Example
-~~~~~~~
-
-The example below shows how the functions of the credential API could be
-used to login to a fictitious "foo" service on a remote host:
-
------------------------------------------------------------------------
-int foo_login(struct foo_connection *f)
-{
-	int status;
-	/*
-	 * Create a credential with some context; we don't yet know the
-	 * username or password.
-	 */
-
-	struct credential c = CREDENTIAL_INIT;
-	c.protocol = xstrdup("foo");
-	c.host = xstrdup(f->hostname);
-
-	/*
-	 * Fill in the username and password fields by contacting
-	 * helpers and/or asking the user. The function will die if it
-	 * fails.
-	 */
-	credential_fill(&c);
-
-	/*
-	 * Otherwise, we have a username and password. Try to use it.
-	 */
-	status = send_foo_login(f, c.username, c.password);
-	switch (status) {
-	case FOO_OK:
-		/* It worked. Store the credential for later use. */
-		credential_accept(&c);
-		break;
-	case FOO_BAD_LOGIN:
-		/* Erase the credential from storage so we don't try it
-		 * again. */
-		credential_reject(&c);
-		break;
-	default:
-		/*
-		 * Some other error occurred. We don't know if the
-		 * credential is good or bad, so report nothing to the
-		 * credential subsystem.
-		 */
-	}
-
-	/* Free any associated resources. */
-	credential_clear(&c);
-
-	return status;
-}
------------------------------------------------------------------------
-
-
-Credential Helpers
-------------------
-
-Credential helpers are programs executed by Git to fetch or save
-credentials from and to long-term storage (where "long-term" is simply
-longer than a single Git process; e.g., credentials may be stored
-in-memory for a few minutes, or indefinitely on disk).
-
-Each helper is specified by a single string in the configuration
-variable `credential.helper` (and others, see linkgit:git-config[1]).
-The string is transformed by Git into a command to be executed using
-these rules:
-
-  1. If the helper string begins with "!", it is considered a shell
-     snippet, and everything after the "!" becomes the command.
-
-  2. Otherwise, if the helper string begins with an absolute path, the
-     verbatim helper string becomes the command.
-
-  3. Otherwise, the string "git credential-" is prepended to the helper
-     string, and the result becomes the command.
-
-The resulting command then has an "operation" argument appended to it
-(see below for details), and the result is executed by the shell.
-
-Here are some example specifications:
-
-----------------------------------------------------
-# run "git credential-foo"
-foo
-
-# same as above, but pass an argument to the helper
-foo --bar=baz
-
-# the arguments are parsed by the shell, so use shell
-# quoting if necessary
-foo --bar="whitespace arg"
-
-# you can also use an absolute path, which will not use the git wrapper
-/path/to/my/helper --with-arguments
-
-# or you can specify your own shell snippet
-!f() { echo "password=`cat $HOME/.secret`"; }; f
-----------------------------------------------------
-
-Generally speaking, rule (3) above is the simplest for users to specify.
-Authors of credential helpers should make an effort to assist their
-users by naming their program "git-credential-$NAME", and putting it in
-the $PATH or $GIT_EXEC_PATH during installation, which will allow a user
-to enable it with `git config credential.helper $NAME`.
-
-When a helper is executed, it will have one "operation" argument
-appended to its command line, which is one of:
-
-`get`::
-
-	Return a matching credential, if any exists.
-
-`store`::
-
-	Store the credential, if applicable to the helper.
-
-`erase`::
-
-	Remove a matching credential, if any, from the helper's storage.
-
-The details of the credential will be provided on the helper's stdin
-stream. The exact format is the same as the input/output format of the
-`git credential` plumbing command (see the section `INPUT/OUTPUT
-FORMAT` in linkgit:git-credential[1] for a detailed specification).
-
-For a `get` operation, the helper should produce a list of attributes
-on stdout in the same format. A helper is free to produce a subset, or
-even no values at all if it has nothing useful to provide. Any provided
-attributes will overwrite those already known about by Git.  If a helper
-outputs a `quit` attribute with a value of `true` or `1`, no further
-helpers will be consulted, nor will the user be prompted (if no
-credential has been provided, the operation will then fail).
-
-For a `store` or `erase` operation, the helper's output is ignored.
-If it fails to perform the requested operation, it may complain to
-stderr to inform the user. If it does not support the requested
-operation (e.g., a read-only store), it should silently ignore the
-request.
-
-If a helper receives any other operation, it should silently ignore the
-request. This leaves room for future operations to be added (older
-helpers will just ignore the new requests).
-
-See also
---------
-
-linkgit:gitcredentials[7]
-
-linkgit:git-config[1] (See configuration variables `credential.*`)
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/technical/api-diff.txt 1.2.3+git2.25.1-1/git/Documentation/technical/api-diff.txt
--- 1.2.1+git2.18.0-1/git/Documentation/technical/api-diff.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/technical/api-diff.txt	1970-01-01 00:00:00.000000000 +0000
@@ -1,174 +0,0 @@
-diff API
-========
-
-The diff API is for programs that compare two sets of files (e.g. two
-trees, one tree and the index) and present the found difference in
-various ways.  The calling program is responsible for feeding the API
-pairs of files, one from the "old" set and the corresponding one from
-"new" set, that are different.  The library called through this API is
-called diffcore, and is responsible for two things.
-
-* finding total rewrites (`-B`), renames (`-M`) and copies (`-C`), and
-  changes that touch a string (`-S`), as specified by the caller.
-
-* outputting the differences in various formats, as specified by the
-  caller.
-
-Calling sequence
-----------------
-
-* Prepare `struct diff_options` to record the set of diff options, and
-  then call `diff_setup()` to initialize this structure.  This sets up
-  the vanilla default.
-
-* Fill in the options structure to specify desired output format, rename
-  detection, etc.  `diff_opt_parse()` can be used to parse options given
-  from the command line in a way consistent with existing git-diff
-  family of programs.
-
-* Call `diff_setup_done()`; this inspects the options set up so far for
-  internal consistency and make necessary tweaking to it (e.g. if
-  textual patch output was asked, recursive behaviour is turned on);
-  the callback set_default in diff_options can be used to tweak this more.
-
-* As you find different pairs of files, call `diff_change()` to feed
-  modified files, `diff_addremove()` to feed created or deleted files,
-  or `diff_unmerge()` to feed a file whose state is 'unmerged' to the
-  API.  These are thin wrappers to a lower-level `diff_queue()` function
-  that is flexible enough to record any of these kinds of changes.
-
-* Once you finish feeding the pairs of files, call `diffcore_std()`.
-  This will tell the diffcore library to go ahead and do its work.
-
-* Calling `diff_flush()` will produce the output.
-
-
-Data structures
----------------
-
-* `struct diff_filespec`
-
-This is the internal representation for a single file (blob).  It
-records the blob object name (if known -- for a work tree file it
-typically is a NUL SHA-1), filemode and pathname.  This is what the
-`diff_addremove()`, `diff_change()` and `diff_unmerge()` synthesize and
-feed `diff_queue()` function with.
-
-* `struct diff_filepair`
-
-This records a pair of `struct diff_filespec`; the filespec for a file
-in the "old" set (i.e. preimage) is called `one`, and the filespec for a
-file in the "new" set (i.e. postimage) is called `two`.  A change that
-represents file creation has NULL in `one`, and file deletion has NULL
-in `two`.
-
-A `filepair` starts pointing at `one` and `two` that are from the same
-filename, but `diffcore_std()` can break pairs and match component
-filespecs with other filespecs from a different filepair to form new
-filepair.  This is called 'rename detection'.
-
-* `struct diff_queue`
-
-This is a collection of filepairs.  Notable members are:
-
-`queue`::
-
-	An array of pointers to `struct diff_filepair`.  This
-	dynamically grows as you add filepairs;
-
-`alloc`::
-
-	The allocated size of the `queue` array;
-
-`nr`::
-
-	The number of elements in the `queue` array.
-
-
-* `struct diff_options`
-
-This describes the set of options the calling program wants to affect
-the operation of diffcore library with.
-
-Notable members are:
-
-`output_format`::
-	The output format used when `diff_flush()` is run.
-
-`context`::
-	Number of context lines to generate in patch output.
-
-`break_opt`, `detect_rename`, `rename-score`, `rename_limit`::
-	Affects the way detection logic for complete rewrites, renames
-	and copies.
-
-`abbrev`::
-	Number of hexdigits to abbreviate raw format output to.
-
-`pickaxe`::
-	A constant string (can and typically does contain newlines to
-	look for a block of text, not just a single line) to filter out
-	the filepairs that do not change the number of strings contained
-	in its preimage and postimage of the diff_queue.
-
-`flags`::
-	This is mostly a collection of boolean options that affects the
-	operation, but some do not have anything to do with the diffcore
-	library.
-
-`touched_flags`::
-	Records whether a flag has been changed due to user request
-	(rather than just set/unset by default).
-
-`set_default`::
-	Callback which allows tweaking the options in diff_setup_done().
-
-BINARY, TEXT;;
-	Affects the way how a file that is seemingly binary is treated.
-
-FULL_INDEX;;
-	Tells the patch output format not to use abbreviated object
-	names on the "index" lines.
-
-FIND_COPIES_HARDER;;
-	Tells the diffcore library that the caller is feeding unchanged
-	filepairs to allow copies from unmodified files be detected.
-
-COLOR_DIFF;;
-	Output should be colored.
-
-COLOR_DIFF_WORDS;;
-	Output is a colored word-diff.
-
-NO_INDEX;;
-	Tells diff-files that the input is not tracked files but files
-	in random locations on the filesystem.
-
-ALLOW_EXTERNAL;;
-	Tells output routine that it is Ok to call user specified patch
-	output routine.  Plumbing disables this to ensure stable output.
-
-QUIET;;
-	Do not show any output.
-
-REVERSE_DIFF;;
-	Tells the library that the calling program is feeding the
-	filepairs reversed; `one` is two, and `two` is one.
-
-EXIT_WITH_STATUS;;
-	For communication between the calling program and the options
-	parser; tell the calling program to signal the presence of
-	difference using program exit code.
-
-HAS_CHANGES;;
-	Internal; used for optimization to see if there is any change.
-
-SILENT_ON_REMOVE;;
-	Affects if diff-files shows removed files.
-
-RECURSIVE, TREE_IN_RECURSIVE;;
-	Tells if tree traversal done by tree-diff should recursively
-	descend into a tree object pair that are different in preimage
-	and postimage set.
-
-(JC)
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/technical/api-directory-listing.txt 1.2.3+git2.25.1-1/git/Documentation/technical/api-directory-listing.txt
--- 1.2.1+git2.18.0-1/git/Documentation/technical/api-directory-listing.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/technical/api-directory-listing.txt	1970-01-01 00:00:00.000000000 +0000
@@ -1,130 +0,0 @@
-directory listing API
-=====================
-
-The directory listing API is used to enumerate paths in the work tree,
-optionally taking `.git/info/exclude` and `.gitignore` files per
-directory into account.
-
-Data structure
---------------
-
-`struct dir_struct` structure is used to pass directory traversal
-options to the library and to record the paths discovered.  A single
-`struct dir_struct` is used regardless of whether or not the traversal
-recursively descends into subdirectories.
-
-The notable options are:
-
-`exclude_per_dir`::
-
-	The name of the file to be read in each directory for excluded
-	files (typically `.gitignore`).
-
-`flags`::
-
-	A bit-field of options:
-
-`DIR_SHOW_IGNORED`:::
-
-	Return just ignored files in `entries[]`, not untracked
-	files. This flag is mutually exclusive with
-	`DIR_SHOW_IGNORED_TOO`.
-
-`DIR_SHOW_IGNORED_TOO`:::
-
-	Similar to `DIR_SHOW_IGNORED`, but return ignored files in
-	`ignored[]` in addition to untracked files in
-	`entries[]`. This flag is mutually exclusive with
-	`DIR_SHOW_IGNORED`.
-
-`DIR_KEEP_UNTRACKED_CONTENTS`:::
-
-	Only has meaning if `DIR_SHOW_IGNORED_TOO` is also set; if this is set, the
-	untracked contents of untracked directories are also returned in
-	`entries[]`.
-
-`DIR_SHOW_IGNORED_TOO_MODE_MATCHING`:::
-
-	Only has meaning if `DIR_SHOW_IGNORED_TOO` is also set; if
-	this is set, returns ignored files and directories that match
-	an exclude pattern. If a directory matches an exclude pattern,
-	then the directory is returned and the contained paths are
-	not. A directory that does not match an exclude pattern will
-	not be returned even if all of its contents are ignored. In
-	this case, the contents are returned as individual entries.
-+
-If this is set, files and directories that explicitly match an ignore
-pattern are reported. Implicity ignored directories (directories that
-do not match an ignore pattern, but whose contents are all ignored)
-are not reported, instead all of the contents are reported.
-
-`DIR_COLLECT_IGNORED`:::
-
-	Special mode for git-add. Return ignored files in `ignored[]` and
-	untracked files in `entries[]`. Only returns ignored files that match
-	pathspec exactly (no wildcards). Does not recurse into ignored
-	directories.
-
-`DIR_SHOW_OTHER_DIRECTORIES`:::
-
-	Include a directory that is not tracked.
-
-`DIR_HIDE_EMPTY_DIRECTORIES`:::
-
-	Do not include a directory that is not tracked and is empty.
-
-`DIR_NO_GITLINKS`:::
-
-	If set, recurse into a directory that looks like a Git
-	directory.  Otherwise it is shown as a directory.
-
-The result of the enumeration is left in these fields:
-
-`entries[]`::
-
-	An array of `struct dir_entry`, each element of which describes
-	a path.
-
-`nr`::
-
-	The number of members in `entries[]` array.
-
-`alloc`::
-
-	Internal use; keeps track of allocation of `entries[]` array.
-
-`ignored[]`::
-
-	An array of `struct dir_entry`, used for ignored paths with the
-	`DIR_SHOW_IGNORED_TOO` and `DIR_COLLECT_IGNORED` flags.
-
-`ignored_nr`::
-
-	The number of members in `ignored[]` array.
-
-Calling sequence
-----------------
-
-Note: index may be looked at for .gitignore files that are CE_SKIP_WORKTREE
-marked. If you to exclude files, make sure you have loaded index first.
-
-* Prepare `struct dir_struct dir` and clear it with `memset(&dir, 0,
-  sizeof(dir))`.
-
-* To add single exclude pattern, call `add_exclude_list()` and then
-  `add_exclude()`.
-
-* To add patterns from a file (e.g. `.git/info/exclude`), call
-  `add_excludes_from_file()` , and/or set `dir.exclude_per_dir`.  A
-  short-hand function `setup_standard_excludes()` can be used to set
-  up the standard set of exclude settings.
-
-* Set options described in the Data Structure section above.
-
-* Call `read_directory()`.
-
-* Use `dir.entries[]`.
-
-* Call `clear_directory()` when none of the contained elements are no longer in use.
-
-(JC)
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/technical/api-gitattributes.txt 1.2.3+git2.25.1-1/git/Documentation/technical/api-gitattributes.txt
--- 1.2.1+git2.18.0-1/git/Documentation/technical/api-gitattributes.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/technical/api-gitattributes.txt	1970-01-01 00:00:00.000000000 +0000
@@ -1,154 +0,0 @@
-gitattributes API
-=================
-
-gitattributes mechanism gives a uniform way to associate various
-attributes to set of paths.
-
-
-Data Structure
---------------
-
-`struct git_attr`::
-
-	An attribute is an opaque object that is identified by its name.
-	Pass the name to `git_attr()` function to obtain the object of
-	this type.  The internal representation of this structure is
-	of no interest to the calling programs.  The name of the
-	attribute can be retrieved by calling `git_attr_name()`.
-
-`struct attr_check_item`::
-
-	This structure represents one attribute and its value.
-
-`struct attr_check`::
-
-	This structure represents a collection of `attr_check_item`.
-	It is passed to `git_check_attr()` function, specifying the
-	attributes to check, and receives their values.
-
-
-Attribute Values
-----------------
-
-An attribute for a path can be in one of four states: Set, Unset,
-Unspecified or set to a string, and `.value` member of `struct
-attr_check_item` records it.  There are three macros to check these:
-
-`ATTR_TRUE()`::
-
-	Returns true if the attribute is Set for the path.
-
-`ATTR_FALSE()`::
-
-	Returns true if the attribute is Unset for the path.
-
-`ATTR_UNSET()`::
-
-	Returns true if the attribute is Unspecified for the path.
-
-If none of the above returns true, `.value` member points at a string
-value of the attribute for the path.
-
-
-Querying Specific Attributes
-----------------------------
-
-* Prepare `struct attr_check` using attr_check_initl()
-  function, enumerating the names of attributes whose values you are
-  interested in, terminated with a NULL pointer.  Alternatively, an
-  empty `struct attr_check` can be prepared by calling
-  `attr_check_alloc()` function and then attributes you want to
-  ask about can be added to it with `attr_check_append()`
-  function.
-
-* Call `git_check_attr()` to check the attributes for the path.
-
-* Inspect `attr_check` structure to see how each of the
-  attribute in the array is defined for the path.
-
-
-Example
--------
-
-To see how attributes "crlf" and "ident" are set for different paths.
-
-. Prepare a `struct attr_check` with two elements (because
-  we are checking two attributes):
-
-------------
-static struct attr_check *check;
-static void setup_check(void)
-{
-	if (check)
-		return; /* already done */
-	check = attr_check_initl("crlf", "ident", NULL);
-}
-------------
-
-. Call `git_check_attr()` with the prepared `struct attr_check`:
-
-------------
-	const char *path;
-
-	setup_check();
-	git_check_attr(path, check);
-------------
-
-. Act on `.value` member of the result, left in `check->items[]`:
-
-------------
-	const char *value = check->items[0].value;
-
-	if (ATTR_TRUE(value)) {
-		The attribute is Set, by listing only the name of the
-		attribute in the gitattributes file for the path.
-	} else if (ATTR_FALSE(value)) {
-		The attribute is Unset, by listing the name of the
-		attribute prefixed with a dash - for the path.
-	} else if (ATTR_UNSET(value)) {
-		The attribute is neither set nor unset for the path.
-	} else if (!strcmp(value, "input")) {
-		If none of ATTR_TRUE(), ATTR_FALSE(), or ATTR_UNSET() is
-		true, the value is a string set in the gitattributes
-		file for the path by saying "attr=value".
-	} else if (... other check using value as string ...) {
-		...
-	}
-------------
-
-To see how attributes in argv[] are set for different paths, only
-the first step in the above would be different.
-
-------------
-static struct attr_check *check;
-static void setup_check(const char **argv)
-{
-	check = attr_check_alloc();
-	while (*argv) {
-		struct git_attr *attr = git_attr(*argv);
-		attr_check_append(check, attr);
-		argv++;
-	}
-}
-------------
-
-
-Querying All Attributes
------------------------
-
-To get the values of all attributes associated with a file:
-
-* Prepare an empty `attr_check` structure by calling
-  `attr_check_alloc()`.
-
-* Call `git_all_attrs()`, which populates the `attr_check`
-  with the attributes attached to the path.
-
-* Iterate over the `attr_check.items[]` array to examine
-  the attribute names and values.  The name of the attribute
-  described by a  `attr_check.items[]` object can be retrieved via
-  `git_attr_name(check->items[i].attr)`.  (Please note that no items
-  will be returned for unset attributes, so `ATTR_UNSET()` will return
-  false for all returned `attr_check.items[]` objects.)
-
-* Free the `attr_check` struct by calling `attr_check_free()`.
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/technical/api-grep.txt 1.2.3+git2.25.1-1/git/Documentation/technical/api-grep.txt
--- 1.2.1+git2.18.0-1/git/Documentation/technical/api-grep.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/technical/api-grep.txt	1970-01-01 00:00:00.000000000 +0000
@@ -1,8 +0,0 @@
-grep API
-========
-
-Talk about <grep.h>, things like:
-
-* grep_buffer()
-
-(JC)
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/technical/api-history-graph.txt 1.2.3+git2.25.1-1/git/Documentation/technical/api-history-graph.txt
--- 1.2.1+git2.18.0-1/git/Documentation/technical/api-history-graph.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/technical/api-history-graph.txt	1970-01-01 00:00:00.000000000 +0000
@@ -1,174 +0,0 @@
-history graph API
-=================
-
-The graph API is used to draw a text-based representation of the commit
-history.  The API generates the graph in a line-by-line fashion.
-
-Functions
----------
-
-Core functions:
-
-* `graph_init()` creates a new `struct git_graph`
-
-* `graph_update()` moves the graph to a new commit.
-
-* `graph_next_line()` outputs the next line of the graph into a strbuf.  It
-  does not add a terminating newline.
-
-* `graph_padding_line()` outputs a line of vertical padding in the graph.  It
-  is similar to `graph_next_line()`, but is guaranteed to never print the line
-  containing the current commit.  Where `graph_next_line()` would print the
-  commit line next, `graph_padding_line()` prints a line that simply extends
-  all branch lines downwards one row, leaving their positions unchanged.
-
-* `graph_is_commit_finished()` determines if the graph has output all lines
-  necessary for the current commit.  If `graph_update()` is called before all
-  lines for the current commit have been printed, the next call to
-  `graph_next_line()` will output an ellipsis, to indicate that a portion of
-  the graph was omitted.
-
-The following utility functions are wrappers around `graph_next_line()` and
-`graph_is_commit_finished()`.  They always print the output to stdout.
-They can all be called with a NULL graph argument, in which case no graph
-output will be printed.
-
-* `graph_show_commit()` calls `graph_next_line()` and
-  `graph_is_commit_finished()` until one of them return non-zero.  This prints
-  all graph lines up to, and including, the line containing this commit.
-  Output is printed to stdout.  The last line printed does not contain a
-  terminating newline.
-
-* `graph_show_oneline()` calls `graph_next_line()` and prints the result to
-  stdout.  The line printed does not contain a terminating newline.
-
-* `graph_show_padding()` calls `graph_padding_line()` and prints the result to
-  stdout.  The line printed does not contain a terminating newline.
-
-* `graph_show_remainder()` calls `graph_next_line()` until
-  `graph_is_commit_finished()` returns non-zero.  Output is printed to stdout.
-  The last line printed does not contain a terminating newline.  Returns 1 if
-  output was printed, and 0 if no output was necessary.
-
-* `graph_show_strbuf()` prints the specified strbuf to stdout, prefixing all
-  lines but the first with a graph line.  The caller is responsible for
-  ensuring graph output for the first line has already been printed to stdout.
-  (This can be done with `graph_show_commit()` or `graph_show_oneline()`.)  If
-  a NULL graph is supplied, the strbuf is printed as-is.
-
-* `graph_show_commit_msg()` is similar to `graph_show_strbuf()`, but it also
-  prints the remainder of the graph, if more lines are needed after the strbuf
-  ends.  It is better than directly calling `graph_show_strbuf()` followed by
-  `graph_show_remainder()` since it properly handles buffers that do not end in
-  a terminating newline.  The output printed by `graph_show_commit_msg()` will
-  end in a newline if and only if the strbuf ends in a newline.
-
-Data structure
---------------
-`struct git_graph` is an opaque data type used to store the current graph
-state.
-
-Calling sequence
-----------------
-
-* Create a `struct git_graph` by calling `graph_init()`.  When using the
-  revision walking API, this is done automatically by `setup_revisions()` if
-  the '--graph' option is supplied.
-
-* Use the revision walking API to walk through a group of contiguous commits.
-  The `get_revision()` function automatically calls `graph_update()` each time
-  it is invoked.
-
-* For each commit, call `graph_next_line()` repeatedly, until
-  `graph_is_commit_finished()` returns non-zero.  Each call go
-  `graph_next_line()` will output a single line of the graph.  The resulting
-  lines will not contain any newlines.  `graph_next_line()` returns 1 if the
-  resulting line contains the current commit, or 0 if this is merely a line
-  needed to adjust the graph before or after the current commit.  This return
-  value can be used to determine where to print the commit summary information
-  alongside the graph output.
-
-Limitations
------------
-
-* `graph_update()` must be called with commits in topological order.  It should
-  not be called on a commit if it has already been invoked with an ancestor of
-  that commit, or the graph output will be incorrect.
-
-* `graph_update()` must be called on a contiguous group of commits.  If
-  `graph_update()` is called on a particular commit, it should later be called
-  on all parents of that commit.  Parents must not be skipped, or the graph
-  output will appear incorrect.
-+
-`graph_update()` may be used on a pruned set of commits only if the parent list
-has been rewritten so as to include only ancestors from the pruned set.
-
-* The graph API does not currently support reverse commit ordering.  In
-  order to implement reverse ordering, the graphing API needs an
-  (efficient) mechanism to find the children of a commit.
-
-Sample usage
-------------
-
-------------
-struct commit *commit;
-struct git_graph *graph = graph_init(opts);
-
-while ((commit = get_revision(opts)) != NULL) {
-	graph_update(graph, commit);
-	while (!graph_is_commit_finished(graph))
-	{
-		struct strbuf sb;
-		int is_commit_line;
-
-		strbuf_init(&sb, 0);
-		is_commit_line = graph_next_line(graph, &sb);
-		fputs(sb.buf, stdout);
-
-		if (is_commit_line)
-			log_tree_commit(opts, commit);
-		else
-			putchar(opts->diffopt.line_termination);
-	}
-}
-------------
-
-Sample output
--------------
-
-The following is an example of the output from the graph API.  This output does
-not include any commit summary information--callers are responsible for
-outputting that information, if desired.
-
-------------
-*
-*
-*
-|\
-* |
-| | *
-| \ \
-|  \ \
-*-. \ \
-|\ \ \ \
-| | * | |
-| | | | | *
-| | | | | *
-| | | | | *
-| | | | | |\
-| | | | | | *
-| * | | | | |
-| | | | | *  \
-| | | | | |\  |
-| | | | * | | |
-| | | | * | | |
-* | | | | | | |
-| |/ / / / / /
-|/| / / / / /
-* | | | | | |
-|/ / / / / /
-* | | | | |
-| | | | | *
-| | | | |/
-| | | | *
-------------
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/technical/api-merge.txt 1.2.3+git2.25.1-1/git/Documentation/technical/api-merge.txt
--- 1.2.1+git2.18.0-1/git/Documentation/technical/api-merge.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/technical/api-merge.txt	2020-02-17 04:47:35.000000000 +0000
@@ -28,77 +28,9 @@ and `diff.c` for examples.
 
 * `struct ll_merge_options`
 
-This describes the set of options the calling program wants to affect
-the operation of a low-level (single file) merge.  Some options:
-
-`virtual_ancestor`::
-	Behave as though this were part of a merge between common
-	ancestors in a recursive merge.
-	If a helper program is specified by the
-	`[merge "<driver>"] recursive` configuration, it will
-	be used (see linkgit:gitattributes[5]).
-
-`variant`::
-	Resolve local conflicts automatically in favor
-	of one side or the other (as in 'git merge-file'
-	`--ours`/`--theirs`/`--union`).  Can be `0`,
-	`XDL_MERGE_FAVOR_OURS`, `XDL_MERGE_FAVOR_THEIRS`, or
-	`XDL_MERGE_FAVOR_UNION`.
-
-`renormalize`::
-	Resmudge and clean the "base", "theirs" and "ours" files
-	before merging.  Use this when the merge is likely to have
-	overlapped with a change in smudge/clean or end-of-line
-	normalization rules.
+Check ll-merge.h for details.
 
 Low-level (single file) merge
 -----------------------------
 
-`ll_merge`::
-
-	Perform a three-way single-file merge in core.  This is
-	a thin wrapper around `xdl_merge` that takes the path and
-	any merge backend specified in `.gitattributes` or
-	`.git/info/attributes` into account.  Returns 0 for a
-	clean merge.
-
-Calling sequence:
-
-* Prepare a `struct ll_merge_options` to record options.
-  If you have no special requests, skip this and pass `NULL`
-  as the `opts` parameter to use the default options.
-
-* Allocate an mmbuffer_t variable for the result.
-
-* Allocate and fill variables with the file's original content
-  and two modified versions (using `read_mmfile`, for example).
-
-* Call `ll_merge()`.
-
-* Read the merged content from `result_buf.ptr` and `result_buf.size`.
-
-* Release buffers when finished.  A simple
-  `free(ancestor.ptr); free(ours.ptr); free(theirs.ptr);
-  free(result_buf.ptr);` will do.
-
-If the modifications do not merge cleanly, `ll_merge` will return a
-nonzero value and `result_buf` will generally include a description of
-the conflict bracketed by markers such as the traditional `<<<<<<<`
-and `>>>>>>>`.
-
-The `ancestor_label`, `our_label`, and `their_label` parameters are
-used to label the different sides of a conflict if the merge driver
-supports this.
-
-Everything else
----------------
-
-Talk about <merge-recursive.h> and merge_file():
-
- - merge_trees() to merge with rename detection
- - merge_recursive() for ancestor consolidation
- - try_merge_command() for other strategies
- - conflict format
- - merge options
-
-(Daniel, Miklos, Stephan, JC)
+Check ll-merge.h for details.
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/technical/api-object-access.txt 1.2.3+git2.25.1-1/git/Documentation/technical/api-object-access.txt
--- 1.2.1+git2.18.0-1/git/Documentation/technical/api-object-access.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/technical/api-object-access.txt	1970-01-01 00:00:00.000000000 +0000
@@ -1,15 +0,0 @@
-object access API
-=================
-
-Talk about <sha1-file.c> and <object.h> family, things like
-
-* read_sha1_file()
-* read_object_with_reference()
-* has_sha1_file()
-* write_sha1_file()
-* pretend_object_file()
-* lookup_{object,commit,tag,blob,tree}
-* parse_{object,commit,tag,blob,tree}
-* Use of object flags
-
-(JC, Shawn, Daniel, Dscho, Linus)
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/technical/api-oid-array.txt 1.2.3+git2.25.1-1/git/Documentation/technical/api-oid-array.txt
--- 1.2.1+git2.18.0-1/git/Documentation/technical/api-oid-array.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/technical/api-oid-array.txt	1970-01-01 00:00:00.000000000 +0000
@@ -1,85 +0,0 @@
-oid-array API
-==============
-
-The oid-array API provides storage and manipulation of sets of object
-identifiers. The emphasis is on storage and processing efficiency,
-making them suitable for large lists. Note that the ordering of items is
-not preserved over some operations.
-
-Data Structures
----------------
-
-`struct oid_array`::
-
-	A single array of object IDs. This should be initialized by
-	assignment from `OID_ARRAY_INIT`.  The `oid` member contains
-	the actual data. The `nr` member contains the number of items in
-	the set.  The `alloc` and `sorted` members are used internally,
-	and should not be needed by API callers.
-
-Functions
----------
-
-`oid_array_append`::
-	Add an item to the set. The object ID will be placed at the end of
-	the array (but note that some operations below may lose this
-	ordering).
-
-`oid_array_lookup`::
-	Perform a binary search of the array for a specific object ID.
-	If found, returns the offset (in number of elements) of the
-	object ID. If not found, returns a negative integer. If the array
-	is not sorted, this function has the side effect of sorting it.
-
-`oid_array_clear`::
-	Free all memory associated with the array and return it to the
-	initial, empty state.
-
-`oid_array_for_each`::
-	Iterate over each element of the list, executing the callback
-	function for each one. Does not sort the list, so any custom
-	hash order is retained. If the callback returns a non-zero
-	value, the iteration ends immediately and the callback's
-	return is propagated; otherwise, 0 is returned.
-
-`oid_array_for_each_unique`::
-	Iterate over each unique element of the list in sorted order,
-	but otherwise behave like `oid_array_for_each`. If the array
-	is not sorted, this function has the side effect of sorting
-	it.
-
-Examples
---------
-
------------------------------------------
-int print_callback(const struct object_id *oid,
-		    void *data)
-{
-	printf("%s\n", oid_to_hex(oid));
-	return 0; /* always continue */
-}
-
-void some_func(void)
-{
-	struct sha1_array hashes = OID_ARRAY_INIT;
-	struct object_id oid;
-
-	/* Read objects into our set */
-	while (read_object_from_stdin(oid.hash))
-		oid_array_append(&hashes, &oid);
-
-	/* Check if some objects are in our set */
-	while (read_object_from_stdin(oid.hash)) {
-		if (oid_array_lookup(&hashes, &oid) >= 0)
-			printf("it's in there!\n");
-
-	/*
-	 * Print the unique set of objects. We could also have
-	 * avoided adding duplicate objects in the first place,
-	 * but we would end up re-sorting the array repeatedly.
-	 * Instead, this will sort once and then skip duplicates
-	 * in linear time.
-	 */
-	oid_array_for_each_unique(&hashes, print_callback, NULL);
-}
------------------------------------------
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/technical/api-parse-options.txt 1.2.3+git2.25.1-1/git/Documentation/technical/api-parse-options.txt
--- 1.2.1+git2.18.0-1/git/Documentation/technical/api-parse-options.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/technical/api-parse-options.txt	2020-02-17 04:47:35.000000000 +0000
@@ -183,10 +183,6 @@ There are some macros to easily define o
 	scale the provided value by 1024, 1024^2 or 1024^3 respectively.
 	The scaled value is put into `unsigned_long_var`.
 
-`OPT_DATE(short, long, &timestamp_t_var, description)`::
-	Introduce an option with date argument, see `approxidate()`.
-	The timestamp is put into `timestamp_t_var`.
-
 `OPT_EXPIRY_DATE(short, long, &timestamp_t_var, description)`::
 	Introduce an option with expiry date argument, see `parse_expiry_date()`.
 	The timestamp is put into `timestamp_t_var`.
@@ -202,8 +198,10 @@ There are some macros to easily define o
 	The filename will be prefixed by passing the filename along with
 	the prefix argument of `parse_options()` to `prefix_filename()`.
 
-`OPT_ARGUMENT(long, description)`::
+`OPT_ARGUMENT(long, &int_var, description)`::
 	Introduce a long-option argument that will be kept in `argv[]`.
+	If this option was seen, `int_var` will be set to one (except
+	if a `NULL` pointer was passed).
 
 `OPT_NUMBER_CALLBACK(&var, description, func_ptr)`::
 	Recognize numerical options like -123 and feed the integer as
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/technical/api-quote.txt 1.2.3+git2.25.1-1/git/Documentation/technical/api-quote.txt
--- 1.2.1+git2.18.0-1/git/Documentation/technical/api-quote.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/technical/api-quote.txt	1970-01-01 00:00:00.000000000 +0000
@@ -1,10 +0,0 @@
-quote API
-=========
-
-Talk about <quote.h>, things like
-
-* sq_quote and unquote
-* c_style quote and unquote
-* quoting for foreign languages
-
-(JC)
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/technical/api-ref-iteration.txt 1.2.3+git2.25.1-1/git/Documentation/technical/api-ref-iteration.txt
--- 1.2.1+git2.18.0-1/git/Documentation/technical/api-ref-iteration.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/technical/api-ref-iteration.txt	1970-01-01 00:00:00.000000000 +0000
@@ -1,78 +0,0 @@
-ref iteration API
-=================
-
-
-Iteration of refs is done by using an iterate function which will call a
-callback function for every ref. The callback function has this
-signature:
-
-	int handle_one_ref(const char *refname, const struct object_id *oid,
-			   int flags, void *cb_data);
-
-There are different kinds of iterate functions which all take a
-callback of this type. The callback is then called for each found ref
-until the callback returns nonzero. The returned value is then also
-returned by the iterate function.
-
-Iteration functions
--------------------
-
-* `head_ref()` just iterates the head ref.
-
-* `for_each_ref()` iterates all refs.
-
-* `for_each_ref_in()` iterates all refs which have a defined prefix and
-  strips that prefix from the passed variable refname.
-
-* `for_each_tag_ref()`, `for_each_branch_ref()`, `for_each_remote_ref()`,
-  `for_each_replace_ref()` iterate refs from the respective area.
-
-* `for_each_glob_ref()` iterates all refs that match the specified glob
-  pattern.
-
-* `for_each_glob_ref_in()` the previous and `for_each_ref_in()` combined.
-
-* Use `refs_` API for accessing submodules. The submodule ref store could
-  be obtained with `get_submodule_ref_store()`.
-
-* `for_each_rawref()` can be used to learn about broken ref and symref.
-
-* `for_each_reflog()` iterates each reflog file.
-
-Submodules
-----------
-
-If you want to iterate the refs of a submodule you first need to add the
-submodules object database. You can do this by a code-snippet like
-this:
-
-	const char *path = "path/to/submodule"
-	if (add_submodule_odb(path))
-		die("Error submodule '%s' not populated.", path);
-
-`add_submodule_odb()` will return zero on success. If you
-do not do this you will get an error for each ref that it does not point
-to a valid object.
-
-Note: As a side-effect of this you can not safely assume that all
-objects you lookup are available in superproject. All submodule objects
-will be available the same way as the superprojects objects.
-
-Example:
---------
-
-----
-static int handle_remote_ref(const char *refname,
-		const unsigned char *sha1, int flags, void *cb_data)
-{
-	struct strbuf *output = cb_data;
-	strbuf_addf(output, "%s\n", refname);
-	return 0;
-}
-
-...
-
-	struct strbuf output = STRBUF_INIT;
-	for_each_remote_ref(handle_remote_ref, &output);
-	printf("%s", output.buf);
-----
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/technical/api-remote.txt 1.2.3+git2.25.1-1/git/Documentation/technical/api-remote.txt
--- 1.2.1+git2.18.0-1/git/Documentation/technical/api-remote.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/technical/api-remote.txt	1970-01-01 00:00:00.000000000 +0000
@@ -1,127 +0,0 @@
-Remotes configuration API
-=========================
-
-The API in remote.h gives access to the configuration related to
-remotes. It handles all three configuration mechanisms historically
-and currently used by Git, and presents the information in a uniform
-fashion. Note that the code also handles plain URLs without any
-configuration, giving them just the default information.
-
-struct remote
--------------
-
-`name`::
-
-	The user's nickname for the remote
-
-`url`::
-
-	An array of all of the url_nr URLs configured for the remote
-
-`pushurl`::
-
-	An array of all of the pushurl_nr push URLs configured for the remote
-
-`push`::
-
-	 An array of refspecs configured for pushing, with
-	 push_refspec being the literal strings, and push_refspec_nr
-	 being the quantity.
-
-`fetch`::
-
-	An array of refspecs configured for fetching, with
-	fetch_refspec being the literal strings, and fetch_refspec_nr
-	being the quantity.
-
-`fetch_tags`::
-
-	The setting for whether to fetch tags (as a separate rule from
-	the configured refspecs); -1 means never to fetch tags, 0
-	means to auto-follow tags based on the default heuristic, 1
-	means to always auto-follow tags, and 2 means to fetch all
-	tags.
-
-`receivepack`, `uploadpack`::
-
-	The configured helper programs to run on the remote side, for
-	Git-native protocols.
-
-`http_proxy`::
-
-	The proxy to use for curl (http, https, ftp, etc.) URLs.
-
-`http_proxy_authmethod`::
-
-	The method used for authenticating against `http_proxy`.
-
-struct remotes can be found by name with remote_get(), and iterated
-through with for_each_remote(). remote_get(NULL) will return the
-default remote, given the current branch and configuration.
-
-struct refspec
---------------
-
-A struct refspec holds the parsed interpretation of a refspec.  If it
-will force updates (starts with a '+'), force is true.  If it is a
-pattern (sides end with '*') pattern is true.  src and dest are the
-two sides (including '*' characters if present); if there is only one
-side, it is src, and dst is NULL; if sides exist but are empty (i.e.,
-the refspec either starts or ends with ':'), the corresponding side is
-"".
-
-An array of strings can be parsed into an array of struct refspecs
-using parse_fetch_refspec() or parse_push_refspec().
-
-remote_find_tracking(), given a remote and a struct refspec with
-either src or dst filled out, will fill out the other such that the
-result is in the "fetch" specification for the remote (note that this
-evaluates patterns and returns a single result).
-
-struct branch
--------------
-
-Note that this may end up moving to branch.h
-
-struct branch holds the configuration for a branch. It can be looked
-up with branch_get(name) for "refs/heads/{name}", or with
-branch_get(NULL) for HEAD.
-
-It contains:
-
-`name`::
-
-	The short name of the branch.
-
-`refname`::
-
-	The full path for the branch ref.
-
-`remote_name`::
-
-	The name of the remote listed in the configuration.
-
-`merge_name`::
-
-	An array of the "merge" lines in the configuration.
-
-`merge`::
-
-	An array of the struct refspecs used for the merge lines. That
-	is, merge[i]->dst is a local tracking ref which should be
-	merged into this branch by default.
-
-`merge_nr`::
-
-	The number of merge configurations
-
-branch_has_merge_config() returns true if the given branch has merge
-configuration given.
-
-Other stuff
------------
-
-There is other stuff in remote.h that is related, in general, to the
-process of interacting with remotes.
-
-(Daniel Barkalow)
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/technical/api-revision-walking.txt 1.2.3+git2.25.1-1/git/Documentation/technical/api-revision-walking.txt
--- 1.2.1+git2.18.0-1/git/Documentation/technical/api-revision-walking.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/technical/api-revision-walking.txt	1970-01-01 00:00:00.000000000 +0000
@@ -1,72 +0,0 @@
-revision walking API
-====================
-
-The revision walking API offers functions to build a list of revisions
-and then iterate over that list.
-
-Calling sequence
-----------------
-
-The walking API has a given calling sequence: first you need to
-initialize a rev_info structure, then add revisions to control what kind
-of revision list do you want to get, finally you can iterate over the
-revision list.
-
-Functions
----------
-
-`init_revisions`::
-
-	Initialize a rev_info structure with default values. The second
-	parameter may be NULL or can be prefix path, and then the `.prefix`
-	variable will be set to it. This is typically the first function you
-	want to call when you want to deal with a revision list. After calling
-	this function, you are free to customize options, like set
-	`.ignore_merges` to 0 if you don't want to ignore merges, and so on. See
-	`revision.h` for a complete list of available options.
-
-`add_pending_object`::
-
-	This function can be used if you want to add commit objects as revision
-	information. You can use the `UNINTERESTING` object flag to indicate if
-	you want to include or exclude the given commit (and commits reachable
-	from the given commit) from the revision list.
-+
-NOTE: If you have the commits as a string list then you probably want to
-use setup_revisions(), instead of parsing each string and using this
-function.
-
-`setup_revisions`::
-
-	Parse revision information, filling in the `rev_info` structure, and
-	removing the used arguments from the argument list. Returns the number
-	of arguments left that weren't recognized, which are also moved to the
-	head of the argument list. The last parameter is used in case no
-	parameter given by the first two arguments.
-
-`prepare_revision_walk`::
-
-	Prepares the rev_info structure for a walk. You should check if it
-	returns any error (non-zero return code) and if it does not, you can
-	start using get_revision() to do the iteration.
-
-`get_revision`::
-
-	Takes a pointer to a `rev_info` structure and iterates over it,
-	returning a `struct commit *` each time you call it. The end of the
-	revision list is indicated by returning a NULL pointer.
-
-`reset_revision_walk`::
-
-	Reset the flags used by the revision walking api. You can use
-	this to do multiple sequential revision walks.
-
-Data structures
----------------
-
-Talk about <revision.h>, things like:
-
-* two diff_options, one for path limiting, another for output;
-* remaining functions;
-
-(Linus, JC, Dscho)
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/technical/api-run-command.txt 1.2.3+git2.25.1-1/git/Documentation/technical/api-run-command.txt
--- 1.2.1+git2.18.0-1/git/Documentation/technical/api-run-command.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/technical/api-run-command.txt	1970-01-01 00:00:00.000000000 +0000
@@ -1,264 +0,0 @@
-run-command API
-===============
-
-The run-command API offers a versatile tool to run sub-processes with
-redirected input and output as well as with a modified environment
-and an alternate current directory.
-
-A similar API offers the capability to run a function asynchronously,
-which is primarily used to capture the output that the function
-produces in the caller in order to process it.
-
-
-Functions
----------
-
-`child_process_init`::
-
-	Initialize a struct child_process variable.
-
-`start_command`::
-
-	Start a sub-process. Takes a pointer to a `struct child_process`
-	that specifies the details and returns pipe FDs (if requested).
-	See below for details.
-
-`finish_command`::
-
-	Wait for the completion of a sub-process that was started with
-	start_command().
-
-`run_command`::
-
-	A convenience function that encapsulates a sequence of
-	start_command() followed by finish_command(). Takes a pointer
-	to a `struct child_process` that specifies the details.
-
-`run_command_v_opt`, `run_command_v_opt_cd_env`::
-
-	Convenience functions that encapsulate a sequence of
-	start_command() followed by finish_command(). The argument argv
-	specifies the program and its arguments. The argument opt is zero
-	or more of the flags `RUN_COMMAND_NO_STDIN`, `RUN_GIT_CMD`,
-	`RUN_COMMAND_STDOUT_TO_STDERR`, or `RUN_SILENT_EXEC_FAILURE`
-	that correspond to the members .no_stdin, .git_cmd,
-	.stdout_to_stderr, .silent_exec_failure of `struct child_process`.
-	The argument dir corresponds the member .dir. The argument env
-	corresponds to the member .env.
-
-`child_process_clear`::
-
-	Release the memory associated with the struct child_process.
-	Most users of the run-command API don't need to call this
-	function explicitly because `start_command` invokes it on
-	failure and `finish_command` calls it automatically already.
-
-The functions above do the following:
-
-. If a system call failed, errno is set and -1 is returned. A diagnostic
-  is printed.
-
-. If the program was not found, then -1 is returned and errno is set to
-  ENOENT; a diagnostic is printed only if .silent_exec_failure is 0.
-
-. Otherwise, the program is run. If it terminates regularly, its exit
-  code is returned. No diagnostic is printed, even if the exit code is
-  non-zero.
-
-. If the program terminated due to a signal, then the return value is the
-  signal number + 128, ie. the same value that a POSIX shell's $? would
-  report.  A diagnostic is printed.
-
-
-`start_async`::
-
-	Run a function asynchronously. Takes a pointer to a `struct
-	async` that specifies the details and returns a set of pipe FDs
-	for communication with the function. See below for details.
-
-`finish_async`::
-
-	Wait for the completion of an asynchronous function that was
-	started with start_async().
-
-`run_hook`::
-
-	Run a hook.
-	The first argument is a pathname to an index file, or NULL
-	if the hook uses the default index file or no index is needed.
-	The second argument is the name of the hook.
-	The further arguments correspond to the hook arguments.
-	The last argument has to be NULL to terminate the arguments list.
-	If the hook does not exist or is not executable, the return
-	value will be zero.
-	If it is executable, the hook will be executed and the exit
-	status of the hook is returned.
-	On execution, .stdout_to_stderr and .no_stdin will be set.
-	(See below.)
-
-
-Data structures
----------------
-
-* `struct child_process`
-
-This describes the arguments, redirections, and environment of a
-command to run in a sub-process.
-
-The caller:
-
-1. allocates and clears (using child_process_init() or
-   CHILD_PROCESS_INIT) a struct child_process variable;
-2. initializes the members;
-3. calls start_command();
-4. processes the data;
-5. closes file descriptors (if necessary; see below);
-6. calls finish_command().
-
-The .argv member is set up as an array of string pointers (NULL
-terminated), of which .argv[0] is the program name to run (usually
-without a path). If the command to run is a git command, set argv[0] to
-the command name without the 'git-' prefix and set .git_cmd = 1.
-
-Note that the ownership of the memory pointed to by .argv stays with the
-caller, but it should survive until `finish_command` completes. If the
-.argv member is NULL, `start_command` will point it at the .args
-`argv_array` (so you may use one or the other, but you must use exactly
-one). The memory in .args will be cleaned up automatically during
-`finish_command` (or during `start_command` when it is unsuccessful).
-
-The members .in, .out, .err are used to redirect stdin, stdout,
-stderr as follows:
-
-. Specify 0 to request no special redirection. No new file descriptor
-  is allocated. The child process simply inherits the channel from the
-  parent.
-
-. Specify -1 to have a pipe allocated; start_command() replaces -1
-  by the pipe FD in the following way:
-
-	.in: Returns the writable pipe end into which the caller writes;
-		the readable end of the pipe becomes the child's stdin.
-
-	.out, .err: Returns the readable pipe end from which the caller
-		reads; the writable end of the pipe end becomes child's
-		stdout/stderr.
-
-  The caller of start_command() must close the so returned FDs
-  after it has completed reading from/writing to it!
-
-. Specify a file descriptor > 0 to be used by the child:
-
-	.in: The FD must be readable; it becomes child's stdin.
-	.out: The FD must be writable; it becomes child's stdout.
-	.err: The FD must be writable; it becomes child's stderr.
-
-  The specified FD is closed by start_command(), even if it fails to
-  run the sub-process!
-
-. Special forms of redirection are available by setting these members
-  to 1:
-
-	.no_stdin, .no_stdout, .no_stderr: The respective channel is
-		redirected to /dev/null.
-
-	.stdout_to_stderr: stdout of the child is redirected to its
-		stderr. This happens after stderr is itself redirected.
-		So stdout will follow stderr to wherever it is
-		redirected.
-
-To modify the environment of the sub-process, specify an array of
-string pointers (NULL terminated) in .env:
-
-. If the string is of the form "VAR=value", i.e. it contains '='
-  the variable is added to the child process's environment.
-
-. If the string does not contain '=', it names an environment
-  variable that will be removed from the child process's environment.
-
-If the .env member is NULL, `start_command` will point it at the
-.env_array `argv_array` (so you may use one or the other, but not both).
-The memory in .env_array will be cleaned up automatically during
-`finish_command` (or during `start_command` when it is unsuccessful).
-
-To specify a new initial working directory for the sub-process,
-specify it in the .dir member.
-
-If the program cannot be found, the functions return -1 and set
-errno to ENOENT. Normally, an error message is printed, but if
-.silent_exec_failure is set to 1, no message is printed for this
-special error condition.
-
-
-* `struct async`
-
-This describes a function to run asynchronously, whose purpose is
-to produce output that the caller reads.
-
-The caller:
-
-1. allocates and clears (memset(&asy, 0, sizeof(asy));) a
-   struct async variable;
-2. initializes .proc and .data;
-3. calls start_async();
-4. processes communicates with proc through .in and .out;
-5. closes .in and .out;
-6. calls finish_async().
-
-The members .in, .out are used to provide a set of fd's for
-communication between the caller and the callee as follows:
-
-. Specify 0 to have no file descriptor passed.  The callee will
-  receive -1 in the corresponding argument.
-
-. Specify < 0 to have a pipe allocated; start_async() replaces
-  with the pipe FD in the following way:
-
-	.in: Returns the writable pipe end into which the caller
-	writes; the readable end of the pipe becomes the function's
-	in argument.
-
-	.out: Returns the readable pipe end from which the caller
-	reads; the writable end of the pipe becomes the function's
-	out argument.
-
-  The caller of start_async() must close the returned FDs after it
-  has completed reading from/writing from them.
-
-. Specify a file descriptor > 0 to be used by the function:
-
-	.in: The FD must be readable; it becomes the function's in.
-	.out: The FD must be writable; it becomes the function's out.
-
-  The specified FD is closed by start_async(), even if it fails to
-  run the function.
-
-The function pointer in .proc has the following signature:
-
-	int proc(int in, int out, void *data);
-
-. in, out specifies a set of file descriptors to which the function
-  must read/write the data that it needs/produces.  The function
-  *must* close these descriptors before it returns.  A descriptor
-  may be -1 if the caller did not configure a descriptor for that
-  direction.
-
-. data is the value that the caller has specified in the .data member
-  of struct async.
-
-. The return value of the function is 0 on success and non-zero
-  on failure. If the function indicates failure, finish_async() will
-  report failure as well.
-
-
-There are serious restrictions on what the asynchronous function can do
-because this facility is implemented by a thread in the same address
-space on most platforms (when pthreads is available), but by a pipe to
-a forked process otherwise:
-
-. It cannot change the program's state (global variables, environment,
-  etc.) in a way that the caller notices; in other words, .in and .out
-  are the only communication channels to the caller.
-
-. It must not change the program's state that the caller of the
-  facility also uses.
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/technical/api-setup.txt 1.2.3+git2.25.1-1/git/Documentation/technical/api-setup.txt
--- 1.2.1+git2.18.0-1/git/Documentation/technical/api-setup.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/technical/api-setup.txt	1970-01-01 00:00:00.000000000 +0000
@@ -1,47 +0,0 @@
-setup API
-=========
-
-Talk about
-
-* setup_git_directory()
-* setup_git_directory_gently()
-* is_inside_git_dir()
-* is_inside_work_tree()
-* setup_work_tree()
-
-(Dscho)
-
-Pathspec
---------
-
-See glossary-context.txt for the syntax of pathspec. In memory, a
-pathspec set is represented by "struct pathspec" and is prepared by
-parse_pathspec(). This function takes several arguments:
-
-- magic_mask specifies what features that are NOT supported by the
-  following code. If a user attempts to use such a feature,
-  parse_pathspec() can reject it early.
-
-- flags specifies other things that the caller wants parse_pathspec to
-  perform.
-
-- prefix and args come from cmd_* functions
-
-parse_pathspec() helps catch unsupported features and reject them
-politely. At a lower level, different pathspec-related functions may
-not support the same set of features. Such pathspec-sensitive
-functions are guarded with GUARD_PATHSPEC(), which will die in an
-unfriendly way when an unsupported feature is requested.
-
-The command designers are supposed to make sure that GUARD_PATHSPEC()
-never dies. They have to make sure all unsupported features are caught
-by parse_pathspec(), not by GUARD_PATHSPEC. grepping GUARD_PATHSPEC()
-should give the designers all pathspec-sensitive codepaths and what
-features they support.
-
-A similar process is applied when a new pathspec magic is added. The
-designer lifts the GUARD_PATHSPEC restriction in the functions that
-support the new magic. At the same time (s)he has to make sure this
-new feature will be caught at parse_pathspec() in commands that cannot
-handle the new magic in some cases. grepping parse_pathspec() should
-help.
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/technical/api-sigchain.txt 1.2.3+git2.25.1-1/git/Documentation/technical/api-sigchain.txt
--- 1.2.1+git2.18.0-1/git/Documentation/technical/api-sigchain.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/technical/api-sigchain.txt	1970-01-01 00:00:00.000000000 +0000
@@ -1,41 +0,0 @@
-sigchain API
-============
-
-Code often wants to set a signal handler to clean up temporary files or
-other work-in-progress when we die unexpectedly. For multiple pieces of
-code to do this without conflicting, each piece of code must remember
-the old value of the handler and restore it either when:
-
-  1. The work-in-progress is finished, and the handler is no longer
-     necessary. The handler should revert to the original behavior
-     (either another handler, SIG_DFL, or SIG_IGN).
-
-  2. The signal is received. We should then do our cleanup, then chain
-     to the next handler (or die if it is SIG_DFL).
-
-Sigchain is a tiny library for keeping a stack of handlers. Your handler
-and installation code should look something like:
-
-------------------------------------------
-  void clean_foo_on_signal(int sig)
-  {
-	  clean_foo();
-	  sigchain_pop(sig);
-	  raise(sig);
-  }
-
-  void other_func()
-  {
-	  sigchain_push_common(clean_foo_on_signal);
-	  mess_up_foo();
-	  clean_foo();
-  }
-------------------------------------------
-
-Handlers are given the typedef of sigchain_fun. This is the same type
-that is given to signal() or sigaction(). It is perfectly reasonable to
-push SIG_DFL or SIG_IGN onto the stack.
-
-You can sigchain_push and sigchain_pop individual signals. For
-convenience, sigchain_push_common will push the handler onto the stack
-for many common signals.
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/technical/api-submodule-config.txt 1.2.3+git2.25.1-1/git/Documentation/technical/api-submodule-config.txt
--- 1.2.1+git2.18.0-1/git/Documentation/technical/api-submodule-config.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/technical/api-submodule-config.txt	1970-01-01 00:00:00.000000000 +0000
@@ -1,66 +0,0 @@
-submodule config cache API
-==========================
-
-The submodule config cache API allows to read submodule
-configurations/information from specified revisions. Internally
-information is lazily read into a cache that is used to avoid
-unnecessary parsing of the same .gitmodules files. Lookups can be done by
-submodule path or name.
-
-Usage
------
-
-To initialize the cache with configurations from the worktree the caller
-typically first calls `gitmodules_config()` to read values from the
-worktree .gitmodules and then to overlay the local git config values
-`parse_submodule_config_option()` from the config parsing
-infrastructure.
-
-The caller can look up information about submodules by using the
-`submodule_from_path()` or `submodule_from_name()` functions. They return
-a `struct submodule` which contains the values. The API automatically
-initializes and allocates the needed infrastructure on-demand. If the
-caller does only want to lookup values from revisions the initialization
-can be skipped.
-
-If the internal cache might grow too big or when the caller is done with
-the API, all internally cached values can be freed with submodule_free().
-
-Data Structures
----------------
-
-`struct submodule`::
-
-	This structure is used to return the information about one
-	submodule for a certain revision. It is returned by the lookup
-	functions.
-
-Functions
----------
-
-`void submodule_free(struct repository *r)`::
-
-	Use these to free the internally cached values.
-
-`int parse_submodule_config_option(const char *var, const char *value)`::
-
-	Can be passed to the config parsing infrastructure to parse
-	local (worktree) submodule configurations.
-
-`const struct submodule *submodule_from_path(const unsigned char *treeish_name, const char *path)`::
-
-	Given a tree-ish in the superproject and a path, return the
-	submodule that is bound at the path in the named tree.
-
-`const struct submodule *submodule_from_name(const unsigned char *treeish_name, const char *name)`::
-
-	The same as above but lookup by name.
-
-Whenever a submodule configuration is parsed in `parse_submodule_config_option`
-via e.g. `gitmodules_config()`, it will overwrite the null_sha1 entry.
-So in the normal case, when HEAD:.gitmodules is parsed first and then overlayed
-with the repository configuration, the null_sha1 entry contains the local
-configuration of a submodule (e.g. consolidated values from local git
-configuration and the .gitmodules file in the worktree).
-
-For an example usage see test-submodule-config.c.
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/technical/api-trace2.txt 1.2.3+git2.25.1-1/git/Documentation/technical/api-trace2.txt
--- 1.2.1+git2.18.0-1/git/Documentation/technical/api-trace2.txt	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/technical/api-trace2.txt	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,1170 @@
+= Trace2 API
+
+The Trace2 API can be used to print debug, performance, and telemetry
+information to stderr or a file.  The Trace2 feature is inactive unless
+explicitly enabled by enabling one or more Trace2 Targets.
+
+The Trace2 API is intended to replace the existing (Trace1)
+printf-style tracing provided by the existing `GIT_TRACE` and
+`GIT_TRACE_PERFORMANCE` facilities.  During initial implementation,
+Trace2 and Trace1 may operate in parallel.
+
+The Trace2 API defines a set of high-level messages with known fields,
+such as (`start`: `argv`) and (`exit`: {`exit-code`, `elapsed-time`}).
+
+Trace2 instrumentation throughout the Git code base sends Trace2
+messages to the enabled Trace2 Targets.  Targets transform these
+messages content into purpose-specific formats and write events to
+their data streams.  In this manner, the Trace2 API can drive
+many different types of analysis.
+
+Targets are defined using a VTable allowing easy extension to other
+formats in the future.  This might be used to define a binary format,
+for example.
+
+Trace2 is controlled using `trace2.*` config values in the system and
+global config files and `GIT_TRACE2*` environment variables.  Trace2 does
+not read from repo local or worktree config files or respect `-c`
+command line config settings.
+
+== Trace2 Targets
+
+Trace2 defines the following set of Trace2 Targets.
+Format details are given in a later section.
+
+=== The Normal Format Target
+
+The normal format target is a tradition printf format and similar
+to GIT_TRACE format.  This format is enabled with the `GIT_TRACE2`
+environment variable or the `trace2.normalTarget` system or global
+config setting.
+
+For example
+
+------------
+$ export GIT_TRACE2=~/log.normal
+$ git version
+git version 2.20.1.155.g426c96fcdb
+------------
+
+or
+
+------------
+$ git config --global trace2.normalTarget ~/log.normal
+$ git version
+git version 2.20.1.155.g426c96fcdb
+------------
+
+yields
+
+------------
+$ cat ~/log.normal
+12:28:42.620009 common-main.c:38                  version 2.20.1.155.g426c96fcdb
+12:28:42.620989 common-main.c:39                  start git version
+12:28:42.621101 git.c:432                         cmd_name version (version)
+12:28:42.621215 git.c:662                         exit elapsed:0.001227 code:0
+12:28:42.621250 trace2/tr2_tgt_normal.c:124       atexit elapsed:0.001265 code:0
+------------
+
+=== The Performance Format Target
+
+The performance format target (PERF) is a column-based format to
+replace GIT_TRACE_PERFORMANCE and is suitable for development and
+testing, possibly to complement tools like gprof.  This format is
+enabled with the `GIT_TRACE2_PERF` environment variable or the
+`trace2.perfTarget` system or global config setting.
+
+For example
+
+------------
+$ export GIT_TRACE2_PERF=~/log.perf
+$ git version
+git version 2.20.1.155.g426c96fcdb
+------------
+
+or
+
+------------
+$ git config --global trace2.perfTarget ~/log.perf
+$ git version
+git version 2.20.1.155.g426c96fcdb
+------------
+
+yields
+
+------------
+$ cat ~/log.perf
+12:28:42.620675 common-main.c:38                  | d0 | main                     | version      |     |           |           |            | 2.20.1.155.g426c96fcdb
+12:28:42.621001 common-main.c:39                  | d0 | main                     | start        |     |  0.001173 |           |            | git version
+12:28:42.621111 git.c:432                         | d0 | main                     | cmd_name     |     |           |           |            | version (version)
+12:28:42.621225 git.c:662                         | d0 | main                     | exit         |     |  0.001227 |           |            | code:0
+12:28:42.621259 trace2/tr2_tgt_perf.c:211         | d0 | main                     | atexit       |     |  0.001265 |           |            | code:0
+------------
+
+=== The Event Format Target
+
+The event format target is a JSON-based format of event data suitable
+for telemetry analysis.  This format is enabled with the `GIT_TRACE2_EVENT`
+environment variable or the `trace2.eventTarget` system or global config
+setting.
+
+For example
+
+------------
+$ export GIT_TRACE2_EVENT=~/log.event
+$ git version
+git version 2.20.1.155.g426c96fcdb
+------------
+
+or
+
+------------
+$ git config --global trace2.eventTarget ~/log.event
+$ git version
+git version 2.20.1.155.g426c96fcdb
+------------
+
+yields
+
+------------
+$ cat ~/log.event
+{"event":"version","sid":"sid":"20190408T191610.507018Z-H9b68c35f-P000059a8","thread":"main","time":"2019-01-16T17:28:42.620713Z","file":"common-main.c","line":38,"evt":"2","exe":"2.20.1.155.g426c96fcdb"}
+{"event":"start","sid":"20190408T191610.507018Z-H9b68c35f-P000059a8","thread":"main","time":"2019-01-16T17:28:42.621027Z","file":"common-main.c","line":39,"t_abs":0.001173,"argv":["git","version"]}
+{"event":"cmd_name","sid":"20190408T191610.507018Z-H9b68c35f-P000059a8","thread":"main","time":"2019-01-16T17:28:42.621122Z","file":"git.c","line":432,"name":"version","hierarchy":"version"}
+{"event":"exit","sid":"20190408T191610.507018Z-H9b68c35f-P000059a8","thread":"main","time":"2019-01-16T17:28:42.621236Z","file":"git.c","line":662,"t_abs":0.001227,"code":0}
+{"event":"atexit","sid":"20190408T191610.507018Z-H9b68c35f-P000059a8","thread":"main","time":"2019-01-16T17:28:42.621268Z","file":"trace2/tr2_tgt_event.c","line":163,"t_abs":0.001265,"code":0}
+------------
+
+=== Enabling a Target
+
+To enable a target, set the corresponding environment variable or
+system or global config value to one of the following:
+
+include::../trace2-target-values.txt[]
+
+When trace files are written to a target directory, they will be named according
+to the last component of the SID (optionally followed by a counter to avoid
+filename collisions).
+
+== Trace2 API
+
+All public Trace2 functions and macros are defined in `trace2.h` and
+`trace2.c`.  All public symbols are prefixed with `trace2_`.
+
+There are no public Trace2 data structures.
+
+The Trace2 code also defines a set of private functions and data types
+in the `trace2/` directory.  These symbols are prefixed with `tr2_`
+and should only be used by functions in `trace2.c`.
+
+== Conventions for Public Functions and Macros
+
+The functions defined by the Trace2 API are declared and documented
+in `trace2.h`.  It defines the API functions and wrapper macros for
+Trace2.
+
+Some functions have a `_fl()` suffix to indicate that they take `file`
+and `line-number` arguments.
+
+Some functions have a `_va_fl()` suffix to indicate that they also
+take a `va_list` argument.
+
+Some functions have a `_printf_fl()` suffix to indicate that they also
+take a varargs argument.
+
+There are CPP wrapper macros and ifdefs to hide most of these details.
+See `trace2.h` for more details.  The following discussion will only
+describe the simplified forms.
+
+== Public API
+
+All Trace2 API functions send a message to all of the active
+Trace2 Targets.  This section describes the set of available
+messages.
+
+It helps to divide these functions into groups for discussion
+purposes.
+
+=== Basic Command Messages
+
+These are concerned with the lifetime of the overall git process.
+e.g: `void trace2_initialize_clock()`, `void trace2_initialize()`,
+`int trace2_is_enabled()`, `void trace2_cmd_start(int argc, const char **argv)`.
+
+=== Command Detail Messages
+
+These are concerned with describing the specific Git command
+after the command line, config, and environment are inspected.
+e.g: `void trace2_cmd_name(const char *name)`,
+`void trace2_cmd_mode(const char *mode)`.
+
+=== Child Process Messages
+
+These are concerned with the various spawned child processes,
+including shell scripts, git commands, editors, pagers, and hooks.
+
+e.g: `void trace2_child_start(struct child_process *cmd)`.
+
+=== Git Thread Messages
+
+These messages are concerned with Git thread usage.
+
+e.g: `void trace2_thread_start(const char *thread_name)`.
+
+=== Region and Data Messages
+
+These are concerned with recording performance data
+over regions or spans of code. e.g:
+`void trace2_region_enter(const char *category, const char *label, const struct repository *repo)`.
+
+Refer to trace2.h for details about all trace2 functions.
+
+== Trace2 Target Formats
+
+=== NORMAL Format
+
+Events are written as lines of the form:
+
+------------
+[<time> SP <filename>:<line> SP+] <event-name> [[SP] <event-message>] LF
+------------
+
+`<event-name>`::
+
+	is the event name.
+
+`<event-message>`::
+	is a free-form printf message intended for human consumption.
++
+Note that this may contain embedded LF or CRLF characters that are
+not escaped, so the event may spill across multiple lines.
+
+If `GIT_TRACE2_BRIEF` or `trace2.normalBrief` is true, the `time`, `filename`,
+and `line` fields are omitted.
+
+This target is intended to be more of a summary (like GIT_TRACE) and
+less detailed than the other targets.  It ignores thread, region, and
+data messages, for example.
+
+=== PERF Format
+
+Events are written as lines of the form:
+
+------------
+[<time> SP <filename>:<line> SP+
+    BAR SP] d<depth> SP
+    BAR SP <thread-name> SP+
+    BAR SP <event-name> SP+
+    BAR SP [r<repo-id>] SP+
+    BAR SP [<t_abs>] SP+
+    BAR SP [<t_rel>] SP+
+    BAR SP [<category>] SP+
+    BAR SP DOTS* <perf-event-message>
+    LF
+------------
+
+`<depth>`::
+	is the git process depth.  This is the number of parent
+	git processes.  A top-level git command has depth value "d0".
+	A child of it has depth value "d1".  A second level child
+	has depth value "d2" and so on.
+
+`<thread-name>`::
+	is a unique name for the thread.  The primary thread
+	is called "main".  Other thread names are of the form "th%d:%s"
+	and include a unique number and the name of the thread-proc.
+
+`<event-name>`::
+	is the event name.
+
+`<repo-id>`::
+	when present, is a number indicating the repository
+	in use.  A `def_repo` event is emitted when a repository is
+	opened.  This defines the repo-id and associated worktree.
+	Subsequent repo-specific events will reference this repo-id.
++
+Currently, this is always "r1" for the main repository.
+This field is in anticipation of in-proc submodules in the future.
+
+`<t_abs>`::
+	when present, is the absolute time in seconds since the
+	program started.
+
+`<t_rel>`::
+	when present, is time in seconds relative to the start of
+	the current region.  For a thread-exit event, it is the elapsed
+	time of the thread.
+
+`<category>`::
+	is present on region and data events and is used to
+	indicate a broad category, such as "index" or "status".
+
+`<perf-event-message>`::
+	is a free-form printf message intended for human consumption.
+
+------------
+15:33:33.532712 wt-status.c:2310                  | d0 | main                     | region_enter | r1  |  0.126064 |           | status     | label:print
+15:33:33.532712 wt-status.c:2331                  | d0 | main                     | region_leave | r1  |  0.127568 |  0.001504 | status     | label:print
+------------
+
+If `GIT_TRACE2_PERF_BRIEF` or `trace2.perfBrief` is true, the `time`, `file`,
+and `line` fields are omitted.
+
+------------
+d0 | main                     | region_leave | r1  |  0.011717 |  0.009122 | index      | label:preload
+------------
+
+The PERF target is intended for interactive performance analysis
+during development and is quite noisy.
+
+=== EVENT Format
+
+Each event is a JSON-object containing multiple key/value pairs
+written as a single line and followed by a LF.
+
+------------
+'{' <key> ':' <value> [',' <key> ':' <value>]* '}' LF
+------------
+
+Some key/value pairs are common to all events and some are
+event-specific.
+
+==== Common Key/Value Pairs
+
+The following key/value pairs are common to all events:
+
+------------
+{
+	"event":"version",
+	"sid":"20190408T191827.272759Z-H9b68c35f-P00003510",
+	"thread":"main",
+	"time":"2019-04-08T19:18:27.282761Z",
+	"file":"common-main.c",
+	"line":42,
+	...
+}
+------------
+
+`"event":<event>`::
+	is the event name.
+
+`"sid":<sid>`::
+	is the session-id.  This is a unique string to identify the
+	process instance to allow all events emitted by a process to
+	be identified.  A session-id is used instead of a PID because
+	PIDs are recycled by the OS.  For child git processes, the
+	session-id is prepended with the session-id of the parent git
+	process to allow parent-child relationships to be identified
+	during post-processing.
+
+`"thread":<thread>`::
+	is the thread name.
+
+`"time":<time>`::
+	is the UTC time of the event.
+
+`"file":<filename>`::
+	is source file generating the event.
+
+`"line":<line-number>`::
+	is the integer source line number generating the event.
+
+`"repo":<repo-id>`::
+	when present, is the integer repo-id as described previously.
+
+If `GIT_TRACE2_EVENT_BRIEF` or `trace2.eventBrief` is true, the `file`
+and `line` fields are omitted from all events and the `time` field is
+only present on the "start" and "atexit" events.
+
+==== Event-Specific Key/Value Pairs
+
+`"version"`::
+	This event gives the version of the executable and the EVENT format. It
+	should always be the first event in a trace session. The EVENT format
+	version will be incremented if new event types are added, if existing
+	fields are removed, or if there are significant changes in
+	interpretation of existing events or fields. Smaller changes, such as
+	adding a new field to an existing event, will not require an increment
+	to the EVENT format version.
++
+------------
+{
+	"event":"version",
+	...
+	"evt":"2",		       # EVENT format version
+	"exe":"2.20.1.155.g426c96fcdb" # git version
+}
+------------
+
+`"discard"`::
+	This event is written to the git-trace2-discard sentinel file if there
+	are too many files in the target trace directory (see the
+	trace2.maxFiles config option).
++
+------------
+{
+	"event":"discard",
+	...
+}
+------------
+
+`"start"`::
+	This event contains the complete argv received by main().
++
+------------
+{
+	"event":"start",
+	...
+	"t_abs":0.001227, # elapsed time in seconds
+	"argv":["git","version"]
+}
+------------
+
+`"exit"`::
+	This event is emitted when git calls `exit()`.
++
+------------
+{
+	"event":"exit",
+	...
+	"t_abs":0.001227, # elapsed time in seconds
+	"code":0	  # exit code
+}
+------------
+
+`"atexit"`::
+	This event is emitted by the Trace2 `atexit` routine during
+	final shutdown.  It should be the last event emitted by the
+	process.
++
+(The elapsed time reported here is greater than the time reported in
+the "exit" event because it runs after all other atexit tasks have
+completed.)
++
+------------
+{
+	"event":"atexit",
+	...
+	"t_abs":0.001227, # elapsed time in seconds
+	"code":0          # exit code
+}
+------------
+
+`"signal"`::
+	This event is emitted when the program is terminated by a user
+	signal.  Depending on the platform, the signal event may
+	prevent the "atexit" event from being generated.
++
+------------
+{
+	"event":"signal",
+	...
+	"t_abs":0.001227,  # elapsed time in seconds
+	"signo":13         # SIGTERM, SIGINT, etc.
+}
+------------
+
+`"error"`::
+	This event is emitted when one of the `error()`, `die()`,
+	or `usage()` functions are called.
++
+------------
+{
+	"event":"error",
+	...
+	"msg":"invalid option: --cahced", # formatted error message
+	"fmt":"invalid option: %s"	  # error format string
+}
+------------
++
+The error event may be emitted more than once.  The format string
+allows post-processors to group errors by type without worrying
+about specific error arguments.
+
+`"cmd_path"`::
+	This event contains the discovered full path of the git
+	executable (on platforms that are configured to resolve it).
++
+------------
+{
+	"event":"cmd_path",
+	...
+	"path":"C:/work/gfw/git.exe"
+}
+------------
+
+`"cmd_name"`::
+	This event contains the command name for this git process
+	and the hierarchy of commands from parent git processes.
++
+------------
+{
+	"event":"cmd_name",
+	...
+	"name":"pack-objects",
+	"hierarchy":"push/pack-objects"
+}
+------------
++
+Normally, the "name" field contains the canonical name of the
+command.  When a canonical name is not available, one of
+these special values are used:
++
+------------
+"_query_"            # "git --html-path"
+"_run_dashed_"       # when "git foo" tries to run "git-foo"
+"_run_shell_alias_"  # alias expansion to a shell command
+"_run_git_alias_"    # alias expansion to a git command
+"_usage_"            # usage error
+------------
+
+`"cmd_mode"`::
+	This event, when present, describes the command variant This
+	event may be emitted more than once.
++
+------------
+{
+	"event":"cmd_mode",
+	...
+	"name":"branch"
+}
+------------
++
+The "name" field is an arbitrary string to describe the command mode.
+For example, checkout can checkout a branch or an individual file.
+And these variations typically have different performance
+characteristics that are not comparable.
+
+`"alias"`::
+	This event is present when an alias is expanded.
++
+------------
+{
+	"event":"alias",
+	...
+	"alias":"l",		 # registered alias
+	"argv":["log","--graph"] # alias expansion
+}
+------------
+
+`"child_start"`::
+	This event describes a child process that is about to be
+	spawned.
++
+------------
+{
+	"event":"child_start",
+	...
+	"child_id":2,
+	"child_class":"?",
+	"use_shell":false,
+	"argv":["git","rev-list","--objects","--stdin","--not","--all","--quiet"]
+
+	"hook_name":"<hook_name>"  # present when child_class is "hook"
+	"cd":"<path>"		   # present when cd is required
+}
+------------
++
+The "child_id" field can be used to match this child_start with the
+corresponding child_exit event.
++
+The "child_class" field is a rough classification, such as "editor",
+"pager", "transport/*", and "hook".  Unclassified children are classified
+with "?".
+
+`"child_exit"`::
+	This event is generated after the current process has returned
+	from the waitpid() and collected the exit information from the
+	child.
++
+------------
+{
+	"event":"child_exit",
+	...
+	"child_id":2,
+	"pid":14708,	 # child PID
+	"code":0,	 # child exit-code
+	"t_rel":0.110605 # observed run-time of child process
+}
+------------
++
+Note that the session-id of the child process is not available to
+the current/spawning process, so the child's PID is reported here as
+a hint for post-processing.  (But it is only a hint because the child
+process may be a shell script which doesn't have a session-id.)
++
+Note that the `t_rel` field contains the observed run time in seconds
+for the child process (starting before the fork/exec/spawn and
+stopping after the waitpid() and includes OS process creation overhead).
+So this time will be slightly larger than the atexit time reported by
+the child process itself.
+
+`"exec"`::
+	This event is generated before git attempts to `exec()`
+	another command rather than starting a child process.
++
+------------
+{
+	"event":"exec",
+	...
+	"exec_id":0,
+	"exe":"git",
+	"argv":["foo", "bar"]
+}
+------------
++
+The "exec_id" field is a command-unique id and is only useful if the
+`exec()` fails and a corresponding exec_result event is generated.
+
+`"exec_result"`::
+	This event is generated if the `exec()` fails and control
+	returns to the current git command.
++
+------------
+{
+	"event":"exec_result",
+	...
+	"exec_id":0,
+	"code":1      # error code (errno) from exec()
+}
+------------
+
+`"thread_start"`::
+	This event is generated when a thread is started.  It is
+	generated from *within* the new thread's thread-proc (for TLS
+	reasons).
++
+------------
+{
+	"event":"thread_start",
+	...
+	"thread":"th02:preload_thread" # thread name
+}
+------------
+
+`"thread_exit"`::
+	This event is generated when a thread exits.  It is generated
+	from *within* the thread's thread-proc (for TLS reasons).
++
+------------
+{
+	"event":"thread_exit",
+	...
+	"thread":"th02:preload_thread", # thread name
+	"t_rel":0.007328                # thread elapsed time
+}
+------------
+
+`"def_param"`::
+	This event is generated to log a global parameter.
++
+------------
+{
+	"event":"def_param",
+	...
+	"param":"core.abbrev",
+	"value":"7"
+}
+------------
+
+`"def_repo"`::
+	This event defines a repo-id and associates it with the root
+	of the worktree.
++
+------------
+{
+	"event":"def_repo",
+	...
+	"repo":1,
+	"worktree":"/Users/jeffhost/work/gfw"
+}
+------------
++
+As stated earlier, the repo-id is currently always 1, so there will
+only be one def_repo event.  Later, if in-proc submodules are
+supported, a def_repo event should be emitted for each submodule
+visited.
+
+`"region_enter"`::
+	This event is generated when entering a region.
++
+------------
+{
+	"event":"region_enter",
+	...
+	"repo":1,                # optional
+	"nesting":1,             # current region stack depth
+	"category":"index",      # optional
+	"label":"do_read_index", # optional
+	"msg":".git/index"       # optional
+}
+------------
++
+The `category` field may be used in a future enhancement to
+do category-based filtering.
++
+`GIT_TRACE2_EVENT_NESTING` or `trace2.eventNesting` can be used to
+filter deeply nested regions and data events.  It defaults to "2".
+
+`"region_leave"`::
+	This event is generated when leaving a region.
++
+------------
+{
+	"event":"region_leave",
+	...
+	"repo":1,                # optional
+	"t_rel":0.002876,        # time spent in region in seconds
+	"nesting":1,             # region stack depth
+	"category":"index",      # optional
+	"label":"do_read_index", # optional
+	"msg":".git/index"       # optional
+}
+------------
+
+`"data"`::
+	This event is generated to log a thread- and region-local
+	key/value pair.
++
+------------
+{
+	"event":"data",
+	...
+	"repo":1,              # optional
+	"t_abs":0.024107,      # absolute elapsed time
+	"t_rel":0.001031,      # elapsed time in region/thread
+	"nesting":2,           # region stack depth
+	"category":"index",
+	"key":"read/cache_nr",
+	"value":"3552"
+}
+------------
++
+The "value" field may be an integer or a string.
+
+`"data-json"`::
+	This event is generated to log a pre-formatted JSON string
+	containing structured data.
++
+------------
+{
+	"event":"data_json",
+	...
+	"repo":1,              # optional
+	"t_abs":0.015905,
+	"t_rel":0.015905,
+	"nesting":1,
+	"category":"process",
+	"key":"windows/ancestry",
+	"value":["bash.exe","bash.exe"]
+}
+------------
+
+== Example Trace2 API Usage
+
+Here is a hypothetical usage of the Trace2 API showing the intended
+usage (without worrying about the actual Git details).
+
+Initialization::
+
+	Initialization happens in `main()`.  Behind the scenes, an
+	`atexit` and `signal` handler are registered.
++
+----------------
+int main(int argc, const char **argv)
+{
+	int exit_code;
+
+	trace2_initialize();
+	trace2_cmd_start(argv);
+
+	exit_code = cmd_main(argc, argv);
+
+	trace2_cmd_exit(exit_code);
+
+	return exit_code;
+}
+----------------
+
+Command Details::
+
+	After the basics are established, additional command
+	information can be sent to Trace2 as it is discovered.
++
+----------------
+int cmd_checkout(int argc, const char **argv)
+{
+	trace2_cmd_name("checkout");
+	trace2_cmd_mode("branch");
+	trace2_def_repo(the_repository);
+
+	// emit "def_param" messages for "interesting" config settings.
+	trace2_cmd_list_config();
+
+	if (do_something())
+	    trace2_cmd_error("Path '%s': cannot do something", path);
+
+	return 0;
+}
+----------------
+
+Child Processes::
+
+	Wrap code spawning child processes.
++
+----------------
+void run_child(...)
+{
+	int child_exit_code;
+	struct child_process cmd = CHILD_PROCESS_INIT;
+	...
+	cmd.trace2_child_class = "editor";
+
+	trace2_child_start(&cmd);
+	child_exit_code = spawn_child_and_wait_for_it();
+	trace2_child_exit(&cmd, child_exit_code);
+}
+----------------
++
+For example, the following fetch command spawned ssh, index-pack,
+rev-list, and gc.  This example also shows that fetch took
+5.199 seconds and of that 4.932 was in ssh.
++
+----------------
+$ export GIT_TRACE2_BRIEF=1
+$ export GIT_TRACE2=~/log.normal
+$ git fetch origin
+...
+----------------
++
+----------------
+$ cat ~/log.normal
+version 2.20.1.vfs.1.1.47.g534dbe1ad1
+start git fetch origin
+worktree /Users/jeffhost/work/gfw
+cmd_name fetch (fetch)
+child_start[0] ssh git@github.com ...
+child_start[1] git index-pack ...
+... (Trace2 events from child processes omitted)
+child_exit[1] pid:14707 code:0 elapsed:0.076353
+child_exit[0] pid:14706 code:0 elapsed:4.931869
+child_start[2] git rev-list ...
+... (Trace2 events from child process omitted)
+child_exit[2] pid:14708 code:0 elapsed:0.110605
+child_start[3] git gc --auto
+... (Trace2 events from child process omitted)
+child_exit[3] pid:14709 code:0 elapsed:0.006240
+exit elapsed:5.198503 code:0
+atexit elapsed:5.198541 code:0
+----------------
++
+When a git process is a (direct or indirect) child of another
+git process, it inherits Trace2 context information.  This
+allows the child to print the command hierarchy.  This example
+shows gc as child[3] of fetch.  When the gc process reports
+its name as "gc", it also reports the hierarchy as "fetch/gc".
+(In this example, trace2 messages from the child process is
+indented for clarity.)
++
+----------------
+$ export GIT_TRACE2_BRIEF=1
+$ export GIT_TRACE2=~/log.normal
+$ git fetch origin
+...
+----------------
++
+----------------
+$ cat ~/log.normal
+version 2.20.1.160.g5676107ecd.dirty
+start git fetch official
+worktree /Users/jeffhost/work/gfw
+cmd_name fetch (fetch)
+...
+child_start[3] git gc --auto
+    version 2.20.1.160.g5676107ecd.dirty
+    start /Users/jeffhost/work/gfw/git gc --auto
+    worktree /Users/jeffhost/work/gfw
+    cmd_name gc (fetch/gc)
+    exit elapsed:0.001959 code:0
+    atexit elapsed:0.001997 code:0
+child_exit[3] pid:20303 code:0 elapsed:0.007564
+exit elapsed:3.868938 code:0
+atexit elapsed:3.868970 code:0
+----------------
+
+Regions::
+
+	Regions can be use to time an interesting section of code.
++
+----------------
+void wt_status_collect(struct wt_status *s)
+{
+	trace2_region_enter("status", "worktrees", s->repo);
+	wt_status_collect_changes_worktree(s);
+	trace2_region_leave("status", "worktrees", s->repo);
+
+	trace2_region_enter("status", "index", s->repo);
+	wt_status_collect_changes_index(s);
+	trace2_region_leave("status", "index", s->repo);
+
+	trace2_region_enter("status", "untracked", s->repo);
+	wt_status_collect_untracked(s);
+	trace2_region_leave("status", "untracked", s->repo);
+}
+
+void wt_status_print(struct wt_status *s)
+{
+	trace2_region_enter("status", "print", s->repo);
+	switch (s->status_format) {
+	    ...
+	}
+	trace2_region_leave("status", "print", s->repo);
+}
+----------------
++
+In this example, scanning for untracked files ran from +0.012568 to
++0.027149 (since the process started) and took 0.014581 seconds.
++
+----------------
+$ export GIT_TRACE2_PERF_BRIEF=1
+$ export GIT_TRACE2_PERF=~/log.perf
+$ git status
+...
+
+$ cat ~/log.perf
+d0 | main                     | version      |     |           |           |            | 2.20.1.160.g5676107ecd.dirty
+d0 | main                     | start        |     |  0.001173 |           |            | git status
+d0 | main                     | def_repo     | r1  |           |           |            | worktree:/Users/jeffhost/work/gfw
+d0 | main                     | cmd_name     |     |           |           |            | status (status)
+...
+d0 | main                     | region_enter | r1  |  0.010988 |           | status     | label:worktrees
+d0 | main                     | region_leave | r1  |  0.011236 |  0.000248 | status     | label:worktrees
+d0 | main                     | region_enter | r1  |  0.011260 |           | status     | label:index
+d0 | main                     | region_leave | r1  |  0.012542 |  0.001282 | status     | label:index
+d0 | main                     | region_enter | r1  |  0.012568 |           | status     | label:untracked
+d0 | main                     | region_leave | r1  |  0.027149 |  0.014581 | status     | label:untracked
+d0 | main                     | region_enter | r1  |  0.027411 |           | status     | label:print
+d0 | main                     | region_leave | r1  |  0.028741 |  0.001330 | status     | label:print
+d0 | main                     | exit         |     |  0.028778 |           |            | code:0
+d0 | main                     | atexit       |     |  0.028809 |           |            | code:0
+----------------
++
+Regions may be nested.  This causes messages to be indented in the
+PERF target, for example.
+Elapsed times are relative to the start of the corresponding nesting
+level as expected.  For example, if we add region message to:
++
+----------------
+static enum path_treatment read_directory_recursive(struct dir_struct *dir,
+	struct index_state *istate, const char *base, int baselen,
+	struct untracked_cache_dir *untracked, int check_only,
+	int stop_at_first_file, const struct pathspec *pathspec)
+{
+	enum path_treatment state, subdir_state, dir_state = path_none;
+
+	trace2_region_enter_printf("dir", "read_recursive", NULL, "%.*s", baselen, base);
+	...
+	trace2_region_leave_printf("dir", "read_recursive", NULL, "%.*s", baselen, base);
+	return dir_state;
+}
+----------------
++
+We can further investigate the time spent scanning for untracked files.
++
+----------------
+$ export GIT_TRACE2_PERF_BRIEF=1
+$ export GIT_TRACE2_PERF=~/log.perf
+$ git status
+...
+$ cat ~/log.perf
+d0 | main                     | version      |     |           |           |            | 2.20.1.162.gb4ccea44db.dirty
+d0 | main                     | start        |     |  0.001173 |           |            | git status
+d0 | main                     | def_repo     | r1  |           |           |            | worktree:/Users/jeffhost/work/gfw
+d0 | main                     | cmd_name     |     |           |           |            | status (status)
+...
+d0 | main                     | region_enter | r1  |  0.015047 |           | status     | label:untracked
+d0 | main                     | region_enter |     |  0.015132 |           | dir        | ..label:read_recursive
+d0 | main                     | region_enter |     |  0.016341 |           | dir        | ....label:read_recursive vcs-svn/
+d0 | main                     | region_leave |     |  0.016422 |  0.000081 | dir        | ....label:read_recursive vcs-svn/
+d0 | main                     | region_enter |     |  0.016446 |           | dir        | ....label:read_recursive xdiff/
+d0 | main                     | region_leave |     |  0.016522 |  0.000076 | dir        | ....label:read_recursive xdiff/
+d0 | main                     | region_enter |     |  0.016612 |           | dir        | ....label:read_recursive git-gui/
+d0 | main                     | region_enter |     |  0.016698 |           | dir        | ......label:read_recursive git-gui/po/
+d0 | main                     | region_enter |     |  0.016810 |           | dir        | ........label:read_recursive git-gui/po/glossary/
+d0 | main                     | region_leave |     |  0.016863 |  0.000053 | dir        | ........label:read_recursive git-gui/po/glossary/
+...
+d0 | main                     | region_enter |     |  0.031876 |           | dir        | ....label:read_recursive builtin/
+d0 | main                     | region_leave |     |  0.032270 |  0.000394 | dir        | ....label:read_recursive builtin/
+d0 | main                     | region_leave |     |  0.032414 |  0.017282 | dir        | ..label:read_recursive
+d0 | main                     | region_leave | r1  |  0.032454 |  0.017407 | status     | label:untracked
+...
+d0 | main                     | exit         |     |  0.034279 |           |            | code:0
+d0 | main                     | atexit       |     |  0.034322 |           |            | code:0
+----------------
++
+Trace2 regions are similar to the existing trace_performance_enter()
+and trace_performance_leave() routines, but are thread safe and
+maintain per-thread stacks of timers.
+
+Data Messages::
+
+	Data messages added to a region.
++
+----------------
+int read_index_from(struct index_state *istate, const char *path,
+	const char *gitdir)
+{
+	trace2_region_enter_printf("index", "do_read_index", the_repository, "%s", path);
+
+	...
+
+	trace2_data_intmax("index", the_repository, "read/version", istate->version);
+	trace2_data_intmax("index", the_repository, "read/cache_nr", istate->cache_nr);
+
+	trace2_region_leave_printf("index", "do_read_index", the_repository, "%s", path);
+}
+----------------
++
+This example shows that the index contained 3552 entries.
++
+----------------
+$ export GIT_TRACE2_PERF_BRIEF=1
+$ export GIT_TRACE2_PERF=~/log.perf
+$ git status
+...
+$ cat ~/log.perf
+d0 | main                     | version      |     |           |           |            | 2.20.1.156.gf9916ae094.dirty
+d0 | main                     | start        |     |  0.001173 |           |            | git status
+d0 | main                     | def_repo     | r1  |           |           |            | worktree:/Users/jeffhost/work/gfw
+d0 | main                     | cmd_name     |     |           |           |            | status (status)
+d0 | main                     | region_enter | r1  |  0.001791 |           | index      | label:do_read_index .git/index
+d0 | main                     | data         | r1  |  0.002494 |  0.000703 | index      | ..read/version:2
+d0 | main                     | data         | r1  |  0.002520 |  0.000729 | index      | ..read/cache_nr:3552
+d0 | main                     | region_leave | r1  |  0.002539 |  0.000748 | index      | label:do_read_index .git/index
+...
+----------------
+
+Thread Events::
+
+	Thread messages added to a thread-proc.
++
+For example, the multithreaded preload-index code can be
+instrumented with a region around the thread pool and then
+per-thread start and exit events within the threadproc.
++
+----------------
+static void *preload_thread(void *_data)
+{
+	// start the per-thread clock and emit a message.
+	trace2_thread_start("preload_thread");
+
+	// report which chunk of the array this thread was assigned.
+	trace2_data_intmax("index", the_repository, "offset", p->offset);
+	trace2_data_intmax("index", the_repository, "count", nr);
+
+	do {
+	    ...
+	} while (--nr > 0);
+	...
+
+	// report elapsed time taken by this thread.
+	trace2_thread_exit();
+	return NULL;
+}
+
+void preload_index(struct index_state *index,
+	const struct pathspec *pathspec,
+	unsigned int refresh_flags)
+{
+	trace2_region_enter("index", "preload", the_repository);
+
+	for (i = 0; i < threads; i++) {
+	    ... /* create thread */
+	}
+
+	for (i = 0; i < threads; i++) {
+	    ... /* join thread */
+	}
+
+	trace2_region_leave("index", "preload", the_repository);
+}
+----------------
++
+In this example preload_index() was executed by the `main` thread
+and started the `preload` region.  Seven threads, named
+`th01:preload_thread` through `th07:preload_thread`, were started.
+Events from each thread are atomically appended to the shared target
+stream as they occur so they may appear in random order with respect
+other threads. Finally, the main thread waits for the threads to
+finish and leaves the region.
++
+Data events are tagged with the active thread name.  They are used
+to report the per-thread parameters.
++
+----------------
+$ export GIT_TRACE2_PERF_BRIEF=1
+$ export GIT_TRACE2_PERF=~/log.perf
+$ git status
+...
+$ cat ~/log.perf
+...
+d0 | main                     | region_enter | r1  |  0.002595 |           | index      | label:preload
+d0 | th01:preload_thread      | thread_start |     |  0.002699 |           |            |
+d0 | th02:preload_thread      | thread_start |     |  0.002721 |           |            |
+d0 | th01:preload_thread      | data         | r1  |  0.002736 |  0.000037 | index      | offset:0
+d0 | th02:preload_thread      | data         | r1  |  0.002751 |  0.000030 | index      | offset:2032
+d0 | th03:preload_thread      | thread_start |     |  0.002711 |           |            |
+d0 | th06:preload_thread      | thread_start |     |  0.002739 |           |            |
+d0 | th01:preload_thread      | data         | r1  |  0.002766 |  0.000067 | index      | count:508
+d0 | th06:preload_thread      | data         | r1  |  0.002856 |  0.000117 | index      | offset:2540
+d0 | th03:preload_thread      | data         | r1  |  0.002824 |  0.000113 | index      | offset:1016
+d0 | th04:preload_thread      | thread_start |     |  0.002710 |           |            |
+d0 | th02:preload_thread      | data         | r1  |  0.002779 |  0.000058 | index      | count:508
+d0 | th06:preload_thread      | data         | r1  |  0.002966 |  0.000227 | index      | count:508
+d0 | th07:preload_thread      | thread_start |     |  0.002741 |           |            |
+d0 | th07:preload_thread      | data         | r1  |  0.003017 |  0.000276 | index      | offset:3048
+d0 | th05:preload_thread      | thread_start |     |  0.002712 |           |            |
+d0 | th05:preload_thread      | data         | r1  |  0.003067 |  0.000355 | index      | offset:1524
+d0 | th05:preload_thread      | data         | r1  |  0.003090 |  0.000378 | index      | count:508
+d0 | th07:preload_thread      | data         | r1  |  0.003037 |  0.000296 | index      | count:504
+d0 | th03:preload_thread      | data         | r1  |  0.002971 |  0.000260 | index      | count:508
+d0 | th04:preload_thread      | data         | r1  |  0.002983 |  0.000273 | index      | offset:508
+d0 | th04:preload_thread      | data         | r1  |  0.007311 |  0.004601 | index      | count:508
+d0 | th05:preload_thread      | thread_exit  |     |  0.008781 |  0.006069 |            |
+d0 | th01:preload_thread      | thread_exit  |     |  0.009561 |  0.006862 |            |
+d0 | th03:preload_thread      | thread_exit  |     |  0.009742 |  0.007031 |            |
+d0 | th06:preload_thread      | thread_exit  |     |  0.009820 |  0.007081 |            |
+d0 | th02:preload_thread      | thread_exit  |     |  0.010274 |  0.007553 |            |
+d0 | th07:preload_thread      | thread_exit  |     |  0.010477 |  0.007736 |            |
+d0 | th04:preload_thread      | thread_exit  |     |  0.011657 |  0.008947 |            |
+d0 | main                     | region_leave | r1  |  0.011717 |  0.009122 | index      | label:preload
+...
+d0 | main                     | exit         |     |  0.029996 |           |            | code:0
+d0 | main                     | atexit       |     |  0.030027 |           |            | code:0
+----------------
++
+In this example, the preload region took 0.009122 seconds.  The 7 threads
+took between 0.006069 and 0.008947 seconds to work on their portion of
+the index.  Thread "th01" worked on 508 items at offset 0.  Thread "th02"
+worked on 508 items at offset 2032.  Thread "th04" worked on 508 items
+at offset 508.
++
+This example also shows that thread names are assigned in a racy manner
+as each thread starts and allocates TLS storage.
+
+== Future Work
+
+=== Relationship to the Existing Trace Api (api-trace.txt)
+
+There are a few issues to resolve before we can completely
+switch to Trace2.
+
+* Updating existing tests that assume GIT_TRACE format messages.
+
+* How to best handle custom GIT_TRACE_<key> messages?
+
+** The GIT_TRACE_<key> mechanism allows each <key> to write to a
+different file (in addition to just stderr).
+
+** Do we want to maintain that ability or simply write to the existing
+Trace2 targets (and convert <key> to a "category").
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/technical/api-trace.txt 1.2.3+git2.25.1-1/git/Documentation/technical/api-trace.txt
--- 1.2.1+git2.18.0-1/git/Documentation/technical/api-trace.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/technical/api-trace.txt	1970-01-01 00:00:00.000000000 +0000
@@ -1,140 +0,0 @@
-trace API
-=========
-
-The trace API can be used to print debug messages to stderr or a file. Trace
-code is inactive unless explicitly enabled by setting `GIT_TRACE*` environment
-variables.
-
-The trace implementation automatically adds `timestamp file:line ... \n` to
-all trace messages. E.g.:
-
-------------
-23:59:59.123456 git.c:312               trace: built-in: git 'foo'
-00:00:00.000001 builtin/foo.c:99        foo: some message
-------------
-
-Data Structures
----------------
-
-`struct trace_key`::
-
-	Defines a trace key (or category). The default (for API functions that
-	don't take a key) is `GIT_TRACE`.
-+
-E.g. to define a trace key controlled by environment variable `GIT_TRACE_FOO`:
-+
-------------
-static struct trace_key trace_foo = TRACE_KEY_INIT(FOO);
-
-static void trace_print_foo(const char *message)
-{
-	trace_printf_key(&trace_foo, "%s", message);
-}
-------------
-+
-Note: don't use `const` as the trace implementation stores internal state in
-the `trace_key` structure.
-
-Functions
----------
-
-`int trace_want(struct trace_key *key)`::
-
-	Checks whether the trace key is enabled. Used to prevent expensive
-	string formatting before calling one of the printing APIs.
-
-`void trace_disable(struct trace_key *key)`::
-
-	Disables tracing for the specified key, even if the environment
-	variable was set.
-
-`void trace_printf(const char *format, ...)`::
-`void trace_printf_key(struct trace_key *key, const char *format, ...)`::
-
-	Prints a formatted message, similar to printf.
-
-`void trace_argv_printf(const char **argv, const char *format, ...)``::
-
-	Prints a formatted message, followed by a quoted list of arguments.
-
-`void trace_strbuf(struct trace_key *key, const struct strbuf *data)`::
-
-	Prints the strbuf, without additional formatting (i.e. doesn't
-	choke on `%` or even `\0`).
-
-`uint64_t getnanotime(void)`::
-
-	Returns nanoseconds since the epoch (01/01/1970), typically used
-	for performance measurements.
-+
-Currently there are high precision timer implementations for Linux (using
-`clock_gettime(CLOCK_MONOTONIC)`) and Windows (`QueryPerformanceCounter`).
-Other platforms use `gettimeofday` as time source.
-
-`void trace_performance(uint64_t nanos, const char *format, ...)`::
-`void trace_performance_since(uint64_t start, const char *format, ...)`::
-
-	Prints the elapsed time (in nanoseconds), or elapsed time since
-	`start`, followed by a formatted message. Enabled via environment
-	variable `GIT_TRACE_PERFORMANCE`. Used for manual profiling, e.g.:
-+
-------------
-uint64_t start = getnanotime();
-/* code section to measure */
-trace_performance_since(start, "foobar");
-------------
-+
-------------
-uint64_t t = 0;
-for (;;) {
-	/* ignore */
-	t -= getnanotime();
-	/* code section to measure */
-	t += getnanotime();
-	/* ignore */
-}
-trace_performance(t, "frotz");
-------------
-
-Bugs & Caveats
---------------
-
-GIT_TRACE_* environment variables can be used to tell Git to show
-trace output to its standard error stream. Git can often spawn a pager
-internally to run its subcommand and send its standard output and
-standard error to it.
-
-Because GIT_TRACE_PERFORMANCE trace is generated only at the very end
-of the program with atexit(), which happens after the pager exits, it
-would not work well if you send its log to the standard error output
-and let Git spawn the pager at the same time.
-
-As a work around, you can for example use '--no-pager', or set
-GIT_TRACE_PERFORMANCE to another file descriptor which is redirected
-to stderr, or set GIT_TRACE_PERFORMANCE to a file specified by its
-absolute path.
-
-For example instead of the following command which by default may not
-print any performance information:
-
-------------
-GIT_TRACE_PERFORMANCE=2 git log -1
-------------
-
-you may want to use:
-
-------------
-GIT_TRACE_PERFORMANCE=2 git --no-pager log -1
-------------
-
-or:
-
-------------
-GIT_TRACE_PERFORMANCE=3 3>&2 git log -1
-------------
-
-or:
-
-------------
-GIT_TRACE_PERFORMANCE=/path/to/log/file git log -1
-------------
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/technical/api-tree-walking.txt 1.2.3+git2.25.1-1/git/Documentation/technical/api-tree-walking.txt
--- 1.2.1+git2.18.0-1/git/Documentation/technical/api-tree-walking.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/technical/api-tree-walking.txt	1970-01-01 00:00:00.000000000 +0000
@@ -1,147 +0,0 @@
-tree walking API
-================
-
-The tree walking API is used to traverse and inspect trees.
-
-Data Structures
----------------
-
-`struct name_entry`::
-
-	An entry in a tree. Each entry has a sha1 identifier, pathname, and
-	mode.
-
-`struct tree_desc`::
-
-	A semi-opaque data structure used to maintain the current state of the
-	walk.
-+
-* `buffer` is a pointer into the memory representation of the tree. It always
-points at the current entry being visited.
-
-* `size` counts the number of bytes left in the `buffer`.
-
-* `entry` points to the current entry being visited.
-
-`struct traverse_info`::
-
-	A structure used to maintain the state of a traversal.
-+
-* `prev` points to the traverse_info which was used to descend into the
-current tree. If this is the top-level tree `prev` will point to
-a dummy traverse_info.
-
-* `name` is the entry for the current tree (if the tree is a subtree).
-
-* `pathlen` is the length of the full path for the current tree.
-
-* `conflicts` can be used by callbacks to maintain directory-file conflicts.
-
-* `fn` is a callback called for each entry in the tree. See Traversing for more
-information.
-
-* `data` can be anything the `fn` callback would want to use.
-
-* `show_all_errors` tells whether to stop at the first error or not.
-
-Initializing
-------------
-
-`init_tree_desc`::
-
-	Initialize a `tree_desc` and decode its first entry. The buffer and
-	size parameters are assumed to be the same as the buffer and size
-	members of `struct tree`.
-
-`fill_tree_descriptor`::
-
-	Initialize a `tree_desc` and decode its first entry given the
-	object ID of a tree. Returns the `buffer` member if the latter
-	is a valid tree identifier and NULL otherwise.
-
-`setup_traverse_info`::
-
-	Initialize a `traverse_info` given the pathname of the tree to start
-	traversing from. The `base` argument is assumed to be the `path`
-	member of the `name_entry` being recursed into unless the tree is a
-	top-level tree in which case the empty string ("") is used.
-
-Walking
--------
-
-`tree_entry`::
-
-	Visit the next entry in a tree. Returns 1 when there are more entries
-	left to visit and 0 when all entries have been visited. This is
-	commonly used in the test of a while loop.
-
-`tree_entry_len`::
-
-	Calculate the length of a tree entry's pathname. This utilizes the
-	memory structure of a tree entry to avoid the overhead of using a
-	generic strlen().
-
-`update_tree_entry`::
-
-	Walk to the next entry in a tree. This is commonly used in conjunction
-	with `tree_entry_extract` to inspect the current entry.
-
-`tree_entry_extract`::
-
-	Decode the entry currently being visited (the one pointed to by
-	`tree_desc's` `entry` member) and return the sha1 of the entry. The
-	`pathp` and `modep` arguments are set to the entry's pathname and mode
-	respectively.
-
-`get_tree_entry`::
-
-	Find an entry in a tree given a pathname and the sha1 of a tree to
-	search. Returns 0 if the entry is found and -1 otherwise. The third
-	and fourth parameters are set to the entry's sha1 and mode
-	respectively.
-
-Traversing
-----------
-
-`traverse_trees`::
-
-	Traverse `n` number of trees in parallel. The `fn` callback member of
-	`traverse_info` is called once for each tree entry.
-
-`traverse_callback_t`::
-	The arguments passed to the traverse callback are as follows:
-+
-* `n` counts the number of trees being traversed.
-
-* `mask` has its nth bit set if something exists in the nth entry.
-
-* `dirmask` has its nth bit set if the nth tree's entry is a directory.
-
-* `entry` is an array of size `n` where the nth entry is from the nth tree.
-
-* `info` maintains the state of the traversal.
-
-+
-Returning a negative value will terminate the traversal. Otherwise the
-return value is treated as an update mask. If the nth bit is set the nth tree
-will be updated and if the bit is not set the nth tree entry will be the
-same in the next callback invocation.
-
-`make_traverse_path`::
-
-	Generate the full pathname of a tree entry based from the root of the
-	traversal. For example, if the traversal has recursed into another
-	tree named "bar" the pathname of an entry "baz" in the "bar"
-	tree would be "bar/baz".
-
-`traverse_path_len`::
-
-	Calculate the length of a pathname returned by `make_traverse_path`.
-	This utilizes the memory structure of a tree entry to avoid the
-	overhead of using a generic strlen().
-
-Authors
--------
-
-Written by Junio C Hamano <gitster@pobox.com> and Linus Torvalds
-<torvalds@linux-foundation.org>
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/technical/api-xdiff-interface.txt 1.2.3+git2.25.1-1/git/Documentation/technical/api-xdiff-interface.txt
--- 1.2.1+git2.18.0-1/git/Documentation/technical/api-xdiff-interface.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/technical/api-xdiff-interface.txt	1970-01-01 00:00:00.000000000 +0000
@@ -1,7 +0,0 @@
-xdiff interface API
-===================
-
-Talk about our calling convention to xdiff library, including
-xdiff_emit_consume_fn.
-
-(Dscho, JC)
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/technical/bundle-format.txt 1.2.3+git2.25.1-1/git/Documentation/technical/bundle-format.txt
--- 1.2.1+git2.18.0-1/git/Documentation/technical/bundle-format.txt	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/technical/bundle-format.txt	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,48 @@
+= Git bundle v2 format
+
+The Git bundle format is a format that represents both refs and Git objects.
+
+== Format
+
+We will use ABNF notation to define the Git bundle format. See
+protocol-common.txt for the details.
+
+----
+bundle    = signature *prerequisite *reference LF pack
+signature = "# v2 git bundle" LF
+
+prerequisite = "-" obj-id SP comment LF
+comment      = *CHAR
+reference    = obj-id SP refname LF
+
+pack         = ... ; packfile
+----
+
+== Semantics
+
+A Git bundle consists of three parts.
+
+* "Prerequisites" lists the objects that are NOT included in the bundle and the
+  reader of the bundle MUST already have, in order to use the data in the
+  bundle. The objects stored in the bundle may refer to prerequisite objects and
+  anything reachable from them (e.g. a tree object in the bundle can reference
+  a blob that is reachable from a prerequisite) and/or expressed as a delta
+  against prerequisite objects.
+
+* "References" record the tips of the history graph, iow, what the reader of the
+  bundle CAN "git fetch" from it.
+
+* "Pack" is the pack data stream "git fetch" would send, if you fetch from a
+  repository that has the references recorded in the "References" above into a
+  repository that has references pointing at the objects listed in
+  "Prerequisites" above.
+
+In the bundle format, there can be a comment following a prerequisite obj-id.
+This is a comment and it has no specific meaning. The writer of the bundle MAY
+put any string here. The reader of the bundle MUST ignore the comment.
+
+=== Note on the shallow clone and a Git bundle
+
+Note that the prerequisites does not represent a shallow-clone boundary. The
+semantics of the prerequisites and the shallow-clone boundaries are different,
+and the Git bundle v2 format cannot represent a shallow clone repository.
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/technical/commit-graph-format.txt 1.2.3+git2.25.1-1/git/Documentation/technical/commit-graph-format.txt
--- 1.2.1+git2.18.0-1/git/Documentation/technical/commit-graph-format.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/technical/commit-graph-format.txt	2020-02-17 04:47:35.000000000 +0000
@@ -18,9 +18,9 @@ metadata, including:
   the graph file.
 
 These positional references are stored as unsigned 32-bit integers
-corresponding to the array position withing the list of commit OIDs. We
-use the most-significant bit for special purposes, so we can store at most
-(1 << 31) - 1 (around 2 billion) commits.
+corresponding to the array position within the list of commit OIDs. Due
+to some special constants we use to track parents, we can store at most
+(1 << 30) + (1 << 29) + (1 << 28) - 1 (around 1.8 billion) commits.
 
 == Commit graph files have the following format:
 
@@ -44,8 +44,9 @@ HEADER:
 
   1-byte number (C) of "chunks"
 
-  1-byte (reserved for later use)
-     Current clients should ignore this value.
+  1-byte number (B) of base commit-graphs
+      We infer the length (H*B) of the Base Graphs chunk
+      from this value.
 
 CHUNK LOOKUP:
 
@@ -70,13 +71,13 @@ CHUNK DATA:
   OID Lookup (ID: {'O', 'I', 'D', 'L'}) (N * H bytes)
       The OIDs for all commits in the graph, sorted in ascending order.
 
-  Commit Data (ID: {'C', 'G', 'E', 'T' }) (N * (H + 16) bytes)
+  Commit Data (ID: {'C', 'D', 'A', 'T' }) (N * (H + 16) bytes)
     * The first H bytes are for the OID of the root tree.
     * The next 8 bytes are for the positions of the first two parents
-      of the ith commit. Stores value 0xffffffff if no parent in that
+      of the ith commit. Stores value 0x7000000 if no parent in that
       position. If there are more than two parents, the second value
       has its most-significant bit on and the other bits store an array
-      position into the Large Edge List chunk.
+      position into the Extra Edge List chunk.
     * The next 8 bytes store the generation number of the commit and
       the commit time in seconds since EPOCH. The generation number
       uses the higher 30 bits of the first 4 bytes, while the commit
@@ -84,7 +85,7 @@ CHUNK DATA:
       2 bits of the lowest byte, storing the 33rd and 34th bit of the
       commit time.
 
-  Large Edge List (ID: {'E', 'D', 'G', 'E'}) [Optional]
+  Extra Edge List (ID: {'E', 'D', 'G', 'E'}) [Optional]
       This list of 4-byte values store the second through nth parents for
       all octopus merges. The second parent value in the commit data stores
       an array position within this list along with the most-significant bit
@@ -92,6 +93,12 @@ CHUNK DATA:
       positions for the parents until reaching a value with the most-significant
       bit on. The other bits correspond to the position of the last parent.
 
+  Base Graphs List (ID: {'B', 'A', 'S', 'E'}) [Optional]
+      This list of H-byte hashes describe a set of B commit-graph files that
+      form a commit-graph chain. The graph position for the ith commit in this
+      file's OID Lookup chunk is equal to i plus the number of commits in all
+      base graphs.  If B is non-zero, this chunk must exist.
+
 TRAILER:
 
 	H-byte HASH-checksum of all of the above.
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/technical/commit-graph.txt 1.2.3+git2.25.1-1/git/Documentation/technical/commit-graph.txt
--- 1.2.1+git2.18.0-1/git/Documentation/technical/commit-graph.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/technical/commit-graph.txt	2020-02-17 04:47:35.000000000 +0000
@@ -15,18 +15,18 @@ There are two main costs here:
 1. Decompressing and parsing commits.
 2. Walking the entire graph to satisfy topological order constraints.
 
-The commit graph file is a supplemental data structure that accelerates
+The commit-graph file is a supplemental data structure that accelerates
 commit graph walks. If a user downgrades or disables the 'core.commitGraph'
 config setting, then the existing ODB is sufficient. The file is stored
 as "commit-graph" either in the .git/objects/info directory or in the info
 directory of an alternate.
 
-The commit graph file stores the commit graph structure along with some
-extra metadata to speed up graph walks. By listing commit OIDs in lexi-
-cographic order, we can identify an integer position for each commit and
-refer to the parents of a commit using those integer positions. We use
-binary search to find initial commits and then use the integer positions
-for fast lookups during the walk.
+The commit-graph file stores the commit graph structure along with some
+extra metadata to speed up graph walks. By listing commit OIDs in
+lexicographic order, we can identify an integer position for each commit
+and refer to the parents of a commit using those integer positions. We
+use binary search to find initial commits and then use the integer
+positions for fast lookups during the walk.
 
 A consumer may load the following info for a commit from the graph:
 
@@ -77,10 +77,33 @@ in the commit graph. We can treat these
 generation number and walk until reaching commits with known generation
 number.
 
+We use the macro GENERATION_NUMBER_INFINITY = 0xFFFFFFFF to mark commits not
+in the commit-graph file. If a commit-graph file was written by a version
+of Git that did not compute generation numbers, then those commits will
+have generation number represented by the macro GENERATION_NUMBER_ZERO = 0.
+
+Since the commit-graph file is closed under reachability, we can guarantee
+the following weaker condition on all commits:
+
+    If A and B are commits with generation numbers N and M, respectively,
+    and N < M, then A cannot reach B.
+
+Note how the strict inequality differs from the inequality when we have
+fully-computed generation numbers. Using strict inequality may result in
+walking a few extra commits, but the simplicity in dealing with commits
+with generation number *_INFINITY or *_ZERO is valuable.
+
+We use the macro GENERATION_NUMBER_MAX = 0x3FFFFFFF to for commits whose
+generation numbers are computed to be at least this value. We limit at
+this value since it is the largest value that can be stored in the
+commit-graph file using the 30 bits available to generation numbers. This
+presents another case where a commit can have generation number equal to
+that of a parent.
+
 Design Details
 --------------
 
-- The commit graph file is stored in a file named 'commit-graph' in the
+- The commit-graph file is stored in a file named 'commit-graph' in the
   .git/objects/info directory. This could be stored in the info directory
   of an alternate.
 
@@ -89,65 +112,225 @@ Design Details
 - The file format includes parameters for the object ID hash function,
   so a future change of hash algorithm does not require a change in format.
 
-Future Work
------------
-
-- The commit graph feature currently does not honor commit grafts. This can
-  be remedied by duplicating or refactoring the current graft logic.
-
-- The 'commit-graph' subcommand does not have a "verify" mode that is
-  necessary for integration with fsck.
-
-- The file format includes room for precomputed generation numbers. These
-  are not currently computed, so all generation numbers will be marked as
-  0 (or "uncomputed"). A later patch will include this calculation.
-
-- After computing and storing generation numbers, we must make graph
-  walks aware of generation numbers to gain the performance benefits they
-  enable. This will mostly be accomplished by swapping a commit-date-ordered
-  priority queue with one ordered by generation number. The following
-  operations are important candidates:
-
-    - paint_down_to_common()
-    - 'log --topo-order'
-
-- Currently, parse_commit_gently() requires filling in the root tree
-  object for a commit. This passes through lookup_tree() and consequently
-  lookup_object(). Also, it calls lookup_commit() when loading the parents.
-  These method calls check the ODB for object existence, even if the
-  consumer does not need the content. For example, we do not need the
-  tree contents when computing merge bases. Now that commit parsing is
-  removed from the computation time, these lookup operations are the
-  slowest operations keeping graph walks from being fast. Consider
-  loading these objects without verifying their existence in the ODB and
-  only loading them fully when consumers need them. Consider a method
-  such as "ensure_tree_loaded(commit)" that fully loads a tree before
-  using commit->tree.
-
-- The current design uses the 'commit-graph' subcommand to generate the graph.
-  When this feature stabilizes enough to recommend to most users, we should
-  add automatic graph writes to common operations that create many commits.
-  For example, one could compute a graph on 'clone', 'fetch', or 'repack'
-  commands.
-
-- A server could provide a commit graph file as part of the network protocol
-  to avoid extra calculations by clients. This feature is only of benefit if
-  the user is willing to trust the file, because verifying the file is correct
-  is as hard as computing it from scratch.
+- Commit grafts and replace objects can change the shape of the commit
+  history. The latter can also be enabled/disabled on the fly using
+  `--no-replace-objects`. This leads to difficultly storing both possible
+  interpretations of a commit id, especially when computing generation
+  numbers. The commit-graph will not be read or written when
+  replace-objects or grafts are present.
+
+- Shallow clones create grafts of commits by dropping their parents. This
+  leads the commit-graph to think those commits have generation number 1.
+  If and when those commits are made unshallow, those generation numbers
+  become invalid. Since shallow clones are intended to restrict the commit
+  history to a very small set of commits, the commit-graph feature is less
+  helpful for these clones, anyway. The commit-graph will not be read or
+  written when shallow commits are present.
+
+Commit Graphs Chains
+--------------------
+
+Typically, repos grow with near-constant velocity (commits per day). Over time,
+the number of commits added by a fetch operation is much smaller than the
+number of commits in the full history. By creating a "chain" of commit-graphs,
+we enable fast writes of new commit data without rewriting the entire commit
+history -- at least, most of the time.
+
+## File Layout
+
+A commit-graph chain uses multiple files, and we use a fixed naming convention
+to organize these files. Each commit-graph file has a name
+`$OBJDIR/info/commit-graphs/graph-{hash}.graph` where `{hash}` is the hex-
+valued hash stored in the footer of that file (which is a hash of the file's
+contents before that hash). For a chain of commit-graph files, a plain-text
+file at `$OBJDIR/info/commit-graphs/commit-graph-chain` contains the
+hashes for the files in order from "lowest" to "highest".
+
+For example, if the `commit-graph-chain` file contains the lines
+
+```
+	{hash0}
+	{hash1}
+	{hash2}
+```
+
+then the commit-graph chain looks like the following diagram:
+
+ +-----------------------+
+ |  graph-{hash2}.graph  |
+ +-----------------------+
+	  |
+ +-----------------------+
+ |                       |
+ |  graph-{hash1}.graph  |
+ |                       |
+ +-----------------------+
+	  |
+ +-----------------------+
+ |                       |
+ |                       |
+ |                       |
+ |  graph-{hash0}.graph  |
+ |                       |
+ |                       |
+ |                       |
+ +-----------------------+
+
+Let X0 be the number of commits in `graph-{hash0}.graph`, X1 be the number of
+commits in `graph-{hash1}.graph`, and X2 be the number of commits in
+`graph-{hash2}.graph`. If a commit appears in position i in `graph-{hash2}.graph`,
+then we interpret this as being the commit in position (X0 + X1 + i), and that
+will be used as its "graph position". The commits in `graph-{hash2}.graph` use these
+positions to refer to their parents, which may be in `graph-{hash1}.graph` or
+`graph-{hash0}.graph`. We can navigate to an arbitrary commit in position j by checking
+its containment in the intervals [0, X0), [X0, X0 + X1), [X0 + X1, X0 + X1 +
+X2).
+
+Each commit-graph file (except the base, `graph-{hash0}.graph`) contains data
+specifying the hashes of all files in the lower layers. In the above example,
+`graph-{hash1}.graph` contains `{hash0}` while `graph-{hash2}.graph` contains
+`{hash0}` and `{hash1}`.
+
+## Merging commit-graph files
+
+If we only added a new commit-graph file on every write, we would run into a
+linear search problem through many commit-graph files.  Instead, we use a merge
+strategy to decide when the stack should collapse some number of levels.
+
+The diagram below shows such a collapse. As a set of new commits are added, it
+is determined by the merge strategy that the files should collapse to
+`graph-{hash1}`. Thus, the new commits, the commits in `graph-{hash2}` and
+the commits in `graph-{hash1}` should be combined into a new `graph-{hash3}`
+file.
+
+			    +---------------------+
+			    |                     |
+			    |    (new commits)    |
+			    |                     |
+			    +---------------------+
+			    |                     |
+ +-----------------------+  +---------------------+
+ |  graph-{hash2} |->|                     |
+ +-----------------------+  +---------------------+
+	  |                 |                     |
+ +-----------------------+  +---------------------+
+ |                       |  |                     |
+ |  graph-{hash1} |->|                     |
+ |                       |  |                     |
+ +-----------------------+  +---------------------+
+	  |                  tmp_graphXXX
+ +-----------------------+
+ |                       |
+ |                       |
+ |                       |
+ |  graph-{hash0} |
+ |                       |
+ |                       |
+ |                       |
+ +-----------------------+
+
+During this process, the commits to write are combined, sorted and we write the
+contents to a temporary file, all while holding a `commit-graph-chain.lock`
+lock-file.  When the file is flushed, we rename it to `graph-{hash3}`
+according to the computed `{hash3}`. Finally, we write the new chain data to
+`commit-graph-chain.lock`:
+
+```
+	{hash3}
+	{hash0}
+```
+
+We then close the lock-file.
+
+## Merge Strategy
+
+When writing a set of commits that do not exist in the commit-graph stack of
+height N, we default to creating a new file at level N + 1. We then decide to
+merge with the Nth level if one of two conditions hold:
+
+  1. `--size-multiple=<X>` is specified or X = 2, and the number of commits in
+     level N is less than X times the number of commits in level N + 1.
+
+  2. `--max-commits=<C>` is specified with non-zero C and the number of commits
+     in level N + 1 is more than C commits.
+
+This decision cascades down the levels: when we merge a level we create a new
+set of commits that then compares to the next level.
+
+The first condition bounds the number of levels to be logarithmic in the total
+number of commits.  The second condition bounds the total number of commits in
+a `graph-{hashN}` file and not in the `commit-graph` file, preventing
+significant performance issues when the stack merges and another process only
+partially reads the previous stack.
+
+The merge strategy values (2 for the size multiple, 64,000 for the maximum
+number of commits) could be extracted into config settings for full
+flexibility.
+
+## Deleting graph-{hash} files
+
+After a new tip file is written, some `graph-{hash}` files may no longer
+be part of a chain. It is important to remove these files from disk, eventually.
+The main reason to delay removal is that another process could read the
+`commit-graph-chain` file before it is rewritten, but then look for the
+`graph-{hash}` files after they are deleted.
+
+To allow holding old split commit-graphs for a while after they are unreferenced,
+we update the modified times of the files when they become unreferenced. Then,
+we scan the `$OBJDIR/info/commit-graphs/` directory for `graph-{hash}`
+files whose modified times are older than a given expiry window. This window
+defaults to zero, but can be changed using command-line arguments or a config
+setting.
+
+## Chains across multiple object directories
+
+In a repo with alternates, we look for the `commit-graph-chain` file starting
+in the local object directory and then in each alternate. The first file that
+exists defines our chain. As we look for the `graph-{hash}` files for
+each `{hash}` in the chain file, we follow the same pattern for the host
+directories.
+
+This allows commit-graphs to be split across multiple forks in a fork network.
+The typical case is a large "base" repo with many smaller forks.
+
+As the base repo advances, it will likely update and merge its commit-graph
+chain more frequently than the forks. If a fork updates their commit-graph after
+the base repo, then it should "reparent" the commit-graph chain onto the new
+chain in the base repo. When reading each `graph-{hash}` file, we track
+the object directory containing it. During a write of a new commit-graph file,
+we check for any changes in the source object directory and read the
+`commit-graph-chain` file for that source and create a new file based on those
+files. During this "reparent" operation, we necessarily need to collapse all
+levels in the fork, as all of the files are invalid against the new base file.
+
+It is crucial to be careful when cleaning up "unreferenced" `graph-{hash}.graph`
+files in this scenario. It falls to the user to define the proper settings for
+their custom environment:
+
+ 1. When merging levels in the base repo, the unreferenced files may still be
+    referenced by chains from fork repos.
+
+ 2. The expiry time should be set to a length of time such that every fork has
+    time to recompute their commit-graph chain to "reparent" onto the new base
+    file(s).
+
+ 3. If the commit-graph chain is updated in the base, the fork will not have
+    access to the new chain until its chain is updated to reference those files.
+    (This may change in the future [5].)
 
 Related Links
 -------------
 [0] https://bugs.chromium.org/p/git/issues/detail?id=8
     Chromium work item for: Serialized Commit Graph
 
-[1] https://public-inbox.org/git/20110713070517.GC18566@sigill.intra.peff.net/
+[1] https://lore.kernel.org/git/20110713070517.GC18566@sigill.intra.peff.net/
     An abandoned patch that introduced generation numbers.
 
-[2] https://public-inbox.org/git/20170908033403.q7e6dj7benasrjes@sigill.intra.peff.net/
+[2] https://lore.kernel.org/git/20170908033403.q7e6dj7benasrjes@sigill.intra.peff.net/
     Discussion about generation numbers on commits and how they interact
     with fsck.
 
-[3] https://public-inbox.org/git/20170908034739.4op3w4f2ma5s65ku@sigill.intra.peff.net/
+[3] https://lore.kernel.org/git/20170908034739.4op3w4f2ma5s65ku@sigill.intra.peff.net/
     More discussion about generation numbers and not storing them inside
     commit objects. A valuable quote:
 
@@ -159,5 +342,9 @@ Related Links
      commit objects (i.e., packv4 or something like the "metapacks" I
      proposed a few years ago)."
 
-[4] https://public-inbox.org/git/20180108154822.54829-1-git@jeffhostetler.com/T/#u
+[4] https://lore.kernel.org/git/20180108154822.54829-1-git@jeffhostetler.com/T/#u
     A patch to remove the ahead-behind calculation from 'status'.
+
+[5] https://lore.kernel.org/git/f27db281-abad-5043-6d71-cbb083b1c877@gmail.com/
+    A discussion of a "two-dimensional graph position" that can allow reading
+    multiple commit-graph chains at the same time.
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/technical/directory-rename-detection.txt 1.2.3+git2.25.1-1/git/Documentation/technical/directory-rename-detection.txt
--- 1.2.1+git2.18.0-1/git/Documentation/technical/directory-rename-detection.txt	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/technical/directory-rename-detection.txt	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,115 @@
+Directory rename detection
+==========================
+
+Rename detection logic in diffcore-rename that checks for renames of
+individual files is aggregated and analyzed in merge-recursive for cases
+where combinations of renames indicate that a full directory has been
+renamed.
+
+Scope of abilities
+------------------
+
+It is perhaps easiest to start with an example:
+
+  * When all of x/a, x/b and x/c have moved to z/a, z/b and z/c, it is
+    likely that x/d added in the meantime would also want to move to z/d by
+    taking the hint that the entire directory 'x' moved to 'z'.
+
+More interesting possibilities exist, though, such as:
+
+  * one side of history renames x -> z, and the other renames some file to
+    x/e, causing the need for the merge to do a transitive rename.
+
+  * one side of history renames x -> z, but also renames all files within x.
+    For example, x/a -> z/alpha, x/b -> z/bravo, etc.
+
+  * both 'x' and 'y' being merged into a single directory 'z', with a
+    directory rename being detected for both x->z and y->z.
+
+  * not all files in a directory being renamed to the same location;
+    i.e. perhaps most the files in 'x' are now found under 'z', but a few
+    are found under 'w'.
+
+  * a directory being renamed, which also contained a subdirectory that was
+    renamed to some entirely different location.  (And perhaps the inner
+    directory itself contained inner directories that were renamed to yet
+    other locations).
+
+  * combinations of the above; see t/t6043-merge-rename-directories.sh for
+    various interesting cases.
+
+Limitations -- applicability of directory renames
+-------------------------------------------------
+
+In order to prevent edge and corner cases resulting in either conflicts
+that cannot be represented in the index or which might be too complex for
+users to try to understand and resolve, a couple basic rules limit when
+directory rename detection applies:
+
+  1) If a given directory still exists on both sides of a merge, we do
+     not consider it to have been renamed.
+
+  2) If a subset of to-be-renamed files have a file or directory in the
+     way (or would be in the way of each other), "turn off" the directory
+     rename for those specific sub-paths and report the conflict to the
+     user.
+
+  3) If the other side of history did a directory rename to a path that
+     your side of history renamed away, then ignore that particular
+     rename from the other side of history for any implicit directory
+     renames (but warn the user).
+
+Limitations -- detailed rules and testcases
+-------------------------------------------
+
+t/t6043-merge-rename-directories.sh contains extensive tests and commentary
+which generate and explore the rules listed above.  It also lists a few
+additional rules:
+
+  a) If renames split a directory into two or more others, the directory
+     with the most renames, "wins".
+
+  b) Avoid directory-rename-detection for a path, if that path is the
+     source of a rename on either side of a merge.
+
+  c) Only apply implicit directory renames to directories if the other side
+     of history is the one doing the renaming.
+
+Limitations -- support in different commands
+--------------------------------------------
+
+Directory rename detection is supported by 'merge' and 'cherry-pick'.
+Other git commands which users might be surprised to see limited or no
+directory rename detection support in:
+
+  * diff
+
+    Folks have requested in the past that `git diff` detect directory
+    renames and somehow simplify its output.  It is not clear whether this
+    would be desirable or how the output should be simplified, so this was
+    simply not implemented.  Further, to implement this, directory rename
+    detection logic would need to move from merge-recursive to
+    diffcore-rename.
+
+  * am
+
+    git-am tries to avoid a full three way merge, instead calling
+    git-apply.  That prevents us from detecting renames at all, which may
+    defeat the directory rename detection.  There is a fallback, though; if
+    the initial git-apply fails and the user has specified the -3 option,
+    git-am will fall back to a three way merge.  However, git-am lacks the
+    necessary information to do a "real" three way merge.  Instead, it has
+    to use build_fake_ancestor() to get a merge base that is missing files
+    whose rename may have been important to detect for directory rename
+    detection to function.
+
+  * rebase
+
+    Since am-based rebases work by first generating a bunch of patches
+    (which no longer record what the original commits were and thus don't
+    have the necessary info from which we can find a real merge-base), and
+    then calling git-am, this implies that am-based rebases will not always
+    successfully detect directory renames either (see the 'am' section
+    above).  merged-based rebases (rebase -m) and cherry-pick-based rebases
+    (rebase -i) are not affected by this shortcoming, and fully support
+    directory rename detection.
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/technical/hash-function-transition.txt 1.2.3+git2.25.1-1/git/Documentation/technical/hash-function-transition.txt
--- 1.2.1+git2.18.0-1/git/Documentation/technical/hash-function-transition.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/technical/hash-function-transition.txt	2020-02-17 04:47:35.000000000 +0000
@@ -59,14 +59,11 @@ that are believed to be cryptographicall
 
 Goals
 -----
-Where NewHash is a strong 256-bit hash function to replace SHA-1 (see
-"Selection of a New Hash", below):
-
-1. The transition to NewHash can be done one local repository at a time.
+1. The transition to SHA-256 can be done one local repository at a time.
    a. Requiring no action by any other party.
-   b. A NewHash repository can communicate with SHA-1 Git servers
+   b. A SHA-256 repository can communicate with SHA-1 Git servers
       (push/fetch).
-   c. Users can use SHA-1 and NewHash identifiers for objects
+   c. Users can use SHA-1 and SHA-256 identifiers for objects
       interchangeably (see "Object names on the command line", below).
    d. New signed objects make use of a stronger hash function than
       SHA-1 for their security guarantees.
@@ -79,7 +76,7 @@ Where NewHash is a strong 256-bit hash f
 
 Non-Goals
 ---------
-1. Add NewHash support to Git protocol. This is valuable and the
+1. Add SHA-256 support to Git protocol. This is valuable and the
    logical next step but it is out of scope for this initial design.
 2. Transparently improving the security of existing SHA-1 signed
    objects.
@@ -87,26 +84,26 @@ Non-Goals
    repository.
 4. Taking the opportunity to fix other bugs in Git's formats and
    protocols.
-5. Shallow clones and fetches into a NewHash repository. (This will
-   change when we add NewHash support to Git protocol.)
-6. Skip fetching some submodules of a project into a NewHash
-   repository. (This also depends on NewHash support in Git
+5. Shallow clones and fetches into a SHA-256 repository. (This will
+   change when we add SHA-256 support to Git protocol.)
+6. Skip fetching some submodules of a project into a SHA-256
+   repository. (This also depends on SHA-256 support in Git
    protocol.)
 
 Overview
 --------
 We introduce a new repository format extension. Repositories with this
-extension enabled use NewHash instead of SHA-1 to name their objects.
+extension enabled use SHA-256 instead of SHA-1 to name their objects.
 This affects both object names and object content --- both the names
 of objects and all references to other objects within an object are
 switched to the new hash function.
 
-NewHash repositories cannot be read by older versions of Git.
+SHA-256 repositories cannot be read by older versions of Git.
 
-Alongside the packfile, a NewHash repository stores a bidirectional
-mapping between NewHash and SHA-1 object names. The mapping is generated
+Alongside the packfile, a SHA-256 repository stores a bidirectional
+mapping between SHA-256 and SHA-1 object names. The mapping is generated
 locally and can be verified using "git fsck". Object lookups use this
-mapping to allow naming objects using either their SHA-1 and NewHash names
+mapping to allow naming objects using either their SHA-1 and SHA-256 names
 interchangeably.
 
 "git cat-file" and "git hash-object" gain options to display an object
@@ -116,7 +113,7 @@ object database so that they can be name
 (using the bidirectional hash mapping).
 
 Fetches from a SHA-1 based server convert the fetched objects into
-NewHash form and record the mapping in the bidirectional mapping table
+SHA-256 form and record the mapping in the bidirectional mapping table
 (see below for details). Pushes to a SHA-1 based server convert the
 objects being pushed into sha1 form so the server does not have to be
 aware of the hash function the client is using.
@@ -125,19 +122,19 @@ Detailed Design
 ---------------
 Repository format extension
 ~~~~~~~~~~~~~~~~~~~~~~~~~~~
-A NewHash repository uses repository format version `1` (see
+A SHA-256 repository uses repository format version `1` (see
 Documentation/technical/repository-version.txt) with extensions
 `objectFormat` and `compatObjectFormat`:
 
 	[core]
 		repositoryFormatVersion = 1
 	[extensions]
-		objectFormat = newhash
+		objectFormat = sha256
 		compatObjectFormat = sha1
 
 The combination of setting `core.repositoryFormatVersion=1` and
 populating `extensions.*` ensures that all versions of Git later than
-`v0.99.9l` will die instead of trying to operate on the NewHash
+`v0.99.9l` will die instead of trying to operate on the SHA-256
 repository, instead producing an error message.
 
 	# Between v0.99.9l and v2.7.0
@@ -155,36 +152,36 @@ repository extensions.
 Object names
 ~~~~~~~~~~~~
 Objects can be named by their 40 hexadecimal digit sha1-name or 64
-hexadecimal digit newhash-name, plus names derived from those (see
+hexadecimal digit sha256-name, plus names derived from those (see
 gitrevisions(7)).
 
 The sha1-name of an object is the SHA-1 of the concatenation of its
 type, length, a nul byte, and the object's sha1-content. This is the
 traditional <sha1> used in Git to name objects.
 
-The newhash-name of an object is the NewHash of the concatenation of its
-type, length, a nul byte, and the object's newhash-content.
+The sha256-name of an object is the SHA-256 of the concatenation of its
+type, length, a nul byte, and the object's sha256-content.
 
 Object format
 ~~~~~~~~~~~~~
 The content as a byte sequence of a tag, commit, or tree object named
-by sha1 and newhash differ because an object named by newhash-name refers to
-other objects by their newhash-names and an object named by sha1-name
+by sha1 and sha256 differ because an object named by sha256-name refers to
+other objects by their sha256-names and an object named by sha1-name
 refers to other objects by their sha1-names.
 
-The newhash-content of an object is the same as its sha1-content, except
-that objects referenced by the object are named using their newhash-names
+The sha256-content of an object is the same as its sha1-content, except
+that objects referenced by the object are named using their sha256-names
 instead of sha1-names. Because a blob object does not refer to any
-other object, its sha1-content and newhash-content are the same.
+other object, its sha1-content and sha256-content are the same.
 
-The format allows round-trip conversion between newhash-content and
+The format allows round-trip conversion between sha256-content and
 sha1-content.
 
 Object storage
 ~~~~~~~~~~~~~~
 Loose objects use zlib compression and packed objects use the packed
 format described in Documentation/technical/pack-format.txt, just like
-today. The content that is compressed and stored uses newhash-content
+today. The content that is compressed and stored uses sha256-content
 instead of sha1-content.
 
 Pack index
@@ -255,10 +252,10 @@ network byte order):
   up to and not including the table of CRC32 values.
 - Zero or more NUL bytes.
 - The trailer consists of the following:
-  - A copy of the 20-byte NewHash checksum at the end of the
+  - A copy of the 20-byte SHA-256 checksum at the end of the
     corresponding packfile.
 
-  - 20-byte NewHash checksum of all of the above.
+  - 20-byte SHA-256 checksum of all of the above.
 
 Loose object index
 ~~~~~~~~~~~~~~~~~~
@@ -266,7 +263,7 @@ A new file $GIT_OBJECT_DIR/loose-object-
 all loose objects. Its format is
 
   # loose-object-idx
-  (newhash-name SP sha1-name LF)*
+  (sha256-name SP sha1-name LF)*
 
 where the object names are in hexadecimal format. The file is not
 sorted.
@@ -292,8 +289,8 @@ To remove entries (e.g. in "git pack-ref
 Translation table
 ~~~~~~~~~~~~~~~~~
 The index files support a bidirectional mapping between sha1-names
-and newhash-names. The lookup proceeds similarly to ordinary object
-lookups. For example, to convert a sha1-name to a newhash-name:
+and sha256-names. The lookup proceeds similarly to ordinary object
+lookups. For example, to convert a sha1-name to a sha256-name:
 
  1. Look for the object in idx files. If a match is present in the
     idx's sorted list of truncated sha1-names, then:
@@ -301,8 +298,8 @@ lookups. For example, to convert a sha1-
        name order mapping.
     b. Read the corresponding entry in the full sha1-name table to
        verify we found the right object. If it is, then
-    c. Read the corresponding entry in the full newhash-name table.
-       That is the object's newhash-name.
+    c. Read the corresponding entry in the full sha256-name table.
+       That is the object's sha256-name.
  2. Check for a loose object. Read lines from loose-object-idx until
     we find a match.
 
@@ -318,25 +315,25 @@ for all objects in the object store.
 
 Reading an object's sha1-content
 ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
-The sha1-content of an object can be read by converting all newhash-names
-its newhash-content references to sha1-names using the translation table.
+The sha1-content of an object can be read by converting all sha256-names
+its sha256-content references to sha1-names using the translation table.
 
 Fetch
 ~~~~~
 Fetching from a SHA-1 based server requires translating between SHA-1
-and NewHash based representations on the fly.
+and SHA-256 based representations on the fly.
 
 SHA-1s named in the ref advertisement that are present on the client
-can be translated to NewHash and looked up as local objects using the
+can be translated to SHA-256 and looked up as local objects using the
 translation table.
 
 Negotiation proceeds as today. Any "have"s generated locally are
 converted to SHA-1 before being sent to the server, and SHA-1s
-mentioned by the server are converted to NewHash when looking them up
+mentioned by the server are converted to SHA-256 when looking them up
 locally.
 
 After negotiation, the server sends a packfile containing the
-requested objects. We convert the packfile to NewHash format using
+requested objects. We convert the packfile to SHA-256 format using
 the following steps:
 
 1. index-pack: inflate each object in the packfile and compute its
@@ -351,12 +348,12 @@ the following steps:
    (This list only contains objects reachable from the "wants". If the
    pack from the server contained additional extraneous objects, then
    they will be discarded.)
-3. convert to newhash: open a new (newhash) packfile. Read the topologically
+3. convert to sha256: open a new (sha256) packfile. Read the topologically
    sorted list just generated. For each object, inflate its
-   sha1-content, convert to newhash-content, and write it to the newhash
-   pack. Record the new sha1<->newhash mapping entry for use in the idx.
+   sha1-content, convert to sha256-content, and write it to the sha256
+   pack. Record the new sha1<->sha256 mapping entry for use in the idx.
 4. sort: reorder entries in the new pack to match the order of objects
-   in the pack the server generated and include blobs. Write a newhash idx
+   in the pack the server generated and include blobs. Write a sha256 idx
    file
 5. clean up: remove the SHA-1 based pack file, index, and
    topologically sorted list obtained from the server in steps 1
@@ -388,16 +385,16 @@ send-pack.
 
 Signed Commits
 ~~~~~~~~~~~~~~
-We add a new field "gpgsig-newhash" to the commit object format to allow
+We add a new field "gpgsig-sha256" to the commit object format to allow
 signing commits without relying on SHA-1. It is similar to the
-existing "gpgsig" field. Its signed payload is the newhash-content of the
-commit object with any "gpgsig" and "gpgsig-newhash" fields removed.
+existing "gpgsig" field. Its signed payload is the sha256-content of the
+commit object with any "gpgsig" and "gpgsig-sha256" fields removed.
 
 This means commits can be signed
 1. using SHA-1 only, as in existing signed commit objects
-2. using both SHA-1 and NewHash, by using both gpgsig-newhash and gpgsig
+2. using both SHA-1 and SHA-256, by using both gpgsig-sha256 and gpgsig
    fields.
-3. using only NewHash, by only using the gpgsig-newhash field.
+3. using only SHA-256, by only using the gpgsig-sha256 field.
 
 Old versions of "git verify-commit" can verify the gpgsig signature in
 cases (1) and (2) without modifications and view case (3) as an
@@ -405,24 +402,24 @@ ordinary unsigned commit.
 
 Signed Tags
 ~~~~~~~~~~~
-We add a new field "gpgsig-newhash" to the tag object format to allow
+We add a new field "gpgsig-sha256" to the tag object format to allow
 signing tags without relying on SHA-1. Its signed payload is the
-newhash-content of the tag with its gpgsig-newhash field and "-----BEGIN PGP
+sha256-content of the tag with its gpgsig-sha256 field and "-----BEGIN PGP
 SIGNATURE-----" delimited in-body signature removed.
 
 This means tags can be signed
 1. using SHA-1 only, as in existing signed tag objects
-2. using both SHA-1 and NewHash, by using gpgsig-newhash and an in-body
+2. using both SHA-1 and SHA-256, by using gpgsig-sha256 and an in-body
    signature.
-3. using only NewHash, by only using the gpgsig-newhash field.
+3. using only SHA-256, by only using the gpgsig-sha256 field.
 
 Mergetag embedding
 ~~~~~~~~~~~~~~~~~~
 The mergetag field in the sha1-content of a commit contains the
 sha1-content of a tag that was merged by that commit.
 
-The mergetag field in the newhash-content of the same commit contains the
-newhash-content of the same tag.
+The mergetag field in the sha256-content of the same commit contains the
+sha256-content of the same tag.
 
 Submodules
 ~~~~~~~~~~
@@ -459,7 +456,7 @@ packfile marked as UNREACHABLE_GARBAGE (
 below). To avoid the race when writing new objects referring to an
 about-to-be-deleted object, code paths that write new objects will
 need to copy any objects from UNREACHABLE_GARBAGE packs that they
-refer to to new, non-UNREACHABLE_GARBAGE packs (or loose objects).
+refer to new, non-UNREACHABLE_GARBAGE packs (or loose objects).
 UNREACHABLE_GARBAGE are then safe to delete if their creation time (as
 indicated by the file's mtime) is long enough ago.
 
@@ -497,7 +494,7 @@ Caveats
 -------
 Invalid objects
 ~~~~~~~~~~~~~~~
-The conversion from sha1-content to newhash-content retains any
+The conversion from sha1-content to sha256-content retains any
 brokenness in the original object (e.g., tree entry modes encoded with
 leading 0, tree objects whose paths are not sorted correctly, and
 commit objects without an author or committer). This is a deliberate
@@ -516,7 +513,7 @@ allow lifting this restriction.
 
 Alternates
 ~~~~~~~~~~
-For the same reason, a newhash repository cannot borrow objects from a
+For the same reason, a sha256 repository cannot borrow objects from a
 sha1 repository using objects/info/alternates or
 $GIT_ALTERNATE_OBJECT_REPOSITORIES.
 
@@ -524,20 +521,20 @@ git notes
 ~~~~~~~~~
 The "git notes" tool annotates objects using their sha1-name as key.
 This design does not describe a way to migrate notes trees to use
-newhash-names. That migration is expected to happen separately (for
+sha256-names. That migration is expected to happen separately (for
 example using a file at the root of the notes tree to describe which
 hash it uses).
 
 Server-side cost
 ~~~~~~~~~~~~~~~~
-Until Git protocol gains NewHash support, using NewHash based storage
+Until Git protocol gains SHA-256 support, using SHA-256 based storage
 on public-facing Git servers is strongly discouraged. Once Git
-protocol gains NewHash support, NewHash based servers are likely not
+protocol gains SHA-256 support, SHA-256 based servers are likely not
 to support SHA-1 compatibility, to avoid what may be a very expensive
-hash reencode during clone and to encourage peers to modernize.
+hash re-encode during clone and to encourage peers to modernize.
 
 The design described here allows fetches by SHA-1 clients of a
-personal NewHash repository because it's not much more difficult than
+personal SHA-256 repository because it's not much more difficult than
 allowing pushes from that repository. This support needs to be guarded
 by a configuration option --- servers like git.kernel.org that serve a
 large number of clients would not be expected to bear that cost.
@@ -547,7 +544,7 @@ Meaning of signatures
 The signed payload for signed commits and tags does not explicitly
 name the hash used to identify objects. If some day Git adopts a new
 hash function with the same length as the current SHA-1 (40
-hexadecimal digit) or NewHash (64 hexadecimal digit) objects then the
+hexadecimal digit) or SHA-256 (64 hexadecimal digit) objects then the
 intent behind the PGP signed payload in an object signature is
 unclear:
 
@@ -562,7 +559,7 @@ Does this mean Git v2.12.0 is the commit
 e7e07d5a4fcc2a203d9873968ad3e6bd4d7419d7 or the commit with
 new-40-digit-hash-name e7e07d5a4fcc2a203d9873968ad3e6bd4d7419d7?
 
-Fortunately NewHash and SHA-1 have different lengths. If Git starts
+Fortunately SHA-256 and SHA-1 have different lengths. If Git starts
 using another hash with the same length to name objects, then it will
 need to change the format of signed payloads using that hash to
 address this issue.
@@ -574,24 +571,24 @@ supports four different modes of operati
 
  1. ("dark launch") Treat object names input by the user as SHA-1 and
     convert any object names written to output to SHA-1, but store
-    objects using NewHash.  This allows users to test the code with no
+    objects using SHA-256.  This allows users to test the code with no
     visible behavior change except for performance.  This allows
     allows running even tests that assume the SHA-1 hash function, to
     sanity-check the behavior of the new mode.
 
- 2. ("early transition") Allow both SHA-1 and NewHash object names in
+ 2. ("early transition") Allow both SHA-1 and SHA-256 object names in
     input. Any object names written to output use SHA-1. This allows
     users to continue to make use of SHA-1 to communicate with peers
     (e.g. by email) that have not migrated yet and prepares for mode 3.
 
- 3. ("late transition") Allow both SHA-1 and NewHash object names in
-    input. Any object names written to output use NewHash. In this
+ 3. ("late transition") Allow both SHA-1 and SHA-256 object names in
+    input. Any object names written to output use SHA-256. In this
     mode, users are using a more secure object naming method by
     default.  The disruption is minimal as long as most of their peers
     are in mode 2 or mode 3.
 
  4. ("post-transition") Treat object names input by the user as
-    NewHash and write output using NewHash. This is safer than mode 3
+    SHA-256 and write output using SHA-256. This is safer than mode 3
     because there is less risk that input is incorrectly interpreted
     using the wrong hash function.
 
@@ -601,27 +598,31 @@ The user can also explicitly specify whi
 particular revision specifier and for output, overriding the mode. For
 example:
 
-git --output-format=sha1 log abac87a^{sha1}..f787cac^{newhash}
+git --output-format=sha1 log abac87a^{sha1}..f787cac^{sha256}
 
-Selection of a New Hash
------------------------
-In early 2005, around the time that Git was written,  Xiaoyun Wang,
+Choice of Hash
+--------------
+In early 2005, around the time that Git was written, Xiaoyun Wang,
 Yiqun Lisa Yin, and Hongbo Yu announced an attack finding SHA-1
 collisions in 2^69 operations. In August they published details.
 Luckily, no practical demonstrations of a collision in full SHA-1 were
 published until 10 years later, in 2017.
 
-The hash function NewHash to replace SHA-1 should be stronger than
-SHA-1 was: we would like it to be trustworthy and useful in practice
-for at least 10 years.
+Git v2.13.0 and later subsequently moved to a hardened SHA-1
+implementation by default that mitigates the SHAttered attack, but
+SHA-1 is still believed to be weak.
+
+The hash to replace this hardened SHA-1 should be stronger than SHA-1
+was: we would like it to be trustworthy and useful in practice for at
+least 10 years.
 
 Some other relevant properties:
 
 1. A 256-bit hash (long enough to match common security practice; not
    excessively long to hurt performance and disk usage).
 
-2. High quality implementations should be widely available (e.g. in
-   OpenSSL).
+2. High quality implementations should be widely available (e.g., in
+   OpenSSL and Apple CommonCrypto).
 
 3. The hash function's properties should match Git's needs (e.g. Git
    requires collision and 2nd preimage resistance and does not require
@@ -630,14 +631,13 @@ Some other relevant properties:
 4. As a tiebreaker, the hash should be fast to compute (fortunately
    many contenders are faster than SHA-1).
 
-Some hashes under consideration are SHA-256, SHA-512/256, SHA-256x16,
-K12, and BLAKE2bp-256.
+We choose SHA-256.
 
 Transition plan
 ---------------
 Some initial steps can be implemented independently of one another:
 - adding a hash function API (vtable)
-- teaching fsck to tolerate the gpgsig-newhash field
+- teaching fsck to tolerate the gpgsig-sha256 field
 - excluding gpgsig-* from the fields copied by "git commit --amend"
 - annotating tests that depend on SHA-1 values with a SHA1 test
   prerequisite
@@ -664,7 +664,7 @@ Next comes introduction of compatObjectF
 - adding appropriate index entries when adding a new object to the
   object store
 - --output-format option
-- ^{sha1} and ^{newhash} revision notation
+- ^{sha1} and ^{sha256} revision notation
 - configuration to specify default input and output format (see
   "Object names on the command line" above)
 
@@ -672,7 +672,7 @@ The next step is supporting fetches and
 - allow pushes to a repository using the compat format
 - generate a topologically sorted list of the SHA-1 names of fetched
   objects
-- convert the fetched packfile to newhash format and generate an idx
+- convert the fetched packfile to sha256 format and generate an idx
   file
 - re-sort to match the order of objects in the fetched packfile
 
@@ -680,30 +680,30 @@ The infrastructure supporting fetch also
 repository. In converted repositories and new clones, end users can
 gain support for the new hash function without any visible change in
 behavior (see "dark launch" in the "Object names on the command line"
-section). In particular this allows users to verify NewHash signatures
+section). In particular this allows users to verify SHA-256 signatures
 on objects in the repository, and it should ensure the transition code
 is stable in production in preparation for using it more widely.
 
 Over time projects would encourage their users to adopt the "early
 transition" and then "late transition" modes to take advantage of the
-new, more futureproof NewHash object names.
+new, more futureproof SHA-256 object names.
 
 When objectFormat and compatObjectFormat are both set, commands
-generating signatures would generate both SHA-1 and NewHash signatures
+generating signatures would generate both SHA-1 and SHA-256 signatures
 by default to support both new and old users.
 
-In projects using NewHash heavily, users could be encouraged to adopt
+In projects using SHA-256 heavily, users could be encouraged to adopt
 the "post-transition" mode to avoid accidentally making implicit use
 of SHA-1 object names.
 
 Once a critical mass of users have upgraded to a version of Git that
-can verify NewHash signatures and have converted their existing
+can verify SHA-256 signatures and have converted their existing
 repositories to support verifying them, we can add support for a
-setting to generate only NewHash signatures. This is expected to be at
+setting to generate only SHA-256 signatures. This is expected to be at
 least a year later.
 
 That is also a good moment to advertise the ability to convert
-repositories to use NewHash only, stripping out all SHA-1 related
+repositories to use SHA-256 only, stripping out all SHA-1 related
 metadata. This improves performance by eliminating translation
 overhead and security by avoiding the possibility of accidentally
 relying on the safety of SHA-1.
@@ -730,7 +730,7 @@ adoption.
 
 Using hash functions in parallel
 ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
-(e.g. https://public-inbox.org/git/22708.8913.864049.452252@chiark.greenend.org.uk/ )
+(e.g. https://lore.kernel.org/git/22708.8913.864049.452252@chiark.greenend.org.uk/ )
 Objects newly created would be addressed by the new hash, but inside
 such an object (e.g. commit) it is still possible to address objects
 using the old hash function.
@@ -742,16 +742,16 @@ using the old hash function.
 
 Signed objects with multiple hashes
 ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
-Instead of introducing the gpgsig-newhash field in commit and tag objects
-for newhash-content based signatures, an earlier version of this design
-added "hash newhash <newhash-name>" fields to strengthen the existing
+Instead of introducing the gpgsig-sha256 field in commit and tag objects
+for sha256-content based signatures, an earlier version of this design
+added "hash sha256 <sha256-name>" fields to strengthen the existing
 sha1-content based signatures.
 
 In other words, a single signature was used to attest to the object
 content using both hash functions. This had some advantages:
 * Using one signature instead of two speeds up the signing process.
 * Having one signed payload with both hashes allows the signer to
-  attest to the sha1-name and newhash-name referring to the same object.
+  attest to the sha1-name and sha256-name referring to the same object.
 * All users consume the same signature. Broken signatures are likely
   to be detected quickly using current versions of git.
 
@@ -760,11 +760,11 @@ However, it also came with disadvantages
   objects it references, even after the transition is complete and
   translation table is no longer needed for anything else. To support
   this, the design added fields such as "hash sha1 tree <sha1-name>"
-  and "hash sha1 parent <sha1-name>" to the newhash-content of a signed
+  and "hash sha1 parent <sha1-name>" to the sha256-content of a signed
   commit, complicating the conversion process.
 * Allowing signed objects without a sha1 (for after the transition is
   complete) complicated the design further, requiring a "nohash sha1"
-  field to suppress including "hash sha1" fields in the newhash-content
+  field to suppress including "hash sha1" fields in the sha256-content
   and signed payload.
 
 Lazily populated translation table
@@ -772,7 +772,7 @@ Lazily populated translation table
 Some of the work of building the translation table could be deferred to
 push time, but that would significantly complicate and slow down pushes.
 Calculating the sha1-name at object creation time at the same time it is
-being streamed to disk and having its newhash-name calculated should be
+being streamed to disk and having its sha256-name calculated should be
 an acceptable cost.
 
 Document History
@@ -783,7 +783,7 @@ bmwill@google.com, jonathantanmy@google.
 sbeller@google.com
 
 Initial version sent to
-http://public-inbox.org/git/20170304011251.GA26789@aiede.mtv.corp.google.com
+http://lore.kernel.org/git/20170304011251.GA26789@aiede.mtv.corp.google.com
 
 2017-03-03 jrnieder@gmail.com
 Incorporated suggestions from jonathantanmy and sbeller:
@@ -814,8 +814,14 @@ Incorporated suggestions from jonathanta
 * avoid loose object overhead by packing more aggressively in
   "git gc --auto"
 
-[1] http://public-inbox.org/git/CA+55aFzJtejiCjV0e43+9oR3QuJK2PiFiLQemytoLpyJWe6P9w@mail.gmail.com/
-[2] http://public-inbox.org/git/CA+55aFz+gkAsDZ24zmePQuEs1XPS9BP_s8O7Q4wQ7LV7X5-oDA@mail.gmail.com/
-[3] http://public-inbox.org/git/20170306084353.nrns455dvkdsfgo5@sigill.intra.peff.net/
-[4] http://public-inbox.org/git/20170304224936.rqqtkdvfjgyezsht@genre.crustytoothpaste.net
-[5] https://public-inbox.org/git/CAJo=hJtoX9=AyLHHpUJS7fueV9ciZ_MNpnEPHUz8Whui6g9F0A@mail.gmail.com/
+Later history:
+
+ See the history of this file in git.git for the history of subsequent
+ edits. This document history is no longer being maintained as it
+ would now be superfluous to the commit log
+
+[1] http://lore.kernel.org/git/CA+55aFzJtejiCjV0e43+9oR3QuJK2PiFiLQemytoLpyJWe6P9w@mail.gmail.com/
+[2] http://lore.kernel.org/git/CA+55aFz+gkAsDZ24zmePQuEs1XPS9BP_s8O7Q4wQ7LV7X5-oDA@mail.gmail.com/
+[3] http://lore.kernel.org/git/20170306084353.nrns455dvkdsfgo5@sigill.intra.peff.net/
+[4] http://lore.kernel.org/git/20170304224936.rqqtkdvfjgyezsht@genre.crustytoothpaste.net
+[5] https://lore.kernel.org/git/CAJo=hJtoX9=AyLHHpUJS7fueV9ciZ_MNpnEPHUz8Whui6g9F0A@mail.gmail.com/
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/technical/http-protocol.txt 1.2.3+git2.25.1-1/git/Documentation/technical/http-protocol.txt
--- 1.2.1+git2.18.0-1/git/Documentation/technical/http-protocol.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/technical/http-protocol.txt	2020-02-17 04:47:35.000000000 +0000
@@ -338,11 +338,11 @@ server advertises capability `allow-tip-
 		       request_end
   request_end       =  "0000" / "done"
 
-  want_list         =  PKT-LINE(want NUL cap_list LF)
+  want_list         =  PKT-LINE(want SP cap_list LF)
 		       *(want_pkt)
   want_pkt          =  PKT-LINE(want LF)
   want              =  "want" SP id
-  cap_list          =  *(SP capability) SP
+  cap_list          =  capability *(SP capability)
 
   have_list         =  *PKT-LINE("have" SP id LF)
 
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/technical/index-format.txt 1.2.3+git2.25.1-1/git/Documentation/technical/index-format.txt
--- 1.2.1+git2.18.0-1/git/Documentation/technical/index-format.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/technical/index-format.txt	2020-02-17 04:47:35.000000000 +0000
@@ -314,3 +314,44 @@ The remaining data of each directory blo
 
   - An ewah bitmap, the n-th bit indicates whether the n-th index entry
     is not CE_FSMONITOR_VALID.
+
+== End of Index Entry
+
+  The End of Index Entry (EOIE) is used to locate the end of the variable
+  length index entries and the beginning of the extensions. Code can take
+  advantage of this to quickly locate the index extensions without having
+  to parse through all of the index entries.
+
+  Because it must be able to be loaded before the variable length cache
+  entries and other index extensions, this extension must be written last.
+  The signature for this extension is { 'E', 'O', 'I', 'E' }.
+
+  The extension consists of:
+
+  - 32-bit offset to the end of the index entries
+
+  - 160-bit SHA-1 over the extension types and their sizes (but not
+	their contents).  E.g. if we have "TREE" extension that is N-bytes
+	long, "REUC" extension that is M-bytes long, followed by "EOIE",
+	then the hash would be:
+
+	SHA-1("TREE" + <binary representation of N> +
+		"REUC" + <binary representation of M>)
+
+== Index Entry Offset Table
+
+  The Index Entry Offset Table (IEOT) is used to help address the CPU
+  cost of loading the index by enabling multi-threading the process of
+  converting cache entries from the on-disk format to the in-memory format.
+  The signature for this extension is { 'I', 'E', 'O', 'T' }.
+
+  The extension consists of:
+
+  - 32-bit version (currently 1)
+
+  - A number of index offset entries each consisting of:
+
+    - 32-bit offset from the beginning of the file to the first cache entry
+	in this block of entries.
+
+    - 32-bit count of cache entries in this block
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/technical/multi-pack-index.txt 1.2.3+git2.25.1-1/git/Documentation/technical/multi-pack-index.txt
--- 1.2.1+git2.18.0-1/git/Documentation/technical/multi-pack-index.txt	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/technical/multi-pack-index.txt	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,109 @@
+Multi-Pack-Index (MIDX) Design Notes
+====================================
+
+The Git object directory contains a 'pack' directory containing
+packfiles (with suffix ".pack") and pack-indexes (with suffix
+".idx"). The pack-indexes provide a way to lookup objects and
+navigate to their offset within the pack, but these must come
+in pairs with the packfiles. This pairing depends on the file
+names, as the pack-index differs only in suffix with its pack-
+file. While the pack-indexes provide fast lookup per packfile,
+this performance degrades as the number of packfiles increases,
+because abbreviations need to inspect every packfile and we are
+more likely to have a miss on our most-recently-used packfile.
+For some large repositories, repacking into a single packfile
+is not feasible due to storage space or excessive repack times.
+
+The multi-pack-index (MIDX for short) stores a list of objects
+and their offsets into multiple packfiles. It contains:
+
+- A list of packfile names.
+- A sorted list of object IDs.
+- A list of metadata for the ith object ID including:
+  - A value j referring to the jth packfile.
+  - An offset within the jth packfile for the object.
+- If large offsets are required, we use another list of large
+  offsets similar to version 2 pack-indexes.
+
+Thus, we can provide O(log N) lookup time for any number
+of packfiles.
+
+Design Details
+--------------
+
+- The MIDX is stored in a file named 'multi-pack-index' in the
+  .git/objects/pack directory. This could be stored in the pack
+  directory of an alternate. It refers only to packfiles in that
+  same directory.
+
+- The core.multiPackIndex config setting must be on to consume MIDX files.
+
+- The file format includes parameters for the object ID hash
+  function, so a future change of hash algorithm does not require
+  a change in format.
+
+- The MIDX keeps only one record per object ID. If an object appears
+  in multiple packfiles, then the MIDX selects the copy in the most-
+  recently modified packfile.
+
+- If there exist packfiles in the pack directory not registered in
+  the MIDX, then those packfiles are loaded into the `packed_git`
+  list and `packed_git_mru` cache.
+
+- The pack-indexes (.idx files) remain in the pack directory so we
+  can delete the MIDX file, set core.midx to false, or downgrade
+  without any loss of information.
+
+- The MIDX file format uses a chunk-based approach (similar to the
+  commit-graph file) that allows optional data to be added.
+
+Future Work
+-----------
+
+- Add a 'verify' subcommand to the 'git midx' builtin to verify the
+  contents of the multi-pack-index file match the offsets listed in
+  the corresponding pack-indexes.
+
+- The multi-pack-index allows many packfiles, especially in a context
+  where repacking is expensive (such as a very large repo), or
+  unexpected maintenance time is unacceptable (such as a high-demand
+  build machine). However, the multi-pack-index needs to be rewritten
+  in full every time. We can extend the format to be incremental, so
+  writes are fast. By storing a small "tip" multi-pack-index that
+  points to large "base" MIDX files, we can keep writes fast while
+  still reducing the number of binary searches required for object
+  lookups.
+
+- The reachability bitmap is currently paired directly with a single
+  packfile, using the pack-order as the object order to hopefully
+  compress the bitmaps well using run-length encoding. This could be
+  extended to pair a reachability bitmap with a multi-pack-index. If
+  the multi-pack-index is extended to store a "stable object order"
+  (a function Order(hash) = integer that is constant for a given hash,
+  even as the multi-pack-index is updated) then a reachability bitmap
+  could point to a multi-pack-index and be updated independently.
+
+- Packfiles can be marked as "special" using empty files that share
+  the initial name but replace ".pack" with ".keep" or ".promisor".
+  We can add an optional chunk of data to the multi-pack-index that
+  records flags of information about the packfiles. This allows new
+  states, such as 'repacked' or 'redeltified', that can help with
+  pack maintenance in a multi-pack environment. It may also be
+  helpful to organize packfiles by object type (commit, tree, blob,
+  etc.) and use this metadata to help that maintenance.
+
+- The partial clone feature records special "promisor" packs that
+  may point to objects that are not stored locally, but available
+  on request to a server. The multi-pack-index does not currently
+  track these promisor packs.
+
+Related Links
+-------------
+[0] https://bugs.chromium.org/p/git/issues/detail?id=6
+    Chromium work item for: Multi-Pack Index (MIDX)
+
+[1] https://lore.kernel.org/git/20180107181459.222909-1-dstolee@microsoft.com/
+    An earlier RFC for the multi-pack-index feature
+
+[2] https://lore.kernel.org/git/alpine.DEB.2.20.1803091557510.23109@alexmv-linux/
+    Git Merge 2018 Contributor's summit notes (includes discussion of MIDX)
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/technical/pack-format.txt 1.2.3+git2.25.1-1/git/Documentation/technical/pack-format.txt
--- 1.2.1+git2.18.0-1/git/Documentation/technical/pack-format.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/technical/pack-format.txt	2020-02-17 04:47:35.000000000 +0000
@@ -252,3 +252,81 @@ Pack file entry: <+
     corresponding packfile.
 
     20-byte SHA-1-checksum of all of the above.
+
+== multi-pack-index (MIDX) files have the following format:
+
+The multi-pack-index files refer to multiple pack-files and loose objects.
+
+In order to allow extensions that add extra data to the MIDX, we organize
+the body into "chunks" and provide a lookup table at the beginning of the
+body. The header includes certain length values, such as the number of packs,
+the number of base MIDX files, hash lengths and types.
+
+All 4-byte numbers are in network order.
+
+HEADER:
+
+	4-byte signature:
+	    The signature is: {'M', 'I', 'D', 'X'}
+
+	1-byte version number:
+	    Git only writes or recognizes version 1.
+
+	1-byte Object Id Version
+	    Git only writes or recognizes version 1 (SHA1).
+
+	1-byte number of "chunks"
+
+	1-byte number of base multi-pack-index files:
+	    This value is currently always zero.
+
+	4-byte number of pack files
+
+CHUNK LOOKUP:
+
+	(C + 1) * 12 bytes providing the chunk offsets:
+	    First 4 bytes describe chunk id. Value 0 is a terminating label.
+	    Other 8 bytes provide offset in current file for chunk to start.
+	    (Chunks are provided in file-order, so you can infer the length
+	    using the next chunk position if necessary.)
+
+	The remaining data in the body is described one chunk at a time, and
+	these chunks may be given in any order. Chunks are required unless
+	otherwise specified.
+
+CHUNK DATA:
+
+	Packfile Names (ID: {'P', 'N', 'A', 'M'})
+	    Stores the packfile names as concatenated, null-terminated strings.
+	    Packfiles must be listed in lexicographic order for fast lookups by
+	    name. This is the only chunk not guaranteed to be a multiple of four
+	    bytes in length, so should be the last chunk for alignment reasons.
+
+	OID Fanout (ID: {'O', 'I', 'D', 'F'})
+	    The ith entry, F[i], stores the number of OIDs with first
+	    byte at most i. Thus F[255] stores the total
+	    number of objects.
+
+	OID Lookup (ID: {'O', 'I', 'D', 'L'})
+	    The OIDs for all objects in the MIDX are stored in lexicographic
+	    order in this chunk.
+
+	Object Offsets (ID: {'O', 'O', 'F', 'F'})
+	    Stores two 4-byte values for every object.
+	    1: The pack-int-id for the pack storing this object.
+	    2: The offset within the pack.
+		If all offsets are less than 2^32, then the large offset chunk
+		will not exist and offsets are stored as in IDX v1.
+		If there is at least one offset value larger than 2^32-1, then
+		the large offset chunk must exist, and offsets larger than
+		2^31-1 must be stored in it instead. If the large offset chunk
+		exists and the 31st bit is on, then removing that bit reveals
+		the row in the large offsets containing the 8-byte offset of
+		this object.
+
+	[Optional] Object Large Offsets (ID: {'L', 'O', 'F', 'F'})
+	    8-byte offsets into large packfiles.
+
+TRAILER:
+
+	20-byte SHA1-checksum of the above contents.
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/technical/pack-protocol.txt 1.2.3+git2.25.1-1/git/Documentation/technical/pack-protocol.txt
--- 1.2.1+git2.18.0-1/git/Documentation/technical/pack-protocol.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/technical/pack-protocol.txt	2020-02-17 04:47:35.000000000 +0000
@@ -22,6 +22,16 @@ protocol-common.txt. When the grammar in
 otherwise noted the usual pkt-line LF rules apply: the sender SHOULD
 include a LF, but the receiver MUST NOT complain if it is not present.
 
+An error packet is a special pkt-line that contains an error string.
+
+----
+  error-line     =  PKT-LINE("ERR" SP explanation-text)
+----
+
+Throughout the protocol, where `PKT-LINE(...)` is expected, an error packet MAY
+be sent. Once this packet is sent by a client or a server, the data transfer
+process defined in this protocol is terminated.
+
 Transports
 ----------
 There are three transports over which the packfile protocol is
@@ -50,7 +60,8 @@ Each Extra Parameter takes the form of `
 
 Servers that receive any such Extra Parameters MUST ignore all
 unrecognized keys. Currently, the only Extra Parameter recognized is
-"version=1".
+"version" with a value of '1' or '2'.  See protocol-v2.txt for more
+information on protocol version 2.
 
 Git Transport
 -------------
@@ -88,13 +99,6 @@ process on the server side over the Git
      "0039git-upload-pack /schacon/gitbook.git\0host=example.com\0" |
      nc -v example.com 9418
 
-If the server refuses the request for some reasons, it could abort
-gracefully with an error message.
-
-----
-  error-line     =  PKT-LINE("ERR" SP explanation-text)
-----
-
 
 SSH Transport
 -------------
@@ -284,7 +288,9 @@ information is sent back to the client i
 The client can optionally request that pack-objects omit various
 objects from the packfile using one of several filtering techniques.
 These are intended for use with partial clone and partial fetch
-operations.  See `rev-list` for possible "filter-spec" values.
+operations. An object that does not meet a filter-spec value is
+omitted unless explicitly requested in a 'want' line. See `rev-list`
+for possible filter-spec values.
 
 Once all the 'want's and 'shallow's (and optional 'deepen') are
 transferred, clients MUST send a flush-pkt, to tell the server side
@@ -395,12 +401,11 @@ from the client).
 Then the server will start sending its packfile data.
 
 ----
-  server-response = *ack_multi ack / nak / error-line
+  server-response = *ack_multi ack / nak
   ack_multi       = PKT-LINE("ACK" SP obj-id ack_status)
   ack_status      = "continue" / "common" / "ready"
   ack             = PKT-LINE("ACK" SP obj-id)
   nak             = PKT-LINE("NAK")
-  error-line     =  PKT-LINE("ERR" SP explanation-text)
 ----
 
 A simple clone may look like this (with no 'have' lines):
@@ -639,7 +644,7 @@ update was successful, or 'ng [refname]
   command-ok        = PKT-LINE("ok" SP refname)
   command-fail      = PKT-LINE("ng" SP refname SP error-msg)
 
-  error-msg         = 1*(OCTECT) ; where not "ok"
+  error-msg         = 1*(OCTET) ; where not "ok"
 ----
 
 Updates can be unsuccessful for a number of reasons.  The reference can have
@@ -652,14 +657,14 @@ can be rejected.
 An example client/server communication might look like this:
 
 ----
-   S: 007c74730d410fcb6603ace96f1dc55ea6196122532d refs/heads/local\0report-status delete-refs ofs-delta\n
+   S: 006274730d410fcb6603ace96f1dc55ea6196122532d refs/heads/local\0report-status delete-refs ofs-delta\n
    S: 003e7d1665144a3a975c05f1f43902ddaf084e784dbe refs/heads/debug\n
    S: 003f74730d410fcb6603ace96f1dc55ea6196122532d refs/heads/master\n
-   S: 003f74730d410fcb6603ace96f1dc55ea6196122532d refs/heads/team\n
+   S: 003d74730d410fcb6603ace96f1dc55ea6196122532d refs/heads/team\n
    S: 0000
 
-   C: 003e7d1665144a3a975c05f1f43902ddaf084e784dbe 74730d410fcb6603ace96f1dc55ea6196122532d refs/heads/debug\n
-   C: 003e74730d410fcb6603ace96f1dc55ea6196122532d 5a3f6be755bbb7deae50065988cbfa1ffa9ab68a refs/heads/master\n
+   C: 00677d1665144a3a975c05f1f43902ddaf084e784dbe 74730d410fcb6603ace96f1dc55ea6196122532d refs/heads/debug\n
+   C: 006874730d410fcb6603ace96f1dc55ea6196122532d 5a3f6be755bbb7deae50065988cbfa1ffa9ab68a refs/heads/master\n
    C: 0000
    C: [PACKDATA]
 
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/technical/partial-clone.txt 1.2.3+git2.25.1-1/git/Documentation/technical/partial-clone.txt
--- 1.2.1+git2.18.0-1/git/Documentation/technical/partial-clone.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/technical/partial-clone.txt	2020-02-17 04:47:35.000000000 +0000
@@ -30,12 +30,20 @@ advance* during clone and fetch operatio
 times and disk usage.  Missing objects can later be "demand fetched"
 if/when needed.
 
+A remote that can later provide the missing objects is called a
+promisor remote, as it promises to send the objects when
+requested. Initially Git supported only one promisor remote, the origin
+remote from which the user cloned and that was configured in the
+"extensions.partialClone" config option. Later support for more than
+one promisor remote has been implemented.
+
 Use of partial clone requires that the user be online and the origin
-remote be available for on-demand fetching of missing objects.  This may
-or may not be problematic for the user.  For example, if the user can
-stay within the pre-selected subset of the source tree, they may not
-encounter any missing objects.  Alternatively, the user could try to
-pre-fetch various objects if they know that they are going offline.
+remote or other promisor remotes be available for on-demand fetching
+of missing objects.  This may or may not be problematic for the user.
+For example, if the user can stay within the pre-selected subset of
+the source tree, they may not encounter any missing objects.
+Alternatively, the user could try to pre-fetch various objects if they
+know that they are going offline.
 
 
 Non-Goals
@@ -69,24 +77,24 @@ Design Details
 
 - A new pack-protocol capability "filter" is added to the fetch-pack and
   upload-pack negotiation.
-
-  This uses the existing capability discovery mechanism.
-  See "filter" in Documentation/technical/pack-protocol.txt.
++
+This uses the existing capability discovery mechanism.
+See "filter" in Documentation/technical/pack-protocol.txt.
 
 - Clients pass a "filter-spec" to clone and fetch which is passed to the
   server to request filtering during packfile construction.
-
-  There are various filters available to accommodate different situations.
-  See "--filter=<filter-spec>" in Documentation/rev-list-options.txt.
++
+There are various filters available to accommodate different situations.
+See "--filter=<filter-spec>" in Documentation/rev-list-options.txt.
 
 - On the server pack-objects applies the requested filter-spec as it
   creates "filtered" packfiles for the client.
-
-  These filtered packfiles are *incomplete* in the traditional sense because
-  they may contain objects that reference objects not contained in the
-  packfile and that the client doesn't already have.  For example, the
-  filtered packfile may contain trees or tags that reference missing blobs
-  or commits that reference missing trees.
++
+These filtered packfiles are *incomplete* in the traditional sense because
+they may contain objects that reference objects not contained in the
+packfile and that the client doesn't already have.  For example, the
+filtered packfile may contain trees or tags that reference missing blobs
+or commits that reference missing trees.
 
 - On the client these incomplete packfiles are marked as "promisor packfiles"
   and treated differently by various commands.
@@ -100,51 +108,51 @@ Design Details
 Handling Missing Objects
 ------------------------
 
-- An object may be missing due to a partial clone or fetch, or missing due
-  to repository corruption.  To differentiate these cases, the local
-  repository specially indicates such filtered packfiles obtained from the
-  promisor remote as "promisor packfiles".
-
-  These promisor packfiles consist of a "<name>.promisor" file with
-  arbitrary contents (like the "<name>.keep" files), in addition to
-  their "<name>.pack" and "<name>.idx" files.
+- An object may be missing due to a partial clone or fetch, or missing
+  due to repository corruption.  To differentiate these cases, the
+  local repository specially indicates such filtered packfiles
+  obtained from promisor remotes as "promisor packfiles".
++
+These promisor packfiles consist of a "<name>.promisor" file with
+arbitrary contents (like the "<name>.keep" files), in addition to
+their "<name>.pack" and "<name>.idx" files.
 
 - The local repository considers a "promisor object" to be an object that
-  it knows (to the best of its ability) that the promisor remote has promised
-  that it has, either because the local repository has that object in one of
+  it knows (to the best of its ability) that promisor remotes have promised
+  that they have, either because the local repository has that object in one of
   its promisor packfiles, or because another promisor object refers to it.
-
-  When Git encounters a missing object, Git can see if it a promisor object
-  and handle it appropriately.  If not, Git can report a corruption.
-
-  This means that there is no need for the client to explicitly maintain an
-  expensive-to-modify list of missing objects.[a]
++
+When Git encounters a missing object, Git can see if it is a promisor object
+and handle it appropriately.  If not, Git can report a corruption.
++
+This means that there is no need for the client to explicitly maintain an
+expensive-to-modify list of missing objects.[a]
 
 - Since almost all Git code currently expects any referenced object to be
   present locally and because we do not want to force every command to do
   a dry-run first, a fallback mechanism is added to allow Git to attempt
-  to dynamically fetch missing objects from the promisor remote.
-
-  When the normal object lookup fails to find an object, Git invokes
-  fetch-object to try to get the object from the server and then retry
-  the object lookup.  This allows objects to be "faulted in" without
-  complicated prediction algorithms.
-
-  For efficiency reasons, no check as to whether the missing object is
-  actually a promisor object is performed.
-
-  Dynamic object fetching tends to be slow as objects are fetched one at
-  a time.
+  to dynamically fetch missing objects from promisor remotes.
++
+When the normal object lookup fails to find an object, Git invokes
+promisor_remote_get_direct() to try to get the object from a promisor
+remote and then retry the object lookup.  This allows objects to be
+"faulted in" without complicated prediction algorithms.
++
+For efficiency reasons, no check as to whether the missing object is
+actually a promisor object is performed.
++
+Dynamic object fetching tends to be slow as objects are fetched one at
+a time.
 
 - `checkout` (and any other command using `unpack-trees`) has been taught
   to bulk pre-fetch all required missing blobs in a single batch.
 
 - `rev-list` has been taught to print missing objects.
-
-  This can be used by other commands to bulk prefetch objects.
-  For example, a "git log -p A..B" may internally want to first do
-  something like "git rev-list --objects --quiet --missing=print A..B"
-  and prefetch those objects in bulk.
++
+This can be used by other commands to bulk prefetch objects.
+For example, a "git log -p A..B" may internally want to first do
+something like "git rev-list --objects --quiet --missing=print A..B"
+and prefetch those objects in bulk.
 
 - `fsck` has been updated to be fully aware of promisor objects.
 
@@ -154,11 +162,10 @@ Handling Missing Objects
 - The global variable "fetch_if_missing" is used to control whether an
   object lookup will attempt to dynamically fetch a missing object or
   report an error.
-
-  We are not happy with this global variable and would like to remove it,
-  but that requires significant refactoring of the object code to pass an
-  additional flag.  We hope that concurrent efforts to add an ODB API can
-  encompass this.
++
+We are not happy with this global variable and would like to remove it,
+but that requires significant refactoring of the object code to pass an
+additional flag.
 
 
 Fetching Missing Objects
@@ -168,10 +175,10 @@ Fetching Missing Objects
   transport_fetch_refs(), setting a new transport option
   TRANS_OPT_NO_DEPENDENTS to indicate that only the objects themselves are
   desired, not any object that they refer to.
-
-  Because some transports invoke fetch_pack() in the same process, fetch_pack()
-  has been updated to not use any object flags when the corresponding argument
-  (no_dependents) is set.
++
+Because some transports invoke fetch_pack() in the same process, fetch_pack()
+has been updated to not use any object flags when the corresponding argument
+(no_dependents) is set.
 
 - The local repository sends a request with the hashes of all requested
   objects as "want" lines, and does not perform any packfile negotiation.
@@ -182,21 +189,63 @@ Fetching Missing Objects
   though they are not necessary.
 
 
-Current Limitations
--------------------
+Using many promisor remotes
+---------------------------
+
+Many promisor remotes can be configured and used.
+
+This allows for example a user to have multiple geographically-close
+cache servers for fetching missing blobs while continuing to do
+filtered `git-fetch` commands from the central server.
 
-- The remote used for a partial clone (or the first partial fetch
-  following a regular clone) is marked as the "promisor remote".
+When fetching objects, promisor remotes are tried one after the other
+until all the objects have been fetched.
 
-  We are currently limited to a single promisor remote and only that
-  remote may be used for subsequent partial fetches.
+Remotes that are considered "promisor" remotes are those specified by
+the following configuration variables:
 
-  We accept this limitation because we believe initial users of this
-  feature will be using it on repositories with a strong single central
-  server.
+- `extensions.partialClone = <name>`
 
-- Dynamic object fetching will only ask the promisor remote for missing
-  objects.  We assume that the promisor remote has a complete view of the
+- `remote.<name>.promisor = true`
+
+- `remote.<name>.partialCloneFilter = ...`
+
+Only one promisor remote can be configured using the
+`extensions.partialClone` config variable. This promisor remote will
+be the last one tried when fetching objects.
+
+We decided to make it the last one we try, because it is likely that
+someone using many promisor remotes is doing so because the other
+promisor remotes are better for some reason (maybe they are closer or
+faster for some kind of objects) than the origin, and the origin is
+likely to be the remote specified by extensions.partialClone.
+
+This justification is not very strong, but one choice had to be made,
+and anyway the long term plan should be to make the order somehow
+fully configurable.
+
+For now though the other promisor remotes will be tried in the order
+they appear in the config file.
+
+Current Limitations
+-------------------
+
+- It is not possible to specify the order in which the promisor
+  remotes are tried in other ways than the order in which they appear
+  in the config file.
++
+It is also not possible to specify an order to be used when fetching
+from one remote and a different order when fetching from another
+remote.
+
+- It is not possible to push only specific objects to a promisor
+  remote.
++
+It is not possible to push at the same time to multiple promisor
+remote in a specific order.
+
+- Dynamic object fetching will only ask promisor remotes for missing
+  objects.  We assume that promisor remotes have a complete view of the
   repository and can satisfy all such requests.
 
 - Repack essentially treats promisor and non-promisor packfiles as 2
@@ -218,16 +267,18 @@ Current Limitations
 Future Work
 -----------
 
-- Allow more than one promisor remote and define a strategy for fetching
-  missing objects from specific promisor remotes or of iterating over the
-  set of promisor remotes until a missing object is found.
-
-  A user might want to have multiple geographically-close cache servers
-  for fetching missing blobs while continuing to do filtered `git-fetch`
-  commands from the central server, for example.
-
-  Or the user might want to work in a triangular work flow with multiple
-  promisor remotes that each have an incomplete view of the repository.
+- Improve the way to specify the order in which promisor remotes are
+  tried.
++
+For example this could allow to specify explicitly something like:
+"When fetching from this remote, I want to use these promisor remotes
+in this order, though, when pushing or fetching to that remote, I want
+to use those promisor remotes in that order."
+
+- Allow pushing to promisor remotes.
++
+The user might want to work in a triangular work flow with multiple
+promisor remotes that each have an incomplete view of the repository.
 
 - Allow repack to work on promisor packfiles (while keeping them distinct
   from non-promisor packfiles).
@@ -238,25 +289,25 @@ Future Work
 - Investigate use of a long-running process to dynamically fetch a series
   of objects, such as proposed in [5,6] to reduce process startup and
   overhead costs.
-
-  It would be nice if pack protocol V2 could allow that long-running
-  process to make a series of requests over a single long-running
-  connection.
++
+It would be nice if pack protocol V2 could allow that long-running
+process to make a series of requests over a single long-running
+connection.
 
 - Investigate pack protocol V2 to avoid the info/refs broadcast on
   each connection with the server to dynamically fetch missing objects.
 
 - Investigate the need to handle loose promisor objects.
-
-  Objects in promisor packfiles are allowed to reference missing objects
-  that can be dynamically fetched from the server.  An assumption was
-  made that loose objects are only created locally and therefore should
-  not reference a missing object.  We may need to revisit that assumption
-  if, for example, we dynamically fetch a missing tree and store it as a
-  loose object rather than a single object packfile.
-
-  This does not necessarily mean we need to mark loose objects as promisor;
-  it may be sufficient to relax the object lookup or is-promisor functions.
++
+Objects in promisor packfiles are allowed to reference missing objects
+that can be dynamically fetched from the server.  An assumption was
+made that loose objects are only created locally and therefore should
+not reference a missing object.  We may need to revisit that assumption
+if, for example, we dynamically fetch a missing tree and store it as a
+loose object rather than a single object packfile.
++
+This does not necessarily mean we need to mark loose objects as promisor;
+it may be sufficient to relax the object lookup or is-promisor functions.
 
 
 Non-Tasks
@@ -265,13 +316,13 @@ Non-Tasks
 - Every time the subject of "demand loading blobs" comes up it seems
   that someone suggests that the server be allowed to "guess" and send
   additional objects that may be related to the requested objects.
-
-  No work has gone into actually doing that; we're just documenting that
-  it is a common suggestion.  We're not sure how it would work and have
-  no plans to work on it.
-
-  It is valid for the server to send more objects than requested (even
-  for a dynamic object fetch), but we are not building on that.
++
+No work has gone into actually doing that; we're just documenting that
+it is a common suggestion.  We're not sure how it would work and have
+no plans to work on it.
++
+It is valid for the server to send more objects than requested (even
+for a dynamic object fetch), but we are not building on that.
 
 
 Footnotes
@@ -282,43 +333,43 @@ Footnotes
     This would essentially be a sorted linear list of OIDs that the were
     omitted by the server during a clone or subsequent fetches.
 
-    This file would need to be loaded into memory on every object lookup.
-    It would need to be read, updated, and re-written (like the .git/index)
-    on every explicit "git fetch" command *and* on any dynamic object fetch.
-
-    The cost to read, update, and write this file could add significant
-    overhead to every command if there are many missing objects.  For example,
-    if there are 100M missing blobs, this file would be at least 2GiB on disk.
+This file would need to be loaded into memory on every object lookup.
+It would need to be read, updated, and re-written (like the .git/index)
+on every explicit "git fetch" command *and* on any dynamic object fetch.
+
+The cost to read, update, and write this file could add significant
+overhead to every command if there are many missing objects.  For example,
+if there are 100M missing blobs, this file would be at least 2GiB on disk.
 
-    With the "promisor" concept, we *infer* a missing object based upon the
-    type of packfile that references it.
+With the "promisor" concept, we *infer* a missing object based upon the
+type of packfile that references it.
 
 
 Related Links
 -------------
-[0] https://bugs.chromium.org/p/git/issues/detail?id=2
-    Chromium work item for: Partial Clone
+[0] https://crbug.com/git/2
+    Bug#2: Partial Clone
 
-[1] https://public-inbox.org/git/20170113155253.1644-1-benpeart@microsoft.com/
-    Subject: [RFC] Add support for downloading blobs on demand
+[1] https://lore.kernel.org/git/20170113155253.1644-1-benpeart@microsoft.com/ +
+    Subject: [RFC] Add support for downloading blobs on demand +
     Date: Fri, 13 Jan 2017 10:52:53 -0500
 
-[2] https://public-inbox.org/git/cover.1506714999.git.jonathantanmy@google.com/
-    Subject: [PATCH 00/18] Partial clone (from clone to lazy fetch in 18 patches)
+[2] https://lore.kernel.org/git/cover.1506714999.git.jonathantanmy@google.com/ +
+    Subject: [PATCH 00/18] Partial clone (from clone to lazy fetch in 18 patches) +
     Date: Fri, 29 Sep 2017 13:11:36 -0700
 
-[3] https://public-inbox.org/git/20170426221346.25337-1-jonathantanmy@google.com/
-    Subject: Proposal for missing blob support in Git repos
+[3] https://lore.kernel.org/git/20170426221346.25337-1-jonathantanmy@google.com/ +
+    Subject: Proposal for missing blob support in Git repos +
     Date: Wed, 26 Apr 2017 15:13:46 -0700
 
-[4] https://public-inbox.org/git/1488999039-37631-1-git-send-email-git@jeffhostetler.com/
-    Subject: [PATCH 00/10] RFC Partial Clone and Fetch
+[4] https://lore.kernel.org/git/1488999039-37631-1-git-send-email-git@jeffhostetler.com/ +
+    Subject: [PATCH 00/10] RFC Partial Clone and Fetch +
     Date: Wed,  8 Mar 2017 18:50:29 +0000
 
-[5] https://public-inbox.org/git/20170505152802.6724-1-benpeart@microsoft.com/
-    Subject: [PATCH v7 00/10] refactor the filter process code into a reusable module
+[5] https://lore.kernel.org/git/20170505152802.6724-1-benpeart@microsoft.com/ +
+    Subject: [PATCH v7 00/10] refactor the filter process code into a reusable module +
     Date: Fri,  5 May 2017 11:27:52 -0400
 
-[6] https://public-inbox.org/git/20170714132651.170708-1-benpeart@microsoft.com/
-    Subject: [RFC/PATCH v2 0/1] Add support for downloading blobs on demand
+[6] https://lore.kernel.org/git/20170714132651.170708-1-benpeart@microsoft.com/ +
+    Subject: [RFC/PATCH v2 0/1] Add support for downloading blobs on demand +
     Date: Fri, 14 Jul 2017 09:26:50 -0400
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/technical/protocol-capabilities.txt 1.2.3+git2.25.1-1/git/Documentation/technical/protocol-capabilities.txt
--- 1.2.1+git2.18.0-1/git/Documentation/technical/protocol-capabilities.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/technical/protocol-capabilities.txt	2020-02-17 04:47:35.000000000 +0000
@@ -1,6 +1,10 @@
 Git Protocol Capabilities
 =========================
 
+NOTE: this document describes capabilities for versions 0 and 1 of the pack
+protocol. For version 2, please refer to the link:protocol-v2.html[protocol-v2]
+doc.
+
 Servers SHOULD support all capabilities defined in this document.
 
 On the very first line of the initial server response of either
@@ -172,6 +176,20 @@ agent strings are purely informative for
 purposes, and MUST NOT be used to programmatically assume the presence
 or absence of particular features.
 
+symref
+------
+
+This parameterized capability is used to inform the receiver which symbolic ref
+points to which ref; for example, "symref=HEAD:refs/heads/master" tells the
+receiver that HEAD points to master. This capability can be repeated to
+represent multiple symrefs.
+
+Servers SHOULD include this capability for the HEAD symref if it is one of the
+refs being sent.
+
+Clients MAY use the parameters from this capability to select the proper initial
+branch when cloning a repository.
+
 shallow
 -------
 
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/technical/protocol-v2.txt 1.2.3+git2.25.1-1/git/Documentation/technical/protocol-v2.txt
--- 1.2.1+git2.18.0-1/git/Documentation/technical/protocol-v2.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/technical/protocol-v2.txt	2020-02-17 04:47:35.000000000 +0000
@@ -1,5 +1,5 @@
- Git Wire Protocol, Version 2
-==============================
+Git Wire Protocol, Version 2
+============================
 
 This document presents a specification for a version 2 of Git's wire
 protocol.  Protocol v2 will improve upon v1 in the following ways:
@@ -22,8 +22,8 @@ will be commands which a client can requ
 has completed, a client can reuse the connection and request that other
 commands be executed.
 
- Packet-Line Framing
----------------------
+Packet-Line Framing
+-------------------
 
 All communication is done using packet-line framing, just as in v1.  See
 `Documentation/technical/pack-protocol.txt` and
@@ -34,8 +34,8 @@ In protocol v2 these special packets wil
   * '0000' Flush Packet (flush-pkt) - indicates the end of a message
   * '0001' Delimiter Packet (delim-pkt) - separates sections of a message
 
- Initial Client Request
-------------------------
+Initial Client Request
+----------------------
 
 In general a client can request to speak protocol v2 by sending
 `version=2` through the respective side-channel for the transport being
@@ -43,30 +43,29 @@ used which inevitably sets `GIT_PROTOCOL
 found in `pack-protocol.txt` and `http-protocol.txt`.  In all cases the
 response from the server is the capability advertisement.
 
- Git Transport
-~~~~~~~~~~~~~~~
+Git Transport
+~~~~~~~~~~~~~
 
 When using the git:// transport, you can request to use protocol v2 by
 sending "version=2" as an extra parameter:
 
    003egit-upload-pack /project.git\0host=myserver.com\0\0version=2\0
 
- SSH and File Transport
-~~~~~~~~~~~~~~~~~~~~~~~~
+SSH and File Transport
+~~~~~~~~~~~~~~~~~~~~~~
 
 When using either the ssh:// or file:// transport, the GIT_PROTOCOL
 environment variable must be set explicitly to include "version=2".
 
- HTTP Transport
-~~~~~~~~~~~~~~~~
+HTTP Transport
+~~~~~~~~~~~~~~
 
 When using the http:// or https:// transport a client makes a "smart"
 info/refs request as described in `http-protocol.txt` and requests that
 v2 be used by supplying "version=2" in the `Git-Protocol` header.
 
-   C: Git-Protocol: version=2
-   C:
    C: GET $GIT_URL/info/refs?service=git-upload-pack HTTP/1.0
+   C: Git-Protocol: version=2
 
 A v2 server would reply:
 
@@ -80,8 +79,8 @@ A v2 server would reply:
 Subsequent requests are then made directly to the service
 `$GIT_URL/git-upload-pack`. (This works the same for git-receive-pack).
 
- Capability Advertisement
---------------------------
+Capability Advertisement
+------------------------
 
 A server which decides to communicate (based on a request from a client)
 using protocol version 2, notifies the client by sending a version string
@@ -102,8 +101,8 @@ to be executed by the client.
     key = 1*(ALPHA | DIGIT | "-_")
     value = 1*(ALPHA | DIGIT | " -_.,?\/{}[]()<>!@#$%^&*+=:;")
 
- Command Request
------------------
+Command Request
+---------------
 
 After receiving the capability advertisement, a client can then issue a
 request to select the command it wants with any particular capabilities
@@ -138,11 +137,11 @@ command be executed or can terminate the
 optionally send an empty request consisting of just a flush-pkt to
 indicate that no more requests will be made.
 
- Capabilities
---------------
+Capabilities
+------------
 
 There are two different types of capabilities: normal capabilities,
-which can be used to to convey information or alter the behavior of a
+which can be used to convey information or alter the behavior of a
 request, and commands, which are the core actions that a client wants to
 perform (fetch, push, etc).
 
@@ -154,8 +153,8 @@ management on the server side in order t
 permits simple round-robin load-balancing on the server side, without
 needing to worry about state management.
 
- agent
-~~~~~~~
+agent
+~~~~~
 
 The server can advertise the `agent` capability with a value `X` (in the
 form `agent=X`) to notify the client that the server is running version
@@ -169,8 +168,8 @@ printable ASCII characters except space
 and debugging purposes, and MUST NOT be used to programmatically assume
 the presence or absence of particular features.
 
- ls-refs
-~~~~~~~~~
+ls-refs
+~~~~~~~
 
 `ls-refs` is the command used to request a reference advertisement in v2.
 Unlike the current reference advertisement, ls-refs takes in arguments
@@ -200,8 +199,8 @@ The output of ls-refs is as follows:
     symref = "symref-target:" symref-target
     peeled = "peeled:" obj-id
 
- fetch
-~~~~~~~
+fetch
+~~~~~
 
 `fetch` is the command used to fetch a packfile in v2.  It can be looked
 at as a modified version of the v1 fetch where the ref-advertisement is
@@ -253,7 +252,7 @@ A `fetch` request can take the following
     ofs-delta
 	Indicate that the client understands PACKv2 with delta referring
 	to its base by position in pack rather than by an oid.  That is,
-	they can read OBJ_OFS_DELTA (ake type 6) in a packfile.
+	they can read OBJ_OFS_DELTA (aka type 6) in a packfile.
 
 If the 'shallow' feature is advertised the following arguments can be
 included in the clients request as well as the potential addition of the
@@ -297,14 +296,39 @@ included in the client's request:
 	Request that various objects from the packfile be omitted
 	using one of several filtering techniques. These are intended
 	for use with partial clone and partial fetch operations. See
-	`rev-list` for possible "filter-spec" values.
+	`rev-list` for possible "filter-spec" values. When communicating
+	with other processes, senders SHOULD translate scaled integers
+	(e.g. "1k") into a fully-expanded form (e.g. "1024") to aid
+	interoperability with older receivers that may not understand
+	newly-invented scaling suffixes. However, receivers SHOULD
+	accept the following suffixes: 'k', 'm', and 'g' for 1024,
+	1048576, and 1073741824, respectively.
+
+If the 'ref-in-want' feature is advertised, the following argument can
+be included in the client's request as well as the potential addition of
+the 'wanted-refs' section in the server's response as explained below.
+
+    want-ref <ref>
+	Indicates to the server that the client wants to retrieve a
+	particular ref, where <ref> is the full name of a ref on the
+	server.
+
+If the 'sideband-all' feature is advertised, the following argument can be
+included in the client's request:
+
+    sideband-all
+	Instruct the server to send the whole response multiplexed, not just
+	the packfile section. All non-flush and non-delim PKT-LINE in the
+	response (not only in the packfile section) will then start with a byte
+	indicating its sideband (1, 2, or 3), and the server may send "0005\2"
+	(a PKT-LINE of sideband 2 with no payload) as a keepalive packet.
 
 The response of `fetch` is broken into a number of sections separated by
 delimiter packets (0001), with each section beginning with its section
 header.
 
     output = *section
-    section = (acknowledgments | shallow-info | packfile)
+    section = (acknowledgments | shallow-info | wanted-refs | packfile)
 	      (flush-pkt | delim-pkt)
 
     acknowledgments = PKT-LINE("acknowledgments" LF)
@@ -319,6 +343,10 @@ header.
     shallow = "shallow" SP obj-id
     unshallow = "unshallow" SP obj-id
 
+    wanted-refs = PKT-LINE("wanted-refs" LF)
+		  *PKT-LINE(wanted-ref LF)
+    wanted-ref = obj-id SP refname
+
     packfile = PKT-LINE("packfile" LF)
 	       *PKT-LINE(%x01-03 *%x00-ff)
 
@@ -379,6 +407,19 @@ header.
 	* This section is only included if a packfile section is also
 	  included in the response.
 
+    wanted-refs section
+	* This section is only included if the client has requested a
+	  ref using a 'want-ref' line and if a packfile section is also
+	  included in the response.
+
+	* Always begins with the section header "wanted-refs".
+
+	* The server will send a ref listing ("<oid> <refname>") for
+	  each reference requested using 'want-ref' lines.
+
+	* The server MUST NOT send any refs which were not requested
+	  using 'want-ref' lines.
+
     packfile section
 	* This section is only included if the client has sent 'want'
 	  lines in its request and either requested that no more
@@ -403,8 +444,8 @@ header.
 		2 - progress messages
 		3 - fatal error message just before stream aborts
 
- server-option
-~~~~~~~~~~~~~~~
+server-option
+~~~~~~~~~~~~~
 
 If advertised, indicates that any number of server specific options can be
 included in a request.  This is done by sending each option as a
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/technical/racy-git.txt 1.2.3+git2.25.1-1/git/Documentation/technical/racy-git.txt
--- 1.2.1+git2.18.0-1/git/Documentation/technical/racy-git.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/technical/racy-git.txt	2020-02-17 04:47:35.000000000 +0000
@@ -51,7 +51,7 @@ of git://git.kernel.org/pub/scm/linux/ke
 only fixes the issue for file systems with exactly 1 ns or 1 s
 resolution. Other file systems are still broken in current Linux
 kernels (e.g. CEPH, CIFS, NTFS, UDF), see
-https://lkml.org/lkml/2015/6/9/714
+https://lore.kernel.org/lkml/5577240D.7020309@gmail.com/
 
 Racy Git
 --------
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/technical/repository-version.txt 1.2.3+git2.25.1-1/git/Documentation/technical/repository-version.txt
--- 1.2.1+git2.18.0-1/git/Documentation/technical/repository-version.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/technical/repository-version.txt	2020-02-17 04:47:35.000000000 +0000
@@ -1,5 +1,4 @@
-Git Repository Format Versions
-==============================
+== Git Repository Format Versions
 
 Every git repository is marked with a numeric version in the
 `core.repositoryformatversion` key of its `config` file. This version
@@ -40,16 +39,14 @@ format by default.
 
 The currently defined format versions are:
 
-Version `0`
------------
+=== Version `0`
 
 This is the format defined by the initial version of git, including but
 not limited to the format of the repository directory, the repository
 configuration file, and the object and ref storage. Specifying the
 complete behavior of git is beyond the scope of this document.
 
-Version `1`
------------
+=== Version `1`
 
 This format is identical to version `0`, with the following exceptions:
 
@@ -74,21 +71,18 @@ it here, in order to claim the name.
 
 The defined extensions are:
 
-`noop`
-~~~~~~
+==== `noop`
 
 This extension does not change git's behavior at all. It is useful only
 for testing format-1 compatibility.
 
-`preciousObjects`
-~~~~~~~~~~~~~~~~~
+==== `preciousObjects`
 
 When the config key `extensions.preciousObjects` is set to `true`,
 objects in the repository MUST NOT be deleted (e.g., by `git-prune` or
 `git repack -d`).
 
-`partialclone`
-~~~~~~~~~~~~~~
+==== `partialclone`
 
 When the config key `extensions.partialclone` is set, it indicates
 that the repo was created with a partial clone (or later performed
@@ -98,3 +92,11 @@ and it promises that all such omitted ob
 in the future.
 
 The value of this key is the name of the promisor remote.
+
+==== `worktreeConfig`
+
+If set, by default "git config" reads from both "config" and
+"config.worktree" file from GIT_DIR in that order. In
+multiple working directory mode, "config" file is shared while
+"config.worktree" is per-working directory (i.e., it's in
+GIT_COMMON_DIR/worktrees/<id>/config.worktree)
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/technical/rerere.txt 1.2.3+git2.25.1-1/git/Documentation/technical/rerere.txt
--- 1.2.1+git2.18.0-1/git/Documentation/technical/rerere.txt	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/technical/rerere.txt	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,186 @@
+Rerere
+======
+
+This document describes the rerere logic.
+
+Conflict normalization
+----------------------
+
+To ensure recorded conflict resolutions can be looked up in the rerere
+database, even when branches are merged in a different order,
+different branches are merged that result in the same conflict, or
+when different conflict style settings are used, rerere normalizes the
+conflicts before writing them to the rerere database.
+
+Different conflict styles and branch names are normalized by stripping
+the labels from the conflict markers, and removing the common ancestor
+version from the `diff3` conflict style. Branches that are merged
+in different order are normalized by sorting the conflict hunks.  More
+on each of those steps in the following sections.
+
+Once these two normalization operations are applied, a conflict ID is
+calculated based on the normalized conflict, which is later used by
+rerere to look up the conflict in the rerere database.
+
+Removing the common ancestor version
+~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
+
+Say we have three branches AB, AC and AC2.  The common ancestor of
+these branches has a file with a line containing the string "A" (for
+brevity this is called "line A" in the rest of the document).  In
+branch AB this line is changed to "B", in AC, this line is changed to
+"C", and branch AC2 is forked off of AC, after the line was changed to
+"C".
+
+Forking a branch ABAC off of branch AB and then merging AC into it, we
+get a conflict like the following:
+
+    <<<<<<< HEAD
+    B
+    =======
+    C
+    >>>>>>> AC
+
+Doing the analogous with AC2 (forking a branch ABAC2 off of branch AB
+and then merging branch AC2 into it), using the diff3 conflict style,
+we get a conflict like the following:
+
+    <<<<<<< HEAD
+    B
+    ||||||| merged common ancestors
+    A
+    =======
+    C
+    >>>>>>> AC2
+
+By resolving this conflict, to leave line D, the user declares:
+
+    After examining what branches AB and AC did, I believe that making
+    line A into line D is the best thing to do that is compatible with
+    what AB and AC wanted to do.
+
+As branch AC2 refers to the same commit as AC, the above implies that
+this is also compatible what AB and AC2 wanted to do.
+
+By extension, this means that rerere should recognize that the above
+conflicts are the same.  To do this, the labels on the conflict
+markers are stripped, and the common ancestor version is removed.  The above
+examples would both result in the following normalized conflict:
+
+    <<<<<<<
+    B
+    =======
+    C
+    >>>>>>>
+
+Sorting hunks
+~~~~~~~~~~~~~
+
+As before, lets imagine that a common ancestor had a file with line A
+its early part, and line X in its late part.  And then four branches
+are forked that do these things:
+
+    - AB: changes A to B
+    - AC: changes A to C
+    - XY: changes X to Y
+    - XZ: changes X to Z
+
+Now, forking a branch ABAC off of branch AB and then merging AC into
+it, and forking a branch ACAB off of branch AC and then merging AB
+into it, would yield the conflict in a different order.  The former
+would say "A became B or C, what now?" while the latter would say "A
+became C or B, what now?"
+
+As a reminder, the act of merging AC into ABAC and resolving the
+conflict to leave line D means that the user declares:
+
+    After examining what branches AB and AC did, I believe that
+    making line A into line D is the best thing to do that is
+    compatible with what AB and AC wanted to do.
+
+So the conflict we would see when merging AB into ACAB should be
+resolved the same way---it is the resolution that is in line with that
+declaration.
+
+Imagine that similarly previously a branch XYXZ was forked from XY,
+and XZ was merged into it, and resolved "X became Y or Z" into "X
+became W".
+
+Now, if a branch ABXY was forked from AB and then merged XY, then ABXY
+would have line B in its early part and line Y in its later part.
+Such a merge would be quite clean.  We can construct 4 combinations
+using these four branches ((AB, AC) x (XY, XZ)).
+
+Merging ABXY and ACXZ would make "an early A became B or C, a late X
+became Y or Z" conflict, while merging ACXY and ABXZ would make "an
+early A became C or B, a late X became Y or Z".  We can see there are
+4 combinations of ("B or C", "C or B") x ("X or Y", "Y or X").
+
+By sorting, the conflict is given its canonical name, namely, "an
+early part became B or C, a late part became X or Y", and whenever
+any of these four patterns appear, and we can get to the same conflict
+and resolution that we saw earlier.
+
+Without the sorting, we'd have to somehow find a previous resolution
+from combinatorial explosion.
+
+Conflict ID calculation
+~~~~~~~~~~~~~~~~~~~~~~~
+
+Once the conflict normalization is done, the conflict ID is calculated
+as the sha1 hash of the conflict hunks appended to each other,
+separated by <NUL> characters.  The conflict markers are stripped out
+before the sha1 is calculated.  So in the example above, where we
+merge branch AC which changes line A to line C, into branch AB, which
+changes line A to line C, the conflict ID would be
+SHA1('B<NUL>C<NUL>').
+
+If there are multiple conflicts in one file, the sha1 is calculated
+the same way with all hunks appended to each other, in the order in
+which they appear in the file, separated by a <NUL> character.
+
+Nested conflicts
+~~~~~~~~~~~~~~~~
+
+Nested conflicts are handled very similarly to "simple" conflicts.
+Similar to simple conflicts, the conflict is first normalized by
+stripping the labels from conflict markers, stripping the common ancestor
+version, and the sorting the conflict hunks, both for the outer and the
+inner conflict.  This is done recursively, so any number of nested
+conflicts can be handled.
+
+Note that this only works for conflict markers that "cleanly nest".  If
+there are any unmatched conflict markers, rerere will fail to handle
+the conflict and record a conflict resolution.
+
+The only difference is in how the conflict ID is calculated.  For the
+inner conflict, the conflict markers themselves are not stripped out
+before calculating the sha1.
+
+Say we have the following conflict for example:
+
+    <<<<<<< HEAD
+    1
+    =======
+    <<<<<<< HEAD
+    3
+    =======
+    2
+    >>>>>>> branch-2
+    >>>>>>> branch-3~
+
+After stripping out the labels of the conflict markers, and sorting
+the hunks, the conflict would look as follows:
+
+    <<<<<<<
+    1
+    =======
+    <<<<<<<
+    2
+    =======
+    3
+    >>>>>>>
+    >>>>>>>
+
+and finally the conflict ID would be calculated as:
+`sha1('1<NUL><<<<<<<\n3\n=======\n2\n>>>>>>><NUL>')`
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/trace2-target-values.txt 1.2.3+git2.25.1-1/git/Documentation/trace2-target-values.txt
--- 1.2.1+git2.18.0-1/git/Documentation/trace2-target-values.txt	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/trace2-target-values.txt	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,12 @@
+--
+* `0` or `false` - Disables the target.
+* `1` or `true` - Writes to `STDERR`.
+* `[2-9]` - Writes to the already opened file descriptor.
+* `<absolute-pathname>` - Writes to the file in append mode. If the target
+already exists and is a directory, the traces will be written to files (one
+per process) underneath the given directory.
+* `af_unix:[<socket_type>:]<absolute-pathname>` - Write to a
+Unix DomainSocket (on platforms that support them).  Socket
+type can be either `stream` or `dgram`; if omitted Git will
+try both.
+--
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/urls.txt 1.2.3+git2.25.1-1/git/Documentation/urls.txt
--- 1.2.1+git2.18.0-1/git/Documentation/urls.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/urls.txt	2020-02-17 04:47:35.000000000 +0000
@@ -53,6 +53,9 @@ These two syntaxes are mostly equivalent
 --local option.
 endif::git-clone[]
 
+'git clone', 'git fetch' and 'git pull', but not 'git push', will also
+accept a suitable bundle file. See linkgit:git-bundle[1].
+
 When Git doesn't know how to handle a certain transport protocol, it
 attempts to use the 'remote-<transport>' remote helper, if one
 exists. To explicitly request a remote helper, the following syntax
@@ -62,7 +65,7 @@ may be used:
 
 where <address> may be a path, a server and path, or an arbitrary
 URL-like string recognized by the specific remote helper being
-invoked. See linkgit:gitremote-helpers[1] for details.
+invoked. See linkgit:gitremote-helpers[7] for details.
 
 If there are a large number of similarly-named remote repositories and
 you want to use a different format for them (such that the URLs you
diff -pruN 1.2.1+git2.18.0-1/git/Documentation/user-manual.txt 1.2.3+git2.25.1-1/git/Documentation/user-manual.txt
--- 1.2.1+git2.18.0-1/git/Documentation/user-manual.txt	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Documentation/user-manual.txt	2020-02-17 04:47:35.000000000 +0000
@@ -1,5 +1,4 @@
-Git User Manual
-===============
+= Git User Manual
 
 Git is a fast distributed revision control system.
 
@@ -41,12 +40,10 @@ complete.
 
 
 [[repositories-and-branches]]
-Repositories and Branches
-=========================
+== Repositories and Branches
 
 [[how-to-get-a-git-repository]]
-How to get a Git repository
----------------------------
+=== How to get a Git repository
 
 It will be useful to have a Git repository to experiment with as you
 read this manual.
@@ -73,8 +70,7 @@ top-level directory named `.git`, which
 about the history of the project.
 
 [[how-to-check-out]]
-How to check out a different version of a project
--------------------------------------------------
+=== How to check out a different version of a project
 
 Git is best thought of as a tool for storing the history of a collection
 of files.  It stores the history as a compressed collection of
@@ -122,10 +118,10 @@ Tags are expected to always point at the
 while heads are expected to advance as development progresses.
 
 Create a new branch head pointing to one of these versions and check it
-out using linkgit:git-checkout[1]:
+out using linkgit:git-switch[1]:
 
 ------------------------------------------------
-$ git checkout -b new v2.6.13
+$ git switch -c new v2.6.13
 ------------------------------------------------
 
 The working directory then reflects the contents that the project had
@@ -151,8 +147,7 @@ with no way to find the history it used
 carefully.
 
 [[understanding-commits]]
-Understanding History: Commits
-------------------------------
+=== Understanding History: Commits
 
 Every change in the history of a project is represented by a commit.
 The linkgit:git-show[1] command shows the most recent commit on the
@@ -202,8 +197,7 @@ history, including file data and directo
 with a name that is a hash of its contents.
 
 [[understanding-reachability]]
-Understanding history: commits, parents, and reachability
-~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
+==== Understanding history: commits, parents, and reachability
 
 Every commit (except the very first commit in a project) also has a
 parent commit which shows what happened before this commit.
@@ -227,8 +221,7 @@ that Y is a descendant of X, or that the
 leading from commit Y to commit X.
 
 [[history-diagrams]]
-Understanding history: History diagrams
-~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
+==== Understanding history: History diagrams
 
 We will sometimes represent Git history using diagrams like the one
 below.  Commits are shown as "o", and the links between them with
@@ -247,8 +240,7 @@ If we need to talk about a particular co
 be replaced with another letter or number.
 
 [[what-is-a-branch]]
-Understanding history: What is a branch?
-~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
+==== Understanding history: What is a branch?
 
 When we need to be precise, we will use the word "branch" to mean a line
 of development, and "branch head" (or just "head") to mean a reference
@@ -261,8 +253,7 @@ However, when no confusion will result,
 "branch" both for branches and for branch heads.
 
 [[manipulating-branches]]
-Manipulating branches
----------------------
+=== Manipulating branches
 
 Creating, deleting, and modifying branches is quick and easy; here's
 a summary of the commands:
@@ -282,10 +273,10 @@ a summary of the commands:
 	this command will fail with a warning.
 `git branch -D <branch>`::
 	delete the branch `<branch>` irrespective of its merged status.
-`git checkout <branch>`::
+`git switch <branch>`::
 	make the current branch `<branch>`, updating the working
 	directory to reflect the version referenced by `<branch>`.
-`git checkout -b <new> <start-point>`::
+`git switch -c <new> <start-point>`::
 	create a new branch `<new>` referencing `<start-point>`, and
 	check it out.
 
@@ -299,25 +290,24 @@ ref: refs/heads/master
 ------------------------------------------------
 
 [[detached-head]]
-Examining an old version without creating a new branch
-------------------------------------------------------
+=== Examining an old version without creating a new branch
 
-The `git checkout` command normally expects a branch head, but will also
-accept an arbitrary commit; for example, you can check out the commit
-referenced by a tag:
+The `git switch` command normally expects a branch head, but will also
+accept an arbitrary commit when invoked with --detach; for example,
+you can check out the commit referenced by a tag:
 
 ------------------------------------------------
-$ git checkout v2.6.17
+$ git switch --detach v2.6.17
 Note: checking out 'v2.6.17'.
 
 You are in 'detached HEAD' state. You can look around, make experimental
 changes and commit them, and you can discard any commits you make in this
-state without impacting any branches by performing another checkout.
+state without impacting any branches by performing another switch.
 
 If you want to create a new branch to retain commits you create, you may
-do so (now or later) by using -b with the checkout command again. Example:
+do so (now or later) by using -c with the switch command again. Example:
 
-  git checkout -b new_branch_name
+  git switch -c new_branch_name
 
 HEAD is now at 427abfa Linux v2.6.17
 ------------------------------------------------
@@ -340,8 +330,7 @@ make up a name for the new branch.   You
 (or tag) for this version later if you decide to.
 
 [[examining-remote-branches]]
-Examining branches from a remote repository
--------------------------------------------
+=== Examining branches from a remote repository
 
 The "master" branch that was created at the time you cloned is a copy
 of the HEAD in the repository that you cloned from.  That repository
@@ -373,7 +362,7 @@ You might want to build on one of these
 on a branch of your own, just as you would for a tag:
 
 ------------------------------------------------
-$ git checkout -b my-todo-copy origin/todo
+$ git switch -c my-todo-copy origin/todo
 ------------------------------------------------
 
 You can also check out `origin/todo` directly to examine it or
@@ -383,8 +372,7 @@ Note that the name "origin" is just the
 to refer to the repository that you cloned from.
 
 [[how-git-stores-references]]
-Naming branches, tags, and other references
--------------------------------------------
+=== Naming branches, tags, and other references
 
 Branches, remote-tracking branches, and tags are all references to
 commits.  All references are named with a slash-separated path name
@@ -413,8 +401,7 @@ references with the same shorthand name,
 REVISIONS" section of linkgit:gitrevisions[7].
 
 [[Updating-a-repository-With-git-fetch]]
-Updating a repository with git fetch
-------------------------------------
+=== Updating a repository with git fetch
 
 After you clone a repository and commit a few changes of your own, you
 may wish to check the original repository for updates.
@@ -425,8 +412,7 @@ repository.  It will not touch any of yo
 "master" branch that was created for you on clone.
 
 [[fetching-branches]]
-Fetching branches from other repositories
------------------------------------------
+=== Fetching branches from other repositories
 
 You can also track branches from repositories other than the one you
 cloned from, using linkgit:git-remote[1]:
@@ -474,8 +460,7 @@ text editor.  (See the "CONFIGURATION FI
 linkgit:git-config[1] for details.)
 
 [[exploring-git-history]]
-Exploring Git history
-=====================
+== Exploring Git history
 
 Git is best thought of as a tool for storing the history of a
 collection of files.  It does this by storing compressed snapshots of
@@ -489,8 +474,7 @@ We start with one specialized tool that
 commit that introduced a bug into a project.
 
 [[using-bisect]]
-How to use bisect to find a regression
---------------------------------------
+=== How to use bisect to find a regression
 
 Suppose version 2.6.18 of your project worked, but the version at
 "master" crashes.  Sometimes the best way to find the cause of such a
@@ -572,8 +556,7 @@ linkgit:git-bisect[1] for more informati
 bisect` features.
 
 [[naming-commits]]
-Naming commits
---------------
+=== Naming commits
 
 We have seen several ways of naming commits already:
 
@@ -637,8 +620,7 @@ e05db0fd4f31dde7005f075a84f96b360d05984b
 -------------------------------------------------
 
 [[creating-tags]]
-Creating tags
--------------
+=== Creating tags
 
 We can also create a tag to refer to a particular commit; after
 running
@@ -655,8 +637,7 @@ should create a tag object instead; see
 for details.
 
 [[browsing-revisions]]
-Browsing revisions
-------------------
+=== Browsing revisions
 
 The linkgit:git-log[1] command can show lists of commits.  On its
 own, it shows all commits reachable from the parent commit; but you
@@ -697,8 +678,7 @@ multiple independent lines of developmen
 commits are listed in may be somewhat arbitrary.
 
 [[generating-diffs]]
-Generating diffs
-----------------
+=== Generating diffs
 
 You can generate diffs between any two versions using
 linkgit:git-diff[1]:
@@ -726,8 +706,7 @@ will generate a file with a patch for ea
 but not from master.
 
 [[viewing-old-file-versions]]
-Viewing old file versions
--------------------------
+=== Viewing old file versions
 
 You can always view an old version of a file by just checking out the
 correct revision first.  But sometimes it is more convenient to be
@@ -742,12 +721,10 @@ Before the colon may be anything that na
 may be any path to a file tracked by Git.
 
 [[history-examples]]
-Examples
---------
+=== Examples
 
 [[counting-commits-on-a-branch]]
-Counting the number of commits on a branch
-~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
+==== Counting the number of commits on a branch
 
 Suppose you want to know how many commits you've made on `mybranch`
 since it diverged from `origin`:
@@ -765,8 +742,7 @@ $ git rev-list origin..mybranch | wc -l
 -------------------------------------------------
 
 [[checking-for-equal-branches]]
-Check whether two branches point at the same history
-~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
+==== Check whether two branches point at the same history
 
 Suppose you want to check whether two branches point at the same point
 in history.
@@ -798,8 +774,7 @@ $ git log origin...master
 will return no commits when the two branches are equal.
 
 [[finding-tagged-descendants]]
-Find first tagged version including a given fix
-~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
+==== Find first tagged version including a given fix
 
 Suppose you know that the commit e05db0fd fixed a certain problem.
 You'd like to find the earliest tagged release that contains that
@@ -883,8 +858,7 @@ shows that e05db0fd is reachable from it
 and from v1.5.0-rc2, and not from v1.5.0-rc0.
 
 [[showing-commits-unique-to-a-branch]]
-Showing commits unique to a given branch
-~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
+==== Showing commits unique to a given branch
 
 Suppose you would like to see all the commits reachable from the branch
 head named `master` but not from any other head in your repository.
@@ -931,8 +905,7 @@ $ gitk $( git show-ref --heads ) --not
 syntax such as `--not`.)
 
 [[making-a-release]]
-Creating a changelog and tarball for a software release
-~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
+==== Creating a changelog and tarball for a software release
 
 The linkgit:git-archive[1] command can create a tar or zip archive from
 any version of a project; for example:
@@ -983,8 +956,7 @@ and then he just cut-and-pastes the outp
 they look OK.
 
 [[Finding-commits-With-given-Content]]
-Finding commits referencing a file with given content
-~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
+==== Finding commits referencing a file with given content
 
 Somebody hands you a copy of a file, and asks which commits modified a
 file such that it contained the given content either before or after the
@@ -1000,12 +972,10 @@ student.  The linkgit:git-log[1], linkgi
 linkgit:git-hash-object[1] man pages may prove helpful.
 
 [[Developing-With-git]]
-Developing with Git
-===================
+== Developing with Git
 
 [[telling-git-your-name]]
-Telling Git your name
----------------------
+=== Telling Git your name
 
 Before creating any commits, you should introduce yourself to Git.
 The easiest way to do so is to use linkgit:git-config[1]:
@@ -1030,8 +1000,7 @@ also edit it with your favorite editor.
 
 
 [[creating-a-new-repository]]
-Creating a new repository
--------------------------
+=== Creating a new repository
 
 Creating a new repository from scratch is very easy:
 
@@ -1052,8 +1021,7 @@ $ git commit
 -------------------------------------------------
 
 [[how-to-make-a-commit]]
-How to make a commit
---------------------
+=== How to make a commit
 
 Creating a new commit takes three steps:
 
@@ -1148,8 +1116,7 @@ for inclusion in the index (by right-cli
 choosing "Stage Hunk For Commit").
 
 [[creating-good-commit-messages]]
-Creating good commit messages
------------------------------
+=== Creating good commit messages
 
 Though not required, it's a good idea to begin the commit message
 with a single short (less than 50 character) line summarizing the
@@ -1162,8 +1129,7 @@ rest of the commit in the body.
 
 
 [[ignoring-files]]
-Ignoring files
---------------
+=== Ignoring files
 
 A project will often generate files that you do 'not' want to track with Git.
 This typically includes files generated by a build process or temporary
@@ -1205,8 +1171,7 @@ Some Git commands can also take exclude
 command line.  See linkgit:gitignore[5] for the details.
 
 [[how-to-merge]]
-How to merge
-------------
+=== How to merge
 
 You can rejoin two diverging branches of development using
 linkgit:git-merge[1]:
@@ -1254,8 +1219,7 @@ has two parents, one pointing to the top
 one to the top of the other branch.
 
 [[resolving-a-merge]]
-Resolving a merge
------------------
+=== Resolving a merge
 
 When a merge isn't resolved automatically, Git leaves the index and
 the working tree in a special state that gives you all the
@@ -1297,8 +1261,7 @@ The above is all you need to know to res
 also provides more information to help resolve conflicts:
 
 [[conflict-resolution]]
-Getting conflict-resolution help during a merge
-~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
+==== Getting conflict-resolution help during a merge
 
 All of the changes that Git was able to merge automatically are
 already added to the index file, so linkgit:git-diff[1] shows only
@@ -1401,14 +1364,13 @@ the different stages of that file will b
 `git diff` will (by default) no longer show diffs for that file.
 
 [[undoing-a-merge]]
-Undoing a merge
----------------
+=== Undoing a merge
 
 If you get stuck and decide to just give up and throw the whole mess
 away, you can always return to the pre-merge state with
 
 -------------------------------------------------
-$ git reset --hard HEAD
+$ git merge --abort
 -------------------------------------------------
 
 Or, if you've already committed the merge that you want to throw away,
@@ -1423,8 +1385,7 @@ itself have been merged into another bra
 further merges.
 
 [[fast-forwards]]
-Fast-forward merges
--------------------
+=== Fast-forward merges
 
 There is one special case not mentioned above, which is treated
 differently.  Normally, a merge results in a merge commit, with two
@@ -1438,15 +1399,14 @@ to point at the head of the merged-in br
 created.
 
 [[fixing-mistakes]]
-Fixing mistakes
----------------
+=== Fixing mistakes
 
 If you've messed up the working tree, but haven't yet committed your
 mistake, you can return the entire working tree to the last committed
 state with
 
 -------------------------------------------------
-$ git reset --hard HEAD
+$ git restore --staged --worktree :/
 -------------------------------------------------
 
 If you make a commit that you later wish you hadn't, there are two
@@ -1463,8 +1423,7 @@ fundamentally different ways to fix the
 	a branch that has had its history changed.
 
 [[reverting-a-commit]]
-Fixing a mistake with a new commit
-~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
+==== Fixing a mistake with a new commit
 
 Creating a new commit that reverts an earlier change is very easy;
 just pass the linkgit:git-revert[1] command a reference to the bad
@@ -1490,8 +1449,7 @@ conflicts manually, just as in the case
 resolving a merge>>.
 
 [[fixing-a-mistake-by-rewriting-history]]
-Fixing a mistake by rewriting history
-~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
+==== Fixing a mistake by rewriting history
 
 If the problematic commit is the most recent commit, and you have not
 yet made that commit public, then you may just
@@ -1518,17 +1476,14 @@ this is an advanced topic to be left for
 <<cleaning-up-history,another chapter>>.
 
 [[checkout-of-path]]
-Checking out an old version of a file
-~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
+==== Checking out an old version of a file
 
 In the process of undoing a previous bad change, you may find it
 useful to check out an older version of a particular file using
-linkgit:git-checkout[1].  We've used `git checkout` before to switch
-branches, but it has quite different behavior if it is given a path
-name: the command
+linkgit:git-restore[1]. The command
 
 -------------------------------------------------
-$ git checkout HEAD^ path/to/file
+$ git restore --source=HEAD^ path/to/file
 -------------------------------------------------
 
 replaces path/to/file by the contents it had in the commit HEAD^, and
@@ -1545,8 +1500,7 @@ $ git show HEAD^:path/to/file
 which will display the given version of the file.
 
 [[interrupted-work]]
-Temporarily setting aside work in progress
-~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
+==== Temporarily setting aside work in progress
 
 While you are in the middle of working on something complicated, you
 find an unrelated but obvious and trivial bug.  You would like to fix it
@@ -1577,8 +1531,7 @@ $ git stash pop
 
 
 [[ensuring-good-performance]]
-Ensuring good performance
--------------------------
+=== Ensuring good performance
 
 On large repositories, Git depends on compression to keep the history
 information from taking up too much space on disk or in memory.  Some
@@ -1589,12 +1542,10 @@ to avoid automatic compression kicking i
 
 
 [[ensuring-reliability]]
-Ensuring reliability
---------------------
+=== Ensuring reliability
 
 [[checking-for-corruption]]
-Checking the repository for corruption
-~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
+==== Checking the repository for corruption
 
 The linkgit:git-fsck[1] command runs a number of self-consistency checks
 on the repository, and reports on any problems.  This may take some
@@ -1620,12 +1571,10 @@ You can run `git fsck --no-dangling` to
 view real errors.
 
 [[recovering-lost-changes]]
-Recovering lost changes
-~~~~~~~~~~~~~~~~~~~~~~~
+==== Recovering lost changes
 
 [[reflogs]]
-Reflogs
-^^^^^^^
+===== Reflogs
 
 Say you modify a branch with <<fixing-mistakes,`git reset --hard`>>,
 and then realize that the branch was the only reference you had to
@@ -1672,8 +1621,7 @@ same project, the reflog history is not
 how the branches in your local repository have changed over time.
 
 [[dangling-object-recovery]]
-Examining dangling objects
-^^^^^^^^^^^^^^^^^^^^^^^^^^
+===== Examining dangling objects
 
 In some situations the reflog may not be able to save you.  For example,
 suppose you delete a branch, then realize you need the history it
@@ -1717,12 +1665,10 @@ dangling objects can arise in other situ
 
 
 [[sharing-development]]
-Sharing development with others
-===============================
+== Sharing development with others
 
 [[getting-updates-With-git-pull]]
-Getting updates with git pull
------------------------------
+=== Getting updates with git pull
 
 After you clone a repository and commit a few changes of your own, you
 may wish to check the original repository for updates and merge them
@@ -1785,8 +1731,7 @@ $ git merge branch
 are roughly equivalent.
 
 [[submitting-patches]]
-Submitting patches to a project
--------------------------------
+=== Submitting patches to a project
 
 If you just have a few changes, the simplest way to submit them may
 just be to send them as patches in email:
@@ -1814,8 +1759,7 @@ Consult the mailing list for your projec
 their requirements for submitting patches.
 
 [[importing-patches]]
-Importing patches to a project
-------------------------------
+=== Importing patches to a project
 
 Git also provides a tool called linkgit:git-am[1] (am stands for
 "apply mailbox"), for importing such an emailed series of patches.
@@ -1847,8 +1791,7 @@ the original mailbox, with authorship an
 taken from the message containing each patch.
 
 [[public-repositories]]
-Public Git repositories
------------------------
+=== Public Git repositories
 
 Another way to submit changes to a project is to tell the maintainer
 of that project to pull the changes from your repository using
@@ -1888,21 +1831,22 @@ pull from that repository.  So the flow
 where there is one other developer with a public repository, looks
 like this:
 
-                        you push
-  your personal repo ------------------> your public repo
-	^                                     |
-	|                                     |
-	| you pull                            | they pull
-	|                                     |
-	|                                     |
-        |               they push             V
-  their public repo <------------------- their repo
+....
+		      you push
+your personal repo ------------------> your public repo
+      ^                                     |
+      |                                     |
+      | you pull                            | they pull
+      |                                     |
+      |                                     |
+      |               they push             V
+their public repo <------------------- their repo
+....
 
 We explain how to do this in the following sections.
 
 [[setting-up-a-public-repository]]
-Setting up a public repository
-~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
+==== Setting up a public repository
 
 Assume your personal repository is in the directory `~/proj`.  We
 first create a new clone of the repository and tell `git daemon` that it
@@ -1922,8 +1866,7 @@ public repository.  You can use scp, rsy
 convenient.
 
 [[exporting-via-git]]
-Exporting a Git repository via the Git protocol
-~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
+==== Exporting a Git repository via the Git protocol
 
 This is the preferred method.
 
@@ -1944,8 +1887,7 @@ linkgit:git-daemon[1] man page for detai
 examples section.)
 
 [[exporting-via-http]]
-Exporting a git repository via HTTP
-~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
+==== Exporting a git repository via HTTP
 
 The Git protocol gives better performance and reliability, but on a
 host with a web server set up, HTTP exports may be simpler to set up.
@@ -1977,8 +1919,7 @@ for a slightly more sophisticated setup
 allows pushing over HTTP.)
 
 [[pushing-changes-to-a-public-repository]]
-Pushing changes to a public repository
-~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
+==== Pushing changes to a public repository
 
 Note that the two techniques outlined above (exporting via
 <<exporting-via-http,http>> or <<exporting-via-git,git>>) allow other
@@ -2037,8 +1978,7 @@ See the explanations of the `remote.<nam
 linkgit:git-config[1] for details.
 
 [[forcing-push]]
-What to do when a push fails
-~~~~~~~~~~~~~~~~~~~~~~~~~~~~
+==== What to do when a push fails
 
 If a push would not result in a <<fast-forwards,fast-forward>> of the
 remote branch, then it will fail with an error like:
@@ -2092,8 +2032,7 @@ pull, or by a fetch followed by a rebase
 linkgit:gitcvs-migration[7] for more.
 
 [[setting-up-a-shared-repository]]
-Setting up a shared repository
-~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
+==== Setting up a shared repository
 
 Another way to collaborate is by using a model similar to that
 commonly used in CVS, where several developers with special rights
@@ -2123,8 +2062,7 @@ advantages over the central shared repos
 	  "out".
 
 [[setting-up-gitweb]]
-Allowing web browsing of a repository
-~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
+==== Allowing web browsing of a repository
 
 The gitweb cgi script provides users an easy way to browse your
 project's revisions, file contents and logs without having to install
@@ -2140,8 +2078,7 @@ linkgit:gitweb[1] for instructions on de
 installation with a CGI or Perl capable server.
 
 [[how-to-get-a-git-repository-with-minimal-history]]
-How to get a Git repository with minimal history
-------------------------------------------------
+=== How to get a Git repository with minimal history
 
 A <<def_shallow_clone,shallow clone>>, with its truncated
 history, is useful when one is interested only in recent history
@@ -2160,12 +2097,10 @@ have to result in huge conflicts.  This
 a repository unsuitable to be used in merge based workflows.
 
 [[sharing-development-examples]]
-Examples
---------
+=== Examples
 
 [[maintaining-topic-branches]]
-Maintaining topic branches for a Linux subsystem maintainer
-~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
+==== Maintaining topic branches for a Linux subsystem maintainer
 
 This describes how Tony Luck uses Git in his role as maintainer of the
 IA64 architecture for the Linux kernel.
@@ -2211,8 +2146,8 @@ $ git branch --track release origin/mast
 These can be easily kept up to date using linkgit:git-pull[1].
 
 -------------------------------------------------
-$ git checkout test && git pull
-$ git checkout release && git pull
+$ git switch test && git pull
+$ git switch release && git pull
 -------------------------------------------------
 
 Important note!  If you have any local changes in these branches, then
@@ -2264,7 +2199,7 @@ tested changes
 2) help future bug hunters that use `git bisect` to find problems
 
 -------------------------------------------------
-$ git checkout -b speed-up-spinlocks v2.6.35
+$ git switch -c speed-up-spinlocks v2.6.35
 -------------------------------------------------
 
 Now you apply the patch(es), run some tests, and commit the change(s).  If
@@ -2279,7 +2214,7 @@ When you are happy with the state of thi
 "test" branch in preparation to make it public:
 
 -------------------------------------------------
-$ git checkout test && git merge speed-up-spinlocks
+$ git switch test && git merge speed-up-spinlocks
 -------------------------------------------------
 
 It is unlikely that you would have any conflicts here ... but you might if you
@@ -2291,7 +2226,7 @@ see the value of keeping each patch (or
 means that the patches can be moved into the `release` tree in any order.
 
 -------------------------------------------------
-$ git checkout release && git merge speed-up-spinlocks
+$ git switch release && git merge speed-up-spinlocks
 -------------------------------------------------
 
 After a while, you will have a number of branches, and despite the
@@ -2461,8 +2396,7 @@ done
 
 
 [[cleaning-up-history]]
-Rewriting history and maintaining patch series
-==============================================
+== Rewriting history and maintaining patch series
 
 Normally commits are only added to a project, never taken away or
 replaced.  Git is designed with this assumption, and violating it will
@@ -2472,8 +2406,7 @@ However, there is a situation in which i
 assumption.
 
 [[patch-series]]
-Creating the perfect patch series
----------------------------------
+=== Creating the perfect patch series
 
 Suppose you are a contributor to a large project, and you want to add a
 complicated feature, and to present it to the other developers in a way
@@ -2505,14 +2438,13 @@ use them, and then explain some of the p
 you are rewriting history.
 
 [[using-git-rebase]]
-Keeping a patch series up to date using git rebase
---------------------------------------------------
+=== Keeping a patch series up to date using git rebase
 
 Suppose that you create a branch `mywork` on a remote-tracking branch
 `origin`, and create some commits on top of it:
 
 -------------------------------------------------
-$ git checkout -b mywork origin
+$ git switch -c mywork origin
 $ vi file.txt
 $ git commit
 $ vi otherfile.txt
@@ -2552,7 +2484,7 @@ commits without any merges, you may inst
 linkgit:git-rebase[1]:
 
 -------------------------------------------------
-$ git checkout mywork
+$ git switch mywork
 $ git rebase origin
 -------------------------------------------------
 
@@ -2593,8 +2525,7 @@ the rebase.  See <<interactive-rebase>>
 <<reordering-patch-series>> for alternatives.
 
 [[rewriting-one-commit]]
-Rewriting a single commit
--------------------------
+=== Rewriting a single commit
 
 We saw in <<fixing-a-mistake-by-rewriting-history>> that you can replace the
 most recent commit using
@@ -2612,8 +2543,7 @@ If you need to amend commits from deeper
 use <<interactive-rebase,interactive rebase's `edit` instruction>>.
 
 [[reordering-patch-series]]
-Reordering or selecting from a patch series
--------------------------------------------
+=== Reordering or selecting from a patch series
 
 Sometimes you want to edit a commit deeper in your history.  One
 approach is to use `git format-patch` to create a series of patches
@@ -2632,8 +2562,7 @@ $ git am *.patch
 -------------------------------------------------
 
 [[interactive-rebase]]
-Using interactive rebases
--------------------------
+=== Using interactive rebases
 
 You can also edit a patch series with an interactive rebase.  This is
 the same as <<reordering-patch-series,reordering a patch series using
@@ -2690,16 +2619,14 @@ For a more detailed discussion of the pr
 see the "INTERACTIVE MODE" section of linkgit:git-rebase[1].
 
 [[patch-series-tools]]
-Other tools
------------
+=== Other tools
 
 There are numerous other tools, such as StGit, which exist for the
 purpose of maintaining a patch series.  These are outside of the scope of
 this manual.
 
 [[problems-With-rewriting-history]]
-Problems with rewriting history
--------------------------------
+=== Problems with rewriting history
 
 The primary problem with rewriting the history of a branch has to do
 with merging.  Suppose somebody fetches your branch and merges it into
@@ -2747,8 +2674,7 @@ For true distributed development that su
 published branches should never be rewritten.
 
 [[bisect-merges]]
-Why bisecting merge commits can be harder than bisecting linear history
------------------------------------------------------------------------
+=== Why bisecting merge commits can be harder than bisecting linear history
 
 The linkgit:git-bisect[1] command correctly handles history that
 includes merge commits.  However, when the commit that it finds is a
@@ -2813,12 +2739,10 @@ linear by rebasing against the latest up
 publishing.
 
 [[advanced-branch-management]]
-Advanced branch management
-==========================
+== Advanced branch management
 
 [[fetching-individual-branches]]
-Fetching individual branches
-----------------------------
+=== Fetching individual branches
 
 Instead of using linkgit:git-remote[1], you can also choose just
 to update one branch at a time, and to store it locally under an
@@ -2846,8 +2770,7 @@ already have a branch named example-mast
 master branch.  In more detail:
 
 [[fetch-fast-forwards]]
-git fetch and fast-forwards
----------------------------
+=== git fetch and fast-forwards
 
 In the previous example, when updating an existing branch, `git fetch`
 checks to make sure that the most recent commit on the remote
@@ -2884,8 +2807,7 @@ unless you've already created a referenc
 them.
 
 [[forcing-fetch]]
-Forcing git fetch to do non-fast-forward updates
-------------------------------------------------
+=== Forcing git fetch to do non-fast-forward updates
 
 If git fetch fails because the new head of a branch is not a
 descendant of the old head, you may force the update with:
@@ -2905,8 +2827,7 @@ Be aware that commits that the old versi
 may be lost, as we saw in the previous section.
 
 [[remote-branch-configuration]]
-Configuring remote-tracking branches
-------------------------------------
+=== Configuring remote-tracking branches
 
 We saw above that `origin` is just a shortcut to refer to the
 repository that you originally cloned from.  This information is
@@ -2957,8 +2878,7 @@ the refspec syntax.
 
 
 [[git-concepts]]
-Git concepts
-============
+== Git concepts
 
 Git is built on a small number of simple but powerful ideas.  While it
 is possible to get things done without understanding them, you will find
@@ -2968,8 +2888,7 @@ We start with the most important, the  <
 database>> and the <<def_index,index>>.
 
 [[the-object-database]]
-The Object Database
--------------------
+=== The Object Database
 
 
 We already saw in <<understanding-commits>> that all commits are stored
@@ -3013,8 +2932,7 @@ There are four different types of object
 The object types in some more detail:
 
 [[commit-object]]
-Commit Object
-~~~~~~~~~~~~~
+==== Commit Object
 
 The "commit" object links a physical state of a tree with a description
 of how we got there and why.  Use the `--pretty=raw` option to
@@ -3066,8 +2984,7 @@ commit whose parent is normally the curr
 taken from the content currently stored in the index.
 
 [[tree-object]]
-Tree Object
-~~~~~~~~~~~
+==== Tree Object
 
 The ever-versatile linkgit:git-show[1] command can also be used to
 examine tree objects, but linkgit:git-ls-tree[1] will give you more
@@ -3106,8 +3023,7 @@ Note that the files all have mode 644 or
 attention to the executable bit.
 
 [[blob-object]]
-Blob Object
-~~~~~~~~~~~
+==== Blob Object
 
 You can use linkgit:git-show[1] to examine the contents of a blob; take,
 for example, the blob in the entry for `COPYING` from the tree above:
@@ -3136,8 +3052,7 @@ sometimes be useful for browsing the con
 currently checked out.
 
 [[trust]]
-Trust
-~~~~~
+==== Trust
 
 If you receive the SHA-1 name of a blob from one source, and its contents
 from another (possibly untrusted) source, you can still trust that those
@@ -3166,8 +3081,7 @@ like GPG/PGP.
 To assist in this, Git also provides the tag object...
 
 [[tag-object]]
-Tag Object
-~~~~~~~~~~
+==== Tag Object
 
 A tag object contains an object, object type, tag name, the name of the
 person ("tagger") who created the tag, and a message, which may contain
@@ -3196,8 +3110,7 @@ objects.  (Note that linkgit:git-tag[1]
 references whose names begin with `refs/tags/`).
 
 [[pack-files]]
-How Git stores objects efficiently: pack files
-~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
+==== How Git stores objects efficiently: pack files
 
 Newly created objects are initially created in a file named after the
 object's SHA-1 hash (stored in `.git/objects`).
@@ -3255,8 +3168,7 @@ The linkgit:git-gc[1] command performs p
 you, so is normally the only high-level command you need.
 
 [[dangling-objects]]
-Dangling objects
-~~~~~~~~~~~~~~~~
+==== Dangling objects
 
 The linkgit:git-fsck[1] command will sometimes complain about dangling
 objects.  They are not a problem.
@@ -3336,8 +3248,7 @@ don't want to do that while the filesyst
 accesses to a repository but you might receive confusing or scary messages.)
 
 [[recovering-from-repository-corruption]]
-Recovering from repository corruption
-~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
+==== Recovering from repository corruption
 
 By design, Git treats data trusted to it with caution.  However, even in
 the absence of bugs in Git itself, it is still possible that hardware or
@@ -3454,8 +3365,7 @@ whole thing. It's up to you--Git does *h
 just missing one particular blob version.
 
 [[the-index]]
-The index
----------
+=== The index
 
 The index is a binary file (generally kept in `.git/index`) containing a
 sorted list of path names, each with permissions and the SHA-1 of a blob
@@ -3513,8 +3423,7 @@ If you blow the index away entirely, you
 information as long as you have the name of the tree that it described.
 
 [[submodules]]
-Submodules
-==========
+== Submodules
 
 Large projects are often composed of smaller, self-contained modules.  For
 example, an embedded Linux distribution's source tree would include every
@@ -3668,13 +3577,13 @@ change within the submodule, and then up
 new commit:
 
 -------------------------------------------------
-$ git checkout master
+$ git switch master
 -------------------------------------------------
 
 or
 
 -------------------------------------------------
-$ git checkout -b fix-up
+$ git switch -c fix-up
 -------------------------------------------------
 
 then
@@ -3700,8 +3609,8 @@ $ git push
 You have to run `git submodule update` after `git pull` if you want to update
 submodules, too.
 
-Pitfalls with submodules
-------------------------
+[[pitfalls-with-submodules]]
+=== Pitfalls with submodules
 
 Always publish the submodule change before publishing the change to the
 superproject that references it. If you forget to publish the submodule change,
@@ -3770,8 +3679,7 @@ submodule update` will not overwrite the
 warning about not being able switch from a dirty branch.
 
 [[low-level-operations]]
-Low-level Git operations
-========================
+== Low-level Git operations
 
 Many of the higher-level commands were originally implemented as shell
 scripts using a smaller core of low-level Git commands.  These can still
@@ -3779,8 +3687,7 @@ be useful when doing unusual things with
 understand its inner workings.
 
 [[object-manipulation]]
-Object access and manipulation
-------------------------------
+=== Object access and manipulation
 
 The linkgit:git-cat-file[1] command can show the contents of any object,
 though the higher-level linkgit:git-show[1] is usually more useful.
@@ -3797,11 +3704,10 @@ verified by linkgit:git-verify-tag[1], t
 use linkgit:git-tag[1] for both.
 
 [[the-workflow]]
-The Workflow
-------------
+=== The Workflow
 
-High-level operations such as linkgit:git-commit[1],
-linkgit:git-checkout[1] and linkgit:git-reset[1] work by moving data
+High-level operations such as linkgit:git-commit[1] and
+linkgit:git-restore[1] work by moving data
 between the working tree, the index, and the object database.  Git
 provides low-level operations which perform each of these steps
 individually.
@@ -3813,8 +3719,7 @@ the database or the working directory. T
 combinations:
 
 [[working-directory-to-index]]
-working directory -> index
-~~~~~~~~~~~~~~~~~~~~~~~~~~
+==== working directory -> index
 
 The linkgit:git-update-index[1] command updates the index with
 information from the working directory.  You generally update the
@@ -3850,8 +3755,7 @@ The previously introduced linkgit:git-ad
 linkgit:git-update-index[1].
 
 [[index-to-object-database]]
-index -> object database
-~~~~~~~~~~~~~~~~~~~~~~~~
+==== index -> object database
 
 You write your current index file to a "tree" object with the program
 
@@ -3866,8 +3770,7 @@ use that tree to re-generate the index a
 other direction:
 
 [[object-database-to-index]]
-object database -> index
-~~~~~~~~~~~~~~~~~~~~~~~~
+==== object database -> index
 
 You read a "tree" file from the object database, and use that to
 populate (and overwrite--don't do this if your index contains any
@@ -3883,8 +3786,7 @@ earlier. However, that is only your 'ind
 directory contents have not been modified.
 
 [[index-to-working-directory]]
-index -> working directory
-~~~~~~~~~~~~~~~~~~~~~~~~~~
+==== index -> working directory
 
 You update your working directory from the index by "checking out"
 files. This is not a very common operation, since normally you'd just
@@ -3913,8 +3815,7 @@ Finally, there are a few odds and ends w
 from one representation to the other:
 
 [[tying-it-all-together]]
-Tying it all together
-~~~~~~~~~~~~~~~~~~~~~
+==== Tying it all together
 
 To commit a tree you have instantiated with `git write-tree`, you'd
 create a "commit" object that refers to that tree and the history
@@ -3988,8 +3889,7 @@ Here is a picture that illustrates how v
 
 
 [[examining-the-data]]
-Examining the data
-------------------
+=== Examining the data
 
 You can examine the data represented in the object database and the
 index with various helper tools. For every object, you can use
@@ -4024,8 +3924,7 @@ $ git cat-file commit HEAD
 to see what the top commit was.
 
 [[merging-multiple-trees]]
-Merging multiple trees
-----------------------
+=== Merging multiple trees
 
 Git can help you perform a three-way merge, which can in turn be
 used for a many-way merge by repeating the merge procedure several
@@ -4075,8 +3974,7 @@ index file, and you can just write the r
 
 
 [[merging-multiple-trees-2]]
-Merging multiple trees, continued
----------------------------------
+=== Merging multiple trees, continued
 
 Sadly, many merges aren't trivial. If there are files that have
 been added, moved or removed, or if both branches have modified the
@@ -4146,15 +4044,13 @@ $ git merge-index git-merge-one-file hel
 and that is what higher level `git merge -s resolve` is implemented with.
 
 [[hacking-git]]
-Hacking Git
-===========
+== Hacking Git
 
 This chapter covers internal details of the Git implementation which
 probably only Git developers need to understand.
 
 [[object-details]]
-Object storage format
----------------------
+=== Object storage format
 
 All objects have a statically determined "type" which identifies the
 format of the object (i.e. how it is used, and how it can refer to other
@@ -4184,8 +4080,7 @@ of all objects, and verifies their inter
 to just verifying their superficial consistency through the hash).
 
 [[birdview-on-the-source-code]]
-A birds-eye view of Git's source code
--------------------------------------
+=== A birds-eye view of Git's source code
 
 It is not always easy for new developers to find their way through Git's
 source code.  This section gives you a little guidance to show where to
@@ -4194,7 +4089,7 @@ start.
 A good place to start is with the contents of the initial commit, with:
 
 ----------------------------------------------------
-$ git checkout e83c5163
+$ git switch --detach e83c5163
 ----------------------------------------------------
 
 The initial revision lays the foundation for almost everything Git has
@@ -4394,25 +4289,22 @@ You see, Git is actually the best tool t
 itself!
 
 [[glossary]]
-Git Glossary
-============
+== Git Glossary
 
 [[git-explained]]
-Git explained
--------------
+=== Git explained
 
 include::glossary-content.txt[]
 
 [[git-quick-start]]
-Appendix A: Git Quick Reference
-===============================
+[appendix]
+== Git Quick Reference
 
 This is a quick summary of the major commands; the previous chapters
 explain how these work in more detail.
 
 [[quick-creating-a-new-repository]]
-Creating a new repository
--------------------------
+=== Creating a new repository
 
 From a tarball:
 
@@ -4433,14 +4325,13 @@ $ cd project
 -----------------------------------------------
 
 [[managing-branches]]
-Managing branches
------------------
+=== Managing branches
 
 -----------------------------------------------
-$ git branch	     # list all local branches in this repo
-$ git checkout test  # switch working directory to branch "test"
-$ git branch new     # create branch "new" starting at current HEAD
-$ git branch -d new  # delete branch "new"
+$ git branch			# list all local branches in this repo
+$ git switch test	        # switch working directory to branch "test"
+$ git branch new		# create branch "new" starting at current HEAD
+$ git branch -d new		# delete branch "new"
 -----------------------------------------------
 
 Instead of basing a new branch on current HEAD (the default), use:
@@ -4456,7 +4347,7 @@ $ git branch new test~10 # ten commits b
 Create and switch to a new branch at the same time:
 
 -----------------------------------------------
-$ git checkout -b new v2.6.15
+$ git switch -c new v2.6.15
 -----------------------------------------------
 
 Update and examine branches from the repository you cloned from:
@@ -4467,7 +4358,7 @@ $ git branch -r		# list
   origin/master
   origin/next
   ...
-$ git checkout -b masterwork origin/master
+$ git switch -c masterwork origin/master
 -----------------------------------------------
 
 Fetch a branch from a different repository, and give it a new
@@ -4498,8 +4389,7 @@ $ git branch -r			# list all remote bran
 
 
 [[exploring-history]]
-Exploring history
------------------
+=== Exploring history
 
 -----------------------------------------------
 $ gitk			    # visualize and browse history
@@ -4534,8 +4424,7 @@ $ git bisect bad		# if this revision is
 -----------------------------------------------
 
 [[making-changes]]
-Making changes
---------------
+=== Making changes
 
 Make sure Git knows who to blame:
 
@@ -4565,8 +4454,7 @@ $ git commit -a	   # use latest content
 -----------------------------------------------
 
 [[merging]]
-Merging
--------
+=== Merging
 
 -----------------------------------------------
 $ git merge test   # merge branch "test" into the current branch
@@ -4576,8 +4464,7 @@ $ git pull . test  # equivalent to git m
 -----------------------------------------------
 
 [[sharing-your-changes]]
-Sharing your changes
---------------------
+=== Sharing your changes
 
 Importing or exporting patches:
 
@@ -4622,8 +4509,7 @@ $ git push example test
 -----------------------------------------------
 
 [[repository-maintenance]]
-Repository maintenance
-----------------------
+=== Repository maintenance
 
 Check for corruption:
 
@@ -4639,12 +4525,11 @@ $ git gc
 
 
 [[todo]]
-Appendix B: Notes and todo list for this manual
-===============================================
+[appendix]
+== Notes and todo list for this manual
 
 [[todo-list]]
-Todo list
----------
+=== Todo list
 
 This is a work in progress.
 
@@ -4689,5 +4574,5 @@ Write a chapter on using plumbing and wr
 Alternates, clone -reference, etc.
 
 More on recovery from repository corruption.  See:
-	http://marc.info/?l=git&m=117263864820799&w=2
-	http://marc.info/?l=git&m=117147855503798&w=2
+	https://lore.kernel.org/git/Pine.LNX.4.64.0702272039540.12485@woody.linux-foundation.org/
+	https://lore.kernel.org/git/Pine.LNX.4.64.0702141033400.3604@woody.linux-foundation.org/
diff -pruN 1.2.1+git2.18.0-1/git/editor.c 1.2.3+git2.25.1-1/git/editor.c
--- 1.2.1+git2.18.0-1/git/editor.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/editor.c	2020-02-17 04:47:35.000000000 +0000
@@ -1,4 +1,5 @@
 #include "cache.h"
+#include "config.h"
 #include "strbuf.h"
 #include "run-command.h"
 #include "sigchain.h"
@@ -34,10 +35,21 @@ const char *git_editor(void)
 	return editor;
 }
 
-int launch_editor(const char *path, struct strbuf *buffer, const char *const *env)
+const char *git_sequence_editor(void)
 {
-	const char *editor = git_editor();
+	const char *editor = getenv("GIT_SEQUENCE_EDITOR");
+
+	if (!editor)
+		git_config_get_string_const("sequence.editor", &editor);
+	if (!editor)
+		editor = git_editor();
 
+	return editor;
+}
+
+static int launch_specified_editor(const char *editor, const char *path,
+				   struct strbuf *buffer, const char *const *env)
+{
 	if (!editor)
 		return error("Terminal is dumb, but EDITOR unset");
 
@@ -66,6 +78,7 @@ int launch_editor(const char *path, stru
 		p.argv = args;
 		p.env = env;
 		p.use_shell = 1;
+		p.trace2_child_class = "editor";
 		if (start_command(&p) < 0)
 			return error("unable to start editor '%s'", editor);
 
@@ -83,10 +96,10 @@ int launch_editor(const char *path, stru
 
 		if (print_waiting_for_editor && !is_terminal_dumb())
 			/*
-			 * Go back to the beginning and erase the entire line to
-			 * avoid wasting the vertical space.
+			 * Erase the entire line to avoid wasting the
+			 * vertical space.
 			 */
-			fputs("\r\033[K", stderr);
+			term_clear_line();
 	}
 
 	if (!buffer)
@@ -95,3 +108,14 @@ int launch_editor(const char *path, stru
 		return error_errno("could not read file '%s'", path);
 	return 0;
 }
+
+int launch_editor(const char *path, struct strbuf *buffer, const char *const *env)
+{
+	return launch_specified_editor(git_editor(), path, buffer, env);
+}
+
+int launch_sequence_editor(const char *path, struct strbuf *buffer,
+			   const char *const *env)
+{
+	return launch_specified_editor(git_sequence_editor(), path, buffer, env);
+}
diff -pruN 1.2.1+git2.18.0-1/git/.editorconfig 1.2.3+git2.25.1-1/git/.editorconfig
--- 1.2.1+git2.18.0-1/git/.editorconfig	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/.editorconfig	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,16 @@
+[*]
+charset = utf-8
+insert_final_newline = true
+
+# The settings for C (*.c and *.h) files are mirrored in .clang-format.  Keep
+# them in sync.
+[*.{c,h,sh,perl,pl,pm}]
+indent_style = tab
+tab_width = 8
+
+[*.py]
+indent_style = space
+indent_size = 4
+
+[COMMIT_EDITMSG]
+max_line_length = 72
diff -pruN 1.2.1+git2.18.0-1/git/entry.c 1.2.3+git2.25.1-1/git/entry.c
--- 1.2.1+git2.18.0-1/git/entry.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/entry.c	2020-02-17 04:47:35.000000000 +0000
@@ -1,5 +1,6 @@
 #include "cache.h"
 #include "blob.h"
+#include "object-store.h"
 #include "dir.h"
 #include "streaming.h"
 #include "submodule.h"
@@ -160,7 +161,7 @@ static int remove_available_paths(struct
 	return !available;
 }
 
-int finish_delayed_checkout(struct checkout *state)
+int finish_delayed_checkout(struct checkout *state, int *nr_checkouts)
 {
 	int errs = 0;
 	unsigned delayed_object_count;
@@ -225,7 +226,7 @@ int finish_delayed_checkout(struct check
 				ce = index_file_exists(state->istate, path->string,
 						       strlen(path->string), 0);
 				if (ce) {
-					errs |= checkout_entry(ce, state, NULL);
+					errs |= checkout_entry(ce, state, NULL, nr_checkouts);
 					filtered_bytes += ce->ce_stat_data.sd_size;
 					display_throughput(progress, filtered_bytes);
 				} else
@@ -265,7 +266,7 @@ static int write_entry(struct cache_entr
 	const struct submodule *sub;
 
 	if (ce_mode_s_ifmt == S_IFREG) {
-		struct stream_filter *filter = get_stream_filter(ce->name,
+		struct stream_filter *filter = get_stream_filter(state->istate, ce->name,
 								 &ce->oid);
 		if (filter &&
 		    !streaming_write_entry(ce, path, filter,
@@ -313,14 +314,14 @@ static int write_entry(struct cache_entr
 		 * Convert from git internal format to working tree format
 		 */
 		if (dco && dco->state != CE_NO_DELAY) {
-			ret = async_convert_to_working_tree(ce->name, new_blob,
+			ret = async_convert_to_working_tree(state->istate, ce->name, new_blob,
 							    size, &buf, dco);
 			if (ret && string_list_has_string(&dco->paths, ce->name)) {
 				free(new_blob);
 				goto delayed;
 			}
 		} else
-			ret = convert_to_working_tree(ce->name, new_blob, size, &buf);
+			ret = convert_to_working_tree(state->istate, ce->name, new_blob, size, &buf);
 
 		if (ret) {
 			free(new_blob);
@@ -372,7 +373,7 @@ finish:
 			if (lstat(ce->name, &st) < 0)
 				return error_errno("unable to stat just-written file %s",
 						   ce->name);
-		fill_stat_cache_info(ce, &st);
+		fill_stat_cache_info(state->istate, ce, &st);
 		ce->ce_flags |= CE_UPDATE_IN_BASE;
 		mark_fsmonitor_invalid(state->istate, ce);
 		state->istate->cache_changed |= CE_ENTRY_CHANGED;
@@ -398,6 +399,34 @@ static int check_path(const char *path,
 	return lstat(path, st);
 }
 
+static void mark_colliding_entries(const struct checkout *state,
+				   struct cache_entry *ce, struct stat *st)
+{
+	int i, trust_ino = check_stat;
+
+#if defined(GIT_WINDOWS_NATIVE) || defined(__CYGWIN__)
+	trust_ino = 0;
+#endif
+
+	ce->ce_flags |= CE_MATCHED;
+
+	for (i = 0; i < state->istate->cache_nr; i++) {
+		struct cache_entry *dup = state->istate->cache[i];
+
+		if (dup == ce)
+			break;
+
+		if (dup->ce_flags & (CE_MATCHED | CE_VALID | CE_SKIP_WORKTREE))
+			continue;
+
+		if ((trust_ino && !match_stat_data(&dup->ce_stat_data, st)) ||
+		    (!trust_ino && !fspathcmp(ce->name, dup->name))) {
+			dup->ce_flags |= CE_MATCHED;
+			break;
+		}
+	}
+}
+
 /*
  * Write the contents from ce out to the working tree.
  *
@@ -406,12 +435,23 @@ static int check_path(const char *path,
  * its name is returned in topath[], which must be able to hold at
  * least TEMPORARY_FILENAME_LENGTH bytes long.
  */
-int checkout_entry(struct cache_entry *ce,
-		   const struct checkout *state, char *topath)
+int checkout_entry(struct cache_entry *ce, const struct checkout *state,
+		   char *topath, int *nr_checkouts)
 {
 	static struct strbuf path = STRBUF_INIT;
 	struct stat st;
 
+	if (ce->ce_flags & CE_WT_REMOVE) {
+		if (topath)
+			/*
+			 * No content and thus no path to create, so we have
+			 * no pathname to return.
+			 */
+			BUG("Can't remove entry to a path");
+		unlink_entry(ce);
+		return 0;
+	}
+
 	if (topath)
 		return write_entry(ce, topath, state, 1);
 
@@ -421,7 +461,8 @@ int checkout_entry(struct cache_entry *c
 
 	if (!check_path(path.buf, path.len, &st, state->base_dir_len)) {
 		const struct submodule *sub;
-		unsigned changed = ce_match_stat(ce, &st, CE_MATCH_IGNORE_VALID|CE_MATCH_IGNORE_SKIP_WORKTREE);
+		unsigned changed = ie_match_stat(state->istate, ce, &st,
+						 CE_MATCH_IGNORE_VALID | CE_MATCH_IGNORE_SKIP_WORKTREE);
 		/*
 		 * Needs to be checked before !changed returns early,
 		 * as the possibly empty directory was not changed
@@ -454,6 +495,9 @@ int checkout_entry(struct cache_entry *c
 			return -1;
 		}
 
+		if (state->clone)
+			mark_colliding_entries(state, ce, &st);
+
 		/*
 		 * We unlink the old file, to get the new one with the
 		 * right permissions (including umask, which is nasty
@@ -473,5 +517,22 @@ int checkout_entry(struct cache_entry *c
 		return 0;
 
 	create_directories(path.buf, path.len, state);
+	if (nr_checkouts)
+		(*nr_checkouts)++;
 	return write_entry(ce, path.buf, state, 0);
 }
+
+void unlink_entry(const struct cache_entry *ce)
+{
+	const struct submodule *sub = submodule_from_ce(ce);
+	if (sub) {
+		/* state.force is set at the caller. */
+		submodule_move_head(ce->name, "HEAD", NULL,
+				    SUBMODULE_MOVE_HEAD_FORCE);
+	}
+	if (!check_leading_path(ce->name, ce_namelen(ce)))
+		return;
+	if (remove_or_warn(ce->ce_mode, ce->name))
+		return;
+	schedule_dir_for_removal(ce->name, ce_namelen(ce));
+}
diff -pruN 1.2.1+git2.18.0-1/git/environment.c 1.2.3+git2.25.1-1/git/environment.c
--- 1.2.1+git2.18.0-1/git/environment.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/environment.c	2020-02-17 04:47:35.000000000 +0000
@@ -8,6 +8,7 @@
  * are.
  */
 #include "cache.h"
+#include "branch.h"
 #include "repository.h"
 #include "config.h"
 #include "refs.h"
@@ -30,8 +31,7 @@ int warn_ambiguous_refs = 1;
 int warn_on_object_refname_ambiguity = 1;
 int ref_paranoia = -1;
 int repository_format_precious_objects;
-char *repository_format_partial_clone;
-const char *core_partial_clone_filter_default;
+int repository_format_worktree_config;
 const char *git_commit_encoding;
 const char *git_log_output_encoding;
 const char *apply_default_whitespace;
@@ -51,7 +51,7 @@ const char *editor_program;
 const char *askpass_program;
 const char *excludes_file;
 enum auto_crlf auto_crlf = AUTO_CRLF_FALSE;
-int check_replace_refs = 1; /* NEEDSWORK: rename to read_replace_refs */
+int read_replace_refs = 1;
 char *git_replace_ref_base;
 enum eol core_eol = EOL_UNSET;
 int global_conv_flags_eol = CONV_EOL_RNDTRP_WARN;
@@ -66,12 +66,11 @@ enum push_default_type push_default = PU
 enum object_creation_mode object_creation_mode = OBJECT_CREATION_MODE;
 char *notes_ref_name;
 int grafts_replace_parents = 1;
-int core_commit_graph;
 int core_apply_sparse_checkout;
+int core_sparse_checkout_cone;
 int merge_log_config = -1;
 int precomposed_unicode = -1; /* see probe_utf8_pathname_composition() */
 unsigned long pack_size_limit_cfg;
-enum hide_dotfiles_type hide_dotfiles = HIDE_DOTFILES_DOTGITONLY;
 enum log_refs_config log_all_ref_updates = LOG_REFS_UNSET;
 
 #ifndef PROTECT_HFS_DEFAULT
@@ -80,7 +79,7 @@ enum log_refs_config log_all_ref_updates
 int protect_hfs = PROTECT_HFS_DEFAULT;
 
 #ifndef PROTECT_NTFS_DEFAULT
-#define PROTECT_NTFS_DEFAULT 0
+#define PROTECT_NTFS_DEFAULT 1
 #endif
 int protect_ntfs = PROTECT_NTFS_DEFAULT;
 const char *core_fsmonitor;
@@ -107,7 +106,7 @@ char *git_work_tree_cfg;
 
 static char *git_namespace;
 
-static const char *super_prefix;
+static char *super_prefix;
 
 /*
  * Repository-local GIT_* environment variables; see cache.h for details.
@@ -147,7 +146,7 @@ static char *expand_namespace(const char
 			strbuf_addf(&buf, "refs/namespaces/%s", (*c)->buf);
 	strbuf_list_free(components);
 	if (check_refname_format(buf.buf, 0))
-		die("bad git namespace path \"%s\"", raw_namespace);
+		die(_("bad git namespace path \"%s\""), raw_namespace);
 	strbuf_addch(&buf, '/');
 	return strbuf_detach(&buf, NULL);
 }
@@ -183,7 +182,7 @@ void setup_git_env(const char *git_dir)
 	argv_array_clear(&to_free);
 
 	if (getenv(NO_REPLACE_OBJECTS_ENVIRONMENT))
-		check_replace_refs = 0;
+		read_replace_refs = 0;
 	replace_ref_base = getenv(GIT_REPLACE_REF_BASE_ENVIRONMENT);
 	free(git_replace_ref_base);
 	git_replace_ref_base = xstrdup(replace_ref_base ? replace_ref_base
@@ -192,7 +191,7 @@ void setup_git_env(const char *git_dir)
 	git_namespace = expand_namespace(getenv(GIT_NAMESPACE_ENVIRONMENT));
 	shallow_file = getenv(GIT_SHALLOW_FILE_ENVIRONMENT);
 	if (shallow_file)
-		set_alternate_shallow_file(shallow_file, 0);
+		set_alternate_shallow_file(the_repository, shallow_file, 0);
 }
 
 int is_bare_repository(void)
@@ -240,7 +239,7 @@ const char *get_super_prefix(void)
 {
 	static int initialized;
 	if (!initialized) {
-		super_prefix = getenv(GIT_SUPER_PREFIX_ENVIRONMENT);
+		super_prefix = xstrdup_or_null(getenv(GIT_SUPER_PREFIX_ENVIRONMENT));
 		initialized = 1;
 	}
 	return super_prefix;
@@ -274,9 +273,9 @@ const char *get_git_work_tree(void)
 
 char *get_object_directory(void)
 {
-	if (!the_repository->objects->objectdir)
+	if (!the_repository->objects->odb)
 		BUG("git environment hasn't been setup");
-	return the_repository->objects->objectdir;
+	return the_repository->objects->odb->path;
 }
 
 int odb_mkstemp(struct strbuf *temp_filename, const char *pattern)
@@ -319,17 +318,17 @@ char *get_index_file(void)
 	return the_repository->index_file;
 }
 
-char *get_graft_file(void)
+char *get_graft_file(struct repository *r)
 {
-	if (!the_repository->graft_file)
+	if (!r->graft_file)
 		BUG("git environment hasn't been setup");
-	return the_repository->graft_file;
+	return r->graft_file;
 }
 
 static void set_git_dir_1(const char *path)
 {
 	if (setenv(GIT_DIR_ENVIRONMENT, path, 1))
-		die("could not set GIT_DIR to '%s'", path);
+		die(_("could not set GIT_DIR to '%s'"), path);
 	setup_git_env(path);
 }
 
diff -pruN 1.2.1+git2.18.0-1/git/ewah/bitmap.c 1.2.3+git2.25.1-1/git/ewah/bitmap.c
--- 1.2.1+git2.18.0-1/git/ewah/bitmap.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/ewah/bitmap.c	2020-02-17 04:47:35.000000000 +0000
@@ -45,14 +45,6 @@ void bitmap_set(struct bitmap *self, siz
 	self->words[block] |= EWAH_MASK(pos);
 }
 
-void bitmap_clear(struct bitmap *self, size_t pos)
-{
-	size_t block = EWAH_BLOCK(pos);
-
-	if (block < self->word_alloc)
-		self->words[block] &= ~EWAH_MASK(pos);
-}
-
 int bitmap_get(struct bitmap *self, size_t pos)
 {
 	size_t block = EWAH_BLOCK(pos);
@@ -137,30 +129,6 @@ void bitmap_or_ewah(struct bitmap *self,
 		self->words[i++] |= word;
 }
 
-void bitmap_each_bit(struct bitmap *self, ewah_callback callback, void *data)
-{
-	size_t pos = 0, i;
-
-	for (i = 0; i < self->word_alloc; ++i) {
-		eword_t word = self->words[i];
-		uint32_t offset;
-
-		if (word == (eword_t)~0) {
-			for (offset = 0; offset < BITS_IN_EWORD; ++offset)
-				callback(pos++, data);
-		} else {
-			for (offset = 0; offset < BITS_IN_EWORD; ++offset) {
-				if ((word >> offset) == 0)
-					break;
-
-				offset += ewah_bit_ctz64(word >> offset);
-				callback(pos + offset, data);
-			}
-			pos += BITS_IN_EWORD;
-		}
-	}
-}
-
 size_t bitmap_popcount(struct bitmap *self)
 {
 	size_t i, count = 0;
diff -pruN 1.2.1+git2.18.0-1/git/ewah/ewah_bitmap.c 1.2.3+git2.25.1-1/git/ewah/ewah_bitmap.c
--- 1.2.1+git2.18.0-1/git/ewah/ewah_bitmap.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/ewah/ewah_bitmap.c	2020-02-17 04:47:35.000000000 +0000
@@ -276,6 +276,18 @@ void ewah_each_bit(struct ewah_bitmap *s
 	}
 }
 
+/**
+ * Clear all the bits in the bitmap. Does not free or resize
+ * memory.
+ */
+static void ewah_clear(struct ewah_bitmap *self)
+{
+	self->buffer_size = 1;
+	self->buffer[0] = 0;
+	self->bit_size = 0;
+	self->rlw = self->buffer;
+}
+
 struct ewah_bitmap *ewah_new(void)
 {
 	struct ewah_bitmap *self;
@@ -288,14 +300,6 @@ struct ewah_bitmap *ewah_new(void)
 	return self;
 }
 
-void ewah_clear(struct ewah_bitmap *self)
-{
-	self->buffer_size = 1;
-	self->buffer[0] = 0;
-	self->bit_size = 0;
-	self->rlw = self->buffer;
-}
-
 void ewah_free(struct ewah_bitmap *self)
 {
 	if (!self)
@@ -376,25 +380,6 @@ void ewah_iterator_init(struct ewah_iter
 		read_new_rlw(it);
 }
 
-void ewah_not(struct ewah_bitmap *self)
-{
-	size_t pointer = 0;
-
-	while (pointer < self->buffer_size) {
-		eword_t *word = &self->buffer[pointer];
-		size_t literals, k;
-
-		rlw_xor_run_bit(word);
-		++pointer;
-
-		literals = rlw_get_literal_words(word);
-		for (k = 0; k < literals; ++k) {
-			self->buffer[pointer] = ~self->buffer[pointer];
-			++pointer;
-		}
-	}
-}
-
 void ewah_xor(
 	struct ewah_bitmap *ewah_i,
 	struct ewah_bitmap *ewah_j,
@@ -459,216 +444,6 @@ void ewah_xor(
 	out->bit_size = max_size(ewah_i->bit_size, ewah_j->bit_size);
 }
 
-void ewah_and(
-	struct ewah_bitmap *ewah_i,
-	struct ewah_bitmap *ewah_j,
-	struct ewah_bitmap *out)
-{
-	struct rlw_iterator rlw_i;
-	struct rlw_iterator rlw_j;
-	size_t literals;
-
-	rlwit_init(&rlw_i, ewah_i);
-	rlwit_init(&rlw_j, ewah_j);
-
-	while (rlwit_word_size(&rlw_i) > 0 && rlwit_word_size(&rlw_j) > 0) {
-		while (rlw_i.rlw.running_len > 0 || rlw_j.rlw.running_len > 0) {
-			struct rlw_iterator *prey, *predator;
-
-			if (rlw_i.rlw.running_len < rlw_j.rlw.running_len) {
-				prey = &rlw_i;
-				predator = &rlw_j;
-			} else {
-				prey = &rlw_j;
-				predator = &rlw_i;
-			}
-
-			if (predator->rlw.running_bit == 0) {
-				ewah_add_empty_words(out, 0,
-					predator->rlw.running_len);
-				rlwit_discard_first_words(prey,
-					predator->rlw.running_len);
-				rlwit_discard_first_words(predator,
-					predator->rlw.running_len);
-			} else {
-				size_t index = rlwit_discharge(prey, out,
-					predator->rlw.running_len, 0);
-				ewah_add_empty_words(out, 0,
-					predator->rlw.running_len - index);
-				rlwit_discard_first_words(predator,
-					predator->rlw.running_len);
-			}
-		}
-
-		literals = min_size(
-			rlw_i.rlw.literal_words,
-			rlw_j.rlw.literal_words);
-
-		if (literals) {
-			size_t k;
-
-			for (k = 0; k < literals; ++k) {
-				ewah_add(out,
-					rlw_i.buffer[rlw_i.literal_word_start + k] &
-					rlw_j.buffer[rlw_j.literal_word_start + k]
-				);
-			}
-
-			rlwit_discard_first_words(&rlw_i, literals);
-			rlwit_discard_first_words(&rlw_j, literals);
-		}
-	}
-
-	if (rlwit_word_size(&rlw_i) > 0)
-		rlwit_discharge_empty(&rlw_i, out);
-	else
-		rlwit_discharge_empty(&rlw_j, out);
-
-	out->bit_size = max_size(ewah_i->bit_size, ewah_j->bit_size);
-}
-
-void ewah_and_not(
-	struct ewah_bitmap *ewah_i,
-	struct ewah_bitmap *ewah_j,
-	struct ewah_bitmap *out)
-{
-	struct rlw_iterator rlw_i;
-	struct rlw_iterator rlw_j;
-	size_t literals;
-
-	rlwit_init(&rlw_i, ewah_i);
-	rlwit_init(&rlw_j, ewah_j);
-
-	while (rlwit_word_size(&rlw_i) > 0 && rlwit_word_size(&rlw_j) > 0) {
-		while (rlw_i.rlw.running_len > 0 || rlw_j.rlw.running_len > 0) {
-			struct rlw_iterator *prey, *predator;
-
-			if (rlw_i.rlw.running_len < rlw_j.rlw.running_len) {
-				prey = &rlw_i;
-				predator = &rlw_j;
-			} else {
-				prey = &rlw_j;
-				predator = &rlw_i;
-			}
-
-			if ((predator->rlw.running_bit && prey == &rlw_i) ||
-				(!predator->rlw.running_bit && prey != &rlw_i)) {
-				ewah_add_empty_words(out, 0,
-					predator->rlw.running_len);
-				rlwit_discard_first_words(prey,
-					predator->rlw.running_len);
-				rlwit_discard_first_words(predator,
-					predator->rlw.running_len);
-			} else {
-				size_t index;
-				int negate_words;
-
-				negate_words = (&rlw_i != prey);
-				index = rlwit_discharge(prey, out,
-					predator->rlw.running_len, negate_words);
-				ewah_add_empty_words(out, negate_words,
-					predator->rlw.running_len - index);
-				rlwit_discard_first_words(predator,
-					predator->rlw.running_len);
-			}
-		}
-
-		literals = min_size(
-			rlw_i.rlw.literal_words,
-			rlw_j.rlw.literal_words);
-
-		if (literals) {
-			size_t k;
-
-			for (k = 0; k < literals; ++k) {
-				ewah_add(out,
-					rlw_i.buffer[rlw_i.literal_word_start + k] &
-					~(rlw_j.buffer[rlw_j.literal_word_start + k])
-				);
-			}
-
-			rlwit_discard_first_words(&rlw_i, literals);
-			rlwit_discard_first_words(&rlw_j, literals);
-		}
-	}
-
-	if (rlwit_word_size(&rlw_i) > 0)
-		rlwit_discharge(&rlw_i, out, ~0, 0);
-	else
-		rlwit_discharge_empty(&rlw_j, out);
-
-	out->bit_size = max_size(ewah_i->bit_size, ewah_j->bit_size);
-}
-
-void ewah_or(
-	struct ewah_bitmap *ewah_i,
-	struct ewah_bitmap *ewah_j,
-	struct ewah_bitmap *out)
-{
-	struct rlw_iterator rlw_i;
-	struct rlw_iterator rlw_j;
-	size_t literals;
-
-	rlwit_init(&rlw_i, ewah_i);
-	rlwit_init(&rlw_j, ewah_j);
-
-	while (rlwit_word_size(&rlw_i) > 0 && rlwit_word_size(&rlw_j) > 0) {
-		while (rlw_i.rlw.running_len > 0 || rlw_j.rlw.running_len > 0) {
-			struct rlw_iterator *prey, *predator;
-
-			if (rlw_i.rlw.running_len < rlw_j.rlw.running_len) {
-				prey = &rlw_i;
-				predator = &rlw_j;
-			} else {
-				prey = &rlw_j;
-				predator = &rlw_i;
-			}
-
-			if (predator->rlw.running_bit) {
-				ewah_add_empty_words(out, 0,
-					predator->rlw.running_len);
-				rlwit_discard_first_words(prey,
-					predator->rlw.running_len);
-				rlwit_discard_first_words(predator,
-					predator->rlw.running_len);
-			} else {
-				size_t index = rlwit_discharge(prey, out,
-					predator->rlw.running_len, 0);
-				ewah_add_empty_words(out, 0,
-					predator->rlw.running_len - index);
-				rlwit_discard_first_words(predator,
-					predator->rlw.running_len);
-			}
-		}
-
-		literals = min_size(
-			rlw_i.rlw.literal_words,
-			rlw_j.rlw.literal_words);
-
-		if (literals) {
-			size_t k;
-
-			for (k = 0; k < literals; ++k) {
-				ewah_add(out,
-					rlw_i.buffer[rlw_i.literal_word_start + k] |
-					rlw_j.buffer[rlw_j.literal_word_start + k]
-				);
-			}
-
-			rlwit_discard_first_words(&rlw_i, literals);
-			rlwit_discard_first_words(&rlw_j, literals);
-		}
-	}
-
-	if (rlwit_word_size(&rlw_i) > 0)
-		rlwit_discharge(&rlw_i, out, ~0, 0);
-	else
-		rlwit_discharge(&rlw_j, out, ~0, 0);
-
-	out->bit_size = max_size(ewah_i->bit_size, ewah_j->bit_size);
-}
-
-
 #define BITMAP_POOL_MAX 16
 static struct ewah_bitmap *bitmap_pool[BITMAP_POOL_MAX];
 static size_t bitmap_pool_size;
diff -pruN 1.2.1+git2.18.0-1/git/ewah/ewah_io.c 1.2.3+git2.25.1-1/git/ewah/ewah_io.c
--- 1.2.1+git2.18.0-1/git/ewah/ewah_io.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/ewah/ewah_io.c	2020-02-17 04:47:35.000000000 +0000
@@ -20,32 +20,6 @@
 #include "ewok.h"
 #include "strbuf.h"
 
-int ewah_serialize_native(struct ewah_bitmap *self, int fd)
-{
-	uint32_t write32;
-	size_t to_write = self->buffer_size * 8;
-
-	/* 32 bit -- bit size for the map */
-	write32 = (uint32_t)self->bit_size;
-	if (write(fd, &write32, 4) != 4)
-		return -1;
-
-	/** 32 bit -- number of compressed 64-bit words */
-	write32 = (uint32_t)self->buffer_size;
-	if (write(fd, &write32, 4) != 4)
-		return -1;
-
-	if (write(fd, self->buffer, to_write) != to_write)
-		return -1;
-
-	/** 32 bit -- position for the RLW */
-	write32 = self->rlw - self->buffer;
-	if (write(fd, &write32, 4) != 4)
-		return -1;
-
-	return (3 * 4) + to_write;
-}
-
 int ewah_serialize_to(struct ewah_bitmap *self,
 		      int (*write_fun)(void *, const void *, size_t),
 		      void *data)
@@ -100,16 +74,6 @@ int ewah_serialize_to(struct ewah_bitmap
 	return (3 * 4) + (self->buffer_size * 8);
 }
 
-static int write_helper(void *fd, const void *buf, size_t len)
-{
-	return write((intptr_t)fd, buf, len);
-}
-
-int ewah_serialize(struct ewah_bitmap *self, int fd)
-{
-	return ewah_serialize_to(self, write_helper, (void *)(intptr_t)fd);
-}
-
 static int write_strbuf(void *user_data, const void *data, size_t len)
 {
 	struct strbuf *sb = user_data;
@@ -168,58 +132,3 @@ ssize_t ewah_read_mmap(struct ewah_bitma
 
 	return ptr - (const uint8_t *)map;
 }
-
-int ewah_deserialize(struct ewah_bitmap *self, int fd)
-{
-	size_t i;
-	eword_t dump[2048];
-	const size_t words_per_dump = sizeof(dump) / sizeof(eword_t);
-	uint32_t bitsize, word_count, rlw_pos;
-
-	eword_t *buffer = NULL;
-	size_t words_left;
-
-	ewah_clear(self);
-
-	/* 32 bit -- bit size for the map */
-	if (read(fd, &bitsize, 4) != 4)
-		return -1;
-
-	self->bit_size = (size_t)ntohl(bitsize);
-
-	/** 32 bit -- number of compressed 64-bit words */
-	if (read(fd, &word_count, 4) != 4)
-		return -1;
-
-	self->buffer_size = self->alloc_size = (size_t)ntohl(word_count);
-	REALLOC_ARRAY(self->buffer, self->alloc_size);
-
-	/** 64 bit x N -- compressed words */
-	buffer = self->buffer;
-	words_left = self->buffer_size;
-
-	while (words_left >= words_per_dump) {
-		if (read(fd, dump, sizeof(dump)) != sizeof(dump))
-			return -1;
-
-		for (i = 0; i < words_per_dump; ++i, ++buffer)
-			*buffer = ntohll(dump[i]);
-
-		words_left -= words_per_dump;
-	}
-
-	if (words_left) {
-		if (read(fd, dump, words_left * 8) != words_left * 8)
-			return -1;
-
-		for (i = 0; i < words_left; ++i, ++buffer)
-			*buffer = ntohll(dump[i]);
-	}
-
-	/** 32 bit -- position for the RLW */
-	if (read(fd, &rlw_pos, 4) != 4)
-		return -1;
-
-	self->rlw = self->buffer + ntohl(rlw_pos);
-	return 0;
-}
diff -pruN 1.2.1+git2.18.0-1/git/ewah/ewah_rlw.c 1.2.3+git2.25.1-1/git/ewah/ewah_rlw.c
--- 1.2.1+git2.18.0-1/git/ewah/ewah_rlw.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/ewah/ewah_rlw.c	2020-02-17 04:47:35.000000000 +0000
@@ -104,11 +104,3 @@ size_t rlwit_discharge(
 
 	return index;
 }
-
-void rlwit_discharge_empty(struct rlw_iterator *it, struct ewah_bitmap *out)
-{
-	while (rlwit_word_size(it) > 0) {
-		ewah_add_empty_words(out, 0, rlwit_word_size(it));
-		rlwit_discard_first_words(it, rlwit_word_size(it));
-	}
-}
diff -pruN 1.2.1+git2.18.0-1/git/ewah/ewok.h 1.2.3+git2.25.1-1/git/ewah/ewok.h
--- 1.2.1+git2.18.0-1/git/ewah/ewok.h	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/ewah/ewok.h	2020-02-17 04:47:35.000000000 +0000
@@ -73,12 +73,6 @@ void ewah_pool_free(struct ewah_bitmap *
 struct ewah_bitmap *ewah_new(void);
 
 /**
- * Clear all the bits in the bitmap. Does not free or resize
- * memory.
- */
-void ewah_clear(struct ewah_bitmap *self);
-
-/**
  * Free all the memory of the bitmap
  */
 void ewah_free(struct ewah_bitmap *self);
@@ -86,23 +80,13 @@ void ewah_free(struct ewah_bitmap *self)
 int ewah_serialize_to(struct ewah_bitmap *self,
 		      int (*write_fun)(void *out, const void *buf, size_t len),
 		      void *out);
-int ewah_serialize(struct ewah_bitmap *self, int fd);
-int ewah_serialize_native(struct ewah_bitmap *self, int fd);
 int ewah_serialize_strbuf(struct ewah_bitmap *self, struct strbuf *);
 
-int ewah_deserialize(struct ewah_bitmap *self, int fd);
 ssize_t ewah_read_mmap(struct ewah_bitmap *self, const void *map, size_t len);
 
 uint32_t ewah_checksum(struct ewah_bitmap *self);
 
 /**
- * Logical not (bitwise negation) in-place on the bitmap
- *
- * This operation is linear time based on the size of the bitmap.
- */
-void ewah_not(struct ewah_bitmap *self);
-
-/**
  * Call the given callback with the position of every single bit
  * that has been set on the bitmap.
  *
@@ -164,26 +148,11 @@ void ewah_iterator_init(struct ewah_iter
  */
 int ewah_iterator_next(eword_t *next, struct ewah_iterator *it);
 
-void ewah_or(
-	struct ewah_bitmap *ewah_i,
-	struct ewah_bitmap *ewah_j,
-	struct ewah_bitmap *out);
-
-void ewah_and_not(
-	struct ewah_bitmap *ewah_i,
-	struct ewah_bitmap *ewah_j,
-	struct ewah_bitmap *out);
-
 void ewah_xor(
 	struct ewah_bitmap *ewah_i,
 	struct ewah_bitmap *ewah_j,
 	struct ewah_bitmap *out);
 
-void ewah_and(
-	struct ewah_bitmap *ewah_i,
-	struct ewah_bitmap *ewah_j,
-	struct ewah_bitmap *out);
-
 /**
  * Direct word access
  */
@@ -204,7 +173,6 @@ struct bitmap {
 
 struct bitmap *bitmap_new(void);
 void bitmap_set(struct bitmap *self, size_t pos);
-void bitmap_clear(struct bitmap *self, size_t pos);
 int bitmap_get(struct bitmap *self, size_t pos);
 void bitmap_reset(struct bitmap *self);
 void bitmap_free(struct bitmap *self);
@@ -218,7 +186,6 @@ void bitmap_and_not(struct bitmap *self,
 void bitmap_or_ewah(struct bitmap *self, struct ewah_bitmap *other);
 void bitmap_or(struct bitmap *self, const struct bitmap *other);
 
-void bitmap_each_bit(struct bitmap *self, ewah_callback callback, void *data);
 size_t bitmap_popcount(struct bitmap *self);
 
 #endif
diff -pruN 1.2.1+git2.18.0-1/git/ewah/ewok_rlw.h 1.2.3+git2.25.1-1/git/ewah/ewok_rlw.h
--- 1.2.1+git2.18.0-1/git/ewah/ewok_rlw.h	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/ewah/ewok_rlw.h	2020-02-17 04:47:35.000000000 +0000
@@ -19,6 +19,8 @@
 #ifndef __EWOK_RLW_H__
 #define __EWOK_RLW_H__
 
+#include "ewok.h"
+
 #define RLW_RUNNING_BITS (sizeof(eword_t) * 4)
 #define RLW_LITERAL_BITS (sizeof(eword_t) * 8 - 1 - RLW_RUNNING_BITS)
 
@@ -29,7 +31,7 @@
 
 #define RLW_RUNNING_LEN_PLUS_BIT (((eword_t)1 << (RLW_RUNNING_BITS + 1)) - 1)
 
-static int rlw_get_run_bit(const eword_t *word)
+static inline int rlw_get_run_bit(const eword_t *word)
 {
 	return *word & (eword_t)1;
 }
@@ -98,7 +100,6 @@ void rlwit_init(struct rlw_iterator *it,
 void rlwit_discard_first_words(struct rlw_iterator *it, size_t x);
 size_t rlwit_discharge(
 	struct rlw_iterator *it, struct ewah_bitmap *out, size_t max, int negate);
-void rlwit_discharge_empty(struct rlw_iterator *it, struct ewah_bitmap *out);
 
 static inline size_t rlwit_word_size(struct rlw_iterator *it)
 {
diff -pruN 1.2.1+git2.18.0-1/git/exec-cmd.c 1.2.3+git2.25.1-1/git/exec-cmd.c
--- 1.2.1+git2.18.0-1/git/exec-cmd.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/exec-cmd.c	2020-02-17 04:47:35.000000000 +0000
@@ -209,6 +209,8 @@ static int git_get_exec_path(struct strb
 		return -1;
 	}
 
+	trace2_cmd_path(buf->buf);
+
 	return 0;
 }
 
@@ -358,7 +360,7 @@ int execl_git_cmd(const char *cmd, ...)
 	}
 	va_end(param);
 	if (MAX_ARGS <= argc)
-		return error("too many args to run %s", cmd);
+		return error(_("too many args to run %s"), cmd);
 
 	argv[argc] = NULL;
 	return execv_git_cmd(argv);
diff -pruN 1.2.1+git2.18.0-1/git/exec-cmd.h 1.2.3+git2.25.1-1/git/exec-cmd.h
--- 1.2.1+git2.18.0-1/git/exec-cmd.h	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/exec-cmd.h	2020-02-17 04:47:35.000000000 +0000
@@ -3,14 +3,14 @@
 
 struct argv_array;
 
-extern void git_set_exec_path(const char *exec_path);
-extern void git_resolve_executable_dir(const char *path);
-extern const char *git_exec_path(void);
-extern void setup_path(void);
-extern const char **prepare_git_cmd(struct argv_array *out, const char **argv);
-extern int execv_git_cmd(const char **argv); /* NULL terminated */
+void git_set_exec_path(const char *exec_path);
+void git_resolve_executable_dir(const char *path);
+const char *git_exec_path(void);
+void setup_path(void);
+const char **prepare_git_cmd(struct argv_array *out, const char **argv);
+int execv_git_cmd(const char **argv); /* NULL terminated */
 LAST_ARG_MUST_BE_NULL
-extern int execl_git_cmd(const char *cmd, ...);
-extern char *system_path(const char *path);
+int execl_git_cmd(const char *cmd, ...);
+char *system_path(const char *path);
 
 #endif /* GIT_EXEC_CMD_H */
diff -pruN 1.2.1+git2.18.0-1/git/fast-import.c 1.2.3+git2.25.1-1/git/fast-import.c
--- 1.2.1+git2.18.0-1/git/fast-import.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/fast-import.c	2020-02-17 04:47:35.000000000 +0000
@@ -1,157 +1,3 @@
-/*
-(See Documentation/git-fast-import.txt for maintained documentation.)
-Format of STDIN stream:
-
-  stream ::= cmd*;
-
-  cmd ::= new_blob
-        | new_commit
-        | new_tag
-        | reset_branch
-        | checkpoint
-        | progress
-        ;
-
-  new_blob ::= 'blob' lf
-    mark?
-    file_content;
-  file_content ::= data;
-
-  new_commit ::= 'commit' sp ref_str lf
-    mark?
-    ('author' (sp name)? sp '<' email '>' sp when lf)?
-    'committer' (sp name)? sp '<' email '>' sp when lf
-    commit_msg
-    ('from' sp commit-ish lf)?
-    ('merge' sp commit-ish lf)*
-    (file_change | ls)*
-    lf?;
-  commit_msg ::= data;
-
-  ls ::= 'ls' sp '"' quoted(path) '"' lf;
-
-  file_change ::= file_clr
-    | file_del
-    | file_rnm
-    | file_cpy
-    | file_obm
-    | file_inm;
-  file_clr ::= 'deleteall' lf;
-  file_del ::= 'D' sp path_str lf;
-  file_rnm ::= 'R' sp path_str sp path_str lf;
-  file_cpy ::= 'C' sp path_str sp path_str lf;
-  file_obm ::= 'M' sp mode sp (hexsha1 | idnum) sp path_str lf;
-  file_inm ::= 'M' sp mode sp 'inline' sp path_str lf
-    data;
-  note_obm ::= 'N' sp (hexsha1 | idnum) sp commit-ish lf;
-  note_inm ::= 'N' sp 'inline' sp commit-ish lf
-    data;
-
-  new_tag ::= 'tag' sp tag_str lf
-    'from' sp commit-ish lf
-    ('tagger' (sp name)? sp '<' email '>' sp when lf)?
-    tag_msg;
-  tag_msg ::= data;
-
-  reset_branch ::= 'reset' sp ref_str lf
-    ('from' sp commit-ish lf)?
-    lf?;
-
-  checkpoint ::= 'checkpoint' lf
-    lf?;
-
-  progress ::= 'progress' sp not_lf* lf
-    lf?;
-
-     # note: the first idnum in a stream should be 1 and subsequent
-     # idnums should not have gaps between values as this will cause
-     # the stream parser to reserve space for the gapped values.  An
-     # idnum can be updated in the future to a new object by issuing
-     # a new mark directive with the old idnum.
-     #
-  mark ::= 'mark' sp idnum lf;
-  data ::= (delimited_data | exact_data)
-    lf?;
-
-    # note: delim may be any string but must not contain lf.
-    # data_line may contain any data but must not be exactly
-    # delim.
-  delimited_data ::= 'data' sp '<<' delim lf
-    (data_line lf)*
-    delim lf;
-
-     # note: declen indicates the length of binary_data in bytes.
-     # declen does not include the lf preceding the binary data.
-     #
-  exact_data ::= 'data' sp declen lf
-    binary_data;
-
-     # note: quoted strings are C-style quoting supporting \c for
-     # common escapes of 'c' (e..g \n, \t, \\, \") or \nnn where nnn
-     # is the signed byte value in octal.  Note that the only
-     # characters which must actually be escaped to protect the
-     # stream formatting is: \, " and LF.  Otherwise these values
-     # are UTF8.
-     #
-  commit-ish  ::= (ref_str | hexsha1 | sha1exp_str | idnum);
-  ref_str     ::= ref;
-  sha1exp_str ::= sha1exp;
-  tag_str     ::= tag;
-  path_str    ::= path    | '"' quoted(path)    '"' ;
-  mode        ::= '100644' | '644'
-                | '100755' | '755'
-                | '120000'
-                ;
-
-  declen ::= # unsigned 32 bit value, ascii base10 notation;
-  bigint ::= # unsigned integer value, ascii base10 notation;
-  binary_data ::= # file content, not interpreted;
-
-  when         ::= raw_when | rfc2822_when;
-  raw_when     ::= ts sp tz;
-  rfc2822_when ::= # Valid RFC 2822 date and time;
-
-  sp ::= # ASCII space character;
-  lf ::= # ASCII newline (LF) character;
-
-     # note: a colon (':') must precede the numerical value assigned to
-     # an idnum.  This is to distinguish it from a ref or tag name as
-     # GIT does not permit ':' in ref or tag strings.
-     #
-  idnum   ::= ':' bigint;
-  path    ::= # GIT style file path, e.g. "a/b/c";
-  ref     ::= # GIT ref name, e.g. "refs/heads/MOZ_GECKO_EXPERIMENT";
-  tag     ::= # GIT tag name, e.g. "FIREFOX_1_5";
-  sha1exp ::= # Any valid GIT SHA1 expression;
-  hexsha1 ::= # SHA1 in hexadecimal format;
-
-     # note: name and email are UTF8 strings, however name must not
-     # contain '<' or lf and email must not contain any of the
-     # following: '<', '>', lf.
-     #
-  name  ::= # valid GIT author/committer name;
-  email ::= # valid GIT author/committer email;
-  ts    ::= # time since the epoch in seconds, ascii base10 notation;
-  tz    ::= # GIT style timezone;
-
-     # note: comments, get-mark, ls-tree, and cat-blob requests may
-     # appear anywhere in the input, except within a data command. Any
-     # form of the data command always escapes the related input from
-     # comment processing.
-     #
-     # In case it is not clear, the '#' that starts the comment
-     # must be the first character on that line (an lf
-     # preceded it).
-     #
-
-  get_mark ::= 'get-mark' sp idnum lf;
-  cat_blob ::= 'cat-blob' sp (hexsha1 | idnum) lf;
-  ls_tree  ::= 'ls' sp (hexsha1 | idnum) sp path_str lf;
-
-  comment ::= '#' not_lf* lf;
-  not_lf  ::= # Any byte that is not ASCII newline (LF);
-*/
-
 #include "builtin.h"
 #include "cache.h"
 #include "repository.h"
@@ -171,6 +17,7 @@ Format of STDIN stream:
 #include "packfile.h"
 #include "object-store.h"
 #include "mem-pool.h"
+#include "commit-reach.h"
 
 #define PACK_ID_BITS 16
 #define MAX_PACK_ID ((1<<PACK_ID_BITS)-1)
@@ -182,6 +29,13 @@ Format of STDIN stream:
  */
 #define NO_DELTA S_ISUID
 
+/*
+ * The amount of additional space required in order to write an object into the
+ * current pack. This is the hash lengths at the end of the pack, plus the
+ * length of one object ID.
+ */
+#define PACK_SIZE_THRESHOLD (the_hash_algo->rawsz * 3)
+
 struct object_entry {
 	struct pack_idx_entry idx;
 	struct object_entry *next;
@@ -363,6 +217,7 @@ static uintmax_t next_mark;
 static struct strbuf new_data = STRBUF_INIT;
 static int seen_data_command;
 static int require_explicit_termination;
+static int allow_unsafe_features;
 
 /* Signal handling */
 static volatile sig_atomic_t checkpoint_requested;
@@ -572,7 +427,7 @@ static struct object_entry *find_object(
 	unsigned int h = oid->hash[0] << 8 | oid->hash[1];
 	struct object_entry *e;
 	for (e = object_table[h]; e; e = e->next)
-		if (!oidcmp(oid, &e->idx.oid))
+		if (oideq(oid, &e->idx.oid))
 			return e;
 	return NULL;
 }
@@ -583,7 +438,7 @@ static struct object_entry *insert_objec
 	struct object_entry *e = object_table[h];
 
 	while (e) {
-		if (!oidcmp(oid, &e->idx.oid))
+		if (oideq(oid, &e->idx.oid))
 			return e;
 		e = e->next;
 	}
@@ -790,7 +645,7 @@ static struct tree_content *grow_tree_co
 	struct tree_content *r = new_tree_content(t->entry_count + amt);
 	r->entry_count = t->entry_count;
 	r->delta_depth = t->delta_depth;
-	memcpy(r->entries,t->entries,t->entry_count*sizeof(t->entries[0]));
+	COPY_ARRAY(r->entries, t->entries, t->entry_count);
 	release_tree_content(t);
 	return r;
 }
@@ -895,7 +750,8 @@ static const char *create_index(void)
 	if (c != last)
 		die("internal consistency error creating the index");
 
-	tmpfile = write_idx_file(NULL, idx, object_count, &pack_idx_opts, pack_data->sha1);
+	tmpfile = write_idx_file(NULL, idx, object_count, &pack_idx_opts,
+				 pack_data->hash);
 	free(idx);
 	return tmpfile;
 }
@@ -906,7 +762,7 @@ static char *keep_pack(const char *curr_
 	struct strbuf name = STRBUF_INIT;
 	int keep_fd;
 
-	odb_pack_name(&name, pack_data->sha1, "keep");
+	odb_pack_name(&name, pack_data->hash, "keep");
 	keep_fd = odb_pack_keep(name.buf);
 	if (keep_fd < 0)
 		die_errno("cannot create keep file");
@@ -914,11 +770,11 @@ static char *keep_pack(const char *curr_
 	if (close(keep_fd))
 		die_errno("failed to write keep file");
 
-	odb_pack_name(&name, pack_data->sha1, "pack");
+	odb_pack_name(&name, pack_data->hash, "pack");
 	if (finalize_object_file(pack_data->pack_name, name.buf))
 		die("cannot store pack file");
 
-	odb_pack_name(&name, pack_data->sha1, "idx");
+	odb_pack_name(&name, pack_data->hash, "idx");
 	if (finalize_object_file(curr_index_name, name.buf))
 		die("cannot store index file");
 	free((void *)curr_index_name);
@@ -932,7 +788,7 @@ static void unkeep_all_packs(void)
 
 	for (k = 0; k < pack_id; k++) {
 		struct packed_git *p = all_packs[k];
-		odb_pack_name(&name, p->sha1, "keep");
+		odb_pack_name(&name, p->hash, "keep");
 		unlink_or_warn(name.buf);
 	}
 	strbuf_release(&name);
@@ -974,9 +830,9 @@ static void end_packfile(void)
 
 		close_pack_windows(pack_data);
 		finalize_hashfile(pack_file, cur_pack_oid.hash, 0);
-		fixup_pack_header_footer(pack_data->pack_fd, pack_data->sha1,
-				    pack_data->pack_name, object_count,
-				    cur_pack_oid.hash, pack_size);
+		fixup_pack_header_footer(pack_data->pack_fd, pack_data->hash,
+					 pack_data->pack_name, object_count,
+					 cur_pack_oid.hash, pack_size);
 
 		if (object_count <= unpack_limit) {
 			if (!loosen_small_pack(pack_data)) {
@@ -1068,7 +924,7 @@ static int store_object(
 		duplicate_count_by_type[type]++;
 		return 1;
 	} else if (find_sha1_pack(oid.hash,
-				  get_packed_git(the_repository))) {
+				  get_all_packs(the_repository))) {
 		e->type = type;
 		e->pack_id = MAX_PACK_ID;
 		e->idx.offset = 1; /* just not zero! */
@@ -1076,7 +932,7 @@ static int store_object(
 		return 1;
 	}
 
-	if (last && last->data.buf && last->depth < max_depth
+	if (last && last->data.len && last->data.buf && last->depth < max_depth
 		&& dat->len > the_hash_algo->rawsz) {
 
 		delta_count_attempts_by_type[type]++;
@@ -1101,8 +957,9 @@ static int store_object(
 	git_deflate_end(&s);
 
 	/* Determine if we should auto-checkpoint. */
-	if ((max_packsize && (pack_size + 60 + s.total_out) > max_packsize)
-		|| (pack_size + 60 + s.total_out) < pack_size) {
+	if ((max_packsize
+		&& (pack_size + PACK_SIZE_THRESHOLD + s.total_out) > max_packsize)
+		|| (pack_size + PACK_SIZE_THRESHOLD + s.total_out) < pack_size) {
 
 		/* This new object needs to *not* have the current pack_id. */
 		e->pack_id = pack_id + 1;
@@ -1197,8 +1054,9 @@ static void stream_blob(uintmax_t len, s
 	int status = Z_OK;
 
 	/* Determine if we should auto-checkpoint. */
-	if ((max_packsize && (pack_size + 60 + len) > max_packsize)
-		|| (pack_size + 60 + len) < pack_size)
+	if ((max_packsize
+		&& (pack_size + PACK_SIZE_THRESHOLD + len) > max_packsize)
+		|| (pack_size + PACK_SIZE_THRESHOLD + len) < pack_size)
 		cycle_packfile();
 
 	hashfile_checkpoint(pack_file, &checkpoint);
@@ -1266,7 +1124,7 @@ static void stream_blob(uintmax_t len, s
 		truncate_pack(&checkpoint);
 
 	} else if (find_sha1_pack(oid.hash,
-				  get_packed_git(the_repository))) {
+				  get_all_packs(the_repository))) {
 		e->type = OBJ_BLOB;
 		e->pack_id = MAX_PACK_ID;
 		e->idx.offset = 1; /* just not zero! */
@@ -1393,7 +1251,7 @@ static void load_tree(struct tree_entry
 		c += e->name->str_len + 1;
 		hashcpy(e->versions[0].oid.hash, (unsigned char *)c);
 		hashcpy(e->versions[1].oid.hash, (unsigned char *)c);
-		c += GIT_SHA1_RAWSZ;
+		c += the_hash_algo->rawsz;
 	}
 	free(buf);
 }
@@ -1440,7 +1298,7 @@ static void mktree(struct tree_content *
 		strbuf_addf(b, "%o %s%c",
 			(unsigned int)(e->versions[v].mode & ~NO_DELTA),
 			e->name->str_dat, '\0');
-		strbuf_add(b, e->versions[v].oid.hash, GIT_SHA1_RAWSZ);
+		strbuf_add(b, e->versions[v].oid.hash, the_hash_algo->rawsz);
 	}
 }
 
@@ -1533,7 +1391,7 @@ static int tree_content_set(
 			if (!*slash1) {
 				if (!S_ISDIR(mode)
 						&& e->versions[1].mode == mode
-						&& !oidcmp(&e->versions[1].oid, oid))
+						&& oideq(&e->versions[1].oid, oid))
 					return 0;
 				e->versions[1].mode = mode;
 				oidcpy(&e->versions[1].oid, oid);
@@ -1724,8 +1582,10 @@ static int update_branch(struct branch *
 	if (!force_update && !is_null_oid(&old_oid)) {
 		struct commit *old_cmit, *new_cmit;
 
-		old_cmit = lookup_commit_reference_gently(&old_oid, 0);
-		new_cmit = lookup_commit_reference_gently(&b->oid, 0);
+		old_cmit = lookup_commit_reference_gently(the_repository,
+							  &old_oid, 0);
+		new_cmit = lookup_commit_reference_gently(the_repository,
+							  &b->oid, 0);
 		if (!old_cmit || !new_cmit)
 			return error("Branch %s is missing commits.", b->name);
 
@@ -1823,6 +1683,12 @@ static void dump_marks(void)
 	if (!export_marks_file || (import_marks_file && !import_marks_file_done))
 		return;
 
+	if (safe_create_leading_directories_const(export_marks_file)) {
+		failure |= error_errno("unable to create leading directories of %s",
+				       export_marks_file);
+		return;
+	}
+
 	if (hold_lock_file_for_update(&mark_lock, export_marks_file, 0) < 0) {
 		failure |= error_errno("Unable to write marks file %s",
 				       export_marks_file);
@@ -1899,14 +1765,11 @@ static int read_next_command(void)
 	}
 
 	for (;;) {
-		const char *p;
-
 		if (unread_command_buf) {
 			unread_command_buf = 0;
 		} else {
 			struct recent_command *rc;
 
-			strbuf_detach(&command_buf, NULL);
 			stdin_eof = strbuf_getline_lf(&command_buf, stdin);
 			if (stdin_eof)
 				return EOF;
@@ -1927,20 +1790,12 @@ static int read_next_command(void)
 				free(rc->buf);
 			}
 
-			rc->buf = command_buf.buf;
+			rc->buf = xstrdup(command_buf.buf);
 			rc->prev = cmd_tail;
 			rc->next = cmd_hist.prev;
 			rc->prev->next = rc;
 			cmd_tail = rc;
 		}
-		if (skip_prefix(command_buf.buf, "get-mark ", &p)) {
-			parse_get_mark(p);
-			continue;
-		}
-		if (skip_prefix(command_buf.buf, "cat-blob ", &p)) {
-			parse_cat_blob(p);
-			continue;
-		}
 		if (command_buf.buf[0] == '#')
 			continue;
 		return 0;
@@ -1965,6 +1820,13 @@ static void parse_mark(void)
 		next_mark = 0;
 }
 
+static void parse_original_identifier(void)
+{
+	const char *v;
+	if (skip_prefix(command_buf.buf, "original-oid ", &v))
+		read_next_command();
+}
+
 static int parse_data(struct strbuf *sb, uintmax_t limit, uintmax_t *len_res)
 {
 	const char *data;
@@ -1977,7 +1839,6 @@ static int parse_data(struct strbuf *sb,
 		char *term = xstrdup(data);
 		size_t term_len = command_buf.len - (data - command_buf.buf);
 
-		strbuf_detach(&command_buf, NULL);
 		for (;;) {
 			if (strbuf_getline_lf(&command_buf, stdin) == EOF)
 				die("EOF in data (terminator '%s' not found)", term);
@@ -2107,6 +1968,7 @@ static void parse_new_blob(void)
 {
 	read_next_command();
 	parse_mark();
+	parse_original_identifier();
 	parse_and_store_blob(&last_blob, NULL, next_mark);
 }
 
@@ -2189,7 +2051,9 @@ static uintmax_t do_change_note_fanout(
 	unsigned int i, tmp_hex_oid_len, tmp_fullpath_len;
 	uintmax_t num_notes = 0;
 	struct object_id oid;
-	char realpath[60];
+	/* hex oid + '/' between each pair of hex digits + NUL */
+	char realpath[GIT_MAX_HEXSZ + ((GIT_MAX_HEXSZ / 2) - 1) + 1];
+	const unsigned hexsz = the_hash_algo->hexsz;
 
 	if (!root->tree)
 		load_tree(root);
@@ -2209,7 +2073,7 @@ static uintmax_t do_change_note_fanout(
 		 * of 2 chars.
 		 */
 		if (!e->versions[1].mode ||
-		    tmp_hex_oid_len > GIT_SHA1_HEXSZ ||
+		    tmp_hex_oid_len > hexsz ||
 		    e->name->str_len % 2)
 			continue;
 
@@ -2223,7 +2087,7 @@ static uintmax_t do_change_note_fanout(
 		tmp_fullpath_len += e->name->str_len;
 		fullpath[tmp_fullpath_len] = '\0';
 
-		if (tmp_hex_oid_len == GIT_SHA1_HEXSZ && !get_oid_hex(hex_oid, &oid)) {
+		if (tmp_hex_oid_len == hexsz && !get_oid_hex(hex_oid, &oid)) {
 			/* This is a note entry */
 			if (fanout == 0xff) {
 				/* Counting mode, no rename */
@@ -2397,8 +2261,15 @@ static void file_change_m(const char *p,
 			strbuf_addstr(&uq, p);
 			p = uq.buf;
 		}
-		read_next_command();
-		parse_and_store_blob(&last_blob, &oid, 0);
+		while (read_next_command() != EOF) {
+			const char *v;
+			if (skip_prefix(command_buf.buf, "cat-blob ", &v))
+				parse_cat_blob(v);
+			else {
+				parse_and_store_blob(&last_blob, &oid, 0);
+				break;
+			}
+		}
 	} else {
 		enum object_type expected = S_ISDIR(mode) ?
 						OBJ_TREE: OBJ_BLOB;
@@ -2494,7 +2365,7 @@ static void note_change_n(const char *p,
 	struct object_entry *oe;
 	struct branch *s;
 	struct object_id oid, commit_oid;
-	char path[60];
+	char path[GIT_MAX_RAWSZ * 3];
 	uint16_t inline_data = 0;
 	unsigned char new_fanout;
 
@@ -2544,10 +2415,11 @@ static void note_change_n(const char *p,
 		oidcpy(&commit_oid, &commit_oe->idx.oid);
 	} else if (!get_oid(p, &commit_oid)) {
 		unsigned long size;
-		char *buf = read_object_with_reference(&commit_oid,
+		char *buf = read_object_with_reference(the_repository,
+						       &commit_oid,
 						       commit_type, &size,
 						       &commit_oid);
-		if (!buf || size < 46)
+		if (!buf || size < the_hash_algo->hexsz + 6)
 			die("Not a valid commit: %s", p);
 		free(buf);
 	} else
@@ -2598,7 +2470,7 @@ static void file_change_deleteall(struct
 
 static void parse_from_commit(struct branch *b, char *buf, unsigned long size)
 {
-	if (!buf || size < GIT_SHA1_HEXSZ + 6)
+	if (!buf || size < the_hash_algo->hexsz + 6)
 		die("Not a valid commit: %s", oid_to_hex(&b->oid));
 	if (memcmp("tree ", buf, 5)
 		|| get_oid_hex(buf + 5, &b->branch_tree.versions[1].oid))
@@ -2616,25 +2488,22 @@ static void parse_from_existing(struct b
 		unsigned long size;
 		char *buf;
 
-		buf = read_object_with_reference(&b->oid, commit_type, &size,
+		buf = read_object_with_reference(the_repository,
+						 &b->oid, commit_type, &size,
 						 &b->oid);
 		parse_from_commit(b, buf, size);
 		free(buf);
 	}
 }
 
-static int parse_from(struct branch *b)
+static int parse_objectish(struct branch *b, const char *objectish)
 {
-	const char *from;
 	struct branch *s;
 	struct object_id oid;
 
-	if (!skip_prefix(command_buf.buf, "from ", &from))
-		return 0;
-
 	oidcpy(&oid, &b->branch_tree.versions[1].oid);
 
-	s = lookup_branch(from);
+	s = lookup_branch(objectish);
 	if (b == s)
 		die("Can't create a branch from itself: %s", b->name);
 	else if (s) {
@@ -2642,12 +2511,12 @@ static int parse_from(struct branch *b)
 		oidcpy(&b->oid, &s->oid);
 		oidcpy(&b->branch_tree.versions[0].oid, t);
 		oidcpy(&b->branch_tree.versions[1].oid, t);
-	} else if (*from == ':') {
-		uintmax_t idnum = parse_mark_ref_eol(from);
+	} else if (*objectish == ':') {
+		uintmax_t idnum = parse_mark_ref_eol(objectish);
 		struct object_entry *oe = find_mark(idnum);
 		if (oe->type != OBJ_COMMIT)
 			die("Mark :%" PRIuMAX " not a commit", idnum);
-		if (oidcmp(&b->oid, &oe->idx.oid)) {
+		if (!oideq(&b->oid, &oe->idx.oid)) {
 			oidcpy(&b->oid, &oe->idx.oid);
 			if (oe->pack_id != MAX_PACK_ID) {
 				unsigned long size;
@@ -2657,15 +2526,15 @@ static int parse_from(struct branch *b)
 			} else
 				parse_from_existing(b);
 		}
-	} else if (!get_oid(from, &b->oid)) {
+	} else if (!get_oid(objectish, &b->oid)) {
 		parse_from_existing(b);
 		if (is_null_oid(&b->oid))
 			b->delete = 1;
 	}
 	else
-		die("Invalid ref name or SHA1 expression: %s", from);
+		die("Invalid ref name or SHA1 expression: %s", objectish);
 
-	if (b->branch_tree.tree && oidcmp(&oid, &b->branch_tree.versions[1].oid)) {
+	if (b->branch_tree.tree && !oideq(&oid, &b->branch_tree.versions[1].oid)) {
 		release_tree_content_recursive(b->branch_tree.tree);
 		b->branch_tree.tree = NULL;
 	}
@@ -2674,6 +2543,26 @@ static int parse_from(struct branch *b)
 	return 1;
 }
 
+static int parse_from(struct branch *b)
+{
+	const char *from;
+
+	if (!skip_prefix(command_buf.buf, "from ", &from))
+		return 0;
+
+	return parse_objectish(b, from);
+}
+
+static int parse_objectish_with_prefix(struct branch *b, const char *prefix)
+{
+	const char *base;
+
+	if (!skip_prefix(command_buf.buf, prefix, &base))
+		return 0;
+
+	return parse_objectish(b, base);
+}
+
 static struct hash_list *parse_merge(unsigned int *count)
 {
 	struct hash_list *list = NULL, **tail = &list, *n;
@@ -2694,10 +2583,11 @@ static struct hash_list *parse_merge(uns
 			oidcpy(&n->oid, &oe->idx.oid);
 		} else if (!get_oid(from, &n->oid)) {
 			unsigned long size;
-			char *buf = read_object_with_reference(&n->oid,
+			char *buf = read_object_with_reference(the_repository,
+							       &n->oid,
 							       commit_type,
 							       &size, &n->oid);
-			if (!buf || size < 46)
+			if (!buf || size < the_hash_algo->hexsz + 6)
 				die("Not a valid commit: %s", from);
 			free(buf);
 		} else
@@ -2719,6 +2609,7 @@ static void parse_new_commit(const char
 	struct branch *b;
 	char *author = NULL;
 	char *committer = NULL;
+	char *encoding = NULL;
 	struct hash_list *merge_list = NULL;
 	unsigned int merge_count;
 	unsigned char prev_fanout, new_fanout;
@@ -2730,6 +2621,7 @@ static void parse_new_commit(const char
 
 	read_next_command();
 	parse_mark();
+	parse_original_identifier();
 	if (skip_prefix(command_buf.buf, "author ", &v)) {
 		author = parse_ident(v);
 		read_next_command();
@@ -2740,6 +2632,10 @@ static void parse_new_commit(const char
 	}
 	if (!committer)
 		die("Expected committer but didn't get one");
+	if (skip_prefix(command_buf.buf, "encoding ", &v)) {
+		encoding = xstrdup(v);
+		read_next_command();
+	}
 	parse_data(&msg, 0, NULL);
 	read_next_command();
 	parse_from(b);
@@ -2769,6 +2665,8 @@ static void parse_new_commit(const char
 			file_change_deleteall(b);
 		else if (skip_prefix(command_buf.buf, "ls ", &v))
 			parse_ls(v, b);
+		else if (skip_prefix(command_buf.buf, "cat-blob ", &v))
+			parse_cat_blob(v);
 		else {
 			unread_command_buf = 1;
 			break;
@@ -2801,12 +2699,17 @@ static void parse_new_commit(const char
 	}
 	strbuf_addf(&new_data,
 		"author %s\n"
-		"committer %s\n"
-		"\n",
+		"committer %s\n",
 		author ? author : committer, committer);
+	if (encoding)
+		strbuf_addf(&new_data,
+			"encoding %s\n",
+			encoding);
+	strbuf_addch(&new_data, '\n');
 	strbuf_addbuf(&new_data, &msg);
 	free(author);
 	free(committer);
+	free(encoding);
 
 	if (!store_object(OBJ_COMMIT, &new_data, NULL, &b->oid, next_mark))
 		b->pack_id = pack_id;
@@ -2834,6 +2737,7 @@ static void parse_new_tag(const char *ar
 		first_tag = t;
 	last_tag = t;
 	read_next_command();
+	parse_mark();
 
 	/* from ... */
 	if (!skip_prefix(command_buf.buf, "from ", &from))
@@ -2862,6 +2766,9 @@ static void parse_new_tag(const char *ar
 		die("Invalid ref name or SHA1 expression: %s", from);
 	read_next_command();
 
+	/* original-oid ... */
+	parse_original_identifier();
+
 	/* tagger ... */
 	if (skip_prefix(command_buf.buf, "tagger ", &v)) {
 		tagger = parse_ident(v);
@@ -2887,7 +2794,7 @@ static void parse_new_tag(const char *ar
 	strbuf_addbuf(&new_data, &msg);
 	free(tagger);
 
-	if (store_object(OBJ_TAG, &new_data, NULL, &t->oid, 0))
+	if (store_object(OBJ_TAG, &new_data, NULL, &t->oid, next_mark))
 		t->pack_id = MAX_PACK_ID;
 	else
 		t->pack_id = pack_id;
@@ -2896,6 +2803,7 @@ static void parse_new_tag(const char *ar
 static void parse_reset_branch(const char *arg)
 {
 	struct branch *b;
+	const char *tag_name;
 
 	b = lookup_branch(arg);
 	if (b) {
@@ -2911,6 +2819,32 @@ static void parse_reset_branch(const cha
 		b = new_branch(arg);
 	read_next_command();
 	parse_from(b);
+	if (b->delete && skip_prefix(b->name, "refs/tags/", &tag_name)) {
+		/*
+		 * Elsewhere, we call dump_branches() before dump_tags(),
+		 * and dump_branches() will handle ref deletions first, so
+		 * in order to make sure the deletion actually takes effect,
+		 * we need to remove the tag from our list of tags to update.
+		 *
+		 * NEEDSWORK: replace list of tags with hashmap for faster
+		 * deletion?
+		 */
+		struct tag *t, *prev = NULL;
+		for (t = first_tag; t; t = t->next_tag) {
+			if (!strcmp(t->name, tag_name))
+				break;
+			prev = t;
+		}
+		if (t) {
+			if (prev)
+				prev->next_tag = t->next_tag;
+			else
+				first_tag = t->next_tag;
+			if (!t->next_tag)
+				last_tag = prev;
+			/* There is no mem_pool_free(t) function to call. */
+		}
+	}
 	if (command_buf.len > 0)
 		unread_command_buf = 1;
 }
@@ -2952,8 +2886,8 @@ static void cat_blob(struct object_entry
 		die("Object %s is a %s but a blob was expected.",
 		    oid_to_hex(oid), type_name(type));
 	strbuf_reset(&line);
-	strbuf_addf(&line, "%s %s %lu\n", oid_to_hex(oid),
-						type_name(type), size);
+	strbuf_addf(&line, "%s %s %"PRIuMAX"\n", oid_to_hex(oid),
+		    type_name(type), (uintmax_t)size);
 	cat_blob_write(line.buf, line.len);
 	strbuf_release(&line);
 	cat_blob_write(buf, size);
@@ -2980,7 +2914,7 @@ static void parse_get_mark(const char *p
 		die("Unknown mark: %s", command_buf.buf);
 
 	xsnprintf(output, sizeof(output), "%s\n", oid_to_hex(&oe->idx.oid));
-	cat_blob_write(output, GIT_SHA1_HEXSZ + 1);
+	cat_blob_write(output, the_hash_algo->hexsz + 1);
 }
 
 static void parse_cat_blob(const char *p)
@@ -3010,6 +2944,8 @@ static struct object_entry *dereference(
 {
 	unsigned long size;
 	char *buf = NULL;
+	const unsigned hexsz = the_hash_algo->hexsz;
+
 	if (!oe) {
 		enum object_type type = oid_object_info(the_repository, oid,
 							NULL);
@@ -3043,12 +2979,12 @@ static struct object_entry *dereference(
 	/* Peel one layer. */
 	switch (oe->type) {
 	case OBJ_TAG:
-		if (size < GIT_SHA1_HEXSZ + strlen("object ") ||
+		if (size < hexsz + strlen("object ") ||
 		    get_oid_hex(buf + strlen("object "), oid))
 			die("Invalid SHA1 in tag: %s", command_buf.buf);
 		break;
 	case OBJ_COMMIT:
-		if (size < GIT_SHA1_HEXSZ + strlen("tree ") ||
+		if (size < hexsz + strlen("tree ") ||
 		    get_oid_hex(buf + strlen("tree "), oid))
 			die("Invalid SHA1 in commit: %s", command_buf.buf);
 	}
@@ -3080,7 +3016,7 @@ static struct object_entry *parse_treeis
 	return e;
 }
 
-static void print_ls(int mode, const unsigned char *sha1, const char *path)
+static void print_ls(int mode, const unsigned char *hash, const char *path)
 {
 	static struct strbuf line = STRBUF_INIT;
 
@@ -3100,7 +3036,7 @@ static void print_ls(int mode, const uns
 		/* mode SP type SP object_name TAB path LF */
 		strbuf_reset(&line);
 		strbuf_addf(&line, "%06o %s %s\t",
-				mode & ~NO_DELTA, type, sha1_to_hex(sha1));
+				mode & ~NO_DELTA, type, hash_to_hex(hash));
 		quote_c_style(path, &line, NULL, 0);
 		strbuf_addch(&line, '\n');
 	}
@@ -3175,6 +3111,28 @@ static void parse_progress(void)
 	skip_optional_lf();
 }
 
+static void parse_alias(void)
+{
+	struct object_entry *e;
+	struct branch b;
+
+	skip_optional_lf();
+	read_next_command();
+
+	/* mark ... */
+	parse_mark();
+	if (!next_mark)
+		die(_("Expected 'mark' command, got %s"), command_buf.buf);
+
+	/* to ... */
+	memset(&b, 0, sizeof(b));
+	if (!parse_objectish_with_prefix(&b, "to "))
+		die(_("Expected 'to' command, got %s"), command_buf.buf);
+	e = find_object(&b.oid);
+	assert(e);
+	insert_mark(next_mark, e);
+}
+
 static char* make_fast_import_path(const char *path)
 {
 	if (!relative_marks_paths || is_absolute_path(path))
@@ -3195,7 +3153,6 @@ static void option_import_marks(const ch
 	}
 
 	import_marks_file = make_fast_import_path(marks);
-	safe_create_leading_directories_const(import_marks_file);
 	import_marks_file_from_stream = from_stream;
 	import_marks_file_ignore_missing = ignore_missing;
 }
@@ -3236,7 +3193,6 @@ static void option_active_branches(const
 static void option_export_marks(const char *marks)
 {
 	export_marks_file = make_fast_import_path(marks);
-	safe_create_leading_directories_const(export_marks_file);
 }
 
 static void option_cat_blob_fd(const char *fd)
@@ -3279,10 +3235,12 @@ static int parse_one_option(const char *
 		option_active_branches(option);
 	} else if (skip_prefix(option, "export-pack-edges=", &option)) {
 		option_export_pack_edges(option);
-	} else if (starts_with(option, "quiet")) {
+	} else if (!strcmp(option, "quiet")) {
 		show_stats = 0;
-	} else if (starts_with(option, "stats")) {
+	} else if (!strcmp(option, "stats")) {
 		show_stats = 1;
+	} else if (!strcmp(option, "allow-unsafe-features")) {
+		; /* already handled during early option parsing */
 	} else {
 		return 0;
 	}
@@ -3290,6 +3248,13 @@ static int parse_one_option(const char *
 	return 1;
 }
 
+static void check_unsafe_feature(const char *feature, int from_stream)
+{
+	if (from_stream && !allow_unsafe_features)
+		die(_("feature '%s' forbidden in input without --allow-unsafe-features"),
+		    feature);
+}
+
 static int parse_one_feature(const char *feature, int from_stream)
 {
 	const char *arg;
@@ -3297,11 +3262,16 @@ static int parse_one_feature(const char
 	if (skip_prefix(feature, "date-format=", &arg)) {
 		option_date_format(arg);
 	} else if (skip_prefix(feature, "import-marks=", &arg)) {
+		check_unsafe_feature("import-marks", from_stream);
 		option_import_marks(arg, from_stream, 0);
 	} else if (skip_prefix(feature, "import-marks-if-exists=", &arg)) {
+		check_unsafe_feature("import-marks-if-exists", from_stream);
 		option_import_marks(arg, from_stream, 1);
 	} else if (skip_prefix(feature, "export-marks=", &arg)) {
+		check_unsafe_feature(feature, from_stream);
 		option_export_marks(arg);
+	} else if (!strcmp(feature, "alias")) {
+		; /* Don't die - this feature is supported */
 	} else if (!strcmp(feature, "get-mark")) {
 		; /* Don't die - this feature is supported */
 	} else if (!strcmp(feature, "cat-blob")) {
@@ -3427,6 +3397,20 @@ int cmd_main(int argc, const char **argv
 	avail_tree_table = xcalloc(avail_tree_table_sz, sizeof(struct avail_tree_content*));
 	marks = mem_pool_calloc(&fi_mem_pool, 1, sizeof(struct mark_set));
 
+	/*
+	 * We don't parse most options until after we've seen the set of
+	 * "feature" lines at the start of the stream (which allows the command
+	 * line to override stream data). But we must do an early parse of any
+	 * command-line options that impact how we interpret the feature lines.
+	 */
+	for (i = 1; i < argc; i++) {
+		const char *arg = argv[i];
+		if (*arg != '-' || !strcmp(arg, "--"))
+			break;
+		if (!strcmp(arg, "--allow-unsafe-features"))
+			allow_unsafe_features = 1;
+	}
+
 	global_argc = argc;
 	global_argv = argv;
 
@@ -3442,18 +3426,24 @@ int cmd_main(int argc, const char **argv
 		const char *v;
 		if (!strcmp("blob", command_buf.buf))
 			parse_new_blob();
-		else if (skip_prefix(command_buf.buf, "ls ", &v))
-			parse_ls(v, NULL);
 		else if (skip_prefix(command_buf.buf, "commit ", &v))
 			parse_new_commit(v);
 		else if (skip_prefix(command_buf.buf, "tag ", &v))
 			parse_new_tag(v);
 		else if (skip_prefix(command_buf.buf, "reset ", &v))
 			parse_reset_branch(v);
+		else if (skip_prefix(command_buf.buf, "ls ", &v))
+			parse_ls(v, NULL);
+		else if (skip_prefix(command_buf.buf, "cat-blob ", &v))
+			parse_cat_blob(v);
+		else if (skip_prefix(command_buf.buf, "get-mark ", &v))
+			parse_get_mark(v);
 		else if (!strcmp("checkpoint", command_buf.buf))
 			parse_checkpoint();
 		else if (!strcmp("done", command_buf.buf))
 			break;
+		else if (!strcmp("alias", command_buf.buf))
+			parse_alias();
 		else if (starts_with(command_buf.buf, "progress "))
 			parse_progress();
 		else if (skip_prefix(command_buf.buf, "feature ", &v))
diff -pruN 1.2.1+git2.18.0-1/git/fetch-negotiator.c 1.2.3+git2.25.1-1/git/fetch-negotiator.c
--- 1.2.1+git2.18.0-1/git/fetch-negotiator.c	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/fetch-negotiator.c	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,21 @@
+#include "git-compat-util.h"
+#include "fetch-negotiator.h"
+#include "negotiator/default.h"
+#include "negotiator/skipping.h"
+#include "repository.h"
+
+void fetch_negotiator_init(struct repository *r,
+			   struct fetch_negotiator *negotiator)
+{
+	prepare_repo_settings(r);
+	switch(r->settings.fetch_negotiation_algorithm) {
+	case FETCH_NEGOTIATION_SKIPPING:
+		skipping_negotiator_init(negotiator);
+		return;
+
+	case FETCH_NEGOTIATION_DEFAULT:
+	default:
+		default_negotiator_init(negotiator);
+		return;
+	}
+}
diff -pruN 1.2.1+git2.18.0-1/git/fetch-negotiator.h 1.2.3+git2.25.1-1/git/fetch-negotiator.h
--- 1.2.1+git2.18.0-1/git/fetch-negotiator.h	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/fetch-negotiator.h	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,59 @@
+#ifndef FETCH_NEGOTIATOR_H
+#define FETCH_NEGOTIATOR_H
+
+struct commit;
+struct repository;
+
+/*
+ * An object that supplies the information needed to negotiate the contents of
+ * the to-be-sent packfile during a fetch.
+ *
+ * To set up the negotiator, call fetch_negotiator_init(), then known_common()
+ * (0 or more times), then add_tip() (0 or more times).
+ *
+ * Then, when "have" lines are required, call next(). Call ack() to report what
+ * the server tells us.
+ *
+ * Once negotiation is done, call release(). The negotiator then cannot be used
+ * (unless reinitialized with fetch_negotiator_init()).
+ */
+struct fetch_negotiator {
+	/*
+	 * Before negotiation starts, indicate that the server is known to have
+	 * this commit.
+	 */
+	void (*known_common)(struct fetch_negotiator *, struct commit *);
+
+	/*
+	 * Once this function is invoked, known_common() cannot be invoked any
+	 * more.
+	 *
+	 * Indicate that this commit and all its ancestors are to be checked
+	 * for commonality with the server.
+	 */
+	void (*add_tip)(struct fetch_negotiator *, struct commit *);
+
+	/*
+	 * Once this function is invoked, known_common() and add_tip() cannot
+	 * be invoked any more.
+	 *
+	 * Return the next commit that the client should send as a "have" line.
+	 */
+	const struct object_id *(*next)(struct fetch_negotiator *);
+
+	/*
+	 * Inform the negotiator that the server has the given commit. This
+	 * method must only be called on commits returned by next().
+	 */
+	int (*ack)(struct fetch_negotiator *, struct commit *);
+
+	void (*release)(struct fetch_negotiator *);
+
+	/* internal use */
+	void *data;
+};
+
+void fetch_negotiator_init(struct repository *r,
+			   struct fetch_negotiator *negotiator);
+
+#endif
diff -pruN 1.2.1+git2.18.0-1/git/fetch-object.c 1.2.3+git2.25.1-1/git/fetch-object.c
--- 1.2.1+git2.18.0-1/git/fetch-object.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/fetch-object.c	1970-01-01 00:00:00.000000000 +0000
@@ -1,45 +0,0 @@
-#include "cache.h"
-#include "packfile.h"
-#include "pkt-line.h"
-#include "strbuf.h"
-#include "transport.h"
-#include "fetch-object.h"
-
-static void fetch_refs(const char *remote_name, struct ref *ref)
-{
-	struct remote *remote;
-	struct transport *transport;
-	int original_fetch_if_missing = fetch_if_missing;
-
-	fetch_if_missing = 0;
-	remote = remote_get(remote_name);
-	if (!remote->url[0])
-		die(_("Remote with no URL"));
-	transport = transport_get(remote, remote->url[0]);
-
-	transport_set_option(transport, TRANS_OPT_FROM_PROMISOR, "1");
-	transport_set_option(transport, TRANS_OPT_NO_DEPENDENTS, "1");
-	transport_fetch_refs(transport, ref);
-	fetch_if_missing = original_fetch_if_missing;
-}
-
-void fetch_object(const char *remote_name, const unsigned char *sha1)
-{
-	struct ref *ref = alloc_ref(sha1_to_hex(sha1));
-	hashcpy(ref->old_oid.hash, sha1);
-	fetch_refs(remote_name, ref);
-}
-
-void fetch_objects(const char *remote_name, const struct oid_array *to_fetch)
-{
-	struct ref *ref = NULL;
-	int i;
-
-	for (i = 0; i < to_fetch->nr; i++) {
-		struct ref *new_ref = alloc_ref(oid_to_hex(&to_fetch->oid[i]));
-		oidcpy(&new_ref->old_oid, &to_fetch->oid[i]);
-		new_ref->next = ref;
-		ref = new_ref;
-	}
-	fetch_refs(remote_name, ref);
-}
diff -pruN 1.2.1+git2.18.0-1/git/fetch-object.h 1.2.3+git2.25.1-1/git/fetch-object.h
--- 1.2.1+git2.18.0-1/git/fetch-object.h	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/fetch-object.h	1970-01-01 00:00:00.000000000 +0000
@@ -1,11 +0,0 @@
-#ifndef FETCH_OBJECT_H
-#define FETCH_OBJECT_H
-
-#include "sha1-array.h"
-
-extern void fetch_object(const char *remote_name, const unsigned char *sha1);
-
-extern void fetch_objects(const char *remote_name,
-			  const struct oid_array *to_fetch);
-
-#endif
diff -pruN 1.2.1+git2.18.0-1/git/fetch-pack.c 1.2.3+git2.25.1-1/git/fetch-pack.c
--- 1.2.1+git2.18.0-1/git/fetch-pack.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/fetch-pack.c	2020-02-17 04:47:35.000000000 +0000
@@ -15,10 +15,13 @@
 #include "connect.h"
 #include "transport.h"
 #include "version.h"
-#include "prio-queue.h"
 #include "sha1-array.h"
 #include "oidset.h"
 #include "packfile.h"
+#include "object-store.h"
+#include "connected.h"
+#include "fetch-negotiator.h"
+#include "fsck.h"
 
 static int transfer_unpack_limit = -1;
 static int fetch_unpack_limit = -1;
@@ -33,16 +36,11 @@ static int agent_supported;
 static int server_supports_filtering;
 static struct lock_file shallow_lock;
 static const char *alternate_shallow_file;
+static struct strbuf fsck_msg_types = STRBUF_INIT;
 
 /* Remember to update object flag allocation in object.h */
 #define COMPLETE	(1U << 0)
-#define COMMON		(1U << 1)
-#define COMMON_REF	(1U << 2)
-#define SEEN		(1U << 3)
-#define POPPED		(1U << 4)
-#define ALTERNATE	(1U << 5)
-
-static int marked;
+#define ALTERNATE	(1U << 1)
 
 /*
  * After sending this many "have"s if we do not get any new ACK , we
@@ -50,8 +48,7 @@ static int marked;
  */
 #define MAX_IN_VAIN 256
 
-static struct prio_queue rev_list = { compare_commits_by_commit_date };
-static int non_common_revs, multi_ack, use_sideband;
+static int multi_ack, use_sideband;
 /* Allow specifying sha1 if it is a ref tip. */
 #define ALLOW_TIP_SHA1	01
 /* Allow request of a sha1 if it is reachable from a ref (possibly hidden ref). */
@@ -78,12 +75,11 @@ struct alternate_object_cache {
 	size_t nr, alloc;
 };
 
-static void cache_one_alternate(const char *refname,
-				const struct object_id *oid,
+static void cache_one_alternate(const struct object_id *oid,
 				void *vcache)
 {
 	struct alternate_object_cache *cache = vcache;
-	struct object *obj = parse_object(oid);
+	struct object *obj = parse_object(the_repository, oid);
 
 	if (!obj || (obj->flags & ALTERNATE))
 		return;
@@ -93,7 +89,9 @@ static void cache_one_alternate(const ch
 	cache->items[cache->nr++] = obj;
 }
 
-static void for_each_cached_alternate(void (*cb)(struct object *))
+static void for_each_cached_alternate(struct fetch_negotiator *negotiator,
+				      void (*cb)(struct fetch_negotiator *,
+						 struct object *))
 {
 	static int initialized;
 	static struct alternate_object_cache cache;
@@ -105,30 +103,19 @@ static void for_each_cached_alternate(vo
 	}
 
 	for (i = 0; i < cache.nr; i++)
-		cb(cache.items[i]);
+		cb(negotiator, cache.items[i]);
 }
 
-static void rev_list_push(struct commit *commit, int mark)
+static int rev_list_insert_ref(struct fetch_negotiator *negotiator,
+			       const char *refname,
+			       const struct object_id *oid)
 {
-	if (!(commit->object.flags & mark)) {
-		commit->object.flags |= mark;
-
-		if (parse_commit(commit))
-			return;
-
-		prio_queue_put(&rev_list, commit);
-
-		if (!(commit->object.flags & COMMON))
-			non_common_revs++;
-	}
-}
-
-static int rev_list_insert_ref(const char *refname, const struct object_id *oid)
-{
-	struct object *o = deref_tag(parse_object(oid), refname, 0);
+	struct object *o = deref_tag(the_repository,
+				     parse_object(the_repository, oid),
+				     refname, 0);
 
 	if (o && o->type == OBJ_COMMIT)
-		rev_list_push((struct commit *)o, SEEN);
+		negotiator->add_tip(negotiator, (struct commit *)o);
 
 	return 0;
 }
@@ -136,98 +123,7 @@ static int rev_list_insert_ref(const cha
 static int rev_list_insert_ref_oid(const char *refname, const struct object_id *oid,
 				   int flag, void *cb_data)
 {
-	return rev_list_insert_ref(refname, oid);
-}
-
-static int clear_marks(const char *refname, const struct object_id *oid,
-		       int flag, void *cb_data)
-{
-	struct object *o = deref_tag(parse_object(oid), refname, 0);
-
-	if (o && o->type == OBJ_COMMIT)
-		clear_commit_marks((struct commit *)o,
-				   COMMON | COMMON_REF | SEEN | POPPED);
-	return 0;
-}
-
-/*
-   This function marks a rev and its ancestors as common.
-   In some cases, it is desirable to mark only the ancestors (for example
-   when only the server does not yet know that they are common).
-*/
-
-static void mark_common(struct commit *commit,
-		int ancestors_only, int dont_parse)
-{
-	if (commit != NULL && !(commit->object.flags & COMMON)) {
-		struct object *o = (struct object *)commit;
-
-		if (!ancestors_only)
-			o->flags |= COMMON;
-
-		if (!(o->flags & SEEN))
-			rev_list_push(commit, SEEN);
-		else {
-			struct commit_list *parents;
-
-			if (!ancestors_only && !(o->flags & POPPED))
-				non_common_revs--;
-			if (!o->parsed && !dont_parse)
-				if (parse_commit(commit))
-					return;
-
-			for (parents = commit->parents;
-					parents;
-					parents = parents->next)
-				mark_common(parents->item, 0, dont_parse);
-		}
-	}
-}
-
-/*
-  Get the next rev to send, ignoring the common.
-*/
-
-static const struct object_id *get_rev(void)
-{
-	struct commit *commit = NULL;
-
-	while (commit == NULL) {
-		unsigned int mark;
-		struct commit_list *parents;
-
-		if (rev_list.nr == 0 || non_common_revs == 0)
-			return NULL;
-
-		commit = prio_queue_get(&rev_list);
-		parse_commit(commit);
-		parents = commit->parents;
-
-		commit->object.flags |= POPPED;
-		if (!(commit->object.flags & COMMON))
-			non_common_revs--;
-
-		if (commit->object.flags & COMMON) {
-			/* do not send "have", and ignore ancestors */
-			commit = NULL;
-			mark = COMMON | SEEN;
-		} else if (commit->object.flags & COMMON_REF)
-			/* send "have", and ignore ancestors */
-			mark = COMMON | SEEN;
-		else
-			/* send "have", also for its ancestors */
-			mark = SEEN;
-
-		while (parents) {
-			if (!(parents->item->object.flags & SEEN))
-				rev_list_push(parents->item, mark);
-			if (mark & COMMON)
-				mark_common(parents->item, 1, 0);
-			parents = parents->next;
-		}
-	}
-
-	return &commit->object.oid;
+	return rev_list_insert_ref(cb_data, refname, oid);
 }
 
 enum ack_type {
@@ -238,52 +134,54 @@ enum ack_type {
 	ACK_ready
 };
 
-static void consume_shallow_list(struct fetch_pack_args *args, int fd)
+static void consume_shallow_list(struct fetch_pack_args *args,
+				 struct packet_reader *reader)
 {
 	if (args->stateless_rpc && args->deepen) {
 		/* If we sent a depth we will get back "duplicate"
 		 * shallow and unshallow commands every time there
 		 * is a block of have lines exchanged.
 		 */
-		char *line;
-		while ((line = packet_read_line(fd, NULL))) {
-			if (starts_with(line, "shallow "))
+		while (packet_reader_read(reader) == PACKET_READ_NORMAL) {
+			if (starts_with(reader->line, "shallow "))
 				continue;
-			if (starts_with(line, "unshallow "))
+			if (starts_with(reader->line, "unshallow "))
 				continue;
 			die(_("git fetch-pack: expected shallow list"));
 		}
+		if (reader->status != PACKET_READ_FLUSH)
+			die(_("git fetch-pack: expected a flush packet after shallow list"));
 	}
 }
 
-static enum ack_type get_ack(int fd, struct object_id *result_oid)
+static enum ack_type get_ack(struct packet_reader *reader,
+			     struct object_id *result_oid)
 {
 	int len;
-	char *line = packet_read_line(fd, &len);
 	const char *arg;
 
-	if (!line)
+	if (packet_reader_read(reader) != PACKET_READ_NORMAL)
 		die(_("git fetch-pack: expected ACK/NAK, got a flush packet"));
-	if (!strcmp(line, "NAK"))
+	len = reader->pktlen;
+
+	if (!strcmp(reader->line, "NAK"))
 		return NAK;
-	if (skip_prefix(line, "ACK ", &arg)) {
-		if (!get_oid_hex(arg, result_oid)) {
-			arg += 40;
-			len -= arg - line;
+	if (skip_prefix(reader->line, "ACK ", &arg)) {
+		const char *p;
+		if (!parse_oid_hex(arg, result_oid, &p)) {
+			len -= p - reader->line;
 			if (len < 1)
 				return ACK;
-			if (strstr(arg, "continue"))
+			if (strstr(p, "continue"))
 				return ACK_continue;
-			if (strstr(arg, "common"))
+			if (strstr(p, "common"))
 				return ACK_common;
-			if (strstr(arg, "ready"))
+			if (strstr(p, "ready"))
 				return ACK_ready;
 			return ACK;
 		}
 	}
-	if (skip_prefix(line, "ERR ", &arg))
-		die(_("remote error: %s"), arg);
-	die(_("git fetch-pack: expected ACK/NAK, got '%s'"), line);
+	die(_("git fetch-pack: expected ACK/NAK, got '%s'"), reader->line);
 }
 
 static void send_request(struct fetch_pack_args *args,
@@ -292,13 +190,16 @@ static void send_request(struct fetch_pa
 	if (args->stateless_rpc) {
 		send_sideband(fd, -1, buf->buf, buf->len, LARGE_PACKET_MAX);
 		packet_flush(fd);
-	} else
-		write_or_die(fd, buf->buf, buf->len);
+	} else {
+		if (write_in_full(fd, buf->buf, buf->len) < 0)
+			die_errno(_("unable to write to remote"));
+	}
 }
 
-static void insert_one_alternate_object(struct object *obj)
+static void insert_one_alternate_object(struct fetch_negotiator *negotiator,
+					struct object *obj)
 {
-	rev_list_insert_ref(NULL, &obj->oid);
+	rev_list_insert_ref(negotiator, NULL, &obj->oid);
 }
 
 #define INITIAL_FLUSH 16
@@ -321,7 +222,24 @@ static int next_flush(int stateless_rpc,
 	return count;
 }
 
-static int find_common(struct fetch_pack_args *args,
+static void mark_tips(struct fetch_negotiator *negotiator,
+		      const struct oid_array *negotiation_tips)
+{
+	int i;
+
+	if (!negotiation_tips) {
+		for_each_ref(rev_list_insert_ref_oid, negotiator);
+		return;
+	}
+
+	for (i = 0; i < negotiation_tips->nr; i++)
+		rev_list_insert_ref(negotiator, NULL,
+				    &negotiation_tips->oid[i]);
+	return;
+}
+
+static int find_common(struct fetch_negotiator *negotiator,
+		       struct fetch_pack_args *args,
 		       int fd[2], struct object_id *result_oid,
 		       struct ref *refs)
 {
@@ -333,15 +251,19 @@ static int find_common(struct fetch_pack
 	int got_ready = 0;
 	struct strbuf req_buf = STRBUF_INIT;
 	size_t state_len = 0;
+	struct packet_reader reader;
 
 	if (args->stateless_rpc && multi_ack == 1)
 		die(_("--stateless-rpc requires multi_ack_detailed"));
-	if (marked)
-		for_each_ref(clear_marks, NULL);
-	marked = 1;
 
-	for_each_ref(rev_list_insert_ref_oid, NULL);
-	for_each_cached_alternate(insert_one_alternate_object);
+	packet_reader_init(&reader, fd[0], NULL, 0,
+			   PACKET_READ_CHOMP_NEWLINE |
+			   PACKET_READ_DIE_ON_ERR_PACKET);
+
+	if (!args->no_dependents) {
+		mark_tips(negotiator, args->negotiation_tips);
+		for_each_cached_alternate(negotiator, insert_one_alternate_object);
+	}
 
 	fetching = 0;
 	for ( ; refs ; refs = refs->next) {
@@ -358,8 +280,12 @@ static int find_common(struct fetch_pack
 		 * We use lookup_object here because we are only
 		 * interested in the case we *know* the object is
 		 * reachable and we have already scanned it.
+		 *
+		 * Do this only if args->no_dependents is false (if it is true,
+		 * we cannot trust the object flags).
 		 */
-		if (((o = lookup_object(remote->hash)) != NULL) &&
+		if (!args->no_dependents &&
+		    ((o = lookup_object(the_repository, remote)) != NULL) &&
 				(o->flags & COMPLETE)) {
 			continue;
 		}
@@ -396,7 +322,7 @@ static int find_common(struct fetch_pack
 		return 1;
 	}
 
-	if (is_repository_shallow())
+	if (is_repository_shallow(the_repository))
 		write_shallow_commits(&req_buf, 1, NULL);
 	if (args->depth > 0)
 		packet_buf_write(&req_buf, "deepen %d", args->depth);
@@ -411,38 +337,39 @@ static int find_common(struct fetch_pack
 			packet_buf_write(&req_buf, "deepen-not %s", s->string);
 		}
 	}
-	if (server_supports_filtering && args->filter_options.choice)
-		packet_buf_write(&req_buf, "filter %s",
-				 args->filter_options.filter_spec);
+	if (server_supports_filtering && args->filter_options.choice) {
+		const char *spec =
+			expand_list_objects_filter_spec(&args->filter_options);
+		packet_buf_write(&req_buf, "filter %s", spec);
+	}
 	packet_buf_flush(&req_buf);
 	state_len = req_buf.len;
 
 	if (args->deepen) {
-		char *line;
 		const char *arg;
 		struct object_id oid;
 
 		send_request(args, fd[1], &req_buf);
-		while ((line = packet_read_line(fd[0], NULL))) {
-			if (skip_prefix(line, "shallow ", &arg)) {
+		while (packet_reader_read(&reader) == PACKET_READ_NORMAL) {
+			if (skip_prefix(reader.line, "shallow ", &arg)) {
 				if (get_oid_hex(arg, &oid))
-					die(_("invalid shallow line: %s"), line);
-				register_shallow(&oid);
+					die(_("invalid shallow line: %s"), reader.line);
+				register_shallow(the_repository, &oid);
 				continue;
 			}
-			if (skip_prefix(line, "unshallow ", &arg)) {
+			if (skip_prefix(reader.line, "unshallow ", &arg)) {
 				if (get_oid_hex(arg, &oid))
-					die(_("invalid unshallow line: %s"), line);
-				if (!lookup_object(oid.hash))
-					die(_("object not found: %s"), line);
+					die(_("invalid unshallow line: %s"), reader.line);
+				if (!lookup_object(the_repository, &oid))
+					die(_("object not found: %s"), reader.line);
 				/* make sure that it is parsed as shallow */
-				if (!parse_object(&oid))
-					die(_("error in object: %s"), line);
+				if (!parse_object(the_repository, &oid))
+					die(_("error in object: %s"), reader.line);
 				if (unregister_shallow(&oid))
-					die(_("no shallow found: %s"), line);
+					die(_("no shallow found: %s"), reader.line);
 				continue;
 			}
-			die(_("expected shallow/unshallow, got %s"), line);
+			die(_("expected shallow/unshallow, got %s"), reader.line);
 		}
 	} else if (!args->stateless_rpc)
 		send_request(args, fd[1], &req_buf);
@@ -455,11 +382,12 @@ static int find_common(struct fetch_pack
 		state_len = 0;
 	}
 
+	trace2_region_enter("fetch-pack", "negotiation_v0_v1", the_repository);
 	flushes = 0;
 	retval = -1;
 	if (args->no_dependents)
 		goto done;
-	while ((oid = get_rev())) {
+	while ((oid = negotiator->next(negotiator))) {
 		packet_buf_write(&req_buf, "have %s\n", oid_to_hex(oid));
 		print_verbose(args, "have %s", oid_to_hex(oid));
 		in_vain++;
@@ -479,9 +407,9 @@ static int find_common(struct fetch_pack
 			if (!args->stateless_rpc && count == INITIAL_FLUSH)
 				continue;
 
-			consume_shallow_list(args, fd[0]);
+			consume_shallow_list(args, &reader);
 			do {
-				ack = get_ack(fd[0], result_oid);
+				ack = get_ack(&reader, result_oid);
 				if (ack)
 					print_verbose(args, _("got %s %d %s"), "ack",
 						      ack, oid_to_hex(result_oid));
@@ -495,12 +423,16 @@ static int find_common(struct fetch_pack
 				case ACK_ready:
 				case ACK_continue: {
 					struct commit *commit =
-						lookup_commit(result_oid);
+						lookup_commit(the_repository,
+							      result_oid);
+					int was_common;
+
 					if (!commit)
 						die(_("invalid commit %s"), oid_to_hex(result_oid));
+					was_common = negotiator->ack(negotiator, commit);
 					if (args->stateless_rpc
 					 && ack == ACK_common
-					 && !(commit->object.flags & COMMON)) {
+					 && !was_common) {
 						/* We need to replay the have for this object
 						 * on the next RPC request so the peer knows
 						 * it is in common with us.
@@ -517,13 +449,10 @@ static int find_common(struct fetch_pack
 					} else if (!args->stateless_rpc
 						   || ack != ACK_common)
 						in_vain = 0;
-					mark_common(commit, 0, 1);
 					retval = 0;
 					got_continue = 1;
-					if (ack == ACK_ready) {
-						clear_prio_queue(&rev_list);
+					if (ack == ACK_ready)
 						got_ready = 1;
-					}
 					break;
 					}
 				}
@@ -533,9 +462,12 @@ static int find_common(struct fetch_pack
 				print_verbose(args, _("giving up"));
 				break; /* give up */
 			}
+			if (got_ready)
+				break;
 		}
 	}
 done:
+	trace2_region_leave("fetch-pack", "negotiation_v0_v1", the_repository);
 	if (!got_ready || !no_done) {
 		packet_buf_write(&req_buf, "done\n");
 		send_request(args, fd[1], &req_buf);
@@ -548,9 +480,9 @@ done:
 	strbuf_release(&req_buf);
 
 	if (!got_ready || !no_done)
-		consume_shallow_list(args, fd[0]);
+		consume_shallow_list(args, &reader);
 	while (flushes || multi_ack) {
-		int ack = get_ack(fd[0], result_oid);
+		int ack = get_ack(&reader, result_oid);
 		if (ack) {
 			print_verbose(args, _("got %s (%d) %s"), "ack",
 				      ack, oid_to_hex(result_oid));
@@ -569,14 +501,14 @@ static struct commit_list *complete;
 
 static int mark_complete(const struct object_id *oid)
 {
-	struct object *o = parse_object(oid);
+	struct object *o = parse_object(the_repository, oid);
 
 	while (o && o->type == OBJ_TAG) {
 		struct tag *t = (struct tag *) o;
 		if (!t->tagged)
 			break; /* broken repository */
 		o->flags |= COMPLETE;
-		o = parse_object(&t->tagged->oid);
+		o = parse_object(the_repository, &t->tagged->oid);
 	}
 	if (o && o->type == OBJ_COMMIT) {
 		struct commit *commit = (struct commit *)o;
@@ -610,21 +542,14 @@ static void add_refs_to_oidset(struct oi
 		oidset_insert(oids, &refs->old_oid);
 }
 
-static int tip_oids_contain(struct oidset *tip_oids,
-			    struct ref *unmatched, struct ref *newlist,
-			    const struct object_id *id)
+static int is_unmatched_ref(const struct ref *ref)
 {
-	/*
-	 * Note that this only looks at the ref lists the first time it's
-	 * called. This works out in filter_refs() because even though it may
-	 * add to "newlist" between calls, the additions will always be for
-	 * oids that are already in the set.
-	 */
-	if (!tip_oids->map.map.tablesize) {
-		add_refs_to_oidset(tip_oids, unmatched);
-		add_refs_to_oidset(tip_oids, newlist);
-	}
-	return oidset_contains(tip_oids, id);
+	struct object_id oid;
+	const char *p;
+	return	ref->match_status == REF_NOT_MATCHED &&
+		!parse_oid_hex(ref->name, &oid, &p) &&
+		*p == '\0' &&
+		oideq(&oid, &ref->old_oid);
 }
 
 static void filter_refs(struct fetch_pack_args *args,
@@ -637,6 +562,8 @@ static void filter_refs(struct fetch_pac
 	struct ref *ref, *next;
 	struct oidset tip_oids = OIDSET_INIT;
 	int i;
+	int strict = !(allow_unadvertised_object_request &
+		       (ALLOW_TIP_SHA1 | ALLOW_REACHABLE_SHA1));
 
 	i = 0;
 	for (ref = *refs; ref; ref = next) {
@@ -644,9 +571,14 @@ static void filter_refs(struct fetch_pac
 		next = ref->next;
 
 		if (starts_with(ref->name, "refs/") &&
-		    check_refname_format(ref->name, 0))
-			; /* trash */
-		else {
+		    check_refname_format(ref->name, 0)) {
+			/*
+			 * trash or a peeled value; do not even add it to
+			 * unmatched list
+			 */
+			free_one_ref(ref);
+			continue;
+		} else {
 			while (i < nr_sought) {
 				int cmp = strcmp(ref->name, sought[i]->name);
 				if (cmp < 0)
@@ -657,11 +589,11 @@ static void filter_refs(struct fetch_pac
 				}
 				i++;
 			}
-		}
 
-		if (!keep && args->fetch_all &&
-		    (!args->deepen || !starts_with(ref->name, "refs/tags/")))
-			keep = 1;
+			if (!keep && args->fetch_all &&
+			    (!args->deepen || !starts_with(ref->name, "refs/tags/")))
+				keep = 1;
+		}
 
 		if (keep) {
 			*newtail = ref;
@@ -673,23 +605,25 @@ static void filter_refs(struct fetch_pac
 		}
 	}
 
+	if (strict) {
+		for (i = 0; i < nr_sought; i++) {
+			ref = sought[i];
+			if (!is_unmatched_ref(ref))
+				continue;
+
+			add_refs_to_oidset(&tip_oids, unmatched);
+			add_refs_to_oidset(&tip_oids, newlist);
+			break;
+		}
+	}
+
 	/* Append unmatched requests to the list */
 	for (i = 0; i < nr_sought; i++) {
-		struct object_id oid;
-		const char *p;
-
 		ref = sought[i];
-		if (ref->match_status != REF_NOT_MATCHED)
-			continue;
-		if (parse_oid_hex(ref->name, &oid, &p) ||
-		    *p != '\0' ||
-		    oidcmp(&oid, &ref->old_oid))
+		if (!is_unmatched_ref(ref))
 			continue;
 
-		if ((allow_unadvertised_object_request &
-		     (ALLOW_TIP_SHA1 | ALLOW_REACHABLE_SHA1)) ||
-		    tip_oids_contain(&tip_oids, unmatched, newlist,
-				     &ref->old_oid)) {
+		if (!strict || oidset_contains(&tip_oids, &ref->old_oid)) {
 			ref->match_status = REF_MATCHED;
 			*newtail = copy_ref(ref);
 			newtail = &(*newtail)->next;
@@ -699,15 +633,13 @@ static void filter_refs(struct fetch_pac
 	}
 
 	oidset_clear(&tip_oids);
-	for (ref = unmatched; ref; ref = next) {
-		next = ref->next;
-		free(ref);
-	}
+	free_refs(unmatched);
 
 	*refs = newlist;
 }
 
-static void mark_alternate_complete(struct object *obj)
+static void mark_alternate_complete(struct fetch_negotiator *unused,
+				    struct object *obj)
 {
 	mark_complete(&obj->oid);
 }
@@ -718,60 +650,39 @@ struct loose_object_iter {
 };
 
 /*
- *  If the number of refs is not larger than the number of loose objects,
- *  this function stops inserting.
+ * Mark recent commits available locally and reachable from a local ref as
+ * COMPLETE. If args->no_dependents is false, also mark COMPLETE remote refs as
+ * COMMON_REF (otherwise, we are not planning to participate in negotiation, and
+ * thus do not need COMMON_REF marks).
+ *
+ * The cutoff time for recency is determined by this heuristic: it is the
+ * earliest commit time of the objects in refs that are commits and that we know
+ * the commit time of.
  */
-static int add_loose_objects_to_set(const struct object_id *oid,
-				    const char *path,
-				    void *data)
-{
-	struct loose_object_iter *iter = data;
-	oidset_insert(iter->loose_object_set, oid);
-	if (iter->refs == NULL)
-		return 1;
-
-	iter->refs = iter->refs->next;
-	return 0;
-}
-
-static int everything_local(struct fetch_pack_args *args,
-			    struct ref **refs,
-			    struct ref **sought, int nr_sought)
+static void mark_complete_and_common_ref(struct fetch_negotiator *negotiator,
+					 struct fetch_pack_args *args,
+					 struct ref **refs)
 {
 	struct ref *ref;
-	int retval;
 	int old_save_commit_buffer = save_commit_buffer;
 	timestamp_t cutoff = 0;
-	struct oidset loose_oid_set = OIDSET_INIT;
-	int use_oidset = 0;
-	struct loose_object_iter iter = {&loose_oid_set, *refs};
-
-	/* Enumerate all loose objects or know refs are not so many. */
-	use_oidset = !for_each_loose_object(add_loose_objects_to_set,
-					    &iter, 0);
 
 	save_commit_buffer = 0;
 
+	trace2_region_enter("fetch-pack", "parse_remote_refs_and_find_cutoff", NULL);
 	for (ref = *refs; ref; ref = ref->next) {
 		struct object *o;
-		unsigned int flags = OBJECT_INFO_QUICK;
-
-		if (use_oidset &&
-		    !oidset_contains(&loose_oid_set, &ref->old_oid)) {
-			/*
-			 * I know this does not exist in the loose form,
-			 * so check if it exists in a non-loose form.
-			 */
-			flags |= OBJECT_INFO_IGNORE_LOOSE;
-		}
 
-		if (!has_object_file_with_flags(&ref->old_oid, flags))
+		if (!has_object_file_with_flags(&ref->old_oid,
+						OBJECT_INFO_QUICK |
+							OBJECT_INFO_SKIP_FETCH_OBJECT))
 			continue;
-		o = parse_object(&ref->old_oid);
+		o = parse_object(the_repository, &ref->old_oid);
 		if (!o)
 			continue;
 
-		/* We already have it -- which may mean that we were
+		/*
+		 * We already have it -- which may mean that we were
 		 * in sync with the other side at some time after
 		 * that (it is OK if we guess wrong here).
 		 */
@@ -781,44 +692,59 @@ static int everything_local(struct fetch
 				cutoff = commit->date;
 		}
 	}
+	trace2_region_leave("fetch-pack", "parse_remote_refs_and_find_cutoff", NULL);
 
-	oidset_clear(&loose_oid_set);
-
-	if (!args->no_dependents) {
-		if (!args->deepen) {
-			for_each_ref(mark_complete_oid, NULL);
-			for_each_cached_alternate(mark_alternate_complete);
-			commit_list_sort_by_date(&complete);
-			if (cutoff)
-				mark_recent_complete_commits(args, cutoff);
-		}
-
-		/*
-		 * Mark all complete remote refs as common refs.
-		 * Don't mark them common yet; the server has to be told so first.
-		 */
-		for (ref = *refs; ref; ref = ref->next) {
-			struct object *o = deref_tag(lookup_object(ref->old_oid.hash),
-						     NULL, 0);
+	/*
+	 * This block marks all local refs as COMPLETE, and then recursively marks all
+	 * parents of those refs as COMPLETE.
+	 */
+	trace2_region_enter("fetch-pack", "mark_complete_local_refs", NULL);
+	if (!args->deepen) {
+		for_each_ref(mark_complete_oid, NULL);
+		for_each_cached_alternate(NULL, mark_alternate_complete);
+		commit_list_sort_by_date(&complete);
+		if (cutoff)
+			mark_recent_complete_commits(args, cutoff);
+	}
+	trace2_region_leave("fetch-pack", "mark_complete_local_refs", NULL);
 
-			if (!o || o->type != OBJ_COMMIT || !(o->flags & COMPLETE))
-				continue;
+	/*
+	 * Mark all complete remote refs as common refs.
+	 * Don't mark them common yet; the server has to be told so first.
+	 */
+	trace2_region_enter("fetch-pack", "mark_common_remote_refs", NULL);
+	for (ref = *refs; ref; ref = ref->next) {
+		struct object *o = deref_tag(the_repository,
+					     lookup_object(the_repository,
+					     &ref->old_oid),
+					     NULL, 0);
 
-			if (!(o->flags & SEEN)) {
-				rev_list_push((struct commit *)o, COMMON_REF | SEEN);
+		if (!o || o->type != OBJ_COMMIT || !(o->flags & COMPLETE))
+			continue;
 
-				mark_common((struct commit *)o, 1, 1);
-			}
-		}
+		negotiator->known_common(negotiator,
+					 (struct commit *)o);
 	}
+	trace2_region_leave("fetch-pack", "mark_common_remote_refs", NULL);
 
-	filter_refs(args, refs, sought, nr_sought);
+	save_commit_buffer = old_save_commit_buffer;
+}
+
+/*
+ * Returns 1 if every object pointed to by the given remote refs is available
+ * locally and reachable from a local ref, and 0 otherwise.
+ */
+static int everything_local(struct fetch_pack_args *args,
+			    struct ref **refs)
+{
+	struct ref *ref;
+	int retval;
 
 	for (retval = 1, ref = *refs; ref ; ref = ref->next) {
 		const struct object_id *remote = &ref->old_oid;
 		struct object *o;
 
-		o = lookup_object(remote->hash);
+		o = lookup_object(the_repository, remote);
 		if (!o || !(o->flags & COMPLETE)) {
 			retval = 0;
 			print_verbose(args, "want %s (%s)", oid_to_hex(remote),
@@ -829,8 +755,6 @@ static int everything_local(struct fetch
 			      ref->name);
 	}
 
-	save_commit_buffer = old_save_commit_buffer;
-
 	return retval;
 }
 
@@ -844,8 +768,33 @@ static int sideband_demux(int in, int ou
 	return ret;
 }
 
+static void write_promisor_file(const char *keep_name,
+				struct ref **sought, int nr_sought)
+{
+	struct strbuf promisor_name = STRBUF_INIT;
+	int suffix_stripped;
+	FILE *output;
+	int i;
+
+	strbuf_addstr(&promisor_name, keep_name);
+	suffix_stripped = strbuf_strip_suffix(&promisor_name, ".keep");
+	if (!suffix_stripped)
+		BUG("name of pack lockfile should end with .keep (was '%s')",
+		    keep_name);
+	strbuf_addstr(&promisor_name, ".promisor");
+
+	output = xfopen(promisor_name.buf, "w");
+	for (i = 0; i < nr_sought; i++)
+		fprintf(output, "%s %s\n", oid_to_hex(&sought[i]->old_oid),
+			sought[i]->name);
+	fclose(output);
+
+	strbuf_release(&promisor_name);
+}
+
 static int get_pack(struct fetch_pack_args *args,
-		    int xd[2], char **pack_lockfile)
+		    int xd[2], char **pack_lockfile,
+		    struct ref **sought, int nr_sought)
 {
 	struct async demux;
 	int do_keep = args->keep_pack;
@@ -907,7 +856,13 @@ static int get_pack(struct fetch_pack_ar
 		}
 		if (args->check_self_contained_and_connected)
 			argv_array_push(&cmd.args, "--check-self-contained-and-connected");
-		if (args->from_promisor)
+		/*
+		 * If we're obtaining the filename of a lockfile, we'll use
+		 * that filename to write a .promisor file with more
+		 * information below. If not, we need index-pack to do it for
+		 * us.
+		 */
+		if (!(do_keep && pack_lockfile) && args->from_promisor)
 			argv_array_push(&cmd.args, "--promisor");
 	}
 	else {
@@ -935,7 +890,8 @@ static int get_pack(struct fetch_pack_ar
 			 */
 			argv_array_push(&cmd.args, "--fsck-objects");
 		else
-			argv_array_push(&cmd.args, "--strict");
+			argv_array_pushf(&cmd.args, "--strict%s",
+					 fsck_msg_types.buf);
 	}
 
 	cmd.in = demux.out;
@@ -960,6 +916,14 @@ static int get_pack(struct fetch_pack_ar
 		die(_("%s failed"), cmd_name);
 	if (use_sideband && finish_async(&demux))
 		die(_("error in sideband demultiplexer"));
+
+	/*
+	 * Now that index-pack has succeeded, write the promisor file using the
+	 * obtained .keep filename if necessary
+	 */
+	if (do_keep && pack_lockfile && args->from_promisor)
+		write_promisor_file(*pack_lockfile, sought, nr_sought);
+
 	return 0;
 }
 
@@ -977,87 +941,116 @@ static struct ref *do_fetch_pack(struct
 				 struct shallow_info *si,
 				 char **pack_lockfile)
 {
+	struct repository *r = the_repository;
 	struct ref *ref = copy_ref_list(orig_ref);
 	struct object_id oid;
 	const char *agent_feature;
 	int agent_len;
+	struct fetch_negotiator negotiator_alloc;
+	struct fetch_negotiator *negotiator;
+
+	if (args->no_dependents) {
+		negotiator = NULL;
+	} else {
+		negotiator = &negotiator_alloc;
+		fetch_negotiator_init(r, negotiator);
+	}
 
 	sort_ref_list(&ref, ref_compare_name);
 	QSORT(sought, nr_sought, cmp_ref_by_name);
 
-	if ((args->depth > 0 || is_repository_shallow()) && !server_supports("shallow"))
+	if ((agent_feature = server_feature_value("agent", &agent_len))) {
+		agent_supported = 1;
+		if (agent_len)
+			print_verbose(args, _("Server version is %.*s"),
+				      agent_len, agent_feature);
+	}
+
+	if (server_supports("shallow"))
+		print_verbose(args, _("Server supports %s"), "shallow");
+	else if (args->depth > 0 || is_repository_shallow(r))
 		die(_("Server does not support shallow clients"));
 	if (args->depth > 0 || args->deepen_since || args->deepen_not)
 		args->deepen = 1;
 	if (server_supports("multi_ack_detailed")) {
-		print_verbose(args, _("Server supports multi_ack_detailed"));
+		print_verbose(args, _("Server supports %s"), "multi_ack_detailed");
 		multi_ack = 2;
 		if (server_supports("no-done")) {
-			print_verbose(args, _("Server supports no-done"));
+			print_verbose(args, _("Server supports %s"), "no-done");
 			if (args->stateless_rpc)
 				no_done = 1;
 		}
 	}
 	else if (server_supports("multi_ack")) {
-		print_verbose(args, _("Server supports multi_ack"));
+		print_verbose(args, _("Server supports %s"), "multi_ack");
 		multi_ack = 1;
 	}
 	if (server_supports("side-band-64k")) {
-		print_verbose(args, _("Server supports side-band-64k"));
+		print_verbose(args, _("Server supports %s"), "side-band-64k");
 		use_sideband = 2;
 	}
 	else if (server_supports("side-band")) {
-		print_verbose(args, _("Server supports side-band"));
+		print_verbose(args, _("Server supports %s"), "side-band");
 		use_sideband = 1;
 	}
 	if (server_supports("allow-tip-sha1-in-want")) {
-		print_verbose(args, _("Server supports allow-tip-sha1-in-want"));
+		print_verbose(args, _("Server supports %s"), "allow-tip-sha1-in-want");
 		allow_unadvertised_object_request |= ALLOW_TIP_SHA1;
 	}
 	if (server_supports("allow-reachable-sha1-in-want")) {
-		print_verbose(args, _("Server supports allow-reachable-sha1-in-want"));
+		print_verbose(args, _("Server supports %s"), "allow-reachable-sha1-in-want");
 		allow_unadvertised_object_request |= ALLOW_REACHABLE_SHA1;
 	}
-	if (!server_supports("thin-pack"))
+	if (server_supports("thin-pack"))
+		print_verbose(args, _("Server supports %s"), "thin-pack");
+	else
 		args->use_thin_pack = 0;
-	if (!server_supports("no-progress"))
+	if (server_supports("no-progress"))
+		print_verbose(args, _("Server supports %s"), "no-progress");
+	else
 		args->no_progress = 0;
-	if (!server_supports("include-tag"))
+	if (server_supports("include-tag"))
+		print_verbose(args, _("Server supports %s"), "include-tag");
+	else
 		args->include_tag = 0;
 	if (server_supports("ofs-delta"))
-		print_verbose(args, _("Server supports ofs-delta"));
+		print_verbose(args, _("Server supports %s"), "ofs-delta");
 	else
 		prefer_ofs_delta = 0;
 
 	if (server_supports("filter")) {
 		server_supports_filtering = 1;
-		print_verbose(args, _("Server supports filter"));
+		print_verbose(args, _("Server supports %s"), "filter");
 	} else if (args->filter_options.choice) {
 		warning("filtering not recognized by server, ignoring");
 	}
 
-	if ((agent_feature = server_feature_value("agent", &agent_len))) {
-		agent_supported = 1;
-		if (agent_len)
-			print_verbose(args, _("Server version is %.*s"),
-				      agent_len, agent_feature);
-	}
-	if (server_supports("deepen-since"))
+	if (server_supports("deepen-since")) {
+		print_verbose(args, _("Server supports %s"), "deepen-since");
 		deepen_since_ok = 1;
-	else if (args->deepen_since)
+	} else if (args->deepen_since)
 		die(_("Server does not support --shallow-since"));
-	if (server_supports("deepen-not"))
+	if (server_supports("deepen-not")) {
+		print_verbose(args, _("Server supports %s"), "deepen-not");
 		deepen_not_ok = 1;
-	else if (args->deepen_not)
+	} else if (args->deepen_not)
 		die(_("Server does not support --shallow-exclude"));
-	if (!server_supports("deepen-relative") && args->deepen_relative)
+	if (server_supports("deepen-relative"))
+		print_verbose(args, _("Server supports %s"), "deepen-relative");
+	else if (args->deepen_relative)
 		die(_("Server does not support --deepen"));
 
-	if (everything_local(args, &ref, sought, nr_sought)) {
-		packet_flush(fd[1]);
-		goto all_done;
+	if (!args->no_dependents) {
+		mark_complete_and_common_ref(negotiator, args, &ref);
+		filter_refs(args, &ref, sought, nr_sought);
+		if (everything_local(args, &ref)) {
+			packet_flush(fd[1]);
+			goto all_done;
+		}
+	} else {
+		filter_refs(args, &ref, sought, nr_sought);
 	}
-	if (find_common(args, fd, &oid, ref) < 0)
+	if (find_common(negotiator, args, fd, &oid, ref) < 0)
 		if (!args->keep_pack)
 			/* When cloning, it is not unusual to have
 			 * no common commit.
@@ -1073,17 +1066,19 @@ static struct ref *do_fetch_pack(struct
 		alternate_shallow_file = setup_temporary_shallow(si->shallow);
 	else
 		alternate_shallow_file = NULL;
-	if (get_pack(args, fd, pack_lockfile))
+	if (get_pack(args, fd, pack_lockfile, sought, nr_sought))
 		die(_("git fetch-pack: fetch failed."));
 
  all_done:
+	if (negotiator)
+		negotiator->release(negotiator);
 	return ref;
 }
 
 static void add_shallow_requests(struct strbuf *req_buf,
 				 const struct fetch_pack_args *args)
 {
-	if (is_repository_shallow())
+	if (is_repository_shallow(the_repository))
 		write_shallow_commits(req_buf, 1, NULL);
 	if (args->depth > 0)
 		packet_buf_write(req_buf, "deepen %d", args->depth);
@@ -1098,13 +1093,16 @@ static void add_shallow_requests(struct
 			packet_buf_write(req_buf, "deepen-not %s", s->string);
 		}
 	}
+	if (args->deepen_relative)
+		packet_buf_write(req_buf, "deepen-relative\n");
 }
 
-static void add_wants(const struct ref *wants, struct strbuf *req_buf)
+static void add_wants(int no_dependents, const struct ref *wants, struct strbuf *req_buf)
 {
+	int use_ref_in_want = server_supports_feature("fetch", "ref-in-want", 0);
+
 	for ( ; wants ; wants = wants->next) {
 		const struct object_id *remote = &wants->old_oid;
-		const char *remote_hex;
 		struct object *o;
 
 		/*
@@ -1116,14 +1114,20 @@ static void add_wants(const struct ref *
 		 * We use lookup_object here because we are only
 		 * interested in the case we *know* the object is
 		 * reachable and we have already scanned it.
+		 *
+		 * Do this only if args->no_dependents is false (if it is true,
+		 * we cannot trust the object flags).
 		 */
-		if (((o = lookup_object(remote->hash)) != NULL) &&
+		if (!no_dependents &&
+		    ((o = lookup_object(the_repository, remote)) != NULL) &&
 		    (o->flags & COMPLETE)) {
 			continue;
 		}
 
-		remote_hex = oid_to_hex(remote);
-		packet_buf_write(req_buf, "want %s\n", remote_hex);
+		if (!use_ref_in_want || wants->exact_oid)
+			packet_buf_write(req_buf, "want %s\n", oid_to_hex(remote));
+		else
+			packet_buf_write(req_buf, "want-ref %s\n", wants->name);
 	}
 }
 
@@ -1138,13 +1142,15 @@ static void add_common(struct strbuf *re
 	}
 }
 
-static int add_haves(struct strbuf *req_buf, int *haves_to_send, int *in_vain)
+static int add_haves(struct fetch_negotiator *negotiator,
+		     struct strbuf *req_buf,
+		     int *haves_to_send, int *in_vain)
 {
 	int ret = 0;
 	int haves_added = 0;
 	const struct object_id *oid;
 
-	while ((oid = get_rev())) {
+	while ((oid = negotiator->next(negotiator))) {
 		packet_buf_write(req_buf, "have %s\n", oid_to_hex(oid));
 		if (++haves_added >= *haves_to_send)
 			break;
@@ -1163,9 +1169,11 @@ static int add_haves(struct strbuf *req_
 	return ret;
 }
 
-static int send_fetch_request(int fd_out, const struct fetch_pack_args *args,
+static int send_fetch_request(struct fetch_negotiator *negotiator, int fd_out,
+			      struct fetch_pack_args *args,
 			      const struct ref *wants, struct oidset *common,
-			      int *haves_to_send, int *in_vain)
+			      int *haves_to_send, int *in_vain,
+			      int sideband_all)
 {
 	int ret = 0;
 	struct strbuf req_buf = STRBUF_INIT;
@@ -1178,7 +1186,7 @@ static int send_fetch_request(int fd_out
 	    server_supports_v2("server-option", 1)) {
 		int i;
 		for (i = 0; i < args->server_options->nr; i++)
-			packet_write_fmt(fd_out, "server-option=%s",
+			packet_buf_write(&req_buf, "server-option=%s",
 					 args->server_options->items[i].string);
 	}
 
@@ -1191,25 +1199,28 @@ static int send_fetch_request(int fd_out
 		packet_buf_write(&req_buf, "include-tag");
 	if (prefer_ofs_delta)
 		packet_buf_write(&req_buf, "ofs-delta");
+	if (sideband_all)
+		packet_buf_write(&req_buf, "sideband-all");
 
 	/* Add shallow-info and deepen request */
 	if (server_supports_feature("fetch", "shallow", 0))
 		add_shallow_requests(&req_buf, args);
-	else if (is_repository_shallow() || args->deepen)
+	else if (is_repository_shallow(the_repository) || args->deepen)
 		die(_("Server does not support shallow requests"));
 
 	/* Add filter */
 	if (server_supports_feature("fetch", "filter", 0) &&
 	    args->filter_options.choice) {
+		const char *spec =
+			expand_list_objects_filter_spec(&args->filter_options);
 		print_verbose(args, _("Server supports filter"));
-		packet_buf_write(&req_buf, "filter %s",
-				 args->filter_options.filter_spec);
+		packet_buf_write(&req_buf, "filter %s", spec);
 	} else if (args->filter_options.choice) {
 		warning("filtering not recognized by server, ignoring");
 	}
 
 	/* add wants */
-	add_wants(wants, &req_buf);
+	add_wants(args->no_dependents, wants, &req_buf);
 
 	if (args->no_dependents) {
 		packet_buf_write(&req_buf, "done");
@@ -1219,12 +1230,13 @@ static int send_fetch_request(int fd_out
 		add_common(&req_buf, common);
 
 		/* Add initial haves */
-		ret = add_haves(&req_buf, haves_to_send, in_vain);
+		ret = add_haves(negotiator, &req_buf, haves_to_send, in_vain);
 	}
 
 	/* Send request */
 	packet_buf_flush(&req_buf);
-	write_or_die(fd_out, req_buf.buf, req_buf.len);
+	if (write_in_full(fd_out, req_buf.buf, req_buf.len) < 0)
+		die_errno(_("unable to write request to remote"));
 
 	strbuf_release(&req_buf);
 	return ret;
@@ -1242,13 +1254,13 @@ static int process_section_header(struct
 	int ret;
 
 	if (packet_reader_peek(reader) != PACKET_READ_NORMAL)
-		die("error reading section header '%s'", section);
+		die(_("error reading section header '%s'"), section);
 
 	ret = !strcmp(reader->line, section);
 
 	if (!peek) {
 		if (!ret)
-			die("expected '%s', received '%s'",
+			die(_("expected '%s', received '%s'"),
 			    section, reader->line);
 		packet_reader_read(reader);
 	}
@@ -1256,7 +1268,9 @@ static int process_section_header(struct
 	return ret;
 }
 
-static int process_acks(struct packet_reader *reader, struct oidset *common)
+static int process_acks(struct fetch_negotiator *negotiator,
+			struct packet_reader *reader,
+			struct oidset *common)
 {
 	/* received */
 	int received_ready = 0;
@@ -1274,32 +1288,48 @@ static int process_acks(struct packet_re
 			if (!get_oid_hex(arg, &oid)) {
 				struct commit *commit;
 				oidset_insert(common, &oid);
-				commit = lookup_commit(&oid);
-				mark_common(commit, 0, 1);
+				commit = lookup_commit(the_repository, &oid);
+				if (negotiator)
+					negotiator->ack(negotiator, commit);
 			}
 			continue;
 		}
 
 		if (!strcmp(reader->line, "ready")) {
-			clear_prio_queue(&rev_list);
 			received_ready = 1;
 			continue;
 		}
 
-		die("unexpected acknowledgment line: '%s'", reader->line);
+		die(_("unexpected acknowledgment line: '%s'"), reader->line);
 	}
 
 	if (reader->status != PACKET_READ_FLUSH &&
 	    reader->status != PACKET_READ_DELIM)
-		die("error processing acks: %d", reader->status);
+		die(_("error processing acks: %d"), reader->status);
+
+	/*
+	 * If an "acknowledgments" section is sent, a packfile is sent if and
+	 * only if "ready" was sent in this section. The other sections
+	 * ("shallow-info" and "wanted-refs") are sent only if a packfile is
+	 * sent. Therefore, a DELIM is expected if "ready" is sent, and a FLUSH
+	 * otherwise.
+	 */
+	if (received_ready && reader->status != PACKET_READ_DELIM)
+		die(_("expected packfile to be sent after 'ready'"));
+	if (!received_ready && reader->status != PACKET_READ_FLUSH)
+		die(_("expected no other sections to be sent after no 'ready'"));
 
 	/* return 0 if no common, 1 if there are common, or 2 if ready */
 	return received_ready ? 2 : (received_ack ? 1 : 0);
 }
 
 static void receive_shallow_info(struct fetch_pack_args *args,
-				 struct packet_reader *reader)
+				 struct packet_reader *reader,
+				 struct oid_array *shallows,
+				 struct shallow_info *si)
 {
+	int unshallow_received = 0;
+
 	process_section_header(reader, "shallow-info", 0);
 	while (packet_reader_read(reader) == PACKET_READ_NORMAL) {
 		const char *arg;
@@ -1308,19 +1338,20 @@ static void receive_shallow_info(struct
 		if (skip_prefix(reader->line, "shallow ", &arg)) {
 			if (get_oid_hex(arg, &oid))
 				die(_("invalid shallow line: %s"), reader->line);
-			register_shallow(&oid);
+			oid_array_append(shallows, &oid);
 			continue;
 		}
 		if (skip_prefix(reader->line, "unshallow ", &arg)) {
 			if (get_oid_hex(arg, &oid))
 				die(_("invalid unshallow line: %s"), reader->line);
-			if (!lookup_object(oid.hash))
+			if (!lookup_object(the_repository, &oid))
 				die(_("object not found: %s"), reader->line);
 			/* make sure that it is parsed as shallow */
-			if (!parse_object(&oid))
+			if (!parse_object(the_repository, &oid))
 				die(_("error in object: %s"), reader->line);
 			if (unregister_shallow(&oid))
 				die(_("no shallow found: %s"), reader->line);
+			unshallow_received = 1;
 			continue;
 		}
 		die(_("expected shallow/unshallow, got %s"), reader->line);
@@ -1328,10 +1359,64 @@ static void receive_shallow_info(struct
 
 	if (reader->status != PACKET_READ_FLUSH &&
 	    reader->status != PACKET_READ_DELIM)
-		die("error processing shallow info: %d", reader->status);
+		die(_("error processing shallow info: %d"), reader->status);
+
+	if (args->deepen || unshallow_received) {
+		/*
+		 * Treat these as shallow lines caused by our depth settings.
+		 * In v0, these lines cannot cause refs to be rejected; do the
+		 * same.
+		 */
+		int i;
+
+		for (i = 0; i < shallows->nr; i++)
+			register_shallow(the_repository, &shallows->oid[i]);
+		setup_alternate_shallow(&shallow_lock, &alternate_shallow_file,
+					NULL);
+		args->deepen = 1;
+	} else if (shallows->nr) {
+		/*
+		 * Treat these as shallow lines caused by the remote being
+		 * shallow. In v0, remote refs that reach these objects are
+		 * rejected (unless --update-shallow is set); do the same.
+		 */
+		prepare_shallow_info(si, shallows);
+		if (si->nr_ours || si->nr_theirs)
+			alternate_shallow_file =
+				setup_temporary_shallow(si->shallow);
+		else
+			alternate_shallow_file = NULL;
+	} else {
+		alternate_shallow_file = NULL;
+	}
+}
 
-	setup_alternate_shallow(&shallow_lock, &alternate_shallow_file, NULL);
-	args->deepen = 1;
+static int cmp_name_ref(const void *name, const void *ref)
+{
+	return strcmp(name, (*(struct ref **)ref)->name);
+}
+
+static void receive_wanted_refs(struct packet_reader *reader,
+				struct ref **sought, int nr_sought)
+{
+	process_section_header(reader, "wanted-refs", 0);
+	while (packet_reader_read(reader) == PACKET_READ_NORMAL) {
+		struct object_id oid;
+		const char *end;
+		struct ref **found;
+
+		if (parse_oid_hex(reader->line, &oid, &end) || *end++ != ' ')
+			die(_("expected wanted-ref, got '%s'"), reader->line);
+
+		found = bsearch(end, sought, nr_sought, sizeof(*sought),
+				cmp_name_ref);
+		if (!found)
+			die(_("unexpected wanted-ref: '%s'"), reader->line);
+		oidcpy(&(*found)->old_oid, &oid);
+	}
+
+	if (reader->status != PACKET_READ_DELIM)
+		die(_("error processing wanted refs: %d"), reader->status);
 }
 
 enum fetch_state {
@@ -1346,16 +1431,35 @@ static struct ref *do_fetch_pack_v2(stru
 				    int fd[2],
 				    const struct ref *orig_ref,
 				    struct ref **sought, int nr_sought,
+				    struct oid_array *shallows,
+				    struct shallow_info *si,
 				    char **pack_lockfile)
 {
+	struct repository *r = the_repository;
 	struct ref *ref = copy_ref_list(orig_ref);
 	enum fetch_state state = FETCH_CHECK_LOCAL;
 	struct oidset common = OIDSET_INIT;
 	struct packet_reader reader;
-	int in_vain = 0;
+	int in_vain = 0, negotiation_started = 0;
 	int haves_to_send = INITIAL_FLUSH;
+	struct fetch_negotiator negotiator_alloc;
+	struct fetch_negotiator *negotiator;
+
+	if (args->no_dependents) {
+		negotiator = NULL;
+	} else {
+		negotiator = &negotiator_alloc;
+		fetch_negotiator_init(r, negotiator);
+	}
+
 	packet_reader_init(&reader, fd[0], NULL, 0,
-			   PACKET_READ_CHOMP_NEWLINE);
+			   PACKET_READ_CHOMP_NEWLINE |
+			   PACKET_READ_DIE_ON_ERR_PACKET);
+	if (git_env_bool("GIT_TEST_SIDEBAND_ALL", 1) &&
+	    server_supports_feature("fetch", "sideband-all", 0)) {
+		reader.use_sideband = 1;
+		reader.me = "fetch-pack";
+	}
 
 	while (state != FETCH_DONE) {
 		switch (state) {
@@ -1369,29 +1473,41 @@ static struct ref *do_fetch_pack_v2(stru
 			if (args->depth > 0 || args->deepen_since || args->deepen_not)
 				args->deepen = 1;
 
-			if (marked)
-				for_each_ref(clear_marks, NULL);
-			marked = 1;
-
-			for_each_ref(rev_list_insert_ref_oid, NULL);
-			for_each_cached_alternate(insert_one_alternate_object);
-
 			/* Filter 'ref' by 'sought' and those that aren't local */
-			if (everything_local(args, &ref, sought, nr_sought))
-				state = FETCH_DONE;
-			else
+			if (!args->no_dependents) {
+				mark_complete_and_common_ref(negotiator, args, &ref);
+				filter_refs(args, &ref, sought, nr_sought);
+				if (everything_local(args, &ref))
+					state = FETCH_DONE;
+				else
+					state = FETCH_SEND_REQUEST;
+
+				mark_tips(negotiator, args->negotiation_tips);
+				for_each_cached_alternate(negotiator,
+							  insert_one_alternate_object);
+			} else {
+				filter_refs(args, &ref, sought, nr_sought);
 				state = FETCH_SEND_REQUEST;
+			}
 			break;
 		case FETCH_SEND_REQUEST:
-			if (send_fetch_request(fd[1], args, ref, &common,
-					       &haves_to_send, &in_vain))
+			if (!negotiation_started) {
+				negotiation_started = 1;
+				trace2_region_enter("fetch-pack",
+						    "negotiation_v2",
+						    the_repository);
+			}
+			if (send_fetch_request(negotiator, fd[1], args, ref,
+					       &common,
+					       &haves_to_send, &in_vain,
+					       reader.use_sideband))
 				state = FETCH_GET_PACK;
 			else
 				state = FETCH_PROCESS_ACKS;
 			break;
 		case FETCH_PROCESS_ACKS:
 			/* Process ACKs/NAKs */
-			switch (process_acks(&reader, &common)) {
+			switch (process_acks(negotiator, &reader, &common)) {
 			case 2:
 				state = FETCH_GET_PACK;
 				break;
@@ -1404,13 +1520,19 @@ static struct ref *do_fetch_pack_v2(stru
 			}
 			break;
 		case FETCH_GET_PACK:
+			trace2_region_leave("fetch-pack",
+					    "negotiation_v2",
+					    the_repository);
 			/* Check for shallow-info section */
 			if (process_section_header(&reader, "shallow-info", 1))
-				receive_shallow_info(args, &reader);
+				receive_shallow_info(args, &reader, shallows, si);
+
+			if (process_section_header(&reader, "wanted-refs", 1))
+				receive_wanted_refs(&reader, sought, nr_sought);
 
 			/* get the pack */
 			process_section_header(&reader, "packfile", 0);
-			if (get_pack(args, fd, pack_lockfile))
+			if (get_pack(args, fd, pack_lockfile, sought, nr_sought))
 				die(_("git fetch-pack: fetch failed."));
 
 			state = FETCH_DONE;
@@ -1420,10 +1542,37 @@ static struct ref *do_fetch_pack_v2(stru
 		}
 	}
 
+	if (negotiator)
+		negotiator->release(negotiator);
 	oidset_clear(&common);
 	return ref;
 }
 
+static int fetch_pack_config_cb(const char *var, const char *value, void *cb)
+{
+	if (strcmp(var, "fetch.fsck.skiplist") == 0) {
+		const char *path;
+
+		if (git_config_pathname(&path, var, value))
+			return 1;
+		strbuf_addf(&fsck_msg_types, "%cskiplist=%s",
+			fsck_msg_types.len ? ',' : '=', path);
+		free((char *)path);
+		return 0;
+	}
+
+	if (skip_prefix(var, "fetch.fsck.", &var)) {
+		if (is_valid_msg_type(var, value))
+			strbuf_addf(&fsck_msg_types, "%c%s=%s",
+				fsck_msg_types.len ? ',' : '=', var, value);
+		else
+			warning("Skipping unknown msg id '%s'", var);
+		return 0;
+	}
+
+	return git_default_config(var, value, cb);
+}
+
 static void fetch_pack_config(void)
 {
 	git_config_get_int("fetch.unpacklimit", &fetch_unpack_limit);
@@ -1432,7 +1581,7 @@ static void fetch_pack_config(void)
 	git_config_get_bool("fetch.fsckobjects", &fetch_fsck_objects);
 	git_config_get_bool("transfer.fsckobjects", &transfer_fsck_objects);
 
-	git_config(git_default_config, NULL);
+	git_config(fetch_pack_config_cb, NULL);
 }
 
 static void fetch_pack_setup(void)
@@ -1479,10 +1628,11 @@ static void update_shallow(struct fetch_
 
 	if (args->deepen && alternate_shallow_file) {
 		if (*alternate_shallow_file == '\0') { /* --unshallow */
-			unlink_or_warn(git_path_shallow());
+			unlink_or_warn(git_path_shallow(the_repository));
 			rollback_lock_file(&shallow_lock);
 		} else
 			commit_lock_file(&shallow_lock);
+		alternate_shallow_file = NULL;
 		return;
 	}
 
@@ -1506,6 +1656,7 @@ static void update_shallow(struct fetch_
 						&alternate_shallow_file,
 						&extra);
 			commit_lock_file(&shallow_lock);
+			alternate_shallow_file = NULL;
 		}
 		oid_array_clear(&extra);
 		return;
@@ -1545,6 +1696,7 @@ static void update_shallow(struct fetch_
 		commit_lock_file(&shallow_lock);
 		oid_array_clear(&extra);
 		oid_array_clear(&ref);
+		alternate_shallow_file = NULL;
 		return;
 	}
 
@@ -1563,10 +1715,21 @@ static void update_shallow(struct fetch_
 	oid_array_clear(&ref);
 }
 
+static int iterate_ref_map(void *cb_data, struct object_id *oid)
+{
+	struct ref **rm = cb_data;
+	struct ref *ref = *rm;
+
+	if (!ref)
+		return -1; /* end of the list */
+	*rm = ref->next;
+	oidcpy(oid, &ref->old_oid);
+	return 0;
+}
+
 struct ref *fetch_pack(struct fetch_pack_args *args,
-		       int fd[], struct child_process *conn,
+		       int fd[],
 		       const struct ref *ref,
-		       const char *dest,
 		       struct ref **sought, int nr_sought,
 		       struct oid_array *shallow,
 		       char **pack_lockfile,
@@ -1574,25 +1737,64 @@ struct ref *fetch_pack(struct fetch_pack
 {
 	struct ref *ref_cpy;
 	struct shallow_info si;
+	struct oid_array shallows_scratch = OID_ARRAY_INIT;
 
 	fetch_pack_setup();
 	if (nr_sought)
 		nr_sought = remove_duplicates_in_refs(sought, nr_sought);
 
-	if (!ref) {
+	if (args->no_dependents && !args->filter_options.choice) {
+		/*
+		 * The protocol does not support requesting that only the
+		 * wanted objects be sent, so approximate this by setting a
+		 * "blob:none" filter if no filter is already set. This works
+		 * for all object types: note that wanted blobs will still be
+		 * sent because they are directly specified as a "want".
+		 *
+		 * NEEDSWORK: Add an option in the protocol to request that
+		 * only the wanted objects be sent, and implement it.
+		 */
+		parse_list_objects_filter(&args->filter_options, "blob:none");
+	}
+
+	if (version != protocol_v2 && !ref) {
 		packet_flush(fd[1]);
 		die(_("no matching remote head"));
 	}
-	prepare_shallow_info(&si, shallow);
-	if (version == protocol_v2)
+	if (version == protocol_v2) {
+		if (shallow->nr)
+			BUG("Protocol V2 does not provide shallows at this point in the fetch");
+		memset(&si, 0, sizeof(si));
 		ref_cpy = do_fetch_pack_v2(args, fd, ref, sought, nr_sought,
+					   &shallows_scratch, &si,
 					   pack_lockfile);
-	else
+	} else {
+		prepare_shallow_info(&si, shallow);
 		ref_cpy = do_fetch_pack(args, fd, ref, sought, nr_sought,
 					&si, pack_lockfile);
+	}
 	reprepare_packed_git(the_repository);
+
+	if (!args->cloning && args->deepen) {
+		struct check_connected_options opt = CHECK_CONNECTED_INIT;
+		struct ref *iterator = ref_cpy;
+		opt.shallow_file = alternate_shallow_file;
+		if (args->deepen)
+			opt.is_deepening_fetch = 1;
+		if (check_connected(iterate_ref_map, &iterator, &opt)) {
+			error(_("remote did not send all necessary objects"));
+			free_refs(ref_cpy);
+			ref_cpy = NULL;
+			rollback_lock_file(&shallow_lock);
+			goto cleanup;
+		}
+		args->connectivity_checked = 1;
+	}
+
 	update_shallow(args, sought, nr_sought, &si);
+cleanup:
 	clear_shallow_info(&si);
+	oid_array_clear(&shallows_scratch);
 	return ref_cpy;
 }
 
diff -pruN 1.2.1+git2.18.0-1/git/fetch-pack.h 1.2.3+git2.25.1-1/git/fetch-pack.h
--- 1.2.1+git2.18.0-1/git/fetch-pack.h	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/fetch-pack.h	2020-02-17 04:47:35.000000000 +0000
@@ -16,6 +16,13 @@ struct fetch_pack_args {
 	const struct string_list *deepen_not;
 	struct list_objects_filter_options filter_options;
 	const struct string_list *server_options;
+
+	/*
+	 * If not NULL, during packfile negotiation, fetch-pack will send "have"
+	 * lines only with these tips and their ancestors.
+	 */
+	const struct oid_array *negotiation_tips;
+
 	unsigned deepen_relative:1;
 	unsigned quiet:1;
 	unsigned keep_pack:1;
@@ -36,11 +43,33 @@ struct fetch_pack_args {
 	unsigned from_promisor:1;
 
 	/*
+	 * Attempt to fetch only the wanted objects, and not any objects
+	 * referred to by them. Due to protocol limitations, extraneous
+	 * objects may still be included. (When fetching non-blob
+	 * objects, only blobs are excluded; when fetching a blob, the
+	 * blob itself will still be sent. The client does not need to
+	 * know whether a wanted object is a blob or not.)
+	 *
 	 * If 1, fetch_pack() will also not modify any object flags.
 	 * This allows fetch_pack() to safely be called by any function,
 	 * regardless of which object flags it uses (if any).
 	 */
 	unsigned no_dependents:1;
+
+	/*
+	 * Because fetch_pack() overwrites the shallow file upon a
+	 * successful deepening non-clone fetch, if this struct
+	 * specifies such a fetch, fetch_pack() needs to perform a
+	 * connectivity check before deciding if a fetch is successful
+	 * (and overwriting the shallow file). fetch_pack() sets this
+	 * field to 1 if such a connectivity check was performed.
+	 *
+	 * This is different from check_self_contained_and_connected
+	 * in that the former allows existing objects in the
+	 * repository to satisfy connectivity needs, whereas the
+	 * latter doesn't.
+	 */
+	unsigned connectivity_checked:1;
 };
 
 /*
@@ -49,9 +78,8 @@ struct fetch_pack_args {
  * marked as such.
  */
 struct ref *fetch_pack(struct fetch_pack_args *args,
-		       int fd[], struct child_process *conn,
+		       int fd[],
 		       const struct ref *ref,
-		       const char *dest,
 		       struct ref **sought,
 		       int nr_sought,
 		       struct oid_array *shallow,
diff -pruN 1.2.1+git2.18.0-1/git/fmt-merge-msg.h 1.2.3+git2.25.1-1/git/fmt-merge-msg.h
--- 1.2.1+git2.18.0-1/git/fmt-merge-msg.h	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/fmt-merge-msg.h	2020-02-17 04:47:35.000000000 +0000
@@ -2,6 +2,6 @@
 #define FMT_MERGE_MSG_H
 
 extern int merge_log_config;
-extern int fmt_merge_msg_config(const char *key, const char *value, void *cb);
+int fmt_merge_msg_config(const char *key, const char *value, void *cb);
 
 #endif /* FMT_MERGE_MSG_H */
diff -pruN 1.2.1+git2.18.0-1/git/fsck.c 1.2.3+git2.25.1-1/git/fsck.c
--- 1.2.1+git2.18.0-1/git/fsck.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/fsck.c	2020-02-17 04:47:35.000000000 +0000
@@ -1,4 +1,6 @@
 #include "cache.h"
+#include "object-store.h"
+#include "repository.h"
 #include "object.h"
 #include "blob.h"
 #include "tree.h"
@@ -8,12 +10,12 @@
 #include "fsck.h"
 #include "refs.h"
 #include "utf8.h"
-#include "sha1-array.h"
 #include "decorate.h"
 #include "oidset.h"
 #include "packfile.h"
 #include "submodule-config.h"
 #include "config.h"
+#include "help.h"
 
 static struct oidset gitmodules_found = OIDSET_INIT;
 static struct oidset gitmodules_done = OIDSET_INIT;
@@ -41,29 +43,28 @@ static struct oidset gitmodules_done = O
 	FUNC(MISSING_AUTHOR, ERROR) \
 	FUNC(MISSING_COMMITTER, ERROR) \
 	FUNC(MISSING_EMAIL, ERROR) \
-	FUNC(MISSING_GRAFT, ERROR) \
 	FUNC(MISSING_NAME_BEFORE_EMAIL, ERROR) \
 	FUNC(MISSING_OBJECT, ERROR) \
-	FUNC(MISSING_PARENT, ERROR) \
 	FUNC(MISSING_SPACE_BEFORE_DATE, ERROR) \
 	FUNC(MISSING_SPACE_BEFORE_EMAIL, ERROR) \
 	FUNC(MISSING_TAG, ERROR) \
 	FUNC(MISSING_TAG_ENTRY, ERROR) \
-	FUNC(MISSING_TAG_OBJECT, ERROR) \
 	FUNC(MISSING_TREE, ERROR) \
 	FUNC(MISSING_TREE_OBJECT, ERROR) \
 	FUNC(MISSING_TYPE, ERROR) \
 	FUNC(MISSING_TYPE_ENTRY, ERROR) \
 	FUNC(MULTIPLE_AUTHORS, ERROR) \
-	FUNC(TAG_OBJECT_NOT_TAG, ERROR) \
 	FUNC(TREE_NOT_SORTED, ERROR) \
 	FUNC(UNKNOWN_TYPE, ERROR) \
 	FUNC(ZERO_PADDED_DATE, ERROR) \
 	FUNC(GITMODULES_MISSING, ERROR) \
 	FUNC(GITMODULES_BLOB, ERROR) \
-	FUNC(GITMODULES_PARSE, ERROR) \
+	FUNC(GITMODULES_LARGE, ERROR) \
 	FUNC(GITMODULES_NAME, ERROR) \
 	FUNC(GITMODULES_SYMLINK, ERROR) \
+	FUNC(GITMODULES_URL, ERROR) \
+	FUNC(GITMODULES_PATH, ERROR) \
+	FUNC(GITMODULES_UPDATE, ERROR) \
 	/* warnings */ \
 	FUNC(BAD_FILEMODE, WARN) \
 	FUNC(EMPTY_NAME, WARN) \
@@ -75,6 +76,7 @@ static struct oidset gitmodules_done = O
 	FUNC(ZERO_PADDED_FILEMODE, WARN) \
 	FUNC(NUL_IN_COMMIT, WARN) \
 	/* infos (reported as warnings, but ignored by default) */ \
+	FUNC(GITMODULES_PARSE, INFO) \
 	FUNC(BAD_TAG_NAME, INFO) \
 	FUNC(MISSING_TAGGER_ENTRY, INFO)
 
@@ -86,37 +88,60 @@ enum fsck_msg_id {
 #undef MSG_ID
 
 #define STR(x) #x
-#define MSG_ID(id, msg_type) { STR(id), NULL, FSCK_##msg_type },
+#define MSG_ID(id, msg_type) { STR(id), NULL, NULL, FSCK_##msg_type },
 static struct {
 	const char *id_string;
 	const char *downcased;
+	const char *camelcased;
 	int msg_type;
 } msg_id_info[FSCK_MSG_MAX + 1] = {
 	FOREACH_MSG_ID(MSG_ID)
-	{ NULL, NULL, -1 }
+	{ NULL, NULL, NULL, -1 }
 };
 #undef MSG_ID
 
-static int parse_msg_id(const char *text)
+static void prepare_msg_ids(void)
 {
 	int i;
 
-	if (!msg_id_info[0].downcased) {
-		/* convert id_string to lower case, without underscores. */
-		for (i = 0; i < FSCK_MSG_MAX; i++) {
-			const char *p = msg_id_info[i].id_string;
-			int len = strlen(p);
-			char *q = xmalloc(len);
-
-			msg_id_info[i].downcased = q;
-			while (*p)
-				if (*p == '_')
-					p++;
-				else
-					*(q)++ = tolower(*(p)++);
-			*q = '\0';
+	if (msg_id_info[0].downcased)
+		return;
+
+	/* convert id_string to lower case, without underscores. */
+	for (i = 0; i < FSCK_MSG_MAX; i++) {
+		const char *p = msg_id_info[i].id_string;
+		int len = strlen(p);
+		char *q = xmalloc(len);
+
+		msg_id_info[i].downcased = q;
+		while (*p)
+			if (*p == '_')
+				p++;
+			else
+				*(q)++ = tolower(*(p)++);
+		*q = '\0';
+
+		p = msg_id_info[i].id_string;
+		q = xmalloc(len);
+		msg_id_info[i].camelcased = q;
+		while (*p) {
+			if (*p == '_') {
+				p++;
+				if (*p)
+					*q++ = *p++;
+			} else {
+				*q++ = tolower(*p++);
+			}
 		}
+		*q = '\0';
 	}
+}
+
+static int parse_msg_id(const char *text)
+{
+	int i;
+
+	prepare_msg_ids();
 
 	for (i = 0; i < FSCK_MSG_MAX; i++)
 		if (!strcmp(text, msg_id_info[i].downcased))
@@ -125,6 +150,16 @@ static int parse_msg_id(const char *text
 	return -1;
 }
 
+void list_config_fsck_msg_ids(struct string_list *list, const char *prefix)
+{
+	int i;
+
+	prepare_msg_ids();
+
+	for (i = 0; i < FSCK_MSG_MAX; i++)
+		list_config_item(list, prefix, msg_id_info[i].camelcased);
+}
+
 static int fsck_msg_type(enum fsck_msg_id msg_id,
 	struct fsck_options *options)
 {
@@ -143,44 +178,6 @@ static int fsck_msg_type(enum fsck_msg_i
 	return msg_type;
 }
 
-static void init_skiplist(struct fsck_options *options, const char *path)
-{
-	static struct oid_array skiplist = OID_ARRAY_INIT;
-	int sorted, fd;
-	char buffer[GIT_MAX_HEXSZ + 1];
-	struct object_id oid;
-
-	if (options->skiplist)
-		sorted = options->skiplist->sorted;
-	else {
-		sorted = 1;
-		options->skiplist = &skiplist;
-	}
-
-	fd = open(path, O_RDONLY);
-	if (fd < 0)
-		die("Could not open skip list: %s", path);
-	for (;;) {
-		const char *p;
-		int result = read_in_full(fd, buffer, sizeof(buffer));
-		if (result < 0)
-			die_errno("Could not read '%s'", path);
-		if (!result)
-			break;
-		if (parse_oid_hex(buffer, &oid, &p) || *p != '\n')
-			die("Invalid SHA-1: %s", buffer);
-		oid_array_append(&skiplist, &oid);
-		if (sorted && skiplist.nr > 1 &&
-				oidcmp(&skiplist.oid[skiplist.nr - 2],
-				       &oid) > 0)
-			sorted = 0;
-	}
-	close(fd);
-
-	if (sorted)
-		skiplist.sorted = 1;
-}
-
 static int parse_msg_type(const char *str)
 {
 	if (!strcmp(str, "error"))
@@ -249,7 +246,7 @@ void fsck_set_msg_types(struct fsck_opti
 		if (!strcmp(buf, "skiplist")) {
 			if (equal == len)
 				die("skiplist requires a path");
-			init_skiplist(options, buf + equal + 1);
+			oidset_parse_file(&options->skiplist, buf + equal + 1);
 			buf += len + 1;
 			continue;
 		}
@@ -281,9 +278,16 @@ static void append_msg_id(struct strbuf
 	strbuf_addstr(sb, ": ");
 }
 
-__attribute__((format (printf, 4, 5)))
-static int report(struct fsck_options *options, struct object *object,
-	enum fsck_msg_id id, const char *fmt, ...)
+static int object_on_skiplist(struct fsck_options *opts,
+			      const struct object_id *oid)
+{
+	return opts && oid && oidset_contains(&opts->skiplist, oid);
+}
+
+__attribute__((format (printf, 5, 6)))
+static int report(struct fsck_options *options,
+		  const struct object_id *oid, enum object_type object_type,
+		  enum fsck_msg_id id, const char *fmt, ...)
 {
 	va_list ap;
 	struct strbuf sb = STRBUF_INIT;
@@ -292,8 +296,7 @@ static int report(struct fsck_options *o
 	if (msg_type == FSCK_IGNORE)
 		return 0;
 
-	if (options->skiplist && object &&
-			oid_array_lookup(options->skiplist, &object->oid) >= 0)
+	if (object_on_skiplist(options, oid))
 		return 0;
 
 	if (msg_type == FSCK_FATAL)
@@ -305,49 +308,71 @@ static int report(struct fsck_options *o
 
 	va_start(ap, fmt);
 	strbuf_vaddf(&sb, fmt, ap);
-	result = options->error_func(options, object, msg_type, sb.buf);
+	result = options->error_func(options, oid, object_type,
+				     msg_type, sb.buf);
 	strbuf_release(&sb);
 	va_end(ap);
 
 	return result;
 }
 
-static char *get_object_name(struct fsck_options *options, struct object *obj)
+void fsck_enable_object_names(struct fsck_options *options)
+{
+	if (!options->object_names)
+		options->object_names = kh_init_oid_map();
+}
+
+const char *fsck_get_object_name(struct fsck_options *options,
+				 const struct object_id *oid)
 {
+	khiter_t pos;
 	if (!options->object_names)
 		return NULL;
-	return lookup_decoration(options->object_names, obj);
+	pos = kh_get_oid_map(options->object_names, *oid);
+	if (pos >= kh_end(options->object_names))
+		return NULL;
+	return kh_value(options->object_names, pos);
 }
 
-static void put_object_name(struct fsck_options *options, struct object *obj,
-	const char *fmt, ...)
+void fsck_put_object_name(struct fsck_options *options,
+			  const struct object_id *oid,
+			  const char *fmt, ...)
 {
 	va_list ap;
 	struct strbuf buf = STRBUF_INIT;
-	char *existing;
+	khiter_t pos;
+	int hashret;
 
 	if (!options->object_names)
 		return;
-	existing = lookup_decoration(options->object_names, obj);
-	if (existing)
+
+	pos = kh_put_oid_map(options->object_names, *oid, &hashret);
+	if (!hashret)
 		return;
 	va_start(ap, fmt);
 	strbuf_vaddf(&buf, fmt, ap);
-	add_decoration(options->object_names, obj, strbuf_detach(&buf, NULL));
+	kh_value(options->object_names, pos) = strbuf_detach(&buf, NULL);
 	va_end(ap);
 }
 
-static const char *describe_object(struct fsck_options *o, struct object *obj)
+const char *fsck_describe_object(struct fsck_options *options,
+				 const struct object_id *oid)
 {
-	static struct strbuf buf = STRBUF_INIT;
-	char *name;
-
-	strbuf_reset(&buf);
-	strbuf_addstr(&buf, oid_to_hex(&obj->oid));
-	if (o->object_names && (name = lookup_decoration(o->object_names, obj)))
-		strbuf_addf(&buf, " (%s)", name);
+	static struct strbuf bufs[] = {
+		STRBUF_INIT, STRBUF_INIT, STRBUF_INIT, STRBUF_INIT
+	};
+	static int b = 0;
+	struct strbuf *buf;
+	const char *name = fsck_get_object_name(options, oid);
+
+	buf = bufs + b;
+	b = (b + 1) % ARRAY_SIZE(bufs);
+	strbuf_reset(buf);
+	strbuf_addstr(buf, oid_to_hex(oid));
+	if (name)
+		strbuf_addf(buf, " (%s)", name);
 
-	return buf.buf;
+	return buf->buf;
 }
 
 static int fsck_walk_tree(struct tree *tree, void *data, struct fsck_options *options)
@@ -360,7 +385,7 @@ static int fsck_walk_tree(struct tree *t
 	if (parse_tree(tree))
 		return -1;
 
-	name = get_object_name(options, &tree->object);
+	name = fsck_get_object_name(options, &tree->object.oid);
 	if (init_tree_desc_gently(&desc, tree->buffer, tree->size))
 		return -1;
 	while (tree_entry_gently(&desc, &entry)) {
@@ -371,22 +396,23 @@ static int fsck_walk_tree(struct tree *t
 			continue;
 
 		if (S_ISDIR(entry.mode)) {
-			obj = (struct object *)lookup_tree(entry.oid);
+			obj = (struct object *)lookup_tree(the_repository, &entry.oid);
 			if (name && obj)
-				put_object_name(options, obj, "%s%s/", name,
-					entry.path);
+				fsck_put_object_name(options, &entry.oid, "%s%s/",
+						     name, entry.path);
 			result = options->walk(obj, OBJ_TREE, data, options);
 		}
 		else if (S_ISREG(entry.mode) || S_ISLNK(entry.mode)) {
-			obj = (struct object *)lookup_blob(entry.oid);
+			obj = (struct object *)lookup_blob(the_repository, &entry.oid);
 			if (name && obj)
-				put_object_name(options, obj, "%s%s", name,
-					entry.path);
+				fsck_put_object_name(options, &entry.oid, "%s%s",
+						     name, entry.path);
 			result = options->walk(obj, OBJ_BLOB, data, options);
 		}
 		else {
 			result = error("in tree %s: entry %s has bad mode %.6o",
-					describe_object(options, &tree->object), entry.path, entry.mode);
+				       fsck_describe_object(options, &tree->object.oid),
+				       entry.path, entry.mode);
 		}
 		if (result < 0)
 			return result;
@@ -407,10 +433,10 @@ static int fsck_walk_commit(struct commi
 	if (parse_commit(commit))
 		return -1;
 
-	name = get_object_name(options, &commit->object);
+	name = fsck_get_object_name(options, &commit->object.oid);
 	if (name)
-		put_object_name(options, &get_commit_tree(commit)->object,
-				"%s:", name);
+		fsck_put_object_name(options, get_commit_tree_oid(commit),
+				     "%s:", name);
 
 	result = options->walk((struct object *)get_commit_tree(commit),
 			       OBJ_TREE, data, options);
@@ -438,16 +464,17 @@ static int fsck_walk_commit(struct commi
 
 	while (parents) {
 		if (name) {
-			struct object *obj = &parents->item->object;
+			struct object_id *oid = &parents->item->object.oid;
 
-			if (++counter > 1)
-				put_object_name(options, obj, "%s^%d",
-					name, counter);
+			if (counter++)
+				fsck_put_object_name(options, oid, "%s^%d",
+						     name, counter);
 			else if (generation > 0)
-				put_object_name(options, obj, "%.*s~%d",
-					name_prefix_len, name, generation + 1);
+				fsck_put_object_name(options, oid, "%.*s~%d",
+						     name_prefix_len, name,
+						     generation + 1);
 			else
-				put_object_name(options, obj, "%s^", name);
+				fsck_put_object_name(options, oid, "%s^", name);
 		}
 		result = options->walk((struct object *)parents->item, OBJ_COMMIT, data, options);
 		if (result < 0)
@@ -461,12 +488,12 @@ static int fsck_walk_commit(struct commi
 
 static int fsck_walk_tag(struct tag *tag, void *data, struct fsck_options *options)
 {
-	char *name = get_object_name(options, &tag->object);
+	const char *name = fsck_get_object_name(options, &tag->object.oid);
 
 	if (parse_tag(tag))
 		return -1;
 	if (name)
-		put_object_name(options, tag->tagged, "%s", name);
+		fsck_put_object_name(options, &tag->tagged->oid, "%s", name);
 	return options->walk(tag->tagged, OBJ_ANY, data, options);
 }
 
@@ -476,7 +503,7 @@ int fsck_walk(struct object *obj, void *
 		return -1;
 
 	if (obj->type == OBJ_NONE)
-		parse_object(&obj->oid);
+		parse_object(the_repository, &obj->oid);
 
 	switch (obj->type) {
 	case OBJ_BLOB:
@@ -488,7 +515,8 @@ int fsck_walk(struct object *obj, void *
 	case OBJ_TAG:
 		return fsck_walk_tag((struct tag *)obj, data, options);
 	default:
-		error("Unknown object type for %s", describe_object(options, obj));
+		error("Unknown object type for %s",
+		      fsck_describe_object(options, &obj->oid));
 		return -1;
 	}
 }
@@ -539,7 +567,9 @@ static int verify_ordered(unsigned mode1
 	return c1 < c2 ? 0 : TREE_UNORDERED;
 }
 
-static int fsck_tree(struct tree *item, struct fsck_options *options)
+static int fsck_tree(const struct object_id *oid,
+		     const char *buffer, unsigned long size,
+		     struct fsck_options *options)
 {
 	int retval = 0;
 	int has_null_sha1 = 0;
@@ -556,8 +586,8 @@ static int fsck_tree(struct tree *item,
 	unsigned o_mode;
 	const char *o_name;
 
-	if (init_tree_desc_gently(&desc, item->buffer, item->size)) {
-		retval += report(options, &item->object, FSCK_MSG_BAD_TREE, "cannot be parsed as a tree");
+	if (init_tree_desc_gently(&desc, buffer, size)) {
+		retval += report(options, oid, OBJ_TREE, FSCK_MSG_BAD_TREE, "cannot be parsed as a tree");
 		return retval;
 	}
 
@@ -565,8 +595,8 @@ static int fsck_tree(struct tree *item,
 	o_name = NULL;
 
 	while (desc.size) {
-		unsigned mode;
-		const char *name;
+		unsigned short mode;
+		const char *name, *backslash;
 		const struct object_id *oid;
 
 		oid = tree_entry_extract(&desc, &name, &mode);
@@ -583,13 +613,30 @@ static int fsck_tree(struct tree *item,
 			if (!S_ISLNK(mode))
 				oidset_insert(&gitmodules_found, oid);
 			else
-				retval += report(options, &item->object,
+				retval += report(options,
+						 oid, OBJ_TREE,
 						 FSCK_MSG_GITMODULES_SYMLINK,
 						 ".gitmodules is a symbolic link");
 		}
 
+		if ((backslash = strchr(name, '\\'))) {
+			while (backslash) {
+				backslash++;
+				has_dotgit |= is_ntfs_dotgit(backslash);
+				if (is_ntfs_dotgitmodules(backslash)) {
+					if (!S_ISLNK(mode))
+						oidset_insert(&gitmodules_found, oid);
+					else
+						retval += report(options, oid, OBJ_TREE,
+								 FSCK_MSG_GITMODULES_SYMLINK,
+								 ".gitmodules is a symbolic link");
+				}
+				backslash = strchr(backslash, '\\');
+			}
+		}
+
 		if (update_tree_entry_gently(&desc)) {
-			retval += report(options, &item->object, FSCK_MSG_BAD_TREE, "cannot be parsed as a tree");
+			retval += report(options, oid, OBJ_TREE, FSCK_MSG_BAD_TREE, "cannot be parsed as a tree");
 			break;
 		}
 
@@ -634,30 +681,31 @@ static int fsck_tree(struct tree *item,
 	}
 
 	if (has_null_sha1)
-		retval += report(options, &item->object, FSCK_MSG_NULL_SHA1, "contains entries pointing to null sha1");
+		retval += report(options, oid, OBJ_TREE, FSCK_MSG_NULL_SHA1, "contains entries pointing to null sha1");
 	if (has_full_path)
-		retval += report(options, &item->object, FSCK_MSG_FULL_PATHNAME, "contains full pathnames");
+		retval += report(options, oid, OBJ_TREE, FSCK_MSG_FULL_PATHNAME, "contains full pathnames");
 	if (has_empty_name)
-		retval += report(options, &item->object, FSCK_MSG_EMPTY_NAME, "contains empty pathname");
+		retval += report(options, oid, OBJ_TREE, FSCK_MSG_EMPTY_NAME, "contains empty pathname");
 	if (has_dot)
-		retval += report(options, &item->object, FSCK_MSG_HAS_DOT, "contains '.'");
+		retval += report(options, oid, OBJ_TREE, FSCK_MSG_HAS_DOT, "contains '.'");
 	if (has_dotdot)
-		retval += report(options, &item->object, FSCK_MSG_HAS_DOTDOT, "contains '..'");
+		retval += report(options, oid, OBJ_TREE, FSCK_MSG_HAS_DOTDOT, "contains '..'");
 	if (has_dotgit)
-		retval += report(options, &item->object, FSCK_MSG_HAS_DOTGIT, "contains '.git'");
+		retval += report(options, oid, OBJ_TREE, FSCK_MSG_HAS_DOTGIT, "contains '.git'");
 	if (has_zero_pad)
-		retval += report(options, &item->object, FSCK_MSG_ZERO_PADDED_FILEMODE, "contains zero-padded file modes");
+		retval += report(options, oid, OBJ_TREE, FSCK_MSG_ZERO_PADDED_FILEMODE, "contains zero-padded file modes");
 	if (has_bad_modes)
-		retval += report(options, &item->object, FSCK_MSG_BAD_FILEMODE, "contains bad file modes");
+		retval += report(options, oid, OBJ_TREE, FSCK_MSG_BAD_FILEMODE, "contains bad file modes");
 	if (has_dup_entries)
-		retval += report(options, &item->object, FSCK_MSG_DUPLICATE_ENTRIES, "contains duplicate file entries");
+		retval += report(options, oid, OBJ_TREE, FSCK_MSG_DUPLICATE_ENTRIES, "contains duplicate file entries");
 	if (not_properly_sorted)
-		retval += report(options, &item->object, FSCK_MSG_TREE_NOT_SORTED, "not properly sorted");
+		retval += report(options, oid, OBJ_TREE, FSCK_MSG_TREE_NOT_SORTED, "not properly sorted");
 	return retval;
 }
 
 static int verify_headers(const void *data, unsigned long size,
-			  struct object *obj, struct fsck_options *options)
+			  const struct object_id *oid, enum object_type type,
+			  struct fsck_options *options)
 {
 	const char *buffer = (const char *)data;
 	unsigned long i;
@@ -665,7 +713,7 @@ static int verify_headers(const void *da
 	for (i = 0; i < size; i++) {
 		switch (buffer[i]) {
 		case '\0':
-			return report(options, obj,
+			return report(options, oid, type,
 				FSCK_MSG_NUL_IN_HEADER,
 				"unterminated header: NUL at offset %ld", i);
 		case '\n':
@@ -683,11 +731,13 @@ static int verify_headers(const void *da
 	if (size && buffer[size - 1] == '\n')
 		return 0;
 
-	return report(options, obj,
+	return report(options, oid, type,
 		FSCK_MSG_UNTERMINATED_HEADER, "unterminated header");
 }
 
-static int fsck_ident(const char **ident, struct object *obj, struct fsck_options *options)
+static int fsck_ident(const char **ident,
+		      const struct object_id *oid, enum object_type type,
+		      struct fsck_options *options)
 {
 	const char *p = *ident;
 	char *end;
@@ -697,28 +747,28 @@ static int fsck_ident(const char **ident
 		(*ident)++;
 
 	if (*p == '<')
-		return report(options, obj, FSCK_MSG_MISSING_NAME_BEFORE_EMAIL, "invalid author/committer line - missing space before email");
+		return report(options, oid, type, FSCK_MSG_MISSING_NAME_BEFORE_EMAIL, "invalid author/committer line - missing space before email");
 	p += strcspn(p, "<>\n");
 	if (*p == '>')
-		return report(options, obj, FSCK_MSG_BAD_NAME, "invalid author/committer line - bad name");
+		return report(options, oid, type, FSCK_MSG_BAD_NAME, "invalid author/committer line - bad name");
 	if (*p != '<')
-		return report(options, obj, FSCK_MSG_MISSING_EMAIL, "invalid author/committer line - missing email");
+		return report(options, oid, type, FSCK_MSG_MISSING_EMAIL, "invalid author/committer line - missing email");
 	if (p[-1] != ' ')
-		return report(options, obj, FSCK_MSG_MISSING_SPACE_BEFORE_EMAIL, "invalid author/committer line - missing space before email");
+		return report(options, oid, type, FSCK_MSG_MISSING_SPACE_BEFORE_EMAIL, "invalid author/committer line - missing space before email");
 	p++;
 	p += strcspn(p, "<>\n");
 	if (*p != '>')
-		return report(options, obj, FSCK_MSG_BAD_EMAIL, "invalid author/committer line - bad email");
+		return report(options, oid, type, FSCK_MSG_BAD_EMAIL, "invalid author/committer line - bad email");
 	p++;
 	if (*p != ' ')
-		return report(options, obj, FSCK_MSG_MISSING_SPACE_BEFORE_DATE, "invalid author/committer line - missing space before date");
+		return report(options, oid, type, FSCK_MSG_MISSING_SPACE_BEFORE_DATE, "invalid author/committer line - missing space before date");
 	p++;
 	if (*p == '0' && p[1] != ' ')
-		return report(options, obj, FSCK_MSG_ZERO_PADDED_DATE, "invalid author/committer line - zero-padded date");
+		return report(options, oid, type, FSCK_MSG_ZERO_PADDED_DATE, "invalid author/committer line - zero-padded date");
 	if (date_overflows(parse_timestamp(p, &end, 10)))
-		return report(options, obj, FSCK_MSG_BAD_DATE_OVERFLOW, "invalid author/committer line - date causes integer overflow");
+		return report(options, oid, type, FSCK_MSG_BAD_DATE_OVERFLOW, "invalid author/committer line - date causes integer overflow");
 	if ((end == p || *end != ' '))
-		return report(options, obj, FSCK_MSG_BAD_DATE, "invalid author/committer line - bad date");
+		return report(options, oid, type, FSCK_MSG_BAD_DATE, "invalid author/committer line - bad date");
 	p = end + 1;
 	if ((*p != '+' && *p != '-') ||
 	    !isdigit(p[1]) ||
@@ -726,83 +776,60 @@ static int fsck_ident(const char **ident
 	    !isdigit(p[3]) ||
 	    !isdigit(p[4]) ||
 	    (p[5] != '\n'))
-		return report(options, obj, FSCK_MSG_BAD_TIMEZONE, "invalid author/committer line - bad time zone");
+		return report(options, oid, type, FSCK_MSG_BAD_TIMEZONE, "invalid author/committer line - bad time zone");
 	p += 6;
 	return 0;
 }
 
-static int fsck_commit_buffer(struct commit *commit, const char *buffer,
-	unsigned long size, struct fsck_options *options)
+static int fsck_commit(const struct object_id *oid,
+		       const char *buffer, unsigned long size,
+		       struct fsck_options *options)
 {
-	struct object_id tree_oid, oid;
-	struct commit_graft *graft;
-	unsigned parent_count, parent_line_count = 0, author_count;
+	struct object_id tree_oid, parent_oid;
+	unsigned author_count;
 	int err;
 	const char *buffer_begin = buffer;
 	const char *p;
 
-	if (verify_headers(buffer, size, &commit->object, options))
+	if (verify_headers(buffer, size, oid, OBJ_COMMIT, options))
 		return -1;
 
 	if (!skip_prefix(buffer, "tree ", &buffer))
-		return report(options, &commit->object, FSCK_MSG_MISSING_TREE, "invalid format - expected 'tree' line");
+		return report(options, oid, OBJ_COMMIT, FSCK_MSG_MISSING_TREE, "invalid format - expected 'tree' line");
 	if (parse_oid_hex(buffer, &tree_oid, &p) || *p != '\n') {
-		err = report(options, &commit->object, FSCK_MSG_BAD_TREE_SHA1, "invalid 'tree' line format - bad sha1");
+		err = report(options, oid, OBJ_COMMIT, FSCK_MSG_BAD_TREE_SHA1, "invalid 'tree' line format - bad sha1");
 		if (err)
 			return err;
 	}
 	buffer = p + 1;
 	while (skip_prefix(buffer, "parent ", &buffer)) {
-		if (parse_oid_hex(buffer, &oid, &p) || *p != '\n') {
-			err = report(options, &commit->object, FSCK_MSG_BAD_PARENT_SHA1, "invalid 'parent' line format - bad sha1");
+		if (parse_oid_hex(buffer, &parent_oid, &p) || *p != '\n') {
+			err = report(options, oid, OBJ_COMMIT, FSCK_MSG_BAD_PARENT_SHA1, "invalid 'parent' line format - bad sha1");
 			if (err)
 				return err;
 		}
 		buffer = p + 1;
-		parent_line_count++;
-	}
-	graft = lookup_commit_graft(&commit->object.oid);
-	parent_count = commit_list_count(commit->parents);
-	if (graft) {
-		if (graft->nr_parent == -1 && !parent_count)
-			; /* shallow commit */
-		else if (graft->nr_parent != parent_count) {
-			err = report(options, &commit->object, FSCK_MSG_MISSING_GRAFT, "graft objects missing");
-			if (err)
-				return err;
-		}
-	} else {
-		if (parent_count != parent_line_count) {
-			err = report(options, &commit->object, FSCK_MSG_MISSING_PARENT, "parent objects missing");
-			if (err)
-				return err;
-		}
 	}
 	author_count = 0;
 	while (skip_prefix(buffer, "author ", &buffer)) {
 		author_count++;
-		err = fsck_ident(&buffer, &commit->object, options);
+		err = fsck_ident(&buffer, oid, OBJ_COMMIT, options);
 		if (err)
 			return err;
 	}
 	if (author_count < 1)
-		err = report(options, &commit->object, FSCK_MSG_MISSING_AUTHOR, "invalid format - expected 'author' line");
+		err = report(options, oid, OBJ_COMMIT, FSCK_MSG_MISSING_AUTHOR, "invalid format - expected 'author' line");
 	else if (author_count > 1)
-		err = report(options, &commit->object, FSCK_MSG_MULTIPLE_AUTHORS, "invalid format - multiple 'author' lines");
+		err = report(options, oid, OBJ_COMMIT, FSCK_MSG_MULTIPLE_AUTHORS, "invalid format - multiple 'author' lines");
 	if (err)
 		return err;
 	if (!skip_prefix(buffer, "committer ", &buffer))
-		return report(options, &commit->object, FSCK_MSG_MISSING_COMMITTER, "invalid format - expected 'committer' line");
-	err = fsck_ident(&buffer, &commit->object, options);
+		return report(options, oid, OBJ_COMMIT, FSCK_MSG_MISSING_COMMITTER, "invalid format - expected 'committer' line");
+	err = fsck_ident(&buffer, oid, OBJ_COMMIT, options);
 	if (err)
 		return err;
-	if (!get_commit_tree(commit)) {
-		err = report(options, &commit->object, FSCK_MSG_BAD_TREE, "could not load commit's tree %s", oid_to_hex(&tree_oid));
-		if (err)
-			return err;
-	}
 	if (memchr(buffer_begin, '\0', size)) {
-		err = report(options, &commit->object, FSCK_MSG_NUL_IN_COMMIT,
+		err = report(options, oid, OBJ_COMMIT, FSCK_MSG_NUL_IN_COMMIT,
 			     "NUL byte in the commit object body");
 		if (err)
 			return err;
@@ -810,91 +837,60 @@ static int fsck_commit_buffer(struct com
 	return 0;
 }
 
-static int fsck_commit(struct commit *commit, const char *data,
-	unsigned long size, struct fsck_options *options)
+static int fsck_tag(const struct object_id *oid, const char *buffer,
+		    unsigned long size, struct fsck_options *options)
 {
-	const char *buffer = data ?  data : get_commit_buffer(commit, &size);
-	int ret = fsck_commit_buffer(commit, buffer, size, options);
-	if (!data)
-		unuse_commit_buffer(commit, buffer);
-	return ret;
-}
-
-static int fsck_tag_buffer(struct tag *tag, const char *data,
-	unsigned long size, struct fsck_options *options)
-{
-	struct object_id oid;
+	struct object_id tagged_oid;
 	int ret = 0;
-	const char *buffer;
-	char *to_free = NULL, *eol;
+	char *eol;
 	struct strbuf sb = STRBUF_INIT;
 	const char *p;
 
-	if (data)
-		buffer = data;
-	else {
-		enum object_type type;
-
-		buffer = to_free =
-			read_object_file(&tag->object.oid, &type, &size);
-		if (!buffer)
-			return report(options, &tag->object,
-				FSCK_MSG_MISSING_TAG_OBJECT,
-				"cannot read tag object");
-
-		if (type != OBJ_TAG) {
-			ret = report(options, &tag->object,
-				FSCK_MSG_TAG_OBJECT_NOT_TAG,
-				"expected tag got %s",
-			    type_name(type));
-			goto done;
-		}
-	}
-
-	ret = verify_headers(buffer, size, &tag->object, options);
+	ret = verify_headers(buffer, size, oid, OBJ_TAG, options);
 	if (ret)
 		goto done;
 
 	if (!skip_prefix(buffer, "object ", &buffer)) {
-		ret = report(options, &tag->object, FSCK_MSG_MISSING_OBJECT, "invalid format - expected 'object' line");
+		ret = report(options, oid, OBJ_TAG, FSCK_MSG_MISSING_OBJECT, "invalid format - expected 'object' line");
 		goto done;
 	}
-	if (parse_oid_hex(buffer, &oid, &p) || *p != '\n') {
-		ret = report(options, &tag->object, FSCK_MSG_BAD_OBJECT_SHA1, "invalid 'object' line format - bad sha1");
+	if (parse_oid_hex(buffer, &tagged_oid, &p) || *p != '\n') {
+		ret = report(options, oid, OBJ_TAG, FSCK_MSG_BAD_OBJECT_SHA1, "invalid 'object' line format - bad sha1");
 		if (ret)
 			goto done;
 	}
 	buffer = p + 1;
 
 	if (!skip_prefix(buffer, "type ", &buffer)) {
-		ret = report(options, &tag->object, FSCK_MSG_MISSING_TYPE_ENTRY, "invalid format - expected 'type' line");
+		ret = report(options, oid, OBJ_TAG, FSCK_MSG_MISSING_TYPE_ENTRY, "invalid format - expected 'type' line");
 		goto done;
 	}
 	eol = strchr(buffer, '\n');
 	if (!eol) {
-		ret = report(options, &tag->object, FSCK_MSG_MISSING_TYPE, "invalid format - unexpected end after 'type' line");
+		ret = report(options, oid, OBJ_TAG, FSCK_MSG_MISSING_TYPE, "invalid format - unexpected end after 'type' line");
 		goto done;
 	}
 	if (type_from_string_gently(buffer, eol - buffer, 1) < 0)
-		ret = report(options, &tag->object, FSCK_MSG_BAD_TYPE, "invalid 'type' value");
+		ret = report(options, oid, OBJ_TAG, FSCK_MSG_BAD_TYPE, "invalid 'type' value");
 	if (ret)
 		goto done;
 	buffer = eol + 1;
 
 	if (!skip_prefix(buffer, "tag ", &buffer)) {
-		ret = report(options, &tag->object, FSCK_MSG_MISSING_TAG_ENTRY, "invalid format - expected 'tag' line");
+		ret = report(options, oid, OBJ_TAG, FSCK_MSG_MISSING_TAG_ENTRY, "invalid format - expected 'tag' line");
 		goto done;
 	}
 	eol = strchr(buffer, '\n');
 	if (!eol) {
-		ret = report(options, &tag->object, FSCK_MSG_MISSING_TAG, "invalid format - unexpected end after 'type' line");
+		ret = report(options, oid, OBJ_TAG, FSCK_MSG_MISSING_TAG, "invalid format - unexpected end after 'type' line");
 		goto done;
 	}
 	strbuf_addf(&sb, "refs/tags/%.*s", (int)(eol - buffer), buffer);
 	if (check_refname_format(sb.buf, 0)) {
-		ret = report(options, &tag->object, FSCK_MSG_BAD_TAG_NAME,
-			   "invalid 'tag' name: %.*s",
-			   (int)(eol - buffer), buffer);
+		ret = report(options, oid, OBJ_TAG,
+			     FSCK_MSG_BAD_TAG_NAME,
+			     "invalid 'tag' name: %.*s",
+			     (int)(eol - buffer), buffer);
 		if (ret)
 			goto done;
 	}
@@ -902,32 +898,20 @@ static int fsck_tag_buffer(struct tag *t
 
 	if (!skip_prefix(buffer, "tagger ", &buffer)) {
 		/* early tags do not contain 'tagger' lines; warn only */
-		ret = report(options, &tag->object, FSCK_MSG_MISSING_TAGGER_ENTRY, "invalid format - expected 'tagger' line");
+		ret = report(options, oid, OBJ_TAG, FSCK_MSG_MISSING_TAGGER_ENTRY, "invalid format - expected 'tagger' line");
 		if (ret)
 			goto done;
 	}
 	else
-		ret = fsck_ident(&buffer, &tag->object, options);
+		ret = fsck_ident(&buffer, oid, OBJ_TAG, options);
 
 done:
 	strbuf_release(&sb);
-	free(to_free);
 	return ret;
 }
 
-static int fsck_tag(struct tag *tag, const char *data,
-	unsigned long size, struct fsck_options *options)
-{
-	struct object *tagged = tag->tagged;
-
-	if (!tagged)
-		return report(options, &tag->object, FSCK_MSG_BAD_TAG_OBJECT, "could not load tagged object");
-
-	return fsck_tag_buffer(tag, data, size, options);
-}
-
 struct fsck_gitmodules_data {
-	struct object *obj;
+	const struct object_id *oid;
 	struct fsck_options *options;
 	int ret;
 };
@@ -945,23 +929,48 @@ static int fsck_gitmodules_fn(const char
 
 	name = xmemdupz(subsection, subsection_len);
 	if (check_submodule_name(name) < 0)
-		data->ret |= report(data->options, data->obj,
+		data->ret |= report(data->options,
+				    data->oid, OBJ_BLOB,
 				    FSCK_MSG_GITMODULES_NAME,
 				    "disallowed submodule name: %s",
 				    name);
+	if (!strcmp(key, "url") && value &&
+	    looks_like_command_line_option(value))
+		data->ret |= report(data->options,
+				    data->oid, OBJ_BLOB,
+				    FSCK_MSG_GITMODULES_URL,
+				    "disallowed submodule url: %s",
+				    value);
+	if (!strcmp(key, "path") && value &&
+	    looks_like_command_line_option(value))
+		data->ret |= report(data->options,
+				    data->oid, OBJ_BLOB,
+				    FSCK_MSG_GITMODULES_PATH,
+				    "disallowed submodule path: %s",
+				    value);
+	if (!strcmp(key, "update") && value &&
+	    parse_submodule_update_type(value) == SM_UPDATE_COMMAND)
+		data->ret |= report(data->options, data->oid, OBJ_BLOB,
+				    FSCK_MSG_GITMODULES_UPDATE,
+				    "disallowed submodule update setting: %s",
+				    value);
 	free(name);
 
 	return 0;
 }
 
-static int fsck_blob(struct blob *blob, const char *buf,
+static int fsck_blob(const struct object_id *oid, const char *buf,
 		     unsigned long size, struct fsck_options *options)
 {
 	struct fsck_gitmodules_data data;
+	struct config_options config_opts = { 0 };
+
+	if (!oidset_contains(&gitmodules_found, oid))
+		return 0;
+	oidset_insert(&gitmodules_done, oid);
 
-	if (!oidset_contains(&gitmodules_found, &blob->object.oid))
+	if (object_on_skiplist(options, oid))
 		return 0;
-	oidset_insert(&gitmodules_done, &blob->object.oid);
 
 	if (!buf) {
 		/*
@@ -969,17 +978,18 @@ static int fsck_blob(struct blob *blob,
 		 * blob too gigantic to load into memory. Let's just consider
 		 * that an error.
 		 */
-		return report(options, &blob->object,
-			      FSCK_MSG_GITMODULES_PARSE,
+		return report(options, oid, OBJ_BLOB,
+			      FSCK_MSG_GITMODULES_LARGE,
 			      ".gitmodules too large to parse");
 	}
 
-	data.obj = &blob->object;
+	data.oid = oid;
 	data.options = options;
 	data.ret = 0;
+	config_opts.error_action = CONFIG_ERROR_SILENT;
 	if (git_config_from_mem(fsck_gitmodules_fn, CONFIG_ORIGIN_BLOB,
-				".gitmodules", buf, size, &data))
-		data.ret |= report(options, &blob->object,
+				".gitmodules", buf, size, &data, &config_opts))
+		data.ret |= report(options, oid, OBJ_BLOB,
 				   FSCK_MSG_GITMODULES_PARSE,
 				   "could not parse gitmodules blob");
 
@@ -990,31 +1000,33 @@ int fsck_object(struct object *obj, void
 	struct fsck_options *options)
 {
 	if (!obj)
-		return report(options, obj, FSCK_MSG_BAD_OBJECT_SHA1, "no valid object to fsck");
+		return report(options, NULL, OBJ_NONE, FSCK_MSG_BAD_OBJECT_SHA1, "no valid object to fsck");
 
 	if (obj->type == OBJ_BLOB)
-		return fsck_blob((struct blob *)obj, data, size, options);
+		return fsck_blob(&obj->oid, data, size, options);
 	if (obj->type == OBJ_TREE)
-		return fsck_tree((struct tree *) obj, options);
+		return fsck_tree(&obj->oid, data, size, options);
 	if (obj->type == OBJ_COMMIT)
-		return fsck_commit((struct commit *) obj, (const char *) data,
-			size, options);
+		return fsck_commit(&obj->oid, data, size, options);
 	if (obj->type == OBJ_TAG)
-		return fsck_tag((struct tag *) obj, (const char *) data,
-			size, options);
+		return fsck_tag(&obj->oid, data, size, options);
 
-	return report(options, obj, FSCK_MSG_UNKNOWN_TYPE, "unknown type '%d' (internal fsck error)",
-			  obj->type);
+	return report(options, &obj->oid, obj->type,
+		      FSCK_MSG_UNKNOWN_TYPE,
+		      "unknown type '%d' (internal fsck error)",
+		      obj->type);
 }
 
 int fsck_error_function(struct fsck_options *o,
-	struct object *obj, int msg_type, const char *message)
+			const struct object_id *oid,
+			enum object_type object_type,
+			int msg_type, const char *message)
 {
 	if (msg_type == FSCK_WARN) {
-		warning("object %s: %s", describe_object(o, obj), message);
+		warning("object %s: %s", fsck_describe_object(o, oid), message);
 		return 0;
 	}
-	error("object %s: %s", describe_object(o, obj), message);
+	error("object %s: %s", fsck_describe_object(o, oid), message);
 	return 1;
 }
 
@@ -1026,7 +1038,6 @@ int fsck_finish(struct fsck_options *opt
 
 	oidset_iter_init(&gitmodules_found, &iter);
 	while ((oid = oidset_iter_next(&iter))) {
-		struct blob *blob;
 		enum object_type type;
 		unsigned long size;
 		char *buf;
@@ -1034,29 +1045,22 @@ int fsck_finish(struct fsck_options *opt
 		if (oidset_contains(&gitmodules_done, oid))
 			continue;
 
-		blob = lookup_blob(oid);
-		if (!blob) {
-			struct object *obj = lookup_unknown_object(oid->hash);
-			ret |= report(options, obj,
-				      FSCK_MSG_GITMODULES_BLOB,
-				      "non-blob found at .gitmodules");
-			continue;
-		}
-
 		buf = read_object_file(oid, &type, &size);
 		if (!buf) {
-			if (is_promisor_object(&blob->object.oid))
+			if (is_promisor_object(oid))
 				continue;
-			ret |= report(options, &blob->object,
+			ret |= report(options,
+				      oid, OBJ_BLOB,
 				      FSCK_MSG_GITMODULES_MISSING,
 				      "unable to read .gitmodules blob");
 			continue;
 		}
 
 		if (type == OBJ_BLOB)
-			ret |= fsck_blob(blob, buf, size, options);
+			ret |= fsck_blob(oid, buf, size, options);
 		else
-			ret |= report(options, &blob->object,
+			ret |= report(options,
+				      oid, type,
 				      FSCK_MSG_GITMODULES_BLOB,
 				      "non-blob found at .gitmodules");
 		free(buf);
diff -pruN 1.2.1+git2.18.0-1/git/fsck.h 1.2.3+git2.25.1-1/git/fsck.h
--- 1.2.1+git2.18.0-1/git/fsck.h	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/fsck.h	2020-02-17 04:47:35.000000000 +0000
@@ -1,11 +1,14 @@
 #ifndef GIT_FSCK_H
 #define GIT_FSCK_H
 
+#include "oidset.h"
+
 #define FSCK_ERROR 1
 #define FSCK_WARN 2
 #define FSCK_IGNORE 3
 
 struct fsck_options;
+struct object;
 
 void fsck_set_msg_type(struct fsck_options *options,
 		const char *msg_id, const char *msg_type);
@@ -24,22 +27,24 @@ typedef int (*fsck_walk_func)(struct obj
 
 /* callback for fsck_object, type is FSCK_ERROR or FSCK_WARN */
 typedef int (*fsck_error)(struct fsck_options *o,
-	struct object *obj, int type, const char *message);
+			  const struct object_id *oid, enum object_type object_type,
+			  int msg_type, const char *message);
 
 int fsck_error_function(struct fsck_options *o,
-	struct object *obj, int type, const char *message);
+			const struct object_id *oid, enum object_type object_type,
+			int msg_type, const char *message);
 
 struct fsck_options {
 	fsck_walk_func walk;
 	fsck_error error_func;
 	unsigned strict:1;
 	int *msg_type;
-	struct oid_array *skiplist;
-	struct decoration *object_names;
+	struct oidset skiplist;
+	kh_oid_map_t *object_names;
 };
 
-#define FSCK_OPTIONS_DEFAULT { NULL, fsck_error_function, 0, NULL }
-#define FSCK_OPTIONS_STRICT { NULL, fsck_error_function, 1, NULL }
+#define FSCK_OPTIONS_DEFAULT { NULL, fsck_error_function, 0, NULL, OIDSET_INIT }
+#define FSCK_OPTIONS_STRICT { NULL, fsck_error_function, 1, NULL, OIDSET_INIT }
 
 /* descend in all linked child objects
  * the return value is:
@@ -49,7 +54,11 @@ struct fsck_options {
  *    0		everything OK
  */
 int fsck_walk(struct object *obj, void *data, struct fsck_options *options);
-/* If NULL is passed for data, we assume the object is local and read it. */
+
+/*
+ * Blob objects my pass a NULL data pointer, which indicates they are too large
+ * to fit in memory. All other types must pass a real buffer.
+ */
 int fsck_object(struct object *obj, void *data, unsigned long size,
 	struct fsck_options *options);
 
@@ -60,4 +69,29 @@ int fsck_object(struct object *obj, void
  */
 int fsck_finish(struct fsck_options *options);
 
+/*
+ * Subsystem for storing human-readable names for each object.
+ *
+ * If fsck_enable_object_names() has not been called, all other functions are
+ * noops.
+ *
+ * Use fsck_put_object_name() to seed initial names (e.g. from refnames); the
+ * fsck code will extend that while walking trees, etc.
+ *
+ * Use fsck_get_object_name() to get a single name (or NULL if none). Or the
+ * more convenient describe_object(), which always produces an output string
+ * with the oid combined with the name (if any). Note that the return value
+ * points to a rotating array of static buffers, and may be invalidated by a
+ * subsequent call.
+ */
+void fsck_enable_object_names(struct fsck_options *options);
+const char *fsck_get_object_name(struct fsck_options *options,
+				 const struct object_id *oid);
+__attribute__((format (printf,3,4)))
+void fsck_put_object_name(struct fsck_options *options,
+			  const struct object_id *oid,
+			  const char *fmt, ...);
+const char *fsck_describe_object(struct fsck_options *options,
+				 const struct object_id *oid);
+
 #endif
diff -pruN 1.2.1+git2.18.0-1/git/fsmonitor.c 1.2.3+git2.25.1-1/git/fsmonitor.c
--- 1.2.1+git2.18.0-1/git/fsmonitor.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/fsmonitor.c	2020-02-17 04:47:35.000000000 +0000
@@ -14,8 +14,13 @@ struct trace_key trace_fsmonitor = TRACE
 static void fsmonitor_ewah_callback(size_t pos, void *is)
 {
 	struct index_state *istate = (struct index_state *)is;
-	struct cache_entry *ce = istate->cache[pos];
+	struct cache_entry *ce;
 
+	if (pos >= istate->cache_nr)
+		BUG("fsmonitor_dirty has more entries than the index (%"PRIuMAX" >= %u)",
+		    (uintmax_t)pos, istate->cache_nr);
+
+	ce = istate->cache[pos];
 	ce->ce_flags &= ~CE_FSMONITOR_VALID;
 }
 
@@ -50,17 +55,25 @@ int read_fsmonitor_extension(struct inde
 	}
 	istate->fsmonitor_dirty = fsmonitor_dirty;
 
+	if (!istate->split_index &&
+	    istate->fsmonitor_dirty->bit_size > istate->cache_nr)
+		BUG("fsmonitor_dirty has more entries than the index (%"PRIuMAX" > %u)",
+		    (uintmax_t)istate->fsmonitor_dirty->bit_size, istate->cache_nr);
+
 	trace_printf_key(&trace_fsmonitor, "read fsmonitor extension successful");
 	return 0;
 }
 
 void fill_fsmonitor_bitmap(struct index_state *istate)
 {
-	int i;
+	unsigned int i, skipped = 0;
 	istate->fsmonitor_dirty = ewah_new();
-	for (i = 0; i < istate->cache_nr; i++)
-		if (!(istate->cache[i]->ce_flags & CE_FSMONITOR_VALID))
-			ewah_set(istate->fsmonitor_dirty, i);
+	for (i = 0; i < istate->cache_nr; i++) {
+		if (istate->cache[i]->ce_flags & CE_REMOVE)
+			skipped++;
+		else if (!(istate->cache[i]->ce_flags & CE_FSMONITOR_VALID))
+			ewah_set(istate->fsmonitor_dirty, i - skipped);
+	}
 }
 
 void write_fsmonitor_extension(struct strbuf *sb, struct index_state *istate)
@@ -71,6 +84,11 @@ void write_fsmonitor_extension(struct st
 	uint32_t ewah_size = 0;
 	int fixup = 0;
 
+	if (!istate->split_index &&
+	    istate->fsmonitor_dirty->bit_size > istate->cache_nr)
+		BUG("fsmonitor_dirty has more entries than the index (%"PRIuMAX" > %u)",
+		    (uintmax_t)istate->fsmonitor_dirty->bit_size, istate->cache_nr);
+
 	put_be32(&hdr_version, INDEX_EXTENSION_VERSION);
 	strbuf_add(sb, &hdr_version, sizeof(uint32_t));
 
@@ -129,17 +147,16 @@ static void fsmonitor_refresh_callback(s
 
 void refresh_fsmonitor(struct index_state *istate)
 {
-	static int has_run_once = 0;
 	struct strbuf query_result = STRBUF_INIT;
 	int query_success = 0;
 	size_t bol; /* beginning of line */
 	uint64_t last_update;
 	char *buf;
-	int i;
+	unsigned int i;
 
-	if (!core_fsmonitor || has_run_once)
+	if (!core_fsmonitor || istate->fsmonitor_has_run_once)
 		return;
-	has_run_once = 1;
+	istate->fsmonitor_has_run_once = 1;
 
 	trace_printf_key(&trace_fsmonitor, "refresh fsmonitor");
 	/*
@@ -174,13 +191,26 @@ void refresh_fsmonitor(struct index_stat
 		}
 		if (bol < query_result.len)
 			fsmonitor_refresh_callback(istate, buf + bol);
+
+		/* Now mark the untracked cache for fsmonitor usage */
+		if (istate->untracked)
+			istate->untracked->use_fsmonitor = 1;
 	} else {
+
+		/* We only want to run the post index changed hook if we've actually changed entries, so keep track
+		 * if we actually changed entries or not */
+		int is_cache_changed = 0;
 		/* Mark all entries invalid */
-		for (i = 0; i < istate->cache_nr; i++)
-			istate->cache[i]->ce_flags &= ~CE_FSMONITOR_VALID;
+		for (i = 0; i < istate->cache_nr; i++) {
+			if (istate->cache[i]->ce_flags & CE_FSMONITOR_VALID) {
+				is_cache_changed = 1;
+				istate->cache[i]->ce_flags &= ~CE_FSMONITOR_VALID;
+			}
+		}
 
 		/* If we're going to check every file, ensure we save the results */
-		istate->cache_changed |= FSMONITOR_CHANGED;
+		if (is_cache_changed)
+			istate->cache_changed |= FSMONITOR_CHANGED;
 
 		if (istate->untracked)
 			istate->untracked->use_fsmonitor = 0;
@@ -193,7 +223,7 @@ void refresh_fsmonitor(struct index_stat
 
 void add_fsmonitor(struct index_state *istate)
 {
-	int i;
+	unsigned int i;
 
 	if (!istate->fsmonitor_last_update) {
 		trace_printf_key(&trace_fsmonitor, "add fsmonitor");
@@ -226,7 +256,7 @@ void remove_fsmonitor(struct index_state
 
 void tweak_fsmonitor(struct index_state *istate)
 {
-	int i;
+	unsigned int i;
 	int fsmonitor_enabled = git_config_get_fsmonitor();
 
 	if (istate->fsmonitor_dirty) {
@@ -237,11 +267,12 @@ void tweak_fsmonitor(struct index_state
 			}
 
 			/* Mark all previously saved entries as dirty */
+			if (istate->fsmonitor_dirty->bit_size > istate->cache_nr)
+				BUG("fsmonitor_dirty has more entries than the index (%"PRIuMAX" > %u)",
+				    (uintmax_t)istate->fsmonitor_dirty->bit_size, istate->cache_nr);
 			ewah_each_bit(istate->fsmonitor_dirty, fsmonitor_ewah_callback, istate);
 
-			/* Now mark the untracked cache for fsmonitor usage */
-			if (istate->untracked)
-				istate->untracked->use_fsmonitor = 1;
+			refresh_fsmonitor(istate);
 		}
 
 		ewah_free(istate->fsmonitor_dirty);
diff -pruN 1.2.1+git2.18.0-1/git/fsmonitor.h 1.2.3+git2.25.1-1/git/fsmonitor.h
--- 1.2.1+git2.18.0-1/git/fsmonitor.h	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/fsmonitor.h	2020-02-17 04:47:35.000000000 +0000
@@ -1,37 +1,40 @@
 #ifndef FSMONITOR_H
 #define FSMONITOR_H
 
+#include "cache.h"
+#include "dir.h"
+
 extern struct trace_key trace_fsmonitor;
 
 /*
  * Read the fsmonitor index extension and (if configured) restore the
  * CE_FSMONITOR_VALID state.
  */
-extern int read_fsmonitor_extension(struct index_state *istate, const void *data, unsigned long sz);
+int read_fsmonitor_extension(struct index_state *istate, const void *data, unsigned long sz);
 
 /*
  * Fill the fsmonitor_dirty ewah bits with their state from the index,
  * before it is split during writing.
  */
-extern void fill_fsmonitor_bitmap(struct index_state *istate);
+void fill_fsmonitor_bitmap(struct index_state *istate);
 
 /*
  * Write the CE_FSMONITOR_VALID state into the fsmonitor index
  * extension.  Reads from the fsmonitor_dirty ewah in the index.
  */
-extern void write_fsmonitor_extension(struct strbuf *sb, struct index_state *istate);
+void write_fsmonitor_extension(struct strbuf *sb, struct index_state *istate);
 
 /*
  * Add/remove the fsmonitor index extension
  */
-extern void add_fsmonitor(struct index_state *istate);
-extern void remove_fsmonitor(struct index_state *istate);
+void add_fsmonitor(struct index_state *istate);
+void remove_fsmonitor(struct index_state *istate);
 
 /*
  * Add/remove the fsmonitor index extension as necessary based on the current
  * core.fsmonitor setting.
  */
-extern void tweak_fsmonitor(struct index_state *istate);
+void tweak_fsmonitor(struct index_state *istate);
 
 /*
  * Run the configured fsmonitor integration script and clear the
@@ -39,16 +42,17 @@ extern void tweak_fsmonitor(struct index
  * any corresponding untracked cache directory structures. Optimized to only
  * run the first time it is called.
  */
-extern void refresh_fsmonitor(struct index_state *istate);
+void refresh_fsmonitor(struct index_state *istate);
 
 /*
  * Set the given cache entries CE_FSMONITOR_VALID bit. This should be
  * called any time the cache entry has been updated to reflect the
  * current state of the file on disk.
  */
-static inline void mark_fsmonitor_valid(struct cache_entry *ce)
+static inline void mark_fsmonitor_valid(struct index_state *istate, struct cache_entry *ce)
 {
-	if (core_fsmonitor) {
+	if (core_fsmonitor && !(ce->ce_flags & CE_FSMONITOR_VALID)) {
+		istate->cache_changed = 1;
 		ce->ce_flags |= CE_FSMONITOR_VALID;
 		trace_printf_key(&trace_fsmonitor, "mark_fsmonitor_clean '%s'", ce->name);
 	}
diff -pruN 1.2.1+git2.18.0-1/git/fuzz-commit-graph.c 1.2.3+git2.25.1-1/git/fuzz-commit-graph.c
--- 1.2.1+git2.18.0-1/git/fuzz-commit-graph.c	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/fuzz-commit-graph.c	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,19 @@
+#include "commit-graph.h"
+#include "repository.h"
+
+struct commit_graph *parse_commit_graph(void *graph_map, int fd,
+					size_t graph_size);
+
+int LLVMFuzzerTestOneInput(const uint8_t *data, size_t size);
+
+int LLVMFuzzerTestOneInput(const uint8_t *data, size_t size)
+{
+	struct commit_graph *g;
+
+	initialize_the_repository();
+	g = parse_commit_graph((void *)data, -1, size);
+	repo_clear(the_repository);
+	free(g);
+
+	return 0;
+}
diff -pruN 1.2.1+git2.18.0-1/git/fuzz-pack-headers.c 1.2.3+git2.25.1-1/git/fuzz-pack-headers.c
--- 1.2.1+git2.18.0-1/git/fuzz-pack-headers.c	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/fuzz-pack-headers.c	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,14 @@
+#include "packfile.h"
+
+int LLVMFuzzerTestOneInput(const uint8_t *data, size_t size);
+
+int LLVMFuzzerTestOneInput(const uint8_t *data, size_t size)
+{
+	enum object_type type;
+	unsigned long len;
+
+	unpack_object_header_buffer((const unsigned char *)data,
+				    (unsigned long)size, &type, &len);
+
+	return 0;
+}
diff -pruN 1.2.1+git2.18.0-1/git/fuzz-pack-idx.c 1.2.3+git2.25.1-1/git/fuzz-pack-idx.c
--- 1.2.1+git2.18.0-1/git/fuzz-pack-idx.c	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/fuzz-pack-idx.c	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,13 @@
+#include "object-store.h"
+#include "packfile.h"
+
+int LLVMFuzzerTestOneInput(const uint8_t *data, size_t size);
+
+int LLVMFuzzerTestOneInput(const uint8_t *data, size_t size)
+{
+	struct packed_git p;
+
+	load_idx("fuzz-input", GIT_SHA1_RAWSZ, (void *)data, size, &p);
+
+	return 0;
+}
diff -pruN 1.2.1+git2.18.0-1/git/generate-cmdlist.sh 1.2.3+git2.25.1-1/git/generate-cmdlist.sh
--- 1.2.1+git2.18.0-1/git/generate-cmdlist.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/generate-cmdlist.sh	2020-02-17 04:47:35.000000000 +0000
@@ -6,7 +6,7 @@ die () {
 }
 
 command_list () {
-	grep -v '^#' "$1"
+	eval "grep -ve '^#' $exclude_programs" <"$1"
 }
 
 get_categories () {
@@ -76,6 +76,31 @@ print_command_list () {
 	echo "};"
 }
 
+print_config_list () {
+	cat <<EOF
+static const char *config_name_list[] = {
+EOF
+	grep -h '^[a-zA-Z].*\..*::$' Documentation/*config.txt Documentation/config/*.txt |
+	sed '/deprecated/d; s/::$//; s/,  */\n/g' |
+	sort |
+	while read line
+	do
+		echo "	\"$line\","
+	done
+	cat <<EOF
+	NULL,
+};
+EOF
+}
+
+exclude_programs=
+while test "--exclude-program" = "$1"
+do
+	shift
+	exclude_programs="$exclude_programs -e \"^$1 \""
+	shift
+done
+
 echo "/* Automatically generated by generate-cmdlist.sh */
 struct cmdname_help {
 	const char *name;
@@ -88,3 +113,5 @@ echo
 define_category_names "$1"
 echo
 print_command_list "$1"
+echo
+print_config_list
diff -pruN 1.2.1+git2.18.0-1/git/gettext.c 1.2.3+git2.25.1-1/git/gettext.c
--- 1.2.1+git2.18.0-1/git/gettext.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/gettext.c	2020-02-17 04:47:35.000000000 +0000
@@ -7,11 +7,30 @@
 #include "gettext.h"
 #include "strbuf.h"
 #include "utf8.h"
+#include "config.h"
 
 #ifndef NO_GETTEXT
 #	include <locale.h>
 #	include <libintl.h>
-#	ifdef HAVE_LIBCHARSET_H
+#	ifdef GIT_WINDOWS_NATIVE
+
+static const char *locale_charset(void)
+{
+	const char *env = getenv("LC_ALL"), *dot;
+
+	if (!env || !*env)
+		env = getenv("LC_CTYPE");
+	if (!env || !*env)
+		env = getenv("LANG");
+
+	if (!env)
+		return "UTF-8";
+
+	dot = strchr(env, '.');
+	return !dot ? env : dot + 1;
+}
+
+#	elif defined HAVE_LIBCHARSET_H
 #		include <libcharset.h>
 #	else
 #		include <langinfo.h>
@@ -46,15 +65,13 @@ const char *get_preferred_languages(void
 	return NULL;
 }
 
-#ifdef GETTEXT_POISON
 int use_gettext_poison(void)
 {
 	static int poison_requested = -1;
 	if (poison_requested == -1)
-		poison_requested = getenv("GIT_GETTEXT_POISON") ? 1 : 0;
+		poison_requested = git_env_bool("GIT_TEST_GETTEXT_POISON", 0);
 	return poison_requested;
 }
-#endif
 
 #ifndef NO_GETTEXT
 static int test_vsnprintf(const char *fmt, ...)
@@ -164,6 +181,8 @@ void git_setup_gettext(void)
 	if (!podir)
 		podir = p = system_path(GIT_LOCALE_PATH);
 
+	use_gettext_poison(); /* getenv() reentrancy paranoia */
+
 	if (!is_directory(podir)) {
 		free(p);
 		return;
diff -pruN 1.2.1+git2.18.0-1/git/gettext.h 1.2.3+git2.25.1-1/git/gettext.h
--- 1.2.1+git2.18.0-1/git/gettext.h	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/gettext.h	2020-02-17 04:47:35.000000000 +0000
@@ -28,12 +28,15 @@
 
 #define FORMAT_PRESERVING(n) __attribute__((format_arg(n)))
 
+int use_gettext_poison(void);
+
 #ifndef NO_GETTEXT
-extern void git_setup_gettext(void);
-extern int gettext_width(const char *s);
+void git_setup_gettext(void);
+int gettext_width(const char *s);
 #else
 static inline void git_setup_gettext(void)
 {
+	use_gettext_poison(); /* getenv() reentrancy paranoia */
 }
 static inline int gettext_width(const char *s)
 {
@@ -41,12 +44,6 @@ static inline int gettext_width(const ch
 }
 #endif
 
-#ifdef GETTEXT_POISON
-extern int use_gettext_poison(void);
-#else
-#define use_gettext_poison() 0
-#endif
-
 static inline FORMAT_PRESERVING(1) const char *_(const char *msgid)
 {
 	if (!*msgid)
@@ -90,6 +87,6 @@ const char *Q_(const char *msgid, const
 #endif
 
 const char *get_preferred_languages(void);
-extern int is_utf8_locale(void);
+int is_utf8_locale(void);
 
 #endif
diff -pruN 1.2.1+git2.18.0-1/git/git-add--interactive.perl 1.2.3+git2.25.1-1/git/git-add--interactive.perl
--- 1.2.1+git2.18.0-1/git/git-add--interactive.perl	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/git-add--interactive.perl	2020-02-17 04:47:35.000000000 +0000
@@ -149,6 +149,20 @@ my %patch_modes = (
 		FILTER => undef,
 		IS_REVERSE => 0,
 	},
+	'worktree_head' => {
+		DIFF => 'diff-index -p',
+		APPLY => sub { apply_patch 'apply -R', @_ },
+		APPLY_CHECK => 'apply -R',
+		FILTER => undef,
+		IS_REVERSE => 1,
+	},
+	'worktree_nothead' => {
+		DIFF => 'diff-index -R -p',
+		APPLY => sub { apply_patch 'apply', @_ },
+		APPLY_CHECK => 'apply',
+		FILTER => undef,
+		IS_REVERSE => 0,
+	},
 );
 
 $patch_mode = 'stage';
@@ -163,7 +177,9 @@ sub run_cmd_pipe {
 	} else {
 		my $fh = undef;
 		open($fh, '-|', @_) or die;
-		return <$fh>;
+		my @out = <$fh>;
+		close $fh || die "Cannot close @_ ($!)";
+		return @out;
 	}
 }
 
@@ -210,7 +226,7 @@ my $status_head = sprintf($status_fmt, _
 	sub get_empty_tree {
 		return $empty_tree if defined $empty_tree;
 
-		$empty_tree = run_cmd_pipe(qw(git hash-object -t tree /dev/null));
+		($empty_tree) = run_cmd_pipe(qw(git hash-object -t tree /dev/null));
 		chomp $empty_tree;
 		return $empty_tree;
 	}
@@ -972,7 +988,11 @@ sub coalesce_overlapping_hunks {
 			next;
 		}
 		if ($ofs_delta) {
-			$n_ofs += $ofs_delta;
+			if ($patch_mode_flavour{IS_REVERSE}) {
+				$o_ofs -= $ofs_delta;
+			} else {
+				$n_ofs += $ofs_delta;
+			}
 			$_->{TEXT}->[0] = format_hunk_header($o_ofs, $o_cnt,
 							     $n_ofs, $n_cnt);
 		}
@@ -1050,6 +1070,12 @@ marked for discarding."),
 	checkout_nothead => N__(
 "If the patch applies cleanly, the edited hunk will immediately be
 marked for applying."),
+	worktree_head => N__(
+"If the patch applies cleanly, the edited hunk will immediately be
+marked for discarding."),
+	worktree_nothead => N__(
+"If the patch applies cleanly, the edited hunk will immediately be
+marked for applying."),
 );
 
 sub recount_edited_hunk {
@@ -1062,7 +1088,7 @@ sub recount_edited_hunk {
 			$o_cnt++;
 		} elsif ($mode eq '+') {
 			$n_cnt++;
-		} elsif ($mode eq ' ') {
+		} elsif ($mode eq ' ' or $mode eq "\n") {
 			$o_cnt++;
 			$n_cnt++;
 		}
@@ -1103,7 +1129,7 @@ aborted and the hunk is left unchanged.
 EOF2
 	close $fh;
 
-	chomp(my $editor = run_cmd_pipe(qw(git var GIT_EDITOR)));
+	chomp(my ($editor) = run_cmd_pipe(qw(git var GIT_EDITOR)));
 	system('sh', '-c', $editor.' "$@"', $editor, $hunkfile);
 
 	if ($? != 0) {
@@ -1260,6 +1286,18 @@ n - do not apply this hunk to index and
 q - quit; do not apply this hunk or any of the remaining ones
 a - apply this hunk and all later hunks in the file
 d - do not apply this hunk or any of the later hunks in the file"),
+	worktree_head => N__(
+"y - discard this hunk from worktree
+n - do not discard this hunk from worktree
+q - quit; do not discard this hunk or any of the remaining ones
+a - discard this hunk and all later hunks in the file
+d - do not discard this hunk or any of the later hunks in the file"),
+	worktree_nothead => N__(
+"y - apply this hunk to worktree
+n - do not apply this hunk to worktree
+q - quit; do not apply this hunk or any of the remaining ones
+a - apply this hunk and all later hunks in the file
+d - do not apply this hunk or any of the later hunks in the file"),
 );
 
 sub help_patch_cmd {
@@ -1421,6 +1459,16 @@ my %patch_update_prompt_modes = (
 		deletion => N__("Apply deletion to index and worktree [y,n,q,a,d%s,?]? "),
 		hunk => N__("Apply this hunk to index and worktree [y,n,q,a,d%s,?]? "),
 	},
+	worktree_head => {
+		mode => N__("Discard mode change from worktree [y,n,q,a,d%s,?]? "),
+		deletion => N__("Discard deletion from worktree [y,n,q,a,d%s,?]? "),
+		hunk => N__("Discard this hunk from worktree [y,n,q,a,d%s,?]? "),
+	},
+	worktree_nothead => {
+		mode => N__("Apply mode change to worktree [y,n,q,a,d%s,?]? "),
+		deletion => N__("Apply deletion to worktree [y,n,q,a,d%s,?]? "),
+		hunk => N__("Apply this hunk to worktree [y,n,q,a,d%s,?]? "),
+	},
 );
 
 sub patch_update_file {
@@ -1495,7 +1543,7 @@ sub patch_update_file {
 		for (@{$hunk[$ix]{DISPLAY}}) {
 			print;
 		}
-		print colored $prompt_color,
+		print colored $prompt_color, "(", ($ix+1), "/$num) ",
 			sprintf(__($patch_update_prompt_modes{$patch_mode}{$hunk[$ix]{TYPE}}), $other);
 
 		my $line = prompt_single_character;
@@ -1756,6 +1804,16 @@ sub process_args {
 						       'checkout_head' : 'checkout_nothead');
 					$arg = shift @ARGV or die __("missing --");
 				}
+			} elsif ($1 eq 'worktree') {
+				$arg = shift @ARGV or die __("missing --");
+				if ($arg eq '--') {
+					$patch_mode = 'checkout_index';
+				} else {
+					$patch_mode_revision = $arg;
+					$patch_mode = ($arg eq 'HEAD' ?
+						       'worktree_head' : 'worktree_nothead');
+					$arg = shift @ARGV or die __("missing --");
+				}
 			} elsif ($1 eq 'stage' or $1 eq 'stash') {
 				$patch_mode = $1;
 				$arg = shift @ARGV or die __("missing --");
diff -pruN 1.2.1+git2.18.0-1/git/.gitattributes 1.2.3+git2.25.1-1/git/.gitattributes
--- 1.2.1+git2.18.0-1/git/.gitattributes	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/.gitattributes	2020-02-17 04:47:35.000000000 +0000
@@ -5,7 +5,13 @@
 *.pl eof=lf diff=perl
 *.pm eol=lf diff=perl
 *.py eol=lf diff=python
-/Documentation/git-*.txt eol=lf
+*.bat eol=crlf
+/Documentation/**/*.txt eol=lf
 /command-list.txt eol=lf
 /GIT-VERSION-GEN eol=lf
 /mergetools/* eol=lf
+/t/oid-info/* eol=lf
+/Documentation/git-merge.txt conflict-marker-size=32
+/Documentation/gitk.txt conflict-marker-size=32
+/Documentation/user-manual.txt conflict-marker-size=32
+/t/t????-*.sh conflict-marker-size=32
diff -pruN 1.2.1+git2.18.0-1/git/git-bisect.sh 1.2.3+git2.25.1-1/git/git-bisect.sh
--- 1.2.1+git2.18.0-1/git/git-bisect.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/git-bisect.sh	2020-02-17 04:47:35.000000000 +0000
@@ -71,122 +71,7 @@ bisect_autostart() {
 }
 
 bisect_start() {
-	#
-	# Check for one bad and then some good revisions.
-	#
-	has_double_dash=0
-	for arg; do
-		case "$arg" in --) has_double_dash=1; break ;; esac
-	done
-	orig_args=$(git rev-parse --sq-quote "$@")
-	bad_seen=0
-	eval=''
-	must_write_terms=0
-	revs=''
-	if test "z$(git rev-parse --is-bare-repository)" != zfalse
-	then
-		mode=--no-checkout
-	else
-		mode=''
-	fi
-	while [ $# -gt 0 ]; do
-		arg="$1"
-		case "$arg" in
-		--)
-			shift
-			break
-		;;
-		--no-checkout)
-			mode=--no-checkout
-			shift ;;
-		--term-good|--term-old)
-			shift
-			must_write_terms=1
-			TERM_GOOD=$1
-			shift ;;
-		--term-good=*|--term-old=*)
-			must_write_terms=1
-			TERM_GOOD=${1#*=}
-			shift ;;
-		--term-bad|--term-new)
-			shift
-			must_write_terms=1
-			TERM_BAD=$1
-			shift ;;
-		--term-bad=*|--term-new=*)
-			must_write_terms=1
-			TERM_BAD=${1#*=}
-			shift ;;
-		--*)
-			die "$(eval_gettext "unrecognised option: '\$arg'")" ;;
-		*)
-			rev=$(git rev-parse -q --verify "$arg^{commit}") || {
-				test $has_double_dash -eq 1 &&
-				die "$(eval_gettext "'\$arg' does not appear to be a valid revision")"
-				break
-			}
-			revs="$revs $rev"
-			shift
-			;;
-		esac
-	done
-
-	for rev in $revs
-	do
-		# The user ran "git bisect start <sha1>
-		# <sha1>", hence did not explicitly specify
-		# the terms, but we are already starting to
-		# set references named with the default terms,
-		# and won't be able to change afterwards.
-		must_write_terms=1
-
-		case $bad_seen in
-		0) state=$TERM_BAD ; bad_seen=1 ;;
-		*) state=$TERM_GOOD ;;
-		esac
-		eval="$eval bisect_write '$state' '$rev' 'nolog' &&"
-	done
-	#
-	# Verify HEAD.
-	#
-	head=$(GIT_DIR="$GIT_DIR" git symbolic-ref -q HEAD) ||
-	head=$(GIT_DIR="$GIT_DIR" git rev-parse --verify HEAD) ||
-	die "$(gettext "Bad HEAD - I need a HEAD")"
-
-	#
-	# Check if we are bisecting.
-	#
-	start_head=''
-	if test -s "$GIT_DIR/BISECT_START"
-	then
-		# Reset to the rev from where we started.
-		start_head=$(cat "$GIT_DIR/BISECT_START")
-		if test "z$mode" != "z--no-checkout"
-		then
-			git checkout "$start_head" -- ||
-			die "$(eval_gettext "Checking out '\$start_head' failed. Try 'git bisect reset <valid-branch>'.")"
-		fi
-	else
-		# Get rev from where we start.
-		case "$head" in
-		refs/heads/*|$_x40)
-			# This error message should only be triggered by
-			# cogito usage, and cogito users should understand
-			# it relates to cg-seek.
-			[ -s "$GIT_DIR/head-name" ] &&
-				die "$(gettext "won't bisect on cg-seek'ed tree")"
-			start_head="${head#refs/heads/}"
-			;;
-		*)
-			die "$(gettext "Bad HEAD - strange symbolic ref")"
-			;;
-		esac
-	fi
-
-	#
-	# Get rid of any old bisect state.
-	#
-	git bisect--helper --bisect-clean-state || exit
+	git bisect--helper --bisect-start $@ || exit
 
 	#
 	# Change state.
@@ -199,44 +84,14 @@ bisect_start() {
 	trap 'exit 255' 1 2 3 15
 
 	#
-	# Write new start state.
-	#
-	echo "$start_head" >"$GIT_DIR/BISECT_START" && {
-		test "z$mode" != "z--no-checkout" ||
-		git update-ref --no-deref BISECT_HEAD "$start_head"
-	} &&
-	git rev-parse --sq-quote "$@" >"$GIT_DIR/BISECT_NAMES" &&
-	eval "$eval true" &&
-	if test $must_write_terms -eq 1
-	then
-		git bisect--helper --write-terms "$TERM_BAD" "$TERM_GOOD" || exit
-	fi &&
-	echo "git bisect start$orig_args" >>"$GIT_DIR/BISECT_LOG" || exit
-	#
 	# Check if we can proceed to the next bisect state.
 	#
+	get_terms
 	bisect_auto_next
 
 	trap '-' 0
 }
 
-bisect_write() {
-	state="$1"
-	rev="$2"
-	nolog="$3"
-	case "$state" in
-		"$TERM_BAD")
-			tag="$state" ;;
-		"$TERM_GOOD"|skip)
-			tag="$state"-"$rev" ;;
-		*)
-			die "$(eval_gettext "Bad bisect_write argument: \$state")" ;;
-	esac
-	git update-ref "refs/bisect/$tag" "$rev" || exit
-	echo "# $state: $(git show-branch $rev)" >>"$GIT_DIR/BISECT_LOG"
-	test -n "$nolog" || echo "git bisect $state $rev" >>"$GIT_DIR/BISECT_LOG"
-}
-
 bisect_skip() {
 	all=''
 	for arg in "$@"
@@ -255,7 +110,8 @@ bisect_skip() {
 bisect_state() {
 	bisect_autostart
 	state=$1
-	check_and_set_terms $state
+	git bisect--helper --check-and-set-terms $state $TERM_GOOD $TERM_BAD || exit
+	get_terms
 	case "$#,$state" in
 	0,*)
 		die "Please call 'bisect_state' with at least one argument." ;;
@@ -263,7 +119,7 @@ bisect_state() {
 		bisected_head=$(bisect_head)
 		rev=$(git rev-parse --verify "$bisected_head") ||
 			die "$(eval_gettext "Bad rev input: \$bisected_head")"
-		bisect_write "$state" "$rev"
+		git bisect--helper --bisect-write "$state" "$rev" "$TERM_GOOD" "$TERM_BAD" || exit
 		git bisect--helper --check-expected-revs "$rev" ;;
 	2,"$TERM_BAD"|*,"$TERM_GOOD"|*,skip)
 		shift
@@ -276,7 +132,7 @@ bisect_state() {
 		done
 		for rev in $hash_list
 		do
-			bisect_write "$state" "$rev"
+			git bisect--helper --bisect-write "$state" "$rev" "$TERM_GOOD" "$TERM_BAD" || exit
 		done
 		git bisect--helper --check-expected-revs $hash_list ;;
 	*,"$TERM_BAD")
@@ -287,59 +143,14 @@ bisect_state() {
 	bisect_auto_next
 }
 
-bisect_next_check() {
-	missing_good= missing_bad=
-	git show-ref -q --verify refs/bisect/$TERM_BAD || missing_bad=t
-	test -n "$(git for-each-ref "refs/bisect/$TERM_GOOD-*")" || missing_good=t
-
-	case "$missing_good,$missing_bad,$1" in
-	,,*)
-		: have both $TERM_GOOD and $TERM_BAD - ok
-		;;
-	*,)
-		# do not have both but not asked to fail - just report.
-		false
-		;;
-	t,,"$TERM_GOOD")
-		# have bad (or new) but not good (or old).  we could bisect although
-		# this is less optimum.
-		eval_gettextln "Warning: bisecting only with a \$TERM_BAD commit." >&2
-		if test -t 0
-		then
-			# TRANSLATORS: Make sure to include [Y] and [n] in your
-			# translation. The program will only accept English input
-			# at this point.
-			gettext "Are you sure [Y/n]? " >&2
-			read yesno
-			case "$yesno" in [Nn]*) exit 1 ;; esac
-		fi
-		: bisect without $TERM_GOOD...
-		;;
-	*)
-		bad_syn=$(bisect_voc bad)
-		good_syn=$(bisect_voc good)
-		if test -s "$GIT_DIR/BISECT_START"
-		then
-
-			eval_gettextln "You need to give me at least one \$bad_syn and one \$good_syn revision.
-(You can use \"git bisect \$bad_syn\" and \"git bisect \$good_syn\" for that.)" >&2
-		else
-			eval_gettextln "You need to start by \"git bisect start\".
-You then need to give me at least one \$good_syn and one \$bad_syn revision.
-(You can use \"git bisect \$bad_syn\" and \"git bisect \$good_syn\" for that.)" >&2
-		fi
-		exit 1 ;;
-	esac
-}
-
 bisect_auto_next() {
-	bisect_next_check && bisect_next || :
+	git bisect--helper --bisect-next-check $TERM_GOOD $TERM_BAD && bisect_next || :
 }
 
 bisect_next() {
 	case "$#" in 0) ;; *) usage ;; esac
 	bisect_autostart
-	bisect_next_check $TERM_GOOD
+	git bisect--helper --bisect-next-check $TERM_GOOD $TERM_BAD $TERM_GOOD|| exit
 
 	# Perform all bisection computation, display and checkout
 	git bisect--helper --next-all $(test -f "$GIT_DIR/BISECT_HEAD" && echo --no-checkout)
@@ -371,7 +182,7 @@ bisect_next() {
 }
 
 bisect_visualize() {
-	bisect_next_check fail
+	git bisect--helper --bisect-next-check $TERM_GOOD $TERM_BAD fail || exit
 
 	if test $# = 0
 	then
@@ -393,35 +204,11 @@ bisect_visualize() {
 	eval '"$@"' --bisect -- $(cat "$GIT_DIR/BISECT_NAMES")
 }
 
-bisect_reset() {
-	test -s "$GIT_DIR/BISECT_START" || {
-		gettextln "We are not bisecting."
-		return
-	}
-	case "$#" in
-	0) branch=$(cat "$GIT_DIR/BISECT_START") ;;
-	1) git rev-parse --quiet --verify "$1^{commit}" >/dev/null || {
-			invalid="$1"
-			die "$(eval_gettext "'\$invalid' is not a valid commit")"
-		}
-		branch="$1" ;;
-	*)
-		usage ;;
-	esac
-
-	if ! test -f "$GIT_DIR/BISECT_HEAD" && ! git checkout "$branch" --
-	then
-		die "$(eval_gettext "Could not check out original HEAD '\$branch'.
-Try 'git bisect reset <commit>'.")"
-	fi
-	git bisect--helper --bisect-clean-state || exit
-}
-
 bisect_replay () {
 	file="$1"
 	test "$#" -eq 1 || die "$(gettext "No logfile given")"
 	test -r "$file" || die "$(eval_gettext "cannot read \$file for replaying")"
-	bisect_reset
+	git bisect--helper --bisect-reset || exit
 	while read git bisect command rev
 	do
 		test "$git $bisect" = "git bisect" || test "$git" = "git-bisect" || continue
@@ -431,15 +218,16 @@ bisect_replay () {
 			command="$bisect"
 		fi
 		get_terms
-		check_and_set_terms "$command"
+		git bisect--helper --check-and-set-terms "$command" "$TERM_GOOD" "$TERM_BAD" || exit
+		get_terms
 		case "$command" in
 		start)
 			cmd="bisect_start $rev"
 			eval "$cmd" ;;
 		"$TERM_GOOD"|"$TERM_BAD"|skip)
-			bisect_write "$command" "$rev" ;;
+			git bisect--helper --bisect-write "$command" "$rev" "$TERM_GOOD" "$TERM_BAD" || exit;;
 		terms)
-			bisect_terms $rev ;;
+			git bisect--helper --bisect-terms $rev || exit;;
 		*)
 			die "$(gettext "?? what are you talking about?")" ;;
 		esac
@@ -448,7 +236,7 @@ bisect_replay () {
 }
 
 bisect_run () {
-	bisect_next_check fail
+	git bisect--helper --bisect-next-check $TERM_GOOD $TERM_BAD fail || exit
 
 	test -n "$*" || die "$(gettext "bisect run failed: no command provided.")"
 
@@ -523,74 +311,6 @@ get_terms () {
 	fi
 }
 
-check_and_set_terms () {
-	cmd="$1"
-	case "$cmd" in
-	skip|start|terms) ;;
-	*)
-		if test -s "$GIT_DIR/BISECT_TERMS" && test "$cmd" != "$TERM_BAD" && test "$cmd" != "$TERM_GOOD"
-		then
-			die "$(eval_gettext "Invalid command: you're currently in a \$TERM_BAD/\$TERM_GOOD bisect.")"
-		fi
-		case "$cmd" in
-		bad|good)
-			if ! test -s "$GIT_DIR/BISECT_TERMS"
-			then
-				TERM_BAD=bad
-				TERM_GOOD=good
-				git bisect--helper --write-terms "$TERM_BAD" "$TERM_GOOD" || exit
-			fi
-			;;
-		new|old)
-			if ! test -s "$GIT_DIR/BISECT_TERMS"
-			then
-				TERM_BAD=new
-				TERM_GOOD=old
-				git bisect--helper --write-terms "$TERM_BAD" "$TERM_GOOD" || exit
-			fi
-			;;
-		esac ;;
-	esac
-}
-
-bisect_voc () {
-	case "$1" in
-	bad) echo "bad|new" ;;
-	good) echo "good|old" ;;
-	esac
-}
-
-bisect_terms () {
-	get_terms
-	if ! test -s "$GIT_DIR/BISECT_TERMS"
-	then
-		die "$(gettext "no terms defined")"
-	fi
-	case "$#" in
-	0)
-		gettextln "Your current terms are $TERM_GOOD for the old state
-and $TERM_BAD for the new state."
-		;;
-	1)
-		arg=$1
-		case "$arg" in
-			--term-good|--term-old)
-				printf '%s\n' "$TERM_GOOD"
-				;;
-			--term-bad|--term-new)
-				printf '%s\n' "$TERM_BAD"
-				;;
-			*)
-				die "$(eval_gettext "invalid argument \$arg for 'git bisect terms'.
-Supported options are: --term-good|--term-old and --term-bad|--term-new.")"
-				;;
-		esac
-		;;
-	*)
-		usage ;;
-	esac
-}
-
 case "$#" in
 0)
 	usage ;;
@@ -613,7 +333,7 @@ case "$#" in
 	visualize|view)
 		bisect_visualize "$@" ;;
 	reset)
-		bisect_reset "$@" ;;
+		git bisect--helper --bisect-reset "$@" ;;
 	replay)
 		bisect_replay "$@" ;;
 	log)
@@ -621,7 +341,7 @@ case "$#" in
 	run)
 		bisect_run "$@" ;;
 	terms)
-		bisect_terms "$@" ;;
+		git bisect--helper --bisect-terms "$@" || exit;;
 	*)
 		usage ;;
 	esac
diff -pruN 1.2.1+git2.18.0-1/git/git.c 1.2.3+git2.25.1-1/git/git.c
--- 1.2.1+git2.18.0-1/git/git.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/git.c	2020-02-17 04:47:35.000000000 +0000
@@ -33,7 +33,8 @@ const char git_usage_string[] =
 const char git_more_info_string[] =
 	N_("'git help -a' and 'git help -g' list available subcommands and some\n"
 	   "concept guides. See 'git help <command>' or 'git help <concept>'\n"
-	   "to read about a specific subcommand or concept.");
+	   "to read about a specific subcommand or concept.\n"
+	   "See 'git help git' for an overview of the system.");
 
 static int use_pager = -1;
 
@@ -62,6 +63,13 @@ static int list_cmds(const char *spec)
 {
 	struct string_list list = STRING_LIST_INIT_DUP;
 	int i;
+	int nongit;
+
+	/*
+	* Set up the repository so we can pick up any repo-level config (like
+	* completion.commands).
+	*/
+	setup_git_directory_gently(&nongit);
 
 	while (*spec) {
 		const char *sep = strchrnul(spec, ',');
@@ -98,7 +106,8 @@ static int list_cmds(const char *spec)
 	return 0;
 }
 
-static void commit_pager_choice(void) {
+static void commit_pager_choice(void)
+{
 	switch (use_pager) {
 	case 0:
 		setenv("GIT_PAGER", "cat", 1);
@@ -146,16 +155,20 @@ static int handle_options(const char ***
 				git_set_exec_path(cmd + 1);
 			else {
 				puts(git_exec_path());
+				trace2_cmd_name("_query_");
 				exit(0);
 			}
 		} else if (!strcmp(cmd, "--html-path")) {
 			puts(system_path(GIT_HTML_PATH));
+			trace2_cmd_name("_query_");
 			exit(0);
 		} else if (!strcmp(cmd, "--man-path")) {
 			puts(system_path(GIT_MAN_PATH));
+			trace2_cmd_name("_query_");
 			exit(0);
 		} else if (!strcmp(cmd, "--info-path")) {
 			puts(system_path(GIT_INFO_PATH));
+			trace2_cmd_name("_query_");
 			exit(0);
 		} else if (!strcmp(cmd, "-p") || !strcmp(cmd, "--paginate")) {
 			use_pager = 1;
@@ -164,7 +177,7 @@ static int handle_options(const char ***
 			if (envchanged)
 				*envchanged = 1;
 		} else if (!strcmp(cmd, "--no-replace-objects")) {
-			check_replace_refs = 0;
+			read_replace_refs = 0;
 			setenv(NO_REPLACE_OBJECTS_ENVIRONMENT, "1", 1);
 			if (envchanged)
 				*envchanged = 1;
@@ -267,7 +280,7 @@ static int handle_options(const char ***
 		} else if (!strcmp(cmd, "--shallow-file")) {
 			(*argv)++;
 			(*argc)--;
-			set_alternate_shallow_file((*argv)[0], 1);
+			set_alternate_shallow_file(the_repository, (*argv)[0], 1);
 			if (envchanged)
 				*envchanged = 1;
 		} else if (!strcmp(cmd, "-C")) {
@@ -284,6 +297,7 @@ static int handle_options(const char ***
 			(*argv)++;
 			(*argc)--;
 		} else if (skip_prefix(cmd, "--list-cmds=", &cmd)) {
+			trace2_cmd_name("_query_");
 			if (!strcmp(cmd, "parseopt")) {
 				struct string_list list = STRING_LIST_INIT_DUP;
 				int i;
@@ -318,6 +332,9 @@ static int handle_alias(int *argcp, cons
 	alias_command = (*argv)[0];
 	alias_string = alias_lookup(alias_command);
 	if (alias_string) {
+		if (*argcp > 1 && !strcmp((*argv)[1], "-h"))
+			fprintf_ln(stderr, _("'%s' is aliased to '%s'"),
+				   alias_command, alias_string);
 		if (alias_string[0] == '!') {
 			struct child_process child = CHILD_PROCESS_INIT;
 			int nongit_ok;
@@ -328,34 +345,38 @@ static int handle_alias(int *argcp, cons
 			commit_pager_choice();
 
 			child.use_shell = 1;
+			child.trace2_child_class = "shell_alias";
 			argv_array_push(&child.args, alias_string + 1);
 			argv_array_pushv(&child.args, (*argv) + 1);
 
+			trace2_cmd_alias(alias_command, child.args.argv);
+			trace2_cmd_list_config();
+			trace2_cmd_name("_run_shell_alias_");
+
 			ret = run_command(&child);
 			if (ret >= 0)   /* normal exit */
 				exit(ret);
 
-			die_errno("while expanding alias '%s': '%s'",
-			    alias_command, alias_string + 1);
+			die_errno(_("while expanding alias '%s': '%s'"),
+				  alias_command, alias_string + 1);
 		}
 		count = split_cmdline(alias_string, &new_argv);
 		if (count < 0)
-			die("Bad alias.%s string: %s", alias_command,
-			    split_cmdline_strerror(count));
+			die(_("bad alias.%s string: %s"), alias_command,
+			    _(split_cmdline_strerror(count)));
 		option_count = handle_options(&new_argv, &count, &envchanged);
 		if (envchanged)
-			die("alias '%s' changes environment variables.\n"
-				 "You can use '!git' in the alias to do this",
-				 alias_command);
-		memmove(new_argv - option_count, new_argv,
-				count * sizeof(char *));
+			die(_("alias '%s' changes environment variables.\n"
+			      "You can use '!git' in the alias to do this"),
+			    alias_command);
+		MOVE_ARRAY(new_argv - option_count, new_argv, count);
 		new_argv -= option_count;
 
 		if (count < 1)
-			die("empty alias for %s", alias_command);
+			die(_("empty alias for %s"), alias_command);
 
 		if (!strcmp(alias_command, new_argv[0]))
-			die("recursive alias: %s", alias_command);
+			die(_("recursive alias: %s"), alias_command);
 
 		trace_argv_printf(new_argv,
 				  "trace: alias expansion: %s =>",
@@ -363,7 +384,10 @@ static int handle_alias(int *argcp, cons
 
 		REALLOC_ARRAY(new_argv, count + *argcp);
 		/* insert after command name */
-		memcpy(new_argv + count, *argv + 1, sizeof(char *) * *argcp);
+		COPY_ARRAY(new_argv + count, *argv + 1, *argcp);
+
+		trace2_cmd_alias(alias_command, new_argv);
+		trace2_cmd_list_config();
 
 		*argv = new_argv;
 		*argcp += count - 1;
@@ -406,15 +430,20 @@ static int run_builtin(struct cmd_struct
 
 	if (!help && get_super_prefix()) {
 		if (!(p->option & SUPPORT_SUPER_PREFIX))
-			die("%s doesn't support --super-prefix", p->cmd);
+			die(_("%s doesn't support --super-prefix"), p->cmd);
 	}
 
 	if (!help && p->option & NEED_WORK_TREE)
 		setup_work_tree();
 
 	trace_argv_printf(argv, "trace: built-in: git");
+	trace2_cmd_name(p->cmd);
+	trace2_cmd_list_config();
 
+	validate_cache_entries(the_repository->index);
 	status = p->fn(argc, argv, prefix);
+	validate_cache_entries(the_repository->index);
+
 	if (status)
 		return status;
 
@@ -427,11 +456,11 @@ static int run_builtin(struct cmd_struct
 
 	/* Check for ENOSPC and EIO errors.. */
 	if (fflush(stdout))
-		die_errno("write failure on standard output");
+		die_errno(_("write failure on standard output"));
 	if (ferror(stdout))
-		die("unknown write failure on standard output");
+		die(_("unknown write failure on standard output"));
 	if (fclose(stdout))
-		die_errno("close failed on standard output");
+		die_errno(_("close failed on standard output"));
 	return 0;
 }
 
@@ -469,7 +498,8 @@ static struct cmd_struct commands[] = {
 	{ "diff-files", cmd_diff_files, RUN_SETUP | NEED_WORK_TREE | NO_PARSEOPT },
 	{ "diff-index", cmd_diff_index, RUN_SETUP | NO_PARSEOPT },
 	{ "diff-tree", cmd_diff_tree, RUN_SETUP | NO_PARSEOPT },
-	{ "difftool", cmd_difftool, RUN_SETUP | NEED_WORK_TREE },
+	{ "difftool", cmd_difftool, RUN_SETUP_GENTLY },
+	{ "env--helper", cmd_env__helper },
 	{ "fast-export", cmd_fast_export, RUN_SETUP },
 	{ "fetch", cmd_fetch, RUN_SETUP },
 	{ "fetch-pack", cmd_fetch_pack, RUN_SETUP | NO_PARSEOPT },
@@ -505,6 +535,7 @@ static struct cmd_struct commands[] = {
 	{ "merge-tree", cmd_merge_tree, RUN_SETUP | NO_PARSEOPT },
 	{ "mktag", cmd_mktag, RUN_SETUP | NO_PARSEOPT },
 	{ "mktree", cmd_mktree, RUN_SETUP },
+	{ "multi-pack-index", cmd_multi_pack_index, RUN_SETUP_GENTLY },
 	{ "mv", cmd_mv, RUN_SETUP | NEED_WORK_TREE },
 	{ "name-rev", cmd_name_rev, RUN_SETUP },
 	{ "notes", cmd_notes, RUN_SETUP },
@@ -517,8 +548,10 @@ static struct cmd_struct commands[] = {
 	{ "prune-packed", cmd_prune_packed, RUN_SETUP },
 	{ "pull", cmd_pull, RUN_SETUP | NEED_WORK_TREE },
 	{ "push", cmd_push, RUN_SETUP },
+	{ "range-diff", cmd_range_diff, RUN_SETUP | USE_PAGER },
 	{ "read-tree", cmd_read_tree, RUN_SETUP | SUPPORT_SUPER_PREFIX},
-	{ "rebase--helper", cmd_rebase__helper, RUN_SETUP | NEED_WORK_TREE },
+	{ "rebase", cmd_rebase, RUN_SETUP | NEED_WORK_TREE },
+	{ "rebase--interactive", cmd_rebase__interactive, RUN_SETUP | NEED_WORK_TREE },
 	{ "receive-pack", cmd_receive_pack },
 	{ "reflog", cmd_reflog, RUN_SETUP },
 	{ "remote", cmd_remote, RUN_SETUP },
@@ -528,20 +561,29 @@ static struct cmd_struct commands[] = {
 	{ "replace", cmd_replace, RUN_SETUP },
 	{ "rerere", cmd_rerere, RUN_SETUP },
 	{ "reset", cmd_reset, RUN_SETUP },
+	{ "restore", cmd_restore, RUN_SETUP | NEED_WORK_TREE },
 	{ "rev-list", cmd_rev_list, RUN_SETUP | NO_PARSEOPT },
 	{ "rev-parse", cmd_rev_parse, NO_PARSEOPT },
 	{ "revert", cmd_revert, RUN_SETUP | NEED_WORK_TREE },
 	{ "rm", cmd_rm, RUN_SETUP },
 	{ "send-pack", cmd_send_pack, RUN_SETUP },
-	{ "serve", cmd_serve, RUN_SETUP },
 	{ "shortlog", cmd_shortlog, RUN_SETUP_GENTLY | USE_PAGER },
 	{ "show", cmd_show, RUN_SETUP },
 	{ "show-branch", cmd_show_branch, RUN_SETUP },
+	{ "show-index", cmd_show_index },
 	{ "show-ref", cmd_show_ref, RUN_SETUP },
+	{ "sparse-checkout", cmd_sparse_checkout, RUN_SETUP | NEED_WORK_TREE },
 	{ "stage", cmd_add, RUN_SETUP | NEED_WORK_TREE },
+	/*
+	 * NEEDSWORK: Until the builtin stash is thoroughly robust and no
+	 * longer needs redirection to the stash shell script this is kept as
+	 * is, then should be changed to RUN_SETUP | NEED_WORK_TREE
+	 */
+	{ "stash", cmd_stash },
 	{ "status", cmd_status, RUN_SETUP | NEED_WORK_TREE },
 	{ "stripspace", cmd_stripspace },
 	{ "submodule--helper", cmd_submodule__helper, RUN_SETUP | SUPPORT_SUPER_PREFIX | NO_PARSEOPT },
+	{ "switch", cmd_switch, RUN_SETUP | NEED_WORK_TREE },
 	{ "symbolic-ref", cmd_symbolic_ref, RUN_SETUP },
 	{ "tag", cmd_tag, RUN_SETUP | DELAY_PAGER_CONFIG },
 	{ "unpack-file", cmd_unpack_file, RUN_SETUP | NO_PARSEOPT },
@@ -639,7 +681,7 @@ static void execv_dashed_external(const
 	int status;
 
 	if (get_super_prefix())
-		die("%s doesn't support --super-prefix", argv[0]);
+		die(_("%s doesn't support --super-prefix"), argv[0]);
 
 	if (use_pager == -1 && !is_builtin(argv[0]))
 		use_pager = check_pager_config(argv[0]);
@@ -650,7 +692,14 @@ static void execv_dashed_external(const
 	cmd.clean_on_exit = 1;
 	cmd.wait_after_clean = 1;
 	cmd.silent_exec_failure = 1;
+	cmd.trace2_child_class = "dashed";
+
+	trace2_cmd_name("_run_dashed_");
 
+	/*
+	 * The code in run_command() logs trace2 child_start/child_exit
+	 * events, so we do not need to report exec/exec_result events here.
+	 */
 	trace_argv_printf(cmd.args.argv, "trace: exec:");
 
 	/*
@@ -660,6 +709,12 @@ static void execv_dashed_external(const
 	 * the program.
 	 */
 	status = run_command(&cmd);
+
+	/*
+	 * If the child process ran and we are now going to exit, emit a
+	 * generic string as our trace2 command verb to indicate that we
+	 * launched a dashed command.
+	 */
 	if (status >= 0)
 		exit(status);
 	else if (errno != ENOENT)
@@ -669,6 +724,8 @@ static void execv_dashed_external(const
 static int run_argv(int *argcp, const char ***argv)
 {
 	int done_alias = 0;
+	struct string_list cmd_list = STRING_LIST_INIT_NODUP;
+	struct string_list_item *seen;
 
 	while (1) {
 		/*
@@ -682,21 +739,75 @@ static int run_argv(int *argcp, const ch
 		 */
 		if (!done_alias)
 			handle_builtin(*argcp, *argv);
+		else if (get_builtin(**argv)) {
+			struct argv_array args = ARGV_ARRAY_INIT;
+			int i;
+
+			/*
+			 * The current process is committed to launching a
+			 * child process to run the command named in (**argv)
+			 * and exiting.  Log a generic string as the trace2
+			 * command verb to indicate this.  Note that the child
+			 * process will log the actual verb when it runs.
+			 */
+			trace2_cmd_name("_run_git_alias_");
+
+			if (get_super_prefix())
+				die("%s doesn't support --super-prefix", **argv);
+
+			commit_pager_choice();
+
+			argv_array_push(&args, "git");
+			for (i = 0; i < *argcp; i++)
+				argv_array_push(&args, (*argv)[i]);
+
+			trace_argv_printf(args.argv, "trace: exec:");
+
+			/*
+			 * if we fail because the command is not found, it is
+			 * OK to return. Otherwise, we just pass along the status code.
+			 */
+			i = run_command_v_opt_tr2(args.argv, RUN_SILENT_EXEC_FAILURE |
+						  RUN_CLEAN_ON_EXIT, "git_alias");
+			if (i >= 0 || errno != ENOENT)
+				exit(i);
+			die("could not execute builtin %s", **argv);
+		}
 
 		/* .. then try the external ones */
 		execv_dashed_external(*argv);
 
-		/* It could be an alias -- this works around the insanity
+		seen = unsorted_string_list_lookup(&cmd_list, *argv[0]);
+		if (seen) {
+			int i;
+			struct strbuf sb = STRBUF_INIT;
+			for (i = 0; i < cmd_list.nr; i++) {
+				struct string_list_item *item = &cmd_list.items[i];
+
+				strbuf_addf(&sb, "\n  %s", item->string);
+				if (item == seen)
+					strbuf_addstr(&sb, " <==");
+				else if (i == cmd_list.nr - 1)
+					strbuf_addstr(&sb, " ==>");
+			}
+			die(_("alias loop detected: expansion of '%s' does"
+			      " not terminate:%s"), cmd_list.items[0].string, sb.buf);
+		}
+
+		string_list_append(&cmd_list, *argv[0]);
+
+		/*
+		 * It could be an alias -- this works around the insanity
 		 * of overriding "git log" with "git show" by having
 		 * alias.log = show
 		 */
-		if (done_alias)
-			break;
 		if (!handle_alias(argcp, argv))
 			break;
 		done_alias = 1;
 	}
 
+	string_list_clear(&cmd_list, 0);
+
 	return done_alias;
 }
 
@@ -729,7 +840,7 @@ int cmd_main(int argc, const char **argv
 	if (skip_prefix(cmd, "git-", &cmd)) {
 		argv[0] = cmd;
 		handle_builtin(argc, argv);
-		die("cannot handle %s as a builtin", cmd);
+		die(_("cannot handle %s as a builtin"), cmd);
 	}
 
 	/* Look for flags.. */
@@ -742,7 +853,7 @@ int cmd_main(int argc, const char **argv
 	} else {
 		/* The user didn't specify a command; give them help */
 		commit_pager_choice();
-		printf("usage: %s\n\n", git_usage_string);
+		printf(_("usage: %s\n\n"), git_usage_string);
 		list_common_cmds_help();
 		printf("\n%s\n", _(git_more_info_string));
 		exit(1);
diff -pruN 1.2.1+git2.18.0-1/git/git-compat-util.h 1.2.3+git2.25.1-1/git/git-compat-util.h
--- 1.2.1+git2.18.0-1/git/git-compat-util.h	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/git-compat-util.h	2020-02-17 04:47:35.000000000 +0000
@@ -1,6 +1,15 @@
 #ifndef GIT_COMPAT_UTIL_H
 #define GIT_COMPAT_UTIL_H
 
+#ifdef USE_MSVC_CRTDBG
+/*
+ * For these to work they must appear very early in each
+ * file -- before most of the standard header files.
+ */
+#include <stdlib.h>
+#include <crtdbg.h>
+#endif
+
 #define _FILE_OFFSET_BITS 64
 
 
@@ -68,7 +77,7 @@
 #endif
 /*
  * ARRAY_SIZE - get the number of elements in a visible array
- *  <at> x: the array whose size you want.
+ * @x: the array whose size you want.
  *
  * This does not work on pointers, or arrays declared as [], or
  * function parameters.  With correct compiler support, such usage
@@ -146,8 +155,8 @@
 #define _SGI_SOURCE 1
 
 #if defined(WIN32) && !defined(__CYGWIN__) /* Both MinGW and MSVC */
-# if defined (_MSC_VER) && !defined(_WIN32_WINNT)
-#  define _WIN32_WINNT 0x0502
+# if !defined(_WIN32_WINNT)
+#  define _WIN32_WINNT 0x0600
 # endif
 #define WIN32_LEAN_AND_MEAN  /* stops windows.h including winsock.h */
 #include <winsock2.h>
@@ -180,9 +189,12 @@
 #include <regex.h>
 #include <utime.h>
 #include <syslog.h>
-#ifndef NO_SYS_POLL_H
+#if !defined(NO_POLL_H)
+#include <poll.h>
+#elif !defined(NO_SYS_POLL_H)
 #include <sys/poll.h>
 #else
+/* Pull the compat stuff */
 #include <poll.h>
 #endif
 #ifdef HAVE_BSD_SYSCTL
@@ -190,12 +202,14 @@
 #endif
 
 #if defined(__CYGWIN__)
-#include "compat/cygwin.h"
+#include "compat/win32/path-utils.h"
 #endif
 #if defined(__MINGW32__)
 /* pull in Windows compatibility stuff */
+#include "compat/win32/path-utils.h"
 #include "compat/mingw.h"
 #elif defined(_MSC_VER)
+#include "compat/win32/path-utils.h"
 #include "compat/msvc.h"
 #else
 #include <sys/utsname.h>
@@ -220,7 +234,7 @@
 #endif
 #ifdef NO_INTPTR_T
 /*
- * On I16LP32, ILP32 and LP64 "long" is the save bet, however
+ * On I16LP32, ILP32 and LP64 "long" is the safe bet, however
  * on LLP86, IL33LLP64 and P64 it needs to be "long long",
  * while on IP16 and IP16L32 it is "int" (resp. "short")
  * Size needs to match (or exceed) 'sizeof(void *)'.
@@ -245,7 +259,7 @@ typedef unsigned long uintptr_t;
 
 #ifdef MKDIR_WO_TRAILING_SLASH
 #define mkdir(a,b) compat_mkdir_wo_trailing_slash((a),(b))
-extern int compat_mkdir_wo_trailing_slash(const char*, mode_t);
+int compat_mkdir_wo_trailing_slash(const char*, mode_t);
 #endif
 
 #ifdef NO_STRUCT_ITIMERVAL
@@ -263,9 +277,9 @@ struct itimerval {
 #include <libgen.h>
 #else
 #define basename gitbasename
-extern char *gitbasename(char *);
+char *gitbasename(char *);
 #define dirname gitdirname
-extern char *gitdirname(char *);
+char *gitdirname(char *);
 #endif
 
 #ifndef NO_ICONV
@@ -306,30 +320,11 @@ extern char *gitdirname(char *);
 #define PATH_MAX 4096
 #endif
 
-#ifndef PRIuMAX
-#define PRIuMAX "llu"
-#endif
-
-#ifndef SCNuMAX
-#define SCNuMAX PRIuMAX
-#endif
-
-#ifndef PRIu32
-#define PRIu32 "u"
-#endif
-
-#ifndef PRIx32
-#define PRIx32 "x"
-#endif
-
-#ifndef PRIo32
-#define PRIo32 "o"
-#endif
-
 typedef uintmax_t timestamp_t;
 #define PRItime PRIuMAX
 #define parse_timestamp strtoumax
 #define TIME_MAX UINTMAX_MAX
+#define TIME_MIN 0
 
 #ifndef PATH_SEP
 #define PATH_SEP ':'
@@ -342,6 +337,14 @@ typedef uintmax_t timestamp_t;
 #define _PATH_DEFPATH "/usr/local/bin:/usr/bin:/bin"
 #endif
 
+#ifndef platform_core_config
+static inline int noop_core_config(const char *var, const char *value, void *cb)
+{
+	return 0;
+}
+#define platform_core_config noop_core_config
+#endif
+
 #ifndef has_dos_drive_prefix
 static inline int git_has_dos_drive_prefix(const char *path)
 {
@@ -374,6 +377,10 @@ static inline int git_offset_1st_compone
 #define offset_1st_component git_offset_1st_component
 #endif
 
+#ifndef is_valid_path
+#define is_valid_path(path) 1
+#endif
+
 #ifndef find_last_dir_sep
 static inline char *git_find_last_dir_sep(const char *path)
 {
@@ -382,6 +389,23 @@ static inline char *git_find_last_dir_se
 #define find_last_dir_sep git_find_last_dir_sep
 #endif
 
+#ifndef query_user_email
+#define query_user_email() NULL
+#endif
+
+#ifdef __TANDEM
+#include <floss.h(floss_execl,floss_execlp,floss_execv,floss_execvp)>
+#include <floss.h(floss_getpwuid)>
+#ifndef NSIG
+/*
+ * NonStop NSE and NSX do not provide NSIG. SIGGUARDIAN(99) is the highest
+ * known, by detective work using kill -l as a list is all signals
+ * instead of signal.h where it should be.
+ */
+# define NSIG 100
+#endif
+#endif
+
 #if defined(__HP_cc) && (__HP_cc >= 61000)
 #define NORETURN __attribute__((noreturn))
 #define NORETURN_PTR
@@ -408,6 +432,8 @@ static inline char *git_find_last_dir_se
 #define LAST_ARG_MUST_BE_NULL
 #endif
 
+#define MAYBE_UNUSED __attribute__((__unused__))
+
 #include "compat/bswap.h"
 
 #include "wildmatch.h"
@@ -415,15 +441,15 @@ static inline char *git_find_last_dir_se
 struct strbuf;
 
 /* General helper functions */
-extern void vreportf(const char *prefix, const char *err, va_list params);
-extern NORETURN void usage(const char *err);
-extern NORETURN void usagef(const char *err, ...) __attribute__((format (printf, 1, 2)));
-extern NORETURN void die(const char *err, ...) __attribute__((format (printf, 1, 2)));
-extern NORETURN void die_errno(const char *err, ...) __attribute__((format (printf, 1, 2)));
-extern int error(const char *err, ...) __attribute__((format (printf, 1, 2)));
-extern int error_errno(const char *err, ...) __attribute__((format (printf, 1, 2)));
-extern void warning(const char *err, ...) __attribute__((format (printf, 1, 2)));
-extern void warning_errno(const char *err, ...) __attribute__((format (printf, 1, 2)));
+void vreportf(const char *prefix, const char *err, va_list params);
+NORETURN void usage(const char *err);
+NORETURN void usagef(const char *err, ...) __attribute__((format (printf, 1, 2)));
+NORETURN void die(const char *err, ...) __attribute__((format (printf, 1, 2)));
+NORETURN void die_errno(const char *err, ...) __attribute__((format (printf, 1, 2)));
+int error(const char *err, ...) __attribute__((format (printf, 1, 2)));
+int error_errno(const char *err, ...) __attribute__((format (printf, 1, 2)));
+void warning(const char *err, ...) __attribute__((format (printf, 1, 2)));
+void warning_errno(const char *err, ...) __attribute__((format (printf, 1, 2)));
 
 #ifndef NO_OPENSSL
 #ifdef APPLE_COMMON_CRYPTO
@@ -451,15 +477,15 @@ static inline int const_error(void)
 #define error_errno(...) (error_errno(__VA_ARGS__), const_error())
 #endif
 
-extern void set_die_routine(NORETURN_PTR void (*routine)(const char *err, va_list params));
-extern void set_error_routine(void (*routine)(const char *err, va_list params));
+void set_die_routine(NORETURN_PTR void (*routine)(const char *err, va_list params));
+void set_error_routine(void (*routine)(const char *err, va_list params));
 extern void (*get_error_routine(void))(const char *err, va_list params);
-extern void set_warn_routine(void (*routine)(const char *warn, va_list params));
+void set_warn_routine(void (*routine)(const char *warn, va_list params));
 extern void (*get_warn_routine(void))(const char *warn, va_list params);
-extern void set_die_is_recursing_routine(int (*routine)(void));
+void set_die_is_recursing_routine(int (*routine)(void));
 
-extern int starts_with(const char *str, const char *prefix);
-extern int istarts_with(const char *str, const char *prefix);
+int starts_with(const char *str, const char *prefix);
+int istarts_with(const char *str, const char *prefix);
 
 /*
  * If the string "str" begins with the string found in "prefix", return 1.
@@ -582,8 +608,8 @@ static inline int ends_with(const char *
 
 #define mmap git_mmap
 #define munmap git_munmap
-extern void *git_mmap(void *start, size_t length, int prot, int flags, int fd, off_t offset);
-extern int git_munmap(void *start, size_t length);
+void *git_mmap(void *start, size_t length, int prot, int flags, int fd, off_t offset);
+int git_munmap(void *start, size_t length);
 
 #else /* NO_MMAP || USE_WIN32_MMAP */
 
@@ -637,17 +663,17 @@ extern int git_munmap(void *start, size_
 #undef stat
 #endif
 #define stat(path, buf) git_stat(path, buf)
-extern int git_stat(const char *, struct stat *);
+int git_stat(const char *, struct stat *);
 #ifdef fstat
 #undef fstat
 #endif
 #define fstat(fd, buf) git_fstat(fd, buf)
-extern int git_fstat(int, struct stat *);
+int git_fstat(int, struct stat *);
 #ifdef lstat
 #undef lstat
 #endif
 #define lstat(path, buf) git_lstat(path, buf)
-extern int git_lstat(const char *, struct stat *);
+int git_lstat(const char *, struct stat *);
 #endif
 
 #define DEFAULT_PACKED_GIT_LIMIT \
@@ -655,56 +681,56 @@ extern int git_lstat(const char *, struc
 
 #ifdef NO_PREAD
 #define pread git_pread
-extern ssize_t git_pread(int fd, void *buf, size_t count, off_t offset);
+ssize_t git_pread(int fd, void *buf, size_t count, off_t offset);
 #endif
 /*
  * Forward decl that will remind us if its twin in cache.h changes.
  * This function is used in compat/pread.c.  But we can't include
  * cache.h there.
  */
-extern ssize_t read_in_full(int fd, void *buf, size_t count);
+ssize_t read_in_full(int fd, void *buf, size_t count);
 
 #ifdef NO_SETENV
 #define setenv gitsetenv
-extern int gitsetenv(const char *, const char *, int);
+int gitsetenv(const char *, const char *, int);
 #endif
 
 #ifdef NO_MKDTEMP
 #define mkdtemp gitmkdtemp
-extern char *gitmkdtemp(char *);
+char *gitmkdtemp(char *);
 #endif
 
 #ifdef NO_UNSETENV
 #define unsetenv gitunsetenv
-extern void gitunsetenv(const char *);
+void gitunsetenv(const char *);
 #endif
 
 #ifdef NO_STRCASESTR
 #define strcasestr gitstrcasestr
-extern char *gitstrcasestr(const char *haystack, const char *needle);
+char *gitstrcasestr(const char *haystack, const char *needle);
 #endif
 
 #ifdef NO_STRLCPY
 #define strlcpy gitstrlcpy
-extern size_t gitstrlcpy(char *, const char *, size_t);
+size_t gitstrlcpy(char *, const char *, size_t);
 #endif
 
 #ifdef NO_STRTOUMAX
 #define strtoumax gitstrtoumax
-extern uintmax_t gitstrtoumax(const char *, char **, int);
+uintmax_t gitstrtoumax(const char *, char **, int);
 #define strtoimax gitstrtoimax
-extern intmax_t gitstrtoimax(const char *, char **, int);
+intmax_t gitstrtoimax(const char *, char **, int);
 #endif
 
 #ifdef NO_HSTRERROR
 #define hstrerror githstrerror
-extern const char *githstrerror(int herror);
+const char *githstrerror(int herror);
 #endif
 
 #ifdef NO_MEMMEM
 #define memmem gitmemmem
 void *gitmemmem(const void *haystack, size_t haystacklen,
-                const void *needle, size_t needlelen);
+		const void *needle, size_t needlelen);
 #endif
 
 #ifdef OVERRIDE_STRDUP
@@ -730,7 +756,7 @@ char *gitstrdup(const char *s);
 #  endif
 #  define fopen(a,b) git_fopen(a,b)
 # endif
-extern FILE *git_fopen(const char*, const char*);
+FILE *git_fopen(const char*, const char*);
 #endif
 
 #ifdef SNPRINTF_RETURNS_BOGUS
@@ -738,14 +764,14 @@ extern FILE *git_fopen(const char*, cons
 #undef snprintf
 #endif
 #define snprintf git_snprintf
-extern int git_snprintf(char *str, size_t maxsize,
-			const char *format, ...);
+int git_snprintf(char *str, size_t maxsize,
+		 const char *format, ...);
 #ifdef vsnprintf
 #undef vsnprintf
 #endif
 #define vsnprintf git_vsnprintf
-extern int git_vsnprintf(char *str, size_t maxsize,
-			 const char *format, va_list ap);
+int git_vsnprintf(char *str, size_t maxsize,
+		  const char *format, va_list ap);
 #endif
 
 #ifdef __GLIBC_PREREQ
@@ -774,12 +800,9 @@ const char *inet_ntop(int af, const void
 
 #ifdef NO_PTHREADS
 #define atexit git_atexit
-extern int git_atexit(void (*handler)(void));
+int git_atexit(void (*handler)(void));
 #endif
 
-typedef void (*try_to_free_t)(size_t);
-extern try_to_free_t set_try_to_free_routine(try_to_free_t);
-
 static inline size_t st_add(size_t a, size_t b)
 {
 	if (unsigned_add_overflows(a, b))
@@ -814,28 +837,28 @@ static inline size_t st_sub(size_t a, si
 # define xalloca(size)      (xmalloc(size))
 # define xalloca_free(p)    (free(p))
 #endif
-extern char *xstrdup(const char *str);
-extern void *xmalloc(size_t size);
-extern void *xmallocz(size_t size);
-extern void *xmallocz_gently(size_t size);
-extern void *xmemdupz(const void *data, size_t len);
-extern char *xstrndup(const char *str, size_t len);
-extern void *xrealloc(void *ptr, size_t size);
-extern void *xcalloc(size_t nmemb, size_t size);
-extern void *xmmap(void *start, size_t length, int prot, int flags, int fd, off_t offset);
-extern void *xmmap_gently(void *start, size_t length, int prot, int flags, int fd, off_t offset);
-extern int xopen(const char *path, int flags, ...);
-extern ssize_t xread(int fd, void *buf, size_t len);
-extern ssize_t xwrite(int fd, const void *buf, size_t len);
-extern ssize_t xpread(int fd, void *buf, size_t len, off_t offset);
-extern int xdup(int fd);
-extern FILE *xfopen(const char *path, const char *mode);
-extern FILE *xfdopen(int fd, const char *mode);
-extern int xmkstemp(char *temp_filename);
-extern int xmkstemp_mode(char *temp_filename, int mode);
-extern char *xgetcwd(void);
-extern FILE *fopen_for_writing(const char *path);
-extern FILE *fopen_or_warn(const char *path, const char *mode);
+char *xstrdup(const char *str);
+void *xmalloc(size_t size);
+void *xmallocz(size_t size);
+void *xmallocz_gently(size_t size);
+void *xmemdupz(const void *data, size_t len);
+char *xstrndup(const char *str, size_t len);
+void *xrealloc(void *ptr, size_t size);
+void *xcalloc(size_t nmemb, size_t size);
+void *xmmap(void *start, size_t length, int prot, int flags, int fd, off_t offset);
+void *xmmap_gently(void *start, size_t length, int prot, int flags, int fd, off_t offset);
+int xopen(const char *path, int flags, ...);
+ssize_t xread(int fd, void *buf, size_t len);
+ssize_t xwrite(int fd, const void *buf, size_t len);
+ssize_t xpread(int fd, void *buf, size_t len, off_t offset);
+int xdup(int fd);
+FILE *xfopen(const char *path, const char *mode);
+FILE *xfdopen(int fd, const char *mode);
+int xmkstemp(char *temp_filename);
+int xmkstemp_mode(char *temp_filename, int mode);
+char *xgetcwd(void);
+FILE *fopen_for_writing(const char *path);
+FILE *fopen_or_warn(const char *path, const char *mode);
 
 /*
  * FREE_AND_NULL(ptr) is like free(ptr) followed by ptr = NULL. Note
@@ -844,6 +867,7 @@ extern FILE *fopen_or_warn(const char *p
 #define FREE_AND_NULL(p) do { free(p); (p) = NULL; } while (0)
 
 #define ALLOC_ARRAY(x, alloc) (x) = xmalloc(st_mult(sizeof(*(x)), (alloc)))
+#define CALLOC_ARRAY(x, alloc) (x) = xcalloc((alloc), sizeof(*(x)));
 #define REALLOC_ARRAY(x, alloc) (x) = xrealloc((x), st_mult(sizeof(*(x)), (alloc)))
 
 #define COPY_ARRAY(dst, src, n) copy_array((dst), (src), (n), sizeof(*(dst)) + \
@@ -934,13 +958,13 @@ static inline size_t xsize_t(off_t len)
 }
 
 __attribute__((format (printf, 3, 4)))
-extern int xsnprintf(char *dst, size_t max, const char *fmt, ...);
+int xsnprintf(char *dst, size_t max, const char *fmt, ...);
 
 #ifndef HOST_NAME_MAX
 #define HOST_NAME_MAX 256
 #endif
 
-extern int xgethostname(char *buf, size_t len);
+int xgethostname(char *buf, size_t len);
 
 /* in ctype.c, for kwset users */
 extern const unsigned char tolower_trans_tbl[256];
@@ -1052,10 +1076,10 @@ static inline int strtol_i(char const *s
 	return 0;
 }
 
+void git_stable_qsort(void *base, size_t nmemb, size_t size,
+		      int(*compar)(const void *, const void *));
 #ifdef INTERNAL_QSORT
-void git_qsort(void *base, size_t nmemb, size_t size,
-	       int(*compar)(const void *, const void *));
-#define qsort git_qsort
+#define qsort git_stable_qsort
 #endif
 
 #define QSORT(base, n, compar) sane_qsort((base), (n), sizeof(*(base)), compar)
@@ -1066,6 +1090,9 @@ static inline void sane_qsort(void *base
 		qsort(base, nmemb, size, compar);
 }
 
+#define STABLE_QSORT(base, n, compar) \
+	git_stable_qsort((base), (n), sizeof(*(base)), compar)
+
 #ifndef HAVE_ISO_QSORT_S
 int git_qsort_s(void *base, size_t nmemb, size_t size,
 		int (*compar)(const void *, const void *, void *), void *ctx);
@@ -1202,6 +1229,24 @@ struct tm *git_gmtime_r(const time_t *,
 #define getc_unlocked(fh) getc(fh)
 #endif
 
+#ifdef FILENO_IS_A_MACRO
+int git_fileno(FILE *stream);
+# ifndef COMPAT_CODE_FILENO
+#  undef fileno
+#  define fileno(p) git_fileno(p)
+# endif
+#endif
+
+#ifdef NEED_ACCESS_ROOT_HANDLER
+int git_access(const char *path, int mode);
+# ifndef COMPAT_CODE_ACCESS
+#  ifdef access
+#  undef access
+#  endif
+#  define access(path, mode) git_access(path, mode)
+# endif
+#endif
+
 /*
  * Our code often opens a path to an optional file, to work on its
  * contents when we can successfully open it.  We can ignore a failure
@@ -1217,7 +1262,14 @@ static inline int is_missing_file_error(
 	return (errno_ == ENOENT || errno_ == ENOTDIR);
 }
 
-extern int cmd_main(int, const char **);
+int cmd_main(int, const char **);
+
+/*
+ * Intercept all calls to exit() and route them to trace2 to
+ * optionally emit a message before calling the real exit().
+ */
+int trace2_cmd_exit_fl(const char *file, int line, int code);
+#define exit(code) exit(trace2_cmd_exit_fl(__FILE__, __LINE__, (code)))
 
 /*
  * You can mark a stack variable with UNLEAK(var) to avoid it being
@@ -1233,10 +1285,54 @@ extern int cmd_main(int, const char **);
  * an annotation, and does nothing in non-leak-checking builds.
  */
 #ifdef SUPPRESS_ANNOTATED_LEAKS
-extern void unleak_memory(const void *ptr, size_t len);
+void unleak_memory(const void *ptr, size_t len);
 #define UNLEAK(var) unleak_memory(&(var), sizeof(var))
 #else
 #define UNLEAK(var) do {} while (0)
 #endif
 
+/*
+ * This include must come after system headers, since it introduces macros that
+ * replace system names.
+ */
+#include "banned.h"
+
+/*
+ * container_of - Get the address of an object containing a field.
+ *
+ * @ptr: pointer to the field.
+ * @type: type of the object.
+ * @member: name of the field within the object.
+ */
+#define container_of(ptr, type, member) \
+	((type *) ((char *)(ptr) - offsetof(type, member)))
+
+/*
+ * helper function for `container_of_or_null' to avoid multiple
+ * evaluation of @ptr
+ */
+static inline void *container_of_or_null_offset(void *ptr, size_t offset)
+{
+	return ptr ? (char *)ptr - offset : NULL;
+}
+
+/*
+ * like `container_of', but allows returned value to be NULL
+ */
+#define container_of_or_null(ptr, type, member) \
+	(type *)container_of_or_null_offset(ptr, offsetof(type, member))
+
+/*
+ * like offsetof(), but takes a pointer to a a variable of type which
+ * contains @member, instead of a specified type.
+ * @ptr is subject to multiple evaluation since we can't rely on __typeof__
+ * everywhere.
+ */
+#if defined(__GNUC__) /* clang sets this, too */
+#define OFFSETOF_VAR(ptr, member) offsetof(__typeof__(*ptr), member)
+#else /* !__GNUC__ */
+#define OFFSETOF_VAR(ptr, member) \
+	((uintptr_t)&(ptr)->member - (uintptr_t)(ptr))
+#endif /* !__GNUC__ */
+
 #endif
diff -pruN 1.2.1+git2.18.0-1/git/git-cvsexportcommit.perl 1.2.3+git2.25.1-1/git/git-cvsexportcommit.perl
--- 1.2.1+git2.18.0-1/git/git-cvsexportcommit.perl	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/git-cvsexportcommit.perl	2020-02-17 04:47:35.000000000 +0000
@@ -431,6 +431,7 @@ END
 sub safe_pipe_capture {
     my @output;
     if (my $pid = open my $child, '-|') {
+	binmode($child, ":crlf");
 	@output = (<$child>);
 	close $child or die join(' ',@_).": $! $?";
     } else {
diff -pruN 1.2.1+git2.18.0-1/git/git-cvsimport.perl 1.2.3+git2.25.1-1/git/git-cvsimport.perl
--- 1.2.1+git2.18.0-1/git/git-cvsimport.perl	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/git-cvsimport.perl	2020-02-17 04:47:35.000000000 +0000
@@ -600,7 +600,7 @@ my $cvs = CVSconn->new($opt_d, $cvs_tree
 sub pdate($) {
 	my ($d) = @_;
 	m#(\d{2,4})/(\d\d)/(\d\d)\s(\d\d):(\d\d)(?::(\d\d))?#
-		or die "Unparseable date: $d\n";
+		or die "Unparsable date: $d\n";
 	my $y=$1;
 	$y+=100 if $y<70;
 	$y+=1900 if $y<1000;
diff -pruN 1.2.1+git2.18.0-1/git/git-difftool--helper.sh 1.2.3+git2.25.1-1/git/git-difftool--helper.sh
--- 1.2.1+git2.18.0-1/git/git-difftool--helper.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/git-difftool--helper.sh	2020-02-17 04:47:35.000000000 +0000
@@ -71,7 +71,7 @@ then
 	then
 		merge_tool="$GIT_DIFF_TOOL"
 	else
-		merge_tool="$(get_merge_tool)" || exit
+		merge_tool="$(get_merge_tool)"
 	fi
 fi
 
diff -pruN 1.2.1+git2.18.0-1/git/git-filter-branch.sh 1.2.3+git2.25.1-1/git/git-filter-branch.sh
--- 1.2.1+git2.18.0-1/git/git-filter-branch.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/git-filter-branch.sh	2020-02-17 04:47:35.000000000 +0000
@@ -83,6 +83,20 @@ set_ident () {
 	finish_ident COMMITTER
 }
 
+if test -z "$FILTER_BRANCH_SQUELCH_WARNING$GIT_TEST_DISALLOW_ABBREVIATED_OPTIONS"
+then
+	cat <<EOF
+WARNING: git-filter-branch has a glut of gotchas generating mangled history
+	 rewrites.  Hit Ctrl-C before proceeding to abort, then use an
+	 alternative filtering tool such as 'git filter-repo'
+	 (https://github.com/newren/git-filter-repo/) instead.  See the
+	 filter-branch manual page for more details; to squelch this warning,
+	 set FILTER_BRANCH_SQUELCH_WARNING=1.
+EOF
+	sleep 10
+	printf "Proceeding with filter-branch...\n\n"
+fi
+
 USAGE="[--setup <command>] [--subdirectory-filter <directory>] [--env-filter <command>]
 	[--tree-filter <command>] [--index-filter <command>]
 	[--parent-filter <command>] [--msg-filter <command>]
@@ -372,6 +386,7 @@ while read commit parents; do
 	git_filter_branch__commit_count=$(($git_filter_branch__commit_count+1))
 
 	report_progress
+	test -f "$workdir"/../map/$commit && continue
 
 	case "$filter_subdir" in
 	"")
diff -pruN 1.2.1+git2.18.0-1/git/git-gui/git-gui.sh 1.2.3+git2.25.1-1/git/git-gui/git-gui.sh
--- 1.2.1+git2.18.0-1/git/git-gui/git-gui.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/git-gui/git-gui.sh	2020-02-17 04:47:35.000000000 +0000
@@ -30,8 +30,8 @@ along with this program; if not, see <ht
 ##
 ## Tcl/Tk sanity check
 
-if {[catch {package require Tcl 8.4} err]
- || [catch {package require Tk  8.4} err]
+if {[catch {package require Tcl 8.6} err]
+ || [catch {package require Tk  8.6} err]
 } {
 	catch {wm withdraw .}
 	tk_messageBox \
@@ -684,6 +684,7 @@ proc load_current_branch {} {
 	global current_branch is_detached
 
 	set fd [open [gitdir HEAD] r]
+	fconfigure $fd -translation binary -encoding utf-8
 	if {[gets $fd ref] < 1} {
 		set ref {}
 	}
@@ -1340,6 +1341,7 @@ set HEAD {}
 set PARENT {}
 set MERGE_HEAD [list]
 set commit_type {}
+set commit_type_is_amend 0
 set empty_tree {}
 set current_branch {}
 set is_detached 0
@@ -1347,8 +1349,9 @@ set current_diff_path {}
 set is_3way_diff 0
 set is_submodule_diff 0
 set is_conflict_diff 0
-set selected_commit_type new
 set diff_empty_count 0
+set last_revert {}
+set last_revert_enc {}
 
 set nullid "0000000000000000000000000000000000000000"
 set nullid2 "0000000000000000000000000000000000000001"
@@ -1434,7 +1437,7 @@ proc PARENT {} {
 }
 
 proc force_amend {} {
-	global selected_commit_type
+	global commit_type_is_amend
 	global HEAD PARENT MERGE_HEAD commit_type
 
 	repository_state newType newHEAD newMERGE_HEAD
@@ -1443,7 +1446,7 @@ proc force_amend {} {
 	set MERGE_HEAD $newMERGE_HEAD
 	set commit_type $newType
 
-	set selected_commit_type amend
+	set commit_type_is_amend 1
 	do_select_commit_type
 }
 
@@ -1795,10 +1798,10 @@ proc ui_status {msg} {
 	}
 }
 
-proc ui_ready {{test {}}} {
+proc ui_ready {} {
 	global main_status
 	if {[info exists main_status]} {
-		$main_status show [mc "Ready."] $test
+		$main_status show [mc "Ready."]
 	}
 }
 
@@ -2148,8 +2151,6 @@ proc incr_font_size {font {amt 1}} {
 ##
 ## ui commands
 
-set starting_gitk_msg [mc "Starting gitk... please wait..."]
-
 proc do_gitk {revs {is_submodule false}} {
 	global current_diff_path file_states current_diff_side ui_index
 	global _gitdir _gitworktree
@@ -2204,10 +2205,11 @@ proc do_gitk {revs {is_submodule false}}
 		set env(GIT_WORK_TREE) $_gitworktree
 		cd $pwd
 
-		ui_status $::starting_gitk_msg
-		after 10000 {
-			ui_ready $starting_gitk_msg
-		}
+		set status_operation [$::main_status \
+			start \
+			[mc "Starting %s... please wait..." "gitk"]]
+
+		after 3500 [list $status_operation stop]
 	}
 }
 
@@ -2238,16 +2240,16 @@ proc do_git_gui {} {
 		set env(GIT_WORK_TREE) $_gitworktree
 		cd $pwd
 
-		ui_status $::starting_gitk_msg
-		after 10000 {
-			ui_ready $starting_gitk_msg
-		}
+		set status_operation [$::main_status \
+			start \
+			[mc "Starting %s... please wait..." "git-gui"]]
+
+		after 3500 [list $status_operation stop]
 	}
 }
 
-proc do_explore {} {
-	global _gitworktree
-	set explorer {}
+# Get the system-specific explorer app/command.
+proc get_explorer {} {
 	if {[is_Cygwin] || [is_Windows]} {
 		set explorer "explorer.exe"
 	} elseif {[is_MacOSX]} {
@@ -2256,9 +2258,23 @@ proc do_explore {} {
 		# freedesktop.org-conforming system is our best shot
 		set explorer "xdg-open"
 	}
+	return $explorer
+}
+
+proc do_explore {} {
+	global _gitworktree
+	set explorer [get_explorer]
 	eval exec $explorer [list [file nativename $_gitworktree]] &
 }
 
+# Open file relative to the working tree by the default associated app.
+proc do_file_open {file} {
+	global _gitworktree
+	set explorer [get_explorer]
+	set full_file_path [file join $_gitworktree $file]
+	exec $explorer [file nativename $full_file_path] &
+}
+
 set is_quitting 0
 set ret_code    1
 
@@ -2494,7 +2510,7 @@ proc force_first_diff {after} {
 
 proc toggle_or_diff {mode w args} {
 	global file_states file_lists current_diff_path ui_index ui_workdir
-	global last_clicked selected_paths
+	global last_clicked selected_paths file_lists_last_clicked
 
 	if {$mode eq "click"} {
 		foreach {x y} $args break
@@ -2551,6 +2567,8 @@ proc toggle_or_diff {mode w args} {
 	$ui_index tag remove in_sel 0.0 end
 	$ui_workdir tag remove in_sel 0.0 end
 
+	set file_lists_last_clicked($w) $path
+
 	# Determine the state of the file
 	if {[info exists file_states($path)]} {
 		set state [lindex $file_states($path) 0]
@@ -2664,6 +2682,32 @@ proc show_less_context {} {
 	}
 }
 
+proc focus_widget {widget} {
+	global file_lists last_clicked selected_paths
+	global file_lists_last_clicked
+
+	if {[llength $file_lists($widget)] > 0} {
+		set path $file_lists_last_clicked($widget)
+		set index [lsearch -sorted -exact $file_lists($widget) $path]
+		if {$index < 0} {
+			set index 0
+			set path [lindex $file_lists($widget) $index]
+		}
+
+		focus $widget
+		set last_clicked [list $widget [expr $index + 1]]
+		array unset selected_paths
+		set selected_paths($path) 1
+		show_diff $path $widget
+	}
+}
+
+proc toggle_commit_type {} {
+	global commit_type_is_amend
+	set commit_type_is_amend [expr !$commit_type_is_amend]
+	do_select_commit_type
+}
+
 ######################################################################
 ##
 ## ui construction
@@ -2706,10 +2750,18 @@ if {![is_bare]} {
 }
 
 if {[is_Windows]} {
+	# Use /git-bash.exe if available
+	set normalized [file normalize $::argv0]
+	regsub "/mingw../libexec/git-core/git-gui$" \
+		$normalized "/git-bash.exe" cmdLine
+	if {$cmdLine != $normalized && [file exists $cmdLine]} {
+		set cmdLine [list "Git Bash" $cmdLine &]
+	} else {
+		set cmdLine [list "Git Bash" bash --login -l &]
+	}
 	.mbar.repository add command \
 		-label [mc "Git Bash"] \
-		-command {eval exec [auto_execok start] \
-					  [list "Git Bash" bash --login -l &]}
+		-command {eval exec [auto_execok start] $cmdLine}
 }
 
 if {[is_Windows] || ![is_bare]} {
@@ -2852,19 +2904,11 @@ if {[is_enabled multicommit] || [is_enab
 	menu .mbar.commit
 
 	if {![is_enabled nocommit]} {
-		.mbar.commit add radiobutton \
-			-label [mc "New Commit"] \
-			-command do_select_commit_type \
-			-variable selected_commit_type \
-			-value new
-		lappend disable_on_lock \
-			[list .mbar.commit entryconf [.mbar.commit index last] -state]
-
-		.mbar.commit add radiobutton \
+		.mbar.commit add checkbutton \
 			-label [mc "Amend Last Commit"] \
-			-command do_select_commit_type \
-			-variable selected_commit_type \
-			-value amend
+			-accelerator $M1T-E \
+			-variable commit_type_is_amend \
+			-command do_select_commit_type
 		lappend disable_on_lock \
 			[list .mbar.commit entryconf [.mbar.commit index last] -state]
 
@@ -3030,8 +3074,23 @@ unset doc_path doc_url
 wm protocol . WM_DELETE_WINDOW do_quit
 bind all <$M1B-Key-q> do_quit
 bind all <$M1B-Key-Q> do_quit
-bind all <$M1B-Key-w> {destroy [winfo toplevel %W]}
-bind all <$M1B-Key-W> {destroy [winfo toplevel %W]}
+
+set m1b_w_script {
+	set toplvl_win [winfo toplevel %W]
+
+	# If we are destroying the main window, we should call do_quit to take
+	# care of cleanup before exiting the program.
+	if {$toplvl_win eq "."} {
+		do_quit
+	} else {
+		destroy $toplvl_win
+	}
+}
+
+bind all <$M1B-Key-w> $m1b_w_script
+bind all <$M1B-Key-W> $m1b_w_script
+
+unset m1b_w_script
 
 set subcommand_args {}
 proc usage {} {
@@ -3337,18 +3396,10 @@ set ui_comm .vpane.lower.commarea.buffer
 set ui_coml .vpane.lower.commarea.buffer.header.l
 
 if {![is_enabled nocommit]} {
-	${NS}::radiobutton .vpane.lower.commarea.buffer.header.new \
-		-text [mc "New Commit"] \
-		-command do_select_commit_type \
-		-variable selected_commit_type \
-		-value new
-	lappend disable_on_lock \
-		[list .vpane.lower.commarea.buffer.header.new conf -state]
-	${NS}::radiobutton .vpane.lower.commarea.buffer.header.amend \
+	${NS}::checkbutton .vpane.lower.commarea.buffer.header.amend \
 		-text [mc "Amend Last Commit"] \
-		-command do_select_commit_type \
-		-variable selected_commit_type \
-		-value amend
+		-variable commit_type_is_amend \
+		-command do_select_commit_type
 	lappend disable_on_lock \
 		[list .vpane.lower.commarea.buffer.header.amend conf -state]
 }
@@ -3373,7 +3424,6 @@ pack $ui_coml -side left -fill x
 
 if {![is_enabled nocommit]} {
 	pack .vpane.lower.commarea.buffer.header.amend -side right
-	pack .vpane.lower.commarea.buffer.header.new -side right
 }
 
 textframe .vpane.lower.commarea.buffer.frame
@@ -3387,10 +3437,16 @@ ttext $ui_comm -background white -foregr
 	-relief sunken \
 	-width $repo_config(gui.commitmsgwidth) -height 9 -wrap none \
 	-font font_diff \
+	-xscrollcommand {.vpane.lower.commarea.buffer.frame.sbx set} \
 	-yscrollcommand {.vpane.lower.commarea.buffer.frame.sby set}
+${NS}::scrollbar .vpane.lower.commarea.buffer.frame.sbx \
+	-orient horizontal \
+	-command [list $ui_comm xview]
 ${NS}::scrollbar .vpane.lower.commarea.buffer.frame.sby \
+	-orient vertical \
 	-command [list $ui_comm yview]
 
+pack .vpane.lower.commarea.buffer.frame.sbx -side bottom -fill x
 pack .vpane.lower.commarea.buffer.frame.sby -side right -fill y
 pack $ui_comm -side left -fill y
 pack .vpane.lower.commarea.buffer.header -side top -fill x
@@ -3470,9 +3526,11 @@ tlabel .vpane.lower.diff.header.file \
 	-justify left
 tlabel .vpane.lower.diff.header.path \
 	-background gold \
-	-foreground black \
+	-foreground blue \
 	-anchor w \
-	-justify left
+	-justify left \
+	-font [eval font create [font configure font_ui] -underline 1] \
+	-cursor hand2
 pack .vpane.lower.diff.header.status -side left
 pack .vpane.lower.diff.header.file -side left
 pack .vpane.lower.diff.header.path -fill x
@@ -3487,8 +3545,12 @@ $ctxm add command \
 			-type STRING \
 			-- $current_diff_path
 	}
+$ctxm add command \
+	-label [mc Open] \
+	-command {do_file_open $current_diff_path}
 lappend diff_actions [list $ctxm entryconf [$ctxm index last] -state]
 bind_button3 .vpane.lower.diff.header.path "tk_popup $ctxm %X %Y"
+bind .vpane.lower.diff.header.path <Button-1> {do_file_open $current_diff_path}
 
 # -- Diff Body
 #
@@ -3547,6 +3609,9 @@ $ui_diff tag conf d_s- \
 $ui_diff tag conf d< \
 	-foreground orange \
 	-font font_diffbold
+$ui_diff tag conf d| \
+	-foreground orange \
+	-font font_diffbold
 $ui_diff tag conf d= \
 	-foreground orange \
 	-font font_diffbold
@@ -3606,16 +3671,32 @@ set ctxm .vpane.lower.diff.body.ctxm
 menu $ctxm -tearoff 0
 $ctxm add command \
 	-label [mc "Apply/Reverse Hunk"] \
-	-command {apply_hunk $cursorX $cursorY}
+	-command {apply_or_revert_hunk $cursorX $cursorY 0}
 set ui_diff_applyhunk [$ctxm index last]
 lappend diff_actions [list $ctxm entryconf $ui_diff_applyhunk -state]
 $ctxm add command \
 	-label [mc "Apply/Reverse Line"] \
-	-command {apply_range_or_line $cursorX $cursorY; do_rescan}
+	-command {apply_or_revert_range_or_line $cursorX $cursorY 0; do_rescan}
 set ui_diff_applyline [$ctxm index last]
 lappend diff_actions [list $ctxm entryconf $ui_diff_applyline -state]
 $ctxm add separator
 $ctxm add command \
+	-label [mc "Revert Hunk"] \
+	-command {apply_or_revert_hunk $cursorX $cursorY 1}
+set ui_diff_reverthunk [$ctxm index last]
+lappend diff_actions [list $ctxm entryconf $ui_diff_reverthunk -state]
+$ctxm add command \
+	-label [mc "Revert Line"] \
+	-command {apply_or_revert_range_or_line $cursorX $cursorY 1; do_rescan}
+set ui_diff_revertline [$ctxm index last]
+lappend diff_actions [list $ctxm entryconf $ui_diff_revertline -state]
+$ctxm add command \
+	-label [mc "Undo Last Revert"] \
+	-command {undo_last_revert; do_rescan}
+set ui_diff_undorevert [$ctxm index last]
+lappend diff_actions [list $ctxm entryconf $ui_diff_undorevert -state]
+$ctxm add separator
+$ctxm add command \
 	-label [mc "Show Less Context"] \
 	-command show_less_context
 lappend diff_actions [list $ctxm entryconf [$ctxm index last] -state]
@@ -3693,7 +3774,7 @@ proc has_textconv {path} {
 }
 
 proc popup_diff_menu {ctxm ctxmmg ctxmsm x y X Y} {
-	global current_diff_path file_states
+	global current_diff_path file_states last_revert
 	set ::cursorX $x
 	set ::cursorY $y
 	if {[info exists file_states($current_diff_path)]} {
@@ -3707,19 +3788,28 @@ proc popup_diff_menu {ctxm ctxmmg ctxmsm
 		tk_popup $ctxmsm $X $Y
 	} else {
 		set has_range [expr {[$::ui_diff tag nextrange sel 0.0] != {}}]
+		set u [mc "Undo Last Revert"]
 		if {$::ui_index eq $::current_diff_side} {
 			set l [mc "Unstage Hunk From Commit"]
+			set h [mc "Revert Hunk"]
+
 			if {$has_range} {
 				set t [mc "Unstage Lines From Commit"]
+				set r [mc "Revert Lines"]
 			} else {
 				set t [mc "Unstage Line From Commit"]
+				set r [mc "Revert Line"]
 			}
 		} else {
 			set l [mc "Stage Hunk For Commit"]
+			set h [mc "Revert Hunk"]
+
 			if {$has_range} {
 				set t [mc "Stage Lines For Commit"]
+				set r [mc "Revert Lines"]
 			} else {
 				set t [mc "Stage Line For Commit"]
+				set r [mc "Revert Line"]
 			}
 		}
 		if {$::is_3way_diff
@@ -3730,11 +3820,35 @@ proc popup_diff_menu {ctxm ctxmmg ctxmsm
 			|| [string match {T?} $state]
 			|| [has_textconv $current_diff_path]} {
 			set s disabled
+			set revert_state disabled
 		} else {
 			set s normal
+
+			# Only allow reverting changes in the working tree. If
+			# the user wants to revert changes in the index, they
+			# need to unstage those first.
+			if {$::ui_workdir eq $::current_diff_side} {
+				set revert_state normal
+			} else {
+				set revert_state disabled
+			}
 		}
+
+		if {$last_revert eq {}} {
+			set undo_state disabled
+		} else {
+			set undo_state normal
+		}
+
 		$ctxm entryconf $::ui_diff_applyhunk -state $s -label $l
 		$ctxm entryconf $::ui_diff_applyline -state $s -label $t
+		$ctxm entryconf $::ui_diff_revertline -state $revert_state \
+			-label $r
+		$ctxm entryconf $::ui_diff_reverthunk -state $revert_state \
+			-label $h
+		$ctxm entryconf $::ui_diff_undorevert -state $undo_state \
+			-label $u
+
 		tk_popup $ctxm $X $Y
 	}
 }
@@ -3861,6 +3975,8 @@ bind .   <$M1B-Key-j> do_revert_selectio
 bind .   <$M1B-Key-J> do_revert_selection
 bind .   <$M1B-Key-i> do_add_all
 bind .   <$M1B-Key-I> do_add_all
+bind .   <$M1B-Key-e> toggle_commit_type
+bind .   <$M1B-Key-E> toggle_commit_type
 bind .   <$M1B-Key-minus> {show_less_context;break}
 bind .   <$M1B-Key-KP_Subtract> {show_less_context;break}
 bind .   <$M1B-Key-equal> {show_more_context;break}
@@ -3877,6 +3993,14 @@ foreach i [list $ui_index $ui_workdir] {
 }
 unset i
 
+bind .   <Alt-Key-1> {focus_widget $::ui_workdir}
+bind .   <Alt-Key-2> {focus_widget $::ui_index}
+bind .   <Alt-Key-3> {focus $::ui_diff}
+bind .   <Alt-Key-4> {focus $::ui_comm}
+
+set file_lists_last_clicked($ui_index) {}
+set file_lists_last_clicked($ui_workdir) {}
+
 set file_lists($ui_index) [list]
 set file_lists($ui_workdir) [list]
 
@@ -4055,6 +4179,9 @@ if {$picked && [is_config_true gui.autoe
 	do_explore
 }
 
+# Clear "Initializing..." status
+after 500 {$main_status show ""}
+
 # Local variables:
 # mode: tcl
 # indent-tabs-mode: t
diff -pruN 1.2.1+git2.18.0-1/git/git-gui/lib/blame.tcl 1.2.3+git2.25.1-1/git/git-gui/lib/blame.tcl
--- 1.2.1+git2.18.0-1/git/git-gui/lib/blame.tcl	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/git-gui/lib/blame.tcl	2020-02-17 04:47:35.000000000 +0000
@@ -24,6 +24,7 @@ field w_cviewer  ; # pane showing commit
 field finder     ; # find mini-dialog frame
 field gotoline   ; # line goto mini-dialog frame
 field status     ; # status mega-widget instance
+field status_operation ; # operation displayed by status mega-widget
 field old_height ; # last known height of $w.file_pane
 
 
@@ -274,6 +275,7 @@ constructor new {i_commit i_path i_jump}
 	pack $w_cviewer -expand 1 -fill both
 
 	set status [::status_bar::new $w.status]
+	set status_operation {}
 
 	menu $w.ctxm -tearoff 0
 	$w.ctxm add command \
@@ -602,16 +604,23 @@ method _exec_blame {cur_w cur_d options
 	} else {
 		lappend options $commit
 	}
+
+	# We may recurse in from another call to _exec_blame and already have
+	# a status operation.
+	if {$status_operation == {}} {
+		set status_operation [$status start \
+			$cur_s \
+			[mc "lines annotated"]]
+	} else {
+		$status_operation restart $cur_s
+	}
+
 	lappend options -- $path
 	set fd [eval git_read --nice blame $options]
 	fconfigure $fd -blocking 0 -translation lf -encoding utf-8
 	fileevent $fd readable [cb _read_blame $fd $cur_w $cur_d]
 	set current_fd $fd
 	set blame_lines 0
-
-	$status start \
-		$cur_s \
-		[mc "lines annotated"]
 }
 
 method _read_blame {fd cur_w cur_d} {
@@ -806,10 +815,11 @@ method _read_blame {fd cur_w cur_d} {
 				[mc "Loading original location annotations..."]
 		} else {
 			set current_fd {}
-			$status stop [mc "Annotation complete."]
+			$status_operation stop [mc "Annotation complete."]
+			set status_operation {}
 		}
 	} else {
-		$status update $blame_lines $total_lines
+		$status_operation update $blame_lines $total_lines
 	}
 } ifdeleted { catch {close $fd} }
 
@@ -1124,7 +1134,7 @@ method _blameparent {} {
 			set diffcmd [list diff-tree --unified=0 $cparent $cmit -- $new_path]
 		}
 		if {[catch {set fd [eval git_read $diffcmd]} err]} {
-			$status stop [mc "Unable to display parent"]
+			$status_operation stop [mc "Unable to display parent"]
 			error_popup [strcat [mc "Error loading diff:"] "\n\n$err"]
 			return
 		}
diff -pruN 1.2.1+git2.18.0-1/git/git-gui/lib/branch.tcl 1.2.3+git2.25.1-1/git/git-gui/lib/branch.tcl
--- 1.2.1+git2.18.0-1/git/git-gui/lib/branch.tcl	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/git-gui/lib/branch.tcl	2020-02-17 04:47:35.000000000 +0000
@@ -8,6 +8,7 @@ proc load_all_heads {} {
 	set rh_len [expr {[string length $rh] + 1}]
 	set all_heads [list]
 	set fd [git_read for-each-ref --format=%(refname) $rh]
+	fconfigure $fd -translation binary -encoding utf-8
 	while {[gets $fd line] > 0} {
 		if {!$some_heads_tracking || ![is_tracking_branch $line]} {
 			lappend all_heads [string range $line $rh_len end]
@@ -24,6 +25,7 @@ proc load_all_tags {} {
 		--sort=-taggerdate \
 		--format=%(refname) \
 		refs/tags]
+	fconfigure $fd -translation binary -encoding utf-8
 	while {[gets $fd line] > 0} {
 		if {![regsub ^refs/tags/ $line {} name]} continue
 		lappend all_tags $name
diff -pruN 1.2.1+git2.18.0-1/git/git-gui/lib/checkout_op.tcl 1.2.3+git2.25.1-1/git/git-gui/lib/checkout_op.tcl
--- 1.2.1+git2.18.0-1/git/git-gui/lib/checkout_op.tcl	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/git-gui/lib/checkout_op.tcl	2020-02-17 04:47:35.000000000 +0000
@@ -341,9 +341,9 @@ method _readtree {} {
 	global HEAD
 
 	set readtree_d {}
-	$::main_status start \
+	set status_bar_operation [$::main_status start \
 		[mc "Updating working directory to '%s'..." [_name $this]] \
-		[mc "files checked out"]
+		[mc "files checked out"]]
 
 	set fd [git_read --stderr read-tree \
 		-m \
@@ -354,26 +354,27 @@ method _readtree {} {
 		$new_hash \
 		]
 	fconfigure $fd -blocking 0 -translation binary
-	fileevent $fd readable [cb _readtree_wait $fd]
+	fileevent $fd readable [cb _readtree_wait $fd $status_bar_operation]
 }
 
-method _readtree_wait {fd} {
+method _readtree_wait {fd status_bar_operation} {
 	global current_branch
 
 	set buf [read $fd]
-	$::main_status update_meter $buf
+	$status_bar_operation update_meter $buf
 	append readtree_d $buf
 
 	fconfigure $fd -blocking 1
 	if {![eof $fd]} {
 		fconfigure $fd -blocking 0
+		$status_bar_operation stop
 		return
 	}
 
 	if {[catch {close $fd}]} {
 		set err $readtree_d
 		regsub {^fatal: } $err {} err
-		$::main_status stop [mc "Aborted checkout of '%s' (file level merging is required)." [_name $this]]
+		$status_bar_operation stop [mc "Aborted checkout of '%s' (file level merging is required)." [_name $this]]
 		warn_popup [strcat [mc "File level merge required."] "
 
 $err
@@ -384,12 +385,12 @@ $err
 		return
 	}
 
-	$::main_status stop
+	$status_bar_operation stop
 	_after_readtree $this
 }
 
 method _after_readtree {} {
-	global selected_commit_type commit_type HEAD MERGE_HEAD PARENT
+	global commit_type HEAD MERGE_HEAD PARENT
 	global current_branch is_detached
 	global ui_comm
 
@@ -490,12 +491,12 @@ method _update_repo_state {} {
 	#    amend mode our file lists are accurate and we can avoid
 	#    the rescan.
 	#
-	global selected_commit_type commit_type HEAD MERGE_HEAD PARENT
+	global commit_type_is_amend commit_type HEAD MERGE_HEAD PARENT
 	global ui_comm
 
 	unlock_index
 	set name [_name $this]
-	set selected_commit_type new
+	set commit_type_is_amend 0
 	if {[string match amend* $commit_type]} {
 		$ui_comm delete 0.0 end
 		$ui_comm edit reset
diff -pruN 1.2.1+git2.18.0-1/git/git-gui/lib/choose_repository.tcl 1.2.3+git2.25.1-1/git/git-gui/lib/choose_repository.tcl
--- 1.2.1+git2.18.0-1/git/git-gui/lib/choose_repository.tcl	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/git-gui/lib/choose_repository.tcl	2020-02-17 04:47:35.000000000 +0000
@@ -9,6 +9,18 @@ field w_body      ; # Widget holding the
 field w_next      ; # Next button
 field w_quit      ; # Quit button
 field o_cons      ; # Console object (if active)
+
+# Status mega-widget instance during _do_clone2 (used by _copy_files and
+# _link_files). Widget is destroyed before _do_clone2 calls
+# _do_clone_checkout
+field o_status
+
+# Operation displayed by status mega-widget during _do_clone_checkout =>
+# _readtree_wait => _postcheckout_wait => _do_clone_submodules =>
+# _do_validate_submodule_cloning. The status mega-widget is a different
+# instance than that stored in $o_status in earlier operations.
+field o_status_op
+
 field w_types     ; # List of type buttons in clone
 field w_recentlist ; # Listbox containing recent repositories
 field w_localpath  ; # Entry widget bound to local_path
@@ -659,12 +671,12 @@ method _do_clone2 {} {
 
 	switch -exact -- $clone_type {
 	hardlink {
-		set o_cons [status_bar::two_line $w_body]
+		set o_status [status_bar::two_line $w_body]
 		pack $w_body -fill x -padx 10 -pady 10
 
-		$o_cons start \
+		set status_op [$o_status start \
 			[mc "Counting objects"] \
-			[mc "buckets"]
+			[mc "buckets"]]
 		update
 
 		if {[file exists [file join $objdir info alternates]]} {
@@ -689,6 +701,7 @@ method _do_clone2 {} {
 			} err]} {
 				catch {cd $pwd}
 				_clone_failed $this [mc "Unable to copy objects/info/alternates: %s" $err]
+				$status_op stop
 				return
 			}
 		}
@@ -700,7 +713,7 @@ method _do_clone2 {} {
 			-directory [file join $objdir] ??]
 		set bcnt [expr {[llength $buckets] + 2}]
 		set bcur 1
-		$o_cons update $bcur $bcnt
+		$status_op update $bcur $bcnt
 		update
 
 		file mkdir [file join .git objects pack]
@@ -708,7 +721,7 @@ method _do_clone2 {} {
 			-directory [file join $objdir pack] *] {
 			lappend tolink [file join pack $i]
 		}
-		$o_cons update [incr bcur] $bcnt
+		$status_op update [incr bcur] $bcnt
 		update
 
 		foreach i $buckets {
@@ -717,10 +730,10 @@ method _do_clone2 {} {
 				-directory [file join $objdir $i] *] {
 				lappend tolink [file join $i $j]
 			}
-			$o_cons update [incr bcur] $bcnt
+			$status_op update [incr bcur] $bcnt
 			update
 		}
-		$o_cons stop
+		$status_op stop
 
 		if {$tolink eq {}} {
 			info_popup [strcat \
@@ -747,6 +760,8 @@ method _do_clone2 {} {
 		if {!$i} return
 
 		destroy $w_body
+
+		set o_status {}
 	}
 	full {
 		set o_cons [console::embed \
@@ -781,9 +796,9 @@ method _do_clone2 {} {
 }
 
 method _copy_files {objdir tocopy} {
-	$o_cons start \
+	set status_op [$o_status start \
 		[mc "Copying objects"] \
-		[mc "KiB"]
+		[mc "KiB"]]
 	set tot 0
 	set cmp 0
 	foreach p $tocopy {
@@ -798,7 +813,7 @@ method _copy_files {objdir tocopy} {
 
 				while {![eof $f_in]} {
 					incr cmp [fcopy $f_in $f_cp -size 16384]
-					$o_cons update \
+					$status_op update \
 						[expr {$cmp / 1024}] \
 						[expr {$tot / 1024}]
 					update
@@ -808,17 +823,19 @@ method _copy_files {objdir tocopy} {
 				close $f_cp
 			} err]} {
 			_clone_failed $this [mc "Unable to copy object: %s" $err]
+			$status_op stop
 			return 0
 		}
 	}
+	$status_op stop
 	return 1
 }
 
 method _link_files {objdir tolink} {
 	set total [llength $tolink]
-	$o_cons start \
+	set status_op [$o_status start \
 		[mc "Linking objects"] \
-		[mc "objects"]
+		[mc "objects"]]
 	for {set i 0} {$i < $total} {} {
 		set p [lindex $tolink $i]
 		if {[catch {
@@ -827,15 +844,17 @@ method _link_files {objdir tolink} {
 					[file join $objdir $p]
 			} err]} {
 			_clone_failed $this [mc "Unable to hardlink object: %s" $err]
+			$status_op stop
 			return 0
 		}
 
 		incr i
 		if {$i % 5 == 0} {
-			$o_cons update $i $total
+			$status_op update $i $total
 			update
 		}
 	}
+	$status_op stop
 	return 1
 }
 
@@ -958,11 +977,26 @@ method _do_clone_checkout {HEAD} {
 		return
 	}
 
-	set o_cons [status_bar::two_line $w_body]
+	set status [status_bar::two_line $w_body]
 	pack $w_body -fill x -padx 10 -pady 10
-	$o_cons start \
+
+	# We start the status operation here.
+	#
+	# This function calls _readtree_wait as a callback.
+	#
+	# _readtree_wait in turn either calls _do_clone_submodules directly,
+	# or calls _postcheckout_wait as a callback which then calls
+	# _do_clone_submodules.
+	#
+	# _do_clone_submodules calls _do_validate_submodule_cloning.
+	#
+	# _do_validate_submodule_cloning stops the status operation.
+	#
+	# There are no other calls into this chain from other code.
+
+	set o_status_op [$status start \
 		[mc "Creating working directory"] \
-		[mc "files"]
+		[mc "files"]]
 
 	set readtree_err {}
 	set fd [git_read --stderr read-tree \
@@ -976,33 +1010,9 @@ method _do_clone_checkout {HEAD} {
 	fileevent $fd readable [cb _readtree_wait $fd]
 }
 
-method _do_validate_submodule_cloning {ok} {
-	if {$ok} {
-		$o_cons done $ok
-		set done 1
-	} else {
-		_clone_failed $this [mc "Cannot clone submodules."]
-	}
-}
-
-method _do_clone_submodules {} {
-	if {$recursive eq {true}} {
-		destroy $w_body
-		set o_cons [console::embed \
-			$w_body \
-			[mc "Cloning submodules"]]
-		pack $w_body -fill both -expand 1 -padx 10
-		$o_cons exec \
-			[list git submodule update --init --recursive] \
-			[cb _do_validate_submodule_cloning]
-	} else {
-		set done 1
-	}
-}
-
 method _readtree_wait {fd} {
 	set buf [read $fd]
-	$o_cons update_meter $buf
+	$o_status_op update_meter $buf
 	append readtree_err $buf
 
 	fconfigure $fd -blocking 1
@@ -1050,6 +1060,34 @@ method _postcheckout_wait {fd_ph} {
 	fconfigure $fd_ph -blocking 0
 }
 
+method _do_clone_submodules {} {
+	if {$recursive eq {true}} {
+		$o_status_op stop
+		set o_status_op {}
+
+		destroy $w_body
+
+		set o_cons [console::embed \
+			$w_body \
+			[mc "Cloning submodules"]]
+		pack $w_body -fill both -expand 1 -padx 10
+		$o_cons exec \
+			[list git submodule update --init --recursive] \
+			[cb _do_validate_submodule_cloning]
+	} else {
+		set done 1
+	}
+}
+
+method _do_validate_submodule_cloning {ok} {
+	if {$ok} {
+		$o_cons done $ok
+		set done 1
+	} else {
+		_clone_failed $this [mc "Cannot clone submodules."]
+	}
+}
+
 ######################################################################
 ##
 ## Open Existing Repository
diff -pruN 1.2.1+git2.18.0-1/git/git-gui/lib/chord.tcl 1.2.3+git2.25.1-1/git/git-gui/lib/chord.tcl
--- 1.2.1+git2.18.0-1/git/git-gui/lib/chord.tcl	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/git-gui/lib/chord.tcl	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,160 @@
+# Simple Chord for Tcl
+#
+# A "chord" is a method with more than one entrypoint and only one body, such
+# that the body runs only once all the entrypoints have been called by
+# different asynchronous tasks. In this implementation, the chord is defined
+# dynamically for each invocation. A SimpleChord object is created, supplying
+# body script to be run when the chord is completed, and then one or more notes
+# are added to the chord. Each note can be called like a proc, and returns
+# immediately if the chord isn't yet complete. When the last remaining note is
+# called, the body runs before the note returns.
+#
+# The SimpleChord class has a constructor that takes the body script, and a
+# method add_note that returns a note object. Since the body script does not
+# run in the context of the procedure that defined it, a mechanism is provided
+# for injecting variables into the chord for use by the body script. The
+# activation of a note is idempotent; multiple calls have the same effect as
+# a simple call.
+#
+# If you are invoking asynchronous operations with chord notes as completion
+# callbacks, and there is a possibility that earlier operations could complete
+# before later ones are started, it is a good practice to create a "common"
+# note on the chord that prevents it from being complete until you're certain
+# you've added all the notes you need.
+#
+# Example:
+#
+#   # Turn off the UI while running a couple of async operations.
+#   lock_ui
+#
+#   set chord [SimpleChord new {
+#     unlock_ui
+#     # Note: $notice here is not referenced in the calling scope
+#     if {$notice} { info_popup $notice }
+#   }
+#
+#   # Configure a note to keep the chord from completing until
+#   # all operations have been initiated.
+#   set common_note [$chord add_note]
+#
+#   # Pass notes as 'after' callbacks to other operations
+#   async_operation $args [$chord add_note]
+#   other_async_operation $args [$chord add_note]
+#
+#   # Communicate with the chord body
+#   if {$condition} {
+#     # This sets $notice in the same context that the chord body runs in.
+#     $chord eval { set notice "Something interesting" }
+#   }
+#
+#   # Activate the common note, making the chord eligible to complete
+#   $common_note
+#
+# At this point, the chord will complete at some unknown point in the future.
+# The common note might have been the first note activated, or the async
+# operations might have completed synchronously and the common note is the
+# last one, completing the chord before this code finishes, or anything in
+# between. The purpose of the chord is to not have to worry about the order.
+
+# SimpleChord class:
+#   Represents a procedure that conceptually has multiple entrypoints that must
+#   all be called before the procedure executes. Each entrypoint is called a
+#   "note". The chord is only "completed" when all the notes are "activated".
+oo::class create SimpleChord {
+	variable notes body is_completed
+
+	# Constructor:
+	#   set chord [SimpleChord new {body}]
+	#     Creates a new chord object with the specified body script. The
+	#     body script is evaluated at most once, when a note is activated
+	#     and the chord has no other non-activated notes.
+	constructor {body} {
+		set notes [list]
+		my eval [list set body $body]
+		set is_completed 0
+	}
+
+	# Method:
+	#   $chord eval {script}
+	#     Runs the specified script in the same context (namespace) in which
+	#     the chord body will be evaluated. This can be used to set variable
+	#     values for the chord body to use.
+	method eval {script} {
+		namespace eval [self] $script
+	}
+
+	# Method:
+	#   set note [$chord add_note]
+	#     Adds a new note to the chord, an instance of ChordNote. Raises an
+	#     error if the chord is already completed, otherwise the chord is
+	#     updated so that the new note must also be activated before the
+	#     body is evaluated.
+	method add_note {} {
+		if {$is_completed} { error "Cannot add a note to a completed chord" }
+
+		set note [ChordNote new [self]]
+
+		lappend notes $note
+
+		return $note
+	}
+
+	# This method is for internal use only and is intentionally undocumented.
+	method notify_note_activation {} {
+		if {!$is_completed} {
+			foreach note $notes {
+				if {![$note is_activated]} { return }
+			}
+
+			set is_completed 1
+
+			namespace eval [self] $body
+			namespace delete [self]
+		}
+	}
+}
+
+# ChordNote class:
+#   Represents a note within a chord, providing a way to activate it. When the
+#   final note of the chord is activated (this can be any note in the chord,
+#   with all other notes already previously activated in any order), the chord's
+#   body is evaluated.
+oo::class create ChordNote {
+	variable chord is_activated
+
+	# Constructor:
+	#   Instances of ChordNote are created internally by calling add_note on
+	#   SimpleChord objects.
+	constructor {chord} {
+		my eval set chord $chord
+		set is_activated 0
+	}
+
+	# Method:
+	#   [$note is_activated]
+	#     Returns true if this note has already been activated.
+	method is_activated {} {
+		return $is_activated
+	}
+
+	# Method:
+	#   $note
+	#     Activates the note, if it has not already been activated, and
+	#     completes the chord if there are no other notes awaiting
+	#     activation. Subsequent calls will have no further effect.
+	#
+	# NB: In TclOO, if an object is invoked like a method without supplying
+	#     any method name, then this internal method `unknown` is what
+	#     actually runs (with no parameters). It is used in the ChordNote
+	#     class for the purpose of allowing the note object to be called as
+	#     a function (see example above). (The `unknown` method can also be
+	#     used to support dynamic dispatch, but must take parameters to
+	#     identify the "unknown" method to be invoked. In this form, this
+	#     proc serves only to make instances behave directly like methods.)
+	method unknown {} {
+		if {!$is_activated} {
+			set is_activated 1
+			$chord notify_note_activation
+		}
+	}
+}
diff -pruN 1.2.1+git2.18.0-1/git/git-gui/lib/commit.tcl 1.2.3+git2.25.1-1/git/git-gui/lib/commit.tcl
--- 1.2.1+git2.18.0-1/git/git-gui/lib/commit.tcl	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/git-gui/lib/commit.tcl	2020-02-17 04:47:35.000000000 +0000
@@ -333,7 +333,7 @@ proc commit_writetree {curHEAD msg_p} {
 proc commit_committree {fd_wt curHEAD msg_p} {
 	global HEAD PARENT MERGE_HEAD commit_type commit_author
 	global current_branch
-	global ui_comm selected_commit_type
+	global ui_comm commit_type_is_amend
 	global file_states selected_paths rescan_active
 	global repo_config
 	global env
@@ -467,8 +467,8 @@ A rescan will be automatically started n
 
 	# -- Update in memory status
 	#
-	set selected_commit_type new
 	set commit_type normal
+	set commit_type_is_amend 0
 	set HEAD $cmt_id
 	set PARENT $cmt_id
 	set MERGE_HEAD [list]
diff -pruN 1.2.1+git2.18.0-1/git/git-gui/lib/console.tcl 1.2.3+git2.25.1-1/git/git-gui/lib/console.tcl
--- 1.2.1+git2.18.0-1/git/git-gui/lib/console.tcl	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/git-gui/lib/console.tcl	2020-02-17 04:47:35.000000000 +0000
@@ -203,6 +203,8 @@ method done {ok} {
 			focus $w.ok
 		}
 	}
+
+	bind $w <Key-Escape> "destroy $w;break"
 }
 
 method _sb_set {sb orient first last} {
diff -pruN 1.2.1+git2.18.0-1/git/git-gui/lib/diff.tcl 1.2.3+git2.25.1-1/git/git-gui/lib/diff.tcl
--- 1.2.1+git2.18.0-1/git/git-gui/lib/diff.tcl	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/git-gui/lib/diff.tcl	2020-02-17 04:47:35.000000000 +0000
@@ -55,7 +55,7 @@ proc reshow_diff {{after {}}} {
 
 proc force_diff_encoding {enc} {
 	global current_diff_path
-	
+
 	if {$current_diff_path ne {}} {
 		force_path_encoding $current_diff_path $enc
 		reshow_diff
@@ -270,19 +270,6 @@ proc show_other_diff {path w m cont_info
 	}
 }
 
-proc get_conflict_marker_size {path} {
-	set size 7
-	catch {
-		set fd_rc [eval [list git_read check-attr "conflict-marker-size" -- $path]]
-		set ret [gets $fd_rc line]
-		close $fd_rc
-		if {$ret > 0} {
-			regexp {.*: conflict-marker-size: (\d+)$} $line line size
-		}
-	}
-	return $size
-}
-
 proc start_show_diff {cont_info {add_opts {}}} {
 	global file_states file_lists
 	global is_3way_diff is_submodule_diff diff_active repo_config
@@ -298,7 +285,7 @@ proc start_show_diff {cont_info {add_opt
 	set is_submodule_diff 0
 	set diff_active 1
 	set current_diff_header {}
-	set conflict_size [get_conflict_marker_size $path]
+	set conflict_size [gitattr $path conflict-marker-size 7]
 
 	set cmd [list]
 	if {$w eq $ui_index} {
@@ -360,6 +347,10 @@ proc start_show_diff {cont_info {add_opt
 	}
 
 	set ::current_diff_inheader 1
+	# Detect pre-image lines of the diff3 conflict-style. They are just
+	# '++' lines which is not bijective. Thus, we need to maintain a state
+	# across lines.
+	set ::conflict_in_pre_image 0
 	fconfigure $fd \
 		-blocking 0 \
 		-encoding [get_path_encoding $path] \
@@ -462,11 +453,23 @@ proc read_diff {fd conflict_size cont_in
 			{--} {set tags d_--}
 			{++} {
 				set regexp [string map [list %conflict_size $conflict_size]\
-								{^\+\+([<>=]){%conflict_size}(?: |$)}]
+								{^\+\+([<>=|]){%conflict_size}(?: |$)}]
 				if {[regexp $regexp $line _g op]} {
 					set is_conflict_diff 1
 					set line [string replace $line 0 1 {  }]
 					set tags d$op
+
+					# The ||| conflict-marker marks the start of the pre-image.
+					# All those lines are also prefixed with '++'. Thus we need
+					# to maintain this state.
+					set ::conflict_in_pre_image [expr {$op eq {|}}]
+				} elseif {$::conflict_in_pre_image} {
+					# This is a pre-image line. It is the one which both sides
+					# are based on. As it has also the '++' line start, it is
+					# normally shown as 'added'. Invert this to '--' to make
+					# it a 'removed' line.
+					set line [string replace $line 0 1 {--}]
+					set tags d_--
 				} else {
 					set tags d_++
 				}
@@ -567,24 +570,31 @@ proc read_diff {fd conflict_size cont_in
 	}
 }
 
-proc apply_hunk {x y} {
+proc apply_or_revert_hunk {x y revert} {
 	global current_diff_path current_diff_header current_diff_side
-	global ui_diff ui_index file_states
+	global ui_diff ui_index file_states last_revert last_revert_enc
 
 	if {$current_diff_path eq {} || $current_diff_header eq {}} return
 	if {![lock_index apply_hunk]} return
 
-	set apply_cmd {apply --cached --whitespace=nowarn}
+	set apply_cmd {apply --whitespace=nowarn}
 	set mi [lindex $file_states($current_diff_path) 0]
 	if {$current_diff_side eq $ui_index} {
 		set failed_msg [mc "Failed to unstage selected hunk."]
-		lappend apply_cmd --reverse
+		lappend apply_cmd --reverse --cached
 		if {[string index $mi 0] ne {M}} {
 			unlock_index
 			return
 		}
 	} else {
-		set failed_msg [mc "Failed to stage selected hunk."]
+		if {$revert} {
+			set failed_msg [mc "Failed to revert selected hunk."]
+			lappend apply_cmd --reverse
+		} else {
+			set failed_msg [mc "Failed to stage selected hunk."]
+			lappend apply_cmd --cached
+		}
+
 		if {[string index $mi 1] ne {M}} {
 			unlock_index
 			return
@@ -603,29 +613,40 @@ proc apply_hunk {x y} {
 		set e_lno end
 	}
 
+	set wholepatch "$current_diff_header[$ui_diff get $s_lno $e_lno]"
+
 	if {[catch {
 		set enc [get_path_encoding $current_diff_path]
 		set p [eval git_write $apply_cmd]
 		fconfigure $p -translation binary -encoding $enc
-		puts -nonewline $p $current_diff_header
-		puts -nonewline $p [$ui_diff get $s_lno $e_lno]
+		puts -nonewline $p $wholepatch
 		close $p} err]} {
 		error_popup "$failed_msg\n\n$err"
 		unlock_index
 		return
 	}
 
+	if {$revert} {
+		# Save a copy of this patch for undoing reverts.
+		set last_revert $wholepatch
+		set last_revert_enc $enc
+	}
+
 	$ui_diff conf -state normal
 	$ui_diff delete $s_lno $e_lno
 	$ui_diff conf -state disabled
 
+	# Check if the hunk was the last one in the file.
 	if {[$ui_diff get 1.0 end] eq "\n"} {
 		set o _
 	} else {
 		set o ?
 	}
 
-	if {$current_diff_side eq $ui_index} {
+	# Update the status flags.
+	if {$revert} {
+		set mi [string index $mi 0]$o
+	} elseif {$current_diff_side eq $ui_index} {
 		set mi ${o}M
 	} elseif {[string index $mi 0] eq {_}} {
 		set mi M$o
@@ -640,9 +661,9 @@ proc apply_hunk {x y} {
 	}
 }
 
-proc apply_range_or_line {x y} {
+proc apply_or_revert_range_or_line {x y revert} {
 	global current_diff_path current_diff_header current_diff_side
-	global ui_diff ui_index file_states
+	global ui_diff ui_index file_states last_revert
 
 	set selected [$ui_diff tag nextrange sel 0.0]
 
@@ -660,19 +681,27 @@ proc apply_range_or_line {x y} {
 	if {$current_diff_path eq {} || $current_diff_header eq {}} return
 	if {![lock_index apply_hunk]} return
 
-	set apply_cmd {apply --cached --whitespace=nowarn}
+	set apply_cmd {apply --whitespace=nowarn}
 	set mi [lindex $file_states($current_diff_path) 0]
 	if {$current_diff_side eq $ui_index} {
 		set failed_msg [mc "Failed to unstage selected line."]
 		set to_context {+}
-		lappend apply_cmd --reverse
+		lappend apply_cmd --reverse --cached
 		if {[string index $mi 0] ne {M}} {
 			unlock_index
 			return
 		}
 	} else {
-		set failed_msg [mc "Failed to stage selected line."]
-		set to_context {-}
+		if {$revert} {
+			set failed_msg [mc "Failed to revert selected line."]
+			set to_context {+}
+			lappend apply_cmd --reverse
+		} else {
+			set failed_msg [mc "Failed to stage selected line."]
+			set to_context {-}
+			lappend apply_cmd --cached
+		}
+
 		if {[string index $mi 1] ne {M}} {
 			unlock_index
 			return
@@ -830,7 +859,47 @@ proc apply_range_or_line {x y} {
 		puts -nonewline $p $wholepatch
 		close $p} err]} {
 		error_popup "$failed_msg\n\n$err"
+		unlock_index
+		return
 	}
 
+	if {$revert} {
+		# Save a copy of this patch for undoing reverts.
+		set last_revert $current_diff_header$wholepatch
+		set last_revert_enc $enc
+	}
+
+	unlock_index
+}
+
+# Undo the last line/hunk reverted. When hunks and lines are reverted, a copy
+# of the diff applied is saved. Re-apply that diff to undo the revert.
+#
+# Right now, we only use a single variable to hold the copy, and not a
+# stack/deque for simplicity, so multiple undos are not possible. Maybe this
+# can be added if the need for something like this is felt in the future.
+proc undo_last_revert {} {
+	global last_revert current_diff_path current_diff_header
+	global last_revert_enc
+
+	if {$last_revert eq {}} return
+	if {![lock_index apply_hunk]} return
+
+	set apply_cmd {apply --whitespace=nowarn}
+	set failed_msg [mc "Failed to undo last revert."]
+
+	if {[catch {
+		set enc $last_revert_enc
+		set p [eval git_write $apply_cmd]
+		fconfigure $p -translation binary -encoding $enc
+		puts -nonewline $p $last_revert
+		close $p} err]} {
+		error_popup "$failed_msg\n\n$err"
+		unlock_index
+		return
+	}
+
+	set last_revert {}
+
 	unlock_index
 }
diff -pruN 1.2.1+git2.18.0-1/git/git-gui/lib/index.tcl 1.2.3+git2.25.1-1/git/git-gui/lib/index.tcl
--- 1.2.1+git2.18.0-1/git/git-gui/lib/index.tcl	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/git-gui/lib/index.tcl	2020-02-17 04:47:35.000000000 +0000
@@ -7,67 +7,74 @@ proc _delete_indexlock {} {
 	}
 }
 
-proc _close_updateindex {fd after} {
-	global use_ttk NS
-	fconfigure $fd -blocking 1
-	if {[catch {close $fd} err]} {
-		set w .indexfried
-		Dialog $w
-		wm withdraw $w
-		wm title $w [strcat "[appname] ([reponame]): " [mc "Index Error"]]
-		wm geometry $w "+[winfo rootx .]+[winfo rooty .]"
-		set s [mc "Updating the Git index failed.  A rescan will be automatically started to resynchronize git-gui."]
-		text $w.msg -yscrollcommand [list $w.vs set] \
-			-width [string length $s] -relief flat \
-			-borderwidth 0 -highlightthickness 0 \
-			-background [get_bg_color $w]
-		$w.msg tag configure bold -font font_uibold -justify center
-		${NS}::scrollbar $w.vs -command [list $w.msg yview]
-		$w.msg insert end $s bold \n\n$err {}
-		$w.msg configure -state disabled
-
-		${NS}::button $w.continue \
-			-text [mc "Continue"] \
-			-command [list destroy $w]
-		${NS}::button $w.unlock \
-			-text [mc "Unlock Index"] \
-			-command "destroy $w; _delete_indexlock"
-		grid $w.msg - $w.vs -sticky news
-		grid $w.unlock $w.continue - -sticky se -padx 2 -pady 2
-		grid columnconfigure $w 0 -weight 1
-		grid rowconfigure $w 0 -weight 1
-
-		wm protocol $w WM_DELETE_WINDOW update
-		bind $w.continue <Visibility> "
-			grab $w
-			focus %W
-		"
-		wm deiconify $w
-		tkwait window $w
-
-		$::main_status stop
+proc close_and_unlock_index {fd after} {
+	if {![catch {_close_updateindex $fd} err]} {
 		unlock_index
-		rescan $after 0
-		return
+		uplevel #0 $after
+	} else {
+		rescan_on_error $err $after
 	}
+}
+
+proc _close_updateindex {fd} {
+	fconfigure $fd -blocking 1
+	close $fd
+}
 
-	$::main_status stop
+proc rescan_on_error {err {after {}}} {
+	global use_ttk NS
+
+	set w .indexfried
+	Dialog $w
+	wm withdraw $w
+	wm title $w [strcat "[appname] ([reponame]): " [mc "Index Error"]]
+	wm geometry $w "+[winfo rootx .]+[winfo rooty .]"
+	set s [mc "Updating the Git index failed.  A rescan will be automatically started to resynchronize git-gui."]
+	text $w.msg -yscrollcommand [list $w.vs set] \
+		-width [string length $s] -relief flat \
+		-borderwidth 0 -highlightthickness 0 \
+		-background [get_bg_color $w]
+	$w.msg tag configure bold -font font_uibold -justify center
+	${NS}::scrollbar $w.vs -command [list $w.msg yview]
+	$w.msg insert end $s bold \n\n$err {}
+	$w.msg configure -state disabled
+
+	${NS}::button $w.continue \
+		-text [mc "Continue"] \
+		-command [list destroy $w]
+	${NS}::button $w.unlock \
+		-text [mc "Unlock Index"] \
+		-command "destroy $w; _delete_indexlock"
+	grid $w.msg - $w.vs -sticky news
+	grid $w.unlock $w.continue - -sticky se -padx 2 -pady 2
+	grid columnconfigure $w 0 -weight 1
+	grid rowconfigure $w 0 -weight 1
+
+	wm protocol $w WM_DELETE_WINDOW update
+	bind $w.continue <Visibility> "
+		grab $w
+		focus %W
+	"
+	wm deiconify $w
+	tkwait window $w
+
+	$::main_status stop_all
 	unlock_index
-	uplevel #0 $after
+	rescan [concat $after [list ui_ready]] 0
 }
 
-proc update_indexinfo {msg pathList after} {
+proc update_indexinfo {msg path_list after} {
 	global update_index_cp
 
 	if {![lock_index update]} return
 
 	set update_index_cp 0
-	set pathList [lsort $pathList]
-	set totalCnt [llength $pathList]
-	set batch [expr {int($totalCnt * .01) + 1}]
+	set path_list [lsort $path_list]
+	set total_cnt [llength $path_list]
+	set batch [expr {int($total_cnt * .01) + 1}]
 	if {$batch > 25} {set batch 25}
 
-	$::main_status start $msg [mc "files"]
+	set status_bar_operation [$::main_status start $msg [mc "files"]]
 	set fd [git_write update-index -z --index-info]
 	fconfigure $fd \
 		-blocking 0 \
@@ -78,26 +85,29 @@ proc update_indexinfo {msg pathList afte
 	fileevent $fd writable [list \
 		write_update_indexinfo \
 		$fd \
-		$pathList \
-		$totalCnt \
+		$path_list \
+		$total_cnt \
 		$batch \
+		$status_bar_operation \
 		$after \
 		]
 }
 
-proc write_update_indexinfo {fd pathList totalCnt batch after} {
+proc write_update_indexinfo {fd path_list total_cnt batch status_bar_operation \
+	after} {
 	global update_index_cp
 	global file_states current_diff_path
 
-	if {$update_index_cp >= $totalCnt} {
-		_close_updateindex $fd $after
+	if {$update_index_cp >= $total_cnt} {
+		$status_bar_operation stop
+		close_and_unlock_index $fd $after
 		return
 	}
 
 	for {set i $batch} \
-		{$update_index_cp < $totalCnt && $i > 0} \
+		{$update_index_cp < $total_cnt && $i > 0} \
 		{incr i -1} {
-		set path [lindex $pathList $update_index_cp]
+		set path [lindex $path_list $update_index_cp]
 		incr update_index_cp
 
 		set s $file_states($path)
@@ -119,21 +129,21 @@ proc write_update_indexinfo {fd pathList
 		display_file $path $new
 	}
 
-	$::main_status update $update_index_cp $totalCnt
+	$status_bar_operation update $update_index_cp $total_cnt
 }
 
-proc update_index {msg pathList after} {
+proc update_index {msg path_list after} {
 	global update_index_cp
 
 	if {![lock_index update]} return
 
 	set update_index_cp 0
-	set pathList [lsort $pathList]
-	set totalCnt [llength $pathList]
-	set batch [expr {int($totalCnt * .01) + 1}]
+	set path_list [lsort $path_list]
+	set total_cnt [llength $path_list]
+	set batch [expr {int($total_cnt * .01) + 1}]
 	if {$batch > 25} {set batch 25}
 
-	$::main_status start $msg [mc "files"]
+	set status_bar_operation [$::main_status start $msg [mc "files"]]
 	set fd [git_write update-index --add --remove -z --stdin]
 	fconfigure $fd \
 		-blocking 0 \
@@ -144,26 +154,29 @@ proc update_index {msg pathList after} {
 	fileevent $fd writable [list \
 		write_update_index \
 		$fd \
-		$pathList \
-		$totalCnt \
+		$path_list \
+		$total_cnt \
 		$batch \
+		$status_bar_operation \
 		$after \
 		]
 }
 
-proc write_update_index {fd pathList totalCnt batch after} {
+proc write_update_index {fd path_list total_cnt batch status_bar_operation \
+	after} {
 	global update_index_cp
 	global file_states current_diff_path
 
-	if {$update_index_cp >= $totalCnt} {
-		_close_updateindex $fd $after
+	if {$update_index_cp >= $total_cnt} {
+		$status_bar_operation stop
+		close_and_unlock_index $fd $after
 		return
 	}
 
 	for {set i $batch} \
-		{$update_index_cp < $totalCnt && $i > 0} \
+		{$update_index_cp < $total_cnt && $i > 0} \
 		{incr i -1} {
-		set path [lindex $pathList $update_index_cp]
+		set path [lindex $path_list $update_index_cp]
 		incr update_index_cp
 
 		switch -glob -- [lindex $file_states($path) 0] {
@@ -190,21 +203,21 @@ proc write_update_index {fd pathList tot
 		display_file $path $new
 	}
 
-	$::main_status update $update_index_cp $totalCnt
+	$status_bar_operation update $update_index_cp $total_cnt
 }
 
-proc checkout_index {msg pathList after} {
+proc checkout_index {msg path_list after capture_error} {
 	global update_index_cp
 
 	if {![lock_index update]} return
 
 	set update_index_cp 0
-	set pathList [lsort $pathList]
-	set totalCnt [llength $pathList]
-	set batch [expr {int($totalCnt * .01) + 1}]
+	set path_list [lsort $path_list]
+	set total_cnt [llength $path_list]
+	set batch [expr {int($total_cnt * .01) + 1}]
 	if {$batch > 25} {set batch 25}
 
-	$::main_status start $msg [mc "files"]
+	set status_bar_operation [$::main_status start $msg [mc "files"]]
 	set fd [git_write checkout-index \
 		--index \
 		--quiet \
@@ -221,26 +234,45 @@ proc checkout_index {msg pathList after}
 	fileevent $fd writable [list \
 		write_checkout_index \
 		$fd \
-		$pathList \
-		$totalCnt \
+		$path_list \
+		$total_cnt \
 		$batch \
+		$status_bar_operation \
 		$after \
+		$capture_error \
 		]
 }
 
-proc write_checkout_index {fd pathList totalCnt batch after} {
+proc write_checkout_index {fd path_list total_cnt batch status_bar_operation \
+	after capture_error} {
 	global update_index_cp
 	global file_states current_diff_path
 
-	if {$update_index_cp >= $totalCnt} {
-		_close_updateindex $fd $after
+	if {$update_index_cp >= $total_cnt} {
+		$status_bar_operation stop
+
+		# We do not unlock the index directly here because this
+		# operation expects to potentially run in parallel with file
+		# deletions scheduled by revert_helper. We're done with the
+		# update index, so we close it, but actually unlocking the index
+		# and dealing with potential errors is deferred to the chord
+		# body that runs when all async operations are completed.
+		#
+		# (See after_chord in revert_helper.)
+
+		if {[catch {_close_updateindex $fd} err]} {
+			uplevel #0 $capture_error [list $err]
+		}
+
+		uplevel #0 $after
+
 		return
 	}
 
 	for {set i $batch} \
-		{$update_index_cp < $totalCnt && $i > 0} \
+		{$update_index_cp < $total_cnt && $i > 0} \
 		{incr i -1} {
-		set path [lindex $pathList $update_index_cp]
+		set path [lindex $path_list $update_index_cp]
 		incr update_index_cp
 		switch -glob -- [lindex $file_states($path) 0] {
 		U? {continue}
@@ -253,7 +285,7 @@ proc write_checkout_index {fd pathList t
 		}
 	}
 
-	$::main_status update $update_index_cp $totalCnt
+	$status_bar_operation update $update_index_cp $total_cnt
 }
 
 proc unstage_helper {txt paths} {
@@ -261,7 +293,7 @@ proc unstage_helper {txt paths} {
 
 	if {![lock_index begin-update]} return
 
-	set pathList [list]
+	set path_list [list]
 	set after {}
 	foreach path $paths {
 		switch -glob -- [lindex $file_states($path) 0] {
@@ -269,19 +301,19 @@ proc unstage_helper {txt paths} {
 		M? -
 		T? -
 		D? {
-			lappend pathList $path
+			lappend path_list $path
 			if {$path eq $current_diff_path} {
 				set after {reshow_diff;}
 			}
 		}
 		}
 	}
-	if {$pathList eq {}} {
+	if {$path_list eq {}} {
 		unlock_index
 	} else {
 		update_indexinfo \
 			$txt \
-			$pathList \
+			$path_list \
 			[concat $after [list ui_ready]]
 	}
 }
@@ -305,7 +337,7 @@ proc add_helper {txt paths} {
 
 	if {![lock_index begin-update]} return
 
-	set pathList [list]
+	set path_list [list]
 	set after {}
 	foreach path $paths {
 		switch -glob -- [lindex $file_states($path) 0] {
@@ -321,19 +353,19 @@ proc add_helper {txt paths} {
 		?M -
 		?D -
 		?T {
-			lappend pathList $path
+			lappend path_list $path
 			if {$path eq $current_diff_path} {
 				set after {reshow_diff;}
 			}
 		}
 		}
 	}
-	if {$pathList eq {}} {
+	if {$path_list eq {}} {
 		unlock_index
 	} else {
 		update_index \
 			$txt \
-			$pathList \
+			$path_list \
 			[concat $after {ui_status [mc "Ready to commit."]}]
 	}
 }
@@ -388,66 +420,301 @@ proc do_add_all {} {
 	add_helper [mc "Adding all changed files"] $paths
 }
 
+# Copied from TclLib package "lambda".
+proc lambda {arguments body args} {
+	return [list ::apply [list $arguments $body] {*}$args]
+}
+
 proc revert_helper {txt paths} {
 	global file_states current_diff_path
 
 	if {![lock_index begin-update]} return
 
-	set pathList [list]
-	set after {}
+	# Common "after" functionality that waits until multiple asynchronous
+	# operations are complete (by waiting for them to activate their notes
+	# on the chord).
+	#
+	# The asynchronous operations are each indicated below by a comment
+	# before the code block that starts the async operation.
+	set after_chord [SimpleChord new {
+		if {[string trim $err] != ""} {
+			rescan_on_error $err
+		} else {
+			unlock_index
+			if {$should_reshow_diff} { reshow_diff }
+			ui_ready
+		}
+	}]
+
+	$after_chord eval { set should_reshow_diff 0 }
+
+	# This function captures an error for processing when after_chord is
+	# completed. (The chord is curried into the lambda function.)
+	set capture_error [lambda \
+		{chord error} \
+		{ $chord eval [list set err $error] } \
+		$after_chord]
+
+	# We don't know how many notes we're going to create (it's dynamic based
+	# on conditional paths below), so create a common note that will delay
+	# the chord's completion until we activate it, and then activate it
+	# after all the other notes have been created.
+	set after_common_note [$after_chord add_note]
+
+	set path_list [list]
+	set untracked_list [list]
+
 	foreach path $paths {
 		switch -glob -- [lindex $file_states($path) 0] {
 		U? {continue}
+		?O {
+			lappend untracked_list $path
+		}
 		?M -
 		?T -
 		?D {
-			lappend pathList $path
+			lappend path_list $path
 			if {$path eq $current_diff_path} {
-				set after {reshow_diff;}
+				$after_chord eval { set should_reshow_diff 1 }
 			}
 		}
 		}
 	}
 
+	set path_cnt [llength $path_list]
+	set untracked_cnt [llength $untracked_list]
 
-	# Split question between singular and plural cases, because
-	# such distinction is needed in some languages. Previously, the
-	# code used "Revert changes in" for both, but that can't work
-	# in languages where 'in' must be combined with word from
-	# rest of string (in different way for both cases of course).
-	#
-	# FIXME: Unfortunately, even that isn't enough in some languages
-	# as they have quite complex plural-form rules. Unfortunately,
-	# msgcat doesn't seem to support that kind of string translation.
-	#
-	set n [llength $pathList]
-	if {$n == 0} {
-		unlock_index
-		return
-	} elseif {$n == 1} {
-		set query [mc "Revert changes in file %s?" [short_path [lindex $pathList]]]
-	} else {
-		set query [mc "Revert changes in these %i files?" $n]
-	}
+	# Asynchronous operation: revert changes by checking them out afresh
+	# from the index.
+	if {$path_cnt > 0} {
+		# Split question between singular and plural cases, because
+		# such distinction is needed in some languages. Previously, the
+		# code used "Revert changes in" for both, but that can't work
+		# in languages where 'in' must be combined with word from
+		# rest of string (in different way for both cases of course).
+		#
+		# FIXME: Unfortunately, even that isn't enough in some languages
+		# as they have quite complex plural-form rules. Unfortunately,
+		# msgcat doesn't seem to support that kind of string
+		# translation.
+		#
+		if {$path_cnt == 1} {
+			set query [mc \
+				"Revert changes in file %s?" \
+				[short_path [lindex $path_list]] \
+				]
+		} else {
+			set query [mc \
+				"Revert changes in these %i files?" \
+				$path_cnt]
+		}
 
-	set reply [tk_dialog \
-		.confirm_revert \
-		"[appname] ([reponame])" \
-		"$query
+		set reply [tk_dialog \
+			.confirm_revert \
+			"[appname] ([reponame])" \
+			"$query
 
 [mc "Any unstaged changes will be permanently lost by the revert."]" \
-		question \
-		1 \
-		[mc "Do Nothing"] \
-		[mc "Revert Changes"] \
-		]
-	if {$reply == 1} {
-		checkout_index \
-			$txt \
-			$pathList \
-			[concat $after [list ui_ready]]
+			question \
+			1 \
+			[mc "Do Nothing"] \
+			[mc "Revert Changes"] \
+			]
+
+		if {$reply == 1} {
+			checkout_index \
+				$txt \
+				$path_list \
+				[$after_chord add_note] \
+				$capture_error
+		}
+	}
+
+	# Asynchronous operation: Deletion of untracked files.
+	if {$untracked_cnt > 0} {
+		# Split question between singular and plural cases, because
+		# such distinction is needed in some languages.
+		#
+		# FIXME: Unfortunately, even that isn't enough in some languages
+		# as they have quite complex plural-form rules. Unfortunately,
+		# msgcat doesn't seem to support that kind of string
+		# translation.
+		#
+		if {$untracked_cnt == 1} {
+			set query [mc \
+				"Delete untracked file %s?" \
+				[short_path [lindex $untracked_list]] \
+				]
+		} else {
+			set query [mc \
+				"Delete these %i untracked files?" \
+				$untracked_cnt \
+				]
+		}
+
+		set reply [tk_dialog \
+			.confirm_revert \
+			"[appname] ([reponame])" \
+			"$query
+
+[mc "Files will be permanently deleted."]" \
+			question \
+			1 \
+			[mc "Do Nothing"] \
+			[mc "Delete Files"] \
+			]
+
+		if {$reply == 1} {
+			$after_chord eval { set should_reshow_diff 1 }
+
+			delete_files $untracked_list [$after_chord add_note]
+		}
+	}
+
+	# Activate the common note. If no other notes were created, this
+	# completes the chord. If other notes were created, then this common
+	# note prevents a race condition where the chord might complete early.
+	$after_common_note
+}
+
+# Delete all of the specified files, performing deletion in batches to allow the
+# UI to remain responsive and updated.
+proc delete_files {path_list after} {
+	# Enable progress bar status updates
+	set status_bar_operation [$::main_status \
+		start \
+		[mc "Deleting"] \
+		[mc "files"]]
+
+	set path_index 0
+	set deletion_errors [list]
+	set batch_size 50
+
+	delete_helper \
+		$path_list \
+		$path_index \
+		$deletion_errors \
+		$batch_size \
+		$status_bar_operation \
+		$after
+}
+
+# Helper function to delete a list of files in batches. Each call deletes one
+# batch of files, and then schedules a call for the next batch after any UI
+# messages have been processed.
+proc delete_helper {path_list path_index deletion_errors batch_size \
+	status_bar_operation after} {
+	global file_states
+
+	set path_cnt [llength $path_list]
+
+	set batch_remaining $batch_size
+
+	while {$batch_remaining > 0} {
+		if {$path_index >= $path_cnt} { break }
+
+		set path [lindex $path_list $path_index]
+
+		set deletion_failed [catch {file delete -- $path} deletion_error]
+
+		if {$deletion_failed} {
+			lappend deletion_errors [list "$deletion_error"]
+		} else {
+			remove_empty_directories [file dirname $path]
+
+			# Don't assume the deletion worked. Remove the file from
+			# the UI, but only if it no longer exists.
+			if {![path_exists $path]} {
+				unset file_states($path)
+				display_file $path __
+			}
+		}
+
+		incr path_index 1
+		incr batch_remaining -1
+	}
+
+	# Update the progress bar to indicate that this batch has been
+	# completed. The update will be visible when this procedure returns
+	# and allows the UI thread to process messages.
+	$status_bar_operation update $path_index $path_cnt
+
+	if {$path_index < $path_cnt} {
+		# The Tcler's Wiki lists this as the best practice for keeping
+		# a UI active and processing messages during a long-running
+		# operation.
+
+		after idle [list after 0 [list \
+			delete_helper \
+			$path_list \
+			$path_index \
+			$deletion_errors \
+			$batch_size \
+			$status_bar_operation \
+			$after
+			]]
 	} else {
-		unlock_index
+		# Finish the status bar operation.
+		$status_bar_operation stop
+
+		# Report error, if any, based on how many deletions failed.
+		set deletion_error_cnt [llength $deletion_errors]
+
+		if {($deletion_error_cnt > 0)
+		 && ($deletion_error_cnt <= [MAX_VERBOSE_FILES_IN_DELETION_ERROR])} {
+			set error_text [mc "Encountered errors deleting files:\n"]
+
+			foreach deletion_error $deletion_errors {
+				append error_text "* [lindex $deletion_error 0]\n"
+			}
+
+			error_popup $error_text
+		} elseif {$deletion_error_cnt == $path_cnt} {
+			error_popup [mc \
+				"None of the %d selected files could be deleted." \
+				$path_cnt \
+				]
+		} elseif {$deletion_error_cnt > 1} {
+			error_popup [mc \
+				"%d of the %d selected files could not be deleted." \
+				$deletion_error_cnt \
+				$path_cnt \
+				]
+		}
+
+		uplevel #0 $after
+	}
+}
+
+proc MAX_VERBOSE_FILES_IN_DELETION_ERROR {} { return 10; }
+
+# This function is from the TCL documentation:
+#
+#   https://wiki.tcl-lang.org/page/file+exists
+#
+# [file exists] returns false if the path does exist but is a symlink to a path
+# that doesn't exist. This proc returns true if the path exists, regardless of
+# whether it is a symlink and whether it is broken.
+proc path_exists {name} {
+	expr {![catch {file lstat $name finfo}]}
+}
+
+# Remove as many empty directories as we can starting at the specified path,
+# walking up the directory tree. If we encounter a directory that is not
+# empty, or if a directory deletion fails, then we stop the operation and
+# return to the caller. Even if this procedure fails to delete any
+# directories at all, it does not report failure.
+proc remove_empty_directories {directory_path} {
+	set parent_path [file dirname $directory_path]
+
+	while {$parent_path != $directory_path} {
+		set contents [glob -nocomplain -dir $directory_path *]
+
+		if {[llength $contents] > 0} { break }
+		if {[catch {file delete -- $directory_path}]} { break }
+
+		set directory_path $parent_path
+		set parent_path [file dirname $directory_path]
 	}
 }
 
@@ -466,19 +733,19 @@ proc do_revert_selection {} {
 }
 
 proc do_select_commit_type {} {
-	global commit_type selected_commit_type
+	global commit_type commit_type_is_amend
 
-	if {$selected_commit_type eq {new}
+	if {$commit_type_is_amend == 0
 		&& [string match amend* $commit_type]} {
 		create_new_commit
-	} elseif {$selected_commit_type eq {amend}
+	} elseif {$commit_type_is_amend == 1
 		&& ![string match amend* $commit_type]} {
 		load_last_commit
 
 		# The amend request was rejected...
 		#
 		if {![string match amend* $commit_type]} {
-			set selected_commit_type new
+			set commit_type_is_amend 0
 		}
 	}
 }
diff -pruN 1.2.1+git2.18.0-1/git/git-gui/lib/merge.tcl 1.2.3+git2.25.1-1/git/git-gui/lib/merge.tcl
--- 1.2.1+git2.18.0-1/git/git-gui/lib/merge.tcl	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/git-gui/lib/merge.tcl	2020-02-17 04:47:35.000000000 +0000
@@ -241,23 +241,27 @@ Continue with resetting the current chan
 	if {[ask_popup $op_question] eq {yes}} {
 		set fd [git_read --stderr read-tree --reset -u -v HEAD]
 		fconfigure $fd -blocking 0 -translation binary
-		fileevent $fd readable [namespace code [list _reset_wait $fd]]
-		$::main_status start [mc "Aborting"] [mc "files reset"]
+		set status_bar_operation [$::main_status \
+			start \
+			[mc "Aborting"] \
+			[mc "files reset"]
+		fileevent $fd readable [namespace code [list \
+			_reset_wait $fd $status_bar_operation]]
 	} else {
 		unlock_index
 	}
 }
 
-proc _reset_wait {fd} {
+proc _reset_wait {fd status_bar_operation} {
 	global ui_comm
 
-	$::main_status update_meter [read $fd]
+	$status_bar_operation update_meter [read $fd]
 
 	fconfigure $fd -blocking 1
 	if {[eof $fd]} {
 		set fail [catch {close $fd} err]
-		$::main_status stop
 		unlock_index
+		$status_bar_operation stop
 
 		$ui_comm delete 0.0 end
 		$ui_comm edit modified false
diff -pruN 1.2.1+git2.18.0-1/git/git-gui/lib/status_bar.tcl 1.2.3+git2.25.1-1/git/git-gui/lib/status_bar.tcl
--- 1.2.1+git2.18.0-1/git/git-gui/lib/status_bar.tcl	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/git-gui/lib/status_bar.tcl	2020-02-17 04:47:35.000000000 +0000
@@ -1,16 +1,42 @@
 # git-gui status bar mega-widget
 # Copyright (C) 2007 Shawn Pearce
 
+# The status_bar class manages the entire status bar. It is possible for
+# multiple overlapping asynchronous operations to want to display status
+# simultaneously. Each one receives a status_bar_operation when it calls the
+# start method, and the status bar combines all active operations into the
+# line of text it displays. Most of the time, there will be at most one
+# ongoing operation.
+#
+# Note that the entire status bar can be either in single-line or two-line
+# mode, depending on the constructor. Multiple active operations are only
+# supported for single-line status bars.
+
 class status_bar {
 
+field allow_multiple ; # configured at construction
+
 field w         ; # our own window path
 field w_l       ; # text widget we draw messages into
 field w_c       ; # canvas we draw a progress bar into
 field c_pack    ; # script to pack the canvas with
-field status  {}; # single line of text we show
-field prefix  {}; # text we format into status
-field units   {}; # unit of progress
-field meter   {}; # current core git progress meter (if active)
+
+field baseline_text   ; # text to show if there are no operations
+field status_bar_text ; # combined text for all operations
+
+field operations ; # list of current ongoing operations
+
+# The status bar can display a progress bar, updated when consumers call the
+# update method on their status_bar_operation. When there are multiple
+# operations, the status bar shows the combined status of all operations.
+#
+# When an overlapping operation completes, the progress bar is going to
+# abruptly have one fewer operation in the calculation, causing a discontinuity.
+# Therefore, whenever an operation completes, if it is not the last operation,
+# this counter is increased, and the progress bar is calculated as though there
+# were still another operation at 100%. When the last operation completes, this
+# is reset to 0.
+field completed_operation_count
 
 constructor new {path} {
 	global use_ttk NS
@@ -18,12 +44,19 @@ constructor new {path} {
 	set w_l $w.l
 	set w_c $w.c
 
+	# Standard single-line status bar: Permit overlapping operations
+	set allow_multiple 1
+
+	set baseline_text ""
+	set operations [list]
+	set completed_operation_count 0
+
 	${NS}::frame $w
 	if {!$use_ttk} {
 		$w configure -borderwidth 1 -relief sunken
 	}
 	${NS}::label $w_l \
-		-textvariable @status \
+		-textvariable @status_bar_text \
 		-anchor w \
 		-justify left
 	pack $w_l -side left
@@ -44,9 +77,16 @@ constructor two_line {path} {
 	set w_l $w.l
 	set w_c $w.c
 
+	# Two-line status bar: Only one ongoing operation permitted.
+	set allow_multiple 0
+
+	set baseline_text ""
+	set operations [list]
+	set completed_operation_count 0
+
 	${NS}::frame $w
 	${NS}::label $w_l \
-		-textvariable @status \
+		-textvariable @status_bar_text \
 		-anchor w \
 		-justify left
 	pack $w_l -anchor w -fill x
@@ -56,7 +96,7 @@ constructor two_line {path} {
 	return $this
 }
 
-method start {msg uds} {
+method ensure_canvas {} {
 	if {[winfo exists $w_c]} {
 		$w_c coords bar 0 0 0 20
 	} else {
@@ -68,31 +108,170 @@ method start {msg uds} {
 		$w_c create rectangle 0 0 0 20 -tags bar -fill navy
 		eval $c_pack
 	}
+}
+
+method show {msg} {
+	$this ensure_canvas
+	set baseline_text $msg
+	$this refresh
+}
+
+method start {msg {uds {}}} {
+	set baseline_text ""
+
+	if {!$allow_multiple && [llength $operations]} {
+		return [lindex $operations 0]
+	}
+
+	$this ensure_canvas
+
+	set operation [status_bar_operation::new $this $msg $uds]
+
+	lappend operations $operation
+
+	$this refresh
+
+	return $operation
+}
+
+method refresh {} {
+	set new_text ""
+
+	set total [expr $completed_operation_count * 100]
+	set have $total
+
+	foreach operation $operations {
+		if {$new_text != ""} {
+			append new_text " / "
+		}
+
+		append new_text [$operation get_status]
+
+		set total [expr $total + 100]
+		set have [expr $have + [$operation get_progress]]
+	}
+
+	if {$new_text == ""} {
+		set new_text $baseline_text
+	}
+
+	set status_bar_text $new_text
+
+	if {[winfo exists $w_c]} {
+		set pixel_width 0
+		if {$have > 0} {
+			set pixel_width [expr {[winfo width $w_c] * $have / $total}]
+		}
+
+		$w_c coords bar 0 0 $pixel_width 20
+	}
+}
+
+method stop {operation stop_msg} {
+	set idx [lsearch $operations $operation]
+
+	if {$idx >= 0} {
+		set operations [lreplace $operations $idx $idx]
+		set completed_operation_count [expr \
+			$completed_operation_count + 1]
+
+		if {[llength $operations] == 0} {
+			set completed_operation_count 0
+
+			destroy $w_c
+			if {$stop_msg ne {}} {
+				set baseline_text $stop_msg
+			}
+		}
+
+		$this refresh
+	}
+}
+
+method stop_all {{stop_msg {}}} {
+	# This makes the operation's call to stop a no-op.
+	set operations_copy $operations
+	set operations [list]
+
+	foreach operation $operations_copy {
+		$operation stop
+	}
+
+	if {$stop_msg ne {}} {
+		set baseline_text $stop_msg
+	}
+
+	$this refresh
+}
+
+method _delete {current} {
+	if {$current eq $w} {
+		delete_this
+	}
+}
+
+}
+
+# The status_bar_operation class tracks a single consumer's ongoing status bar
+# activity, with the context that there are a few situations where multiple
+# overlapping asynchronous operations might want to display status information
+# simultaneously. Instances of status_bar_operation are created by calling
+# start on the status_bar, and when the caller is done with its stauts bar
+# operation, it calls stop on the operation.
+
+class status_bar_operation {
+
+field status_bar; # reference back to the status_bar that owns this object
+
+field is_active;
+
+field status   {}; # single line of text we show
+field progress {}; # current progress (0 to 100)
+field prefix   {}; # text we format into status
+field units    {}; # unit of progress
+field meter    {}; # current core git progress meter (if active)
+
+constructor new {owner msg uds} {
+	set status_bar $owner
 
 	set status $msg
+	set progress 0
 	set prefix $msg
 	set units  $uds
 	set meter  {}
+
+	set is_active 1
+
+	return $this
 }
 
+method get_is_active {} { return $is_active }
+method get_status {} { return $status }
+method get_progress {} { return $progress }
+
 method update {have total} {
-	set pdone 0
-	set cdone 0
+	if {!$is_active} { return }
+
+	set progress 0
+
 	if {$total > 0} {
-		set pdone [expr {100 * $have / $total}]
-		set cdone [expr {[winfo width $w_c] * $have / $total}]
+		set progress [expr {100 * $have / $total}]
 	}
 
 	set prec [string length [format %i $total]]
+
 	set status [mc "%s ... %*i of %*i %s (%3i%%)" \
 		$prefix \
 		$prec $have \
 		$prec $total \
-		$units $pdone]
-	$w_c coords bar 0 0 $cdone 20
+		$units $progress]
+
+	$status_bar refresh
 }
 
 method update_meter {buf} {
+	if {!$is_active} { return }
+
 	append meter $buf
 	set r [string last "\r" $meter]
 	if {$r == -1} {
@@ -109,23 +288,25 @@ method update_meter {buf} {
 	}
 }
 
-method stop {{msg {}}} {
-	destroy $w_c
-	if {$msg ne {}} {
-		set status $msg
+method stop {{stop_msg {}}} {
+	if {$is_active} {
+		set is_active 0
+		$status_bar stop $this $stop_msg
 	}
 }
 
-method show {msg {test {}}} {
-	if {$test eq {} || $status eq $test} {
-		set status $msg
-	}
+method restart {msg} {
+	if {!$is_active} { return }
+
+	set status $msg
+	set prefix $msg
+	set meter {}
+	$status_bar refresh
 }
 
-method _delete {current} {
-	if {$current eq $w} {
-		delete_this
-	}
+method _delete {} {
+	stop
+	delete_this
 }
 
 }
diff -pruN 1.2.1+git2.18.0-1/git/git-gui/po/ja.po 1.2.3+git2.25.1-1/git/git-gui/po/ja.po
--- 1.2.1+git2.18.0-1/git/git-gui/po/ja.po	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/git-gui/po/ja.po	2020-02-17 04:47:35.000000000 +0000
@@ -4,14 +4,15 @@
 #
 # しらいし ななこ <nanako3@bluebottle.com>, 2007.
 # Satoshi Yasushima <s.yasushima@gmail.com>, 2016.
+# KIDANI Akito <a.kid.1985@gmail.com>, 2019.
 #
 msgid ""
 msgstr ""
 "Project-Id-Version: git-gui\n"
 "Report-Msgid-Bugs-To: \n"
 "POT-Creation-Date: 2016-05-27 17:52+0900\n"
-"PO-Revision-Date: 2016-06-22 12:50+0900\n"
-"Last-Translator: Satoshi Yasushima <s.yasushima@gmail.com>\n"
+"PO-Revision-Date: 2019-10-13 23:20+0900\n"
+"Last-Translator: KIDANI Akito <a.kid.1985@gmail.com>\n"
 "Language-Team: Japanese\n"
 "Language: ja\n"
 "MIME-Version: 1.0\n"
@@ -661,7 +662,7 @@ msgstr ""
 #: lib/merge.tcl:108
 #, tcl-format
 msgid "%s of %s"
-msgstr "%s の %s ブランチ"
+msgstr "%2$s の %1$s ブランチ"
 
 #: lib/merge.tcl:122
 #, tcl-format
@@ -956,7 +957,7 @@ msgstr "エラー: コマンドが失敗
 #: lib/checkout_op.tcl:85
 #, tcl-format
 msgid "Fetching %s from %s"
-msgstr "%s から %s をフェッチしています"
+msgstr "%2$s から %1$s をフェッチしています"
 
 #: lib/checkout_op.tcl:133
 #, tcl-format
diff -pruN 1.2.1+git2.18.0-1/git/git-gui/README.md 1.2.3+git2.25.1-1/git/git-gui/README.md
--- 1.2.1+git2.18.0-1/git/git-gui/README.md	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/git-gui/README.md	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,174 @@
+# Git GUI - A graphical user interface for Git
+
+Git GUI allows you to use the [Git source control management
+tools](https://git-scm.com/) via a GUI. This includes staging, committing,
+adding, pushing, etc. It can also be used as a blame viewer, a tree browser,
+and a citool (make exactly one commit before exiting and returning to shell).
+More details about Git GUI can be found in its manual page by either running
+`man git-gui`, or by visiting the [online manual
+page](https://git-scm.com/docs/git-gui).
+
+Git GUI was initially written by Shawn O. Pearce, and is distributed with the
+standard Git installation.
+
+# Building and installing
+
+You need to have the following dependencies installed before you begin:
+
+- Git
+- Tcl
+- Tk
+- wish
+- Gitk (needed for browsing history)
+- msgfmt
+
+Most of Git GUI is written in Tcl, so there is no compilation involved. Still,
+some things do need to be done (mostly some substitutions), so you do need to
+"build" it.
+
+You can build Git GUI using:
+
+```
+make
+```
+
+And then install it using:
+
+```
+make install
+```
+
+You probably need to have root/admin permissions to install.
+
+# Contributing
+
+The project is currently maintained by Pratyush Yadav over at
+https://github.com/prati0100/git-gui. Even though the project is hosted at
+GitHub, the development does not happen over GitHub Issues and Pull Requests.
+Instead, an email based workflow is used. The Git mailing list
+[git@vger.kernel.org](mailto:git@vger.kernel.org) is where the patches are
+discussed and reviewed.
+
+More information about the Git mailing list and instructions to subscribe can
+be found [here](https://git.wiki.kernel.org/index.php/GitCommunity).
+
+## Sending your changes
+
+Since the development happens over email, you need to send in your commits in
+text format. Commits can be converted to emails via the two tools provided by
+Git: `git-send-email` and `git-format-patch`.
+
+You can use `git-format-patch` to generate patches in mbox format from your
+commits that can then be sent via email. Let's say you are working on a branch
+called 'foo' that was created on top of 'master'. You can run:
+
+```
+git format-patch -o output_dir master..foo
+```
+
+to convert all the extra commits in 'foo' into a set of patches saved in the
+folder `output_dir`.
+
+If you are sending multiple patches, it is recommended to include a cover
+letter. A cover letter is an email explaining in brief what the series is
+supposed to do. A cover letter template can be generated by passing
+`--cover-letter` to `git-format-patch`.
+
+After you send your patches, you might get a review suggesting some changes.
+Make those changes, and re-send your patch(es) in reply to the first patch of
+your initial version. Also please mention the version of the patch. This can be
+done by passing `-v X` to `git-format-patch`, where 'X' is the version number
+of the patch(es).
+
+### Using git-send-email
+
+You can use `git-send-email` to send patches generated via `git-format-patch`.
+While you can directly send patches via `git-send-email`, it is recommended
+that you first use `git-format-patch` to generate the emails, audit them, and
+then send them via `git-send-email`.
+
+A pretty good guide to configuring and using `git-send-email` can be found
+[here](https://www.freedesktop.org/wiki/Software/PulseAudio/HowToUseGitSendEmail/)
+
+### Using your email client
+
+If your email client supports sending mbox format emails, you can use
+`git-format-patch` to get an mbox file for each commit, and then send them. If
+there is more than one patch in the series, then all patches after the first
+patch (or the cover letter) need to be sent as replies to the first.
+`git-send-email` does this by default.
+
+### Using GitGitGadget
+
+Since some people prefer a GitHub pull request based workflow, they can use
+[GitGitGadget](https://gitgitgadget.github.io/) to send in patches. The tool
+was originally written for sending patches to the Git project, but it now also
+supports sending patches for git-gui.
+
+Instructions for using GitGitGadget to send git-gui patches, courtesy of
+Johannes Schindelin:
+
+If you don't already have a fork of the [git/git](https://github.com/git/git)
+repo, you need to make one. Then clone your fork:
+
+```
+git clone https://github.com/<your-username>/git
+```
+
+Then add GitGitGadget as a remote:
+
+```
+git remote add gitgitgadget https://github.com/gitgitgadget/git
+```
+
+Then fetch the git-gui branch:
+
+```
+git fetch gitgitgadget git-gui/master
+```
+
+Then create a new branch based on git-gui/master:
+
+```
+git checkout -b <your-branch-name> git-gui/master
+```
+
+Make whatever commits you need to, push them to your fork, and then head over
+to https://github.com/gitgitgadget/git/pulls and open a Pull Request targeting
+git-gui/master.
+
+GitGitGadget will welcome you with a (hopefully) helpful message.
+
+## Signing off
+
+You need to sign off your commits before sending them to the list. You can do
+that by passing the `-s` option to `git-commit`. You can also use the "Sign
+Off" option in Git GUI.
+
+A sign-off is a simple 'Signed-off-by: A U Thor \<author@example.com\>' line at
+the end of the commit message, after your explanation of the commit.
+
+A sign-off means that you are legally allowed to send the code, and it serves
+as a certificate of origin. More information can be found at
+[developercertificate.org](https://developercertificate.org/).
+
+## Responding to review comments
+
+It is quite likely your patches will get review comments. Those comments are
+sent on the Git mailing list as replies to your patch, and you will usually be
+Cc'ed in those replies.
+
+You are expected to respond by either explaining your code further to convince
+the reviewer what you are doing is correct, or acknowledge the comments and
+re-send the patches with those comments addressed.
+
+Some tips for those not familiar with communication on a mailing list:
+
+- Use only plain text emails. No HTML at all.
+- Wrap lines at around 75 characters.
+- Do not send attachments. If you do need to send some files, consider using a
+  hosting service, and paste the link in your email.
+- Do not [top post](http://www.idallen.com/topposting.html).
+- Always "reply all". Keep all correspondents and the list in Cc. If you reply
+  directly to a reviewer, and not Cc the list, other people would not be able
+  to chime in.
diff -pruN 1.2.1+git2.18.0-1/git/git-gui/version 1.2.3+git2.25.1-1/git/git-gui/version
--- 1.2.1+git2.18.0-1/git/git-gui/version	2018-06-21 17:18:51.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/git-gui/version	2020-02-17 04:47:36.000000000 +0000
@@ -1 +1 @@
-0.21.GITGUI
+0.21.0.53.g0d211
diff -pruN 1.2.1+git2.18.0-1/git/.github/CONTRIBUTING.md 1.2.3+git2.25.1-1/git/.github/CONTRIBUTING.md
--- 1.2.1+git2.18.0-1/git/.github/CONTRIBUTING.md	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/.github/CONTRIBUTING.md	2020-02-17 04:47:35.000000000 +0000
@@ -5,7 +5,7 @@ Git community does not use github.com fo
 a mailing list (git@vger.kernel.org) for code submissions, code
 reviews, and bug reports.
 
-Nevertheless, you can use [submitGit](http://submitgit.herokuapp.com/) to
+Nevertheless, you can use [GitGitGadget](https://gitgitgadget.github.io/) to
 conveniently send your Pull Requests commits to our mailing list.
 
 Please read ["A note from the maintainer"](https://git.kernel.org/pub/scm/git/git.git/plain/MaintNotes?h=todo)
diff -pruN 1.2.1+git2.18.0-1/git/.github/PULL_REQUEST_TEMPLATE.md 1.2.3+git2.25.1-1/git/.github/PULL_REQUEST_TEMPLATE.md
--- 1.2.1+git2.18.0-1/git/.github/PULL_REQUEST_TEMPLATE.md	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/.github/PULL_REQUEST_TEMPLATE.md	2020-02-17 04:47:35.000000000 +0000
@@ -1,7 +1,7 @@
 Thanks for taking the time to contribute to Git! Please be advised that the
 Git community does not use github.com for their contributions. Instead, we use
 a mailing list (git@vger.kernel.org) for code submissions, code reviews, and
-bug reports. Nevertheless, you can use submitGit to conveniently send your Pull
-Requests commits to our mailing list.
+bug reports. Nevertheless, you can use GitGitGadget (https://gitgitgadget.github.io/)
+to conveniently send your Pull Requests commits to our mailing list.
 
 Please read the "guidelines for contributing" linked above!
diff -pruN 1.2.1+git2.18.0-1/git/.gitignore 1.2.3+git2.25.1-1/git/.gitignore
--- 1.2.1+git2.18.0-1/git/.gitignore	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/.gitignore	2020-02-17 04:47:35.000000000 +0000
@@ -1,3 +1,7 @@
+/fuzz-commit-graph
+/fuzz_corpora
+/fuzz-pack-headers
+/fuzz-pack-idx
 /GIT-BUILD-OPTIONS
 /GIT-CFLAGS
 /GIT-LDFLAGS
@@ -54,6 +58,7 @@
 /git-difftool
 /git-difftool--helper
 /git-describe
+/git-env--helper
 /git-fast-export
 /git-fast-import
 /git-fetch
@@ -78,6 +83,7 @@
 /git-init-db
 /git-interpret-trailers
 /git-instaweb
+/git-legacy-stash
 /git-log
 /git-ls-files
 /git-ls-remote
@@ -99,8 +105,9 @@
 /git-mergetool--lib
 /git-mktag
 /git-mktree
-/git-name-rev
+/git-multi-pack-index
 /git-mv
+/git-name-rev
 /git-notes
 /git-p4
 /git-pack-redundant
@@ -113,12 +120,10 @@
 /git-pull
 /git-push
 /git-quiltimport
+/git-range-diff
 /git-read-tree
 /git-rebase
-/git-rebase--am
-/git-rebase--helper
-/git-rebase--interactive
-/git-rebase--merge
+/git-rebase--preserve-merges
 /git-receive-pack
 /git-reflog
 /git-remote
@@ -128,7 +133,6 @@
 /git-remote-ftps
 /git-remote-fd
 /git-remote-ext
-/git-remote-testgit
 /git-remote-testpy
 /git-remote-testsvn
 /git-repack
@@ -136,6 +140,7 @@
 /git-request-pull
 /git-rerere
 /git-reset
+/git-restore
 /git-rev-list
 /git-rev-parse
 /git-revert
@@ -153,6 +158,7 @@
 /git-show-branch
 /git-show-index
 /git-show-ref
+/git-sparse-checkout
 /git-stage
 /git-stash
 /git-status
@@ -160,6 +166,7 @@
 /git-submodule
 /git-submodule--helper
 /git-svn
+/git-switch
 /git-symbolic-ref
 /git-tag
 /git-unpack-file
@@ -206,9 +213,11 @@
 /config.mak.autogen
 /config.mak.append
 /configure
+/.vscode/
 /tags
 /TAGS
 /cscope*
+*.hcc
 *.obj
 *.lib
 *.res
@@ -219,5 +228,14 @@
 *.user
 *.idb
 *.pdb
-/Debug/
-/Release/
+*.ilk
+*.iobj
+*.ipdb
+*.dll
+.vs/
+Debug/
+Release/
+/UpgradeLog*.htm
+/git.VC.VC.opendb
+/git.VC.db
+*.dSYM
diff -pruN 1.2.1+git2.18.0-1/git/git-instaweb.sh 1.2.3+git2.25.1-1/git/git-instaweb.sh
--- 1.2.1+git2.18.0-1/git/git-instaweb.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/git-instaweb.sh	2020-02-17 04:47:35.000000000 +0000
@@ -67,6 +67,13 @@ resolve_full_httpd () {
 		httpd_only="${httpd%% *}" # cut on first space
 		return
 		;;
+	*python*)
+		# server is started by running via generated gitweb.py in
+		# $fqgitdir/gitweb
+		full_httpd="$fqgitdir/gitweb/gitweb.py"
+		httpd_only="${httpd%% *}" # cut on first space
+		return
+		;;
 	esac
 
 	httpd_only="$(echo $httpd | cut -f1 -d' ')"
@@ -110,7 +117,7 @@ start_httpd () {
 
 	# don't quote $full_httpd, there can be arguments to it (-f)
 	case "$httpd" in
-	*mongoose*|*plackup*)
+	*mongoose*|*plackup*|*python*)
 		#These servers don't have a daemon mode so we'll have to fork it
 		$full_httpd "$conf" &
 		#Save the pid before doing anything else (we'll print it later)
@@ -326,13 +333,17 @@ EOF
 }
 
 apache2_conf () {
-	if test -z "$module_path"
-	then
-		test -d "/usr/lib/httpd/modules" &&
-			module_path="/usr/lib/httpd/modules"
-		test -d "/usr/lib/apache2/modules" &&
-			module_path="/usr/lib/apache2/modules"
-	fi
+	for candidate in \
+		/etc/httpd \
+		/usr/lib/apache2 \
+		/usr/lib/httpd ;
+	do
+		if test -d "$candidate/modules"
+		then
+			module_path="$candidate/modules"
+			break
+		fi
+	done
 	bind=
 	test x"$local" = xtrue && bind='127.0.0.1:'
 	echo 'text/css css' > "$fqgitdir/mime.types"
@@ -356,7 +367,7 @@ EOF
 			break
 		fi
 	done
-	for mod in mime dir env log_config authz_core
+	for mod in mime dir env log_config authz_core unixd
 	do
 		if test -e $module_path/mod_${mod}.so
 		then
@@ -591,6 +602,121 @@ EOF
 	rm -f "$conf"
 }
 
+python_conf() {
+	# Python's builtin http.server and its CGI support is very limited.
+	# CGI handler is capable of running CGI script only from inside a directory.
+	# Trying to set cgi_directories=["/"] will add double slash to SCRIPT_NAME
+	# and that in turn breaks gitweb's relative link generation.
+
+	# create a simple web root where $fqgitdir/gitweb/$httpd_only is our root
+	mkdir -p "$fqgitdir/gitweb/$httpd_only/cgi-bin"
+	# Python http.server follows the symlinks
+	ln -sf "$root/gitweb.cgi" "$fqgitdir/gitweb/$httpd_only/cgi-bin/gitweb.cgi"
+	ln -sf "$root/static" "$fqgitdir/gitweb/$httpd_only/"
+
+	# generate a standalone 'python http.server' script in $fqgitdir/gitweb
+	# This asumes that python is in user's $PATH
+	# This script is Python 2 and 3 compatible
+	cat > "$fqgitdir/gitweb/gitweb.py" <<EOF
+#!/usr/bin/env python
+import os
+import sys
+
+# Open log file in line buffering mode
+accesslogfile = open("$fqgitdir/gitweb/access.log", 'a', buffering=1)
+errorlogfile = open("$fqgitdir/gitweb/error.log", 'a', buffering=1)
+
+# and replace our stdout and stderr with log files
+# also do a lowlevel duplicate of the logfile file descriptors so that
+# our CGI child process writes any stderr warning also to the log file
+_orig_stdout_fd = sys.stdout.fileno()
+sys.stdout.close()
+os.dup2(accesslogfile.fileno(), _orig_stdout_fd)
+sys.stdout = accesslogfile
+
+_orig_stderr_fd = sys.stderr.fileno()
+sys.stderr.close()
+os.dup2(errorlogfile.fileno(), _orig_stderr_fd)
+sys.stderr = errorlogfile
+
+from functools import partial
+
+if sys.version_info < (3, 0):  # Python 2
+	from CGIHTTPServer import CGIHTTPRequestHandler
+	from BaseHTTPServer import HTTPServer as ServerClass
+else:  # Python 3
+	from http.server import CGIHTTPRequestHandler
+	from http.server import HTTPServer as ServerClass
+
+
+# Those environment variables will be passed to the cgi script
+os.environ.update({
+	"GIT_EXEC_PATH": "$GIT_EXEC_PATH",
+	"GIT_DIR": "$GIT_DIR",
+	"GITWEB_CONFIG": "$GITWEB_CONFIG"
+})
+
+
+class GitWebRequestHandler(CGIHTTPRequestHandler):
+
+	def log_message(self, format, *args):
+		# Write access logs to stdout
+		sys.stdout.write("%s - - [%s] %s\n" %
+				(self.address_string(),
+				self.log_date_time_string(),
+				format%args))
+
+	def do_HEAD(self):
+		self.redirect_path()
+		CGIHTTPRequestHandler.do_HEAD(self)
+
+	def do_GET(self):
+		if self.path == "/":
+			self.send_response(303, "See Other")
+			self.send_header("Location", "/cgi-bin/gitweb.cgi")
+			self.end_headers()
+			return
+		self.redirect_path()
+		CGIHTTPRequestHandler.do_GET(self)
+
+	def do_POST(self):
+		self.redirect_path()
+		CGIHTTPRequestHandler.do_POST(self)
+
+	# rewrite path of every request that is not gitweb.cgi to out of cgi-bin
+	def redirect_path(self):
+		if not self.path.startswith("/cgi-bin/gitweb.cgi"):
+			self.path = self.path.replace("/cgi-bin/", "/")
+
+	# gitweb.cgi is the only thing that is ever going to be run here.
+	# Ignore everything else
+	def is_cgi(self):
+		result = False
+		if self.path.startswith('/cgi-bin/gitweb.cgi'):
+			result = CGIHTTPRequestHandler.is_cgi(self)
+		return result
+
+
+bind = "127.0.0.1"
+if "$local" == "true":
+	bind = "0.0.0.0"
+
+# Set our http root directory
+# This is a work around for a missing directory argument in older Python versions
+# as this was added to SimpleHTTPRequestHandler in Python 3.7
+os.chdir("$fqgitdir/gitweb/$httpd_only/")
+
+GitWebRequestHandler.protocol_version = "HTTP/1.0"
+httpd = ServerClass((bind, $port), GitWebRequestHandler)
+
+sa = httpd.socket.getsockname()
+print("Serving HTTP on", sa[0], "port", sa[1], "...")
+httpd.serve_forever()
+EOF
+
+	chmod a+x "$fqgitdir/gitweb/gitweb.py"
+}
+
 gitweb_conf() {
 	cat > "$fqgitdir/gitweb/gitweb_config.perl" <<EOF
 #!@@PERL@@
@@ -619,6 +745,9 @@ configure_httpd() {
 	*plackup*)
 		plackup_conf
 		;;
+	*python*)
+		python_conf
+		;;
 	*)
 		echo "Unknown httpd specified: $httpd"
 		exit 1
diff -pruN 1.2.1+git2.18.0-1/git/gitk-git/gitk 1.2.3+git2.25.1-1/git/gitk-git/gitk
--- 1.2.1+git2.18.0-1/git/gitk-git/gitk	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/gitk-git/gitk	2020-02-17 04:47:35.000000000 +0000
@@ -3404,6 +3404,8 @@ set rectmask {
 }
 image create bitmap reficon-H -background black -foreground "#00ff00" \
     -data $rectdata -maskdata $rectmask
+image create bitmap reficon-R -background black -foreground "#ffddaa" \
+    -data $rectdata -maskdata $rectmask
 image create bitmap reficon-o -background black -foreground "#ddddff" \
     -data $rectdata -maskdata $rectmask
 
@@ -7016,6 +7018,7 @@ proc commit_descriptor {p} {
 
 # append some text to the ctext widget, and make any SHA1 ID
 # that we know about be a clickable link.
+# Also look for URLs of the form "http[s]://..." and make them web links.
 proc appendwithlinks {text tags} {
     global ctext linknum curview
 
@@ -7032,6 +7035,18 @@ proc appendwithlinks {text tags} {
 	setlink $linkid link$linknum
 	incr linknum
     }
+    set wlinks [regexp -indices -all -inline -line \
+		    {https?://[^[:space:]]+} $text]
+    foreach l $wlinks {
+	set s2 [lindex $l 0]
+	set e2 [lindex $l 1]
+	set url [string range $text $s2 $e2]
+	incr e2
+	$ctext tag delete link$linknum
+	$ctext tag add link$linknum "$start + $s2 c" "$start + $e2 c"
+	setwlink $url link$linknum
+	incr linknum
+    }
 }
 
 proc setlink {id lk} {
@@ -7064,6 +7079,18 @@ proc setlink {id lk} {
     }
 }
 
+proc setwlink {url lk} {
+    global ctext
+    global linkfgcolor
+    global web_browser
+
+    if {$web_browser eq {}} return
+    $ctext tag conf $lk -foreground $linkfgcolor -underline 1
+    $ctext tag bind $lk <1> [list browseweb $url]
+    $ctext tag bind $lk <Enter> {linkcursor %W 1}
+    $ctext tag bind $lk <Leave> {linkcursor %W -1}
+}
+
 proc appendshortlink {id {pre {}} {post {}}} {
     global ctext linknum
 
@@ -7098,6 +7125,16 @@ proc linkcursor {w inc} {
     }
 }
 
+proc browseweb {url} {
+    global web_browser
+
+    if {$web_browser eq {}} return
+    # Use eval here in case $web_browser is a command plus some arguments
+    if {[catch {eval exec $web_browser [list $url] &} err]} {
+	error_popup "[mc "Error starting web browser:"] $err"
+    }
+}
+
 proc viewnextline {dir} {
     global canv linespc
 
@@ -8191,11 +8228,11 @@ proc parseblobdiffline {ids line} {
 	} else {
 	    $ctext insert end "$line\n" filesep
 	}
-    } elseif {![string compare -length 3 "  >" $line]} {
+    } elseif {$currdiffsubmod != "" && ![string compare -length 3 "  >" $line]} {
 	set $currdiffsubmod ""
 	set line [encoding convertfrom $diffencoding $line]
 	$ctext insert end "$line\n" dresult
-    } elseif {![string compare -length 3 "  <" $line]} {
+    } elseif {$currdiffsubmod != "" && ![string compare -length 3 "  <" $line]} {
 	set $currdiffsubmod ""
 	set line [encoding convertfrom $diffencoding $line]
 	$ctext insert end "$line\n" d0
@@ -10022,6 +10059,7 @@ proc sel_reflist {w x y} {
     set n [lindex $ref 0]
     switch -- [lindex $ref 1] {
 	"H" {selbyid $headids($n)}
+	"R" {selbyid $headids($n)}
 	"T" {selbyid $tagids($n)}
 	"o" {selbyid $otherrefids($n)}
     }
@@ -10051,7 +10089,11 @@ proc refill_reflist {} {
     foreach n [array names headids] {
 	if {[string match $reflistfilter $n]} {
 	    if {[commitinview $headids($n) $curview]} {
-		lappend refs [list $n H]
+		if {[string match "remotes/*" $n]} {
+		    lappend refs [list $n R]
+		} else {
+		    lappend refs [list $n H]
+		}
 	    } else {
 		interestedin $headids($n) {run refill_reflist}
 	    }
@@ -11488,7 +11530,7 @@ proc create_prefs_page {w} {
 proc prefspage_general {notebook} {
     global NS maxwidth maxgraphpct showneartags showlocalchanges
     global tabstop limitdiffs autoselect autosellen extdifftool perfile_attrs
-    global hideremotes want_ttk have_ttk maxrefs
+    global hideremotes want_ttk have_ttk maxrefs web_browser
 
     set page [create_prefs_page $notebook.general]
 
@@ -11539,6 +11581,13 @@ proc prefspage_general {notebook} {
     pack configure $page.extdifff.l -padx 10
     grid x $page.extdifff $page.extdifft -sticky ew
 
+    ${NS}::entry $page.webbrowser -textvariable web_browser
+    ${NS}::frame $page.webbrowserf
+    ${NS}::label $page.webbrowserf.l -text [mc "Web browser" ]
+    pack $page.webbrowserf.l -side left
+    pack configure $page.webbrowserf.l -padx 10
+    grid x $page.webbrowserf $page.webbrowser -sticky ew
+
     ${NS}::label $page.lgen -text [mc "General options"]
     grid $page.lgen - -sticky w -pady 10
     ${NS}::checkbutton $page.want_ttk -variable want_ttk \
@@ -12310,6 +12359,7 @@ if {[tk windowingsystem] eq "win32"} {
     set bgcolor SystemWindow
     set fgcolor SystemWindowText
     set selectbgcolor SystemHighlight
+    set web_browser "cmd /c start"
 } else {
     set uicolor grey85
     set uifgcolor black
@@ -12317,6 +12367,11 @@ if {[tk windowingsystem] eq "win32"} {
     set bgcolor white
     set fgcolor black
     set selectbgcolor gray85
+    if {[tk windowingsystem] eq "aqua"} {
+	set web_browser "open"
+    } else {
+	set web_browser "xdg-open"
+    }
 }
 set diffcolors {red "#00a000" blue}
 set diffcontext 3
@@ -12390,6 +12445,7 @@ set config_variables {
     filesepbgcolor filesepfgcolor linehoverbgcolor linehoverfgcolor
     linehoveroutlinecolor mainheadcirclecolor workingfilescirclecolor
     indexcirclecolor circlecolors linkfgcolor circleoutlinecolor
+    web_browser
 }
 foreach var $config_variables {
     config_init_trace $var
diff -pruN 1.2.1+git2.18.0-1/git/gitk-git/po/bg.po 1.2.3+git2.25.1-1/git/gitk-git/po/bg.po
--- 1.2.1+git2.18.0-1/git/gitk-git/po/bg.po	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/gitk-git/po/bg.po	2020-02-17 04:47:35.000000000 +0000
@@ -1,15 +1,15 @@
 # Bulgarian translation of gitk po-file.
-# Copyright (C) 2014, 2015 Alexander Shopov <ash@kambanaria.org>.
+# Copyright (C) 2014, 2015, 2019 Alexander Shopov <ash@kambanaria.org>.
 # This file is distributed under the same license as the git package.
-# Alexander Shopov <ash@kambanaria.org>, 2014, 2015.
+# Alexander Shopov <ash@kambanaria.org>, 2014, 2015, 2019.
 #
 #
 msgid ""
 msgstr ""
 "Project-Id-Version: gitk master\n"
 "Report-Msgid-Bugs-To: \n"
-"POT-Creation-Date: 2015-12-19 11:48+0200\n"
-"PO-Revision-Date: 2015-12-19 11:49+0200\n"
+"POT-Creation-Date: 2019-03-04 11:27+0100\n"
+"PO-Revision-Date: 2019-03-04 11:39+0100\n"
 "Last-Translator: Alexander Shopov <ash@kambanaria.org>\n"
 "Language-Team: Bulgarian <dict@fsa-bg.org>\n"
 "Language: bg\n"
@@ -22,17 +22,17 @@ msgstr ""
 msgid "Couldn't get list of unmerged files:"
 msgstr "Списъкът с неслети файлове не може да бъде получен:"
 
-#: gitk:212 gitk:2399
+#: gitk:212 gitk:2403
 msgid "Color words"
 msgstr "Оцветяване на думите"
 
-#: gitk:217 gitk:2399 gitk:8239 gitk:8272
+#: gitk:217 gitk:2403 gitk:8249 gitk:8282
 msgid "Markup words"
 msgstr "Отбелязване на думите"
 
 #: gitk:324
 msgid "Error parsing revisions:"
-msgstr "Грешка при разбор на версиите:"
+msgstr "Грешка при анализ на версиите:"
 
 #: gitk:380
 msgid "Error executing --argscmd command:"
@@ -59,314 +59,318 @@ msgstr "Грешка при изпълн
 msgid "Reading"
 msgstr "Прочитане"
 
-#: gitk:496 gitk:4544
+#: gitk:496 gitk:4549
 msgid "Reading commits..."
 msgstr "Прочитане на подаванията…"
 
-#: gitk:499 gitk:1637 gitk:4547
+#: gitk:499 gitk:1641 gitk:4552
 msgid "No commits selected"
 msgstr "Не са избрани подавания"
 
-#: gitk:1445 gitk:4064 gitk:12469
+#: gitk:1449 gitk:4069 gitk:12583
 msgid "Command line"
 msgstr "Команден ред"
 
-#: gitk:1511
+#: gitk:1515
 msgid "Can't parse git log output:"
 msgstr "Изходът от „git log“ не може да се анализира:"
 
-#: gitk:1740
+#: gitk:1744
 msgid "No commit information available"
 msgstr "Липсва информация за подавания"
 
-#: gitk:1903 gitk:1932 gitk:4334 gitk:9702 gitk:11274 gitk:11554
+#: gitk:1907 gitk:1936 gitk:4339 gitk:9789 gitk:11388 gitk:11668
 msgid "OK"
 msgstr "Добре"
 
-#: gitk:1934 gitk:4336 gitk:9215 gitk:9294 gitk:9424 gitk:9473 gitk:9704
-#: gitk:11275 gitk:11555
+#: gitk:1938 gitk:4341 gitk:9225 gitk:9304 gitk:9434 gitk:9520 gitk:9791
+#: gitk:11389 gitk:11669
 msgid "Cancel"
 msgstr "Отказ"
 
-#: gitk:2083
+#: gitk:2087
 msgid "&Update"
 msgstr "&Обновяване"
 
-#: gitk:2084
+#: gitk:2088
 msgid "&Reload"
 msgstr "&Презареждане"
 
-#: gitk:2085
+#: gitk:2089
 msgid "Reread re&ferences"
-msgstr "&Наново прочитане на настройките"
+msgstr "&Наново прочитане"
 
-#: gitk:2086
+#: gitk:2090
 msgid "&List references"
 msgstr "&Изброяване на указателите"
 
-#: gitk:2088
+#: gitk:2092
 msgid "Start git &gui"
 msgstr "&Стартиране на „git gui“"
 
-#: gitk:2090
+#: gitk:2094
 msgid "&Quit"
 msgstr "&Спиране на програмата"
 
-#: gitk:2082
+#: gitk:2086
 msgid "&File"
 msgstr "&Файл"
 
-#: gitk:2094
+#: gitk:2098
 msgid "&Preferences"
 msgstr "&Настройки"
 
-#: gitk:2093
+#: gitk:2097
 msgid "&Edit"
 msgstr "&Редактиране"
 
-#: gitk:2098
+#: gitk:2102
 msgid "&New view..."
 msgstr "&Нов изглед…"
 
-#: gitk:2099
+#: gitk:2103
 msgid "&Edit view..."
 msgstr "&Редактиране на изгледа…"
 
-#: gitk:2100
+#: gitk:2104
 msgid "&Delete view"
 msgstr "&Изтриване на изгледа"
 
-#: gitk:2102
+#: gitk:2106
 msgid "&All files"
 msgstr "&Всички файлове"
 
-#: gitk:2097
+#: gitk:2101
 msgid "&View"
 msgstr "&Изглед"
 
-#: gitk:2107 gitk:2117
+#: gitk:2111 gitk:2121
 msgid "&About gitk"
 msgstr "&Относно gitk"
 
-#: gitk:2108 gitk:2122
+#: gitk:2112 gitk:2126
 msgid "&Key bindings"
 msgstr "&Клавишни комбинации"
 
-#: gitk:2106 gitk:2121
+#: gitk:2110 gitk:2125
 msgid "&Help"
 msgstr "Помо&щ"
 
-#: gitk:2199 gitk:8671
+#: gitk:2203 gitk:8681
 msgid "SHA1 ID:"
 msgstr "SHA1:"
 
-#: gitk:2243
+#: gitk:2247
 msgid "Row"
 msgstr "Ред"
 
-#: gitk:2281
+#: gitk:2285
 msgid "Find"
 msgstr "Търсене"
 
-#: gitk:2309
+#: gitk:2313
 msgid "commit"
 msgstr "подаване"
 
-#: gitk:2313 gitk:2315 gitk:4706 gitk:4729 gitk:4753 gitk:6774 gitk:6846
-#: gitk:6931
+#: gitk:2317 gitk:2319 gitk:4711 gitk:4734 gitk:4758 gitk:6779 gitk:6851
+#: gitk:6936
 msgid "containing:"
 msgstr "съдържащо:"
 
-#: gitk:2316 gitk:3545 gitk:3550 gitk:4782
+#: gitk:2320 gitk:3550 gitk:3555 gitk:4787
 msgid "touching paths:"
-msgstr "засягащо пътищата:"
+msgstr "в пътищата:"
 
-#: gitk:2317 gitk:4796
+#: gitk:2321 gitk:4801
 msgid "adding/removing string:"
 msgstr "добавящо/премахващо низ"
 
-#: gitk:2318 gitk:4798
+#: gitk:2322 gitk:4803
 msgid "changing lines matching:"
 msgstr "променящо редове напасващи:"
 
-#: gitk:2327 gitk:2329 gitk:4785
+#: gitk:2331 gitk:2333 gitk:4790
 msgid "Exact"
 msgstr "Точно"
 
-#: gitk:2329 gitk:4873 gitk:6742
+#: gitk:2333 gitk:4878 gitk:6747
 msgid "IgnCase"
 msgstr "Без регистър"
 
-#: gitk:2329 gitk:4755 gitk:4871 gitk:6738
+#: gitk:2333 gitk:4760 gitk:4876 gitk:6743
 msgid "Regexp"
 msgstr "Рег. израз"
 
-#: gitk:2331 gitk:2332 gitk:4893 gitk:4923 gitk:4930 gitk:6867 gitk:6935
+#: gitk:2335 gitk:2336 gitk:4898 gitk:4928 gitk:4935 gitk:6872 gitk:6940
 msgid "All fields"
 msgstr "Всички полета"
 
-#: gitk:2332 gitk:4890 gitk:4923 gitk:6805
+#: gitk:2336 gitk:4895 gitk:4928 gitk:6810
 msgid "Headline"
 msgstr "Първи ред"
 
-#: gitk:2333 gitk:4890 gitk:6805 gitk:6935 gitk:7408
+#: gitk:2337 gitk:4895 gitk:6810 gitk:6940 gitk:7413
 msgid "Comments"
 msgstr "Коментари"
 
-#: gitk:2333 gitk:4890 gitk:4895 gitk:4930 gitk:6805 gitk:7343 gitk:8849
-#: gitk:8864
+#: gitk:2337 gitk:4895 gitk:4900 gitk:4935 gitk:6810 gitk:7348 gitk:8859
+#: gitk:8874
 msgid "Author"
 msgstr "Автор"
 
-#: gitk:2333 gitk:4890 gitk:6805 gitk:7345
+#: gitk:2337 gitk:4895 gitk:6810 gitk:7350
 msgid "Committer"
 msgstr "Подаващ"
 
-#: gitk:2367
+#: gitk:2371
 msgid "Search"
 msgstr "Търсене"
 
-#: gitk:2375
+#: gitk:2379
 msgid "Diff"
 msgstr "Разлики"
 
-#: gitk:2377
+#: gitk:2381
 msgid "Old version"
 msgstr "Стара версия"
 
-#: gitk:2379
+#: gitk:2383
 msgid "New version"
 msgstr "Нова версия"
 
-#: gitk:2382
+#: gitk:2386
 msgid "Lines of context"
 msgstr "Контекст в редове"
 
-#: gitk:2392
+#: gitk:2396
 msgid "Ignore space change"
 msgstr "Празните знаци без значение"
 
-#: gitk:2396 gitk:2398 gitk:7978 gitk:8225
+#: gitk:2400 gitk:2402 gitk:7983 gitk:8235
 msgid "Line diff"
 msgstr "Поредови разлики"
 
-#: gitk:2463
+#: gitk:2467
 msgid "Patch"
 msgstr "Кръпка"
 
-#: gitk:2465
+#: gitk:2469
 msgid "Tree"
 msgstr "Дърво"
 
-#: gitk:2635 gitk:2656
+#: gitk:2639 gitk:2660
 msgid "Diff this -> selected"
 msgstr "Разлики между това и избраното"
 
-#: gitk:2636 gitk:2657
+#: gitk:2640 gitk:2661
 msgid "Diff selected -> this"
 msgstr "Разлики между избраното и това"
 
-#: gitk:2637 gitk:2658
+#: gitk:2641 gitk:2662
 msgid "Make patch"
 msgstr "Създаване на кръпка"
 
-#: gitk:2638 gitk:9273
+#: gitk:2642 gitk:9283
 msgid "Create tag"
 msgstr "Създаване на етикет"
 
-#: gitk:2639
+#: gitk:2643
 msgid "Copy commit summary"
 msgstr "Копиране на информацията за подаване"
 
-#: gitk:2640 gitk:9404
+#: gitk:2644 gitk:9414
 msgid "Write commit to file"
 msgstr "Запазване на подаването във файл"
 
-#: gitk:2641 gitk:9461
+#: gitk:2645
 msgid "Create new branch"
 msgstr "Създаване на нов клон"
 
-#: gitk:2642
+#: gitk:2646
 msgid "Cherry-pick this commit"
 msgstr "Отбиране на това подаване"
 
-#: gitk:2643
+#: gitk:2647
 msgid "Reset HEAD branch to here"
 msgstr "Привеждане на върха на клона към текущото подаване"
 
-#: gitk:2644
+#: gitk:2648
 msgid "Mark this commit"
 msgstr "Отбелязване на това подаване"
 
-#: gitk:2645
+#: gitk:2649
 msgid "Return to mark"
 msgstr "Връщане към отбелязаното подаване"
 
-#: gitk:2646
+#: gitk:2650
 msgid "Find descendant of this and mark"
 msgstr "Откриване и отбелязване на наследниците"
 
-#: gitk:2647
+#: gitk:2651
 msgid "Compare with marked commit"
 msgstr "Сравнение с отбелязаното подаване"
 
-#: gitk:2648 gitk:2659
+#: gitk:2652 gitk:2663
 msgid "Diff this -> marked commit"
 msgstr "Разлики между това и отбелязаното"
 
-#: gitk:2649 gitk:2660
+#: gitk:2653 gitk:2664
 msgid "Diff marked commit -> this"
 msgstr "Разлики между отбелязаното и това"
 
-#: gitk:2650
+#: gitk:2654
 msgid "Revert this commit"
 msgstr "Отмяна на това подаване"
 
-#: gitk:2666
+#: gitk:2670
 msgid "Check out this branch"
 msgstr "Изтегляне на този клон"
 
-#: gitk:2667
+#: gitk:2671
+msgid "Rename this branch"
+msgstr "Преименуване на този клон"
+
+#: gitk:2672
 msgid "Remove this branch"
 msgstr "Изтриване на този клон"
 
-#: gitk:2668
+#: gitk:2673
 msgid "Copy branch name"
 msgstr "Копиране на името на клона"
 
-#: gitk:2675
+#: gitk:2680
 msgid "Highlight this too"
 msgstr "Отбелязване и на това"
 
-#: gitk:2676
+#: gitk:2681
 msgid "Highlight this only"
 msgstr "Отбелязване само на това"
 
-#: gitk:2677
+#: gitk:2682
 msgid "External diff"
 msgstr "Външна програма за разлики"
 
-#: gitk:2678
+#: gitk:2683
 msgid "Blame parent commit"
 msgstr "Анотиране на родителското подаване"
 
-#: gitk:2679
+#: gitk:2684
 msgid "Copy path"
 msgstr "Копиране на пътя"
 
-#: gitk:2686
+#: gitk:2691
 msgid "Show origin of this line"
 msgstr "Показване на произхода на този ред"
 
-#: gitk:2687
+#: gitk:2692
 msgid "Run git gui blame on this line"
 msgstr "Изпълнение на „git gui blame“ върху този ред"
 
-#: gitk:3031
+#: gitk:3036
 msgid "About gitk"
 msgstr "Относно gitk"
 
-#: gitk:3033
+#: gitk:3038
 msgid ""
 "\n"
 "Gitk - a commit viewer for git\n"
@@ -382,324 +386,324 @@ msgstr ""
 "\n"
 "Използвайте и разпространявайте при условията на ОПЛ на ГНУ"
 
-#: gitk:3041 gitk:3108 gitk:9890
+#: gitk:3046 gitk:3113 gitk:10004
 msgid "Close"
 msgstr "Затваряне"
 
-#: gitk:3062
+#: gitk:3067
 msgid "Gitk key bindings"
 msgstr "Клавишни комбинации"
 
-#: gitk:3065
+#: gitk:3070
 msgid "Gitk key bindings:"
 msgstr "Клавишни комбинации:"
 
-#: gitk:3067
+#: gitk:3072
 #, tcl-format
 msgid "<%s-Q>\t\tQuit"
 msgstr "<%s-Q>\t\tСпиране на програмата"
 
-#: gitk:3068
+#: gitk:3073
 #, tcl-format
 msgid "<%s-W>\t\tClose window"
 msgstr "<%s-W>\t\tЗатваряне на прозореца"
 
-#: gitk:3069
+#: gitk:3074
 msgid "<Home>\t\tMove to first commit"
 msgstr "<Home>\t\tКъм първото подаване"
 
-#: gitk:3070
+#: gitk:3075
 msgid "<End>\t\tMove to last commit"
 msgstr "<End>\t\tКъм последното подаване"
 
-#: gitk:3071
+#: gitk:3076
 msgid "<Up>, p, k\tMove up one commit"
 msgstr "<Up>, p, k\tЕдно подаване нагоре"
 
-#: gitk:3072
+#: gitk:3077
 msgid "<Down>, n, j\tMove down one commit"
 msgstr "<Down>, n, j\tЕдно подаване надолу"
 
-#: gitk:3073
+#: gitk:3078
 msgid "<Left>, z, h\tGo back in history list"
 msgstr "<Left>, z, h\tНазад в историята"
 
-#: gitk:3074
+#: gitk:3079
 msgid "<Right>, x, l\tGo forward in history list"
 msgstr "<Right>, x, l\tНапред в историята"
 
-#: gitk:3075
+#: gitk:3080
 #, tcl-format
 msgid "<%s-n>\tGo to n-th parent of current commit in history list"
 msgstr "<%s-n>\tКъм n-тия родител на текущото подаване в историята"
 
-#: gitk:3076
+#: gitk:3081
 msgid "<PageUp>\tMove up one page in commit list"
 msgstr "<PageUp>\tСтраница нагоре в списъка с подаванията"
 
-#: gitk:3077
+#: gitk:3082
 msgid "<PageDown>\tMove down one page in commit list"
 msgstr "<PageDown>\tСтраница надолу в списъка с подаванията"
 
-#: gitk:3078
+#: gitk:3083
 #, tcl-format
 msgid "<%s-Home>\tScroll to top of commit list"
 msgstr "<%s-Home>\tКъм началото на списъка с подаванията"
 
-#: gitk:3079
+#: gitk:3084
 #, tcl-format
 msgid "<%s-End>\tScroll to bottom of commit list"
 msgstr "<%s-End>\tКъм края на списъка с подаванията"
 
-#: gitk:3080
+#: gitk:3085
 #, tcl-format
 msgid "<%s-Up>\tScroll commit list up one line"
 msgstr "<%s-Up>\tРед нагоре в списъка с подавания"
 
-#: gitk:3081
+#: gitk:3086
 #, tcl-format
 msgid "<%s-Down>\tScroll commit list down one line"
 msgstr "<%s-Down>\tРед надолу в списъка с подавания"
 
-#: gitk:3082
+#: gitk:3087
 #, tcl-format
 msgid "<%s-PageUp>\tScroll commit list up one page"
 msgstr "<%s-PageUp>\tСтраница нагоре в списъка с подавания"
 
-#: gitk:3083
+#: gitk:3088
 #, tcl-format
 msgid "<%s-PageDown>\tScroll commit list down one page"
 msgstr "<%s-PageDown>\tСтраница надолу в списъка с подавания"
 
-#: gitk:3084
+#: gitk:3089
 msgid "<Shift-Up>\tFind backwards (upwards, later commits)"
 msgstr "<Shift-Up>\tТърсене назад (визуално нагоре, исторически — последващи)"
 
-#: gitk:3085
+#: gitk:3090
 msgid "<Shift-Down>\tFind forwards (downwards, earlier commits)"
 msgstr ""
 "<Shift-Down>\tТърсене напред (визуално надолу, исторически — предхождащи)"
 
-#: gitk:3086
+#: gitk:3091
 msgid "<Delete>, b\tScroll diff view up one page"
 msgstr "<Delete>, b\tСтраница нагоре в изгледа за разлики"
 
-#: gitk:3087
+#: gitk:3092
 msgid "<Backspace>\tScroll diff view up one page"
 msgstr "<Backspace>\tСтраница надолу в изгледа за разлики"
 
-#: gitk:3088
+#: gitk:3093
 msgid "<Space>\t\tScroll diff view down one page"
 msgstr "<Space>\t\tСтраница надолу в изгледа за разлики"
 
-#: gitk:3089
+#: gitk:3094
 msgid "u\t\tScroll diff view up 18 lines"
 msgstr "u\t\t18 реда нагоре в изгледа за разлики"
 
-#: gitk:3090
+#: gitk:3095
 msgid "d\t\tScroll diff view down 18 lines"
 msgstr "d\t\t18 реда надолу в изгледа за разлики"
 
-#: gitk:3091
+#: gitk:3096
 #, tcl-format
 msgid "<%s-F>\t\tFind"
 msgstr "<%s-F>\t\tТърсене"
 
-#: gitk:3092
+#: gitk:3097
 #, tcl-format
 msgid "<%s-G>\t\tMove to next find hit"
 msgstr "<%s-G>\t\tКъм следващата поява"
 
-#: gitk:3093
+#: gitk:3098
 msgid "<Return>\tMove to next find hit"
 msgstr "<Return>\tКъм следващата поява"
 
-#: gitk:3094
+#: gitk:3099
 msgid "g\t\tGo to commit"
 msgstr "g\t\tКъм последното подаване"
 
-#: gitk:3095
+#: gitk:3100
 msgid "/\t\tFocus the search box"
 msgstr "/\t\tФокус върху полето за търсене"
 
-#: gitk:3096
+#: gitk:3101
 msgid "?\t\tMove to previous find hit"
 msgstr "?\t\tКъм предишната поява"
 
-#: gitk:3097
+#: gitk:3102
 msgid "f\t\tScroll diff view to next file"
 msgstr "f\t\tСледващ файл в изгледа за разлики"
 
-#: gitk:3098
+#: gitk:3103
 #, tcl-format
 msgid "<%s-S>\t\tSearch for next hit in diff view"
 msgstr "<%s-S>\t\tТърсене на следващата поява в изгледа за разлики"
 
-#: gitk:3099
+#: gitk:3104
 #, tcl-format
 msgid "<%s-R>\t\tSearch for previous hit in diff view"
 msgstr "<%s-R>\t\tТърсене на предишната поява в изгледа за разлики"
 
-#: gitk:3100
+#: gitk:3105
 #, tcl-format
 msgid "<%s-KP+>\tIncrease font size"
 msgstr "<%s-KP+>\tПо-голям размер на шрифта"
 
-#: gitk:3101
+#: gitk:3106
 #, tcl-format
 msgid "<%s-plus>\tIncrease font size"
 msgstr "<%s-plus>\tПо-голям размер на шрифта"
 
-#: gitk:3102
+#: gitk:3107
 #, tcl-format
 msgid "<%s-KP->\tDecrease font size"
 msgstr "<%s-KP->\tПо-малък размер на шрифта"
 
-#: gitk:3103
+#: gitk:3108
 #, tcl-format
 msgid "<%s-minus>\tDecrease font size"
 msgstr "<%s-minus>\tПо-малък размер на шрифта"
 
-#: gitk:3104
+#: gitk:3109
 msgid "<F5>\t\tUpdate"
 msgstr "<F5>\t\tОбновяване"
 
-#: gitk:3569 gitk:3578
+#: gitk:3574 gitk:3583
 #, tcl-format
 msgid "Error creating temporary directory %s:"
 msgstr "Грешка при създаването на временната директория „%s“:"
 
-#: gitk:3591
+#: gitk:3596
 #, tcl-format
 msgid "Error getting \"%s\" from %s:"
 msgstr "Грешка при получаването на „%s“ от %s:"
 
-#: gitk:3654
+#: gitk:3659
 msgid "command failed:"
 msgstr "неуспешно изпълнение на команда:"
 
-#: gitk:3803
+#: gitk:3808
 msgid "No such commit"
 msgstr "Такова подаване няма"
 
-#: gitk:3817
+#: gitk:3822
 msgid "git gui blame: command failed:"
 msgstr "„git gui blame“: неуспешно изпълнение на команда:"
 
-#: gitk:3848
+#: gitk:3853
 #, tcl-format
 msgid "Couldn't read merge head: %s"
 msgstr "Върхът за сливане не може да бъде прочетен: %s"
 
-#: gitk:3856
+#: gitk:3861
 #, tcl-format
 msgid "Error reading index: %s"
 msgstr "Грешка при прочитане на индекса: %s"
 
-#: gitk:3881
+#: gitk:3886
 #, tcl-format
 msgid "Couldn't start git blame: %s"
 msgstr "Командата „git blame“ не може да бъде стартирана: %s"
 
-#: gitk:3884 gitk:6773
+#: gitk:3889 gitk:6778
 msgid "Searching"
 msgstr "Търсене"
 
-#: gitk:3916
+#: gitk:3921
 #, tcl-format
 msgid "Error running git blame: %s"
 msgstr "Грешка при изпълнението на „git blame“: %s"
 
-#: gitk:3944
+#: gitk:3949
 #, tcl-format
 msgid "That line comes from commit %s,  which is not in this view"
 msgstr "Този ред идва от подаването %s, което не е в изгледа"
 
-#: gitk:3958
+#: gitk:3963
 msgid "External diff viewer failed:"
 msgstr "Неуспешно изпълнение на външната програма за разлики:"
 
-#: gitk:4062
+#: gitk:4067
 msgid "All files"
 msgstr "Всички файлове"
 
-#: gitk:4086
+#: gitk:4091
 msgid "View"
 msgstr "Изглед"
 
-#: gitk:4089
+#: gitk:4094
 msgid "Gitk view definition"
 msgstr "Дефиниция на изглед в Gitk"
 
-#: gitk:4093
+#: gitk:4098
 msgid "Remember this view"
 msgstr "Запазване на този изглед"
 
-#: gitk:4094
+#: gitk:4099
 msgid "References (space separated list):"
 msgstr "Указатели (списък с разделител интервал):"
 
-#: gitk:4095
+#: gitk:4100
 msgid "Branches & tags:"
 msgstr "Клони и етикети:"
 
-#: gitk:4096
+#: gitk:4101
 msgid "All refs"
 msgstr "Всички указатели"
 
-#: gitk:4097
+#: gitk:4102
 msgid "All (local) branches"
 msgstr "Всички (локални) клони"
 
-#: gitk:4098
+#: gitk:4103
 msgid "All tags"
 msgstr "Всички етикети"
 
-#: gitk:4099
+#: gitk:4104
 msgid "All remote-tracking branches"
 msgstr "Всички следящи клони"
 
-#: gitk:4100
+#: gitk:4105
 msgid "Commit Info (regular expressions):"
 msgstr "Информация за подаване (рег. изр.):"
 
-#: gitk:4101
+#: gitk:4106
 msgid "Author:"
 msgstr "Автор:"
 
-#: gitk:4102
+#: gitk:4107
 msgid "Committer:"
 msgstr "Подал:"
 
-#: gitk:4103
+#: gitk:4108
 msgid "Commit Message:"
 msgstr "Съобщение при подаване:"
 
-#: gitk:4104
+#: gitk:4109
 msgid "Matches all Commit Info criteria"
 msgstr "Съвпадение по всички характеристики на подаването"
 
-#: gitk:4105
+#: gitk:4110
 msgid "Matches no Commit Info criteria"
 msgstr "Не съвпада по никоя от характеристиките на подаването"
 
-#: gitk:4106
+#: gitk:4111
 msgid "Changes to Files:"
 msgstr "Промени по файловете:"
 
-#: gitk:4107
+#: gitk:4112
 msgid "Fixed String"
 msgstr "Дословен низ"
 
-#: gitk:4108
+#: gitk:4113
 msgid "Regular Expression"
 msgstr "Регулярен израз"
 
-#: gitk:4109
+#: gitk:4114
 msgid "Search string:"
 msgstr "Низ за търсене:"
 
-#: gitk:4110
+#: gitk:4115
 msgid ""
 "Commit Dates (\"2 weeks ago\", \"2009-03-17 15:27:38\", \"March 17, 2009 "
 "15:27:38\"):"
@@ -707,204 +711,204 @@ msgstr ""
 "Дата на подаване („2 weeks ago“ (преди 2 седмици), „2009-03-17 15:27:38“, "
 "„March 17, 2009 15:27:38“):"
 
-#: gitk:4111
+#: gitk:4116
 msgid "Since:"
 msgstr "От:"
 
-#: gitk:4112
+#: gitk:4117
 msgid "Until:"
 msgstr "До:"
 
-#: gitk:4113
+#: gitk:4118
 msgid "Limit and/or skip a number of revisions (positive integer):"
 msgstr ""
 "Ограничаване и/или прескачане на определен брой версии (неотрицателно цяло "
 "число):"
 
-#: gitk:4114
+#: gitk:4119
 msgid "Number to show:"
 msgstr "Брой показани:"
 
-#: gitk:4115
+#: gitk:4120
 msgid "Number to skip:"
 msgstr "Брой прескочени:"
 
-#: gitk:4116
+#: gitk:4121
 msgid "Miscellaneous options:"
 msgstr "Разни:"
 
-#: gitk:4117
+#: gitk:4122
 msgid "Strictly sort by date"
 msgstr "Подреждане по дата"
 
-#: gitk:4118
+#: gitk:4123
 msgid "Mark branch sides"
 msgstr "Отбелязване на страните по клона"
 
-#: gitk:4119
+#: gitk:4124
 msgid "Limit to first parent"
 msgstr "Само първия родител"
 
-#: gitk:4120
+#: gitk:4125
 msgid "Simple history"
 msgstr "Опростена история"
 
-#: gitk:4121
+#: gitk:4126
 msgid "Additional arguments to git log:"
 msgstr "Допълнителни аргументи към „git log“:"
 
-#: gitk:4122
+#: gitk:4127
 msgid "Enter files and directories to include, one per line:"
 msgstr "Въведете файловете и директориите за включване, по елемент на ред"
 
-#: gitk:4123
+#: gitk:4128
 msgid "Command to generate more commits to include:"
 msgstr ""
 "Команда за генерирането на допълнителни подавания, които да бъдат включени:"
 
-#: gitk:4247
+#: gitk:4252
 msgid "Gitk: edit view"
 msgstr "Gitk: редактиране на изглед"
 
-#: gitk:4255
+#: gitk:4260
 msgid "-- criteria for selecting revisions"
 msgstr "— критерии за избор на версии"
 
-#: gitk:4260
+#: gitk:4265
 msgid "View Name"
 msgstr "Име на изглед"
 
-#: gitk:4335
+#: gitk:4340
 msgid "Apply (F5)"
 msgstr "Прилагане (F5)"
 
-#: gitk:4373
+#: gitk:4378
 msgid "Error in commit selection arguments:"
 msgstr "Грешка в аргументите за избор на подавания:"
 
-#: gitk:4428 gitk:4481 gitk:4943 gitk:4957 gitk:6227 gitk:12410 gitk:12411
+#: gitk:4433 gitk:4486 gitk:4948 gitk:4962 gitk:6232 gitk:12524 gitk:12525
 msgid "None"
 msgstr "Няма"
 
-#: gitk:5040 gitk:5045
+#: gitk:5045 gitk:5050
 msgid "Descendant"
 msgstr "Наследник"
 
-#: gitk:5041
+#: gitk:5046
 msgid "Not descendant"
 msgstr "Не е наследник"
 
-#: gitk:5048 gitk:5053
+#: gitk:5053 gitk:5058
 msgid "Ancestor"
 msgstr "Предшественик"
 
-#: gitk:5049
+#: gitk:5054
 msgid "Not ancestor"
 msgstr "Не е предшественик"
 
-#: gitk:5343
+#: gitk:5348
 msgid "Local changes checked in to index but not committed"
 msgstr "Локални промени добавени към индекса, но неподадени"
 
-#: gitk:5379
+#: gitk:5384
 msgid "Local uncommitted changes, not checked in to index"
 msgstr "Локални промени извън индекса"
 
-#: gitk:7153
+#: gitk:7158
 msgid "and many more"
 msgstr "и още много"
 
-#: gitk:7156
+#: gitk:7161
 msgid "many"
 msgstr "много"
 
-#: gitk:7347
+#: gitk:7352
 msgid "Tags:"
 msgstr "Етикети:"
 
-#: gitk:7364 gitk:7370 gitk:8844
+#: gitk:7369 gitk:7375 gitk:8854
 msgid "Parent"
 msgstr "Родител"
 
-#: gitk:7375
+#: gitk:7380
 msgid "Child"
 msgstr "Дете"
 
-#: gitk:7384
+#: gitk:7389
 msgid "Branch"
 msgstr "Клон"
 
-#: gitk:7387
+#: gitk:7392
 msgid "Follows"
 msgstr "Следва"
 
-#: gitk:7390
+#: gitk:7395
 msgid "Precedes"
 msgstr "Предшества"
 
-#: gitk:7985
+#: gitk:7990
 #, tcl-format
 msgid "Error getting diffs: %s"
 msgstr "Грешка при получаването на разликите: %s"
 
-#: gitk:8669
+#: gitk:8679
 msgid "Goto:"
 msgstr "Към ред:"
 
-#: gitk:8690
+#: gitk:8700
 #, tcl-format
 msgid "Short SHA1 id %s is ambiguous"
 msgstr "Съкратената сума по SHA1 %s не е еднозначна"
 
-#: gitk:8697
+#: gitk:8707
 #, tcl-format
 msgid "Revision %s is not known"
 msgstr "Непозната версия %s"
 
-#: gitk:8707
+#: gitk:8717
 #, tcl-format
 msgid "SHA1 id %s is not known"
 msgstr "Непозната сума по SHA1 %s"
 
-#: gitk:8709
+#: gitk:8719
 #, tcl-format
 msgid "Revision %s is not in the current view"
 msgstr "Версия %s не е в текущия изглед"
 
-#: gitk:8851 gitk:8866
+#: gitk:8861 gitk:8876
 msgid "Date"
 msgstr "Дата"
 
-#: gitk:8854
+#: gitk:8864
 msgid "Children"
 msgstr "Деца"
 
-#: gitk:8917
+#: gitk:8927
 #, tcl-format
 msgid "Reset %s branch to here"
 msgstr "Зануляване на клона „%s“ към текущото подаване"
 
-#: gitk:8919
+#: gitk:8929
 msgid "Detached head: can't reset"
 msgstr "Несвързан връх: невъзможно зануляване"
 
-#: gitk:9024 gitk:9030
+#: gitk:9034 gitk:9040
 msgid "Skipping merge commit "
 msgstr "Пропускане на подаването на сливането"
 
-#: gitk:9039 gitk:9044
+#: gitk:9049 gitk:9054
 msgid "Error getting patch ID for "
 msgstr "Грешка при получаването на идентификатора на "
 
-#: gitk:9040 gitk:9045
+#: gitk:9050 gitk:9055
 msgid " - stopping\n"
 msgstr " — спиране\n"
 
-#: gitk:9050 gitk:9053 gitk:9061 gitk:9075 gitk:9084
+#: gitk:9060 gitk:9063 gitk:9071 gitk:9085 gitk:9094
 msgid "Commit "
 msgstr "Подаване"
 
-#: gitk:9054
+#: gitk:9064
 msgid ""
 " is the same patch as\n"
 "       "
@@ -912,7 +916,7 @@ msgstr ""
 " е същата кръпка като\n"
 "       "
 
-#: gitk:9062
+#: gitk:9072
 msgid ""
 " differs from\n"
 "       "
@@ -920,7 +924,7 @@ msgstr ""
 " се различава от\n"
 "       "
 
-#: gitk:9064
+#: gitk:9074
 msgid ""
 "Diff of commits:\n"
 "\n"
@@ -928,130 +932,147 @@ msgstr ""
 "Разлика между подаванията:\n"
 "\n"
 
-#: gitk:9076 gitk:9085
+#: gitk:9086 gitk:9095
 #, tcl-format
 msgid " has %s children - stopping\n"
 msgstr " има %s деца — спиране\n"
 
-#: gitk:9104
+#: gitk:9114
 #, tcl-format
 msgid "Error writing commit to file: %s"
 msgstr "Грешка при запазването на подаването във файл: %s"
 
-#: gitk:9110
+#: gitk:9120
 #, tcl-format
 msgid "Error diffing commits: %s"
 msgstr "Грешка при изчисляването на разликите между подаванията: %s"
 
-#: gitk:9156
+#: gitk:9166
 msgid "Top"
 msgstr "Най-горе"
 
-#: gitk:9157
+#: gitk:9167
 msgid "From"
 msgstr "От"
 
-#: gitk:9162
+#: gitk:9172
 msgid "To"
 msgstr "До"
 
-#: gitk:9186
+#: gitk:9196
 msgid "Generate patch"
 msgstr "Генериране на кръпка"
 
-#: gitk:9188
+#: gitk:9198
 msgid "From:"
 msgstr "От:"
 
-#: gitk:9197
+#: gitk:9207
 msgid "To:"
 msgstr "До:"
 
-#: gitk:9206
+#: gitk:9216
 msgid "Reverse"
 msgstr "Обръщане"
 
-#: gitk:9208 gitk:9418
+#: gitk:9218 gitk:9428
 msgid "Output file:"
 msgstr "Запазване във файла:"
 
-#: gitk:9214
+#: gitk:9224
 msgid "Generate"
 msgstr "Генериране"
 
-#: gitk:9252
+#: gitk:9262
 msgid "Error creating patch:"
 msgstr "Грешка при създаването на кръпка:"
 
-#: gitk:9275 gitk:9406 gitk:9463
+#: gitk:9285 gitk:9416 gitk:9504
 msgid "ID:"
 msgstr "Идентификатор:"
 
-#: gitk:9284
+#: gitk:9294
 msgid "Tag name:"
 msgstr "Име на етикет:"
 
-#: gitk:9287
+#: gitk:9297
 msgid "Tag message is optional"
 msgstr "Съобщението за етикет е незадължително"
 
-#: gitk:9289
+#: gitk:9299
 msgid "Tag message:"
 msgstr "Съобщение за етикет:"
 
-#: gitk:9293 gitk:9472
+#: gitk:9303 gitk:9474
 msgid "Create"
 msgstr "Създаване"
 
-#: gitk:9311
+#: gitk:9321
 msgid "No tag name specified"
 msgstr "Липсва име на етикет"
 
-#: gitk:9315
+#: gitk:9325
 #, tcl-format
 msgid "Tag \"%s\" already exists"
 msgstr "Етикетът „%s“ вече съществува"
 
-#: gitk:9325
+#: gitk:9335
 msgid "Error creating tag:"
 msgstr "Грешка при създаването на етикет:"
 
-#: gitk:9415
+#: gitk:9425
 msgid "Command:"
 msgstr "Команда:"
 
-#: gitk:9423
+#: gitk:9433
 msgid "Write"
 msgstr "Запазване"
 
-#: gitk:9441
+#: gitk:9451
 msgid "Error writing commit:"
 msgstr "Грешка при запазването на подаването:"
 
-#: gitk:9468
+#: gitk:9473
+msgid "Create branch"
+msgstr "Създаване на клон"
+
+#: gitk:9489
+#, tcl-format
+msgid "Rename branch %s"
+msgstr "Преименуване на клона „%s“"
+
+#: gitk:9490
+msgid "Rename"
+msgstr "Преименуване"
+
+#: gitk:9514
 msgid "Name:"
 msgstr "Име:"
 
-#: gitk:9491
+#: gitk:9538
 msgid "Please specify a name for the new branch"
 msgstr "Укажете име за новия клон"
 
-#: gitk:9496
+#: gitk:9543
 #, tcl-format
 msgid "Branch '%s' already exists. Overwrite?"
 msgstr "Клонът „%s“ вече съществува. Да бъде ли презаписан?"
 
-#: gitk:9563
+#: gitk:9587
+msgid "Please specify a new name for the branch"
+msgstr "Укажете ново име за клона"
+
+#: gitk:9650
 #, tcl-format
 msgid "Commit %s is already included in branch %s -- really re-apply it?"
 msgstr ""
 "Подаването „%s“ вече е включено в клона „%s“ — да бъде ли приложено отново?"
 
-#: gitk:9568
+#: gitk:9655
 msgid "Cherry-picking"
 msgstr "Отбиране"
 
-#: gitk:9577
+#: gitk:9664
 #, tcl-format
 msgid ""
 "Cherry-pick failed because of local changes to file '%s'.\n"
@@ -1060,7 +1081,7 @@ msgstr ""
 "Неуспешно отбиране, защото във файла „%s“ има локални промени.\n"
 "Подайте, занулете или ги скатайте и пробвайте отново."
 
-#: gitk:9583
+#: gitk:9670
 msgid ""
 "Cherry-pick failed because of merge conflict.\n"
 "Do you wish to run git citool to resolve it?"
@@ -1068,29 +1089,29 @@ msgstr ""
 "Неуспешно отбиране поради конфликти при сливане.\n"
 "Искате ли да ги коригирате чрез „git citool“?"
 
-#: gitk:9599 gitk:9657
+#: gitk:9686 gitk:9744
 msgid "No changes committed"
 msgstr "Не са подадени промени"
 
-#: gitk:9626
+#: gitk:9713
 #, tcl-format
 msgid "Commit %s is not included in branch %s -- really revert it?"
 msgstr "Подаването „%s“ не е включено в клона „%s“. Да бъде ли отменено?"
 
-#: gitk:9631
+#: gitk:9718
 msgid "Reverting"
 msgstr "Отмяна"
 
-#: gitk:9639
+#: gitk:9726
 #, tcl-format
 msgid ""
 "Revert failed because of local changes to the following files:%s Please "
 "commit, reset or stash  your changes and try again."
 msgstr ""
 "Неуспешна отмяна, защото във файла „%s“ има локални промени.\n"
-"Подайте, занулете или ги скатайте и пробвайте отново.<"
+"Подайте, занулете или ги скатайте и пробвайте отново."
 
-#: gitk:9643
+#: gitk:9730
 msgid ""
 "Revert failed because of merge conflict.\n"
 " Do you wish to run git citool to resolve it?"
@@ -1098,66 +1119,71 @@ msgstr ""
 "Неуспешно отмяна поради конфликти при сливане.\n"
 "Искате ли да ги коригирате чрез „git citool“?"
 
-#: gitk:9686
+#: gitk:9773
 msgid "Confirm reset"
 msgstr "Потвърждаване на зануляването"
 
-#: gitk:9688
+#: gitk:9775
 #, tcl-format
 msgid "Reset branch %s to %s?"
 msgstr "Да се занули ли клонът „%s“ към „%s“?"
 
-#: gitk:9690
+#: gitk:9777
 msgid "Reset type:"
 msgstr "Вид зануляване:"
 
-#: gitk:9693
+#: gitk:9780
 msgid "Soft: Leave working tree and index untouched"
 msgstr "Слабо: работното дърво и индекса остават същите"
 
-#: gitk:9696
+#: gitk:9783
 msgid "Mixed: Leave working tree untouched, reset index"
 msgstr "Смесено: работното дърво остава същото, индексът се занулява"
 
-#: gitk:9699
+#: gitk:9786
 msgid ""
 "Hard: Reset working tree and index\n"
 "(discard ALL local changes)"
 msgstr ""
 "Силно: зануляване и на работното дърво, и на индекса\n"
-"(*ВСИЧКИ* локални промени ще бъдат безвъзвратно загубени)"
+"(ВСИЧКИ локални промени ще бъдат безвъзвратно загубени)"
 
-#: gitk:9716
+#: gitk:9803
 msgid "Resetting"
 msgstr "Зануляване"
 
-#: gitk:9776
+#: gitk:9876
+#, tcl-format
+msgid "A local branch named %s exists already"
+msgstr "Вече съществува локален клон „%s“."
+
+#: gitk:9884
 msgid "Checking out"
 msgstr "Изтегляне"
 
-#: gitk:9829
+#: gitk:9943
 msgid "Cannot delete the currently checked-out branch"
 msgstr "Текущо изтегленият клон не може да бъде изтрит"
 
-#: gitk:9835
+#: gitk:9949
 #, tcl-format
 msgid ""
 "The commits on branch %s aren't on any other branch.\n"
 "Really delete branch %s?"
 msgstr ""
 "Подаванията на клона „%s“ не са на никой друг клон.\n"
-"Наистина ли да се изтрие клонът „%s“?"
+"Наистина ли искате да изтриете клона „%s“?"
 
-#: gitk:9866
+#: gitk:9980
 #, tcl-format
 msgid "Tags and heads: %s"
 msgstr "Етикети и върхове: %s"
 
-#: gitk:9883
+#: gitk:9997
 msgid "Filter"
 msgstr "Филтриране"
 
-#: gitk:10179
+#: gitk:10293
 msgid ""
 "Error reading commit topology information; branch and preceding/following "
 "tag information will be incomplete."
@@ -1165,201 +1191,201 @@ msgstr ""
 "Грешка при прочитането на топологията на подаванията. Информацията за клона "
 "и предшестващите/следващите етикети ще е непълна."
 
-#: gitk:11156
+#: gitk:11270
 msgid "Tag"
 msgstr "Етикет"
 
-#: gitk:11160
+#: gitk:11274
 msgid "Id"
 msgstr "Идентификатор"
 
-#: gitk:11243
+#: gitk:11357
 msgid "Gitk font chooser"
 msgstr "Избор на шрифт за Gitk"
 
-#: gitk:11260
+#: gitk:11374
 msgid "B"
 msgstr "Ч"
 
-#: gitk:11263
+#: gitk:11377
 msgid "I"
 msgstr "К"
 
-#: gitk:11381
+#: gitk:11495
 msgid "Commit list display options"
 msgstr "Настройки на списъка с подавания"
 
-#: gitk:11384
+#: gitk:11498
 msgid "Maximum graph width (lines)"
 msgstr "Максимална широчина на графа (в редове)"
 
-#: gitk:11388
+#: gitk:11502
 #, no-tcl-format
 msgid "Maximum graph width (% of pane)"
 msgstr "Максимална широчина на графа (% от панела)"
 
-#: gitk:11391
+#: gitk:11505
 msgid "Show local changes"
 msgstr "Показване на локалните промени"
 
-#: gitk:11394
+#: gitk:11508
 msgid "Auto-select SHA1 (length)"
 msgstr "Автоматично избиране на SHA1 (дължина)"
 
-#: gitk:11398
+#: gitk:11512
 msgid "Hide remote refs"
 msgstr "Скриване на отдалечените указатели"
 
-#: gitk:11402
+#: gitk:11516
 msgid "Diff display options"
 msgstr "Настройки на показването на разликите"
 
-#: gitk:11404
+#: gitk:11518
 msgid "Tab spacing"
 msgstr "Широчина на табулатора"
 
-#: gitk:11407
+#: gitk:11521
 msgid "Display nearby tags/heads"
 msgstr "Извеждане на близките етикети и върхове"
 
-#: gitk:11410
+#: gitk:11524
 msgid "Maximum # tags/heads to show"
 msgstr "Максимален брой етикети/върхове за показване"
 
-#: gitk:11413
+#: gitk:11527
 msgid "Limit diffs to listed paths"
 msgstr "Разлика само в избраните пътища"
 
-#: gitk:11416
+#: gitk:11530
 msgid "Support per-file encodings"
 msgstr "Поддръжка на различни кодирания за всеки файл"
 
-#: gitk:11422 gitk:11569
+#: gitk:11536 gitk:11683
 msgid "External diff tool"
 msgstr "Външен инструмент за разлики"
 
-#: gitk:11423
+#: gitk:11537
 msgid "Choose..."
 msgstr "Избор…"
 
-#: gitk:11428
+#: gitk:11542
 msgid "General options"
 msgstr "Общи настройки"
 
-#: gitk:11431
+#: gitk:11545
 msgid "Use themed widgets"
 msgstr "Използване на тема за графичните обекти"
 
-#: gitk:11433
+#: gitk:11547
 msgid "(change requires restart)"
 msgstr "(промяната изисква рестартиране на Gitk)"
 
-#: gitk:11435
+#: gitk:11549
 msgid "(currently unavailable)"
 msgstr "(в момента недостъпно)"
 
-#: gitk:11446
+#: gitk:11560
 msgid "Colors: press to choose"
 msgstr "Цветове: избира се с натискане"
 
-#: gitk:11449
+#: gitk:11563
 msgid "Interface"
 msgstr "Интерфейс"
 
-#: gitk:11450
+#: gitk:11564
 msgid "interface"
 msgstr "интерфейс"
 
-#: gitk:11453
+#: gitk:11567
 msgid "Background"
 msgstr "Фон"
 
-#: gitk:11454 gitk:11484
+#: gitk:11568 gitk:11598
 msgid "background"
 msgstr "фон"
 
-#: gitk:11457
+#: gitk:11571
 msgid "Foreground"
 msgstr "Знаци"
 
-#: gitk:11458
+#: gitk:11572
 msgid "foreground"
 msgstr "знаци"
 
-#: gitk:11461
+#: gitk:11575
 msgid "Diff: old lines"
 msgstr "Разлика: стари редове"
 
-#: gitk:11462
+#: gitk:11576
 msgid "diff old lines"
 msgstr "разлика, стари редове"
 
-#: gitk:11466
+#: gitk:11580
 msgid "Diff: new lines"
 msgstr "Разлика: нови редове"
 
-#: gitk:11467
+#: gitk:11581
 msgid "diff new lines"
 msgstr "разлика, нови редове"
 
-#: gitk:11471
+#: gitk:11585
 msgid "Diff: hunk header"
 msgstr "Разлика: начало на парче"
 
-#: gitk:11473
+#: gitk:11587
 msgid "diff hunk header"
 msgstr "разлика, начало на парче"
 
-#: gitk:11477
+#: gitk:11591
 msgid "Marked line bg"
 msgstr "Фон на отбелязан ред"
 
-#: gitk:11479
+#: gitk:11593
 msgid "marked line background"
 msgstr "фон на отбелязан ред"
 
-#: gitk:11483
+#: gitk:11597
 msgid "Select bg"
 msgstr "Избор на фон"
 
-#: gitk:11492
+#: gitk:11606
 msgid "Fonts: press to choose"
 msgstr "Шрифтове: избира се с натискане"
 
-#: gitk:11494
+#: gitk:11608
 msgid "Main font"
 msgstr "Основен шрифт"
 
-#: gitk:11495
+#: gitk:11609
 msgid "Diff display font"
 msgstr "Шрифт за разликите"
 
-#: gitk:11496
+#: gitk:11610
 msgid "User interface font"
 msgstr "Шрифт на интерфейса"
 
-#: gitk:11518
+#: gitk:11632
 msgid "Gitk preferences"
 msgstr "Настройки на Gitk"
 
-#: gitk:11527
+#: gitk:11641
 msgid "General"
 msgstr "Общи"
 
-#: gitk:11528
+#: gitk:11642
 msgid "Colors"
 msgstr "Цветове"
 
-#: gitk:11529
+#: gitk:11643
 msgid "Fonts"
 msgstr "Шрифтове"
 
-#: gitk:11579
+#: gitk:11693
 #, tcl-format
 msgid "Gitk: choose color for %s"
 msgstr "Gitk: избор на цвят на „%s“"
 
-#: gitk:12092
+#: gitk:12206
 msgid ""
 "Sorry, gitk cannot run with this version of Tcl/Tk.\n"
 " Gitk requires at least Tcl/Tk 8.4."
@@ -1367,15 +1393,15 @@ msgstr ""
 "Тази версия на Tcl/Tk не се поддържа от Gitk.\n"
 " Необходима ви е поне Tcl/Tk 8.4."
 
-#: gitk:12302
+#: gitk:12416
 msgid "Cannot find a git repository here."
 msgstr "Тук липсва хранилище на Git."
 
-#: gitk:12349
+#: gitk:12463
 #, tcl-format
 msgid "Ambiguous argument '%s': both revision and filename"
 msgstr "Нееднозначен аргумент „%s“: има и такава версия, и такъв файл"
 
-#: gitk:12361
+#: gitk:12475
 msgid "Bad arguments to gitk:"
 msgstr "Неправилни аргументи на gitk:"
diff -pruN 1.2.1+git2.18.0-1/git/gitk-git/po/zh_cn.po 1.2.3+git2.25.1-1/git/gitk-git/po/zh_cn.po
--- 1.2.1+git2.18.0-1/git/gitk-git/po/zh_cn.po	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/gitk-git/po/zh_cn.po	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,1367 @@
+# Translation of gitk to Simplified Chinese.
+#
+# Translators:
+# YanKe <imyanke@163.com>, 2017
+
+msgid ""
+msgstr ""
+"Project-Id-Version: Git Chinese Localization Project\n"
+"Report-Msgid-Bugs-To: \n"
+"POT-Creation-Date: 2017-02-28 23:11+0800\n"
+"PO-Revision-Date: 2017-03-11 02:27+0800\n"
+"Last-Translator: YanKe <imyanke@163.com>\n"
+"Language-Team: Chinese\n"
+"MIME-Version: 1.0\n"
+"Content-Type: text/plain; charset=UTF-8\n"
+"Content-Transfer-Encoding: 8bit\n"
+"Language: zh_CN\n"
+
+#: gitk:140
+msgid "Couldn't get list of unmerged files:"
+msgstr "不能获取未合并文件列表："
+
+#: gitk:212 gitk:2403
+msgid "Color words"
+msgstr "着色显示差异"
+
+#: gitk:217 gitk:2403 gitk:8249 gitk:8282
+msgid "Markup words"
+msgstr "标记显示差异"
+
+#: gitk:324
+msgid "Error parsing revisions:"
+msgstr "解析版本错误："
+
+#: gitk:380
+msgid "Error executing --argscmd command:"
+msgstr "运行 --argscmd命令出错"
+
+#: gitk:393
+msgid "No files selected: --merge specified but no files are unmerged."
+msgstr "没有选中文件：--指定merge参数但没有未合并的文件。"
+
+#: gitk:396
+msgid ""
+"No files selected: --merge specified but no unmerged files are within file "
+"limit."
+msgstr "没有选中文件：--指定merge参数但没有未合并的文件在文件中"
+
+#: gitk:418 gitk:566
+msgid "Error executing git log:"
+msgstr "执行git log命令出错："
+
+#: gitk:436 gitk:582
+msgid "Reading"
+msgstr "读取中"
+
+#: gitk:496 gitk:4549
+msgid "Reading commits..."
+msgstr "提交记录读取中..."
+
+#: gitk:499 gitk:1641 gitk:4552
+msgid "No commits selected"
+msgstr "未选中任何提交"
+
+#: gitk:1449 gitk:4069 gitk:12583
+msgid "Command line"
+msgstr "命令行"
+
+#: gitk:1515
+msgid "Can't parse git log output:"
+msgstr "不能解析git log输出："
+
+#: gitk:1744
+msgid "No commit information available"
+msgstr "无可用提交信息"
+
+#: gitk:1907 gitk:1936 gitk:4339 gitk:9789 gitk:11388 gitk:11668
+msgid "OK"
+msgstr "确定"
+
+#: gitk:1938 gitk:4341 gitk:9225 gitk:9304 gitk:9434 gitk:9520 gitk:9791
+#: gitk:11389 gitk:11669
+msgid "Cancel"
+msgstr "取消"
+
+#: gitk:2087
+msgid "&Update"
+msgstr "更新"
+
+#: gitk:2088
+msgid "&Reload"
+msgstr "重新加载"
+
+#: gitk:2089
+msgid "Reread re&ferences"
+msgstr "重新读取引用"
+
+#: gitk:2090
+msgid "&List references"
+msgstr "列出引用(分支以及tag)"
+
+#: gitk:2092
+msgid "Start git &gui"
+msgstr "启动git gui客户端"
+
+#: gitk:2094
+msgid "&Quit"
+msgstr "退出"
+
+#: gitk:2086
+msgid "&File"
+msgstr "文件"
+
+#: gitk:2098
+msgid "&Preferences"
+msgstr "偏好设置"
+
+#: gitk:2097
+msgid "&Edit"
+msgstr "编辑"
+
+#: gitk:2102
+msgid "&New view..."
+msgstr "新视图..."
+
+#: gitk:2103
+msgid "&Edit view..."
+msgstr "编辑视图..."
+
+#: gitk:2104
+msgid "&Delete view"
+msgstr "删除视图"
+
+#: gitk:2106
+msgid "&All files"
+msgstr "所有文件"
+
+#: gitk:2101
+msgid "&View"
+msgstr "视图"
+
+#: gitk:2111 gitk:2121
+msgid "&About gitk"
+msgstr "关于gitk"
+
+#: gitk:2112 gitk:2126
+msgid "&Key bindings"
+msgstr "快捷键"
+
+#: gitk:2110 gitk:2125
+msgid "&Help"
+msgstr "帮助"
+
+#: gitk:2203 gitk:8681
+msgid "SHA1 ID:"
+msgstr "SHA1 ID："
+
+#: gitk:2247
+msgid "Row"
+msgstr "行"
+
+#: gitk:2285
+msgid "Find"
+msgstr "查找"
+
+#: gitk:2313
+msgid "commit"
+msgstr "提交"
+
+#: gitk:2317 gitk:2319 gitk:4711 gitk:4734 gitk:4758 gitk:6779 gitk:6851
+#: gitk:6936
+msgid "containing:"
+msgstr "包含："
+
+#: gitk:2320 gitk:3550 gitk:3555 gitk:4787
+msgid "touching paths:"
+msgstr "影响路径："
+
+#: gitk:2321 gitk:4801
+msgid "adding/removing string:"
+msgstr "增加/删除字符串："
+
+#: gitk:2322 gitk:4803
+msgid "changing lines matching:"
+msgstr "改变行匹配："
+
+#: gitk:2331 gitk:2333 gitk:4790
+msgid "Exact"
+msgstr "精确匹配"
+
+#: gitk:2333 gitk:4878 gitk:6747
+msgid "IgnCase"
+msgstr "忽略大小写"
+
+#: gitk:2333 gitk:4760 gitk:4876 gitk:6743
+msgid "Regexp"
+msgstr "正则"
+
+#: gitk:2335 gitk:2336 gitk:4898 gitk:4928 gitk:4935 gitk:6872 gitk:6940
+msgid "All fields"
+msgstr "所有字段"
+
+#: gitk:2336 gitk:4895 gitk:4928 gitk:6810
+msgid "Headline"
+msgstr "标题"
+
+#: gitk:2337 gitk:4895 gitk:6810 gitk:6940 gitk:7413
+msgid "Comments"
+msgstr "提交注释"
+
+#: gitk:2337 gitk:4895 gitk:4900 gitk:4935 gitk:6810 gitk:7348 gitk:8859
+#: gitk:8874
+msgid "Author"
+msgstr "作者"
+
+#: gitk:2337 gitk:4895 gitk:6810 gitk:7350
+msgid "Committer"
+msgstr "提交者"
+
+#: gitk:2371
+msgid "Search"
+msgstr "搜索"
+
+#: gitk:2379
+msgid "Diff"
+msgstr "差异"
+
+#: gitk:2381
+msgid "Old version"
+msgstr "老版本"
+
+#: gitk:2383
+msgid "New version"
+msgstr "新版本"
+
+#: gitk:2386
+msgid "Lines of context"
+msgstr "Diff上下文显示行数"
+
+#: gitk:2396
+msgid "Ignore space change"
+msgstr "忽略空格修改"
+
+#: gitk:2400 gitk:2402 gitk:7983 gitk:8235
+msgid "Line diff"
+msgstr "按行显示差异"
+
+#: gitk:2467
+msgid "Patch"
+msgstr "补丁"
+
+#: gitk:2469
+msgid "Tree"
+msgstr "树"
+
+#: gitk:2639 gitk:2660
+msgid "Diff this -> selected"
+msgstr "比较从当前提交到选中提交的差异"
+
+#: gitk:2640 gitk:2661
+msgid "Diff selected -> this"
+msgstr "比较从选中提交到当前提交的差异"
+
+#: gitk:2641 gitk:2662
+msgid "Make patch"
+msgstr "制作补丁"
+
+#: gitk:2642 gitk:9283
+msgid "Create tag"
+msgstr "创建tag"
+
+#: gitk:2643
+msgid "Copy commit summary"
+msgstr "复制提交摘要"
+
+#: gitk:2644 gitk:9414
+msgid "Write commit to file"
+msgstr "写入提交到文件"
+
+#: gitk:2645
+msgid "Create new branch"
+msgstr "创建新分支"
+
+#: gitk:2646
+msgid "Cherry-pick this commit"
+msgstr "在此提交运用补丁(cherry-pick)命令"
+
+#: gitk:2647
+msgid "Reset HEAD branch to here"
+msgstr "将分支头(HEAD)重置到此处"
+
+#: gitk:2648
+msgid "Mark this commit"
+msgstr "标记此提交"
+
+#: gitk:2649
+msgid "Return to mark"
+msgstr "返回到标记"
+
+#: gitk:2650
+msgid "Find descendant of this and mark"
+msgstr "查找本次提交的子提交并标记"
+
+#: gitk:2651
+msgid "Compare with marked commit"
+msgstr "和已标记的提交作比较"
+
+#: gitk:2652 gitk:2663
+msgid "Diff this -> marked commit"
+msgstr "比较从当前提交到已标记提交的差异"
+
+#: gitk:2653 gitk:2664
+msgid "Diff marked commit -> this"
+msgstr "比较从已标记提交到当前提交的差异"
+
+#: gitk:2654
+msgid "Revert this commit"
+msgstr "撤销(revert)此提交"
+
+#: gitk:2670
+msgid "Check out this branch"
+msgstr "检出(checkout)此分支"
+
+#: gitk:2671
+msgid "Rename this branch"
+msgstr "重命名(Rename)此分支"
+
+#: gitk:2672
+msgid "Remove this branch"
+msgstr "删除(Remove)此分支"
+
+#: gitk:2673
+msgid "Copy branch name"
+msgstr "复制分支名称"
+
+#: gitk:2680
+msgid "Highlight this too"
+msgstr "高亮此处"
+
+#: gitk:2681
+msgid "Highlight this only"
+msgstr "只高亮此处"
+
+#: gitk:2682
+msgid "External diff"
+msgstr "外部diff"
+
+#: gitk:2683
+msgid "Blame parent commit"
+msgstr "Blame父提交"
+
+#: gitk:2684
+msgid "Copy path"
+msgstr "复制路径"
+
+#: gitk:2691
+msgid "Show origin of this line"
+msgstr "显示此行原始提交"
+
+#: gitk:2692
+msgid "Run git gui blame on this line"
+msgstr "在此行运行git gui客户端的blame"
+
+#: gitk:3036
+msgid "About gitk"
+msgstr "关于gitk"
+
+#: gitk:3038
+msgid ""
+"\n"
+"Gitk - a commit viewer for git\n"
+"\n"
+"Copyright © 2005-2016 Paul Mackerras\n"
+"\n"
+"Use and redistribute under the terms of the GNU General Public License"
+msgstr "\nGitk — 一个git的提交查看器\n\n© 2005-2016 Paul Mackerras\n\n在GNU许可证下使用以及分发"
+
+#: gitk:3046 gitk:3113 gitk:10004
+msgid "Close"
+msgstr "关闭"
+
+#: gitk:3067
+msgid "Gitk key bindings"
+msgstr "Gitk快捷键"
+
+#: gitk:3070
+msgid "Gitk key bindings:"
+msgstr "Gitk快捷键："
+
+#: gitk:3072
+#, tcl-format
+msgid "<%s-Q>\t\tQuit"
+msgstr "<%s-Q>\t\t退出"
+
+#: gitk:3073
+#, tcl-format
+msgid "<%s-W>\t\tClose window"
+msgstr "<%s-W>\t\t关闭窗口"
+
+#: gitk:3074
+msgid "<Home>\t\tMove to first commit"
+msgstr "<Home>\t\t移动到第一次提交"
+
+#: gitk:3075
+msgid "<End>\t\tMove to last commit"
+msgstr "<End>\t\t移动到最后一次提交"
+
+#: gitk:3076
+msgid "<Up>, p, k\tMove up one commit"
+msgstr "<Up>, p, k\t移动到上一次提交"
+
+#: gitk:3077
+msgid "<Down>, n, j\tMove down one commit"
+msgstr "<Down>, n, j\t移动到下一次提交"
+
+#: gitk:3078
+msgid "<Left>, z, h\tGo back in history list"
+msgstr "<Left>, z, h\t历史列表的上一项"
+
+#: gitk:3079
+msgid "<Right>, x, l\tGo forward in history list"
+msgstr "<Right>, x, l\t历史列表的下一项"
+
+#: gitk:3080
+#, tcl-format
+msgid "<%s-n>\tGo to n-th parent of current commit in history list"
+msgstr "<%s-n>\t在历史列表中前往本次提交的第n个父提交"
+
+#: gitk:3081
+msgid "<PageUp>\tMove up one page in commit list"
+msgstr "<PageUp>\t上一页提交列表"
+
+#: gitk:3082
+msgid "<PageDown>\tMove down one page in commit list"
+msgstr "<PageDown>\t下一页提交列表"
+
+#: gitk:3083
+#, tcl-format
+msgid "<%s-Home>\tScroll to top of commit list"
+msgstr "<%s-Home>\t滚动到提交列表顶部"
+
+#: gitk:3084
+#, tcl-format
+msgid "<%s-End>\tScroll to bottom of commit list"
+msgstr "<%s-End>\t滚动到提交列表底部"
+
+#: gitk:3085
+#, tcl-format
+msgid "<%s-Up>\tScroll commit list up one line"
+msgstr "<%s-Up>\t向上滚动一行提交列表"
+
+#: gitk:3086
+#, tcl-format
+msgid "<%s-Down>\tScroll commit list down one line"
+msgstr "<%s-Down>\t向下滚动一行提交列表"
+
+#: gitk:3087
+#, tcl-format
+msgid "<%s-PageUp>\tScroll commit list up one page"
+msgstr "<%s-PageUp>\t向上滚动一页提交列表"
+
+#: gitk:3088
+#, tcl-format
+msgid "<%s-PageDown>\tScroll commit list down one page"
+msgstr "<%s-PageDown>\t向下滚动一页提交列表"
+
+#: gitk:3089
+msgid "<Shift-Up>\tFind backwards (upwards, later commits)"
+msgstr "<Shift-Up>\t向后查找(向上的，更晚的提交)"
+
+#: gitk:3090
+msgid "<Shift-Down>\tFind forwards (downwards, earlier commits)"
+msgstr "<Shift-Down>\t向前查找(向下的，更早的提交)"
+
+#: gitk:3091
+msgid "<Delete>, b\tScroll diff view up one page"
+msgstr "<Delete>, b\t向上滚动diff视图一页"
+
+#: gitk:3092
+msgid "<Backspace>\tScroll diff view up one page"
+msgstr "<Backspace>\t向上滚动diff视图一页"
+
+#: gitk:3093
+msgid "<Space>\t\tScroll diff view down one page"
+msgstr "<Space>\t\t向下滚动diff视图一页"
+
+#: gitk:3094
+msgid "u\t\tScroll diff view up 18 lines"
+msgstr "u\t\t向上滚动diff视图18行"
+
+#: gitk:3095
+msgid "d\t\tScroll diff view down 18 lines"
+msgstr "d\t\t向下滚动diff视图18行"
+
+#: gitk:3096
+#, tcl-format
+msgid "<%s-F>\t\tFind"
+msgstr "<%s-F>\t\t查找"
+
+#: gitk:3097
+#, tcl-format
+msgid "<%s-G>\t\tMove to next find hit"
+msgstr "<%s-G>\t\t移动到下一次查找命中"
+
+#: gitk:3098
+msgid "<Return>\tMove to next find hit"
+msgstr "<Return>\t\t移动到下一次查找命中"
+
+#: gitk:3099
+msgid "g\t\tGo to commit"
+msgstr "g\t\t转到提交"
+
+#: gitk:3100
+msgid "/\t\tFocus the search box"
+msgstr "/\t\t选中搜索框"
+
+#: gitk:3101
+msgid "?\t\tMove to previous find hit"
+msgstr "?\t\t移动到上一次查找命中"
+
+#: gitk:3102
+msgid "f\t\tScroll diff view to next file"
+msgstr "f\t\t滚动diff视图到下一个文件"
+
+#: gitk:3103
+#, tcl-format
+msgid "<%s-S>\t\tSearch for next hit in diff view"
+msgstr "<%s-S>\t\t在diff视图中查找下一此命中"
+
+#: gitk:3104
+#, tcl-format
+msgid "<%s-R>\t\tSearch for previous hit in diff view"
+msgstr "<%s-R>\t\t在diff视图中查找上一次命中"
+
+#: gitk:3105
+#, tcl-format
+msgid "<%s-KP+>\tIncrease font size"
+msgstr "<%s-KP+>\t增大字体大小"
+
+#: gitk:3106
+#, tcl-format
+msgid "<%s-plus>\tIncrease font size"
+msgstr "<%s-plus>\t增大字体大小"
+
+#: gitk:3107
+#, tcl-format
+msgid "<%s-KP->\tDecrease font size"
+msgstr "<%s-KP->\t减小字体大小"
+
+#: gitk:3108
+#, tcl-format
+msgid "<%s-minus>\tDecrease font size"
+msgstr "<%s-minus>\t减小字体大小"
+
+#: gitk:3109
+msgid "<F5>\t\tUpdate"
+msgstr "<F5>\t\t更新"
+
+#: gitk:3574 gitk:3583
+#, tcl-format
+msgid "Error creating temporary directory %s:"
+msgstr "创建临时目录出错%s："
+
+#: gitk:3596
+#, tcl-format
+msgid "Error getting \"%s\" from %s:"
+msgstr "从%s获取\"%s\"出错："
+
+#: gitk:3659
+msgid "command failed:"
+msgstr "执行命令失败："
+
+#: gitk:3808
+msgid "No such commit"
+msgstr "无此提交"
+
+#: gitk:3822
+msgid "git gui blame: command failed:"
+msgstr "git gui blame：执行命令失败："
+
+#: gitk:3853
+#, tcl-format
+msgid "Couldn't read merge head: %s"
+msgstr "不能读取合并头(merge head)：%s"
+
+#: gitk:3861
+#, tcl-format
+msgid "Error reading index: %s"
+msgstr "读取索引出错：%s"
+
+#: gitk:3886
+#, tcl-format
+msgid "Couldn't start git blame: %s"
+msgstr "不能执行git blame：%s"
+
+#: gitk:3889 gitk:6778
+msgid "Searching"
+msgstr "搜索中"
+
+#: gitk:3921
+#, tcl-format
+msgid "Error running git blame: %s"
+msgstr "运行git blame出错：%s"
+
+#: gitk:3949
+#, tcl-format
+msgid "That line comes from commit %s,  which is not in this view"
+msgstr "此行来自提交%s，不在此视图中"
+
+#: gitk:3963
+msgid "External diff viewer failed:"
+msgstr "外部diff查看器失败："
+
+#: gitk:4067
+msgid "All files"
+msgstr "所有文件"
+
+#: gitk:4091
+msgid "View"
+msgstr "视图"
+
+#: gitk:4094
+msgid "Gitk view definition"
+msgstr "Gitk视图定义"
+
+#: gitk:4098
+msgid "Remember this view"
+msgstr "记住此视图"
+
+#: gitk:4099
+msgid "References (space separated list):"
+msgstr "引用(空格切分的列表)："
+
+#: gitk:4100
+msgid "Branches & tags:"
+msgstr "分支和tags"
+
+#: gitk:4101
+msgid "All refs"
+msgstr "所有引用"
+
+#: gitk:4102
+msgid "All (local) branches"
+msgstr "所有(本地)分支"
+
+#: gitk:4103
+msgid "All tags"
+msgstr "所有tag"
+
+#: gitk:4104
+msgid "All remote-tracking branches"
+msgstr "所有远程跟踪分支"
+
+#: gitk:4105
+msgid "Commit Info (regular expressions):"
+msgstr "提交信息 (正则表达式)："
+
+#: gitk:4106
+msgid "Author:"
+msgstr "作者："
+
+#: gitk:4107
+msgid "Committer:"
+msgstr "提交者："
+
+#: gitk:4108
+msgid "Commit Message:"
+msgstr "提交信息："
+
+#: gitk:4109
+msgid "Matches all Commit Info criteria"
+msgstr "匹配所有提交信息标准"
+
+#: gitk:4110
+msgid "Matches no Commit Info criteria"
+msgstr "匹配无提交信息标准"
+
+#: gitk:4111
+msgid "Changes to Files:"
+msgstr "文件修改列表："
+
+#: gitk:4112
+msgid "Fixed String"
+msgstr "固定字符串"
+
+#: gitk:4113
+msgid "Regular Expression"
+msgstr "正则表达式："
+
+#: gitk:4114
+msgid "Search string:"
+msgstr "搜索字符串："
+
+#: gitk:4115
+msgid ""
+"Commit Dates (\"2 weeks ago\", \"2009-03-17 15:27:38\", \"March 17, 2009 "
+"15:27:38\"):"
+msgstr "提交日期 (\"2星期之前\", \"2009-03-17 15:27:38\", \"5月 17, 2009 15:27:38\"):"
+
+#: gitk:4116
+msgid "Since:"
+msgstr "自："
+
+#: gitk:4117
+msgid "Until:"
+msgstr "到："
+
+#: gitk:4118
+msgid "Limit and/or skip a number of revisions (positive integer):"
+msgstr "限制 且/或 跳过一定数量的版本(正整数)："
+
+#: gitk:4119
+msgid "Number to show:"
+msgstr "显示数量："
+
+#: gitk:4120
+msgid "Number to skip:"
+msgstr "跳过数量："
+
+#: gitk:4121
+msgid "Miscellaneous options:"
+msgstr "其他选项："
+
+#: gitk:4122
+msgid "Strictly sort by date"
+msgstr "严格按日期整理"
+
+#: gitk:4123
+msgid "Mark branch sides"
+msgstr "标记分支边界"
+
+#: gitk:4124
+msgid "Limit to first parent"
+msgstr "限制到第一个父提交"
+
+#: gitk:4125
+msgid "Simple history"
+msgstr "简易历史"
+
+#: gitk:4126
+msgid "Additional arguments to git log:"
+msgstr "git log命令的额外参数："
+
+#: gitk:4127
+msgid "Enter files and directories to include, one per line:"
+msgstr "输入文件和文件夹来引用，每行一个："
+
+#: gitk:4128
+msgid "Command to generate more commits to include:"
+msgstr "命令产生更多的提交来引用："
+
+#: gitk:4252
+msgid "Gitk: edit view"
+msgstr "Gitk: 编辑视图"
+
+#: gitk:4260
+msgid "-- criteria for selecting revisions"
+msgstr "-- 用来选择版本的规则"
+
+#: gitk:4265
+msgid "View Name"
+msgstr "视图名称"
+
+#: gitk:4340
+msgid "Apply (F5)"
+msgstr "应用(F5)"
+
+#: gitk:4378
+msgid "Error in commit selection arguments:"
+msgstr "提交选择参数错误："
+
+#: gitk:4433 gitk:4486 gitk:4948 gitk:4962 gitk:6232 gitk:12524 gitk:12525
+msgid "None"
+msgstr "无"
+
+#: gitk:5045 gitk:5050
+msgid "Descendant"
+msgstr "子提交"
+
+#: gitk:5046
+msgid "Not descendant"
+msgstr "非子提交"
+
+#: gitk:5053 gitk:5058
+msgid "Ancestor"
+msgstr "父提交"
+
+#: gitk:5054
+msgid "Not ancestor"
+msgstr "非父提交"
+
+#: gitk:5348
+msgid "Local changes checked in to index but not committed"
+msgstr "已添加到索引但未提交的修改"
+
+#: gitk:5384
+msgid "Local uncommitted changes, not checked in to index"
+msgstr "未添加到索引且未提交的修改"
+
+#: gitk:7158
+msgid "and many more"
+msgstr "更多"
+
+#: gitk:7161
+msgid "many"
+msgstr "很多"
+
+#: gitk:7352
+msgid "Tags:"
+msgstr "Tags:"
+
+#: gitk:7369 gitk:7375 gitk:8854
+msgid "Parent"
+msgstr "父节点"
+
+#: gitk:7380
+msgid "Child"
+msgstr "子节点"
+
+#: gitk:7389
+msgid "Branch"
+msgstr "分支"
+
+#: gitk:7392
+msgid "Follows"
+msgstr "之后的tag"
+
+#: gitk:7395
+msgid "Precedes"
+msgstr "之前的tag"
+
+#: gitk:7990
+#, tcl-format
+msgid "Error getting diffs: %s"
+msgstr "获取差异错误：%s"
+
+#: gitk:8679
+msgid "Goto:"
+msgstr "转到："
+
+#: gitk:8700
+#, tcl-format
+msgid "Short SHA1 id %s is ambiguous"
+msgstr "短格式的SHA1提交号%s不明确、有歧义"
+
+#: gitk:8707
+#, tcl-format
+msgid "Revision %s is not known"
+msgstr "版本%s未知"
+
+#: gitk:8717
+#, tcl-format
+msgid "SHA1 id %s is not known"
+msgstr "提交号(SHA1 id)%s未知"
+
+#: gitk:8719
+#, tcl-format
+msgid "Revision %s is not in the current view"
+msgstr "版本%s不在当前视图中"
+
+#: gitk:8861 gitk:8876
+msgid "Date"
+msgstr "日期"
+
+#: gitk:8864
+msgid "Children"
+msgstr "子节点"
+
+#: gitk:8927
+#, tcl-format
+msgid "Reset %s branch to here"
+msgstr "重置分支%s到此处"
+
+#: gitk:8929
+msgid "Detached head: can't reset"
+msgstr "分离的头(head)：不能重置(reset)"
+
+#: gitk:9034 gitk:9040
+msgid "Skipping merge commit "
+msgstr "跳过合并提交"
+
+#: gitk:9049 gitk:9054
+msgid "Error getting patch ID for "
+msgstr "获取补丁ID出错"
+
+#: gitk:9050 gitk:9055
+msgid " - stopping\n"
+msgstr " — 停止中\n"
+
+#: gitk:9060 gitk:9063 gitk:9071 gitk:9085 gitk:9094
+msgid "Commit "
+msgstr "提交"
+
+#: gitk:9064
+msgid ""
+" is the same patch as\n"
+"       "
+msgstr " 是相同的补丁(patch)\n       "
+
+#: gitk:9072
+msgid ""
+" differs from\n"
+"       "
+msgstr " 差异来自\n       "
+
+#: gitk:9074
+msgid ""
+"Diff of commits:\n"
+"\n"
+msgstr "提交的差异(Diff)：\n\n"
+
+#: gitk:9086 gitk:9095
+#, tcl-format
+msgid " has %s children - stopping\n"
+msgstr "有%s子节点 — 停止中\n"
+
+#: gitk:9114
+#, tcl-format
+msgid "Error writing commit to file: %s"
+msgstr "写入提交到文件出错：%s"
+
+#: gitk:9120
+#, tcl-format
+msgid "Error diffing commits: %s"
+msgstr "比较提交差异出错：%s"
+
+#: gitk:9166
+msgid "Top"
+msgstr "顶部"
+
+#: gitk:9167
+msgid "From"
+msgstr "从"
+
+#: gitk:9172
+msgid "To"
+msgstr "到"
+
+#: gitk:9196
+msgid "Generate patch"
+msgstr "生成补丁(patch)"
+
+#: gitk:9198
+msgid "From:"
+msgstr "从："
+
+#: gitk:9207
+msgid "To:"
+msgstr "到："
+
+#: gitk:9216
+msgid "Reverse"
+msgstr "反向(Reverse)"
+
+#: gitk:9218 gitk:9428
+msgid "Output file:"
+msgstr "输出文件："
+
+#: gitk:9224
+msgid "Generate"
+msgstr "生成"
+
+#: gitk:9262
+msgid "Error creating patch:"
+msgstr "创建补丁(patch)出错："
+
+#: gitk:9285 gitk:9416 gitk:9504
+msgid "ID:"
+msgstr "ID:"
+
+#: gitk:9294
+msgid "Tag name:"
+msgstr "Tag名称："
+
+#: gitk:9297
+msgid "Tag message is optional"
+msgstr "Tag信息是可选的"
+
+#: gitk:9299
+msgid "Tag message:"
+msgstr "Tag信息："
+
+#: gitk:9303 gitk:9474
+msgid "Create"
+msgstr "创建"
+
+#: gitk:9321
+msgid "No tag name specified"
+msgstr "未指定tag名称"
+
+#: gitk:9325
+#, tcl-format
+msgid "Tag \"%s\" already exists"
+msgstr "Tag\"%s\"已经存在"
+
+#: gitk:9335
+msgid "Error creating tag:"
+msgstr "创建tag出错："
+
+#: gitk:9425
+msgid "Command:"
+msgstr "命令："
+
+#: gitk:9433
+msgid "Write"
+msgstr "写入"
+
+#: gitk:9451
+msgid "Error writing commit:"
+msgstr "写入提交出错："
+
+#: gitk:9473
+msgid "Create branch"
+msgstr "创建分支"
+
+#: gitk:9489
+#, tcl-format
+msgid "Rename branch %s"
+msgstr "重命名分支%s"
+
+#: gitk:9490
+msgid "Rename"
+msgstr "重命名"
+
+#: gitk:9514
+msgid "Name:"
+msgstr "名称："
+
+#: gitk:9538
+msgid "Please specify a name for the new branch"
+msgstr "请指定新分支的名称"
+
+#: gitk:9543
+#, tcl-format
+msgid "Branch '%s' already exists. Overwrite?"
+msgstr "分支\"%s\"已经存在。覆盖它？"
+
+#: gitk:9587
+msgid "Please specify a new name for the branch"
+msgstr "请重新指定新分支的名称"
+
+#: gitk:9650
+#, tcl-format
+msgid "Commit %s is already included in branch %s -- really re-apply it?"
+msgstr "提交%s已经存在于分支%s。确定重新应用它？"
+
+#: gitk:9655
+msgid "Cherry-picking"
+msgstr "打补丁中(Cherry-picking)"
+
+#: gitk:9664
+#, tcl-format
+msgid ""
+"Cherry-pick failed because of local changes to file '%s'.\n"
+"Please commit, reset or stash your changes and try again."
+msgstr "打补丁(Cherry-pick)失败，因为本地修改了文件\"%s\"。\n请提交(commit)、重置(reset)或暂存(stash)修改后重试。"
+
+#: gitk:9670
+msgid ""
+"Cherry-pick failed because of merge conflict.\n"
+"Do you wish to run git citool to resolve it?"
+msgstr "打补丁(Cherry-pick)失败因为合并冲突。\n你是否希望运行git citool 来解决冲突？"
+
+#: gitk:9686 gitk:9744
+msgid "No changes committed"
+msgstr "无已经提交的修改"
+
+#: gitk:9713
+#, tcl-format
+msgid "Commit %s is not included in branch %s -- really revert it?"
+msgstr "提交%s不包含在分支%s中，确认回滚(revert)它？"
+
+#: gitk:9718
+msgid "Reverting"
+msgstr "回滚中(Reverting)"
+
+#: gitk:9726
+#, tcl-format
+msgid ""
+"Revert failed because of local changes to the following files:%s Please "
+"commit, reset or stash  your changes and try again."
+msgstr "回滚(revert)失败，因为如下的本地文件修改：%s\n请提交(commit)、重置(reset)或者暂存(stash)改变后重试。"
+
+#: gitk:9730
+msgid ""
+"Revert failed because of merge conflict.\n"
+" Do you wish to run git citool to resolve it?"
+msgstr "回滚(revert)失败，因为合并冲突。\n你是否希望运行git citool来解决冲突？"
+
+#: gitk:9773
+msgid "Confirm reset"
+msgstr "确认重置(reset)"
+
+#: gitk:9775
+#, tcl-format
+msgid "Reset branch %s to %s?"
+msgstr "重置(reset)分支%s到%s？"
+
+#: gitk:9777
+msgid "Reset type:"
+msgstr "重置(reset)类型："
+
+#: gitk:9780
+msgid "Soft: Leave working tree and index untouched"
+msgstr "软性：离开工作树，索引未改变"
+
+#: gitk:9783
+msgid "Mixed: Leave working tree untouched, reset index"
+msgstr "混合：离开工作树(未改变)，索引重置"
+
+#: gitk:9786
+msgid ""
+"Hard: Reset working tree and index\n"
+"(discard ALL local changes)"
+msgstr "硬性：重置工作树和索引\n(丢弃所有的本地修改)"
+
+#: gitk:9803
+msgid "Resetting"
+msgstr "重置中(Resetting)"
+
+#: gitk:9876
+#, tcl-format
+msgid "A local branch named %s exists already"
+msgstr "本地分支%s已经存在"
+
+#: gitk:9884
+msgid "Checking out"
+msgstr "检出中(Checking out)"
+
+#: gitk:9943
+msgid "Cannot delete the currently checked-out branch"
+msgstr "不能删除当前检出(checkout)分支"
+
+#: gitk:9949
+#, tcl-format
+msgid ""
+"The commits on branch %s aren't on any other branch.\n"
+"Really delete branch %s?"
+msgstr "在分支%s上的提交不在其他任何分支上。\n确认删除分支%s？"
+
+#: gitk:9980
+#, tcl-format
+msgid "Tags and heads: %s"
+msgstr "Tags和头指针(heads)：%s"
+
+#: gitk:9997
+msgid "Filter"
+msgstr "过滤器"
+
+#: gitk:10293
+msgid ""
+"Error reading commit topology information; branch and preceding/following "
+"tag information will be incomplete."
+msgstr "读取提交拓扑信息出错；分支和之前/之后的tag信息将不能完成。"
+
+#: gitk:11270
+msgid "Tag"
+msgstr "标签(Tag)"
+
+#: gitk:11274
+msgid "Id"
+msgstr "Id"
+
+#: gitk:11357
+msgid "Gitk font chooser"
+msgstr "Gitk字体选择"
+
+#: gitk:11374
+msgid "B"
+msgstr "粗体"
+
+#: gitk:11377
+msgid "I"
+msgstr "斜体"
+
+#: gitk:11495
+msgid "Commit list display options"
+msgstr "提交列表展示选项"
+
+#: gitk:11498
+msgid "Maximum graph width (lines)"
+msgstr "最大图宽度(行数)"
+
+#: gitk:11502
+#, no-tcl-format
+msgid "Maximum graph width (% of pane)"
+msgstr "最大图宽度(%窗口百分比)"
+
+#: gitk:11505
+msgid "Show local changes"
+msgstr "显示本地修改"
+
+#: gitk:11508
+msgid "Auto-select SHA1 (length)"
+msgstr "自动选择SHA1(长度)"
+
+#: gitk:11512
+msgid "Hide remote refs"
+msgstr "隐藏远程引用"
+
+#: gitk:11516
+msgid "Diff display options"
+msgstr "差异(Diff)展示选项"
+
+#: gitk:11518
+msgid "Tab spacing"
+msgstr "制表符宽度"
+
+#: gitk:11521
+msgid "Display nearby tags/heads"
+msgstr "显示临近的tags/heads"
+
+#: gitk:11524
+msgid "Maximum # tags/heads to show"
+msgstr "最大tags/heads展示数量"
+
+#: gitk:11527
+msgid "Limit diffs to listed paths"
+msgstr "diff中列出文件限制"
+
+#: gitk:11530
+msgid "Support per-file encodings"
+msgstr "单独文件编码支持"
+
+#: gitk:11536 gitk:11683
+msgid "External diff tool"
+msgstr "外部差异(diff)工具"
+
+#: gitk:11537
+msgid "Choose..."
+msgstr "选择..."
+
+#: gitk:11542
+msgid "General options"
+msgstr "常规选项"
+
+#: gitk:11545
+msgid "Use themed widgets"
+msgstr "使用主题小部件"
+
+#: gitk:11547
+msgid "(change requires restart)"
+msgstr "(需重启生效)"
+
+#: gitk:11549
+msgid "(currently unavailable)"
+msgstr "(当前不可用)"
+
+#: gitk:11560
+msgid "Colors: press to choose"
+msgstr "颜色：点击来选择"
+
+#: gitk:11563
+msgid "Interface"
+msgstr "界面"
+
+#: gitk:11564
+msgid "interface"
+msgstr "界面"
+
+#: gitk:11567
+msgid "Background"
+msgstr "背景"
+
+#: gitk:11568 gitk:11598
+msgid "background"
+msgstr "背景"
+
+#: gitk:11571
+msgid "Foreground"
+msgstr "前景"
+
+#: gitk:11572
+msgid "foreground"
+msgstr "前景"
+
+#: gitk:11575
+msgid "Diff: old lines"
+msgstr "差异(Diff)：老代码行"
+
+#: gitk:11576
+msgid "diff old lines"
+msgstr "差异(diff)老代码行"
+
+#: gitk:11580
+msgid "Diff: new lines"
+msgstr "差异(Diff)：新代码行"
+
+#: gitk:11581
+msgid "diff new lines"
+msgstr "差异(diff)新代码行"
+
+#: gitk:11585
+msgid "Diff: hunk header"
+msgstr "差异(Diff)：补丁片段头信息"
+
+#: gitk:11587
+msgid "diff hunk header"
+msgstr "差异(diff)补丁片段头信息"
+
+#: gitk:11591
+msgid "Marked line bg"
+msgstr "已标记代码行背景"
+
+#: gitk:11593
+msgid "marked line background"
+msgstr "已标记代码行背景"
+
+#: gitk:11597
+msgid "Select bg"
+msgstr "选择背景"
+
+#: gitk:11606
+msgid "Fonts: press to choose"
+msgstr "字体：点击来选择"
+
+#: gitk:11608
+msgid "Main font"
+msgstr "主字体"
+
+#: gitk:11609
+msgid "Diff display font"
+msgstr "差异(Diff)显示字体"
+
+#: gitk:11610
+msgid "User interface font"
+msgstr "用户界面字体"
+
+#: gitk:11632
+msgid "Gitk preferences"
+msgstr "Gitk偏好设置"
+
+#: gitk:11641
+msgid "General"
+msgstr "常规"
+
+#: gitk:11642
+msgid "Colors"
+msgstr "颜色"
+
+#: gitk:11643
+msgid "Fonts"
+msgstr "字体"
+
+#: gitk:11693
+#, tcl-format
+msgid "Gitk: choose color for %s"
+msgstr "Gitk：选择颜色用于%s"
+
+#: gitk:12206
+msgid ""
+"Sorry, gitk cannot run with this version of Tcl/Tk.\n"
+" Gitk requires at least Tcl/Tk 8.4."
+msgstr "对不起，gitk不能运行在当前版本的Tcl/Tk中。\nGitk运行需要最低版本为Tcl/Tk8.4。"
+
+#: gitk:12416
+msgid "Cannot find a git repository here."
+msgstr "在此位置未发现git仓库。"
+
+#: gitk:12463
+#, tcl-format
+msgid "Ambiguous argument '%s': both revision and filename"
+msgstr "不明确有歧义的参数\"%s\"：版本和文件名称"
+
+#: gitk:12475
+msgid "Bad arguments to gitk:"
+msgstr "运行gitk参数错误："
diff -pruN 1.2.1+git2.18.0-1/git/git-legacy-stash.sh 1.2.3+git2.25.1-1/git/git-legacy-stash.sh
--- 1.2.1+git2.18.0-1/git/git-legacy-stash.sh	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/git-legacy-stash.sh	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,798 @@
+#!/bin/sh
+# Copyright (c) 2007, Nanako Shiraishi
+
+dashless=$(basename "$0" | sed -e 's/-/ /')
+USAGE="list [<options>]
+   or: $dashless show [<stash>]
+   or: $dashless drop [-q|--quiet] [<stash>]
+   or: $dashless ( pop | apply ) [--index] [-q|--quiet] [<stash>]
+   or: $dashless branch <branchname> [<stash>]
+   or: $dashless save [--patch] [-k|--[no-]keep-index] [-q|--quiet]
+		      [-u|--include-untracked] [-a|--all] [<message>]
+   or: $dashless [push [--patch] [-k|--[no-]keep-index] [-q|--quiet]
+		       [-u|--include-untracked] [-a|--all] [-m <message>]
+		       [-- <pathspec>...]]
+   or: $dashless clear"
+
+SUBDIRECTORY_OK=Yes
+OPTIONS_SPEC=
+START_DIR=$(pwd)
+. git-sh-setup
+require_work_tree
+prefix=$(git rev-parse --show-prefix) || exit 1
+cd_to_toplevel
+
+TMP="$GIT_DIR/.git-stash.$$"
+TMPindex=${GIT_INDEX_FILE-"$(git rev-parse --git-path index)"}.stash.$$
+trap 'rm -f "$TMP-"* "$TMPindex"' 0
+
+ref_stash=refs/stash
+
+if git config --get-colorbool color.interactive; then
+       help_color="$(git config --get-color color.interactive.help 'red bold')"
+       reset_color="$(git config --get-color '' reset)"
+else
+       help_color=
+       reset_color=
+fi
+
+no_changes () {
+	git diff-index --quiet --cached HEAD --ignore-submodules -- "$@" &&
+	git diff-files --quiet --ignore-submodules -- "$@" &&
+	(test -z "$untracked" || test -z "$(untracked_files "$@")")
+}
+
+untracked_files () {
+	if test "$1" = "-z"
+	then
+		shift
+		z=-z
+	else
+		z=
+	fi
+	excl_opt=--exclude-standard
+	test "$untracked" = "all" && excl_opt=
+	git ls-files -o $z $excl_opt -- "$@"
+}
+
+prepare_fallback_ident () {
+	if ! git -c user.useconfigonly=yes var GIT_COMMITTER_IDENT >/dev/null 2>&1
+	then
+		GIT_AUTHOR_NAME="git stash"
+		GIT_AUTHOR_EMAIL=git@stash
+		GIT_COMMITTER_NAME="git stash"
+		GIT_COMMITTER_EMAIL=git@stash
+		export GIT_AUTHOR_NAME
+		export GIT_AUTHOR_EMAIL
+		export GIT_COMMITTER_NAME
+		export GIT_COMMITTER_EMAIL
+	fi
+}
+
+clear_stash () {
+	if test $# != 0
+	then
+		die "$(gettext "git stash clear with parameters is unimplemented")"
+	fi
+	if current=$(git rev-parse --verify --quiet $ref_stash)
+	then
+		git update-ref -d $ref_stash $current
+	fi
+}
+
+maybe_quiet () {
+	case "$1" in
+	--keep-stdout)
+		shift
+		if test -n "$GIT_QUIET"
+		then
+			"$@" 2>/dev/null
+		else
+			"$@"
+		fi
+		;;
+	*)
+		if test -n "$GIT_QUIET"
+		then
+			"$@" >/dev/null 2>&1
+		else
+			"$@"
+		fi
+		;;
+	esac
+}
+
+create_stash () {
+
+	prepare_fallback_ident
+
+	stash_msg=
+	untracked=
+	while test $# != 0
+	do
+		case "$1" in
+		-m|--message)
+			shift
+			stash_msg=${1?"BUG: create_stash () -m requires an argument"}
+			;;
+		-m*)
+			stash_msg=${1#-m}
+			;;
+		--message=*)
+			stash_msg=${1#--message=}
+			;;
+		-u|--include-untracked)
+			shift
+			untracked=${1?"BUG: create_stash () -u requires an argument"}
+			;;
+		--)
+			shift
+			break
+			;;
+		esac
+		shift
+	done
+
+	git update-index -q --refresh
+	if maybe_quiet no_changes "$@"
+	then
+		exit 0
+	fi
+
+	# state of the base commit
+	if b_commit=$(maybe_quiet --keep-stdout git rev-parse --verify HEAD)
+	then
+		head=$(git rev-list --oneline -n 1 HEAD --)
+	elif test -n "$GIT_QUIET"
+	then
+		exit 1
+	else
+		die "$(gettext "You do not have the initial commit yet")"
+	fi
+
+	if branch=$(git symbolic-ref -q HEAD)
+	then
+		branch=${branch#refs/heads/}
+	else
+		branch='(no branch)'
+	fi
+	msg=$(printf '%s: %s' "$branch" "$head")
+
+	# state of the index
+	i_tree=$(git write-tree) &&
+	i_commit=$(printf 'index on %s\n' "$msg" |
+		git commit-tree $i_tree -p $b_commit) ||
+		die "$(gettext "Cannot save the current index state")"
+
+	if test -n "$untracked"
+	then
+		# Untracked files are stored by themselves in a parentless commit, for
+		# ease of unpacking later.
+		u_commit=$(
+			untracked_files -z "$@" | (
+				GIT_INDEX_FILE="$TMPindex" &&
+				export GIT_INDEX_FILE &&
+				rm -f "$TMPindex" &&
+				git update-index -z --add --remove --stdin &&
+				u_tree=$(git write-tree) &&
+				printf 'untracked files on %s\n' "$msg" | git commit-tree $u_tree  &&
+				rm -f "$TMPindex"
+		) ) || die "$(gettext "Cannot save the untracked files")"
+
+		untracked_commit_option="-p $u_commit";
+	else
+		untracked_commit_option=
+	fi
+
+	if test -z "$patch_mode"
+	then
+
+		# state of the working tree
+		w_tree=$( (
+			git read-tree --index-output="$TMPindex" -m $i_tree &&
+			GIT_INDEX_FILE="$TMPindex" &&
+			export GIT_INDEX_FILE &&
+			git diff-index --name-only -z HEAD -- "$@" >"$TMP-stagenames" &&
+			git update-index --ignore-skip-worktree-entries \
+				-z --add --remove --stdin <"$TMP-stagenames" &&
+			git write-tree &&
+			rm -f "$TMPindex"
+		) ) ||
+			die "$(gettext "Cannot save the current worktree state")"
+
+	else
+
+		rm -f "$TMP-index" &&
+		GIT_INDEX_FILE="$TMP-index" git read-tree HEAD &&
+
+		# find out what the user wants
+		GIT_INDEX_FILE="$TMP-index" \
+			git add--interactive --patch=stash -- "$@" &&
+
+		# state of the working tree
+		w_tree=$(GIT_INDEX_FILE="$TMP-index" git write-tree) ||
+		die "$(gettext "Cannot save the current worktree state")"
+
+		git diff-tree -p HEAD $w_tree -- >"$TMP-patch" &&
+		test -s "$TMP-patch" ||
+		die "$(gettext "No changes selected")"
+
+		rm -f "$TMP-index" ||
+		die "$(gettext "Cannot remove temporary index (can't happen)")"
+
+	fi
+
+	# create the stash
+	if test -z "$stash_msg"
+	then
+		stash_msg=$(printf 'WIP on %s' "$msg")
+	else
+		stash_msg=$(printf 'On %s: %s' "$branch" "$stash_msg")
+	fi
+	w_commit=$(printf '%s\n' "$stash_msg" |
+	git commit-tree $w_tree -p $b_commit -p $i_commit $untracked_commit_option) ||
+	die "$(gettext "Cannot record working tree state")"
+}
+
+store_stash () {
+	while test $# != 0
+	do
+		case "$1" in
+		-m|--message)
+			shift
+			stash_msg="$1"
+			;;
+		-m*)
+			stash_msg=${1#-m}
+			;;
+		--message=*)
+			stash_msg=${1#--message=}
+			;;
+		-q|--quiet)
+			quiet=t
+			;;
+		*)
+			break
+			;;
+		esac
+		shift
+	done
+	test $# = 1 ||
+	die "$(eval_gettext "\"$dashless store\" requires one <commit> argument")"
+
+	w_commit="$1"
+	if test -z "$stash_msg"
+	then
+		stash_msg="Created via \"git stash store\"."
+	fi
+
+	git update-ref --create-reflog -m "$stash_msg" $ref_stash $w_commit
+	ret=$?
+	test $ret != 0 && test -z "$quiet" &&
+	die "$(eval_gettext "Cannot update \$ref_stash with \$w_commit")"
+	return $ret
+}
+
+push_stash () {
+	keep_index=
+	patch_mode=
+	untracked=
+	stash_msg=
+	while test $# != 0
+	do
+		case "$1" in
+		-k|--keep-index)
+			keep_index=t
+			;;
+		--no-keep-index)
+			keep_index=n
+			;;
+		-p|--patch)
+			patch_mode=t
+			# only default to keep if we don't already have an override
+			test -z "$keep_index" && keep_index=t
+			;;
+		-q|--quiet)
+			GIT_QUIET=t
+			;;
+		-u|--include-untracked)
+			untracked=untracked
+			;;
+		-a|--all)
+			untracked=all
+			;;
+		-m|--message)
+			shift
+			test -z ${1+x} && usage
+			stash_msg=$1
+			;;
+		-m*)
+			stash_msg=${1#-m}
+			;;
+		--message=*)
+			stash_msg=${1#--message=}
+			;;
+		--help)
+			show_help
+			;;
+		--)
+			shift
+			break
+			;;
+		-*)
+			option="$1"
+			eval_gettextln "error: unknown option for 'stash push': \$option"
+			usage
+			;;
+		*)
+			break
+			;;
+		esac
+		shift
+	done
+
+	eval "set $(git rev-parse --sq --prefix "$prefix" -- "$@")"
+
+	if test -n "$patch_mode" && test -n "$untracked"
+	then
+		die "$(gettext "Can't use --patch and --include-untracked or --all at the same time")"
+	fi
+
+	test -n "$untracked" || git ls-files --error-unmatch -- "$@" >/dev/null || exit 1
+
+	git update-index -q --refresh
+	if maybe_quiet no_changes "$@"
+	then
+		say "$(gettext "No local changes to save")"
+		exit 0
+	fi
+
+	git reflog exists $ref_stash ||
+		clear_stash || die "$(gettext "Cannot initialize stash")"
+
+	create_stash -m "$stash_msg" -u "$untracked" -- "$@"
+	store_stash -m "$stash_msg" -q $w_commit ||
+	die "$(gettext "Cannot save the current status")"
+	say "$(eval_gettext "Saved working directory and index state \$stash_msg")"
+
+	if test -z "$patch_mode"
+	then
+		test "$untracked" = "all" && CLEAN_X_OPTION=-x || CLEAN_X_OPTION=
+		if test -n "$untracked" && test $# = 0
+		then
+			git clean --force --quiet -d $CLEAN_X_OPTION
+		fi
+
+		if test $# != 0
+		then
+			test -z "$untracked" && UPDATE_OPTION="-u" || UPDATE_OPTION=
+			test "$untracked" = "all" && FORCE_OPTION="--force" || FORCE_OPTION=
+			git add $UPDATE_OPTION $FORCE_OPTION -- "$@"
+			git diff-index -p --cached --binary HEAD -- "$@" |
+			git apply --index -R
+		else
+			git reset --hard -q --no-recurse-submodules
+		fi
+
+		if test "$keep_index" = "t" && test -n "$i_tree"
+		then
+			git read-tree --reset $i_tree
+			git ls-files -z --modified -- "$@" |
+			git checkout-index -z --force --stdin
+		fi
+	else
+		git apply -R < "$TMP-patch" ||
+		die "$(gettext "Cannot remove worktree changes")"
+
+		if test "$keep_index" != "t"
+		then
+			git reset -q -- "$@"
+		fi
+	fi
+}
+
+save_stash () {
+	push_options=
+	while test $# != 0
+	do
+		case "$1" in
+		-q|--quiet)
+			GIT_QUIET=t
+			;;
+		--)
+			shift
+			break
+			;;
+		-*)
+			# pass all options through to push_stash
+			push_options="$push_options $1"
+			;;
+		*)
+			break
+			;;
+		esac
+		shift
+	done
+
+	stash_msg="$*"
+
+	if test -z "$stash_msg"
+	then
+		push_stash $push_options
+	else
+		push_stash $push_options -m "$stash_msg"
+	fi
+}
+
+have_stash () {
+	git rev-parse --verify --quiet $ref_stash >/dev/null
+}
+
+list_stash () {
+	have_stash || return 0
+	git log --format="%gd: %gs" -g --first-parent -m "$@" $ref_stash --
+}
+
+show_stash () {
+	ALLOW_UNKNOWN_FLAGS=t
+	assert_stash_like "$@"
+
+	if test -z "$FLAGS"
+	then
+		if test "$(git config --bool stash.showStat || echo true)" = "true"
+		then
+			FLAGS=--stat
+		fi
+
+		if test "$(git config --bool stash.showPatch || echo false)" = "true"
+		then
+			FLAGS=${FLAGS}${FLAGS:+ }-p
+		fi
+
+		if test -z "$FLAGS"
+		then
+			return 0
+		fi
+	fi
+
+	git diff ${FLAGS} $b_commit $w_commit
+}
+
+show_help () {
+	exec git help stash
+	exit 1
+}
+
+#
+# Parses the remaining options looking for flags and
+# at most one revision defaulting to ${ref_stash}@{0}
+# if none found.
+#
+# Derives related tree and commit objects from the
+# revision, if one is found.
+#
+# stash records the work tree, and is a merge between the
+# base commit (first parent) and the index tree (second parent).
+#
+#   REV is set to the symbolic version of the specified stash-like commit
+#   IS_STASH_LIKE is non-blank if ${REV} looks like a stash
+#   IS_STASH_REF is non-blank if the ${REV} looks like a stash ref
+#   s is set to the SHA1 of the stash commit
+#   w_commit is set to the commit containing the working tree
+#   b_commit is set to the base commit
+#   i_commit is set to the commit containing the index tree
+#   u_commit is set to the commit containing the untracked files tree
+#   w_tree is set to the working tree
+#   b_tree is set to the base tree
+#   i_tree is set to the index tree
+#   u_tree is set to the untracked files tree
+#
+#   GIT_QUIET is set to t if -q is specified
+#   INDEX_OPTION is set to --index if --index is specified.
+#   FLAGS is set to the remaining flags (if allowed)
+#
+# dies if:
+#   * too many revisions specified
+#   * no revision is specified and there is no stash stack
+#   * a revision is specified which cannot be resolve to a SHA1
+#   * a non-existent stash reference is specified
+#   * unknown flags were set and ALLOW_UNKNOWN_FLAGS is not "t"
+#
+
+parse_flags_and_rev()
+{
+	test "$PARSE_CACHE" = "$*" && return 0 # optimisation
+	PARSE_CACHE="$*"
+
+	IS_STASH_LIKE=
+	IS_STASH_REF=
+	INDEX_OPTION=
+	s=
+	w_commit=
+	b_commit=
+	i_commit=
+	u_commit=
+	w_tree=
+	b_tree=
+	i_tree=
+	u_tree=
+
+	FLAGS=
+	REV=
+	for opt
+	do
+		case "$opt" in
+			-q|--quiet)
+				GIT_QUIET=-t
+			;;
+			--index)
+				INDEX_OPTION=--index
+			;;
+			--help)
+				show_help
+			;;
+			-*)
+				test "$ALLOW_UNKNOWN_FLAGS" = t ||
+					die "$(eval_gettext "unknown option: \$opt")"
+				FLAGS="${FLAGS}${FLAGS:+ }$opt"
+			;;
+			*)
+				REV="${REV}${REV:+ }'$opt'"
+			;;
+		esac
+	done
+
+	eval set -- $REV
+
+	case $# in
+		0)
+			have_stash || die "$(gettext "No stash entries found.")"
+			set -- ${ref_stash}@{0}
+		;;
+		1)
+			:
+		;;
+		*)
+			die "$(eval_gettext "Too many revisions specified: \$REV")"
+		;;
+	esac
+
+	case "$1" in
+		*[!0-9]*)
+			:
+		;;
+		*)
+			set -- "${ref_stash}@{$1}"
+		;;
+	esac
+
+	REV=$(git rev-parse --symbolic --verify --quiet "$1") || {
+		reference="$1"
+		die "$(eval_gettext "\$reference is not a valid reference")"
+	}
+
+	i_commit=$(git rev-parse --verify --quiet "$REV^2") &&
+	set -- $(git rev-parse "$REV" "$REV^1" "$REV:" "$REV^1:" "$REV^2:" 2>/dev/null) &&
+	s=$1 &&
+	w_commit=$1 &&
+	b_commit=$2 &&
+	w_tree=$3 &&
+	b_tree=$4 &&
+	i_tree=$5 &&
+	IS_STASH_LIKE=t &&
+	test "$ref_stash" = "$(git rev-parse --symbolic-full-name "${REV%@*}")" &&
+	IS_STASH_REF=t
+
+	u_commit=$(git rev-parse --verify --quiet "$REV^3") &&
+	u_tree=$(git rev-parse "$REV^3:" 2>/dev/null)
+}
+
+is_stash_like()
+{
+	parse_flags_and_rev "$@"
+	test -n "$IS_STASH_LIKE"
+}
+
+assert_stash_like() {
+	is_stash_like "$@" || {
+		args="$*"
+		die "$(eval_gettext "'\$args' is not a stash-like commit")"
+	}
+}
+
+is_stash_ref() {
+	is_stash_like "$@" && test -n "$IS_STASH_REF"
+}
+
+assert_stash_ref() {
+	is_stash_ref "$@" || {
+		args="$*"
+		die "$(eval_gettext "'\$args' is not a stash reference")"
+	}
+}
+
+apply_stash () {
+
+	assert_stash_like "$@"
+
+	git update-index -q --refresh || die "$(gettext "unable to refresh index")"
+
+	# current index state
+	c_tree=$(git write-tree) ||
+		die "$(gettext "Cannot apply a stash in the middle of a merge")"
+
+	unstashed_index_tree=
+	if test -n "$INDEX_OPTION" && test "$b_tree" != "$i_tree" &&
+			test "$c_tree" != "$i_tree"
+	then
+		git diff-tree --binary $s^2^..$s^2 | git apply --cached
+		test $? -ne 0 &&
+			die "$(gettext "Conflicts in index. Try without --index.")"
+		unstashed_index_tree=$(git write-tree) ||
+			die "$(gettext "Could not save index tree")"
+		git reset
+	fi
+
+	if test -n "$u_tree"
+	then
+		GIT_INDEX_FILE="$TMPindex" git read-tree "$u_tree" &&
+		GIT_INDEX_FILE="$TMPindex" git checkout-index --all &&
+		rm -f "$TMPindex" ||
+		die "$(gettext "Could not restore untracked files from stash entry")"
+	fi
+
+	eval "
+		GITHEAD_$w_tree='Stashed changes' &&
+		GITHEAD_$c_tree='Updated upstream' &&
+		GITHEAD_$b_tree='Version stash was based on' &&
+		export GITHEAD_$w_tree GITHEAD_$c_tree GITHEAD_$b_tree
+	"
+
+	if test -n "$GIT_QUIET"
+	then
+		GIT_MERGE_VERBOSITY=0 && export GIT_MERGE_VERBOSITY
+	fi
+	if git merge-recursive $b_tree -- $c_tree $w_tree
+	then
+		# No conflict
+		if test -n "$unstashed_index_tree"
+		then
+			git read-tree "$unstashed_index_tree"
+		else
+			a="$TMP-added" &&
+			git diff-index --cached --name-only --diff-filter=A $c_tree >"$a" &&
+			git read-tree --reset $c_tree &&
+			git update-index --add --stdin <"$a" ||
+				die "$(gettext "Cannot unstage modified files")"
+			rm -f "$a"
+		fi
+		squelch=
+		if test -n "$GIT_QUIET"
+		then
+			squelch='>/dev/null 2>&1'
+		fi
+		(cd "$START_DIR" && eval "git status $squelch") || :
+	else
+		# Merge conflict; keep the exit status from merge-recursive
+		status=$?
+		git rerere
+		if test -n "$INDEX_OPTION"
+		then
+			gettextln "Index was not unstashed." >&2
+		fi
+		exit $status
+	fi
+}
+
+pop_stash() {
+	assert_stash_ref "$@"
+
+	if apply_stash "$@"
+	then
+		drop_stash "$@"
+	else
+		status=$?
+		say "$(gettext "The stash entry is kept in case you need it again.")"
+		exit $status
+	fi
+}
+
+drop_stash () {
+	assert_stash_ref "$@"
+
+	git reflog delete --updateref --rewrite "${REV}" &&
+		say "$(eval_gettext "Dropped \${REV} (\$s)")" ||
+		die "$(eval_gettext "\${REV}: Could not drop stash entry")"
+
+	# clear_stash if we just dropped the last stash entry
+	git rev-parse --verify --quiet "$ref_stash@{0}" >/dev/null ||
+	clear_stash
+}
+
+apply_to_branch () {
+	test -n "$1" || die "$(gettext "No branch name specified")"
+	branch=$1
+	shift 1
+
+	set -- --index "$@"
+	assert_stash_like "$@"
+
+	git checkout -b $branch $REV^ &&
+	apply_stash "$@" && {
+		test -z "$IS_STASH_REF" || drop_stash "$@"
+	}
+}
+
+test "$1" = "-p" && set "push" "$@"
+
+PARSE_CACHE='--not-parsed'
+# The default command is "push" if nothing but options are given
+seen_non_option=
+for opt
+do
+	case "$opt" in
+	--) break ;;
+	-*) ;;
+	*) seen_non_option=t; break ;;
+	esac
+done
+
+test -n "$seen_non_option" || set "push" "$@"
+
+# Main command set
+case "$1" in
+list)
+	shift
+	list_stash "$@"
+	;;
+show)
+	shift
+	show_stash "$@"
+	;;
+save)
+	shift
+	save_stash "$@"
+	;;
+push)
+	shift
+	push_stash "$@"
+	;;
+apply)
+	shift
+	apply_stash "$@"
+	;;
+clear)
+	shift
+	clear_stash "$@"
+	;;
+create)
+	shift
+	create_stash -m "$*" && echo "$w_commit"
+	;;
+store)
+	shift
+	store_stash "$@"
+	;;
+drop)
+	shift
+	drop_stash "$@"
+	;;
+pop)
+	shift
+	pop_stash "$@"
+	;;
+branch)
+	shift
+	apply_to_branch "$@"
+	;;
+*)
+	case $# in
+	0)
+		push_stash &&
+		say "$(gettext "(To restore them type \"git stash apply\")")"
+		;;
+	*)
+		usage
+	esac
+	;;
+esac
diff -pruN 1.2.1+git2.18.0-1/git/git-mergetool--lib.sh 1.2.3+git2.25.1-1/git/git-mergetool--lib.sh
--- 1.2.1+git2.18.0-1/git/git-mergetool--lib.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/git-mergetool--lib.sh	2020-02-17 04:47:35.000000000 +0000
@@ -80,14 +80,18 @@ show_tool_names () {
 	}
 }
 
-diff_mode() {
+diff_mode () {
 	test "$TOOL_MODE" = diff
 }
 
-merge_mode() {
+merge_mode () {
 	test "$TOOL_MODE" = merge
 }
 
+gui_mode () {
+	test "$GIT_MERGETOOL_GUI" = true
+}
+
 translate_merge_tool_path () {
 	echo "$1"
 }
@@ -279,6 +283,7 @@ list_merge_tool_candidates () {
 		fi
 		tools="$tools gvimdiff diffuse diffmerge ecmerge"
 		tools="$tools p4merge araxis bc codecompare"
+		tools="$tools smerge"
 	fi
 	case "${VISUAL:-$EDITOR}" in
 	*vim*)
@@ -350,17 +355,39 @@ guess_merge_tool () {
 }
 
 get_configured_merge_tool () {
-	# Diff mode first tries diff.tool and falls back to merge.tool.
-	# Merge mode only checks merge.tool
+	keys=
 	if diff_mode
 	then
-		merge_tool=$(git config diff.tool || git config merge.tool)
+		if gui_mode
+		then
+			keys="diff.guitool merge.guitool diff.tool merge.tool"
+		else
+			keys="diff.tool merge.tool"
+		fi
 	else
-		merge_tool=$(git config merge.tool)
+		if gui_mode
+		then
+			keys="merge.guitool merge.tool"
+		else
+			keys="merge.tool"
+		fi
 	fi
+
+	merge_tool=$(
+		IFS=' '
+		for key in $keys
+		do
+			selected=$(git config $key)
+			if test -n "$selected"
+			then
+				echo "$selected"
+				return
+			fi
+		done)
+
 	if test -n "$merge_tool" && ! valid_tool "$merge_tool"
 	then
-		echo >&2 "git config option $TOOL_MODE.tool set to unknown tool: $merge_tool"
+		echo >&2 "git config option $TOOL_MODE.${gui_prefix}tool set to unknown tool: $merge_tool"
 		echo >&2 "Resetting to default..."
 		return 1
 	fi
@@ -397,14 +424,17 @@ get_merge_tool_path () {
 }
 
 get_merge_tool () {
+	is_guessed=false
 	# Check if a merge tool has been configured
 	merge_tool=$(get_configured_merge_tool)
 	# Try to guess an appropriate merge tool if no tool has been set.
 	if test -z "$merge_tool"
 	then
 		merge_tool=$(guess_merge_tool) || exit
+		is_guessed=true
 	fi
 	echo "$merge_tool"
+	test "$is_guessed" = false
 }
 
 mergetool_find_win32_cmd () {
diff -pruN 1.2.1+git2.18.0-1/git/git-mergetool.sh 1.2.3+git2.25.1-1/git/git-mergetool.sh
--- 1.2.1+git2.18.0-1/git/git-mergetool.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/git-mergetool.sh	2020-02-17 04:47:35.000000000 +0000
@@ -9,7 +9,7 @@
 # at the discretion of Junio C Hamano.
 #
 
-USAGE='[--tool=tool] [--tool-help] [-y|--no-prompt|--prompt] [-O<orderfile>] [file to merge] ...'
+USAGE='[--tool=tool] [--tool-help] [-y|--no-prompt|--prompt] [-g|--gui|--no-gui] [-O<orderfile>] [file to merge] ...'
 SUBDIRECTORY_OK=Yes
 NONGIT_OK=Yes
 OPTIONS_SPEC=
@@ -228,9 +228,8 @@ stage_submodule () {
 }
 
 checkout_staged_file () {
-	tmpfile=$(expr \
-		"$(git checkout-index --temp --stage="$1" "$2" 2>/dev/null)" \
-		: '\([^	]*\)	')
+	tmpfile="$(git checkout-index --temp --stage="$1" "$2" 2>/dev/null)" &&
+	tmpfile=${tmpfile%%'	'*}
 
 	if test $? -eq 0 && test -n "$tmpfile"
 	then
@@ -255,13 +254,16 @@ merge_file () {
 		return 1
 	fi
 
-	if BASE=$(expr "$MERGED" : '\(.*\)\.[^/]*$')
-	then
-		ext=$(expr "$MERGED" : '.*\(\.[^/]*\)$')
-	else
+	# extract file extension from the last path component
+	case "${MERGED##*/}" in
+	*.*)
+		ext=.${MERGED##*.}
+		BASE=${MERGED%"$ext"}
+		;;
+	*)
 		BASE=$MERGED
 		ext=
-	fi
+	esac
 
 	mergetool_tmpdir_init
 
@@ -277,15 +279,30 @@ merge_file () {
 	REMOTE="$MERGETOOL_TMPDIR/${BASE}_REMOTE_$$$ext"
 	BASE="$MERGETOOL_TMPDIR/${BASE}_BASE_$$$ext"
 
-	base_mode=$(git ls-files -u -- "$MERGED" | awk '{if ($3==1) print $1;}')
-	local_mode=$(git ls-files -u -- "$MERGED" | awk '{if ($3==2) print $1;}')
-	remote_mode=$(git ls-files -u -- "$MERGED" | awk '{if ($3==3) print $1;}')
+	base_mode= local_mode= remote_mode=
+
+	# here, $IFS is just a LF
+	for line in $f
+	do
+		mode=${line%% *}		# 1st word
+		sha1=${line#"$mode "}
+		sha1=${sha1%% *}		# 2nd word
+		case "${line#$mode $sha1 }" in	# remainder
+		'1	'*)
+			base_mode=$mode
+			;;
+		'2	'*)
+			local_mode=$mode local_sha1=$sha1
+			;;
+		'3	'*)
+			remote_mode=$mode remote_sha1=$sha1
+			;;
+		esac
+	done
 
 	if is_submodule "$local_mode" || is_submodule "$remote_mode"
 	then
 		echo "Submodule merge conflict for '$MERGED':"
-		local_sha1=$(git ls-files -u -- "$MERGED" | awk '{if ($3==2) print $2;}')
-		remote_sha1=$(git ls-files -u -- "$MERGED" | awk '{if ($3==3) print $2;}')
 		describe_file "$local_mode" "local" "$local_sha1"
 		describe_file "$remote_mode" "remote" "$remote_sha1"
 		resolve_submodule_merge
@@ -389,6 +406,7 @@ print_noop_and_exit () {
 
 main () {
 	prompt=$(git config --bool mergetool.prompt)
+	GIT_MERGETOOL_GUI=false
 	guessed_merge_tool=false
 	orderfile=
 
@@ -405,7 +423,7 @@ main () {
 		-t|--tool*)
 			case "$#,$1" in
 			*,*=*)
-				merge_tool=$(expr "z$1" : 'z-[^=]*=\(.*\)')
+				merge_tool=${1#*=}
 				;;
 			1,*)
 				usage ;;
@@ -414,6 +432,12 @@ main () {
 				shift ;;
 			esac
 			;;
+		--no-gui)
+			GIT_MERGETOOL_GUI=false
+			;;
+		-g|--gui)
+			GIT_MERGETOOL_GUI=true
+			;;
 		-y|--no-prompt)
 			prompt=false
 			;;
@@ -442,12 +466,8 @@ main () {
 
 	if test -z "$merge_tool"
 	then
-		# Check if a merge tool has been configured
-		merge_tool=$(get_configured_merge_tool)
-		# Try to guess an appropriate merge tool if no tool has been set.
-		if test -z "$merge_tool"
+		if ! merge_tool=$(get_merge_tool)
 		then
-			merge_tool=$(guess_merge_tool) || exit
 			guessed_merge_tool=true
 		fi
 	fi
@@ -491,14 +511,16 @@ main () {
 	printf "%s\n" "$files"
 
 	rc=0
-	for i in $files
+	set -- $files
+	while test $# -ne 0
 	do
 		printf "\n"
-		if ! merge_file "$i"
+		if ! merge_file "$1"
 		then
 			rc=1
-			prompt_after_failed_merge || exit 1
+			test $# -ne 1 && prompt_after_failed_merge || exit 1
 		fi
+		shift
 	done
 
 	exit $rc
diff -pruN 1.2.1+git2.18.0-1/git/git-p4.py 1.2.3+git2.25.1-1/git/git-p4.py
--- 1.2.1+git2.18.0-1/git/git-p4.py	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/git-p4.py	2020-02-17 04:47:35.000000000 +0000
@@ -27,6 +27,22 @@ import zlib
 import ctypes
 import errno
 
+# support basestring in python3
+try:
+    unicode = unicode
+except NameError:
+    # 'unicode' is undefined, must be Python 3
+    str = str
+    unicode = str
+    bytes = bytes
+    basestring = (str,bytes)
+else:
+    # 'unicode' exists, must be Python 2
+    str = str
+    unicode = unicode
+    bytes = str
+    basestring = basestring
+
 try:
     from subprocess import CalledProcessError
 except ImportError:
@@ -151,6 +167,21 @@ def die(msg):
         sys.stderr.write(msg + "\n")
         sys.exit(1)
 
+def prompt(prompt_text):
+    """ Prompt the user to choose one of the choices
+
+    Choices are identified in the prompt_text by square brackets around
+    a single letter option.
+    """
+    choices = set(m.group(1) for m in re.finditer(r"\[(.)\]", prompt_text))
+    while True:
+        response = raw_input(prompt_text).strip().lower()
+        if not response:
+            continue
+        response = response[0]
+        if response in choices:
+            return response
+
 def write_pipe(c, stdin):
     if verbose:
         sys.stderr.write('Writing pipe: %s\n' % str(c))
@@ -316,6 +347,8 @@ def p4_check_access(min_expiration=1):
             die_bad_access("p4 error: {0}".format(data))
         else:
             die_bad_access("unknown error")
+    elif code == "info":
+        return
     else:
         die_bad_access("unknown error code {0}".format(code))
 
@@ -719,7 +752,7 @@ def extractLogMessageFromGitCommit(commi
 
     ## fixme: title is first line of commit, not 1st paragraph.
     foundTitle = False
-    for log in read_pipe_lines("git cat-file commit %s" % commit):
+    for log in read_pipe_lines(["git", "cat-file", "commit", commit]):
        if not foundTitle:
            if len(log) == 1:
                foundTitle = True
@@ -767,7 +800,7 @@ def gitDeleteRef(ref):
 _gitConfig = {}
 
 def gitConfig(key, typeSpecifier=None):
-    if not _gitConfig.has_key(key):
+    if key not in _gitConfig:
         cmd = [ "git", "config" ]
         if typeSpecifier:
             cmd += [ typeSpecifier ]
@@ -781,12 +814,12 @@ def gitConfigBool(key):
        variable is set to true, and False if set to false or not present
        in the config."""
 
-    if not _gitConfig.has_key(key):
+    if key not in _gitConfig:
         _gitConfig[key] = gitConfig(key, '--bool') == "true"
     return _gitConfig[key]
 
 def gitConfigInt(key):
-    if not _gitConfig.has_key(key):
+    if key not in _gitConfig:
         cmd = [ "git", "config", "--int", key ]
         s = read_pipe(cmd, ignore_error=True)
         v = s.strip()
@@ -797,7 +830,7 @@ def gitConfigInt(key):
     return _gitConfig[key]
 
 def gitConfigList(key):
-    if not _gitConfig.has_key(key):
+    if key not in _gitConfig:
         s = read_pipe(["git", "config", "--get-all", key], ignore_error=True)
         _gitConfig[key] = s.strip().splitlines()
         if _gitConfig[key] == ['']:
@@ -855,7 +888,7 @@ def findUpstreamBranchPoint(head = "HEAD
         tip = branches[branch]
         log = extractLogMessageFromGitCommit(tip)
         settings = extractSettingsGitLog(log)
-        if settings.has_key("depot-paths"):
+        if "depot-paths" in settings:
             paths = ",".join(settings["depot-paths"])
             branchByDepotPath[paths] = "remotes/p4/" + branch
 
@@ -865,9 +898,9 @@ def findUpstreamBranchPoint(head = "HEAD
         commit = head + "~%s" % parent
         log = extractLogMessageFromGitCommit(commit)
         settings = extractSettingsGitLog(log)
-        if settings.has_key("depot-paths"):
+        if "depot-paths" in settings:
             paths = ",".join(settings["depot-paths"])
-            if branchByDepotPath.has_key(paths):
+            if paths in branchByDepotPath:
                 return [branchByDepotPath[paths], settings]
 
         parent = parent + 1
@@ -876,7 +909,7 @@ def findUpstreamBranchPoint(head = "HEAD
 
 def createOrUpdateBranchesFromOrigin(localRefPrefix = "refs/remotes/p4/", silent=True):
     if not silent:
-        print ("Creating/updating branch(es) in %s based on origin branch(es)"
+        print("Creating/updating branch(es) in %s based on origin branch(es)"
                % localRefPrefix)
 
     originPrefix = "origin/p4/"
@@ -891,29 +924,29 @@ def createOrUpdateBranchesFromOrigin(loc
         originHead = line
 
         original = extractSettingsGitLog(extractLogMessageFromGitCommit(originHead))
-        if (not original.has_key('depot-paths')
-            or not original.has_key('change')):
+        if ('depot-paths' not in original
+            or 'change' not in original):
             continue
 
         update = False
         if not gitBranchExists(remoteHead):
             if verbose:
-                print "creating %s" % remoteHead
+                print("creating %s" % remoteHead)
             update = True
         else:
             settings = extractSettingsGitLog(extractLogMessageFromGitCommit(remoteHead))
-            if settings.has_key('change') > 0:
+            if 'change' in settings:
                 if settings['depot-paths'] == original['depot-paths']:
                     originP4Change = int(original['change'])
                     p4Change = int(settings['change'])
                     if originP4Change > p4Change:
-                        print ("%s (%s) is newer than %s (%s). "
+                        print("%s (%s) is newer than %s (%s). "
                                "Updating p4 branch from origin."
                                % (originHead, originP4Change,
                                   remoteHead, p4Change))
                         update = True
                 else:
-                    print ("Ignoring: %s was imported from %s while "
+                    print("Ignoring: %s was imported from %s while "
                            "%s was imported from %s"
                            % (originHead, ','.join(original['depot-paths']),
                               remoteHead, ','.join(settings['depot-paths'])))
@@ -1002,7 +1035,7 @@ def p4ChangesForPaths(depotPaths, change
 
         # Insert changes in chronological order
         for entry in reversed(result):
-            if not entry.has_key('change'):
+            if 'change' not in entry:
                 continue
             changes.add(int(entry['change']))
 
@@ -1142,13 +1175,11 @@ class LargeFileSystem(object):
             if contentsSize <= gitConfigInt('git-p4.largeFileCompressedThreshold'):
                 return False
             contentTempFile = self.generateTempFile(contents)
-            compressedContentFile = tempfile.NamedTemporaryFile(prefix='git-p4-large-file', delete=False)
-            zf = zipfile.ZipFile(compressedContentFile.name, mode='w')
-            zf.write(contentTempFile, compress_type=zipfile.ZIP_DEFLATED)
-            zf.close()
-            compressedContentsSize = zf.infolist()[0].compress_size
+            compressedContentFile = tempfile.NamedTemporaryFile(prefix='git-p4-large-file', delete=True)
+            with zipfile.ZipFile(compressedContentFile, mode='w') as zf:
+                zf.write(contentTempFile, compress_type=zipfile.ZIP_DEFLATED)
+                compressedContentsSize = zf.infolist()[0].compress_size
             os.remove(contentTempFile)
-            os.remove(compressedContentFile.name)
             if compressedContentsSize > gitConfigInt('git-p4.largeFileCompressedThreshold'):
                 return True
         return False
@@ -1241,9 +1272,15 @@ class GitLFS(LargeFileSystem):
             pointerFile = re.sub(r'Git LFS pointer for.*\n\n', '', pointerFile)
 
         oid = re.search(r'^oid \w+:(\w+)', pointerFile, re.MULTILINE).group(1)
+        # if someone use external lfs.storage ( not in local repo git )
+        lfs_path = gitConfig('lfs.storage')
+        if not lfs_path:
+            lfs_path = 'lfs'
+        if not os.path.isabs(lfs_path):
+            lfs_path = os.path.join(os.getcwd(), '.git', lfs_path)
         localLargeFile = os.path.join(
-            os.getcwd(),
-            '.git', 'lfs', 'objects', oid[:2], oid[2:4],
+            lfs_path,
+            'objects', oid[:2], oid[2:4],
             oid,
         )
         # LFS Spec states that pointer files should not have the executable bit set.
@@ -1290,12 +1327,15 @@ class GitLFS(LargeFileSystem):
             return LargeFileSystem.processContent(self, git_mode, relPath, contents)
 
 class Command:
+    delete_actions = ( "delete", "move/delete", "purge" )
+    add_actions = ( "add", "branch", "move/add" )
+
     def __init__(self):
         self.usage = "usage: %prog [options]"
         self.needsGit = True
         self.verbose = False
 
-    # This is required for the "append" cloneExclude action
+    # This is required for the "append" update_shelve action
     def ensure_value(self, attr, value):
         if not hasattr(self, attr) or getattr(self, attr) is None:
             setattr(self, attr, value)
@@ -1312,7 +1352,7 @@ class P4UserMap:
 
         results = p4CmdList("user -o")
         for r in results:
-            if r.has_key('User'):
+            if 'User' in r:
                 self.myP4UserId = r['User']
                 return r['User']
         die("Could not find your p4 user id")
@@ -1336,7 +1376,7 @@ class P4UserMap:
         self.emails = {}
 
         for output in p4CmdList("users"):
-            if not output.has_key("User"):
+            if "User" not in output:
                 continue
             self.users[output["User"]] = output["FullName"] + " <" + output["Email"] + ">"
             self.emails[output["Email"]] = output["User"]
@@ -1381,9 +1421,9 @@ class P4Debug(Command):
     def run(self, args):
         j = 0
         for output in p4CmdList(args):
-            print 'Element: %d' % j
+            print('Element: %d' % j)
             j += 1
-            print output
+            print(output)
         return True
 
 class P4RollBack(Command):
@@ -1424,14 +1464,14 @@ class P4RollBack(Command):
 
                 if len(p4Cmd("changes -m 1 "  + ' '.join (['%s...@%s' % (p, maxChange)
                                                            for p in depotPaths]))) == 0:
-                    print "Branch %s did not exist at change %s, deleting." % (ref, maxChange)
+                    print("Branch %s did not exist at change %s, deleting." % (ref, maxChange))
                     system("git update-ref -d %s `git rev-parse %s`" % (ref, ref))
                     continue
 
                 while change and int(change) > maxChange:
                     changed = True
                     if self.verbose:
-                        print "%s is at %s ; rewinding towards %s" % (ref, change, maxChange)
+                        print("%s is at %s ; rewinding towards %s" % (ref, change, maxChange))
                     system("git update-ref %s \"%s^\"" % (ref, ref))
                     log = extractLogMessageFromGitCommit(ref)
                     settings =  extractSettingsGitLog(log)
@@ -1441,7 +1481,7 @@ class P4RollBack(Command):
                     change = settings['change']
 
                 if changed:
-                    print "%s rewound to %s" % (ref, change)
+                    print("%s rewound to %s" % (ref, change))
 
         return True
 
@@ -1478,7 +1518,13 @@ class P4Submit(Command, P4UserMap):
                 optparse.make_option("--disable-p4sync", dest="disable_p4sync", action="store_true",
                                      help="Skip Perforce sync of p4/master after submit or shelve"),
         ]
-        self.description = "Submit changes from git to the perforce depot."
+        self.description = """Submit changes from git to the perforce depot.\n
+    The `p4-pre-submit` hook is executed if it exists and is executable.
+    The hook takes no parameters and nothing from standard input. Exiting with
+    non-zero status from this script prevents `git-p4 submit` from launching.
+
+    One usage scenario is to run unit tests in the hook."""
+
         self.usage += " [name of git branch to submit into perforce depot]"
         self.origin = ""
         self.detectRenames = False
@@ -1577,10 +1623,10 @@ class P4Submit(Command, P4UserMap):
         except:
             # cleanup our temporary file
             os.unlink(outFileName)
-            print "Failed to strip RCS keywords in %s" % file
+            print("Failed to strip RCS keywords in %s" % file)
             raise
 
-        print "Patched up RCS keywords in %s" % file
+        print("Patched up RCS keywords in %s" % file)
 
     def p4UserForCommit(self,id):
         # Return the tuple (perforce user,git email) for a given git commit id
@@ -1588,7 +1634,7 @@ class P4Submit(Command, P4UserMap):
         gitEmail = read_pipe(["git", "log", "--max-count=1",
                               "--format=%ae", id])
         gitEmail = gitEmail.strip()
-        if not self.emails.has_key(gitEmail):
+        if gitEmail not in self.emails:
             return (None,gitEmail)
         else:
             return (self.emails[gitEmail],gitEmail)
@@ -1600,7 +1646,7 @@ class P4Submit(Command, P4UserMap):
             if not user:
                 msg = "Cannot find p4 user for email %s in commit %s." % (email, id)
                 if gitConfigBool("git-p4.allowMissingP4Users"):
-                    print "%s" % msg
+                    print("%s" % msg)
                 else:
                     die("Error: %s\nSet git-p4.allowMissingP4Users to true to allow this." % msg)
 
@@ -1612,14 +1658,14 @@ class P4Submit(Command, P4UserMap):
         results = p4CmdList("client -o")        # find the current client
         client = None
         for r in results:
-            if r.has_key('Client'):
+            if 'Client' in r:
                 client = r['Client']
                 break
         if not client:
             die("could not get client spec")
         results = p4CmdList(["changes", "-c", client, "-m", "1"])
         for r in results:
-            if r.has_key('change'):
+            if 'change' in r:
                 return r['change']
         die("Could not get changelist number for last submit - cannot patch up user details")
 
@@ -1637,10 +1683,10 @@ class P4Submit(Command, P4UserMap):
 
         result = p4CmdList("change -f -i", stdin=input)
         for r in result:
-            if r.has_key('code'):
+            if 'code' in r:
                 if r['code'] == 'error':
                     die("Could not modify user field of changelist %s to %s:%s" % (changelist, newUser, r['data']))
-            if r.has_key('data'):
+            if 'data' in r:
                 print("Updated user field for changelist %s to %s" % (changelist, newUser))
                 return
         die("Could not modify user field of changelist %s to %s" % (changelist, newUser))
@@ -1650,7 +1696,7 @@ class P4Submit(Command, P4UserMap):
         # which are required to modify changelists.
         results = p4CmdList(["protects", self.depotPath])
         for r in results:
-            if r.has_key('perm'):
+            if 'perm' in r:
                 if r['perm'] == 'admin':
                     return 1
                 if r['perm'] == 'super':
@@ -1690,7 +1736,7 @@ class P4Submit(Command, P4UserMap):
         if changelist:
             args.append(str(changelist))
         for entry in p4CmdList(args):
-            if not entry.has_key('code'):
+            if 'code' not in entry:
                 continue
             if entry['code'] == 'stat':
                 change_entry = entry
@@ -1699,7 +1745,7 @@ class P4Submit(Command, P4UserMap):
             die('Failed to decode output of p4 change -o')
         for key, value in change_entry.iteritems():
             if key.startswith('File'):
-                if settings.has_key('depot-paths'):
+                if 'depot-paths' in settings:
                     if not [p for p in settings['depot-paths']
                             if p4PathStartsWith(value, p)]:
                         continue
@@ -1710,7 +1756,7 @@ class P4Submit(Command, P4UserMap):
                 continue
         # Output in the order expected by prepareLogMessage
         for key in ['Change', 'Client', 'User', 'Status', 'Description', 'Jobs']:
-            if not change_entry.has_key(key):
+            if key not in change_entry:
                 continue
             template += '\n'
             template += key + ':'
@@ -1738,7 +1784,7 @@ class P4Submit(Command, P4UserMap):
         mtime = os.stat(template_file).st_mtime
 
         # invoke the editor
-        if os.environ.has_key("P4EDITOR") and (os.environ.get("P4EDITOR") != ""):
+        if "P4EDITOR" in os.environ and (os.environ.get("P4EDITOR") != ""):
             editor = os.environ.get("P4EDITOR")
         else:
             editor = read_pipe("git var GIT_EDITOR").strip()
@@ -1753,16 +1799,15 @@ class P4Submit(Command, P4UserMap):
         if os.stat(template_file).st_mtime > mtime:
             return True
 
-        while True:
-            response = raw_input("Submit template unchanged. Submit anyway? [y]es, [n]o (skip this patch) ")
-            if response == 'y':
-                return True
-            if response == 'n':
-                return False
+        response = prompt("Submit template unchanged. Submit anyway? [y]es, [n]o (skip this patch) ")
+        if response == 'y':
+            return True
+        if response == 'n':
+            return False
 
     def get_diff_description(self, editedFiles, filesToAdd, symlinks):
         # diff
-        if os.environ.has_key("P4DIFF"):
+        if "P4DIFF" in os.environ:
             del(os.environ["P4DIFF"])
         diff = ""
         for editedFile in editedFiles:
@@ -1792,8 +1837,8 @@ class P4Submit(Command, P4UserMap):
     def applyCommit(self, id):
         """Apply one commit, return True if it succeeded."""
 
-        print "Applying", read_pipe(["git", "show", "-s",
-                                     "--format=format:%h %s", id])
+        print("Applying", read_pipe(["git", "show", "-s",
+                                     "--format=format:%h %s", id]))
 
         (p4User, gitEmail) = self.p4UserForCommit(id)
 
@@ -1825,7 +1870,7 @@ class P4Submit(Command, P4UserMap):
                     filesToDelete.remove(path)
 
                 dst_mode = int(diff['dst_mode'], 8)
-                if dst_mode == 0120000:
+                if dst_mode == 0o120000:
                     symlinks.add(path)
 
             elif modifier == "D":
@@ -1834,6 +1879,7 @@ class P4Submit(Command, P4UserMap):
                     filesToAdd.remove(path)
             elif modifier == "C":
                 src, dest = diff['src'], diff['dst']
+                all_files.append(dest)
                 p4_integrate(src, dest)
                 pureRenameCopy.add(dest)
                 if diff['src_sha1'] != diff['dst_sha1']:
@@ -1850,6 +1896,7 @@ class P4Submit(Command, P4UserMap):
                 editedFiles.add(dest)
             elif modifier == "R":
                 src, dest = diff['src'], diff['dst']
+                all_files.append(dest)
                 if self.p4HasMoveCommand:
                     p4_edit(src)        # src must be open before move
                     p4_move(src, dest)  # opens for (move/delete, move/add)
@@ -1883,7 +1930,7 @@ class P4Submit(Command, P4UserMap):
         if os.system(tryPatchCmd) != 0:
             fixed_rcs_keywords = False
             patch_succeeded = False
-            print "Unfortunately applying the change failed!"
+            print("Unfortunately applying the change failed!")
 
             # Patch failed, maybe it's just RCS keyword woes. Look through
             # the patch to see if that's possible.
@@ -1901,13 +1948,13 @@ class P4Submit(Command, P4UserMap):
                         for line in read_pipe_lines(["git", "diff", "%s^..%s" % (id, id), file]):
                             if regexp.search(line):
                                 if verbose:
-                                    print "got keyword match on %s in %s in %s" % (pattern, line, file)
+                                    print("got keyword match on %s in %s in %s" % (pattern, line, file))
                                 kwfiles[file] = pattern
                                 break
 
                 for file in kwfiles:
                     if verbose:
-                        print "zapping %s with %s" % (line,pattern)
+                        print("zapping %s with %s" % (line,pattern))
                     # File is being deleted, so not open in p4.  Must
                     # disable the read-only bit on windows.
                     if self.isWindows and file not in editedFiles:
@@ -1916,7 +1963,7 @@ class P4Submit(Command, P4UserMap):
                     fixed_rcs_keywords = True
 
             if fixed_rcs_keywords:
-                print "Retrying the patch with RCS keywords cleaned up"
+                print("Retrying the patch with RCS keywords cleaned up")
                 if os.system(tryPatchCmd) == 0:
                     patch_succeeded = True
 
@@ -1984,34 +2031,34 @@ class P4Submit(Command, P4UserMap):
             # Leave the p4 tree prepared, and the submit template around
             # and let the user decide what to do next
             #
-            print
-            print "P4 workspace prepared for submission."
-            print "To submit or revert, go to client workspace"
-            print "  " + self.clientPath
-            print
-            print "To submit, use \"p4 submit\" to write a new description,"
-            print "or \"p4 submit -i <%s\" to use the one prepared by" \
-                  " \"git p4\"." % fileName
-            print "You can delete the file \"%s\" when finished." % fileName
+            print()
+            print("P4 workspace prepared for submission.")
+            print("To submit or revert, go to client workspace")
+            print("  " + self.clientPath)
+            print()
+            print("To submit, use \"p4 submit\" to write a new description,")
+            print("or \"p4 submit -i <%s\" to use the one prepared by" \
+                  " \"git p4\"." % fileName)
+            print("You can delete the file \"%s\" when finished." % fileName)
 
             if self.preserveUser and p4User and not self.p4UserIsMe(p4User):
-                print "To preserve change ownership by user %s, you must\n" \
+                print("To preserve change ownership by user %s, you must\n" \
                       "do \"p4 change -f <change>\" after submitting and\n" \
-                      "edit the User field."
+                      "edit the User field.")
             if pureRenameCopy:
-                print "After submitting, renamed files must be re-synced."
-                print "Invoke \"p4 sync -f\" on each of these files:"
+                print("After submitting, renamed files must be re-synced.")
+                print("Invoke \"p4 sync -f\" on each of these files:")
                 for f in pureRenameCopy:
-                    print "  " + f
+                    print("  " + f)
 
-            print
-            print "To revert the changes, use \"p4 revert ...\", and delete"
-            print "the submit template file \"%s\"" % fileName
+            print()
+            print("To revert the changes, use \"p4 revert ...\", and delete")
+            print("the submit template file \"%s\"" % fileName)
             if filesToAdd:
-                print "Since the commit adds new files, they must be deleted:"
+                print("Since the commit adds new files, they must be deleted:")
                 for f in filesToAdd:
-                    print "  " + f
-            print
+                    print("  " + f)
+            print()
             return True
 
         #
@@ -2078,17 +2125,17 @@ class P4Submit(Command, P4UserMap):
 
             if not m.match(name):
                 if verbose:
-                    print "tag %s does not match regexp %s" % (name, validLabelRegexp)
+                    print("tag %s does not match regexp %s" % (name, validLabelRegexp))
                 continue
 
             # Get the p4 commit this corresponds to
             logMessage = extractLogMessageFromGitCommit(name)
             values = extractSettingsGitLog(logMessage)
 
-            if not values.has_key('change'):
+            if 'change' not in values:
                 # a tag pointing to something not sent to p4; ignore
                 if verbose:
-                    print "git tag %s does not give a p4 commit" % name
+                    print("git tag %s does not give a p4 commit" % name)
                 continue
             else:
                 changelist = values['change']
@@ -2123,10 +2170,10 @@ class P4Submit(Command, P4UserMap):
                 labelTemplate += "\t%s\n" % depot_side
 
             if self.dry_run:
-                print "Would create p4 label %s for tag" % name
+                print("Would create p4 label %s for tag" % name)
             elif self.prepare_p4_only:
-                print "Not creating p4 label %s for tag due to option" \
-                      " --prepare-p4-only" % name
+                print("Not creating p4 label %s for tag due to option" \
+                      " --prepare-p4-only" % name)
             else:
                 p4_write_pipe(["label", "-i"], labelTemplate)
 
@@ -2135,7 +2182,7 @@ class P4Submit(Command, P4UserMap):
                           ["%s@%s" % (depot_side, changelist) for depot_side in clientSpec.mappings])
 
                 if verbose:
-                    print "created p4 label for tag %s" % name
+                    print("created p4 label for tag %s" % name)
 
     def run(self, args):
         if len(args) == 0:
@@ -2179,10 +2226,10 @@ class P4Submit(Command, P4UserMap):
             self.conflict_behavior = val
 
         if self.verbose:
-            print "Origin branch is " + self.origin
+            print("Origin branch is " + self.origin)
 
         if len(self.depotPath) == 0:
-            print "Internal error: cannot locate perforce depot path from existing branches"
+            print("Internal error: cannot locate perforce depot path from existing branches")
             sys.exit(128)
 
         self.useClientSpec = False
@@ -2203,7 +2250,7 @@ class P4Submit(Command, P4UserMap):
         if self.clientPath == "":
             die("Error: Cannot locate perforce checkout of %s in client view" % self.depotPath)
 
-        print "Perforce checkout for depot path %s located at %s" % (self.depotPath, self.clientPath)
+        print("Perforce checkout for depot path %s located at %s" % (self.depotPath, self.clientPath))
         self.oldWorkingDirectory = os.getcwd()
 
         # ensure the clientPath exists
@@ -2214,9 +2261,9 @@ class P4Submit(Command, P4UserMap):
 
         chdir(self.clientPath, is_client_path=True)
         if self.dry_run:
-            print "Would synchronize p4 checkout in %s" % self.clientPath
+            print("Would synchronize p4 checkout in %s" % self.clientPath)
         else:
-            print "Synchronizing p4 checkout..."
+            print("Synchronizing p4 checkout...")
             if new_client_dir:
                 # old one was destroyed, and maybe nobody told p4
                 p4_sync("...", "-f")
@@ -2287,18 +2334,26 @@ class P4Submit(Command, P4UserMap):
             sys.exit("number of commits (%d) must match number of shelved changelist (%d)" %
                      (len(commits), num_shelves))
 
+        hooks_path = gitConfig("core.hooksPath")
+        if len(hooks_path) <= 0:
+            hooks_path = os.path.join(os.environ.get("GIT_DIR", ".git"), "hooks")
+
+        hook_file = os.path.join(hooks_path, "p4-pre-submit")
+        if os.path.isfile(hook_file) and os.access(hook_file, os.X_OK) and subprocess.call([hook_file]) != 0:
+            sys.exit(1)
+
         #
         # Apply the commits, one at a time.  On failure, ask if should
         # continue to try the rest of the patches, or quit.
         #
         if self.dry_run:
-            print "Would apply"
+            print("Would apply")
         applied = []
         last = len(commits) - 1
         for i, commit in enumerate(commits):
             if self.dry_run:
-                print " ", read_pipe(["git", "show", "-s",
-                                      "--format=format:%h %s", commit])
+                print(" ", read_pipe(["git", "show", "-s",
+                                      "--format=format:%h %s", commit]))
                 ok = True
             else:
                 ok = self.applyCommit(commit)
@@ -2306,35 +2361,26 @@ class P4Submit(Command, P4UserMap):
                 applied.append(commit)
             else:
                 if self.prepare_p4_only and i < last:
-                    print "Processing only the first commit due to option" \
-                          " --prepare-p4-only"
+                    print("Processing only the first commit due to option" \
+                          " --prepare-p4-only")
                     break
                 if i < last:
-                    quit = False
-                    while True:
-                        # prompt for what to do, or use the option/variable
-                        if self.conflict_behavior == "ask":
-                            print "What do you want to do?"
-                            response = raw_input("[s]kip this commit but apply"
-                                                 " the rest, or [q]uit? ")
-                            if not response:
-                                continue
-                        elif self.conflict_behavior == "skip":
-                            response = "s"
-                        elif self.conflict_behavior == "quit":
-                            response = "q"
-                        else:
-                            die("Unknown conflict_behavior '%s'" %
-                                self.conflict_behavior)
+                    # prompt for what to do, or use the option/variable
+                    if self.conflict_behavior == "ask":
+                        print("What do you want to do?")
+                        response = prompt("[s]kip this commit but apply the rest, or [q]uit? ")
+                    elif self.conflict_behavior == "skip":
+                        response = "s"
+                    elif self.conflict_behavior == "quit":
+                        response = "q"
+                    else:
+                        die("Unknown conflict_behavior '%s'" %
+                            self.conflict_behavior)
 
-                        if response[0] == "s":
-                            print "Skipping this commit, but applying the rest"
-                            break
-                        if response[0] == "q":
-                            print "Quitting"
-                            quit = True
-                            break
-                    if quit:
+                    if response == "s":
+                        print("Skipping this commit, but applying the rest")
+                    if response == "q":
+                        print("Quitting")
                         break
 
         chdir(self.oldWorkingDirectory)
@@ -2344,7 +2390,7 @@ class P4Submit(Command, P4UserMap):
         elif self.prepare_p4_only:
             pass
         elif len(commits) == len(applied):
-            print ("All commits {0}!".format(shelved_applied))
+            print("All commits {0}!".format(shelved_applied))
 
             sync = P4Sync()
             if self.branch:
@@ -2360,17 +2406,17 @@ class P4Submit(Command, P4UserMap):
 
         else:
             if len(applied) == 0:
-                print ("No commits {0}.".format(shelved_applied))
+                print("No commits {0}.".format(shelved_applied))
             else:
-                print ("{0} only the commits marked with '*':".format(shelved_applied.capitalize()))
+                print("{0} only the commits marked with '*':".format(shelved_applied.capitalize()))
                 for c in commits:
                     if c in applied:
                         star = "*"
                     else:
                         star = " "
-                    print star, read_pipe(["git", "show", "-s",
-                                           "--format=format:%h %s",  c])
-                print "You will have to do 'git p4 sync' and rebase."
+                    print(star, read_pipe(["git", "show", "-s",
+                                           "--format=format:%h %s",  c]))
+                print("You will have to do 'git p4 sync' and rebase.")
 
         if gitConfigBool("git-p4.exportLabels"):
             self.exportLabels = True
@@ -2493,8 +2539,12 @@ class View(object):
         die( "Error: %s is not found in client spec path" % depot_path )
         return ""
 
+def cloneExcludeCallback(option, opt_str, value, parser):
+    # prepend "/" because the first "/" was consumed as part of the option itself.
+    # ("-//depot/A/..." becomes "/depot/A/..." after option parsing)
+    parser.values.cloneExclude += ["/" + re.sub(r"\.\.\.$", "", value)]
+
 class P4Sync(Command, P4UserMap):
-    delete_actions = ( "delete", "move/delete", "purge" )
 
     def __init__(self):
         Command.__init__(self)
@@ -2517,7 +2567,7 @@ class P4Sync(Command, P4UserMap):
                 optparse.make_option("--use-client-spec", dest="useClientSpec", action='store_true',
                                      help="Only sync files that are included in the Perforce Client Spec"),
                 optparse.make_option("-/", dest="cloneExclude",
-                                     action="append", type="string",
+                                     action="callback", callback=cloneExcludeCallback, type="string",
                                      help="exclude depot path"),
         ]
         self.description = """Imports from Perforce into a git repository.\n
@@ -2580,35 +2630,27 @@ class P4Sync(Command, P4UserMap):
         self.gitStream.write("progress checkpoint\n\n")
         out = self.gitOutput.readline()
         if self.verbose:
-            print "checkpoint finished: " + out
-
-    def cmp_shelved(self, path, filerev, revision):
-        """ Determine if a path at revision #filerev is the same as the file
-            at revision @revision for a shelved changelist. If they don't match,
-            unshelving won't be safe (we will get other changes mixed in).
+            print("checkpoint finished: " + out)
 
-            This is comparing the revision that the shelved changelist is *based* on, not
-            the shelved changelist itself.
-        """
-        ret = p4Cmd(["diff2", "{0}#{1}".format(path, filerev), "{0}@{1}".format(path, revision)])
-        if verbose:
-            print("p4 diff2 path %s filerev %s revision %s => %s" % (path, filerev, revision, ret))
-        return ret["status"] == "identical"
+    def isPathWanted(self, path):
+        for p in self.cloneExclude:
+            if p.endswith("/"):
+                if p4PathStartsWith(path, p):
+                    return False
+            # "-//depot/file1" without a trailing "/" should only exclude "file1", but not "file111" or "file1_dir/file2"
+            elif path.lower() == p.lower():
+                return False
+        for p in self.depotPaths:
+            if p4PathStartsWith(path, p):
+                return True
+        return False
 
-    def extractFilesFromCommit(self, commit, shelved=False, shelved_cl = 0, origin_revision = 0):
-        self.cloneExclude = [re.sub(r"\.\.\.$", "", path)
-                             for path in self.cloneExclude]
+    def extractFilesFromCommit(self, commit, shelved=False, shelved_cl = 0):
         files = []
         fnum = 0
-        while commit.has_key("depotFile%s" % fnum):
+        while "depotFile%s" % fnum in commit:
             path =  commit["depotFile%s" % fnum]
-
-            if [p for p in self.cloneExclude
-                if p4PathStartsWith(path, p)]:
-                found = False
-            else:
-                found = [p for p in self.depotPaths
-                         if p4PathStartsWith(path, p)]
+            found = self.isPathWanted(path)
             if not found:
                 fnum = fnum + 1
                 continue
@@ -2620,17 +2662,6 @@ class P4Sync(Command, P4UserMap):
             file["type"] = commit["type%s" % fnum]
             if shelved:
                 file["shelved_cl"] = int(shelved_cl)
-
-                # For shelved changelists, check that the revision of each file that the
-                # shelve was based on matches the revision that we are using for the
-                # starting point for git-fast-import (self.initialParent). Otherwise
-                # the resulting diff will contain deltas from multiple commits.
-
-                if file["action"] != "add" and \
-                    not self.cmp_shelved(path, file["rev"], origin_revision):
-                    sys.exit("change {0} not based on {1} for {2}, cannot unshelve".format(
-                        commit["change"], self.initialParent, path))
-
             files.append(file)
             fnum = fnum + 1
         return files
@@ -2638,7 +2669,7 @@ class P4Sync(Command, P4UserMap):
     def extractJobsFromCommit(self, commit):
         jobs = []
         jnum = 0
-        while commit.has_key("job%s" % jnum):
+        while "job%s" % jnum in commit:
             job = commit["job%s" % jnum]
             jobs.append(job)
             jnum = jnum + 1
@@ -2656,7 +2687,7 @@ class P4Sync(Command, P4UserMap):
             path = self.clientSpecDirs.map_in_client(path)
             if self.detectBranches:
                 for b in self.knownBranches:
-                    if path.startswith(b + "/"):
+                    if p4PathStartsWith(path, b + "/"):
                         path = path[len(b)+1:]
 
         elif self.keepRepoPath:
@@ -2686,10 +2717,9 @@ class P4Sync(Command, P4UserMap):
 
         branches = {}
         fnum = 0
-        while commit.has_key("depotFile%s" % fnum):
+        while "depotFile%s" % fnum in commit:
             path =  commit["depotFile%s" % fnum]
-            found = [p for p in self.depotPaths
-                     if p4PathStartsWith(path, p)]
+            found = self.isPathWanted(path)
             if not found:
                 fnum = fnum + 1
                 continue
@@ -2711,7 +2741,7 @@ class P4Sync(Command, P4UserMap):
             for branch in self.knownBranches.keys():
                 # add a trailing slash so that a commit into qt/4.2foo
                 # doesn't end up in qt/4.2, e.g.
-                if relPath.startswith(branch + "/"):
+                if p4PathStartsWith(relPath, branch + "/"):
                     if branch not in branches:
                         branches[branch] = []
                     branches[branch].append(file)
@@ -2735,7 +2765,7 @@ class P4Sync(Command, P4UserMap):
                 encoding = gitConfig('git-p4.pathEncoding')
             path = path.decode(encoding, 'replace').encode('utf8', 'replace')
             if self.verbose:
-                print 'Path with non-ASCII characters detected. Used %s to encode: %s ' % (encoding, path)
+                print('Path with non-ASCII characters detected. Used %s to encode: %s ' % (encoding, path))
         return path
 
     # output one file from the P4 stream
@@ -2745,7 +2775,10 @@ class P4Sync(Command, P4UserMap):
         relPath = self.stripRepoPath(file['depotFile'], self.branchPrefixes)
         relPath = self.encodeWithUTF8(relPath)
         if verbose:
-            size = int(self.stream_file['fileSize'])
+            if 'fileSize' in self.stream_file:
+                size = int(self.stream_file['fileSize'])
+            else:
+                size = 0 # deleted files don't get a fileSize apparently
             sys.stdout.write('\r%s --> %s (%i MB)\n' % (file['depotFile'], relPath, size/1024/1024))
             sys.stdout.flush()
 
@@ -2764,7 +2797,7 @@ class P4Sync(Command, P4UserMap):
                 # to nothing.  This causes p4 errors when checking out such
                 # a change, and errors here too.  Work around it by ignoring
                 # the bad symlink; hopefully a future change fixes it.
-                print "\nIgnoring empty symlink in %s" % file['depotFile']
+                print("\nIgnoring empty symlink in %s" % file['depotFile'])
                 return
             elif data[-1] == '\n':
                 contents = [data[:-1]]
@@ -2804,7 +2837,7 @@ class P4Sync(Command, P4UserMap):
             # Ideally, someday, this script can learn how to generate
             # appledouble files directly and import those to git, but
             # non-mac machines can never find a use for apple filetype.
-            print "\nIgnoring apple filetype file %s" % file['depotFile']
+            print("\nIgnoring apple filetype file %s" % file['depotFile'])
             return
 
         # Note that we do not try to de-mangle keywords on utf16 files,
@@ -2866,7 +2899,7 @@ class P4Sync(Command, P4UserMap):
             else:
                 die("Error from p4 print: %s" % err)
 
-        if marshalled.has_key('depotFile') and self.stream_have_file_info:
+        if 'depotFile' in marshalled and self.stream_have_file_info:
             # start of a new file - output the old one first
             self.streamOneP4File(self.stream_file, self.stream_contents)
             self.stream_file = {}
@@ -2938,7 +2971,7 @@ class P4Sync(Command, P4UserMap):
                       cb=streamP4FilesCbSelf)
 
             # do the last chunk
-            if self.stream_file.has_key('depotFile'):
+            if 'depotFile' in self.stream_file:
                 self.streamOneP4File(self.stream_file, self.stream_contents)
 
     def make_email(self, userid):
@@ -2953,11 +2986,11 @@ class P4Sync(Command, P4UserMap):
         """
 
         if verbose:
-            print "writing tag %s for commit %s" % (labelName, commit)
+            print("writing tag %s for commit %s" % (labelName, commit))
         gitStream.write("tag %s\n" % labelName)
         gitStream.write("from %s\n" % commit)
 
-        if labelDetails.has_key('Owner'):
+        if 'Owner' in labelDetails:
             owner = labelDetails["Owner"]
         else:
             owner = None
@@ -2972,8 +3005,8 @@ class P4Sync(Command, P4UserMap):
 
         gitStream.write("tagger %s\n" % tagger)
 
-        print "labelDetails=",labelDetails
-        if labelDetails.has_key('Description'):
+        print("labelDetails=",labelDetails)
+        if 'Description' in labelDetails:
             description = labelDetails['Description']
         else:
             description = 'Label from git p4'
@@ -2999,7 +3032,7 @@ class P4Sync(Command, P4UserMap):
             print('Ignoring file outside of prefix: {0}'.format(path))
         return hasPrefix
 
-    def commit(self, details, files, branch, parent = ""):
+    def commit(self, details, files, branch, parent = "", allow_empty=False):
         epoch = details["time"]
         author = details["user"]
         jobs = self.extractJobsFromCommit(details)
@@ -3013,7 +3046,10 @@ class P4Sync(Command, P4UserMap):
         files = [f for f in files
             if self.inClientSpec(f['path']) and self.hasBranchPrefix(f['path'])]
 
-        if not files and not gitConfigBool('git-p4.keepEmptyCommits'):
+        if gitConfigBool('git-p4.keepEmptyCommits'):
+            allow_empty = True
+
+        if not files and not allow_empty:
             print('Ignoring revision {0} as it would produce an empty commit.'
                 .format(details['change']))
             return
@@ -3044,7 +3080,7 @@ class P4Sync(Command, P4UserMap):
 
         if len(parent) > 0:
             if self.verbose:
-                print "parent %s" % parent
+                print("parent %s" % parent)
             self.gitStream.write("from %s\n" % parent)
 
         self.streamP4Files(files)
@@ -3052,12 +3088,12 @@ class P4Sync(Command, P4UserMap):
 
         change = int(details["change"])
 
-        if self.labels.has_key(change):
+        if change in self.labels:
             label = self.labels[change]
             labelDetails = label[0]
             labelRevisions = label[1]
             if self.verbose:
-                print "Change %s is labelled %s" % (change, labelDetails)
+                print("Change %s is labelled %s" % (change, labelDetails))
 
             files = p4CmdList(["files"] + ["%s...@%s" % (p, change)
                                                 for p in self.branchPrefixes])
@@ -3075,12 +3111,12 @@ class P4Sync(Command, P4UserMap):
 
                 else:
                     if not self.silent:
-                        print ("Tag %s does not match with change %s: files do not match."
+                        print("Tag %s does not match with change %s: files do not match."
                                % (labelDetails["label"], change))
 
             else:
                 if not self.silent:
-                    print ("Tag %s does not match with change %s: file count is different."
+                    print("Tag %s does not match with change %s: file count is different."
                            % (labelDetails["label"], change))
 
     # Build a dictionary of changelists and labels, for "detect-labels" option.
@@ -3089,14 +3125,14 @@ class P4Sync(Command, P4UserMap):
 
         l = p4CmdList(["labels"] + ["%s..." % p for p in self.depotPaths])
         if len(l) > 0 and not self.silent:
-            print "Finding files belonging to labels in %s" % `self.depotPaths`
+            print("Finding files belonging to labels in %s" % self.depotPaths)
 
         for output in l:
             label = output["label"]
             revisions = {}
             newestChange = 0
             if self.verbose:
-                print "Querying files for label %s" % label
+                print("Querying files for label %s" % label)
             for file in p4CmdList(["files"] +
                                       ["%s...@%s" % (p, label)
                                           for p in self.depotPaths]):
@@ -3108,7 +3144,7 @@ class P4Sync(Command, P4UserMap):
             self.labels[newestChange] = [output, revisions]
 
         if self.verbose:
-            print "Label changes: %s" % self.labels.keys()
+            print("Label changes: %s" % self.labels.keys())
 
     # Import p4 labels as git tags. A direct mapping does not
     # exist, so assume that if all the files are at the same revision
@@ -3116,7 +3152,7 @@ class P4Sync(Command, P4UserMap):
     # just ignore.
     def importP4Labels(self, stream, p4Labels):
         if verbose:
-            print "import p4 labels: " + ' '.join(p4Labels)
+            print("import p4 labels: " + ' '.join(p4Labels))
 
         ignoredP4Labels = gitConfigList("git-p4.ignoredP4Labels")
         validLabelRegexp = gitConfig("git-p4.labelImportRegexp")
@@ -3129,7 +3165,7 @@ class P4Sync(Command, P4UserMap):
 
             if not m.match(name):
                 if verbose:
-                    print "label %s does not match regexp %s" % (name,validLabelRegexp)
+                    print("label %s does not match regexp %s" % (name,validLabelRegexp))
                 continue
 
             if name in ignoredP4Labels:
@@ -3141,7 +3177,7 @@ class P4Sync(Command, P4UserMap):
             change = p4Cmd(["changes", "-m", "1"] + ["%s...@%s" % (p, name)
                                 for p in self.depotPaths])
 
-            if change.has_key('change'):
+            if 'change' in change:
                 # find the corresponding git commit; take the oldest commit
                 changelist = int(change['change'])
                 if changelist in self.committedChanges:
@@ -3151,7 +3187,7 @@ class P4Sync(Command, P4UserMap):
                     gitCommit = read_pipe(["git", "rev-list", "--max-count=1",
                         "--reverse", ":/\[git-p4:.*change = %d\]" % changelist], ignore_error=True)
                     if len(gitCommit) == 0:
-                        print "importing label %s: could not find git commit for changelist %d" % (name, changelist)
+                        print("importing label %s: could not find git commit for changelist %d" % (name, changelist))
                     else:
                         commitFound = True
                         gitCommit = gitCommit.strip()
@@ -3161,16 +3197,16 @@ class P4Sync(Command, P4UserMap):
                     try:
                         tmwhen = time.strptime(labelDetails['Update'], "%Y/%m/%d %H:%M:%S")
                     except ValueError:
-                        print "Could not convert label time %s" % labelDetails['Update']
+                        print("Could not convert label time %s" % labelDetails['Update'])
                         tmwhen = 1
 
                     when = int(time.mktime(tmwhen))
                     self.streamTag(stream, name, labelDetails, gitCommit, when)
                     if verbose:
-                        print "p4 label %s mapped to git commit %s" % (name, gitCommit)
+                        print("p4 label %s mapped to git commit %s" % (name, gitCommit))
             else:
                 if verbose:
-                    print "Label %s has no changelists - possibly deleted?" % name
+                    print("Label %s has no changelists - possibly deleted?" % name)
 
             if not commitFound:
                 # We can't import this label; don't try again as it will get very
@@ -3200,7 +3236,7 @@ class P4Sync(Command, P4UserMap):
         for info in p4CmdList(command):
             details = p4Cmd(["branch", "-o", info["branch"]])
             viewIdx = 0
-            while details.has_key("View%s" % viewIdx):
+            while "View%s" % viewIdx in details:
                 paths = details["View%s" % viewIdx].split(" ")
                 viewIdx = viewIdx + 1
                 # require standard //depot/foo/... //depot/bar/... mapping
@@ -3215,8 +3251,8 @@ class P4Sync(Command, P4UserMap):
 
                     if destination in self.knownBranches:
                         if not self.silent:
-                            print "p4 branch %s defines a mapping from %s to %s" % (info["branch"], source, destination)
-                            print "but there exists another mapping from %s to %s already!" % (self.knownBranches[destination], destination)
+                            print("p4 branch %s defines a mapping from %s to %s" % (info["branch"], source, destination))
+                            print("but there exists another mapping from %s to %s already!" % (self.knownBranches[destination], destination))
                         continue
 
                     self.knownBranches[destination] = source
@@ -3266,7 +3302,7 @@ class P4Sync(Command, P4UserMap):
         d["options"] = ' '.join(sorted(option_keys.keys()))
 
     def readOptions(self, d):
-        self.keepRepoPath = (d.has_key('options')
+        self.keepRepoPath = ('options' in d
                              and ('keepRepoPath' in d['options']))
 
     def gitRefForBranch(self, branch):
@@ -3280,34 +3316,36 @@ class P4Sync(Command, P4UserMap):
 
     def gitCommitByP4Change(self, ref, change):
         if self.verbose:
-            print "looking in ref " + ref + " for change %s using bisect..." % change
+            print("looking in ref " + ref + " for change %s using bisect..." % change)
 
         earliestCommit = ""
         latestCommit = parseRevision(ref)
 
         while True:
             if self.verbose:
-                print "trying: earliest %s latest %s" % (earliestCommit, latestCommit)
+                print("trying: earliest %s latest %s" % (earliestCommit, latestCommit))
             next = read_pipe("git rev-list --bisect %s %s" % (latestCommit, earliestCommit)).strip()
             if len(next) == 0:
                 if self.verbose:
-                    print "argh"
+                    print("argh")
                 return ""
             log = extractLogMessageFromGitCommit(next)
             settings = extractSettingsGitLog(log)
             currentChange = int(settings['change'])
             if self.verbose:
-                print "current change %s" % currentChange
+                print("current change %s" % currentChange)
 
             if currentChange == change:
                 if self.verbose:
-                    print "found %s" % next
+                    print("found %s" % next)
                 return next
 
             if currentChange < change:
                 earliestCommit = "^%s" % next
             else:
-                latestCommit = "%s" % next
+                if next == latestCommit:
+                    die("Infinite loop while looking in ref %s for change %s. Check your branch mappings" % (ref, change))
+                latestCommit = "%s^@" % next
 
         return ""
 
@@ -3347,17 +3385,17 @@ class P4Sync(Command, P4UserMap):
             if len(read_pipe(["git", "diff-tree", blob, target])) == 0:
                 parentFound = True
                 if self.verbose:
-                    print "Found parent of %s in commit %s" % (branch, blob)
+                    print("Found parent of %s in commit %s" % (branch, blob))
                 break
         if parentFound:
             return blob
         else:
             return None
 
-    def importChanges(self, changes, shelved=False, origin_revision=0):
+    def importChanges(self, changes, origin_revision=0):
         cnt = 1
         for change in changes:
-            description = p4_describe(change, shelved)
+            description = p4_describe(change)
             self.updateOptionDict(description)
 
             if not self.silent:
@@ -3378,7 +3416,7 @@ class P4Sync(Command, P4UserMap):
                         filesForCommit = branches[branch]
 
                         if self.verbose:
-                            print "branch is %s" % branch
+                            print("branch is %s" % branch)
 
                         self.updatedBranches.add(branch)
 
@@ -3399,13 +3437,13 @@ class P4Sync(Command, P4UserMap):
                                         print("\n    Resuming with change %s" % change);
 
                                 if self.verbose:
-                                    print "parent determined through known branches: %s" % parent
+                                    print("parent determined through known branches: %s" % parent)
 
                         branch = self.gitRefForBranch(branch)
                         parent = self.gitRefForBranch(parent)
 
                         if self.verbose:
-                            print "looking for initial parent for %s; current parent is %s" % (branch, parent)
+                            print("looking for initial parent for %s; current parent is %s" % (branch, parent))
 
                         if len(parent) == 0 and branch in self.initialParents:
                             parent = self.initialParents[branch]
@@ -3415,7 +3453,7 @@ class P4Sync(Command, P4UserMap):
                         if len(parent) > 0:
                             tempBranch = "%s/%d" % (self.tempBranchLocation, change)
                             if self.verbose:
-                                print "Creating temporary branch: " + tempBranch
+                                print("Creating temporary branch: " + tempBranch)
                             self.commit(description, filesForCommit, tempBranch)
                             self.tempBranches.append(tempBranch)
                             self.checkpoint()
@@ -3424,16 +3462,16 @@ class P4Sync(Command, P4UserMap):
                             self.commit(description, filesForCommit, branch, blob)
                         else:
                             if self.verbose:
-                                print "Parent of %s not found. Committing into head of %s" % (branch, parent)
+                                print("Parent of %s not found. Committing into head of %s" % (branch, parent))
                             self.commit(description, filesForCommit, branch, parent)
                 else:
-                    files = self.extractFilesFromCommit(description, shelved, change, origin_revision)
+                    files = self.extractFilesFromCommit(description)
                     self.commit(description, files, self.branch,
                                 self.initialParent)
                     # only needed once, to connect to the previous commit
                     self.initialParent = ""
             except IOError:
-                print self.gitError.read()
+                print(self.gitError.read())
                 sys.exit(1)
 
     def sync_origin_only(self):
@@ -3441,11 +3479,11 @@ class P4Sync(Command, P4UserMap):
             self.hasOrigin = originP4BranchesExist()
             if self.hasOrigin:
                 if not self.silent:
-                    print 'Syncing with origin first, using "git fetch origin"'
+                    print('Syncing with origin first, using "git fetch origin"')
                 system("git fetch origin")
 
     def importHeadRevision(self, revision):
-        print "Doing initial import of %s from revision %s into %s" % (' '.join(self.depotPaths), revision, self.branch)
+        print("Doing initial import of %s from revision %s into %s" % (' '.join(self.depotPaths), revision, self.branch))
 
         details = {}
         details["user"] = "git perforce import user"
@@ -3496,9 +3534,10 @@ class P4Sync(Command, P4UserMap):
         self.updateOptionDict(details)
         try:
             self.commit(details, self.extractFilesFromCommit(details), self.branch)
-        except IOError:
-            print "IO error with git fast-import. Is your git version recent enough?"
-            print self.gitError.read()
+        except IOError as err:
+            print("IO error with git fast-import. Is your git version recent enough?")
+            print("IO error details: {}".format(err))
+            print(self.gitError.read())
 
     def openStreams(self):
         self.importProcess = subprocess.Popen(["git", "fast-import"],
@@ -3560,14 +3599,14 @@ class P4Sync(Command, P4UserMap):
 
             if len(self.p4BranchesInGit) > 1:
                 if not self.silent:
-                    print "Importing from/into multiple branches"
+                    print("Importing from/into multiple branches")
                 self.detectBranches = True
                 for branch in branches.keys():
                     self.initialParents[self.refPrefix + branch] = \
                         branches[branch]
 
             if self.verbose:
-                print "branches: %s" % self.p4BranchesInGit
+                print("branches: %s" % self.p4BranchesInGit)
 
             p4Change = 0
             for branch in self.p4BranchesInGit:
@@ -3576,8 +3615,8 @@ class P4Sync(Command, P4UserMap):
                 settings = extractSettingsGitLog(logMsg)
 
                 self.readOptions(settings)
-                if (settings.has_key('depot-paths')
-                    and settings.has_key ('change')):
+                if ('depot-paths' in settings
+                    and 'change' in settings):
                     change = int(settings['change']) + 1
                     p4Change = max(p4Change, change)
 
@@ -3590,7 +3629,7 @@ class P4Sync(Command, P4UserMap):
                             prev_list = prev.split("/")
                             cur_list = cur.split("/")
                             for i in range(0, min(len(cur_list), len(prev_list))):
-                                if cur_list[i] <> prev_list[i]:
+                                if cur_list[i] != prev_list[i]:
                                     i = i - 1
                                     break
 
@@ -3602,7 +3641,7 @@ class P4Sync(Command, P4UserMap):
                 self.depotPaths = sorted(self.previousDepotPaths)
                 self.changeRange = "@%s,#head" % p4Change
                 if not self.silent and not self.detectBranches:
-                    print "Performing incremental import into %s git branch" % self.branch
+                    print("Performing incremental import into %s git branch" % self.branch)
 
         # accept multiple ref name abbreviations:
         #    refs/foo/bar/branch -> use it exactly
@@ -3619,10 +3658,10 @@ class P4Sync(Command, P4UserMap):
 
         if len(args) == 0 and self.depotPaths:
             if not self.silent:
-                print "Depot paths: %s" % ' '.join(self.depotPaths)
+                print("Depot paths: %s" % ' '.join(self.depotPaths))
         else:
             if self.depotPaths and self.depotPaths != args:
-                print ("previous import used depot path %s and now %s was specified. "
+                print("previous import used depot path %s and now %s was specified. "
                        "This doesn't work!" % (' '.join (self.depotPaths),
                                                ' '.join (args)))
                 sys.exit(1)
@@ -3689,8 +3728,8 @@ class P4Sync(Command, P4UserMap):
             else:
                 self.getBranchMapping()
             if self.verbose:
-                print "p4-git branches: %s" % self.p4BranchesInGit
-                print "initial parents: %s" % self.initialParents
+                print("p4-git branches: %s" % self.p4BranchesInGit)
+                print("initial parents: %s" % self.initialParents)
             for b in self.p4BranchesInGit:
                 if b != "master":
 
@@ -3734,8 +3773,8 @@ class P4Sync(Command, P4UserMap):
                                     self.branch)
 
                 if self.verbose:
-                    print "Getting p4 changes for %s...%s" % (', '.join(self.depotPaths),
-                                                              self.changeRange)
+                    print("Getting p4 changes for %s...%s" % (', '.join(self.depotPaths),
+                                                              self.changeRange))
                 changes = p4ChangesForPaths(self.depotPaths, self.changeRange, self.changes_block_size)
 
                 if len(self.maxChanges) > 0:
@@ -3743,10 +3782,10 @@ class P4Sync(Command, P4UserMap):
 
             if len(changes) == 0:
                 if not self.silent:
-                    print "No changes to import!"
+                    print("No changes to import!")
             else:
                 if not self.silent and not self.detectBranches:
-                    print "Import destination: %s" % self.branch
+                    print("Import destination: %s" % self.branch)
 
                 self.updatedBranches = set()
 
@@ -3761,7 +3800,7 @@ class P4Sync(Command, P4UserMap):
                 self.importChanges(changes)
 
                 if not self.silent:
-                    print ""
+                    print("")
                     if len(self.updatedBranches) > 0:
                         sys.stdout.write("Updated branches: ")
                         for b in self.updatedBranches:
@@ -3825,7 +3864,7 @@ class P4Rebase(Command):
         # the branchpoint may be p4/foo~3, so strip off the parent
         upstream = re.sub("~[0-9]+$", "", upstream)
 
-        print "Rebasing the current branch onto %s" % upstream
+        print("Rebasing the current branch onto %s" % upstream)
         oldHead = read_pipe("git rev-parse HEAD").strip()
         system("git rebase %s" % upstream)
         system("git diff-tree --stat --summary -M %s HEAD --" % oldHead)
@@ -3870,7 +3909,6 @@ class P4Clone(P4Sync):
             self.cloneDestination = depotPaths[-1]
             depotPaths = depotPaths[:-1]
 
-        self.cloneExclude = ["/"+p for p in self.cloneExclude]
         for p in depotPaths:
             if not p.startswith("//"):
                 sys.stderr.write('Depot paths must start with "//": %s\n' % p)
@@ -3879,7 +3917,7 @@ class P4Clone(P4Sync):
         if not self.cloneDestination:
             self.cloneDestination = self.defaultDestination(args)
 
-        print "Importing from %s into %s" % (', '.join(depotPaths), self.cloneDestination)
+        print("Importing from %s into %s" % (', '.join(depotPaths), self.cloneDestination))
 
         if not os.path.exists(self.cloneDestination):
             os.makedirs(self.cloneDestination)
@@ -3901,8 +3939,8 @@ class P4Clone(P4Sync):
             if not self.cloneBare:
                 system([ "git", "checkout", "-f" ])
         else:
-            print 'Not checking out any branch, use ' \
-                  '"git checkout -q -b master <branch>"'
+            print('Not checking out any branch, use ' \
+                  '"git checkout -q -b master <branch>"')
 
         # auto-set this variable if invoked with --use-client-spec
         if self.useClientSpec_from_options:
@@ -3923,7 +3961,7 @@ class P4Unshelve(Command):
         ]
         self.verbose = False
         self.noCommit = False
-        self.destbranch = "refs/remotes/p4/unshelved"
+        self.destbranch = "refs/remotes/p4-unshelved"
 
     def renameBranch(self, branch_name):
         """ Rename the existing branch to branch_name.N
@@ -3950,11 +3988,37 @@ class P4Unshelve(Command):
         for parent in (range(65535)):
             log = extractLogMessageFromGitCommit("{0}^{1}".format(starting_point, parent))
             settings = extractSettingsGitLog(log)
-            if settings.has_key('change'):
+            if 'change' in settings:
                 return settings
 
         sys.exit("could not find git-p4 commits in {0}".format(self.origin))
 
+    def createShelveParent(self, change, branch_name, sync, origin):
+        """ Create a commit matching the parent of the shelved changelist 'change'
+        """
+        parent_description = p4_describe(change, shelved=True)
+        parent_description['desc'] = 'parent for shelved changelist {}\n'.format(change)
+        files = sync.extractFilesFromCommit(parent_description, shelved=False, shelved_cl=change)
+
+        parent_files = []
+        for f in files:
+            # if it was added in the shelved changelist, it won't exist in the parent
+            if f['action'] in self.add_actions:
+                continue
+
+            # if it was deleted in the shelved changelist it must not be deleted
+            # in the parent - we might even need to create it if the origin branch
+            # does not have it
+            if f['action'] in self.delete_actions:
+                f['action'] = 'add'
+
+            parent_files.append(f)
+
+        sync.commit(parent_description, parent_files, branch_name,
+                parent=origin, allow_empty=True)
+        print("created parent commit for {0} based on {1} in {2}".format(
+            change, self.origin, branch_name))
+
     def run(self, args):
         if len(args) != 1:
             return False
@@ -3964,9 +4028,8 @@ class P4Unshelve(Command):
 
         sync = P4Sync()
         changes = args
-        sync.initialParent = self.origin
 
-        # use the first change in the list to construct the branch to unshelve into
+        # only one change at a time
         change = changes[0]
 
         # if the target branch already exists, rename it
@@ -3979,14 +4042,21 @@ class P4Unshelve(Command):
         sync.suppress_meta_comment = True
 
         settings = self.findLastP4Revision(self.origin)
-        origin_revision = settings['change']
         sync.depotPaths = settings['depot-paths']
         sync.branchPrefixes = sync.depotPaths
 
         sync.openStreams()
         sync.loadUserMapFromCache()
         sync.silent = True
-        sync.importChanges(changes, shelved=True, origin_revision=origin_revision)
+
+        # create a commit for the parent of the shelved changelist
+        self.createShelveParent(change, branch_name, sync, self.origin)
+
+        # create the commit for the shelved changelist itself
+        description = p4_describe(change, True)
+        files = sync.extractFilesFromCommit(description, True, change)
+
+        sync.commit(description, files, branch_name, "")
         sync.closeStreams()
 
         print("unshelved changelist {0} into {1}".format(change, branch_name))
@@ -4018,7 +4088,7 @@ class P4Branches(Command):
             log = extractLogMessageFromGitCommit("refs/remotes/%s" % branch)
             settings = extractSettingsGitLog(log)
 
-            print "%s <= %s (%s)" % (branch, ",".join(settings["depot-paths"]), settings["change"])
+            print("%s <= %s (%s)" % (branch, ",".join(settings["depot-paths"]), settings["change"]))
         return True
 
 class HelpFormatter(optparse.IndentedHelpFormatter):
@@ -4032,12 +4102,12 @@ class HelpFormatter(optparse.IndentedHel
             return ""
 
 def printUsage(commands):
-    print "usage: %s <command> [options]" % sys.argv[0]
-    print ""
-    print "valid commands: %s" % ", ".join(commands)
-    print ""
-    print "Try %s <command> --help for command specific help." % sys.argv[0]
-    print ""
+    print("usage: %s <command> [options]" % sys.argv[0])
+    print("")
+    print("valid commands: %s" % ", ".join(commands))
+    print("")
+    print("Try %s <command> --help for command specific help." % sys.argv[0])
+    print("")
 
 commands = {
     "debug" : P4Debug,
@@ -4062,8 +4132,8 @@ def main():
         klass = commands[cmdName]
         cmd = klass()
     except KeyError:
-        print "unknown command %s" % cmdName
-        print ""
+        print("unknown command %s" % cmdName)
+        print("")
         printUsage(commands.keys())
         sys.exit(2)
 
@@ -4081,7 +4151,12 @@ def main():
                                    description = cmd.description,
                                    formatter = HelpFormatter())
 
-    (cmd, args) = parser.parse_args(sys.argv[2:], cmd);
+    try:
+        (cmd, args) = parser.parse_args(sys.argv[2:], cmd);
+    except:
+        parser.print_help()
+        raise
+
     global verbose
     verbose = cmd.verbose
     if cmd.needsGit:
diff -pruN 1.2.1+git2.18.0-1/git/git-quiltimport.sh 1.2.3+git2.25.1-1/git/git-quiltimport.sh
--- 1.2.1+git2.18.0-1/git/git-quiltimport.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/git-quiltimport.sh	2020-02-17 04:47:35.000000000 +0000
@@ -8,6 +8,7 @@ n,dry-run     dry run
 author=       author name and email address for patches without any
 patches=      path to the quilt patches
 series=       path to the quilt series file
+keep-non-patch Pass -b to git mailinfo
 "
 SUBDIRECTORY_ON=Yes
 . git-sh-setup
@@ -32,6 +33,9 @@ do
 		shift
 		QUILT_SERIES="$1"
 		;;
+	--keep-non-patch)
+		MAILINFO_OPT="-b"
+		;;
 	--)
 		shift
 		break;;
@@ -98,7 +102,7 @@ do
 		continue
 	fi
 	echo $patch_name
-	git mailinfo "$tmp_msg" "$tmp_patch" \
+	git mailinfo $MAILINFO_OPT "$tmp_msg" "$tmp_patch" \
 		<"$QUILT_PATCHES/$patch_name" >"$tmp_info" || exit 3
 	test -s "$tmp_patch" || {
 		echo "Patch is empty.  Was it split wrong?"
diff -pruN 1.2.1+git2.18.0-1/git/git.rc 1.2.3+git2.25.1-1/git/git.rc
--- 1.2.1+git2.18.0-1/git/git.rc	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/git.rc	2020-02-17 04:47:35.000000000 +0000
@@ -20,3 +20,5 @@ BEGIN
     VALUE "Translation", 0x409, 1200
   END
 END
+
+1 RT_MANIFEST "compat/win32/git.manifest"
diff -pruN 1.2.1+git2.18.0-1/git/git-rebase--am.sh 1.2.3+git2.25.1-1/git/git-rebase--am.sh
--- 1.2.1+git2.18.0-1/git/git-rebase--am.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/git-rebase--am.sh	1970-01-01 00:00:00.000000000 +0000
@@ -1,85 +0,0 @@
-# This shell script fragment is sourced by git-rebase to implement
-# its default, fast, patch-based, non-interactive mode.
-#
-# Copyright (c) 2010 Junio C Hamano.
-#
-
-git_rebase__am () {
-
-case "$action" in
-continue)
-	git am --resolved --resolvemsg="$resolvemsg" \
-		${gpg_sign_opt:+"$gpg_sign_opt"} &&
-	move_to_original_branch
-	return
-	;;
-skip)
-	git am --skip --resolvemsg="$resolvemsg" &&
-	move_to_original_branch
-	return
-	;;
-show-current-patch)
-	exec git am --show-current-patch
-	;;
-esac
-
-if test -z "$rebase_root"
-	# this is now equivalent to ! -z "$upstream"
-then
-	revisions=$upstream...$orig_head
-else
-	revisions=$onto...$orig_head
-fi
-
-ret=0
-rm -f "$GIT_DIR/rebased-patches"
-
-git format-patch -k --stdout --full-index --cherry-pick --right-only \
-	--src-prefix=a/ --dst-prefix=b/ --no-renames --no-cover-letter \
-	--pretty=mboxrd \
-	$git_format_patch_opt \
-	"$revisions" ${restrict_revision+^$restrict_revision} \
-	>"$GIT_DIR/rebased-patches"
-ret=$?
-
-if test 0 != $ret
-then
-	rm -f "$GIT_DIR/rebased-patches"
-	case "$head_name" in
-	refs/heads/*)
-		git checkout -q "$head_name"
-		;;
-	*)
-		git checkout -q "$orig_head"
-		;;
-	esac
-
-	cat >&2 <<-EOF
-
-	git encountered an error while preparing the patches to replay
-	these revisions:
-
-	    $revisions
-
-	As a result, git cannot rebase them.
-	EOF
-	return $ret
-fi
-
-git am $git_am_opt --rebasing --resolvemsg="$resolvemsg" \
-	--patch-format=mboxrd \
-	$allow_rerere_autoupdate \
-	${gpg_sign_opt:+"$gpg_sign_opt"} <"$GIT_DIR/rebased-patches"
-ret=$?
-
-rm -f "$GIT_DIR/rebased-patches"
-
-if test 0 != $ret
-then
-	test -d "$state_dir" && write_basic_state
-	return $ret
-fi
-
-move_to_original_branch
-
-}
diff -pruN 1.2.1+git2.18.0-1/git/git-rebase--interactive.sh 1.2.3+git2.25.1-1/git/git-rebase--interactive.sh
--- 1.2.1+git2.18.0-1/git/git-rebase--interactive.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/git-rebase--interactive.sh	1970-01-01 00:00:00.000000000 +0000
@@ -1,1071 +0,0 @@
-# This shell script fragment is sourced by git-rebase to implement
-# its interactive mode.  "git rebase --interactive" makes it easy
-# to fix up commits in the middle of a series and rearrange commits.
-#
-# Copyright (c) 2006 Johannes E. Schindelin
-#
-# The original idea comes from Eric W. Biederman, in
-# https://public-inbox.org/git/m1odwkyuf5.fsf_-_@ebiederm.dsl.xmission.com/
-#
-# The file containing rebase commands, comments, and empty lines.
-# This file is created by "git rebase -i" then edited by the user.  As
-# the lines are processed, they are removed from the front of this
-# file and written to the tail of $done.
-todo="$state_dir"/git-rebase-todo
-
-# The rebase command lines that have already been processed.  A line
-# is moved here when it is first handled, before any associated user
-# actions.
-done="$state_dir"/done
-
-# The commit message that is planned to be used for any changes that
-# need to be committed following a user interaction.
-msg="$state_dir"/message
-
-# The file into which is accumulated the suggested commit message for
-# squash/fixup commands.  When the first of a series of squash/fixups
-# is seen, the file is created and the commit message from the
-# previous commit and from the first squash/fixup commit are written
-# to it.  The commit message for each subsequent squash/fixup commit
-# is appended to the file as it is processed.
-#
-# The first line of the file is of the form
-#     # This is a combination of $count commits.
-# where $count is the number of commits whose messages have been
-# written to the file so far (including the initial "pick" commit).
-# Each time that a commit message is processed, this line is read and
-# updated.  It is deleted just before the combined commit is made.
-squash_msg="$state_dir"/message-squash
-
-# If the current series of squash/fixups has not yet included a squash
-# command, then this file exists and holds the commit message of the
-# original "pick" commit.  (If the series ends without a "squash"
-# command, then this can be used as the commit message of the combined
-# commit without opening the editor.)
-fixup_msg="$state_dir"/message-fixup
-
-# $rewritten is the name of a directory containing files for each
-# commit that is reachable by at least one merge base of $head and
-# $upstream. They are not necessarily rewritten, but their children
-# might be.  This ensures that commits on merged, but otherwise
-# unrelated side branches are left alone. (Think "X" in the man page's
-# example.)
-rewritten="$state_dir"/rewritten
-
-dropped="$state_dir"/dropped
-
-end="$state_dir"/end
-msgnum="$state_dir"/msgnum
-
-# A script to set the GIT_AUTHOR_NAME, GIT_AUTHOR_EMAIL, and
-# GIT_AUTHOR_DATE that will be used for the commit that is currently
-# being rebased.
-author_script="$state_dir"/author-script
-
-# When an "edit" rebase command is being processed, the SHA1 of the
-# commit to be edited is recorded in this file.  When "git rebase
-# --continue" is executed, if there are any staged changes then they
-# will be amended to the HEAD commit, but only provided the HEAD
-# commit is still the commit to be edited.  When any other rebase
-# command is processed, this file is deleted.
-amend="$state_dir"/amend
-
-# For the post-rewrite hook, we make a list of rewritten commits and
-# their new sha1s.  The rewritten-pending list keeps the sha1s of
-# commits that have been processed, but not committed yet,
-# e.g. because they are waiting for a 'squash' command.
-rewritten_list="$state_dir"/rewritten-list
-rewritten_pending="$state_dir"/rewritten-pending
-
-# Work around Git for Windows' Bash whose "read" does not strip CRLF
-# and leaves CR at the end instead.
-cr=$(printf "\015")
-
-empty_tree=$(git hash-object -t tree /dev/null)
-
-strategy_args=${strategy:+--strategy=$strategy}
-test -n "$strategy_opts" &&
-eval '
-	for strategy_opt in '"$strategy_opts"'
-	do
-		strategy_args="$strategy_args -X$(git rev-parse --sq-quote "${strategy_opt#--}")"
-	done
-'
-
-GIT_CHERRY_PICK_HELP="$resolvemsg"
-export GIT_CHERRY_PICK_HELP
-
-comment_char=$(git config --get core.commentchar 2>/dev/null)
-case "$comment_char" in
-'' | auto)
-	comment_char="#"
-	;;
-?)
-	;;
-*)
-	comment_char=$(echo "$comment_char" | cut -c1)
-	;;
-esac
-
-warn () {
-	printf '%s\n' "$*" >&2
-}
-
-# Output the commit message for the specified commit.
-commit_message () {
-	git cat-file commit "$1" | sed "1,/^$/d"
-}
-
-orig_reflog_action="$GIT_REFLOG_ACTION"
-
-comment_for_reflog () {
-	case "$orig_reflog_action" in
-	''|rebase*)
-		GIT_REFLOG_ACTION="rebase -i ($1)"
-		export GIT_REFLOG_ACTION
-		;;
-	esac
-}
-
-last_count=
-mark_action_done () {
-	sed -e 1q < "$todo" >> "$done"
-	sed -e 1d < "$todo" >> "$todo".new
-	mv -f "$todo".new "$todo"
-	new_count=$(( $(git stripspace --strip-comments <"$done" | wc -l) ))
-	echo $new_count >"$msgnum"
-	total=$(($new_count + $(git stripspace --strip-comments <"$todo" | wc -l)))
-	echo $total >"$end"
-	if test "$last_count" != "$new_count"
-	then
-		last_count=$new_count
-		eval_gettext "Rebasing (\$new_count/\$total)"; printf "\r"
-		test -z "$verbose" || echo
-	fi
-}
-
-# Put the last action marked done at the beginning of the todo list
-# again. If there has not been an action marked done yet, leave the list of
-# items on the todo list unchanged.
-reschedule_last_action () {
-	tail -n 1 "$done" | cat - "$todo" >"$todo".new
-	sed -e \$d <"$done" >"$done".new
-	mv -f "$todo".new "$todo"
-	mv -f "$done".new "$done"
-}
-
-append_todo_help () {
-	gettext "
-Commands:
-p, pick <commit> = use commit
-r, reword <commit> = use commit, but edit the commit message
-e, edit <commit> = use commit, but stop for amending
-s, squash <commit> = use commit, but meld into previous commit
-f, fixup <commit> = like \"squash\", but discard this commit's log message
-x, exec <command> = run command (the rest of the line) using shell
-d, drop <commit> = remove commit
-l, label <label> = label current HEAD with a name
-t, reset <label> = reset HEAD to a label
-m, merge [-C <commit> | -c <commit>] <label> [# <oneline>]
-.       create a merge commit using the original merge commit's
-.       message (or the oneline, if no original merge commit was
-.       specified). Use -c <commit> to reword the commit message.
-
-These lines can be re-ordered; they are executed from top to bottom.
-" | git stripspace --comment-lines >>"$todo"
-
-	if test $(get_missing_commit_check_level) = error
-	then
-		gettext "
-Do not remove any line. Use 'drop' explicitly to remove a commit.
-" | git stripspace --comment-lines >>"$todo"
-	else
-		gettext "
-If you remove a line here THAT COMMIT WILL BE LOST.
-" | git stripspace --comment-lines >>"$todo"
-	fi
-}
-
-make_patch () {
-	sha1_and_parents="$(git rev-list --parents -1 "$1")"
-	case "$sha1_and_parents" in
-	?*' '?*' '?*)
-		git diff --cc $sha1_and_parents
-		;;
-	?*' '?*)
-		git diff-tree -p "$1^!"
-		;;
-	*)
-		echo "Root commit"
-		;;
-	esac > "$state_dir"/patch
-	test -f "$msg" ||
-		commit_message "$1" > "$msg"
-	test -f "$author_script" ||
-		get_author_ident_from_commit "$1" > "$author_script"
-}
-
-die_with_patch () {
-	echo "$1" > "$state_dir"/stopped-sha
-	git update-ref REBASE_HEAD "$1"
-	make_patch "$1"
-	die "$2"
-}
-
-exit_with_patch () {
-	echo "$1" > "$state_dir"/stopped-sha
-	git update-ref REBASE_HEAD "$1"
-	make_patch $1
-	git rev-parse --verify HEAD > "$amend"
-	gpg_sign_opt_quoted=${gpg_sign_opt:+$(git rev-parse --sq-quote "$gpg_sign_opt")}
-	warn "$(eval_gettext "\
-You can amend the commit now, with
-
-	git commit --amend \$gpg_sign_opt_quoted
-
-Once you are satisfied with your changes, run
-
-	git rebase --continue")"
-	warn
-	exit $2
-}
-
-die_abort () {
-	apply_autostash
-	rm -rf "$state_dir"
-	die "$1"
-}
-
-has_action () {
-	test -n "$(git stripspace --strip-comments <"$1")"
-}
-
-is_empty_commit() {
-	tree=$(git rev-parse -q --verify "$1"^{tree} 2>/dev/null) || {
-		sha1=$1
-		die "$(eval_gettext "\$sha1: not a commit that can be picked")"
-	}
-	ptree=$(git rev-parse -q --verify "$1"^^{tree} 2>/dev/null) ||
-		ptree=$empty_tree
-	test "$tree" = "$ptree"
-}
-
-is_merge_commit()
-{
-	git rev-parse --verify --quiet "$1"^2 >/dev/null 2>&1
-}
-
-# Run command with GIT_AUTHOR_NAME, GIT_AUTHOR_EMAIL, and
-# GIT_AUTHOR_DATE exported from the current environment.
-do_with_author () {
-	(
-		export GIT_AUTHOR_NAME GIT_AUTHOR_EMAIL GIT_AUTHOR_DATE
-		"$@"
-	)
-}
-
-git_sequence_editor () {
-	if test -z "$GIT_SEQUENCE_EDITOR"
-	then
-		GIT_SEQUENCE_EDITOR="$(git config sequence.editor)"
-		if [ -z "$GIT_SEQUENCE_EDITOR" ]
-		then
-			GIT_SEQUENCE_EDITOR="$(git var GIT_EDITOR)" || return $?
-		fi
-	fi
-
-	eval "$GIT_SEQUENCE_EDITOR" '"$@"'
-}
-
-pick_one () {
-	ff=--ff
-
-	case "$1" in -n) sha1=$2; ff= ;; *) sha1=$1 ;; esac
-	case "$force_rebase" in '') ;; ?*) ff= ;; esac
-	output git rev-parse --verify $sha1 || die "$(eval_gettext "Invalid commit name: \$sha1")"
-
-	if is_empty_commit "$sha1"
-	then
-		empty_args="--allow-empty"
-	fi
-
-	test -d "$rewritten" &&
-		pick_one_preserving_merges "$@" && return
-	output eval git cherry-pick $allow_rerere_autoupdate $allow_empty_message \
-			${gpg_sign_opt:+$(git rev-parse --sq-quote "$gpg_sign_opt")} \
-			$signoff "$strategy_args" $empty_args $ff "$@"
-
-	# If cherry-pick dies it leaves the to-be-picked commit unrecorded. Reschedule
-	# previous task so this commit is not lost.
-	ret=$?
-	case "$ret" in [01]) ;; *) reschedule_last_action ;; esac
-	return $ret
-}
-
-pick_one_preserving_merges () {
-	fast_forward=t
-	case "$1" in
-	-n)
-		fast_forward=f
-		sha1=$2
-		;;
-	*)
-		sha1=$1
-		;;
-	esac
-	sha1=$(git rev-parse $sha1)
-
-	if test -f "$state_dir"/current-commit && test "$fast_forward" = t
-	then
-		while read current_commit
-		do
-			git rev-parse HEAD > "$rewritten"/$current_commit
-		done <"$state_dir"/current-commit
-		rm "$state_dir"/current-commit ||
-			die "$(gettext "Cannot write current commit's replacement sha1")"
-	fi
-
-	echo $sha1 >> "$state_dir"/current-commit
-
-	# rewrite parents; if none were rewritten, we can fast-forward.
-	new_parents=
-	pend=" $(git rev-list --parents -1 $sha1 | cut -d' ' -s -f2-)"
-	if test "$pend" = " "
-	then
-		pend=" root"
-	fi
-	while [ "$pend" != "" ]
-	do
-		p=$(expr "$pend" : ' \([^ ]*\)')
-		pend="${pend# $p}"
-
-		if test -f "$rewritten"/$p
-		then
-			new_p=$(cat "$rewritten"/$p)
-
-			# If the todo reordered commits, and our parent is marked for
-			# rewriting, but hasn't been gotten to yet, assume the user meant to
-			# drop it on top of the current HEAD
-			if test -z "$new_p"
-			then
-				new_p=$(git rev-parse HEAD)
-			fi
-
-			test $p != $new_p && fast_forward=f
-			case "$new_parents" in
-			*$new_p*)
-				;; # do nothing; that parent is already there
-			*)
-				new_parents="$new_parents $new_p"
-				;;
-			esac
-		else
-			if test -f "$dropped"/$p
-			then
-				fast_forward=f
-				replacement="$(cat "$dropped"/$p)"
-				test -z "$replacement" && replacement=root
-				pend=" $replacement$pend"
-			else
-				new_parents="$new_parents $p"
-			fi
-		fi
-	done
-	case $fast_forward in
-	t)
-		output warn "$(eval_gettext "Fast-forward to \$sha1")"
-		output git reset --hard $sha1 ||
-			die "$(eval_gettext "Cannot fast-forward to \$sha1")"
-		;;
-	f)
-		first_parent=$(expr "$new_parents" : ' \([^ ]*\)')
-
-		if [ "$1" != "-n" ]
-		then
-			# detach HEAD to current parent
-			output git checkout $first_parent 2> /dev/null ||
-				die "$(eval_gettext "Cannot move HEAD to \$first_parent")"
-		fi
-
-		case "$new_parents" in
-		' '*' '*)
-			test "a$1" = a-n && die "$(eval_gettext "Refusing to squash a merge: \$sha1")"
-
-			# redo merge
-			author_script_content=$(get_author_ident_from_commit $sha1)
-			eval "$author_script_content"
-			msg_content="$(commit_message $sha1)"
-			# No point in merging the first parent, that's HEAD
-			new_parents=${new_parents# $first_parent}
-			merge_args="--no-log --no-ff"
-			if ! do_with_author output eval \
-				git merge ${gpg_sign_opt:+$(git rev-parse \
-					--sq-quote "$gpg_sign_opt")} \
-				$allow_rerere_autoupdate "$merge_args" \
-				"$strategy_args" \
-				-m "$(git rev-parse --sq-quote "$msg_content")" \
-				"$new_parents"
-			then
-				printf "%s\n" "$msg_content" > "$GIT_DIR"/MERGE_MSG
-				die_with_patch $sha1 "$(eval_gettext "Error redoing merge \$sha1")"
-			fi
-			echo "$sha1 $(git rev-parse HEAD^0)" >> "$rewritten_list"
-			;;
-		*)
-			output eval git cherry-pick $allow_rerere_autoupdate \
-				$allow_empty_message \
-				${gpg_sign_opt:+$(git rev-parse --sq-quote "$gpg_sign_opt")} \
-				"$strategy_args" "$@" ||
-				die_with_patch $sha1 "$(eval_gettext "Could not pick \$sha1")"
-			;;
-		esac
-		;;
-	esac
-}
-
-this_nth_commit_message () {
-	n=$1
-	eval_gettext "This is the commit message #\${n}:"
-}
-
-skip_nth_commit_message () {
-	n=$1
-	eval_gettext "The commit message #\${n} will be skipped:"
-}
-
-update_squash_messages () {
-	if test -f "$squash_msg"; then
-		mv "$squash_msg" "$squash_msg".bak || exit
-		count=$(($(sed -n \
-			-e "1s/^$comment_char[^0-9]*\([0-9][0-9]*\).*/\1/p" \
-			-e "q" < "$squash_msg".bak)+1))
-		{
-			printf '%s\n' "$comment_char $(eval_ngettext \
-				"This is a combination of \$count commit." \
-				"This is a combination of \$count commits." \
-				$count)"
-			sed -e 1d -e '2,/^./{
-				/^$/d
-			}' <"$squash_msg".bak
-		} >"$squash_msg"
-	else
-		commit_message HEAD >"$fixup_msg" ||
-		die "$(eval_gettext "Cannot write \$fixup_msg")"
-		count=2
-		{
-			printf '%s\n' "$comment_char $(gettext "This is a combination of 2 commits.")"
-			printf '%s\n' "$comment_char $(gettext "This is the 1st commit message:")"
-			echo
-			cat "$fixup_msg"
-		} >"$squash_msg"
-	fi
-	case $1 in
-	squash)
-		rm -f "$fixup_msg"
-		echo
-		printf '%s\n' "$comment_char $(this_nth_commit_message $count)"
-		echo
-		commit_message $2
-		;;
-	fixup)
-		echo
-		printf '%s\n' "$comment_char $(skip_nth_commit_message $count)"
-		echo
-		# Change the space after the comment character to TAB:
-		commit_message $2 | git stripspace --comment-lines | sed -e 's/ /	/'
-		;;
-	esac >>"$squash_msg"
-}
-
-peek_next_command () {
-	git stripspace --strip-comments <"$todo" | sed -n -e 's/ .*//p' -e q
-}
-
-# A squash/fixup has failed.  Prepare the long version of the squash
-# commit message, then die_with_patch.  This code path requires the
-# user to edit the combined commit message for all commits that have
-# been squashed/fixedup so far.  So also erase the old squash
-# messages, effectively causing the combined commit to be used as the
-# new basis for any further squash/fixups.  Args: sha1 rest
-die_failed_squash() {
-	sha1=$1
-	rest=$2
-	mv "$squash_msg" "$msg" || exit
-	rm -f "$fixup_msg"
-	cp "$msg" "$GIT_DIR"/MERGE_MSG || exit
-	warn
-	warn "$(eval_gettext "Could not apply \$sha1... \$rest")"
-	die_with_patch $sha1 ""
-}
-
-flush_rewritten_pending() {
-	test -s "$rewritten_pending" || return
-	newsha1="$(git rev-parse HEAD^0)"
-	sed "s/$/ $newsha1/" < "$rewritten_pending" >> "$rewritten_list"
-	rm -f "$rewritten_pending"
-}
-
-record_in_rewritten() {
-	oldsha1="$(git rev-parse $1)"
-	echo "$oldsha1" >> "$rewritten_pending"
-
-	case "$(peek_next_command)" in
-	squash|s|fixup|f)
-		;;
-	*)
-		flush_rewritten_pending
-		;;
-	esac
-}
-
-do_pick () {
-	sha1=$1
-	rest=$2
-	if test "$(git rev-parse HEAD)" = "$squash_onto"
-	then
-		# Set the correct commit message and author info on the
-		# sentinel root before cherry-picking the original changes
-		# without committing (-n).  Finally, update the sentinel again
-		# to include these changes.  If the cherry-pick results in a
-		# conflict, this means our behaviour is similar to a standard
-		# failed cherry-pick during rebase, with a dirty index to
-		# resolve before manually running git commit --amend then git
-		# rebase --continue.
-		git commit --allow-empty --allow-empty-message --amend \
-			   --no-post-rewrite -n -q -C $sha1 $signoff &&
-			pick_one -n $sha1 &&
-			git commit --allow-empty --allow-empty-message \
-				   --amend --no-post-rewrite -n -q -C $sha1 $signoff \
-				   ${gpg_sign_opt:+"$gpg_sign_opt"} ||
-				   die_with_patch $sha1 "$(eval_gettext "Could not apply \$sha1... \$rest")"
-	else
-		pick_one $sha1 ||
-			die_with_patch $sha1 "$(eval_gettext "Could not apply \$sha1... \$rest")"
-	fi
-}
-
-do_next () {
-	rm -f "$msg" "$author_script" "$amend" "$state_dir"/stopped-sha || exit
-	read -r command sha1 rest < "$todo"
-	case "$command" in
-	"$comment_char"*|''|noop|drop|d)
-		mark_action_done
-		;;
-	"$cr")
-		# Work around CR left by "read" (e.g. with Git for Windows' Bash).
-		mark_action_done
-		;;
-	pick|p)
-		comment_for_reflog pick
-
-		mark_action_done
-		do_pick $sha1 "$rest"
-		record_in_rewritten $sha1
-		;;
-	reword|r)
-		comment_for_reflog reword
-
-		mark_action_done
-		do_pick $sha1 "$rest"
-		git commit --amend --no-post-rewrite ${gpg_sign_opt:+"$gpg_sign_opt"} \
-			$allow_empty_message || {
-			warn "$(eval_gettext "\
-Could not amend commit after successfully picking \$sha1... \$rest
-This is most likely due to an empty commit message, or the pre-commit hook
-failed. If the pre-commit hook failed, you may need to resolve the issue before
-you are able to reword the commit.")"
-			exit_with_patch $sha1 1
-		}
-		record_in_rewritten $sha1
-		;;
-	edit|e)
-		comment_for_reflog edit
-
-		mark_action_done
-		do_pick $sha1 "$rest"
-		sha1_abbrev=$(git rev-parse --short $sha1)
-		warn "$(eval_gettext "Stopped at \$sha1_abbrev... \$rest")"
-		exit_with_patch $sha1 0
-		;;
-	squash|s|fixup|f)
-		case "$command" in
-		squash|s)
-			squash_style=squash
-			;;
-		fixup|f)
-			squash_style=fixup
-			;;
-		esac
-		comment_for_reflog $squash_style
-
-		test -f "$done" && has_action "$done" ||
-			die "$(eval_gettext "Cannot '\$squash_style' without a previous commit")"
-
-		mark_action_done
-		update_squash_messages $squash_style $sha1
-		author_script_content=$(get_author_ident_from_commit HEAD)
-		echo "$author_script_content" > "$author_script"
-		eval "$author_script_content"
-		if ! pick_one -n $sha1
-		then
-			git rev-parse --verify HEAD >"$amend"
-			die_failed_squash $sha1 "$rest"
-		fi
-		case "$(peek_next_command)" in
-		squash|s|fixup|f)
-			# This is an intermediate commit; its message will only be
-			# used in case of trouble.  So use the long version:
-			do_with_author output git commit --amend --no-verify -F "$squash_msg" \
-				${gpg_sign_opt:+"$gpg_sign_opt"} $allow_empty_message ||
-				die_failed_squash $sha1 "$rest"
-			;;
-		*)
-			# This is the final command of this squash/fixup group
-			if test -f "$fixup_msg"
-			then
-				do_with_author git commit --amend --no-verify -F "$fixup_msg" \
-					${gpg_sign_opt:+"$gpg_sign_opt"} $allow_empty_message ||
-					die_failed_squash $sha1 "$rest"
-			else
-				cp "$squash_msg" "$GIT_DIR"/SQUASH_MSG || exit
-				rm -f "$GIT_DIR"/MERGE_MSG
-				do_with_author git commit --amend --no-verify -F "$GIT_DIR"/SQUASH_MSG -e \
-					${gpg_sign_opt:+"$gpg_sign_opt"} $allow_empty_message ||
-					die_failed_squash $sha1 "$rest"
-			fi
-			rm -f "$squash_msg" "$fixup_msg"
-			;;
-		esac
-		record_in_rewritten $sha1
-		;;
-	x|"exec")
-		read -r command rest < "$todo"
-		mark_action_done
-		eval_gettextln "Executing: \$rest"
-		"${SHELL:-@SHELL_PATH@}" -c "$rest" # Actual execution
-		status=$?
-		# Run in subshell because require_clean_work_tree can die.
-		dirty=f
-		(require_clean_work_tree "rebase" 2>/dev/null) || dirty=t
-		if test "$status" -ne 0
-		then
-			warn "$(eval_gettext "Execution failed: \$rest")"
-			test "$dirty" = f ||
-				warn "$(gettext "and made changes to the index and/or the working tree")"
-
-			warn "$(gettext "\
-You can fix the problem, and then run
-
-	git rebase --continue")"
-			warn
-			if test $status -eq 127		# command not found
-			then
-				status=1
-			fi
-			exit "$status"
-		elif test "$dirty" = t
-		then
-			# TRANSLATORS: after these lines is a command to be issued by the user
-			warn "$(eval_gettext "\
-Execution succeeded: \$rest
-but left changes to the index and/or the working tree
-Commit or stash your changes, and then run
-
-	git rebase --continue")"
-			warn
-			exit 1
-		fi
-		;;
-	*)
-		warn "$(eval_gettext "Unknown command: \$command \$sha1 \$rest")"
-		fixtodo="$(gettext "Please fix this using 'git rebase --edit-todo'.")"
-		if git rev-parse --verify -q "$sha1" >/dev/null
-		then
-			die_with_patch $sha1 "$fixtodo"
-		else
-			die "$fixtodo"
-		fi
-		;;
-	esac
-	test -s "$todo" && return
-
-	comment_for_reflog finish &&
-	newhead=$(git rev-parse HEAD) &&
-	case $head_name in
-	refs/*)
-		message="$GIT_REFLOG_ACTION: $head_name onto $onto" &&
-		git update-ref -m "$message" $head_name $newhead $orig_head &&
-		git symbolic-ref \
-		  -m "$GIT_REFLOG_ACTION: returning to $head_name" \
-		  HEAD $head_name
-		;;
-	esac && {
-		test ! -f "$state_dir"/verbose ||
-			git diff-tree --stat $orig_head..HEAD
-	} &&
-	{
-		test -s "$rewritten_list" &&
-		git notes copy --for-rewrite=rebase < "$rewritten_list" ||
-		true # we don't care if this copying failed
-	} &&
-	hook="$(git rev-parse --git-path hooks/post-rewrite)"
-	if test -x "$hook" && test -s "$rewritten_list"; then
-		"$hook" rebase < "$rewritten_list"
-		true # we don't care if this hook failed
-	fi &&
-		warn "$(eval_gettext "Successfully rebased and updated \$head_name.")"
-
-	return 1 # not failure; just to break the do_rest loop
-}
-
-# can only return 0, when the infinite loop breaks
-do_rest () {
-	while :
-	do
-		do_next || break
-	done
-}
-
-expand_todo_ids() {
-	git rebase--helper --expand-ids
-}
-
-collapse_todo_ids() {
-	git rebase--helper --shorten-ids
-}
-
-# Switch to the branch in $into and notify it in the reflog
-checkout_onto () {
-	GIT_REFLOG_ACTION="$GIT_REFLOG_ACTION: checkout $onto_name"
-	output git checkout $onto || die_abort "$(gettext "could not detach HEAD")"
-	git update-ref ORIG_HEAD $orig_head
-}
-
-get_missing_commit_check_level () {
-	check_level=$(git config --get rebase.missingCommitsCheck)
-	check_level=${check_level:-ignore}
-	# Don't be case sensitive
-	printf '%s' "$check_level" | tr 'A-Z' 'a-z'
-}
-
-# Initiate an action. If the cannot be any
-# further action it  may exec a command
-# or exit and not return.
-#
-# TODO: Consider a cleaner return model so it
-# never exits and always return 0 if process
-# is complete.
-#
-# Parameter 1 is the action to initiate.
-#
-# Returns 0 if the action was able to complete
-# and if 1 if further processing is required.
-initiate_action () {
-	case "$1" in
-	continue)
-		if test ! -d "$rewritten"
-		then
-			exec git rebase--helper ${force_rebase:+--no-ff} $allow_empty_message \
-				--continue
-		fi
-		# do we have anything to commit?
-		if git diff-index --cached --quiet HEAD --
-		then
-			# Nothing to commit -- skip this commit
-
-			test ! -f "$GIT_DIR"/CHERRY_PICK_HEAD ||
-			rm "$GIT_DIR"/CHERRY_PICK_HEAD ||
-			die "$(gettext "Could not remove CHERRY_PICK_HEAD")"
-		else
-			if ! test -f "$author_script"
-			then
-				gpg_sign_opt_quoted=${gpg_sign_opt:+$(git rev-parse --sq-quote "$gpg_sign_opt")}
-				die "$(eval_gettext "\
-You have staged changes in your working tree.
-If these changes are meant to be
-squashed into the previous commit, run:
-
-  git commit --amend \$gpg_sign_opt_quoted
-
-If they are meant to go into a new commit, run:
-
-  git commit \$gpg_sign_opt_quoted
-
-In both cases, once you're done, continue with:
-
-  git rebase --continue
-")"
-			fi
-			. "$author_script" ||
-				die "$(gettext "Error trying to find the author identity to amend commit")"
-			if test -f "$amend"
-			then
-				current_head=$(git rev-parse --verify HEAD)
-				test "$current_head" = $(cat "$amend") ||
-				die "$(gettext "\
-You have uncommitted changes in your working tree. Please commit them
-first and then run 'git rebase --continue' again.")"
-				do_with_author git commit --amend --no-verify -F "$msg" -e \
-					${gpg_sign_opt:+"$gpg_sign_opt"} $allow_empty_message ||
-					die "$(gettext "Could not commit staged changes.")"
-			else
-				do_with_author git commit --no-verify -F "$msg" -e \
-					${gpg_sign_opt:+"$gpg_sign_opt"} $allow_empty_message ||
-					die "$(gettext "Could not commit staged changes.")"
-			fi
-		fi
-
-		if test -r "$state_dir"/stopped-sha
-		then
-			record_in_rewritten "$(cat "$state_dir"/stopped-sha)"
-		fi
-
-		require_clean_work_tree "rebase"
-		do_rest
-		return 0
-		;;
-	skip)
-		git rerere clear
-
-		if test ! -d "$rewritten"
-		then
-			exec git rebase--helper ${force_rebase:+--no-ff} $allow_empty_message \
-				--continue
-		fi
-		do_rest
-		return 0
-		;;
-	edit-todo)
-		git stripspace --strip-comments <"$todo" >"$todo".new
-		mv -f "$todo".new "$todo"
-		collapse_todo_ids
-		append_todo_help
-		gettext "
-You are editing the todo file of an ongoing interactive rebase.
-To continue rebase after editing, run:
-    git rebase --continue
-
-" | git stripspace --comment-lines >>"$todo"
-
-		git_sequence_editor "$todo" ||
-			die "$(gettext "Could not execute editor")"
-		expand_todo_ids
-
-		exit
-		;;
-	show-current-patch)
-		exec git show REBASE_HEAD --
-		;;
-	*)
-		return 1 # continue
-		;;
-	esac
-}
-
-setup_reflog_action () {
-	comment_for_reflog start
-
-	if test ! -z "$switch_to"
-	then
-		GIT_REFLOG_ACTION="$GIT_REFLOG_ACTION: checkout $switch_to"
-		output git checkout "$switch_to" -- ||
-			die "$(eval_gettext "Could not checkout \$switch_to")"
-
-		comment_for_reflog start
-	fi
-}
-
-init_basic_state () {
-	orig_head=$(git rev-parse --verify HEAD) || die "$(gettext "No HEAD?")"
-	mkdir -p "$state_dir" || die "$(eval_gettext "Could not create temporary \$state_dir")"
-	rm -f "$(git rev-parse --git-path REBASE_HEAD)"
-
-	: > "$state_dir"/interactive || die "$(gettext "Could not mark as interactive")"
-	write_basic_state
-}
-
-init_revisions_and_shortrevisions () {
-	shorthead=$(git rev-parse --short $orig_head)
-	shortonto=$(git rev-parse --short $onto)
-	if test -z "$rebase_root"
-		# this is now equivalent to ! -z "$upstream"
-	then
-		shortupstream=$(git rev-parse --short $upstream)
-		revisions=$upstream...$orig_head
-		shortrevisions=$shortupstream..$shorthead
-	else
-		revisions=$onto...$orig_head
-		shortrevisions=$shorthead
-		test -z "$squash_onto" ||
-		echo "$squash_onto" >"$state_dir"/squash-onto
-	fi
-}
-
-complete_action() {
-	test -s "$todo" || echo noop >> "$todo"
-	test -z "$autosquash" || git rebase--helper --rearrange-squash || exit
-	test -n "$cmd" && git rebase--helper --add-exec-commands "$cmd"
-
-	todocount=$(git stripspace --strip-comments <"$todo" | wc -l)
-	todocount=${todocount##* }
-
-cat >>"$todo" <<EOF
-
-$comment_char $(eval_ngettext \
-	"Rebase \$shortrevisions onto \$shortonto (\$todocount command)" \
-	"Rebase \$shortrevisions onto \$shortonto (\$todocount commands)" \
-	"$todocount")
-EOF
-	append_todo_help
-	gettext "
-	However, if you remove everything, the rebase will be aborted.
-
-	" | git stripspace --comment-lines >>"$todo"
-
-	if test -z "$keep_empty"
-	then
-		printf '%s\n' "$comment_char $(gettext "Note that empty commits are commented out")" >>"$todo"
-	fi
-
-
-	has_action "$todo" ||
-		return 2
-
-	cp "$todo" "$todo".backup
-	collapse_todo_ids
-	git_sequence_editor "$todo" ||
-		die_abort "$(gettext "Could not execute editor")"
-
-	has_action "$todo" ||
-		return 2
-
-	git rebase--helper --check-todo-list || {
-		ret=$?
-		checkout_onto
-		exit $ret
-	}
-
-	expand_todo_ids
-
-	test -d "$rewritten" || test -n "$force_rebase" ||
-	onto="$(git rebase--helper --skip-unnecessary-picks)" ||
-	die "Could not skip unnecessary pick commands"
-
-	checkout_onto
-	if test ! -d "$rewritten"
-	then
-		require_clean_work_tree "rebase"
-		exec git rebase--helper ${force_rebase:+--no-ff} $allow_empty_message \
-			--continue
-	fi
-	do_rest
-}
-
-git_rebase__interactive () {
-	initiate_action "$action"
-	ret=$?
-	if test $ret = 0; then
-		return 0
-	fi
-
-	setup_reflog_action
-	init_basic_state
-
-	init_revisions_and_shortrevisions
-
-	git rebase--helper --make-script ${keep_empty:+--keep-empty} \
-		${rebase_merges:+--rebase-merges} \
-		${rebase_cousins:+--rebase-cousins} \
-		$revisions ${restrict_revision+^$restrict_revision} >"$todo" ||
-	die "$(gettext "Could not generate todo list")"
-
-	complete_action
-}
-
-git_rebase__interactive__preserve_merges () {
-	initiate_action "$action"
-	ret=$?
-	if test $ret = 0; then
-		return 0
-	fi
-
-	setup_reflog_action
-	init_basic_state
-
-	if test -z "$rebase_root"
-	then
-		mkdir "$rewritten" &&
-		for c in $(git merge-base --all $orig_head $upstream)
-		do
-			echo $onto > "$rewritten"/$c ||
-				die "$(gettext "Could not init rewritten commits")"
-		done
-	else
-		mkdir "$rewritten" &&
-		echo $onto > "$rewritten"/root ||
-			die "$(gettext "Could not init rewritten commits")"
-	fi
-
-	init_revisions_and_shortrevisions
-
-	format=$(git config --get rebase.instructionFormat)
-	# the 'rev-list .. | sed' requires %m to parse; the instruction requires %H to parse
-	git rev-list --format="%m%H ${format:-%s}" \
-		--reverse --left-right --topo-order \
-		$revisions ${restrict_revision+^$restrict_revision} | \
-		sed -n "s/^>//p" |
-	while read -r sha1 rest
-	do
-		if test -z "$keep_empty" && is_empty_commit $sha1 && ! is_merge_commit $sha1
-		then
-			comment_out="$comment_char "
-		else
-			comment_out=
-		fi
-
-		if test -z "$rebase_root"
-		then
-			preserve=t
-			for p in $(git rev-list --parents -1 $sha1 | cut -d' ' -s -f2-)
-			do
-				if test -f "$rewritten"/$p
-				then
-					preserve=f
-				fi
-			done
-		else
-			preserve=f
-		fi
-		if test f = "$preserve"
-		then
-			touch "$rewritten"/$sha1
-			printf '%s\n' "${comment_out}pick $sha1 $rest" >>"$todo"
-		fi
-	done
-
-	# Watch for commits that been dropped by --cherry-pick
-	mkdir "$dropped"
-	# Save all non-cherry-picked changes
-	git rev-list $revisions --left-right --cherry-pick | \
-		sed -n "s/^>//p" > "$state_dir"/not-cherry-picks
-	# Now all commits and note which ones are missing in
-	# not-cherry-picks and hence being dropped
-	git rev-list $revisions |
-	while read rev
-	do
-		if test -f "$rewritten"/$rev &&
-		   ! sane_grep "$rev" "$state_dir"/not-cherry-picks >/dev/null
-		then
-			# Use -f2 because if rev-list is telling us this commit is
-			# not worthwhile, we don't want to track its multiple heads,
-			# just the history of its first-parent for others that will
-			# be rebasing on top of it
-			git rev-list --parents -1 $rev | cut -d' ' -s -f2 > "$dropped"/$rev
-			sha1=$(git rev-list -1 $rev)
-			sane_grep -v "^[a-z][a-z]* $sha1" <"$todo" > "${todo}2" ; mv "${todo}2" "$todo"
-			rm "$rewritten"/$rev
-		fi
-	done
-
-	complete_action
-}
diff -pruN 1.2.1+git2.18.0-1/git/git-rebase--merge.sh 1.2.3+git2.25.1-1/git/git-rebase--merge.sh
--- 1.2.1+git2.18.0-1/git/git-rebase--merge.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/git-rebase--merge.sh	1970-01-01 00:00:00.000000000 +0000
@@ -1,164 +0,0 @@
-# This shell script fragment is sourced by git-rebase to implement
-# its merge-based non-interactive mode that copes well with renamed
-# files.
-#
-# Copyright (c) 2010 Junio C Hamano.
-#
-
-prec=4
-
-read_state () {
-	onto_name=$(cat "$state_dir"/onto_name) &&
-	end=$(cat "$state_dir"/end) &&
-	msgnum=$(cat "$state_dir"/msgnum)
-}
-
-continue_merge () {
-	test -d "$state_dir" || die "$state_dir directory does not exist"
-
-	unmerged=$(git ls-files -u)
-	if test -n "$unmerged"
-	then
-		echo "You still have unmerged paths in your index"
-		echo "did you forget to use git add?"
-		die "$resolvemsg"
-	fi
-
-	cmt=$(cat "$state_dir/current")
-	if ! git diff-index --quiet --ignore-submodules HEAD --
-	then
-		if ! git commit ${gpg_sign_opt:+"$gpg_sign_opt"} $signoff $allow_empty_message \
-			--no-verify -C "$cmt"
-		then
-			echo "Commit failed, please do not call \"git commit\""
-			echo "directly, but instead do one of the following: "
-			die "$resolvemsg"
-		fi
-		if test -z "$GIT_QUIET"
-		then
-			printf "Committed: %0${prec}d " $msgnum
-		fi
-		echo "$cmt $(git rev-parse HEAD^0)" >> "$state_dir/rewritten"
-	else
-		if test -z "$GIT_QUIET"
-		then
-			printf "Already applied: %0${prec}d " $msgnum
-		fi
-	fi
-	test -z "$GIT_QUIET" &&
-	GIT_PAGER='' git log --format=%s -1 "$cmt"
-
-	# onto the next patch:
-	msgnum=$(($msgnum + 1))
-	echo "$msgnum" >"$state_dir/msgnum"
-}
-
-call_merge () {
-	msgnum="$1"
-	echo "$msgnum" >"$state_dir/msgnum"
-	cmt="$(cat "$state_dir/cmt.$msgnum")"
-	echo "$cmt" > "$state_dir/current"
-	git update-ref REBASE_HEAD "$cmt"
-	hd=$(git rev-parse --verify HEAD)
-	cmt_name=$(git symbolic-ref HEAD 2> /dev/null || echo HEAD)
-	eval GITHEAD_$cmt='"${cmt_name##refs/heads/}~$(($end - $msgnum))"'
-	eval GITHEAD_$hd='$onto_name'
-	export GITHEAD_$cmt GITHEAD_$hd
-	if test -n "$GIT_QUIET"
-	then
-		GIT_MERGE_VERBOSITY=1 && export GIT_MERGE_VERBOSITY
-	fi
-	test -z "$strategy" && strategy=recursive
-	# If cmt doesn't have a parent, don't include it as a base
-	base=$(git rev-parse --verify --quiet $cmt^)
-	eval 'git-merge-$strategy' $strategy_opts $base ' -- "$hd" "$cmt"'
-	rv=$?
-	case "$rv" in
-	0)
-		unset GITHEAD_$cmt GITHEAD_$hd
-		return
-		;;
-	1)
-		git rerere $allow_rerere_autoupdate
-		die "$resolvemsg"
-		;;
-	2)
-		echo "Strategy: $strategy failed, try another" 1>&2
-		die "$resolvemsg"
-		;;
-	*)
-		die "Unknown exit code ($rv) from command:" \
-			"git-merge-$strategy $cmt^ -- HEAD $cmt"
-		;;
-	esac
-}
-
-finish_rb_merge () {
-	move_to_original_branch
-	if test -s "$state_dir"/rewritten
-	then
-		git notes copy --for-rewrite=rebase <"$state_dir"/rewritten
-		hook="$(git rev-parse --git-path hooks/post-rewrite)"
-		test -x "$hook" && "$hook" rebase <"$state_dir"/rewritten
-	fi
-	say All done.
-}
-
-git_rebase__merge () {
-
-case "$action" in
-continue)
-	read_state
-	continue_merge
-	while test "$msgnum" -le "$end"
-	do
-		call_merge "$msgnum"
-		continue_merge
-	done
-	finish_rb_merge
-	return
-	;;
-skip)
-	read_state
-	git rerere clear
-	msgnum=$(($msgnum + 1))
-	while test "$msgnum" -le "$end"
-	do
-		call_merge "$msgnum"
-		continue_merge
-	done
-	finish_rb_merge
-	return
-	;;
-show-current-patch)
-	exec git show REBASE_HEAD --
-	;;
-esac
-
-mkdir -p "$state_dir"
-echo "$onto_name" > "$state_dir/onto_name"
-write_basic_state
-rm -f "$(git rev-parse --git-path REBASE_HEAD)"
-
-msgnum=0
-for cmt in $(git rev-list --reverse --no-merges "$revisions")
-do
-	msgnum=$(($msgnum + 1))
-	echo "$cmt" > "$state_dir/cmt.$msgnum"
-done
-
-echo 1 >"$state_dir/msgnum"
-echo $msgnum >"$state_dir/end"
-
-end=$msgnum
-msgnum=1
-
-while test "$msgnum" -le "$end"
-do
-	call_merge "$msgnum"
-	continue_merge
-done
-
-finish_rb_merge
-
-}
diff -pruN 1.2.1+git2.18.0-1/git/git-rebase--preserve-merges.sh 1.2.3+git2.25.1-1/git/git-rebase--preserve-merges.sh
--- 1.2.1+git2.18.0-1/git/git-rebase--preserve-merges.sh	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/git-rebase--preserve-merges.sh	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,1067 @@
+# This shell script fragment is sourced by git-rebase to implement its
+# preserve-merges mode.
+#
+# Copyright (c) 2006 Johannes E. Schindelin
+#
+# The file containing rebase commands, comments, and empty lines.
+# This file is created by "git rebase -i" then edited by the user.  As
+# the lines are processed, they are removed from the front of this
+# file and written to the tail of $done.
+todo="$state_dir"/git-rebase-todo
+
+# The rebase command lines that have already been processed.  A line
+# is moved here when it is first handled, before any associated user
+# actions.
+done="$state_dir"/done
+
+# The commit message that is planned to be used for any changes that
+# need to be committed following a user interaction.
+msg="$state_dir"/message
+
+# The file into which is accumulated the suggested commit message for
+# squash/fixup commands.  When the first of a series of squash/fixups
+# is seen, the file is created and the commit message from the
+# previous commit and from the first squash/fixup commit are written
+# to it.  The commit message for each subsequent squash/fixup commit
+# is appended to the file as it is processed.
+#
+# The first line of the file is of the form
+#     # This is a combination of $count commits.
+# where $count is the number of commits whose messages have been
+# written to the file so far (including the initial "pick" commit).
+# Each time that a commit message is processed, this line is read and
+# updated.  It is deleted just before the combined commit is made.
+squash_msg="$state_dir"/message-squash
+
+# If the current series of squash/fixups has not yet included a squash
+# command, then this file exists and holds the commit message of the
+# original "pick" commit.  (If the series ends without a "squash"
+# command, then this can be used as the commit message of the combined
+# commit without opening the editor.)
+fixup_msg="$state_dir"/message-fixup
+
+# $rewritten is the name of a directory containing files for each
+# commit that is reachable by at least one merge base of $head and
+# $upstream. They are not necessarily rewritten, but their children
+# might be.  This ensures that commits on merged, but otherwise
+# unrelated side branches are left alone. (Think "X" in the man page's
+# example.)
+rewritten="$state_dir"/rewritten
+
+dropped="$state_dir"/dropped
+
+end="$state_dir"/end
+msgnum="$state_dir"/msgnum
+
+# A script to set the GIT_AUTHOR_NAME, GIT_AUTHOR_EMAIL, and
+# GIT_AUTHOR_DATE that will be used for the commit that is currently
+# being rebased.
+author_script="$state_dir"/author-script
+
+# When an "edit" rebase command is being processed, the SHA1 of the
+# commit to be edited is recorded in this file.  When "git rebase
+# --continue" is executed, if there are any staged changes then they
+# will be amended to the HEAD commit, but only provided the HEAD
+# commit is still the commit to be edited.  When any other rebase
+# command is processed, this file is deleted.
+amend="$state_dir"/amend
+
+# For the post-rewrite hook, we make a list of rewritten commits and
+# their new sha1s.  The rewritten-pending list keeps the sha1s of
+# commits that have been processed, but not committed yet,
+# e.g. because they are waiting for a 'squash' command.
+rewritten_list="$state_dir"/rewritten-list
+rewritten_pending="$state_dir"/rewritten-pending
+
+# Work around Git for Windows' Bash whose "read" does not strip CRLF
+# and leaves CR at the end instead.
+cr=$(printf "\015")
+
+resolvemsg="
+$(gettext 'Resolve all conflicts manually, mark them as resolved with
+"git add/rm <conflicted_files>", then run "git rebase --continue".
+You can instead skip this commit: run "git rebase --skip".
+To abort and get back to the state before "git rebase", run "git rebase --abort".')
+"
+
+write_basic_state () {
+	echo "$head_name" > "$state_dir"/head-name &&
+	echo "$onto" > "$state_dir"/onto &&
+	echo "$orig_head" > "$state_dir"/orig-head &&
+	test t = "$GIT_QUIET" && : > "$state_dir"/quiet
+	test t = "$verbose" && : > "$state_dir"/verbose
+	test -n "$strategy" && echo "$strategy" > "$state_dir"/strategy
+	test -n "$strategy_opts" && echo "$strategy_opts" > \
+		"$state_dir"/strategy_opts
+	test -n "$allow_rerere_autoupdate" && echo "$allow_rerere_autoupdate" > \
+		"$state_dir"/allow_rerere_autoupdate
+	test -n "$gpg_sign_opt" && echo "$gpg_sign_opt" > "$state_dir"/gpg_sign_opt
+	test -n "$signoff" && echo "$signoff" >"$state_dir"/signoff
+	test -n "$reschedule_failed_exec" && : > "$state_dir"/reschedule-failed-exec
+}
+
+apply_autostash () {
+	if test -f "$state_dir/autostash"
+	then
+		stash_sha1=$(cat "$state_dir/autostash")
+		if git stash apply $stash_sha1 >/dev/null 2>&1
+		then
+			echo "$(gettext 'Applied autostash.')" >&2
+		else
+			git stash store -m "autostash" -q $stash_sha1 ||
+			die "$(eval_gettext "Cannot store \$stash_sha1")"
+			gettext 'Applying autostash resulted in conflicts.
+Your changes are safe in the stash.
+You can run "git stash pop" or "git stash drop" at any time.
+' >&2
+		fi
+	fi
+}
+
+output () {
+	case "$verbose" in
+	'')
+		output=$("$@" 2>&1 )
+		status=$?
+		test $status != 0 && printf "%s\n" "$output"
+		return $status
+		;;
+	*)
+		"$@"
+		;;
+	esac
+}
+
+strategy_args=${strategy:+--strategy=$strategy}
+test -n "$strategy_opts" &&
+eval '
+	for strategy_opt in '"$strategy_opts"'
+	do
+		strategy_args="$strategy_args -X$(git rev-parse --sq-quote "${strategy_opt#--}")"
+	done
+'
+
+GIT_CHERRY_PICK_HELP="$resolvemsg"
+export GIT_CHERRY_PICK_HELP
+
+comment_char=$(git config --get core.commentchar 2>/dev/null)
+case "$comment_char" in
+'' | auto)
+	comment_char="#"
+	;;
+?)
+	;;
+*)
+	comment_char=$(echo "$comment_char" | cut -c1)
+	;;
+esac
+
+warn () {
+	printf '%s\n' "$*" >&2
+}
+
+# Output the commit message for the specified commit.
+commit_message () {
+	git cat-file commit "$1" | sed "1,/^$/d"
+}
+
+orig_reflog_action="$GIT_REFLOG_ACTION"
+
+comment_for_reflog () {
+	case "$orig_reflog_action" in
+	''|rebase*)
+		GIT_REFLOG_ACTION="rebase -i ($1)"
+		export GIT_REFLOG_ACTION
+		;;
+	esac
+}
+
+last_count=
+mark_action_done () {
+	sed -e 1q < "$todo" >> "$done"
+	sed -e 1d < "$todo" >> "$todo".new
+	mv -f "$todo".new "$todo"
+	new_count=$(( $(git stripspace --strip-comments <"$done" | wc -l) ))
+	echo $new_count >"$msgnum"
+	total=$(($new_count + $(git stripspace --strip-comments <"$todo" | wc -l)))
+	echo $total >"$end"
+	if test "$last_count" != "$new_count"
+	then
+		last_count=$new_count
+		eval_gettext "Rebasing (\$new_count/\$total)"; printf "\r"
+		test -z "$verbose" || echo
+	fi
+}
+
+# Put the last action marked done at the beginning of the todo list
+# again. If there has not been an action marked done yet, leave the list of
+# items on the todo list unchanged.
+reschedule_last_action () {
+	tail -n 1 "$done" | cat - "$todo" >"$todo".new
+	sed -e \$d <"$done" >"$done".new
+	mv -f "$todo".new "$todo"
+	mv -f "$done".new "$done"
+}
+
+append_todo_help () {
+	gettext "
+Commands:
+p, pick <commit> = use commit
+r, reword <commit> = use commit, but edit the commit message
+e, edit <commit> = use commit, but stop for amending
+s, squash <commit> = use commit, but meld into previous commit
+f, fixup <commit> = like \"squash\", but discard this commit's log message
+x, exec <commit> = run command (the rest of the line) using shell
+d, drop <commit> = remove commit
+l, label <label> = label current HEAD with a name
+t, reset <label> = reset HEAD to a label
+m, merge [-C <commit> | -c <commit>] <label> [# <oneline>]
+.       create a merge commit using the original merge commit's
+.       message (or the oneline, if no original merge commit was
+.       specified). Use -c <commit> to reword the commit message.
+
+These lines can be re-ordered; they are executed from top to bottom.
+" | git stripspace --comment-lines >>"$todo"
+
+	if test $(get_missing_commit_check_level) = error
+	then
+		gettext "
+Do not remove any line. Use 'drop' explicitly to remove a commit.
+" | git stripspace --comment-lines >>"$todo"
+	else
+		gettext "
+If you remove a line here THAT COMMIT WILL BE LOST.
+" | git stripspace --comment-lines >>"$todo"
+	fi
+}
+
+make_patch () {
+	sha1_and_parents="$(git rev-list --parents -1 "$1")"
+	case "$sha1_and_parents" in
+	?*' '?*' '?*)
+		git diff --cc $sha1_and_parents
+		;;
+	?*' '?*)
+		git diff-tree -p "$1^!"
+		;;
+	*)
+		echo "Root commit"
+		;;
+	esac > "$state_dir"/patch
+	test -f "$msg" ||
+		commit_message "$1" > "$msg"
+	test -f "$author_script" ||
+		get_author_ident_from_commit "$1" > "$author_script"
+}
+
+die_with_patch () {
+	echo "$1" > "$state_dir"/stopped-sha
+	git update-ref REBASE_HEAD "$1"
+	make_patch "$1"
+	die "$2"
+}
+
+exit_with_patch () {
+	echo "$1" > "$state_dir"/stopped-sha
+	git update-ref REBASE_HEAD "$1"
+	make_patch $1
+	git rev-parse --verify HEAD > "$amend"
+	gpg_sign_opt_quoted=${gpg_sign_opt:+$(git rev-parse --sq-quote "$gpg_sign_opt")}
+	warn "$(eval_gettext "\
+You can amend the commit now, with
+
+	git commit --amend \$gpg_sign_opt_quoted
+
+Once you are satisfied with your changes, run
+
+	git rebase --continue")"
+	warn
+	exit $2
+}
+
+die_abort () {
+	apply_autostash
+	rm -rf "$state_dir"
+	die "$1"
+}
+
+has_action () {
+	test -n "$(git stripspace --strip-comments <"$1")"
+}
+
+is_empty_commit() {
+	tree=$(git rev-parse -q --verify "$1"^{tree} 2>/dev/null) || {
+		sha1=$1
+		die "$(eval_gettext "\$sha1: not a commit that can be picked")"
+	}
+	ptree=$(git rev-parse -q --verify "$1"^^{tree} 2>/dev/null) ||
+		ptree=4b825dc642cb6eb9a060e54bf8d69288fbee4904
+	test "$tree" = "$ptree"
+}
+
+is_merge_commit()
+{
+	git rev-parse --verify --quiet "$1"^2 >/dev/null 2>&1
+}
+
+# Run command with GIT_AUTHOR_NAME, GIT_AUTHOR_EMAIL, and
+# GIT_AUTHOR_DATE exported from the current environment.
+do_with_author () {
+	(
+		export GIT_AUTHOR_NAME GIT_AUTHOR_EMAIL GIT_AUTHOR_DATE
+		"$@"
+	)
+}
+
+git_sequence_editor () {
+	if test -z "$GIT_SEQUENCE_EDITOR"
+	then
+		GIT_SEQUENCE_EDITOR="$(git config sequence.editor)"
+		if [ -z "$GIT_SEQUENCE_EDITOR" ]
+		then
+			GIT_SEQUENCE_EDITOR="$(git var GIT_EDITOR)" || return $?
+		fi
+	fi
+
+	eval "$GIT_SEQUENCE_EDITOR" '"$@"'
+}
+
+pick_one () {
+	ff=--ff
+
+	case "$1" in -n) sha1=$2; ff= ;; *) sha1=$1 ;; esac
+	case "$force_rebase" in '') ;; ?*) ff= ;; esac
+	output git rev-parse --verify $sha1 || die "$(eval_gettext "Invalid commit name: \$sha1")"
+
+	if is_empty_commit "$sha1"
+	then
+		empty_args="--allow-empty"
+	fi
+
+	pick_one_preserving_merges "$@"
+}
+
+pick_one_preserving_merges () {
+	fast_forward=t
+	case "$1" in
+	-n)
+		fast_forward=f
+		sha1=$2
+		;;
+	*)
+		sha1=$1
+		;;
+	esac
+	sha1=$(git rev-parse $sha1)
+
+	if test -f "$state_dir"/current-commit && test "$fast_forward" = t
+	then
+		while read current_commit
+		do
+			git rev-parse HEAD > "$rewritten"/$current_commit
+		done <"$state_dir"/current-commit
+		rm "$state_dir"/current-commit ||
+			die "$(gettext "Cannot write current commit's replacement sha1")"
+	fi
+
+	echo $sha1 >> "$state_dir"/current-commit
+
+	# rewrite parents; if none were rewritten, we can fast-forward.
+	new_parents=
+	pend=" $(git rev-list --parents -1 $sha1 | cut -d' ' -s -f2-)"
+	if test "$pend" = " "
+	then
+		pend=" root"
+	fi
+	while [ "$pend" != "" ]
+	do
+		p=$(expr "$pend" : ' \([^ ]*\)')
+		pend="${pend# $p}"
+
+		if test -f "$rewritten"/$p
+		then
+			new_p=$(cat "$rewritten"/$p)
+
+			# If the todo reordered commits, and our parent is marked for
+			# rewriting, but hasn't been gotten to yet, assume the user meant to
+			# drop it on top of the current HEAD
+			if test -z "$new_p"
+			then
+				new_p=$(git rev-parse HEAD)
+			fi
+
+			test $p != $new_p && fast_forward=f
+			case "$new_parents" in
+			*$new_p*)
+				;; # do nothing; that parent is already there
+			*)
+				new_parents="$new_parents $new_p"
+				;;
+			esac
+		else
+			if test -f "$dropped"/$p
+			then
+				fast_forward=f
+				replacement="$(cat "$dropped"/$p)"
+				test -z "$replacement" && replacement=root
+				pend=" $replacement$pend"
+			else
+				new_parents="$new_parents $p"
+			fi
+		fi
+	done
+	case $fast_forward in
+	t)
+		output warn "$(eval_gettext "Fast-forward to \$sha1")"
+		output git reset --hard $sha1 ||
+			die "$(eval_gettext "Cannot fast-forward to \$sha1")"
+		;;
+	f)
+		first_parent=$(expr "$new_parents" : ' \([^ ]*\)')
+
+		if [ "$1" != "-n" ]
+		then
+			# detach HEAD to current parent
+			output git checkout $first_parent 2> /dev/null ||
+				die "$(eval_gettext "Cannot move HEAD to \$first_parent")"
+		fi
+
+		case "$new_parents" in
+		' '*' '*)
+			test "a$1" = a-n && die "$(eval_gettext "Refusing to squash a merge: \$sha1")"
+
+			# redo merge
+			author_script_content=$(get_author_ident_from_commit $sha1)
+			eval "$author_script_content"
+			msg_content="$(commit_message $sha1)"
+			# No point in merging the first parent, that's HEAD
+			new_parents=${new_parents# $first_parent}
+			merge_args="--no-log --no-ff"
+			if ! do_with_author output eval \
+				git merge ${gpg_sign_opt:+$(git rev-parse \
+					--sq-quote "$gpg_sign_opt")} \
+				$allow_rerere_autoupdate "$merge_args" \
+				"$strategy_args" \
+				-m "$(git rev-parse --sq-quote "$msg_content")" \
+				"$new_parents"
+			then
+				printf "%s\n" "$msg_content" > "$GIT_DIR"/MERGE_MSG
+				die_with_patch $sha1 "$(eval_gettext "Error redoing merge \$sha1")"
+			fi
+			echo "$sha1 $(git rev-parse HEAD^0)" >> "$rewritten_list"
+			;;
+		*)
+			output eval git cherry-pick $allow_rerere_autoupdate \
+				$allow_empty_message \
+				${gpg_sign_opt:+$(git rev-parse --sq-quote "$gpg_sign_opt")} \
+				"$strategy_args" "$@" ||
+				die_with_patch $sha1 "$(eval_gettext "Could not pick \$sha1")"
+			;;
+		esac
+		;;
+	esac
+}
+
+this_nth_commit_message () {
+	n=$1
+	eval_gettext "This is the commit message #\${n}:"
+}
+
+skip_nth_commit_message () {
+	n=$1
+	eval_gettext "The commit message #\${n} will be skipped:"
+}
+
+update_squash_messages () {
+	if test -f "$squash_msg"; then
+		mv "$squash_msg" "$squash_msg".bak || exit
+		count=$(($(sed -n \
+			-e "1s/^$comment_char[^0-9]*\([0-9][0-9]*\).*/\1/p" \
+			-e "q" < "$squash_msg".bak)+1))
+		{
+			printf '%s\n' "$comment_char $(eval_ngettext \
+				"This is a combination of \$count commit." \
+				"This is a combination of \$count commits." \
+				$count)"
+			sed -e 1d -e '2,/^./{
+				/^$/d
+			}' <"$squash_msg".bak
+		} >"$squash_msg"
+	else
+		commit_message HEAD >"$fixup_msg" ||
+		die "$(eval_gettext "Cannot write \$fixup_msg")"
+		count=2
+		{
+			printf '%s\n' "$comment_char $(gettext "This is a combination of 2 commits.")"
+			printf '%s\n' "$comment_char $(gettext "This is the 1st commit message:")"
+			echo
+			cat "$fixup_msg"
+		} >"$squash_msg"
+	fi
+	case $1 in
+	squash)
+		rm -f "$fixup_msg"
+		echo
+		printf '%s\n' "$comment_char $(this_nth_commit_message $count)"
+		echo
+		commit_message $2
+		;;
+	fixup)
+		echo
+		printf '%s\n' "$comment_char $(skip_nth_commit_message $count)"
+		echo
+		# Change the space after the comment character to TAB:
+		commit_message $2 | git stripspace --comment-lines | sed -e 's/ /	/'
+		;;
+	esac >>"$squash_msg"
+}
+
+peek_next_command () {
+	git stripspace --strip-comments <"$todo" | sed -n -e 's/ .*//p' -e q
+}
+
+# A squash/fixup has failed.  Prepare the long version of the squash
+# commit message, then die_with_patch.  This code path requires the
+# user to edit the combined commit message for all commits that have
+# been squashed/fixedup so far.  So also erase the old squash
+# messages, effectively causing the combined commit to be used as the
+# new basis for any further squash/fixups.  Args: sha1 rest
+die_failed_squash() {
+	sha1=$1
+	rest=$2
+	mv "$squash_msg" "$msg" || exit
+	rm -f "$fixup_msg"
+	cp "$msg" "$GIT_DIR"/MERGE_MSG || exit
+	warn
+	warn "$(eval_gettext "Could not apply \$sha1... \$rest")"
+	die_with_patch $sha1 ""
+}
+
+flush_rewritten_pending() {
+	test -s "$rewritten_pending" || return
+	newsha1="$(git rev-parse HEAD^0)"
+	sed "s/$/ $newsha1/" < "$rewritten_pending" >> "$rewritten_list"
+	rm -f "$rewritten_pending"
+}
+
+record_in_rewritten() {
+	oldsha1="$(git rev-parse $1)"
+	echo "$oldsha1" >> "$rewritten_pending"
+
+	case "$(peek_next_command)" in
+	squash|s|fixup|f)
+		;;
+	*)
+		flush_rewritten_pending
+		;;
+	esac
+}
+
+do_pick () {
+	sha1=$1
+	rest=$2
+	if test "$(git rev-parse HEAD)" = "$squash_onto"
+	then
+		# Set the correct commit message and author info on the
+		# sentinel root before cherry-picking the original changes
+		# without committing (-n).  Finally, update the sentinel again
+		# to include these changes.  If the cherry-pick results in a
+		# conflict, this means our behaviour is similar to a standard
+		# failed cherry-pick during rebase, with a dirty index to
+		# resolve before manually running git commit --amend then git
+		# rebase --continue.
+		git commit --allow-empty --allow-empty-message --amend \
+			   --no-post-rewrite -n -q -C $sha1 $signoff &&
+			pick_one -n $sha1 &&
+			git commit --allow-empty --allow-empty-message \
+				   --amend --no-post-rewrite -n -q -C $sha1 $signoff \
+				   ${gpg_sign_opt:+"$gpg_sign_opt"} ||
+				   die_with_patch $sha1 "$(eval_gettext "Could not apply \$sha1... \$rest")"
+	else
+		pick_one $sha1 ||
+			die_with_patch $sha1 "$(eval_gettext "Could not apply \$sha1... \$rest")"
+	fi
+}
+
+do_next () {
+	rm -f "$msg" "$author_script" "$amend" "$state_dir"/stopped-sha || exit
+	read -r command sha1 rest < "$todo"
+	case "$command" in
+	"$comment_char"*|''|noop|drop|d)
+		mark_action_done
+		;;
+	"$cr")
+		# Work around CR left by "read" (e.g. with Git for Windows' Bash).
+		mark_action_done
+		;;
+	pick|p)
+		comment_for_reflog pick
+
+		mark_action_done
+		do_pick $sha1 "$rest"
+		record_in_rewritten $sha1
+		;;
+	reword|r)
+		comment_for_reflog reword
+
+		mark_action_done
+		do_pick $sha1 "$rest"
+		git commit --amend --no-post-rewrite ${gpg_sign_opt:+"$gpg_sign_opt"} \
+			$allow_empty_message || {
+			warn "$(eval_gettext "\
+Could not amend commit after successfully picking \$sha1... \$rest
+This is most likely due to an empty commit message, or the pre-commit hook
+failed. If the pre-commit hook failed, you may need to resolve the issue before
+you are able to reword the commit.")"
+			exit_with_patch $sha1 1
+		}
+		record_in_rewritten $sha1
+		;;
+	edit|e)
+		comment_for_reflog edit
+
+		mark_action_done
+		do_pick $sha1 "$rest"
+		sha1_abbrev=$(git rev-parse --short $sha1)
+		warn "$(eval_gettext "Stopped at \$sha1_abbrev... \$rest")"
+		exit_with_patch $sha1 0
+		;;
+	squash|s|fixup|f)
+		case "$command" in
+		squash|s)
+			squash_style=squash
+			;;
+		fixup|f)
+			squash_style=fixup
+			;;
+		esac
+		comment_for_reflog $squash_style
+
+		test -f "$done" && has_action "$done" ||
+			die "$(eval_gettext "Cannot '\$squash_style' without a previous commit")"
+
+		mark_action_done
+		update_squash_messages $squash_style $sha1
+		author_script_content=$(get_author_ident_from_commit HEAD)
+		echo "$author_script_content" > "$author_script"
+		eval "$author_script_content"
+		if ! pick_one -n $sha1
+		then
+			git rev-parse --verify HEAD >"$amend"
+			die_failed_squash $sha1 "$rest"
+		fi
+		case "$(peek_next_command)" in
+		squash|s|fixup|f)
+			# This is an intermediate commit; its message will only be
+			# used in case of trouble.  So use the long version:
+			do_with_author output git commit --amend --no-verify -F "$squash_msg" \
+				${gpg_sign_opt:+"$gpg_sign_opt"} $allow_empty_message ||
+				die_failed_squash $sha1 "$rest"
+			;;
+		*)
+			# This is the final command of this squash/fixup group
+			if test -f "$fixup_msg"
+			then
+				do_with_author git commit --amend --no-verify -F "$fixup_msg" \
+					${gpg_sign_opt:+"$gpg_sign_opt"} $allow_empty_message ||
+					die_failed_squash $sha1 "$rest"
+			else
+				cp "$squash_msg" "$GIT_DIR"/SQUASH_MSG || exit
+				rm -f "$GIT_DIR"/MERGE_MSG
+				do_with_author git commit --amend --no-verify -F "$GIT_DIR"/SQUASH_MSG -e \
+					${gpg_sign_opt:+"$gpg_sign_opt"} $allow_empty_message ||
+					die_failed_squash $sha1 "$rest"
+			fi
+			rm -f "$squash_msg" "$fixup_msg"
+			;;
+		esac
+		record_in_rewritten $sha1
+		;;
+	x|"exec")
+		read -r command rest < "$todo"
+		mark_action_done
+		eval_gettextln "Executing: \$rest"
+		"${SHELL:-@SHELL_PATH@}" -c "$rest" # Actual execution
+		status=$?
+		# Run in subshell because require_clean_work_tree can die.
+		dirty=f
+		(require_clean_work_tree "rebase" 2>/dev/null) || dirty=t
+		if test "$status" -ne 0
+		then
+			warn "$(eval_gettext "Execution failed: \$rest")"
+			test "$dirty" = f ||
+				warn "$(gettext "and made changes to the index and/or the working tree")"
+
+			warn "$(gettext "\
+You can fix the problem, and then run
+
+	git rebase --continue")"
+			warn
+			if test $status -eq 127		# command not found
+			then
+				status=1
+			fi
+			exit "$status"
+		elif test "$dirty" = t
+		then
+			# TRANSLATORS: after these lines is a command to be issued by the user
+			warn "$(eval_gettext "\
+Execution succeeded: \$rest
+but left changes to the index and/or the working tree
+Commit or stash your changes, and then run
+
+	git rebase --continue")"
+			warn
+			exit 1
+		fi
+		;;
+	*)
+		warn "$(eval_gettext "Unknown command: \$command \$sha1 \$rest")"
+		fixtodo="$(gettext "Please fix this using 'git rebase --edit-todo'.")"
+		if git rev-parse --verify -q "$sha1" >/dev/null
+		then
+			die_with_patch $sha1 "$fixtodo"
+		else
+			die "$fixtodo"
+		fi
+		;;
+	esac
+	test -s "$todo" && return
+
+	comment_for_reflog finish &&
+	newhead=$(git rev-parse HEAD) &&
+	case $head_name in
+	refs/*)
+		message="$GIT_REFLOG_ACTION: $head_name onto $onto" &&
+		git update-ref -m "$message" $head_name $newhead $orig_head &&
+		git symbolic-ref \
+		  -m "$GIT_REFLOG_ACTION: returning to $head_name" \
+		  HEAD $head_name
+		;;
+	esac && {
+		test ! -f "$state_dir"/verbose ||
+			git diff-tree --stat $orig_head..HEAD
+	} &&
+	{
+		test -s "$rewritten_list" &&
+		git notes copy --for-rewrite=rebase < "$rewritten_list" ||
+		true # we don't care if this copying failed
+	} &&
+	hook="$(git rev-parse --git-path hooks/post-rewrite)"
+	if test -x "$hook" && test -s "$rewritten_list"; then
+		"$hook" rebase < "$rewritten_list"
+		true # we don't care if this hook failed
+	fi &&
+		warn "$(eval_gettext "Successfully rebased and updated \$head_name.")"
+
+	return 1 # not failure; just to break the do_rest loop
+}
+
+# can only return 0, when the infinite loop breaks
+do_rest () {
+	while :
+	do
+		do_next || break
+	done
+}
+
+expand_todo_ids() {
+	git rebase--interactive --expand-ids
+}
+
+collapse_todo_ids() {
+	git rebase--interactive --shorten-ids
+}
+
+# Switch to the branch in $into and notify it in the reflog
+checkout_onto () {
+	GIT_REFLOG_ACTION="$GIT_REFLOG_ACTION: checkout $onto_name"
+	output git checkout $onto || die_abort "$(gettext "could not detach HEAD")"
+	git update-ref ORIG_HEAD $orig_head
+}
+
+get_missing_commit_check_level () {
+	check_level=$(git config --get rebase.missingCommitsCheck)
+	check_level=${check_level:-ignore}
+	# Don't be case sensitive
+	printf '%s' "$check_level" | tr 'A-Z' 'a-z'
+}
+
+# Initiate an action. If the cannot be any
+# further action it  may exec a command
+# or exit and not return.
+#
+# TODO: Consider a cleaner return model so it
+# never exits and always return 0 if process
+# is complete.
+#
+# Parameter 1 is the action to initiate.
+#
+# Returns 0 if the action was able to complete
+# and if 1 if further processing is required.
+initiate_action () {
+	case "$1" in
+	continue)
+		# do we have anything to commit?
+		if git diff-index --cached --quiet HEAD --
+		then
+			# Nothing to commit -- skip this commit
+
+			test ! -f "$GIT_DIR"/CHERRY_PICK_HEAD ||
+			rm "$GIT_DIR"/CHERRY_PICK_HEAD ||
+			die "$(gettext "Could not remove CHERRY_PICK_HEAD")"
+		else
+			if ! test -f "$author_script"
+			then
+				gpg_sign_opt_quoted=${gpg_sign_opt:+$(git rev-parse --sq-quote "$gpg_sign_opt")}
+				die "$(eval_gettext "\
+You have staged changes in your working tree.
+If these changes are meant to be
+squashed into the previous commit, run:
+
+  git commit --amend \$gpg_sign_opt_quoted
+
+If they are meant to go into a new commit, run:
+
+  git commit \$gpg_sign_opt_quoted
+
+In both cases, once you're done, continue with:
+
+  git rebase --continue
+")"
+			fi
+			. "$author_script" ||
+				die "$(gettext "Error trying to find the author identity to amend commit")"
+			if test -f "$amend"
+			then
+				current_head=$(git rev-parse --verify HEAD)
+				test "$current_head" = $(cat "$amend") ||
+				die "$(gettext "\
+You have uncommitted changes in your working tree. Please commit them
+first and then run 'git rebase --continue' again.")"
+				do_with_author git commit --amend --no-verify -F "$msg" -e \
+					${gpg_sign_opt:+"$gpg_sign_opt"} $allow_empty_message ||
+					die "$(gettext "Could not commit staged changes.")"
+			else
+				do_with_author git commit --no-verify -F "$msg" -e \
+					${gpg_sign_opt:+"$gpg_sign_opt"} $allow_empty_message ||
+					die "$(gettext "Could not commit staged changes.")"
+			fi
+		fi
+
+		if test -r "$state_dir"/stopped-sha
+		then
+			record_in_rewritten "$(cat "$state_dir"/stopped-sha)"
+		fi
+
+		require_clean_work_tree "rebase"
+		do_rest
+		return 0
+		;;
+	skip)
+		git rerere clear
+		do_rest
+		return 0
+		;;
+	edit-todo)
+		git stripspace --strip-comments <"$todo" >"$todo".new
+		mv -f "$todo".new "$todo"
+		collapse_todo_ids
+		append_todo_help
+		gettext "
+You are editing the todo file of an ongoing interactive rebase.
+To continue rebase after editing, run:
+    git rebase --continue
+
+" | git stripspace --comment-lines >>"$todo"
+
+		git_sequence_editor "$todo" ||
+			die "$(gettext "Could not execute editor")"
+		expand_todo_ids
+
+		exit
+		;;
+	show-current-patch)
+		exec git show REBASE_HEAD --
+		;;
+	*)
+		return 1 # continue
+		;;
+	esac
+}
+
+setup_reflog_action () {
+	comment_for_reflog start
+
+	if test ! -z "$switch_to"
+	then
+		GIT_REFLOG_ACTION="$GIT_REFLOG_ACTION: checkout $switch_to"
+		output git checkout "$switch_to" -- ||
+			die "$(eval_gettext "Could not checkout \$switch_to")"
+
+		comment_for_reflog start
+	fi
+}
+
+init_basic_state () {
+	orig_head=$(git rev-parse --verify HEAD) || die "$(gettext "No HEAD?")"
+	mkdir -p "$state_dir" || die "$(eval_gettext "Could not create temporary \$state_dir")"
+	rm -f "$(git rev-parse --git-path REBASE_HEAD)"
+
+	: > "$state_dir"/interactive || die "$(gettext "Could not mark as interactive")"
+	write_basic_state
+}
+
+init_revisions_and_shortrevisions () {
+	shorthead=$(git rev-parse --short $orig_head)
+	shortonto=$(git rev-parse --short $onto)
+	if test -z "$rebase_root"
+		# this is now equivalent to ! -z "$upstream"
+	then
+		shortupstream=$(git rev-parse --short $upstream)
+		revisions=$upstream...$orig_head
+		shortrevisions=$shortupstream..$shorthead
+	else
+		revisions=$onto...$orig_head
+		shortrevisions=$shorthead
+		test -z "$squash_onto" ||
+		echo "$squash_onto" >"$state_dir"/squash-onto
+	fi
+}
+
+complete_action() {
+	test -s "$todo" || echo noop >> "$todo"
+	test -z "$autosquash" || git rebase--interactive --rearrange-squash || exit
+	test -n "$cmd" && git rebase--interactive --add-exec-commands --cmd "$cmd"
+
+	todocount=$(git stripspace --strip-comments <"$todo" | wc -l)
+	todocount=${todocount##* }
+
+cat >>"$todo" <<EOF
+
+$comment_char $(eval_ngettext \
+	"Rebase \$shortrevisions onto \$shortonto (\$todocount command)" \
+	"Rebase \$shortrevisions onto \$shortonto (\$todocount commands)" \
+	"$todocount")
+EOF
+	append_todo_help
+	gettext "
+However, if you remove everything, the rebase will be aborted.
+
+" | git stripspace --comment-lines >>"$todo"
+
+	if test -z "$keep_empty"
+	then
+		printf '%s\n' "$comment_char $(gettext "Note that empty commits are commented out")" >>"$todo"
+	fi
+
+
+	has_action "$todo" ||
+		return 2
+
+	cp "$todo" "$todo".backup
+	collapse_todo_ids
+	git_sequence_editor "$todo" ||
+		die_abort "$(gettext "Could not execute editor")"
+
+	has_action "$todo" ||
+		return 2
+
+	git rebase--interactive --check-todo-list || {
+		ret=$?
+		checkout_onto
+		exit $ret
+	}
+
+	expand_todo_ids
+	checkout_onto
+	do_rest
+}
+
+git_rebase__preserve_merges () {
+	initiate_action "$action"
+	ret=$?
+	if test $ret = 0; then
+		return 0
+	fi
+
+	setup_reflog_action
+	init_basic_state
+
+	if test -z "$rebase_root"
+	then
+		mkdir "$rewritten" &&
+		for c in $(git merge-base --all $orig_head $upstream)
+		do
+			echo $onto > "$rewritten"/$c ||
+				die "$(gettext "Could not init rewritten commits")"
+		done
+	else
+		mkdir "$rewritten" &&
+		echo $onto > "$rewritten"/root ||
+			die "$(gettext "Could not init rewritten commits")"
+	fi
+
+	init_revisions_and_shortrevisions
+
+	format=$(git config --get rebase.instructionFormat)
+	# the 'rev-list .. | sed' requires %m to parse; the instruction requires %H to parse
+	git rev-list --format="%m%H ${format:-%s}" \
+		--reverse --left-right --topo-order \
+		$revisions ${restrict_revision+^$restrict_revision} | \
+		sed -n "s/^>//p" |
+	while read -r sha1 rest
+	do
+		if test -z "$keep_empty" && is_empty_commit $sha1 && ! is_merge_commit $sha1
+		then
+			comment_out="$comment_char "
+		else
+			comment_out=
+		fi
+
+		if test -z "$rebase_root"
+		then
+			preserve=t
+			for p in $(git rev-list --parents -1 $sha1 | cut -d' ' -s -f2-)
+			do
+				if test -f "$rewritten"/$p
+				then
+					preserve=f
+				fi
+			done
+		else
+			preserve=f
+		fi
+		if test f = "$preserve"
+		then
+			touch "$rewritten"/$sha1
+			printf '%s\n' "${comment_out}pick $sha1 $rest" >>"$todo"
+		fi
+	done
+
+	# Watch for commits that been dropped by --cherry-pick
+	mkdir "$dropped"
+	# Save all non-cherry-picked changes
+	git rev-list $revisions --left-right --cherry-pick | \
+		sed -n "s/^>//p" > "$state_dir"/not-cherry-picks
+	# Now all commits and note which ones are missing in
+	# not-cherry-picks and hence being dropped
+	git rev-list $revisions |
+	while read rev
+	do
+		if test -f "$rewritten"/$rev &&
+		   ! sane_grep "$rev" "$state_dir"/not-cherry-picks >/dev/null
+		then
+			# Use -f2 because if rev-list is telling us this commit is
+			# not worthwhile, we don't want to track its multiple heads,
+			# just the history of its first-parent for others that will
+			# be rebasing on top of it
+			git rev-list --parents -1 $rev | cut -d' ' -s -f2 > "$dropped"/$rev
+			sha1=$(git rev-list -1 $rev)
+			sane_grep -v "^[a-z][a-z]* $sha1" <"$todo" > "${todo}2" ; mv "${todo}2" "$todo"
+			rm "$rewritten"/$rev
+		fi
+	done
+
+	complete_action
+}
diff -pruN 1.2.1+git2.18.0-1/git/git-rebase.sh 1.2.3+git2.25.1-1/git/git-rebase.sh
--- 1.2.1+git2.18.0-1/git/git-rebase.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/git-rebase.sh	1970-01-01 00:00:00.000000000 +0000
@@ -1,720 +0,0 @@
-#!/bin/sh
-#
-# Copyright (c) 2005 Junio C Hamano.
-#
-
-SUBDIRECTORY_OK=Yes
-OPTIONS_KEEPDASHDASH=
-OPTIONS_STUCKLONG=t
-OPTIONS_SPEC="\
-git rebase [-i] [options] [--exec <cmd>] [--onto <newbase>] [<upstream>] [<branch>]
-git rebase [-i] [options] [--exec <cmd>] [--onto <newbase>] --root [<branch>]
-git rebase --continue | --abort | --skip | --edit-todo
---
- Available options are
-v,verbose!         display a diffstat of what changed upstream
-q,quiet!           be quiet. implies --no-stat
-autostash          automatically stash/stash pop before and after
-fork-point         use 'merge-base --fork-point' to refine upstream
-onto=!             rebase onto given branch instead of upstream
-r,rebase-merges?   try to rebase merges instead of skipping them
-p,preserve-merges! try to recreate merges instead of ignoring them
-s,strategy=!       use the given merge strategy
-no-ff!             cherry-pick all commits, even if unchanged
-m,merge!           use merging strategies to rebase
-i,interactive!     let the user edit the list of commits to rebase
-x,exec=!           add exec lines after each commit of the editable list
-k,keep-empty	   preserve empty commits during rebase
-allow-empty-message allow rebasing commits with empty messages
-f,force-rebase!    force rebase even if branch is up to date
-X,strategy-option=! pass the argument through to the merge strategy
-stat!              display a diffstat of what changed upstream
-n,no-stat!         do not show diffstat of what changed upstream
-verify             allow pre-rebase hook to run
-rerere-autoupdate  allow rerere to update index with resolved conflicts
-root!              rebase all reachable commits up to the root(s)
-autosquash         move commits that begin with squash!/fixup! under -i
-committer-date-is-author-date! passed to 'git am'
-ignore-date!       passed to 'git am'
-signoff            passed to 'git am'
-whitespace=!       passed to 'git apply'
-ignore-whitespace! passed to 'git apply'
-C=!                passed to 'git apply'
-S,gpg-sign?        GPG-sign commits
- Actions:
-continue!          continue
-abort!             abort and check out the original branch
-skip!              skip current patch and continue
-edit-todo!         edit the todo list during an interactive rebase
-quit!              abort but keep HEAD where it is
-show-current-patch! show the patch file being applied or merged
-"
-. git-sh-setup
-set_reflog_action rebase
-require_work_tree_exists
-cd_to_toplevel
-
-LF='
-'
-ok_to_skip_pre_rebase=
-resolvemsg="
-$(gettext 'Resolve all conflicts manually, mark them as resolved with
-"git add/rm <conflicted_files>", then run "git rebase --continue".
-You can instead skip this commit: run "git rebase --skip".
-To abort and get back to the state before "git rebase", run "git rebase --abort".')
-"
-squash_onto=
-unset onto
-unset restrict_revision
-cmd=
-strategy=
-strategy_opts=
-do_merge=
-merge_dir="$GIT_DIR"/rebase-merge
-apply_dir="$GIT_DIR"/rebase-apply
-verbose=
-diffstat=
-test "$(git config --bool rebase.stat)" = true && diffstat=t
-autostash="$(git config --bool rebase.autostash || echo false)"
-fork_point=auto
-git_am_opt=
-git_format_patch_opt=
-rebase_root=
-force_rebase=
-allow_rerere_autoupdate=
-# Non-empty if a rebase was in progress when 'git rebase' was invoked
-in_progress=
-# One of {am, merge, interactive}
-type=
-# One of {"$GIT_DIR"/rebase-apply, "$GIT_DIR"/rebase-merge}
-state_dir=
-# One of {'', continue, skip, abort}, as parsed from command line
-action=
-rebase_merges=
-rebase_cousins=
-preserve_merges=
-autosquash=
-keep_empty=
-allow_empty_message=
-signoff=
-test "$(git config --bool rebase.autosquash)" = "true" && autosquash=t
-case "$(git config --bool commit.gpgsign)" in
-true)	gpg_sign_opt=-S ;;
-*)	gpg_sign_opt= ;;
-esac
-
-read_basic_state () {
-	test -f "$state_dir/head-name" &&
-	test -f "$state_dir/onto" &&
-	head_name=$(cat "$state_dir"/head-name) &&
-	onto=$(cat "$state_dir"/onto) &&
-	# We always write to orig-head, but interactive rebase used to write to
-	# head. Fall back to reading from head to cover for the case that the
-	# user upgraded git with an ongoing interactive rebase.
-	if test -f "$state_dir"/orig-head
-	then
-		orig_head=$(cat "$state_dir"/orig-head)
-	else
-		orig_head=$(cat "$state_dir"/head)
-	fi &&
-	GIT_QUIET=$(cat "$state_dir"/quiet) &&
-	test -f "$state_dir"/verbose && verbose=t
-	test -f "$state_dir"/strategy && strategy="$(cat "$state_dir"/strategy)"
-	test -f "$state_dir"/strategy_opts &&
-		strategy_opts="$(cat "$state_dir"/strategy_opts)"
-	test -f "$state_dir"/allow_rerere_autoupdate &&
-		allow_rerere_autoupdate="$(cat "$state_dir"/allow_rerere_autoupdate)"
-	test -f "$state_dir"/gpg_sign_opt &&
-		gpg_sign_opt="$(cat "$state_dir"/gpg_sign_opt)"
-	test -f "$state_dir"/signoff && {
-		signoff="$(cat "$state_dir"/signoff)"
-		force_rebase=t
-	}
-}
-
-write_basic_state () {
-	echo "$head_name" > "$state_dir"/head-name &&
-	echo "$onto" > "$state_dir"/onto &&
-	echo "$orig_head" > "$state_dir"/orig-head &&
-	echo "$GIT_QUIET" > "$state_dir"/quiet &&
-	test t = "$verbose" && : > "$state_dir"/verbose
-	test -n "$strategy" && echo "$strategy" > "$state_dir"/strategy
-	test -n "$strategy_opts" && echo "$strategy_opts" > \
-		"$state_dir"/strategy_opts
-	test -n "$allow_rerere_autoupdate" && echo "$allow_rerere_autoupdate" > \
-		"$state_dir"/allow_rerere_autoupdate
-	test -n "$gpg_sign_opt" && echo "$gpg_sign_opt" > "$state_dir"/gpg_sign_opt
-	test -n "$signoff" && echo "$signoff" >"$state_dir"/signoff
-}
-
-output () {
-	case "$verbose" in
-	'')
-		output=$("$@" 2>&1 )
-		status=$?
-		test $status != 0 && printf "%s\n" "$output"
-		return $status
-		;;
-	*)
-		"$@"
-		;;
-	esac
-}
-
-move_to_original_branch () {
-	case "$head_name" in
-	refs/*)
-		message="rebase finished: $head_name onto $onto"
-		git update-ref -m "$message" \
-			$head_name $(git rev-parse HEAD) $orig_head &&
-		git symbolic-ref \
-			-m "rebase finished: returning to $head_name" \
-			HEAD $head_name ||
-		die "$(eval_gettext "Could not move back to \$head_name")"
-		;;
-	esac
-}
-
-apply_autostash () {
-	if test -f "$state_dir/autostash"
-	then
-		stash_sha1=$(cat "$state_dir/autostash")
-		if git stash apply $stash_sha1 >/dev/null 2>&1
-		then
-			echo "$(gettext 'Applied autostash.')" >&2
-		else
-			git stash store -m "autostash" -q $stash_sha1 ||
-			die "$(eval_gettext "Cannot store \$stash_sha1")"
-			gettext 'Applying autostash resulted in conflicts.
-Your changes are safe in the stash.
-You can run "git stash pop" or "git stash drop" at any time.
-' >&2
-		fi
-	fi
-}
-
-finish_rebase () {
-	rm -f "$(git rev-parse --git-path REBASE_HEAD)"
-	apply_autostash &&
-	{ git gc --auto || true; } &&
-	rm -rf "$state_dir"
-}
-
-run_specific_rebase () {
-	if [ "$interactive_rebase" = implied ]; then
-		GIT_EDITOR=:
-		export GIT_EDITOR
-		autosquash=
-	fi
-	. git-rebase--$type
-	git_rebase__$type${preserve_merges:+__preserve_merges}
-	ret=$?
-	if test $ret -eq 0
-	then
-		finish_rebase
-	elif test $ret -eq 2 # special exit status for rebase -i
-	then
-		apply_autostash &&
-		rm -rf "$state_dir" &&
-		die "Nothing to do"
-	fi
-	exit $ret
-}
-
-run_pre_rebase_hook () {
-	if test -z "$ok_to_skip_pre_rebase" &&
-	   test -x "$(git rev-parse --git-path hooks/pre-rebase)"
-	then
-		"$(git rev-parse --git-path hooks/pre-rebase)" ${1+"$@"} ||
-		die "$(gettext "The pre-rebase hook refused to rebase.")"
-	fi
-}
-
-test -f "$apply_dir"/applying &&
-	die "$(gettext "It looks like 'git am' is in progress. Cannot rebase.")"
-
-if test -d "$apply_dir"
-then
-	type=am
-	state_dir="$apply_dir"
-elif test -d "$merge_dir"
-then
-	if test -f "$merge_dir"/interactive
-	then
-		type=interactive
-		interactive_rebase=explicit
-	else
-		type=merge
-	fi
-	state_dir="$merge_dir"
-fi
-test -n "$type" && in_progress=t
-
-total_argc=$#
-while test $# != 0
-do
-	case "$1" in
-	--no-verify)
-		ok_to_skip_pre_rebase=yes
-		;;
-	--verify)
-		ok_to_skip_pre_rebase=
-		;;
-	--continue|--skip|--abort|--quit|--edit-todo|--show-current-patch)
-		test $total_argc -eq 2 || usage
-		action=${1##--}
-		;;
-	--onto=*)
-		onto="${1#--onto=}"
-		;;
-	--exec=*)
-		cmd="${cmd}exec ${1#--exec=}${LF}"
-		test -z "$interactive_rebase" && interactive_rebase=implied
-		;;
-	--interactive)
-		interactive_rebase=explicit
-		;;
-	--keep-empty)
-		keep_empty=yes
-		;;
-	--allow-empty-message)
-		allow_empty_message=--allow-empty-message
-		;;
-	--no-keep-empty)
-		keep_empty=
-		;;
-	--rebase-merges)
-		rebase_merges=t
-		test -z "$interactive_rebase" && interactive_rebase=implied
-		;;
-	--rebase-merges=*)
-		rebase_merges=t
-		case "${1#*=}" in
-		rebase-cousins) rebase_cousins=t;;
-		no-rebase-cousins) rebase_cousins=;;
-		*) die "Unknown mode: $1";;
-		esac
-		test -z "$interactive_rebase" && interactive_rebase=implied
-		;;
-	--preserve-merges)
-		preserve_merges=t
-		test -z "$interactive_rebase" && interactive_rebase=implied
-		;;
-	--autosquash)
-		autosquash=t
-		;;
-	--no-autosquash)
-		autosquash=
-		;;
-	--fork-point)
-		fork_point=t
-		;;
-	--no-fork-point)
-		fork_point=
-		;;
-	--merge)
-		do_merge=t
-		;;
-	--strategy-option=*)
-		strategy_opts="$strategy_opts $(git rev-parse --sq-quote "--${1#--strategy-option=}")"
-		do_merge=t
-		test -z "$strategy" && strategy=recursive
-		;;
-	--strategy=*)
-		strategy="${1#--strategy=}"
-		do_merge=t
-		;;
-	--no-stat)
-		diffstat=
-		;;
-	--stat)
-		diffstat=t
-		;;
-	--autostash)
-		autostash=true
-		;;
-	--no-autostash)
-		autostash=false
-		;;
-	--verbose)
-		verbose=t
-		diffstat=t
-		GIT_QUIET=
-		;;
-	--quiet)
-		GIT_QUIET=t
-		git_am_opt="$git_am_opt -q"
-		verbose=
-		diffstat=
-		;;
-	--whitespace=*)
-		git_am_opt="$git_am_opt --whitespace=${1#--whitespace=}"
-		case "${1#--whitespace=}" in
-		fix|strip)
-			force_rebase=t
-			;;
-		esac
-		;;
-	--ignore-whitespace)
-		git_am_opt="$git_am_opt $1"
-		;;
-	--signoff)
-		signoff=--signoff
-		;;
-	--no-signoff)
-		signoff=
-		;;
-	--committer-date-is-author-date|--ignore-date)
-		git_am_opt="$git_am_opt $1"
-		force_rebase=t
-		;;
-	-C*)
-		git_am_opt="$git_am_opt $1"
-		;;
-	--root)
-		rebase_root=t
-		;;
-	--force-rebase|--no-ff)
-		force_rebase=t
-		;;
-	--rerere-autoupdate|--no-rerere-autoupdate)
-		allow_rerere_autoupdate="$1"
-		;;
-	--gpg-sign)
-		gpg_sign_opt=-S
-		;;
-	--gpg-sign=*)
-		gpg_sign_opt="-S${1#--gpg-sign=}"
-		;;
-	--)
-		shift
-		break
-		;;
-	*)
-		usage
-		;;
-	esac
-	shift
-done
-test $# -gt 2 && usage
-
-if test -n "$action"
-then
-	test -z "$in_progress" && die "$(gettext "No rebase in progress?")"
-	# Only interactive rebase uses detailed reflog messages
-	if test "$type" = interactive && test "$GIT_REFLOG_ACTION" = rebase
-	then
-		GIT_REFLOG_ACTION="rebase -i ($action)"
-		export GIT_REFLOG_ACTION
-	fi
-fi
-
-if test "$action" = "edit-todo" && test "$type" != "interactive"
-then
-	die "$(gettext "The --edit-todo action can only be used during interactive rebase.")"
-fi
-
-case "$action" in
-continue)
-	# Sanity check
-	git rev-parse --verify HEAD >/dev/null ||
-		die "$(gettext "Cannot read HEAD")"
-	git update-index --ignore-submodules --refresh &&
-	git diff-files --quiet --ignore-submodules || {
-		echo "$(gettext "You must edit all merge conflicts and then
-mark them as resolved using git add")"
-		exit 1
-	}
-	read_basic_state
-	run_specific_rebase
-	;;
-skip)
-	output git reset --hard HEAD || exit $?
-	read_basic_state
-	run_specific_rebase
-	;;
-abort)
-	git rerere clear
-	read_basic_state
-	case "$head_name" in
-	refs/*)
-		git symbolic-ref -m "rebase: aborting" HEAD $head_name ||
-		die "$(eval_gettext "Could not move back to \$head_name")"
-		;;
-	esac
-	output git reset --hard $orig_head
-	finish_rebase
-	exit
-	;;
-quit)
-	exec rm -rf "$state_dir"
-	;;
-edit-todo)
-	run_specific_rebase
-	;;
-show-current-patch)
-	run_specific_rebase
-	die "BUG: run_specific_rebase is not supposed to return here"
-	;;
-esac
-
-# Make sure no rebase is in progress
-if test -n "$in_progress"
-then
-	state_dir_base=${state_dir##*/}
-	cmd_live_rebase="git rebase (--continue | --abort | --skip)"
-	cmd_clear_stale_rebase="rm -fr \"$state_dir\""
-	die "
-$(eval_gettext 'It seems that there is already a $state_dir_base directory, and
-I wonder if you are in the middle of another rebase.  If that is the
-case, please try
-	$cmd_live_rebase
-If that is not the case, please
-	$cmd_clear_stale_rebase
-and run me again.  I am stopping in case you still have something
-valuable there.')"
-fi
-
-if test -n "$rebase_root" && test -z "$onto"
-then
-	test -z "$interactive_rebase" && interactive_rebase=implied
-fi
-
-if test -n "$keep_empty"
-then
-	test -z "$interactive_rebase" && interactive_rebase=implied
-fi
-
-if test -n "$interactive_rebase"
-then
-	type=interactive
-	state_dir="$merge_dir"
-elif test -n "$do_merge"
-then
-	type=merge
-	state_dir="$merge_dir"
-else
-	type=am
-	state_dir="$apply_dir"
-fi
-
-if test -t 2 && test -z "$GIT_QUIET"
-then
-	git_format_patch_opt="$git_format_patch_opt --progress"
-fi
-
-if test -n "$signoff"
-then
-	test -n "$preserve_merges" &&
-		die "$(gettext "error: cannot combine '--signoff' with '--preserve-merges'")"
-	git_am_opt="$git_am_opt $signoff"
-	force_rebase=t
-fi
-
-if test -z "$rebase_root"
-then
-	case "$#" in
-	0)
-		if ! upstream_name=$(git rev-parse --symbolic-full-name \
-			--verify -q @{upstream} 2>/dev/null)
-		then
-			. git-parse-remote
-			error_on_missing_default_upstream "rebase" "rebase" \
-				"against" "git rebase $(gettext '<branch>')"
-		fi
-
-		test "$fork_point" = auto && fork_point=t
-		;;
-	*)	upstream_name="$1"
-		if test "$upstream_name" = "-"
-		then
-			upstream_name="@{-1}"
-		fi
-		shift
-		;;
-	esac
-	upstream=$(peel_committish "${upstream_name}") ||
-	die "$(eval_gettext "invalid upstream '\$upstream_name'")"
-	upstream_arg="$upstream_name"
-else
-	if test -z "$onto"
-	then
-		empty_tree=$(git hash-object -t tree /dev/null)
-		onto=$(git commit-tree $empty_tree </dev/null)
-		squash_onto="$onto"
-	fi
-	unset upstream_name
-	unset upstream
-	test $# -gt 1 && usage
-	upstream_arg=--root
-fi
-
-# Make sure the branch to rebase onto is valid.
-onto_name=${onto-"$upstream_name"}
-case "$onto_name" in
-*...*)
-	if	left=${onto_name%...*} right=${onto_name#*...} &&
-		onto=$(git merge-base --all ${left:-HEAD} ${right:-HEAD})
-	then
-		case "$onto" in
-		?*"$LF"?*)
-			die "$(eval_gettext "\$onto_name: there are more than one merge bases")"
-			;;
-		'')
-			die "$(eval_gettext "\$onto_name: there is no merge base")"
-			;;
-		esac
-	else
-		die "$(eval_gettext "\$onto_name: there is no merge base")"
-	fi
-	;;
-*)
-	onto=$(peel_committish "$onto_name") ||
-	die "$(eval_gettext "Does not point to a valid commit: \$onto_name")"
-	;;
-esac
-
-# If the branch to rebase is given, that is the branch we will rebase
-# $branch_name -- branch/commit being rebased, or HEAD (already detached)
-# $orig_head -- commit object name of tip of the branch before rebasing
-# $head_name -- refs/heads/<that-branch> or "detached HEAD"
-switch_to=
-case "$#" in
-1)
-	# Is it "rebase other $branchname" or "rebase other $commit"?
-	branch_name="$1"
-	switch_to="$1"
-
-	# Is it a local branch?
-	if git show-ref --verify --quiet -- "refs/heads/$branch_name" &&
-	   orig_head=$(git rev-parse -q --verify "refs/heads/$branch_name")
-	then
-		head_name="refs/heads/$branch_name"
-	# If not is it a valid ref (branch or commit)?
-	elif orig_head=$(git rev-parse -q --verify "$branch_name")
-	then
-		head_name="detached HEAD"
-
-	else
-		die "$(eval_gettext "fatal: no such branch/commit '\$branch_name'")"
-	fi
-	;;
-0)
-	# Do not need to switch branches, we are already on it.
-	if branch_name=$(git symbolic-ref -q HEAD)
-	then
-		head_name=$branch_name
-		branch_name=$(expr "z$branch_name" : 'zrefs/heads/\(.*\)')
-	else
-		head_name="detached HEAD"
-		branch_name=HEAD
-	fi
-	orig_head=$(git rev-parse --verify HEAD) || exit
-	;;
-*)
-	die "BUG: unexpected number of arguments left to parse"
-	;;
-esac
-
-if test "$fork_point" = t
-then
-	new_upstream=$(git merge-base --fork-point "$upstream_name" \
-			"${switch_to:-HEAD}")
-	if test -n "$new_upstream"
-	then
-		restrict_revision=$new_upstream
-	fi
-fi
-
-if test "$autostash" = true && ! (require_clean_work_tree) 2>/dev/null
-then
-	stash_sha1=$(git stash create "autostash") ||
-	die "$(gettext 'Cannot autostash')"
-
-	mkdir -p "$state_dir" &&
-	echo $stash_sha1 >"$state_dir/autostash" &&
-	stash_abbrev=$(git rev-parse --short $stash_sha1) &&
-	echo "$(eval_gettext 'Created autostash: $stash_abbrev')" &&
-	git reset --hard
-fi
-
-require_clean_work_tree "rebase" "$(gettext "Please commit or stash them.")"
-
-# Now we are rebasing commits $upstream..$orig_head (or with --root,
-# everything leading up to $orig_head) on top of $onto
-
-# Check if we are already based on $onto with linear history,
-# but this should be done only when upstream and onto are the same
-# and if this is not an interactive rebase.
-mb=$(git merge-base "$onto" "$orig_head")
-if test "$type" != interactive && test "$upstream" = "$onto" &&
-	test "$mb" = "$onto" && test -z "$restrict_revision" &&
-	# linear history?
-	! (git rev-list --parents "$onto".."$orig_head" | sane_grep " .* ") > /dev/null
-then
-	if test -z "$force_rebase"
-	then
-		# Lazily switch to the target branch if needed...
-		test -z "$switch_to" ||
-		GIT_REFLOG_ACTION="$GIT_REFLOG_ACTION: checkout $switch_to" \
-			git checkout -q "$switch_to" --
-		if test "$branch_name" = "HEAD" &&
-			 ! git symbolic-ref -q HEAD
-		then
-			say "$(eval_gettext "HEAD is up to date.")"
-		else
-			say "$(eval_gettext "Current branch \$branch_name is up to date.")"
-		fi
-		finish_rebase
-		exit 0
-	else
-		if test "$branch_name" = "HEAD" &&
-			 ! git symbolic-ref -q HEAD
-		then
-			say "$(eval_gettext "HEAD is up to date, rebase forced.")"
-		else
-			say "$(eval_gettext "Current branch \$branch_name is up to date, rebase forced.")"
-		fi
-	fi
-fi
-
-# If a hook exists, give it a chance to interrupt
-run_pre_rebase_hook "$upstream_arg" "$@"
-
-if test -n "$diffstat"
-then
-	if test -n "$verbose"
-	then
-		echo "$(eval_gettext "Changes from \$mb to \$onto:")"
-	fi
-	# We want color (if set), but no pager
-	GIT_PAGER='' git diff --stat --summary "$mb" "$onto"
-fi
-
-test "$type" = interactive && run_specific_rebase
-
-# Detach HEAD and reset the tree
-say "$(gettext "First, rewinding head to replay your work on top of it...")"
-
-GIT_REFLOG_ACTION="$GIT_REFLOG_ACTION: checkout $onto_name" \
-	git checkout -q "$onto^0" || die "could not detach HEAD"
-git update-ref ORIG_HEAD $orig_head
-
-# If the $onto is a proper descendant of the tip of the branch, then
-# we just fast-forwarded.
-if test "$mb" = "$orig_head"
-then
-	say "$(eval_gettext "Fast-forwarded \$branch_name to \$onto_name.")"
-	move_to_original_branch
-	finish_rebase
-	exit 0
-fi
-
-if test -n "$rebase_root"
-then
-	revisions="$onto..$orig_head"
-else
-	revisions="${restrict_revision-$upstream}..$orig_head"
-fi
-
-run_specific_rebase
diff -pruN 1.2.1+git2.18.0-1/git/git-remote-testgit.sh 1.2.3+git2.25.1-1/git/git-remote-testgit.sh
--- 1.2.1+git2.18.0-1/git/git-remote-testgit.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/git-remote-testgit.sh	1970-01-01 00:00:00.000000000 +0000
@@ -1,147 +0,0 @@
-#!/bin/sh
-# Copyright (c) 2012 Felipe Contreras
-
-# The first argument can be a url when the fetch/push command was a url
-# instead of a configured remote. In this case, use a generic alias.
-if test "$1" = "testgit::$2"; then
-	alias=_
-else
-	alias=$1
-fi
-url=$2
-
-dir="$GIT_DIR/testgit/$alias"
-prefix="refs/testgit/$alias"
-
-default_refspec="refs/heads/*:${prefix}/heads/*"
-
-refspec="${GIT_REMOTE_TESTGIT_REFSPEC-$default_refspec}"
-
-test -z "$refspec" && prefix="refs"
-
-GIT_DIR="$url/.git"
-export GIT_DIR
-
-force=
-
-mkdir -p "$dir"
-
-if test -z "$GIT_REMOTE_TESTGIT_NO_MARKS"
-then
-	gitmarks="$dir/git.marks"
-	testgitmarks="$dir/testgit.marks"
-	test -e "$gitmarks" || >"$gitmarks"
-	test -e "$testgitmarks" || >"$testgitmarks"
-fi
-
-while read line
-do
-	case $line in
-	capabilities)
-		echo 'import'
-		echo 'export'
-		test -n "$refspec" && echo "refspec $refspec"
-		if test -n "$gitmarks"
-		then
-			echo "*import-marks $gitmarks"
-			echo "*export-marks $gitmarks"
-		fi
-		test -n "$GIT_REMOTE_TESTGIT_SIGNED_TAGS" && echo "signed-tags"
-		test -n "$GIT_REMOTE_TESTGIT_NO_PRIVATE_UPDATE" && echo "no-private-update"
-		echo 'option'
-		echo
-		;;
-	list)
-		git for-each-ref --format='? %(refname)' 'refs/heads/'
-		head=$(git symbolic-ref HEAD)
-		echo "@$head HEAD"
-		echo
-		;;
-	import*)
-		# read all import lines
-		while true
-		do
-			ref="${line#* }"
-			refs="$refs $ref"
-			read line
-			test "${line%% *}" != "import" && break
-		done
-
-		if test -n "$gitmarks"
-		then
-			echo "feature import-marks=$gitmarks"
-			echo "feature export-marks=$gitmarks"
-		fi
-
-		if test -n "$GIT_REMOTE_TESTGIT_FAILURE"
-		then
-			echo "feature done"
-			exit 1
-		fi
-
-		echo "feature done"
-		git fast-export \
-			${testgitmarks:+"--import-marks=$testgitmarks"} \
-			${testgitmarks:+"--export-marks=$testgitmarks"} \
-			$refs |
-		sed -e "s#refs/heads/#${prefix}/heads/#g"
-		echo "done"
-		;;
-	export)
-		if test -n "$GIT_REMOTE_TESTGIT_FAILURE"
-		then
-			# consume input so fast-export doesn't get SIGPIPE;
-			# git would also notice that case, but we want
-			# to make sure we are exercising the later
-			# error checks
-			while read line; do
-				test "done" = "$line" && break
-			done
-			exit 1
-		fi
-
-		before=$(git for-each-ref --format=' %(refname) %(objectname) ')
-
-		git fast-import \
-			${force:+--force} \
-			${testgitmarks:+"--import-marks=$testgitmarks"} \
-			${testgitmarks:+"--export-marks=$testgitmarks"} \
-			--quiet
-
-		# figure out which refs were updated
-		git for-each-ref --format='%(refname) %(objectname)' |
-		while read ref a
-		do
-			case "$before" in
-			*" $ref $a "*)
-				continue ;;	# unchanged
-			esac
-			if test -z "$GIT_REMOTE_TESTGIT_PUSH_ERROR"
-			then
-				echo "ok $ref"
-			else
-				echo "error $ref $GIT_REMOTE_TESTGIT_PUSH_ERROR"
-			fi
-		done
-
-		echo
-		;;
-	option\ *)
-		read cmd opt val <<-EOF
-		$line
-		EOF
-		case $opt in
-		force)
-			test $val = "true" && force="true" || force=
-			echo "ok"
-			;;
-		*)
-			echo "unsupported"
-			;;
-		esac
-		;;
-	'')
-		exit
-		;;
-	esac
-done
diff -pruN 1.2.1+git2.18.0-1/git/git-request-pull.sh 1.2.3+git2.25.1-1/git/git-request-pull.sh
--- 1.2.1+git2.18.0-1/git/git-request-pull.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/git-request-pull.sh	2020-02-17 04:47:35.000000000 +0000
@@ -65,6 +65,8 @@ test -z "$head" && die "fatal: Not a val
 headrev=$(git rev-parse --verify --quiet "$head"^0)
 test -z "$headrev" && die "fatal: Ambiguous revision: $local"
 
+local_sha1=$(git rev-parse --verify --quiet "$head")
+
 # Was it a branch with a description?
 branch_name=${head#refs/heads/}
 if test "z$branch_name" = "z$headref" ||
@@ -77,43 +79,53 @@ merge_base=$(git merge-base $baserev $he
 die "fatal: No commits in common between $base and $head"
 
 # $head is the refname from the command line.
-# If a ref with the same name as $head exists at the remote
-# and their values match, use that.
-#
-# Otherwise find a random ref that matches $headrev.
+# Find a ref with the same name as $head that exists at the remote
+# and points to the same commit as the local object.
 find_matching_ref='
 	my ($head,$headrev) = (@ARGV);
-	my ($found);
+	my $pattern = qr{/\Q$head\E$};
+	my ($remote_sha1, $found);
 
 	while (<STDIN>) {
 		chomp;
 		my ($sha1, $ref, $deref) = /^(\S+)\s+([^^]+)(\S*)$/;
-		my ($pattern);
-		next unless ($sha1 eq $headrev);
 
-		$pattern="/$head\$";
-		if ($ref eq $head) {
-			$found = $ref;
-		}
-		if ($ref =~ /$pattern/) {
-			$found = $ref;
-		}
 		if ($sha1 eq $head) {
-			$found = $sha1;
+			$found = $remote_sha1 = $sha1;
+			break;
+		}
+
+		if ($ref eq $head || $ref =~ $pattern) {
+			if ($deref eq "") {
+				# Remember the matching object on the remote side
+				$remote_sha1 = $sha1;
+			}
+			if ($sha1 eq $headrev) {
+				$found = $ref;
+				break;
+			}
 		}
 	}
 	if ($found) {
-		print "$found\n";
+		$remote_sha1 = $headrev if ! defined $remote_sha1;
+		print "$remote_sha1 $found\n";
 	}
 '
 
-ref=$(git ls-remote "$url" | @@PERL@@ -e "$find_matching_ref" "${remote:-HEAD}" "$headrev")
+set fnord $(git ls-remote "$url" | @@PERL@@ -e "$find_matching_ref" "${remote:-HEAD}" "$headrev")
+remote_sha1=$2
+ref=$3
 
 if test -z "$ref"
 then
 	echo "warn: No match for commit $headrev found at $url" >&2
 	echo "warn: Are you sure you pushed '${remote:-HEAD}' there?" >&2
 	status=1
+elif test "$local_sha1" != "$remote_sha1"
+then
+	echo "warn: $head found at $url but points to a different object" >&2
+	echo "warn: Are you sure you pushed '${remote:-HEAD}' there?" >&2
+	status=1
 fi
 
 # Special case: turn "for_linus" to "tags/for_linus" when it is correct
diff -pruN 1.2.1+git2.18.0-1/git/git-send-email.perl 1.2.3+git2.25.1-1/git/git-send-email.perl
--- 1.2.1+git2.18.0-1/git/git-send-email.perl	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/git-send-email.perl	2020-02-17 04:47:35.000000000 +0000
@@ -82,8 +82,11 @@ git send-email --dump-aliases
                                      Pass an empty string to disable certificate
                                      verification.
     --smtp-domain           <str>  * The domain name sent to HELO/EHLO handshake
-    --smtp-auth             <str>  * Space-separated list of allowed AUTH mechanisms.
+    --smtp-auth             <str>  * Space-separated list of allowed AUTH mechanisms, or
+                                     "none" to disable authentication.
                                      This setting forces to use one of the listed mechanisms.
+    --no-smtp-auth                   Disable SMTP authentication. Shorthand for
+                                     `--smtp-auth=none`
     --smtp-debug            <0|1>  * Disable, enable Net::SMTP debug.
 
     --batch-size            <int>  * send max <int> message per connection.
@@ -94,7 +97,7 @@ git send-email --dump-aliases
     --identity              <str>  * Use the sendemail.<id> options.
     --to-cmd                <str>  * Email To: via `<str> \$patch_path`
     --cc-cmd                <str>  * Email Cc: via `<str> \$patch_path`
-    --suppress-cc           <str>  * author, self, sob, cc, cccmd, body, bodycc, all.
+    --suppress-cc           <str>  * author, self, sob, cc, cccmd, body, bodycc, misc-by, all.
     --[no-]cc-cover                * Email Cc: addresses in the cover letter.
     --[no-]to-cover                * Email To: addresses in the cover letter.
     --[no-]signed-off-by-cc        * Send to Signed-off-by: addresses. Default on.
@@ -119,6 +122,11 @@ EOT
 	exit(1);
 }
 
+sub completion_helper {
+    print Git::command('format-patch', '--git-completion-helper');
+    exit(0);
+}
+
 # most mail servers generate the Date: header, but not all...
 sub format_2822_time {
 	my ($time) = @_;
@@ -169,11 +177,15 @@ my $re_encoded_text = qr/[^? \000-\037\1
 my $re_encoded_word = qr/=\?($re_token)\?($re_token)\?($re_encoded_text)\?=/;
 
 # Variables we fill in automatically, or via prompting:
-my (@to,$no_to,@initial_to,@cc,$no_cc,@initial_cc,@bcclist,$no_bcc,@xh,
+my (@to,@cc,@xh,$envelope_sender,
 	$initial_in_reply_to,$reply_to,$initial_subject,@files,
-	$author,$sender,$smtp_authpass,$annotate,$use_xmailer,$compose,$time);
-
-my $envelope_sender;
+	$author,$sender,$smtp_authpass,$annotate,$compose,$time);
+# Things we either get from config, *or* are overridden on the
+# command-line.
+my ($no_cc, $no_to, $no_bcc, $no_identity);
+my (@config_to, @getopt_to);
+my (@config_cc, @getopt_cc);
+my (@config_bcc, @getopt_bcc);
 
 # Example reply to:
 #$initial_in_reply_to = ''; #<20050203173208.GA23964@foobar.com>';
@@ -220,33 +232,37 @@ sub do_edit {
 }
 
 # Variables with corresponding config settings
-my ($thread, $chain_reply_to, $suppress_from, $signed_off_by_cc);
+my ($suppress_from, $signed_off_by_cc);
 my ($cover_cc, $cover_to);
 my ($to_cmd, $cc_cmd);
 my ($smtp_server, $smtp_server_port, @smtp_server_options);
 my ($smtp_authuser, $smtp_encryption, $smtp_ssl_cert_path);
 my ($batch_size, $relogin_delay);
 my ($identity, $aliasfiletype, @alias_files, $smtp_domain, $smtp_auth);
-my ($validate, $confirm);
+my ($confirm);
 my (@suppress_cc);
 my ($auto_8bit_encoding);
 my ($compose_encoding);
-my ($target_xfer_encoding);
-
+# Variables with corresponding config settings & hardcoded defaults
 my ($debug_net_smtp) = 0;		# Net::SMTP, see send_message()
+my $thread = 1;
+my $chain_reply_to = 0;
+my $use_xmailer = 1;
+my $validate = 1;
+my $target_xfer_encoding = 'auto';
 
 my %config_bool_settings = (
-    "thread" => [\$thread, 1],
-    "chainreplyto" => [\$chain_reply_to, 0],
-    "suppressfrom" => [\$suppress_from, undef],
-    "signedoffbycc" => [\$signed_off_by_cc, undef],
-    "cccover" => [\$cover_cc, undef],
-    "tocover" => [\$cover_to, undef],
-    "signedoffcc" => [\$signed_off_by_cc, undef],      # Deprecated
-    "validate" => [\$validate, 1],
-    "multiedit" => [\$multiedit, undef],
-    "annotate" => [\$annotate, undef],
-    "xmailer" => [\$use_xmailer, 1]
+    "thread" => \$thread,
+    "chainreplyto" => \$chain_reply_to,
+    "suppressfrom" => \$suppress_from,
+    "signedoffbycc" => \$signed_off_by_cc,
+    "cccover" => \$cover_cc,
+    "tocover" => \$cover_to,
+    "signedoffcc" => \$signed_off_by_cc,
+    "validate" => \$validate,
+    "multiedit" => \$multiedit,
+    "annotate" => \$annotate,
+    "xmailer" => \$use_xmailer,
 );
 
 my %config_settings = (
@@ -259,12 +275,12 @@ my %config_settings = (
     "smtpauth" => \$smtp_auth,
     "smtpbatchsize" => \$batch_size,
     "smtprelogindelay" => \$relogin_delay,
-    "to" => \@initial_to,
+    "to" => \@config_to,
     "tocmd" => \$to_cmd,
-    "cc" => \@initial_cc,
+    "cc" => \@config_cc,
     "cccmd" => \$cc_cmd,
     "aliasfiletype" => \$aliasfiletype,
-    "bcc" => \@bcclist,
+    "bcc" => \@config_bcc,
     "suppresscc" => \@suppress_cc,
     "envelopesender" => \$envelope_sender,
     "confirm"   => \$confirm,
@@ -307,12 +323,87 @@ sub signal_handler {
 $SIG{TERM} = \&signal_handler;
 $SIG{INT}  = \&signal_handler;
 
+# Read our sendemail.* config
+sub read_config {
+	my ($configured, $prefix) = @_;
+
+	foreach my $setting (keys %config_bool_settings) {
+		my $target = $config_bool_settings{$setting};
+		my $v = Git::config_bool(@repo, "$prefix.$setting");
+		next unless defined $v;
+		next if $configured->{$setting}++;
+		$$target = $v;
+	}
+
+	foreach my $setting (keys %config_path_settings) {
+		my $target = $config_path_settings{$setting};
+		if (ref($target) eq "ARRAY") {
+			my @values = Git::config_path(@repo, "$prefix.$setting");
+			next unless @values;
+			next if $configured->{$setting}++;
+			@$target = @values;
+		}
+		else {
+			my $v = Git::config_path(@repo, "$prefix.$setting");
+			next unless defined $v;
+			next if $configured->{$setting}++;
+			$$target = $v;
+		}
+	}
+
+	foreach my $setting (keys %config_settings) {
+		my $target = $config_settings{$setting};
+		if (ref($target) eq "ARRAY") {
+			my @values = Git::config(@repo, "$prefix.$setting");
+			next unless @values;
+			next if $configured->{$setting}++;
+			@$target = @values;
+		}
+		else {
+			my $v = Git::config(@repo, "$prefix.$setting");
+			next unless defined $v;
+			next if $configured->{$setting}++;
+			$$target = $v;
+		}
+	}
+
+	if (!defined $smtp_encryption) {
+		my $setting = "$prefix.smtpencryption";
+		my $enc = Git::config(@repo, $setting);
+		return unless defined $enc;
+		return if $configured->{$setting}++;
+		if (defined $enc) {
+			$smtp_encryption = $enc;
+		} elsif (Git::config_bool(@repo, "$prefix.smtpssl")) {
+			$smtp_encryption = 'ssl';
+		}
+	}
+}
+
+# sendemail.identity yields to --identity. We must parse this
+# special-case first before the rest of the config is read.
+$identity = Git::config(@repo, "sendemail.identity");
+my $rc = GetOptions(
+	"identity=s" => \$identity,
+	"no-identity" => \$no_identity,
+);
+usage() unless $rc;
+undef $identity if $no_identity;
+
+# Now we know enough to read the config
+{
+    my %configured;
+    read_config(\%configured, "sendemail.$identity") if defined $identity;
+    read_config(\%configured, "sendemail");
+}
+
 # Begin by accumulating all the variables (defined above), that we will end up
 # needing, first, from the command line:
 
 my $help;
-my $rc = GetOptions("h" => \$help,
-                    "dump-aliases" => \$dump_aliases);
+my $git_completion_helper;
+$rc = GetOptions("h" => \$help,
+                 "dump-aliases" => \$dump_aliases);
 usage() unless $rc;
 die __("--dump-aliases incompatible with other options\n")
     if !$help and $dump_aliases and @ARGV;
@@ -321,12 +412,12 @@ $rc = GetOptions(
                     "in-reply-to=s" => \$initial_in_reply_to,
 		    "reply-to=s" => \$reply_to,
 		    "subject=s" => \$initial_subject,
-		    "to=s" => \@initial_to,
+		    "to=s" => \@getopt_to,
 		    "to-cmd=s" => \$to_cmd,
 		    "no-to" => \$no_to,
-		    "cc=s" => \@initial_cc,
+		    "cc=s" => \@getopt_cc,
 		    "no-cc" => \$no_cc,
-		    "bcc=s" => \@bcclist,
+		    "bcc=s" => \@getopt_bcc,
 		    "no-bcc" => \$no_bcc,
 		    "chain-reply-to!" => \$chain_reply_to,
 		    "no-chain-reply-to" => sub {$chain_reply_to = 0},
@@ -341,7 +432,7 @@ $rc = GetOptions(
 		    "smtp-debug:i" => \$debug_net_smtp,
 		    "smtp-domain:s" => \$smtp_domain,
 		    "smtp-auth=s" => \$smtp_auth,
-		    "identity=s" => \$identity,
+		    "no-smtp-auth" => sub {$smtp_auth = 'none'},
 		    "annotate!" => \$annotate,
 		    "no-annotate" => sub {$annotate = 0},
 		    "compose" => \$compose,
@@ -373,9 +464,16 @@ $rc = GetOptions(
 		    "no-xmailer" => sub {$use_xmailer = 0},
 		    "batch-size=i" => \$batch_size,
 		    "relogin-delay=i" => \$relogin_delay,
+		    "git-completion-helper" => \$git_completion_helper,
 	 );
 
+# Munge any "either config or getopt, not both" variables
+my @initial_to = @getopt_to ? @getopt_to : ($no_to ? () : @config_to);
+my @initial_cc = @getopt_cc ? @getopt_cc : ($no_cc ? () : @config_cc);
+my @initial_bcc = @getopt_bcc ? @getopt_bcc : ($no_bcc ? () : @config_bcc);
+
 usage() if $help;
+completion_helper() if $git_completion_helper;
 unless ($rc) {
     usage();
 }
@@ -387,65 +485,6 @@ die __("`batch-size` and `relogin` must
 	"(via command-line or configuration option)\n")
 	if defined $relogin_delay and not defined $batch_size;
 
-# Now, let's fill any that aren't set in with defaults:
-
-sub read_config {
-	my ($prefix) = @_;
-
-	foreach my $setting (keys %config_bool_settings) {
-		my $target = $config_bool_settings{$setting}->[0];
-		$$target = Git::config_bool(@repo, "$prefix.$setting") unless (defined $$target);
-	}
-
-	foreach my $setting (keys %config_path_settings) {
-		my $target = $config_path_settings{$setting};
-		if (ref($target) eq "ARRAY") {
-			unless (@$target) {
-				my @values = Git::config_path(@repo, "$prefix.$setting");
-				@$target = @values if (@values && defined $values[0]);
-			}
-		}
-		else {
-			$$target = Git::config_path(@repo, "$prefix.$setting") unless (defined $$target);
-		}
-	}
-
-	foreach my $setting (keys %config_settings) {
-		my $target = $config_settings{$setting};
-		next if $setting eq "to" and defined $no_to;
-		next if $setting eq "cc" and defined $no_cc;
-		next if $setting eq "bcc" and defined $no_bcc;
-		if (ref($target) eq "ARRAY") {
-			unless (@$target) {
-				my @values = Git::config(@repo, "$prefix.$setting");
-				@$target = @values if (@values && defined $values[0]);
-			}
-		}
-		else {
-			$$target = Git::config(@repo, "$prefix.$setting") unless (defined $$target);
-		}
-	}
-
-	if (!defined $smtp_encryption) {
-		my $enc = Git::config(@repo, "$prefix.smtpencryption");
-		if (defined $enc) {
-			$smtp_encryption = $enc;
-		} elsif (Git::config_bool(@repo, "$prefix.smtpssl")) {
-			$smtp_encryption = 'ssl';
-		}
-	}
-}
-
-# read configuration from [sendemail "$identity"], fall back on [sendemail]
-$identity = Git::config(@repo, "sendemail.identity") unless (defined $identity);
-read_config("sendemail.$identity") if (defined $identity);
-read_config("sendemail");
-
-# fall back on builtin bool defaults
-foreach my $setting (values %config_bool_settings) {
-	${$setting->[0]} = $setting->[1] unless (defined (${$setting->[0]}));
-}
-
 # 'default' encryption is none -- this only prevents a warning
 $smtp_encryption = '' unless (defined $smtp_encryption);
 
@@ -453,14 +492,16 @@ $smtp_encryption = '' unless (defined $s
 my(%suppress_cc);
 if (@suppress_cc) {
 	foreach my $entry (@suppress_cc) {
+		# Please update $__git_send_email_suppresscc_options
+		# in git-completion.bash when you add new options.
 		die sprintf(__("Unknown --suppress-cc field: '%s'\n"), $entry)
-			unless $entry =~ /^(?:all|cccmd|cc|author|self|sob|body|bodycc)$/;
+			unless $entry =~ /^(?:all|cccmd|cc|author|self|sob|body|bodycc|misc-by)$/;
 		$suppress_cc{$entry} = 1;
 	}
 }
 
 if ($suppress_cc{'all'}) {
-	foreach my $entry (qw (cccmd cc author self sob body bodycc)) {
+	foreach my $entry (qw (cccmd cc author self sob body bodycc misc-by)) {
 		$suppress_cc{$entry} = 1;
 	}
 	delete $suppress_cc{'all'};
@@ -471,7 +512,7 @@ $suppress_cc{'self'} = $suppress_from if
 $suppress_cc{'sob'} = !$signed_off_by_cc if defined $signed_off_by_cc;
 
 if ($suppress_cc{'body'}) {
-	foreach my $entry (qw (sob bodycc)) {
+	foreach my $entry (qw (sob bodycc misc-by)) {
 		$suppress_cc{$entry} = 1;
 	}
 	delete $suppress_cc{'body'};
@@ -482,6 +523,8 @@ my $confirm_unconfigured = !defined $con
 if ($confirm_unconfigured) {
 	$confirm = scalar %suppress_cc ? 'compose' : 'auto';
 };
+# Please update $__git_send_email_confirm_options in
+# git-completion.bash when you add new options.
 die sprintf(__("Unknown --confirm setting: '%s'\n"), $confirm)
 	unless $confirm =~ /^(?:auto|cc|compose|always|never)/;
 
@@ -575,6 +618,8 @@ my %parse_alias = (
 		if (/\(define-mail-alias\s+"(\S+?)"\s+"(\S+?)"\)/) {
 			$aliases{$1} = [ $2 ];
 		}}}
+	# Please update _git_config() in git-completion.bash when you
+	# add new MUAs.
 );
 
 if (@alias_files and $aliasfiletype and defined $parse_alias{$aliasfiletype}) {
@@ -645,7 +690,7 @@ if (@rev_list_opts) {
 if ($validate) {
 	foreach my $f (@files) {
 		unless (-p $f) {
-			my $error = validate_patch($f);
+			my $error = validate_patch($f, $target_xfer_encoding);
 			$error and die sprintf(__("fatal: %s: %s\nwarning: no patches were sent\n"),
 						  $f, $error);
 		}
@@ -923,7 +968,7 @@ sub expand_one_alias {
 
 @initial_to = process_address_list(@initial_to);
 @initial_cc = process_address_list(@initial_cc);
-@bcclist = process_address_list(@bcclist);
+@initial_bcc = process_address_list(@initial_bcc);
 
 if ($thread && !defined $initial_in_reply_to && $prompting) {
 	$initial_in_reply_to = ask(
@@ -1183,7 +1228,7 @@ sub process_address_list {
 # domain name that corresponds the IP address in the HELO/EHLO
 # handshake. This is used to verify the connection and prevent
 # spammers from trying to hide their identity. If the DNS and IP don't
-# match, the receiveing MTA may deny the connection.
+# match, the receiving MTA may deny the connection.
 #
 # Here is a deny example of Net::SMTP with the default "localhost.localdomain"
 #
@@ -1241,7 +1286,7 @@ sub smtp_host_string {
 # (smtp_user was not specified), and 0 otherwise.
 
 sub smtp_auth_maybe {
-	if (!defined $smtp_authuser || $auth) {
+	if (!defined $smtp_authuser || $auth || (defined $smtp_auth && $smtp_auth eq "none")) {
 		return 1;
 	}
 
@@ -1346,7 +1391,7 @@ sub send_message {
 		    }
 	       @cc);
 	my $to = join (",\n\t", @recipients);
-	@recipients = unique_email_list(@recipients,@cc,@bcclist);
+	@recipients = unique_email_list(@recipients,@cc,@initial_bcc);
 	@recipients = (map { extract_valid_address_or_die($_) } @recipients);
 	my $date = format_2822_time($time++);
 	my $gitversion = '@@GIT_VERSION@@';
@@ -1479,7 +1524,7 @@ EOF
 							 SSL => 1);
 			}
 		}
-		else {
+		elsif (!$smtp) {
 			$smtp_server_port ||= 25;
 			$smtp ||= Net::SMTP->new($smtp_server,
 						 Hello => $smtp_domain,
@@ -1501,7 +1546,6 @@ EOF
 					$smtp->starttls(ssl_verify_params())
 						or die sprintf(__("STARTTLS failed! %s"), IO::Socket::SSL::errstr());
 				}
-				$smtp_encryption = '';
 				# Send EHLO again to receive fresh
 				# supported commands
 				$smtp->hello($smtp_domain);
@@ -1682,7 +1726,7 @@ sub process_file {
 	# Now parse the message body
 	while(<$fh>) {
 		$message .=  $_;
-		if (/^(Signed-off-by|Cc): (.*)/i) {
+		if (/^([a-z][a-z-]*-by|Cc): (.*)/i) {
 			chomp;
 			my ($what, $c) = ($1, $2);
 			# strip garbage for the address we'll use:
@@ -1692,8 +1736,18 @@ sub process_file {
 			if ($sc eq $sender) {
 				next if ($suppress_cc{'self'});
 			} else {
-				next if $suppress_cc{'sob'} and $what =~ /Signed-off-by/i;
-				next if $suppress_cc{'bodycc'} and $what =~ /Cc/i;
+				if ($what =~ /^Signed-off-by$/i) {
+					next if $suppress_cc{'sob'};
+				} elsif ($what =~ /-by$/i) {
+					next if $suppress_cc{'misc-by'};
+				} elsif ($what =~ /Cc/i) {
+					next if $suppress_cc{'bodycc'};
+				}
+			}
+			if ($c !~ /.+@.+|<.+>/) {
+				printf("(body) Ignoring %s from line '%s'\n",
+					$what, $_) unless $quiet;
+				next;
 			}
 			push @cc, $c;
 			printf(__("(body) Adding cc: %s from line '%s'\n"),
@@ -1737,18 +1791,11 @@ sub process_file {
 			}
 		}
 	}
-	if (defined $target_xfer_encoding) {
-		$xfer_encoding = '8bit' if not defined $xfer_encoding;
-		$message = apply_transfer_encoding(
-			$message, $xfer_encoding, $target_xfer_encoding);
-		$xfer_encoding = $target_xfer_encoding;
-	}
-	if (defined $xfer_encoding) {
-		push @xh, "Content-Transfer-Encoding: $xfer_encoding";
-	}
-	if (defined $xfer_encoding or $has_content_type) {
-		unshift @xh, 'MIME-Version: 1.0' unless $has_mime_version;
-	}
+	$xfer_encoding = '8bit' if not defined $xfer_encoding;
+	($message, $xfer_encoding) = apply_transfer_encoding(
+		$message, $xfer_encoding, $target_xfer_encoding);
+	push @xh, "Content-Transfer-Encoding: $xfer_encoding";
+	unshift @xh, 'MIME-Version: 1.0' unless $has_mime_version;
 
 	$needs_confirm = (
 		$confirm eq "always" or
@@ -1842,7 +1889,7 @@ sub apply_transfer_encoding {
 	my $from = shift;
 	my $to = shift;
 
-	return $message if ($from eq $to and $from ne '7bit');
+	return ($message, $to) if ($from eq $to and $from ne '7bit');
 
 	require MIME::QuotedPrint;
 	require MIME::Base64;
@@ -1852,13 +1899,16 @@ sub apply_transfer_encoding {
 	$message = MIME::Base64::decode($message)
 		if ($from eq 'base64');
 
+	$to = ($message =~ /(?:.{999,}|\r)/) ? 'quoted-printable' : '8bit'
+		if $to eq 'auto';
+
 	die __("cannot send message as 7bit")
 		if ($to eq '7bit' and $message =~ /[^[:ascii:]]/);
-	return $message
+	return ($message, $to)
 		if ($to eq '7bit' or $to eq '8bit');
-	return MIME::QuotedPrint::encode($message, "\n", 0)
+	return (MIME::QuotedPrint::encode($message, "\n", 0), $to)
 		if ($to eq 'quoted-printable');
-	return MIME::Base64::encode($message, "\n")
+	return (MIME::Base64::encode($message, "\n"), $to)
 		if ($to eq 'base64');
 	die __("invalid transfer encoding");
 }
@@ -1877,7 +1927,7 @@ sub unique_email_list {
 }
 
 sub validate_patch {
-	my $fn = shift;
+	my ($fn, $xfer_encoding) = @_;
 
 	if ($repo) {
 		my $validate_hook = catfile(catdir($repo->repo_path(), 'hooks'),
@@ -1897,11 +1947,15 @@ sub validate_patch {
 		return $hook_error if $hook_error;
 	}
 
-	open(my $fh, '<', $fn)
-		or die sprintf(__("unable to open %s: %s\n"), $fn, $!);
-	while (my $line = <$fh>) {
-		if (length($line) > 998) {
-			return sprintf(__("%s: patch contains a line longer than 998 characters"), $.);
+	# Any long lines will be automatically fixed if we use a suitable transfer
+	# encoding.
+	unless ($xfer_encoding =~ /^(?:auto|quoted-printable|base64)$/) {
+		open(my $fh, '<', $fn)
+			or die sprintf(__("unable to open %s: %s\n"), $fn, $!);
+		while (my $line = <$fh>) {
+			if (length($line) > 998) {
+				return sprintf(__("%s: patch contains a line longer than 998 characters"), $.);
+			}
 		}
 	}
 	return;
diff -pruN 1.2.1+git2.18.0-1/git/git-sh-i18n.sh 1.2.3+git2.25.1-1/git/git-sh-i18n.sh
--- 1.2.1+git2.18.0-1/git/git-sh-i18n.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/git-sh-i18n.sh	2020-02-17 04:47:35.000000000 +0000
@@ -17,7 +17,9 @@ export TEXTDOMAINDIR
 
 # First decide what scheme to use...
 GIT_INTERNAL_GETTEXT_SH_SCHEME=fallthrough
-if test -n "$GIT_GETTEXT_POISON"
+if test -n "$GIT_TEST_GETTEXT_POISON" &&
+	    git env--helper --type=bool --default=0 --exit-code \
+		GIT_TEST_GETTEXT_POISON
 then
 	GIT_INTERNAL_GETTEXT_SH_SCHEME=poison
 elif test -n "@@USE_GETTEXT_SCHEME@@"
diff -pruN 1.2.1+git2.18.0-1/git/git-sh-setup.sh 1.2.3+git2.25.1-1/git/git-sh-setup.sh
--- 1.2.1+git2.18.0-1/git/git-sh-setup.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/git-sh-setup.sh	2020-02-17 04:47:35.000000000 +0000
@@ -101,6 +101,7 @@ $LONG_USAGE")"
 	case "$1" in
 		-h)
 		echo "$LONG_USAGE"
+		case "$0" in *git-legacy-stash) exit 129;; esac
 		exit
 	esac
 fi
diff -pruN 1.2.1+git2.18.0-1/git/git-stash.sh 1.2.3+git2.25.1-1/git/git-stash.sh
--- 1.2.1+git2.18.0-1/git/git-stash.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/git-stash.sh	1970-01-01 00:00:00.000000000 +0000
@@ -1,752 +0,0 @@
-#!/bin/sh
-# Copyright (c) 2007, Nanako Shiraishi
-
-dashless=$(basename "$0" | sed -e 's/-/ /')
-USAGE="list [<options>]
-   or: $dashless show [<stash>]
-   or: $dashless drop [-q|--quiet] [<stash>]
-   or: $dashless ( pop | apply ) [--index] [-q|--quiet] [<stash>]
-   or: $dashless branch <branchname> [<stash>]
-   or: $dashless save [--patch] [-k|--[no-]keep-index] [-q|--quiet]
-		      [-u|--include-untracked] [-a|--all] [<message>]
-   or: $dashless [push [--patch] [-k|--[no-]keep-index] [-q|--quiet]
-		       [-u|--include-untracked] [-a|--all] [-m <message>]
-		       [-- <pathspec>...]]
-   or: $dashless clear"
-
-SUBDIRECTORY_OK=Yes
-OPTIONS_SPEC=
-START_DIR=$(pwd)
-. git-sh-setup
-require_work_tree
-prefix=$(git rev-parse --show-prefix) || exit 1
-cd_to_toplevel
-
-TMP="$GIT_DIR/.git-stash.$$"
-TMPindex=${GIT_INDEX_FILE-"$(git rev-parse --git-path index)"}.stash.$$
-trap 'rm -f "$TMP-"* "$TMPindex"' 0
-
-ref_stash=refs/stash
-
-if git config --get-colorbool color.interactive; then
-       help_color="$(git config --get-color color.interactive.help 'red bold')"
-       reset_color="$(git config --get-color '' reset)"
-else
-       help_color=
-       reset_color=
-fi
-
-no_changes () {
-	git diff-index --quiet --cached HEAD --ignore-submodules -- "$@" &&
-	git diff-files --quiet --ignore-submodules -- "$@" &&
-	(test -z "$untracked" || test -z "$(untracked_files "$@")")
-}
-
-untracked_files () {
-	if test "$1" = "-z"
-	then
-		shift
-		z=-z
-	else
-		z=
-	fi
-	excl_opt=--exclude-standard
-	test "$untracked" = "all" && excl_opt=
-	git ls-files -o $z $excl_opt -- "$@"
-}
-
-clear_stash () {
-	if test $# != 0
-	then
-		die "$(gettext "git stash clear with parameters is unimplemented")"
-	fi
-	if current=$(git rev-parse --verify --quiet $ref_stash)
-	then
-		git update-ref -d $ref_stash $current
-	fi
-}
-
-create_stash () {
-	stash_msg=
-	untracked=
-	while test $# != 0
-	do
-		case "$1" in
-		-m|--message)
-			shift
-			stash_msg=${1?"BUG: create_stash () -m requires an argument"}
-			;;
-		-m*)
-			stash_msg=${1#-m}
-			;;
-		--message=*)
-			stash_msg=${1#--message=}
-			;;
-		-u|--include-untracked)
-			shift
-			untracked=${1?"BUG: create_stash () -u requires an argument"}
-			;;
-		--)
-			shift
-			break
-			;;
-		esac
-		shift
-	done
-
-	git update-index -q --refresh
-	if no_changes "$@"
-	then
-		exit 0
-	fi
-
-	# state of the base commit
-	if b_commit=$(git rev-parse --verify HEAD)
-	then
-		head=$(git rev-list --oneline -n 1 HEAD --)
-	else
-		die "$(gettext "You do not have the initial commit yet")"
-	fi
-
-	if branch=$(git symbolic-ref -q HEAD)
-	then
-		branch=${branch#refs/heads/}
-	else
-		branch='(no branch)'
-	fi
-	msg=$(printf '%s: %s' "$branch" "$head")
-
-	# state of the index
-	i_tree=$(git write-tree) &&
-	i_commit=$(printf 'index on %s\n' "$msg" |
-		git commit-tree $i_tree -p $b_commit) ||
-		die "$(gettext "Cannot save the current index state")"
-
-	if test -n "$untracked"
-	then
-		# Untracked files are stored by themselves in a parentless commit, for
-		# ease of unpacking later.
-		u_commit=$(
-			untracked_files -z "$@" | (
-				GIT_INDEX_FILE="$TMPindex" &&
-				export GIT_INDEX_FILE &&
-				rm -f "$TMPindex" &&
-				git update-index -z --add --remove --stdin &&
-				u_tree=$(git write-tree) &&
-				printf 'untracked files on %s\n' "$msg" | git commit-tree $u_tree  &&
-				rm -f "$TMPindex"
-		) ) || die "$(gettext "Cannot save the untracked files")"
-
-		untracked_commit_option="-p $u_commit";
-	else
-		untracked_commit_option=
-	fi
-
-	if test -z "$patch_mode"
-	then
-
-		# state of the working tree
-		w_tree=$( (
-			git read-tree --index-output="$TMPindex" -m $i_tree &&
-			GIT_INDEX_FILE="$TMPindex" &&
-			export GIT_INDEX_FILE &&
-			git diff-index --name-only -z HEAD -- "$@" >"$TMP-stagenames" &&
-			git update-index -z --add --remove --stdin <"$TMP-stagenames" &&
-			git write-tree &&
-			rm -f "$TMPindex"
-		) ) ||
-			die "$(gettext "Cannot save the current worktree state")"
-
-	else
-
-		rm -f "$TMP-index" &&
-		GIT_INDEX_FILE="$TMP-index" git read-tree HEAD &&
-
-		# find out what the user wants
-		GIT_INDEX_FILE="$TMP-index" \
-			git add--interactive --patch=stash -- "$@" &&
-
-		# state of the working tree
-		w_tree=$(GIT_INDEX_FILE="$TMP-index" git write-tree) ||
-		die "$(gettext "Cannot save the current worktree state")"
-
-		git diff-tree -p HEAD $w_tree -- >"$TMP-patch" &&
-		test -s "$TMP-patch" ||
-		die "$(gettext "No changes selected")"
-
-		rm -f "$TMP-index" ||
-		die "$(gettext "Cannot remove temporary index (can't happen)")"
-
-	fi
-
-	# create the stash
-	if test -z "$stash_msg"
-	then
-		stash_msg=$(printf 'WIP on %s' "$msg")
-	else
-		stash_msg=$(printf 'On %s: %s' "$branch" "$stash_msg")
-	fi
-	w_commit=$(printf '%s\n' "$stash_msg" |
-	git commit-tree $w_tree -p $b_commit -p $i_commit $untracked_commit_option) ||
-	die "$(gettext "Cannot record working tree state")"
-}
-
-store_stash () {
-	while test $# != 0
-	do
-		case "$1" in
-		-m|--message)
-			shift
-			stash_msg="$1"
-			;;
-		-m*)
-			stash_msg=${1#-m}
-			;;
-		--message=*)
-			stash_msg=${1#--message=}
-			;;
-		-q|--quiet)
-			quiet=t
-			;;
-		*)
-			break
-			;;
-		esac
-		shift
-	done
-	test $# = 1 ||
-	die "$(eval_gettext "\"$dashless store\" requires one <commit> argument")"
-
-	w_commit="$1"
-	if test -z "$stash_msg"
-	then
-		stash_msg="Created via \"git stash store\"."
-	fi
-
-	git update-ref --create-reflog -m "$stash_msg" $ref_stash $w_commit
-	ret=$?
-	test $ret != 0 && test -z "$quiet" &&
-	die "$(eval_gettext "Cannot update \$ref_stash with \$w_commit")"
-	return $ret
-}
-
-push_stash () {
-	keep_index=
-	patch_mode=
-	untracked=
-	stash_msg=
-	while test $# != 0
-	do
-		case "$1" in
-		-k|--keep-index)
-			keep_index=t
-			;;
-		--no-keep-index)
-			keep_index=n
-			;;
-		-p|--patch)
-			patch_mode=t
-			# only default to keep if we don't already have an override
-			test -z "$keep_index" && keep_index=t
-			;;
-		-q|--quiet)
-			GIT_QUIET=t
-			;;
-		-u|--include-untracked)
-			untracked=untracked
-			;;
-		-a|--all)
-			untracked=all
-			;;
-		-m|--message)
-			shift
-			test -z ${1+x} && usage
-			stash_msg=$1
-			;;
-		-m*)
-			stash_msg=${1#-m}
-			;;
-		--message=*)
-			stash_msg=${1#--message=}
-			;;
-		--help)
-			show_help
-			;;
-		--)
-			shift
-			break
-			;;
-		-*)
-			option="$1"
-			eval_gettextln "error: unknown option for 'stash push': \$option"
-			usage
-			;;
-		*)
-			break
-			;;
-		esac
-		shift
-	done
-
-	eval "set $(git rev-parse --sq --prefix "$prefix" -- "$@")"
-
-	if test -n "$patch_mode" && test -n "$untracked"
-	then
-		die "$(gettext "Can't use --patch and --include-untracked or --all at the same time")"
-	fi
-
-	test -n "$untracked" || git ls-files --error-unmatch -- "$@" >/dev/null || exit 1
-
-	git update-index -q --refresh
-	if no_changes "$@"
-	then
-		say "$(gettext "No local changes to save")"
-		exit 0
-	fi
-
-	git reflog exists $ref_stash ||
-		clear_stash || die "$(gettext "Cannot initialize stash")"
-
-	create_stash -m "$stash_msg" -u "$untracked" -- "$@"
-	store_stash -m "$stash_msg" -q $w_commit ||
-	die "$(gettext "Cannot save the current status")"
-	say "$(eval_gettext "Saved working directory and index state \$stash_msg")"
-
-	if test -z "$patch_mode"
-	then
-		test "$untracked" = "all" && CLEAN_X_OPTION=-x || CLEAN_X_OPTION=
-		if test -n "$untracked" && test $# = 0
-		then
-			git clean --force --quiet -d $CLEAN_X_OPTION
-		fi
-
-		if test $# != 0
-		then
-			test -z "$untracked" && UPDATE_OPTION="-u" || UPDATE_OPTION=
-			test "$untracked" = "all" && FORCE_OPTION="--force" || FORCE_OPTION=
-			git add $UPDATE_OPTION $FORCE_OPTION -- "$@"
-			git diff-index -p --cached --binary HEAD -- "$@" |
-			git apply --index -R
-		else
-			git reset --hard -q
-		fi
-
-		if test "$keep_index" = "t" && test -n "$i_tree"
-		then
-			git read-tree --reset $i_tree
-			git ls-files -z --modified -- "$@" |
-			git checkout-index -z --force --stdin
-		fi
-	else
-		git apply -R < "$TMP-patch" ||
-		die "$(gettext "Cannot remove worktree changes")"
-
-		if test "$keep_index" != "t"
-		then
-			git reset -q -- "$@"
-		fi
-	fi
-}
-
-save_stash () {
-	push_options=
-	while test $# != 0
-	do
-		case "$1" in
-		--)
-			shift
-			break
-			;;
-		-*)
-			# pass all options through to push_stash
-			push_options="$push_options $1"
-			;;
-		*)
-			break
-			;;
-		esac
-		shift
-	done
-
-	stash_msg="$*"
-
-	if test -z "$stash_msg"
-	then
-		push_stash $push_options
-	else
-		push_stash $push_options -m "$stash_msg"
-	fi
-}
-
-have_stash () {
-	git rev-parse --verify --quiet $ref_stash >/dev/null
-}
-
-list_stash () {
-	have_stash || return 0
-	git log --format="%gd: %gs" -g --first-parent -m "$@" $ref_stash --
-}
-
-show_stash () {
-	ALLOW_UNKNOWN_FLAGS=t
-	assert_stash_like "$@"
-
-	if test -z "$FLAGS"
-	then
-		if test "$(git config --bool stash.showStat || echo true)" = "true"
-		then
-			FLAGS=--stat
-		fi
-
-		if test "$(git config --bool stash.showPatch || echo false)" = "true"
-		then
-			FLAGS=${FLAGS}${FLAGS:+ }-p
-		fi
-
-		if test -z "$FLAGS"
-		then
-			return 0
-		fi
-	fi
-
-	git diff ${FLAGS} $b_commit $w_commit
-}
-
-show_help () {
-	exec git help stash
-	exit 1
-}
-
-#
-# Parses the remaining options looking for flags and
-# at most one revision defaulting to ${ref_stash}@{0}
-# if none found.
-#
-# Derives related tree and commit objects from the
-# revision, if one is found.
-#
-# stash records the work tree, and is a merge between the
-# base commit (first parent) and the index tree (second parent).
-#
-#   REV is set to the symbolic version of the specified stash-like commit
-#   IS_STASH_LIKE is non-blank if ${REV} looks like a stash
-#   IS_STASH_REF is non-blank if the ${REV} looks like a stash ref
-#   s is set to the SHA1 of the stash commit
-#   w_commit is set to the commit containing the working tree
-#   b_commit is set to the base commit
-#   i_commit is set to the commit containing the index tree
-#   u_commit is set to the commit containing the untracked files tree
-#   w_tree is set to the working tree
-#   b_tree is set to the base tree
-#   i_tree is set to the index tree
-#   u_tree is set to the untracked files tree
-#
-#   GIT_QUIET is set to t if -q is specified
-#   INDEX_OPTION is set to --index if --index is specified.
-#   FLAGS is set to the remaining flags (if allowed)
-#
-# dies if:
-#   * too many revisions specified
-#   * no revision is specified and there is no stash stack
-#   * a revision is specified which cannot be resolve to a SHA1
-#   * a non-existent stash reference is specified
-#   * unknown flags were set and ALLOW_UNKNOWN_FLAGS is not "t"
-#
-
-parse_flags_and_rev()
-{
-	test "$PARSE_CACHE" = "$*" && return 0 # optimisation
-	PARSE_CACHE="$*"
-
-	IS_STASH_LIKE=
-	IS_STASH_REF=
-	INDEX_OPTION=
-	s=
-	w_commit=
-	b_commit=
-	i_commit=
-	u_commit=
-	w_tree=
-	b_tree=
-	i_tree=
-	u_tree=
-
-	FLAGS=
-	REV=
-	for opt
-	do
-		case "$opt" in
-			-q|--quiet)
-				GIT_QUIET=-t
-			;;
-			--index)
-				INDEX_OPTION=--index
-			;;
-			--help)
-				show_help
-			;;
-			-*)
-				test "$ALLOW_UNKNOWN_FLAGS" = t ||
-					die "$(eval_gettext "unknown option: \$opt")"
-				FLAGS="${FLAGS}${FLAGS:+ }$opt"
-			;;
-			*)
-				REV="${REV}${REV:+ }'$opt'"
-			;;
-		esac
-	done
-
-	eval set -- $REV
-
-	case $# in
-		0)
-			have_stash || die "$(gettext "No stash entries found.")"
-			set -- ${ref_stash}@{0}
-		;;
-		1)
-			:
-		;;
-		*)
-			die "$(eval_gettext "Too many revisions specified: \$REV")"
-		;;
-	esac
-
-	case "$1" in
-		*[!0-9]*)
-			:
-		;;
-		*)
-			set -- "${ref_stash}@{$1}"
-		;;
-	esac
-
-	REV=$(git rev-parse --symbolic --verify --quiet "$1") || {
-		reference="$1"
-		die "$(eval_gettext "\$reference is not a valid reference")"
-	}
-
-	i_commit=$(git rev-parse --verify --quiet "$REV^2") &&
-	set -- $(git rev-parse "$REV" "$REV^1" "$REV:" "$REV^1:" "$REV^2:" 2>/dev/null) &&
-	s=$1 &&
-	w_commit=$1 &&
-	b_commit=$2 &&
-	w_tree=$3 &&
-	b_tree=$4 &&
-	i_tree=$5 &&
-	IS_STASH_LIKE=t &&
-	test "$ref_stash" = "$(git rev-parse --symbolic-full-name "${REV%@*}")" &&
-	IS_STASH_REF=t
-
-	u_commit=$(git rev-parse --verify --quiet "$REV^3") &&
-	u_tree=$(git rev-parse "$REV^3:" 2>/dev/null)
-}
-
-is_stash_like()
-{
-	parse_flags_and_rev "$@"
-	test -n "$IS_STASH_LIKE"
-}
-
-assert_stash_like() {
-	is_stash_like "$@" || {
-		args="$*"
-		die "$(eval_gettext "'\$args' is not a stash-like commit")"
-	}
-}
-
-is_stash_ref() {
-	is_stash_like "$@" && test -n "$IS_STASH_REF"
-}
-
-assert_stash_ref() {
-	is_stash_ref "$@" || {
-		args="$*"
-		die "$(eval_gettext "'\$args' is not a stash reference")"
-	}
-}
-
-apply_stash () {
-
-	assert_stash_like "$@"
-
-	git update-index -q --refresh || die "$(gettext "unable to refresh index")"
-
-	# current index state
-	c_tree=$(git write-tree) ||
-		die "$(gettext "Cannot apply a stash in the middle of a merge")"
-
-	unstashed_index_tree=
-	if test -n "$INDEX_OPTION" && test "$b_tree" != "$i_tree" &&
-			test "$c_tree" != "$i_tree"
-	then
-		git diff-tree --binary $s^2^..$s^2 | git apply --cached
-		test $? -ne 0 &&
-			die "$(gettext "Conflicts in index. Try without --index.")"
-		unstashed_index_tree=$(git write-tree) ||
-			die "$(gettext "Could not save index tree")"
-		git reset
-	fi
-
-	if test -n "$u_tree"
-	then
-		GIT_INDEX_FILE="$TMPindex" git read-tree "$u_tree" &&
-		GIT_INDEX_FILE="$TMPindex" git checkout-index --all &&
-		rm -f "$TMPindex" ||
-		die "$(gettext "Could not restore untracked files from stash entry")"
-	fi
-
-	eval "
-		GITHEAD_$w_tree='Stashed changes' &&
-		GITHEAD_$c_tree='Updated upstream' &&
-		GITHEAD_$b_tree='Version stash was based on' &&
-		export GITHEAD_$w_tree GITHEAD_$c_tree GITHEAD_$b_tree
-	"
-
-	if test -n "$GIT_QUIET"
-	then
-		GIT_MERGE_VERBOSITY=0 && export GIT_MERGE_VERBOSITY
-	fi
-	if git merge-recursive $b_tree -- $c_tree $w_tree
-	then
-		# No conflict
-		if test -n "$unstashed_index_tree"
-		then
-			git read-tree "$unstashed_index_tree"
-		else
-			a="$TMP-added" &&
-			git diff-index --cached --name-only --diff-filter=A $c_tree >"$a" &&
-			git read-tree --reset $c_tree &&
-			git update-index --add --stdin <"$a" ||
-				die "$(gettext "Cannot unstage modified files")"
-			rm -f "$a"
-		fi
-		squelch=
-		if test -n "$GIT_QUIET"
-		then
-			squelch='>/dev/null 2>&1'
-		fi
-		(cd "$START_DIR" && eval "git status $squelch") || :
-	else
-		# Merge conflict; keep the exit status from merge-recursive
-		status=$?
-		git rerere
-		if test -n "$INDEX_OPTION"
-		then
-			gettextln "Index was not unstashed." >&2
-		fi
-		exit $status
-	fi
-}
-
-pop_stash() {
-	assert_stash_ref "$@"
-
-	if apply_stash "$@"
-	then
-		drop_stash "$@"
-	else
-		status=$?
-		say "$(gettext "The stash entry is kept in case you need it again.")"
-		exit $status
-	fi
-}
-
-drop_stash () {
-	assert_stash_ref "$@"
-
-	git reflog delete --updateref --rewrite "${REV}" &&
-		say "$(eval_gettext "Dropped \${REV} (\$s)")" ||
-		die "$(eval_gettext "\${REV}: Could not drop stash entry")"
-
-	# clear_stash if we just dropped the last stash entry
-	git rev-parse --verify --quiet "$ref_stash@{0}" >/dev/null ||
-	clear_stash
-}
-
-apply_to_branch () {
-	test -n "$1" || die "$(gettext "No branch name specified")"
-	branch=$1
-	shift 1
-
-	set -- --index "$@"
-	assert_stash_like "$@"
-
-	git checkout -b $branch $REV^ &&
-	apply_stash "$@" && {
-		test -z "$IS_STASH_REF" || drop_stash "$@"
-	}
-}
-
-test "$1" = "-p" && set "push" "$@"
-
-PARSE_CACHE='--not-parsed'
-# The default command is "push" if nothing but options are given
-seen_non_option=
-for opt
-do
-	case "$opt" in
-	--) break ;;
-	-*) ;;
-	*) seen_non_option=t; break ;;
-	esac
-done
-
-test -n "$seen_non_option" || set "push" "$@"
-
-# Main command set
-case "$1" in
-list)
-	shift
-	list_stash "$@"
-	;;
-show)
-	shift
-	show_stash "$@"
-	;;
-save)
-	shift
-	save_stash "$@"
-	;;
-push)
-	shift
-	push_stash "$@"
-	;;
-apply)
-	shift
-	apply_stash "$@"
-	;;
-clear)
-	shift
-	clear_stash "$@"
-	;;
-create)
-	shift
-	create_stash -m "$*" && echo "$w_commit"
-	;;
-store)
-	shift
-	store_stash "$@"
-	;;
-drop)
-	shift
-	drop_stash "$@"
-	;;
-pop)
-	shift
-	pop_stash "$@"
-	;;
-branch)
-	shift
-	apply_to_branch "$@"
-	;;
-*)
-	case $# in
-	0)
-		push_stash &&
-		say "$(gettext "(To restore them type \"git stash apply\")")"
-		;;
-	*)
-		usage
-	esac
-	;;
-esac
diff -pruN 1.2.1+git2.18.0-1/git/git-submodule.sh 1.2.3+git2.25.1-1/git/git-submodule.sh
--- 1.2.1+git2.18.0-1/git/git-submodule.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/git-submodule.sh	2020-02-17 04:47:35.000000000 +0000
@@ -5,11 +5,14 @@
 # Copyright (c) 2007 Lars Hjemli
 
 dashless=$(basename "$0" | sed -e 's/-/ /')
-USAGE="[--quiet] add [-b <branch>] [-f|--force] [--name <name>] [--reference <repository>] [--] <repository> [<path>]
+USAGE="[--quiet] [--cached]
+   or: $dashless [--quiet] add [-b <branch>] [-f|--force] [--name <name>] [--reference <repository>] [--] <repository> [<path>]
    or: $dashless [--quiet] status [--cached] [--recursive] [--] [<path>...]
    or: $dashless [--quiet] init [--] [<path>...]
    or: $dashless [--quiet] deinit [-f|--force] (--all| [--] <path>...)
    or: $dashless [--quiet] update [--init] [--remote] [-N|--no-fetch] [-f|--force] [--checkout|--merge|--rebase] [--[no-]recommend-shallow] [--reference <repository>] [--recursive] [--] [<path>...]
+   or: $dashless [--quiet] set-branch (--default|--branch <branch>) [--] <path>
+   or: $dashless [--quiet] set-url [--] <path> <newurl>
    or: $dashless [--quiet] summary [--cached|--files] [--summary-limit <n>] [commit] [--] [<path>...]
    or: $dashless [--quiet] foreach [--recursive] <command>
    or: $dashless [--quiet] sync [--recursive] [--] [<path>...]
@@ -34,6 +37,7 @@ reference=
 cached=
 recursive=
 init=
+require_init=
 files=
 remote=
 nofetch=
@@ -72,7 +76,7 @@ get_submodule_config () {
 	value=$(git config submodule."$name"."$option")
 	if test -z "$value"
 	then
-		value=$(git config -f .gitmodules submodule."$name"."$option")
+		value=$(git submodule--helper config submodule."$name"."$option")
 	fi
 	printf '%s' "${value:-$default}"
 }
@@ -82,6 +86,11 @@ isnumber()
 	n=$(($1 + 0)) 2>/dev/null && test "$n" = "$1"
 }
 
+# Given a full hex object ID, is this the zero OID?
+is_zero_oid () {
+	echo "$1" | sane_egrep '^0+$' >/dev/null 2>&1
+}
+
 # Sanitize the local git environment for use within a submodule. We
 # can't simply use clear_local_git_env since we want to preserve some
 # of the settings from GIT_CONFIG_PARAMETERS.
@@ -159,6 +168,11 @@ cmd_add()
 		shift
 	done
 
+	if ! git submodule--helper config --check-writeable >/dev/null 2>&1
+	then
+		 die "$(eval_gettext "please make sure that the .gitmodules file is in the working tree")"
+	fi
+
 	if test -n "$reference_path"
 	then
 		is_absolute_path "$reference_path" ||
@@ -220,6 +234,13 @@ cmd_add()
 		die "$(eval_gettext "'\$sm_path' already exists in the index and is not a submodule")"
 	fi
 
+	if test -d "$sm_path" &&
+		test -z $(git -C "$sm_path" rev-parse --show-cdup 2>/dev/null)
+	then
+	    git -C "$sm_path" rev-parse --verify -q HEAD >/dev/null ||
+	    die "$(eval_gettext "'\$sm_path' does not have a commit checked out")"
+	fi
+
 	if test -z "$force" &&
 		! git add --dry-run --ignore-missing --no-warn-embedded-repo "$sm_path" > /dev/null 2>&1
 	then
@@ -283,11 +304,11 @@ or you are unsure what this means choose
 	git add --no-warn-embedded-repo $force "$sm_path" ||
 	die "$(eval_gettext "Failed to add submodule '\$sm_path'")"
 
-	git config -f .gitmodules submodule."$sm_name".path "$sm_path" &&
-	git config -f .gitmodules submodule."$sm_name".url "$repo" &&
+	git submodule--helper config submodule."$sm_name".path "$sm_path" &&
+	git submodule--helper config submodule."$sm_name".url "$repo" &&
 	if test -n "$branch"
 	then
-		git config -f .gitmodules submodule."$sm_name".branch "$branch"
+		git submodule--helper config submodule."$sm_name".branch "$branch"
 	fi &&
 	git add --force .gitmodules ||
 	die "$(eval_gettext "Failed to register submodule '\$sm_path'")"
@@ -335,45 +356,7 @@ cmd_foreach()
 		shift
 	done
 
-	toplevel=$(pwd)
-
-	# dup stdin so that it can be restored when running the external
-	# command in the subshell (and a recursive call to this function)
-	exec 3<&0
-
-	{
-		git submodule--helper list --prefix "$wt_prefix" ||
-		echo "#unmatched" $?
-	} |
-	while read -r mode sha1 stage sm_path
-	do
-		die_if_unmatched "$mode" "$sha1"
-		if test -e "$sm_path"/.git
-		then
-			displaypath=$(git submodule--helper relative-path "$prefix$sm_path" "$wt_prefix")
-			say "$(eval_gettext "Entering '\$displaypath'")"
-			name=$(git submodule--helper name "$sm_path")
-			(
-				prefix="$prefix$sm_path/"
-				sanitize_submodule_env
-				cd "$sm_path" &&
-				sm_path=$(git submodule--helper relative-path "$sm_path" "$wt_prefix") &&
-				# we make $path available to scripts ...
-				path=$sm_path &&
-				if test $# -eq 1
-				then
-					eval "$1"
-				else
-					"$@"
-				fi &&
-				if test -n "$recursive"
-				then
-					cmd_foreach "--recursive" "$@"
-				fi
-			) <&3 3<&- ||
-			die "$(eval_gettext "Stopping at '\$displaypath'; script returned non-zero status.")"
-		fi
-	done
+	git ${wt_prefix:+-C "$wt_prefix"} ${prefix:+--super-prefix "$prefix"} submodule--helper foreach ${GIT_QUIET:+--quiet} ${recursive:+--recursive} -- "$@"
 }
 
 #
@@ -404,7 +387,7 @@ cmd_init()
 		shift
 	done
 
-	git ${wt_prefix:+-C "$wt_prefix"} ${prefix:+--super-prefix "$prefix"} submodule--helper init ${GIT_QUIET:+--quiet}  "$@"
+	git ${wt_prefix:+-C "$wt_prefix"} ${prefix:+--super-prefix "$prefix"} submodule--helper init ${GIT_QUIET:+--quiet} -- "$@"
 }
 
 #
@@ -440,7 +423,7 @@ cmd_deinit()
 		shift
 	done
 
-	git ${wt_prefix:+-C "$wt_prefix"} submodule--helper deinit ${GIT_QUIET:+--quiet} ${prefix:+--prefix "$prefix"} ${force:+--force} ${deinit_all:+--all} "$@"
+	git ${wt_prefix:+-C "$wt_prefix"} submodule--helper deinit ${GIT_QUIET:+--quiet} ${prefix:+--prefix "$prefix"} ${force:+--force} ${deinit_all:+--all} -- "$@"
 }
 
 is_tip_reachable () (
@@ -476,12 +459,19 @@ cmd_update()
 		-q|--quiet)
 			GIT_QUIET=1
 			;;
+		-v)
+			GIT_QUIET=0
+			;;
 		--progress)
 			progress=1
 			;;
 		-i|--init)
 			init=1
 			;;
+		--require-init)
+			init=1
+			require_init=1
+			;;
 		--remote)
 			remote=1
 			;;
@@ -564,36 +554,26 @@ cmd_update()
 		${reference:+"$reference"} \
 		${dissociate:+"--dissociate"} \
 		${depth:+--depth "$depth"} \
+		${require_init:+--require-init} \
 		$recommend_shallow \
 		$jobs \
+		-- \
 		"$@" || echo "#unmatched" $?
 	} | {
 	err=
-	while read -r mode sha1 stage just_cloned sm_path
+	while read -r quickabort sha1 just_cloned sm_path
 	do
-		die_if_unmatched "$mode" "$sha1"
+		die_if_unmatched "$quickabort" "$sha1"
 
-		name=$(git submodule--helper name "$sm_path") || exit
-		if ! test -z "$update"
-		then
-			update_module=$update
-		else
-			update_module=$(git config submodule."$name".update)
-			if test -z "$update_module"
-			then
-				update_module="checkout"
-			fi
-		fi
+		git submodule--helper ensure-core-worktree "$sm_path" || exit 1
+
+		update_module=$(git submodule--helper update-module-mode $just_cloned "$sm_path" $update)
 
 		displaypath=$(git submodule--helper relative-path "$prefix$sm_path" "$wt_prefix")
 
 		if test $just_cloned -eq 1
 		then
 			subsha1=
-			case "$update_module" in
-			merge | rebase | none)
-				update_module=checkout ;;
-			esac
 		else
 			subsha1=$(sanitize_submodule_env; cd "$sm_path" &&
 				git rev-parse --verify HEAD) ||
@@ -630,7 +610,7 @@ cmd_update()
 				# is not reachable from a ref.
 				is_tip_reachable "$sm_path" "$sha1" ||
 				fetch_in_submodule "$sm_path" $depth ||
-				say "$(eval_gettext "Unable to fetch in submodule path '\$displaypath'")"
+				say "$(eval_gettext "Unable to fetch in submodule path '\$displaypath'; trying to directly fetch \$sha1:")"
 
 				# Now we tried the usual fetch, but $sha1 may
 				# not be reachable from any of the refs
@@ -665,7 +645,7 @@ cmd_update()
 				must_die_on_failure=yes
 				;;
 			*)
-				die "$(eval_gettext "Invalid update mode '$update_module' for submodule '$name'")"
+				die "$(eval_gettext "Invalid update mode '$update_module' for submodule path '$path'")"
 			esac
 
 			if (sanitize_submodule_env; cd "$sm_path" && $command "$sha1")
@@ -722,6 +702,121 @@ cmd_update()
 }
 
 #
+# Configures a submodule's default branch
+#
+# $@ = requested path
+#
+cmd_set_branch() {
+	unset_branch=false
+	branch=
+
+	while test $# -ne 0
+	do
+		case "$1" in
+		-q|--quiet)
+			# we don't do anything with this but we need to accept it
+			;;
+		-d|--default)
+			unset_branch=true
+			;;
+		-b|--branch)
+			case "$2" in '') usage ;; esac
+			branch=$2
+			shift
+			;;
+		--)
+			shift
+			break
+			;;
+		-*)
+			usage
+			;;
+		*)
+			break
+			;;
+		esac
+		shift
+	done
+
+	if test $# -ne 1
+	then
+		usage
+	fi
+
+	# we can't use `git submodule--helper name` here because internally, it
+	# hashes the path so a trailing slash could lead to an unintentional no match
+	name="$(git submodule--helper list "$1" | cut -f2)"
+	if test -z "$name"
+	then
+		exit 1
+	fi
+
+	test -n "$branch"; has_branch=$?
+	test "$unset_branch" = true; has_unset_branch=$?
+
+	if test $((!$has_branch != !$has_unset_branch)) -eq 0
+	then
+		usage
+	fi
+
+	if test $has_branch -eq 0
+	then
+		git submodule--helper config submodule."$name".branch "$branch"
+	else
+		git submodule--helper config --unset submodule."$name".branch
+	fi
+}
+
+#
+# Configures a submodule's remote url
+#
+# $@ = requested path, requested url
+#
+cmd_set_url() {
+	while test $# -ne 0
+	do
+		case "$1" in
+		-q|--quiet)
+			GIT_QUIET=1
+			;;
+		--)
+			shift
+			break
+			;;
+		-*)
+			usage
+			;;
+		*)
+			break
+			;;
+		esac
+		shift
+	done
+
+	if test $# -ne 2
+	then
+		usage
+	fi
+
+	# we can't use `git submodule--helper name` here because internally, it
+	# hashes the path so a trailing slash could lead to an unintentional no match
+	name="$(git submodule--helper list "$1" | cut -f2)"
+	if test -z "$name"
+	then
+		exit 1
+	fi
+
+	url="$2"
+	if test -z "$url"
+	then
+		exit 1
+	fi
+
+	git submodule--helper config submodule."$name".url "$url"
+	git submodule--helper sync ${GIT_QUIET:+--quiet} "$name"
+}
+
+#
 # Show commit summary for submodules in index or working tree
 #
 # If '--cached' is given, show summary between index and given commit,
@@ -827,7 +922,7 @@ cmd_summary() {
 	while read -r mod_src mod_dst sha1_src sha1_dst status name
 	do
 		if test -z "$cached" &&
-			test $sha1_dst = 0000000000000000000000000000000000000000
+			is_zero_oid $sha1_dst
 		then
 			case "$mod_dst" in
 			160000)
@@ -887,8 +982,11 @@ cmd_summary() {
 			;;
 		esac
 
-		sha1_abbr_src=$(echo $sha1_src | cut -c1-7)
-		sha1_abbr_dst=$(echo $sha1_dst | cut -c1-7)
+		sha1_abbr_src=$(GIT_DIR="$name/.git" git rev-parse --short $sha1_src 2>/dev/null ||
+			echo $sha1_src | cut -c1-7)
+		sha1_abbr_dst=$(GIT_DIR="$name/.git" git rev-parse --short $sha1_dst 2>/dev/null ||
+			echo $sha1_dst | cut -c1-7)
+
 		if test $status = T
 		then
 			blob="$(gettext "blob")"
@@ -967,7 +1065,7 @@ cmd_status()
 		shift
 	done
 
-	git ${wt_prefix:+-C "$wt_prefix"} ${prefix:+--super-prefix "$prefix"} submodule--helper status ${GIT_QUIET:+--quiet} ${cached:+--cached} ${recursive:+--recursive} "$@"
+	git ${wt_prefix:+-C "$wt_prefix"} ${prefix:+--super-prefix "$prefix"} submodule--helper status ${GIT_QUIET:+--quiet} ${cached:+--cached} ${recursive:+--recursive} -- "$@"
 }
 #
 # Sync remote urls for submodules
@@ -1000,7 +1098,7 @@ cmd_sync()
 		esac
 	done
 
-	git ${wt_prefix:+-C "$wt_prefix"} ${prefix:+--super-prefix "$prefix"} submodule--helper sync ${GIT_QUIET:+--quiet} ${recursive:+--recursive} "$@"
+	git ${wt_prefix:+-C "$wt_prefix"} ${prefix:+--super-prefix "$prefix"} submodule--helper sync ${GIT_QUIET:+--quiet} ${recursive:+--recursive} -- "$@"
 }
 
 cmd_absorbgitdirs()
@@ -1017,7 +1115,7 @@ cmd_absorbgitdirs()
 while test $# != 0 && test -z "$command"
 do
 	case "$1" in
-	add | foreach | init | deinit | update | status | summary | sync | absorbgitdirs)
+	add | foreach | init | deinit | update | set-branch | set-url | status | summary | sync | absorbgitdirs)
 		command=$1
 		;;
 	-q|--quiet)
@@ -1058,8 +1156,8 @@ then
     fi
 fi
 
-# "-b branch" is accepted only by "add"
-if test -n "$branch" && test "$command" != add
+# "-b branch" is accepted only by "add" and "set-branch"
+if test -n "$branch" && (test "$command" != add || test "$command" != set-branch)
 then
 	usage
 fi
@@ -1070,4 +1168,4 @@ then
 	usage
 fi
 
-"cmd_$command" "$@"
+"cmd_$(echo $command | sed -e s/-/_/g)" "$@"
diff -pruN 1.2.1+git2.18.0-1/git/git-svn.perl 1.2.3+git2.25.1-1/git/git-svn.perl
--- 1.2.1+git2.18.0-1/git/git-svn.perl	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/git-svn.perl	2020-02-17 04:47:35.000000000 +0000
@@ -110,7 +110,7 @@ my ($_stdin, $_help, $_edit,
 	$_template, $_shared,
 	$_version, $_fetch_all, $_no_rebase, $_fetch_parent,
 	$_before, $_after,
-	$_merge, $_strategy, $_preserve_merges, $_dry_run, $_parents, $_local,
+	$_merge, $_strategy, $_rebase_merges, $_dry_run, $_parents, $_local,
 	$_prefix, $_no_checkout, $_url, $_verbose,
 	$_commit_url, $_tag, $_merge_info, $_interactive, $_set_svn_props);
 
@@ -270,7 +270,8 @@ my %cmd = (
 			  'local|l' => \$_local,
 			  'fetch-all|all' => \$_fetch_all,
 			  'dry-run|n' => \$_dry_run,
-			  'preserve-merges|p' => \$_preserve_merges,
+			  'rebase-merges|p' => \$_rebase_merges,
+			  'preserve-merges|p' => \$_rebase_merges,
 			  %fc_opts } ],
 	'commit-diff' => [ \&cmd_commit_diff,
 	                   'Commit a diff between two trees',
@@ -1054,7 +1055,7 @@ sub cmd_dcommit {
 					  'If you are attempting to commit ',
 					  "merges, try running:\n\t",
 					  'git rebase --interactive',
-					  '--preserve-merges ',
+					  '--rebase-merges ',
 					  $gs->refname,
 					  "\nBefore dcommitting";
 				}
@@ -1717,7 +1718,7 @@ sub rebase_cmd {
 	push @cmd, '-v' if $_verbose;
 	push @cmd, qw/--merge/ if $_merge;
 	push @cmd, "--strategy=$_strategy" if $_strategy;
-	push @cmd, "--preserve-merges" if $_preserve_merges;
+	push @cmd, "--rebase-merges" if $_rebase_merges;
 	@cmd;
 }
 
diff -pruN 1.2.1+git2.18.0-1/git/GIT-VERSION-GEN 1.2.3+git2.25.1-1/git/GIT-VERSION-GEN
--- 1.2.1+git2.18.0-1/git/GIT-VERSION-GEN	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/GIT-VERSION-GEN	2020-02-17 04:47:35.000000000 +0000
@@ -1,7 +1,7 @@
 #!/bin/sh
 
 GVF=GIT-VERSION-FILE
-DEF_VER=v2.18.0
+DEF_VER=v2.25.1
 
 LF='
 '
diff -pruN 1.2.1+git2.18.0-1/git/gitweb/gitweb.perl 1.2.3+git2.25.1-1/git/gitweb/gitweb.perl
--- 1.2.1+git2.18.0-1/git/gitweb/gitweb.perl	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/gitweb/gitweb.perl	2020-02-17 04:47:35.000000000 +0000
@@ -741,7 +741,7 @@ sub evaluate_gitweb_config {
 	$GITWEB_CONFIG_SYSTEM = "" if ($GITWEB_CONFIG_SYSTEM eq $GITWEB_CONFIG_COMMON);
 
 	# Common system-wide settings for convenience.
-	# Those settings can be ovverriden by GITWEB_CONFIG or GITWEB_CONFIG_SYSTEM.
+	# Those settings can be overridden by GITWEB_CONFIG or GITWEB_CONFIG_SYSTEM.
 	read_config_file($GITWEB_CONFIG_COMMON);
 
 	# Use first config file that exists.  This means use the per-instance
@@ -788,6 +788,38 @@ sub check_loadavg {
 # ======================================================================
 # input validation and dispatch
 
+# Various hash size-related values.
+my $sha1_len = 40;
+my $sha256_extra_len = 24;
+my $sha256_len = $sha1_len + $sha256_extra_len;
+
+# A regex matching $len hex characters. $len may be a range (e.g. 7,64).
+sub oid_nlen_regex {
+	my $len = shift;
+	my $hchr = qr/[0-9a-fA-F]/;
+	return qr/(?:(?:$hchr){$len})/;
+}
+
+# A regex matching two sets of $nlen hex characters, prefixed by the literal
+# string $prefix and with the literal string $infix between them.
+sub oid_nlen_prefix_infix_regex {
+	my $nlen = shift;
+	my $prefix = shift;
+	my $infix = shift;
+
+	my $rx = oid_nlen_regex($nlen);
+
+	return qr/^\Q$prefix\E$rx\Q$infix\E$rx$/;
+}
+
+# A regex matching a valid object ID.
+our $oid_regex;
+{
+	my $x = oid_nlen_regex($sha1_len);
+	my $y = oid_nlen_regex($sha256_extra_len);
+	$oid_regex = qr/(?:$x(?:$y)?)/;
+}
+
 # input parameters can be collected from a variety of sources (presently, CGI
 # and PATH_INFO), so we define an %input_params hash that collects them all
 # together during validation: this allows subsequent uses (e.g. href()) to be
@@ -1516,7 +1548,7 @@ sub is_valid_refname {
 
 	return undef unless defined $input;
 	# textual hashes are O.K.
-	if ($input =~ m/^[0-9a-fA-F]{40}$/) {
+	if ($input =~ m/^$oid_regex$/) {
 		return 1;
 	}
 	# it must be correct pathname
@@ -1625,15 +1657,15 @@ sub quot_cec {
 	my $cntrl = shift;
 	my %opts = @_;
 	my %es = ( # character escape codes, aka escape sequences
-		"\t" => '\t',   # tab            (HT)
-		"\n" => '\n',   # line feed      (LF)
-		"\r" => '\r',   # carrige return (CR)
-		"\f" => '\f',   # form feed      (FF)
-		"\b" => '\b',   # backspace      (BS)
-		"\a" => '\a',   # alarm (bell)   (BEL)
-		"\e" => '\e',   # escape         (ESC)
-		"\013" => '\v', # vertical tab   (VT)
-		"\000" => '\0', # nul character  (NUL)
+		"\t" => '\t',   # tab             (HT)
+		"\n" => '\n',   # line feed       (LF)
+		"\r" => '\r',   # carriage return (CR)
+		"\f" => '\f',   # form feed       (FF)
+		"\b" => '\b',   # backspace       (BS)
+		"\a" => '\a',   # alarm (bell)    (BEL)
+		"\e" => '\e',   # escape          (ESC)
+		"\013" => '\v', # vertical tab    (VT)
+		"\000" => '\0', # nul character   (NUL)
 	);
 	my $chr = ( (exists $es{$cntrl})
 		    ? $es{$cntrl}
@@ -2028,6 +2060,9 @@ sub file_type_long {
 sub format_log_line_html {
 	my $line = shift;
 
+	# Potentially abbreviated OID.
+	my $regex = oid_nlen_regex("7,64");
+
 	$line = esc_html($line, -nbsp=>1);
 	$line =~ s{
         \b
@@ -2037,10 +2072,10 @@ sub format_log_line_html {
             (?<!-) # see strbuf_check_tag_ref(). Tags can't start with -
             [A-Za-z0-9.-]+
             (?!\.) # refs can't end with ".", see check_refname_format()
-            -g[0-9a-fA-F]{7,40}
+            -g$regex
             |
             # Just a normal looking Git SHA1
-            [0-9a-fA-F]{7,40}
+	    $regex
         )
         \b
     }{
@@ -2286,7 +2321,8 @@ sub format_extended_diff_header_line {
 		         ')</span>';
 	}
 	# match <hash>
-	if ($line =~ m/^index [0-9a-fA-F]{40},[0-9a-fA-F]{40}/) {
+	if ($line =~ oid_nlen_prefix_infix_regex($sha1_len, "index ", ",") |
+	    $line =~ oid_nlen_prefix_infix_regex($sha256_len, "index ", ",")) {
 		# can match only for combined diff
 		$line = 'index ';
 		for (my $i = 0; $i < $diffinfo->{'nparents'}; $i++) {
@@ -2308,7 +2344,8 @@ sub format_extended_diff_header_line {
 			$line .= '0' x 7;
 		}
 
-	} elsif ($line =~ m/^index [0-9a-fA-F]{40}..[0-9a-fA-F]{40}/) {
+	} elsif ($line =~ oid_nlen_prefix_infix_regex($sha1_len, "index ", "..") |
+		 $line =~ oid_nlen_prefix_infix_regex($sha256_len, "index ", "..")) {
 		# can match only for ordinary diff
 		my ($from_link, $to_link);
 		if ($from->{'href'}) {
@@ -2834,7 +2871,7 @@ sub git_get_hash_by_path {
 	}
 
 	#'100644 blob 0fa3f3a66fb6a137f6ec2c19351ed4d807070ffa	panic.c'
-	$line =~ m/^([0-9]+) (.+) ([0-9a-fA-F]{40})\t/;
+	$line =~ m/^([0-9]+) (.+) ($oid_regex)\t/;
 	if (defined $type && $type ne $2) {
 		# type doesn't match
 		return undef;
@@ -3333,7 +3370,7 @@ sub git_get_references {
 
 	while (my $line = <$fd>) {
 		chomp $line;
-		if ($line =~ m!^([0-9a-fA-F]{40})\srefs/($type.*)$!) {
+		if ($line =~ m!^($oid_regex)\srefs/($type.*)$!) {
 			if (defined $refs{$1}) {
 				push @{$refs{$1}}, $2;
 			} else {
@@ -3407,7 +3444,7 @@ sub parse_tag {
 	$tag{'id'} = $tag_id;
 	while (my $line = <$fd>) {
 		chomp $line;
-		if ($line =~ m/^object ([0-9a-fA-F]{40})$/) {
+		if ($line =~ m/^object ($oid_regex)$/) {
 			$tag{'object'} = $1;
 		} elsif ($line =~ m/^type (.+)$/) {
 			$tag{'type'} = $1;
@@ -3451,15 +3488,15 @@ sub parse_commit_text {
 	}
 
 	my $header = shift @commit_lines;
-	if ($header !~ m/^[0-9a-fA-F]{40}/) {
+	if ($header !~ m/^$oid_regex/) {
 		return;
 	}
 	($co{'id'}, my @parents) = split ' ', $header;
 	while (my $line = shift @commit_lines) {
 		last if $line eq "\n";
-		if ($line =~ m/^tree ([0-9a-fA-F]{40})$/) {
+		if ($line =~ m/^tree ($oid_regex)$/) {
 			$co{'tree'} = $1;
-		} elsif ((!defined $withparents) && ($line =~ m/^parent ([0-9a-fA-F]{40})$/)) {
+		} elsif ((!defined $withparents) && ($line =~ m/^parent ($oid_regex)$/)) {
 			push @parents, $1;
 		} elsif ($line =~ m/^author (.*) ([0-9]+) (.*)$/) {
 			$co{'author'} = to_utf8($1);
@@ -3591,7 +3628,7 @@ sub parse_difftree_raw_line {
 
 	# ':100644 100644 03b218260e99b78c6df0ed378e59ed9205ccc96d 3b93d5e7cc7f7dd4ebed13a5cc1a4ad976fc94d8 M	ls-files.c'
 	# ':100644 100644 7f9281985086971d3877aca27704f2aaf9c448ce bc190ebc71bbd923f2b728e505408f5e54bd073a M	rev-tree.c'
-	if ($line =~ m/^:([0-7]{6}) ([0-7]{6}) ([0-9a-fA-F]{40}) ([0-9a-fA-F]{40}) (.)([0-9]{0,3})\t(.*)$/) {
+	if ($line =~ m/^:([0-7]{6}) ([0-7]{6}) ($oid_regex) ($oid_regex) (.)([0-9]{0,3})\t(.*)$/) {
 		$res{'from_mode'} = $1;
 		$res{'to_mode'} = $2;
 		$res{'from_id'} = $3;
@@ -3606,7 +3643,7 @@ sub parse_difftree_raw_line {
 	}
 	# '::100755 100755 100755 60e79ca1b01bc8b057abe17ddab484699a7f5fdb 94067cc5f73388f33722d52ae02f44692bc07490 94067cc5f73388f33722d52ae02f44692bc07490 MR	git-gui/git-gui.sh'
 	# combined diff (for merge commit)
-	elsif ($line =~ s/^(::+)((?:[0-7]{6} )+)((?:[0-9a-fA-F]{40} )+)([a-zA-Z]+)\t(.*)$//) {
+	elsif ($line =~ s/^(::+)((?:[0-7]{6} )+)((?:$oid_regex )+)([a-zA-Z]+)\t(.*)$//) {
 		$res{'nparents'}  = length($1);
 		$res{'from_mode'} = [ split(' ', $2) ];
 		$res{'to_mode'} = pop @{$res{'from_mode'}};
@@ -3616,7 +3653,7 @@ sub parse_difftree_raw_line {
 		$res{'to_file'} = unquote($5);
 	}
 	# 'c512b523472485aef4fff9e57b229d9d243c967f'
-	elsif ($line =~ m/^([0-9a-fA-F]{40})$/) {
+	elsif ($line =~ m/^($oid_regex)$/) {
 		$res{'commit'} = $1;
 	}
 
@@ -3644,7 +3681,7 @@ sub parse_ls_tree_line {
 
 	if ($opts{'-l'}) {
 		#'100644 blob 0fa3f3a66fb6a137f6ec2c19351ed4d807070ffa   16717	panic.c'
-		$line =~ m/^([0-9]+) (.+) ([0-9a-fA-F]{40}) +(-|[0-9]+)\t(.+)$/s;
+		$line =~ m/^([0-9]+) (.+) ($oid_regex) +(-|[0-9]+)\t(.+)$/s;
 
 		$res{'mode'} = $1;
 		$res{'type'} = $2;
@@ -3657,7 +3694,7 @@ sub parse_ls_tree_line {
 		}
 	} else {
 		#'100644 blob 0fa3f3a66fb6a137f6ec2c19351ed4d807070ffa	panic.c'
-		$line =~ m/^([0-9]+) (.+) ([0-9a-fA-F]{40})\t(.+)$/s;
+		$line =~ m/^([0-9]+) (.+) ($oid_regex)\t(.+)$/s;
 
 		$res{'mode'} = $1;
 		$res{'type'} = $2;
@@ -4011,7 +4048,7 @@ sub print_feed_meta {
 
 			$href_params{'extra_options'} = undef;
 			$href_params{'action'} = $type;
-			$link_attr{'-href'} = href(%href_params);
+			$link_attr{'-href'} = esc_attr(href(%href_params));
 			print "<link ".
 			      "rel=\"$link_attr{'-rel'}\" ".
 			      "title=\"$link_attr{'-title'}\" ".
@@ -4020,7 +4057,7 @@ sub print_feed_meta {
 			      "/>\n";
 
 			$href_params{'extra_options'} = '--no-merges';
-			$link_attr{'-href'} = href(%href_params);
+			$link_attr{'-href'} = esc_attr(href(%href_params));
 			$link_attr{'-title'} .= ' (no merges)';
 			print "<link ".
 			      "rel=\"$link_attr{'-rel'}\" ".
@@ -4033,10 +4070,12 @@ sub print_feed_meta {
 	} else {
 		printf('<link rel="alternate" title="%s projects list" '.
 		       'href="%s" type="text/plain; charset=utf-8" />'."\n",
-		       esc_attr($site_name), href(project=>undef, action=>"project_index"));
+		       esc_attr($site_name),
+		       esc_attr(href(project=>undef, action=>"project_index")));
 		printf('<link rel="alternate" title="%s projects feeds" '.
 		       'href="%s" type="text/x-opml" />'."\n",
-		       esc_attr($site_name), href(project=>undef, action=>"opml"));
+		       esc_attr($site_name),
+		       esc_attr(href(project=>undef, action=>"opml")));
 	}
 }
 
@@ -4250,8 +4289,8 @@ sub git_footer_html {
 	if (defined $action &&
 	    $action eq 'blame_incremental') {
 		print qq!<script type="text/javascript">\n!.
-		      qq!startBlame("!. href(action=>"blame_data", -replay=>1) .qq!",\n!.
-		      qq!           "!. href() .qq!");\n!.
+		      qq!startBlame("!. esc_attr(href(action=>"blame_data", -replay=>1)) .qq!",\n!.
+		      qq!           "!. esc_attr(href()) .qq!");\n!.
 		      qq!</script>\n!;
 	} else {
 		my ($jstimezone, $tz_cookie, $datetime_class) =
@@ -4799,7 +4838,7 @@ sub fill_from_file_info {
 sub is_deleted {
 	my $diffinfo = shift;
 
-	return $diffinfo->{'to_id'} eq ('0' x 40);
+	return $diffinfo->{'to_id'} eq ('0' x 40) || $diffinfo->{'to_id'} eq ('0' x 64);
 }
 
 # does patch correspond to [previous] difftree raw line
@@ -5246,7 +5285,7 @@ sub format_ctx_rem_add_lines {
 		#    + c
 		#   +  d
 		#
-		# Otherwise the highlightling would be confusing.
+		# Otherwise the highlighting would be confusing.
 		if ($is_combined) {
 			for (my $i = 0; $i < @$add; $i++) {
 				my $prefix_rem = substr($rem->[$i], 0, $num_parents);
@@ -6285,7 +6324,7 @@ sub git_search_changes {
 			              -class => "list subject"},
 			              chop_and_escape_str($co{'title'}, 50) . "<br/>");
 		} elsif (defined $set{'to_id'}) {
-			next if ($set{'to_id'} =~ m/^0{40}$/);
+			next if is_deleted(\%set);
 
 			print $cgi->a({-href => href(action=>"blob", hash_base=>$co{'id'},
 			                             hash=>$set{'to_id'}, file_name=>$set{'to_file'}),
@@ -6829,7 +6868,7 @@ sub git_blame_common {
 			# the header: <SHA-1> <src lineno> <dst lineno> [<lines in group>]
 			# no <lines in group> for subsequent lines in group of lines
 			my ($full_rev, $orig_lineno, $lineno, $group_size) =
-			   ($line =~ /^([0-9a-f]{40}) (\d+) (\d+)(?: (\d+))?$/);
+			   ($line =~ /^($oid_regex) (\d+) (\d+)(?: (\d+))?$/);
 			if (!exists $metainfo{$full_rev}) {
 				$metainfo{$full_rev} = { 'nprevious' => 0 };
 			}
@@ -6879,7 +6918,7 @@ sub git_blame_common {
 			}
 			# 'previous' <sha1 of parent commit> <filename at commit>
 			if (exists $meta->{'previous'} &&
-			    $meta->{'previous'} =~ /^([a-fA-F0-9]{40}) (.*)$/) {
+			    $meta->{'previous'} =~ /^($oid_regex) (.*)$/) {
 				$meta->{'parent'} = $1;
 				$meta->{'file_parent'} = unquote($2);
 			}
@@ -6996,7 +7035,7 @@ sub git_blob_plain {
 		} else {
 			die_error(400, "No file name defined");
 		}
-	} elsif ($hash =~ m/^[0-9a-fA-F]{40}$/) {
+	} elsif ($hash =~ m/^$oid_regex$/) {
 		# blobs defined by non-textual hash id's can be cached
 		$expires = "+1d";
 	}
@@ -7057,7 +7096,7 @@ sub git_blob {
 		} else {
 			die_error(400, "No file name defined");
 		}
-	} elsif ($hash =~ m/^[0-9a-fA-F]{40}$/) {
+	} elsif ($hash =~ m/^$oid_regex$/) {
 		# blobs defined by non-textual hash id's can be cached
 		$expires = "+1d";
 	}
@@ -7118,8 +7157,8 @@ sub git_blob {
 			print qq! alt="!.esc_attr($file_name).qq!" title="!.esc_attr($file_name).qq!"!;
 		}
 		print qq! src="! .
-		      href(action=>"blob_plain", hash=>$hash,
-		           hash_base=>$hash_base, file_name=>$file_name) .
+		      esc_attr(href(action=>"blob_plain", hash=>$hash,
+		           hash_base=>$hash_base, file_name=>$file_name)) .
 		      qq!" />\n!;
 	} else {
 		my $nr;
@@ -7515,7 +7554,7 @@ sub git_commit {
 
 	# non-textual hash id's can be cached
 	my $expires;
-	if ($hash =~ m/^[0-9a-fA-F]{40}$/) {
+	if ($hash =~ m/^$oid_regex$/) {
 		$expires = "+1d";
 	}
 	my $refs = git_get_references();
@@ -7609,7 +7648,7 @@ sub git_object {
 		close $fd;
 
 		#'100644 blob 0fa3f3a66fb6a137f6ec2c19351ed4d807070ffa	panic.c'
-		unless ($line && $line =~ m/^([0-9]+) (.+) ([0-9a-fA-F]{40})\t/) {
+		unless ($line && $line =~ m/^([0-9]+) (.+) ($oid_regex)\t/) {
 			die_error(404, "File or directory for given base does not exist");
 		}
 		$type = $2;
@@ -7649,7 +7688,7 @@ sub git_blobdiff {
 				or die_error(404, "Blob diff not found");
 
 		} elsif (defined $hash &&
-		         $hash =~ /[0-9a-fA-F]{40}/) {
+		         $hash =~ $oid_regex) {
 			# try to find filename from $hash
 
 			# read filtered raw output
@@ -7659,7 +7698,7 @@ sub git_blobdiff {
 			@difftree =
 				# ':100644 100644 03b21826... 3b93d5e7... M	ls-files.c'
 				# $hash == to_id
-				grep { /^:[0-7]{6} [0-7]{6} [0-9a-fA-F]{40} $hash/ }
+				grep { /^:[0-7]{6} [0-7]{6} $oid_regex $hash/ }
 				map { chomp; $_ } <$fd>;
 			close $fd
 				or die_error(404, "Reading git-diff-tree failed");
@@ -7682,8 +7721,8 @@ sub git_blobdiff {
 		$hash        ||= $diffinfo{'to_id'};
 
 		# non-textual hash id's can be cached
-		if ($hash_base =~ m/^[0-9a-fA-F]{40}$/ &&
-		    $hash_parent_base =~ m/^[0-9a-fA-F]{40}$/) {
+		if ($hash_base =~ m/^$oid_regex$/ &&
+		    $hash_parent_base =~ m/^$oid_regex$/) {
 			$expires = '+1d';
 		}
 
@@ -7819,7 +7858,7 @@ sub git_commitdiff {
 		    $hash_parent ne '-c' && $hash_parent ne '--cc') {
 			# commitdiff with two commits given
 			my $hash_parent_short = $hash_parent;
-			if ($hash_parent =~ m/^[0-9a-fA-F]{40}$/) {
+			if ($hash_parent =~ m/^$oid_regex$/) {
 				$hash_parent_short = substr($hash_parent, 0, 7);
 			}
 			$formats_nav .=
@@ -7928,7 +7967,7 @@ sub git_commitdiff {
 
 	# non-textual hash id's can be cached
 	my $expires;
-	if ($hash =~ m/^[0-9a-fA-F]{40}$/) {
+	if ($hash =~ m/^$oid_regex$/) {
 		$expires = "+1d";
 	}
 
@@ -8202,6 +8241,7 @@ sub git_feed {
 	} else {
 		$alt_url = href(-full=>1, action=>"summary");
 	}
+	$alt_url = esc_attr($alt_url);
 	print qq!<?xml version="1.0" encoding="utf-8"?>\n!;
 	if ($format eq 'rss') {
 		print <<XML;
@@ -8239,7 +8279,7 @@ XML
 		      $alt_url . '" />' . "\n" .
 		      '<link rel="self" type="' . $content_type . '" href="' .
 		      $cgi->self_url() . '" />' . "\n" .
-		      "<id>" . href(-full=>1) . "</id>\n" .
+		      "<id>" . esc_url(href(-full=>1)) . "</id>\n" .
 		      # use project owner for feed author
 		      "<author><name>$owner</name></author>\n";
 		if (defined $favicon) {
@@ -8285,7 +8325,7 @@ XML
 			      "<author>" . esc_html($co{'author'}) . "</author>\n" .
 			      "<pubDate>$cd{'rfc2822'}</pubDate>\n" .
 			      "<guid isPermaLink=\"true\">$co_url</guid>\n" .
-			      "<link>$co_url</link>\n" .
+			      "<link>" . esc_html($co_url) . "</link>\n" .
 			      "<description>" . esc_html($co{'title'}) . "</description>\n" .
 			      "<content:encoded>" .
 			      "<![CDATA[\n";
@@ -8307,8 +8347,8 @@ XML
 			}
 			print "</contributor>\n" .
 			      "<published>$cd{'iso-8601'}</published>\n" .
-			      "<link rel=\"alternate\" type=\"text/html\" href=\"$co_url\" />\n" .
-			      "<id>$co_url</id>\n" .
+			      "<link rel=\"alternate\" type=\"text/html\" href=\"" . esc_attr($co_url) . "\" />\n" .
+			      "<id>" . esc_html($co_url) . "</id>\n" .
 			      "<content type=\"xhtml\" xml:base=\"" . esc_url($my_url) . "\">\n" .
 			      "<div xmlns=\"http://www.w3.org/1999/xhtml\">\n";
 		}
@@ -8415,8 +8455,8 @@ XML
 		}
 
 		my $path = esc_html(chop_str($proj{'path'}, 25, 5));
-		my $rss  = href('project' => $proj{'path'}, 'action' => 'rss', -full => 1);
-		my $html = href('project' => $proj{'path'}, 'action' => 'summary', -full => 1);
+		my $rss  = esc_attr(href('project' => $proj{'path'}, 'action' => 'rss', -full => 1));
+		my $html = esc_attr(href('project' => $proj{'path'}, 'action' => 'summary', -full => 1));
 		print "<outline type=\"rss\" text=\"$path\" title=\"$path\" xmlUrl=\"$rss\" htmlUrl=\"$html\"/>\n";
 	}
 	print <<XML;
diff -pruN 1.2.1+git2.18.0-1/git/gitweb/static/js/blame_incremental.js 1.2.3+git2.25.1-1/git/gitweb/static/js/blame_incremental.js
--- 1.2.1+git2.18.0-1/git/gitweb/static/js/blame_incremental.js	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/gitweb/static/js/blame_incremental.js	2020-02-17 04:47:35.000000000 +0000
@@ -484,7 +484,7 @@ function processBlameLines(lines) {
 			case 'previous':
 				curCommit.nprevious++;
 				// store only first 'previous' header
-				if (!'previous' in curCommit) {
+				if (!('previous' in curCommit)) {
 					var parts = data.split(' ', 2);
 					curCommit.previous    = parts[0];
 					curCommit.file_parent = unquote(parts[1]);
diff -pruN 1.2.1+git2.18.0-1/git/gpg-interface.c 1.2.3+git2.25.1-1/git/gpg-interface.c
--- 1.2.1+git2.18.0-1/git/gpg-interface.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/gpg-interface.c	2020-02-17 04:47:35.000000000 +0000
@@ -7,10 +7,64 @@
 #include "tempfile.h"
 
 static char *configured_signing_key;
-static const char *gpg_program = "gpg";
+struct gpg_format {
+	const char *name;
+	const char *program;
+	const char **verify_args;
+	const char **sigs;
+};
+
+static const char *openpgp_verify_args[] = {
+	"--keyid-format=long",
+	NULL
+};
+static const char *openpgp_sigs[] = {
+	"-----BEGIN PGP SIGNATURE-----",
+	"-----BEGIN PGP MESSAGE-----",
+	NULL
+};
 
-#define PGP_SIGNATURE "-----BEGIN PGP SIGNATURE-----"
-#define PGP_MESSAGE "-----BEGIN PGP MESSAGE-----"
+static const char *x509_verify_args[] = {
+	NULL
+};
+static const char *x509_sigs[] = {
+	"-----BEGIN SIGNED MESSAGE-----",
+	NULL
+};
+
+static struct gpg_format gpg_format[] = {
+	{ .name = "openpgp", .program = "gpg",
+	  .verify_args = openpgp_verify_args,
+	  .sigs = openpgp_sigs
+	},
+	{ .name = "x509", .program = "gpgsm",
+	  .verify_args = x509_verify_args,
+	  .sigs = x509_sigs
+	},
+};
+
+static struct gpg_format *use_format = &gpg_format[0];
+
+static struct gpg_format *get_format_by_name(const char *str)
+{
+	int i;
+
+	for (i = 0; i < ARRAY_SIZE(gpg_format); i++)
+		if (!strcmp(gpg_format[i].name, str))
+			return gpg_format + i;
+	return NULL;
+}
+
+static struct gpg_format *get_format_by_sig(const char *sig)
+{
+	int i, j;
+
+	for (i = 0; i < ARRAY_SIZE(gpg_format); i++)
+		for (j = 0; gpg_format[i].sigs[j]; j++)
+			if (starts_with(sig, gpg_format[i].sigs[j]))
+				return gpg_format + i;
+	return NULL;
+}
 
 void signature_check_clear(struct signature_check *sigc)
 {
@@ -19,49 +73,187 @@ void signature_check_clear(struct signat
 	FREE_AND_NULL(sigc->gpg_status);
 	FREE_AND_NULL(sigc->signer);
 	FREE_AND_NULL(sigc->key);
+	FREE_AND_NULL(sigc->fingerprint);
+	FREE_AND_NULL(sigc->primary_key_fingerprint);
 }
 
+/* An exclusive status -- only one of them can appear in output */
+#define GPG_STATUS_EXCLUSIVE	(1<<0)
+/* The status includes key identifier */
+#define GPG_STATUS_KEYID	(1<<1)
+/* The status includes user identifier */
+#define GPG_STATUS_UID		(1<<2)
+/* The status includes key fingerprints */
+#define GPG_STATUS_FINGERPRINT	(1<<3)
+
+/* Short-hand for standard exclusive *SIG status with keyid & UID */
+#define GPG_STATUS_STDSIG	(GPG_STATUS_EXCLUSIVE|GPG_STATUS_KEYID|GPG_STATUS_UID)
+
 static struct {
 	char result;
 	const char *check;
+	unsigned int flags;
 } sigcheck_gpg_status[] = {
-	{ 'G', "\n[GNUPG:] GOODSIG " },
-	{ 'B', "\n[GNUPG:] BADSIG " },
-	{ 'U', "\n[GNUPG:] TRUST_NEVER" },
-	{ 'U', "\n[GNUPG:] TRUST_UNDEFINED" },
-	{ 'E', "\n[GNUPG:] ERRSIG "},
-	{ 'X', "\n[GNUPG:] EXPSIG "},
-	{ 'Y', "\n[GNUPG:] EXPKEYSIG "},
-	{ 'R', "\n[GNUPG:] REVKEYSIG "},
+	{ 'G', "GOODSIG ", GPG_STATUS_STDSIG },
+	{ 'B', "BADSIG ", GPG_STATUS_STDSIG },
+	{ 'U', "TRUST_NEVER", 0 },
+	{ 'U', "TRUST_UNDEFINED", 0 },
+	{ 'E', "ERRSIG ", GPG_STATUS_EXCLUSIVE|GPG_STATUS_KEYID },
+	{ 'X', "EXPSIG ", GPG_STATUS_STDSIG },
+	{ 'Y', "EXPKEYSIG ", GPG_STATUS_STDSIG },
+	{ 'R', "REVKEYSIG ", GPG_STATUS_STDSIG },
+	{ 0, "VALIDSIG ", GPG_STATUS_FINGERPRINT },
 };
 
-void parse_gpg_output(struct signature_check *sigc)
+static void replace_cstring(char **field, const char *line, const char *next)
+{
+	free(*field);
+
+	if (line && next)
+		*field = xmemdupz(line, next - line);
+	else
+		*field = NULL;
+}
+
+static void parse_gpg_output(struct signature_check *sigc)
 {
 	const char *buf = sigc->gpg_status;
-	int i;
+	const char *line, *next;
+	int i, j;
+	int seen_exclusive_status = 0;
+
+	/* Iterate over all lines */
+	for (line = buf; *line; line = strchrnul(line+1, '\n')) {
+		while (*line == '\n')
+			line++;
+		if (!*line)
+			break;
+
+		/* Skip lines that don't start with GNUPG status */
+		if (!skip_prefix(line, "[GNUPG:] ", &line))
+			continue;
+
+		/* Iterate over all search strings */
+		for (i = 0; i < ARRAY_SIZE(sigcheck_gpg_status); i++) {
+			if (skip_prefix(line, sigcheck_gpg_status[i].check, &line)) {
+				if (sigcheck_gpg_status[i].flags & GPG_STATUS_EXCLUSIVE) {
+					if (seen_exclusive_status++)
+						goto found_duplicate_status;
+				}
+
+				if (sigcheck_gpg_status[i].result)
+					sigc->result = sigcheck_gpg_status[i].result;
+				/* Do we have key information? */
+				if (sigcheck_gpg_status[i].flags & GPG_STATUS_KEYID) {
+					next = strchrnul(line, ' ');
+					replace_cstring(&sigc->key, line, next);
+					/* Do we have signer information? */
+					if (*next && (sigcheck_gpg_status[i].flags & GPG_STATUS_UID)) {
+						line = next + 1;
+						next = strchrnul(line, '\n');
+						replace_cstring(&sigc->signer, line, next);
+					}
+				}
+				/* Do we have fingerprint? */
+				if (sigcheck_gpg_status[i].flags & GPG_STATUS_FINGERPRINT) {
+					const char *limit;
+					char **field;
+
+					next = strchrnul(line, ' ');
+					replace_cstring(&sigc->fingerprint, line, next);
+
+					/*
+					 * Skip interim fields.  The search is
+					 * limited to the same line since only
+					 * OpenPGP signatures has a field with
+					 * the primary fingerprint.
+					 */
+					limit = strchrnul(line, '\n');
+					for (j = 9; j > 0; j--) {
+						if (!*next || limit <= next)
+							break;
+						line = next + 1;
+						next = strchrnul(line, ' ');
+					}
+
+					field = &sigc->primary_key_fingerprint;
+					if (!j) {
+						next = strchrnul(line, '\n');
+						replace_cstring(field, line, next);
+					} else {
+						replace_cstring(field, NULL, NULL);
+					}
+				}
 
-	/* Iterate over all search strings */
-	for (i = 0; i < ARRAY_SIZE(sigcheck_gpg_status); i++) {
-		const char *found, *next;
-
-		if (!skip_prefix(buf, sigcheck_gpg_status[i].check + 1, &found)) {
-			found = strstr(buf, sigcheck_gpg_status[i].check);
-			if (!found)
-				continue;
-			found += strlen(sigcheck_gpg_status[i].check);
-		}
-		sigc->result = sigcheck_gpg_status[i].result;
-		/* The trust messages are not followed by key/signer information */
-		if (sigc->result != 'U') {
-			sigc->key = xmemdupz(found, 16);
-			/* The ERRSIG message is not followed by signer information */
-			if (sigc-> result != 'E') {
-				found += 17;
-				next = strchrnul(found, '\n');
-				sigc->signer = xmemdupz(found, next - found);
+				break;
 			}
 		}
 	}
+	return;
+
+found_duplicate_status:
+	/*
+	 * GOODSIG, BADSIG etc. can occur only once for each signature.
+	 * Therefore, if we had more than one then we're dealing with multiple
+	 * signatures.  We don't support them currently, and they're rather
+	 * hard to create, so something is likely fishy and we should reject
+	 * them altogether.
+	 */
+	sigc->result = 'E';
+	/* Clear partial data to avoid confusion */
+	FREE_AND_NULL(sigc->primary_key_fingerprint);
+	FREE_AND_NULL(sigc->fingerprint);
+	FREE_AND_NULL(sigc->signer);
+	FREE_AND_NULL(sigc->key);
+}
+
+static int verify_signed_buffer(const char *payload, size_t payload_size,
+				const char *signature, size_t signature_size,
+				struct strbuf *gpg_output,
+				struct strbuf *gpg_status)
+{
+	struct child_process gpg = CHILD_PROCESS_INIT;
+	struct gpg_format *fmt;
+	struct tempfile *temp;
+	int ret;
+	struct strbuf buf = STRBUF_INIT;
+
+	temp = mks_tempfile_t(".git_vtag_tmpXXXXXX");
+	if (!temp)
+		return error_errno(_("could not create temporary file"));
+	if (write_in_full(temp->fd, signature, signature_size) < 0 ||
+	    close_tempfile_gently(temp) < 0) {
+		error_errno(_("failed writing detached signature to '%s'"),
+			    temp->filename.buf);
+		delete_tempfile(&temp);
+		return -1;
+	}
+
+	fmt = get_format_by_sig(signature);
+	if (!fmt)
+		BUG("bad signature '%s'", signature);
+
+	argv_array_push(&gpg.args, fmt->program);
+	argv_array_pushv(&gpg.args, fmt->verify_args);
+	argv_array_pushl(&gpg.args,
+			 "--status-fd=1",
+			 "--verify", temp->filename.buf, "-",
+			 NULL);
+
+	if (!gpg_status)
+		gpg_status = &buf;
+
+	sigchain_push(SIGPIPE, SIG_IGN);
+	ret = pipe_command(&gpg, payload, payload_size,
+			   gpg_status, 0, gpg_output, 0);
+	sigchain_pop(SIGPIPE);
+
+	delete_tempfile(&temp);
+
+	ret |= !strstr(gpg_status->buf, "\n[GNUPG:] GOODSIG ");
+	strbuf_release(&buf); /* no matter it was used or not */
+
+	return ret;
 }
 
 int check_signature(const char *payload, size_t plen, const char *signature,
@@ -81,12 +273,13 @@ int check_signature(const char *payload,
 	sigc->gpg_output = strbuf_detach(&gpg_output, NULL);
 	sigc->gpg_status = strbuf_detach(&gpg_status, NULL);
 	parse_gpg_output(sigc);
+	status |= sigc->result != 'G' && sigc->result != 'U';
 
  out:
 	strbuf_release(&gpg_status);
 	strbuf_release(&gpg_output);
 
-	return sigc->result != 'G' && sigc->result != 'U';
+	return !!status;
 }
 
 void print_signature_buffer(const struct signature_check *sigc, unsigned flags)
@@ -101,12 +294,6 @@ void print_signature_buffer(const struct
 		fputs(output, stderr);
 }
 
-static int is_gpg_start(const char *line)
-{
-	return starts_with(line, PGP_SIGNATURE) ||
-		starts_with(line, PGP_MESSAGE);
-}
-
 size_t parse_signature(const char *buf, size_t size)
 {
 	size_t len = 0;
@@ -114,7 +301,7 @@ size_t parse_signature(const char *buf,
 	while (len < size) {
 		const char *eol;
 
-		if (is_gpg_start(buf + len))
+		if (get_format_by_sig(buf + len))
 			match = len;
 
 		eol = memchr(buf + len, '\n', size - len);
@@ -131,6 +318,9 @@ void set_signing_key(const char *key)
 
 int git_gpg_config(const char *var, const char *value, void *cb)
 {
+	struct gpg_format *fmt = NULL;
+	char *fmtname = NULL;
+
 	if (!strcmp(var, "user.signingkey")) {
 		if (!value)
 			return config_error_nonbool(var);
@@ -138,13 +328,28 @@ int git_gpg_config(const char *var, cons
 		return 0;
 	}
 
-	if (!strcmp(var, "gpg.program")) {
+	if (!strcmp(var, "gpg.format")) {
 		if (!value)
 			return config_error_nonbool(var);
-		gpg_program = xstrdup(value);
+		fmt = get_format_by_name(value);
+		if (!fmt)
+			return error("unsupported value for %s: %s",
+				     var, value);
+		use_format = fmt;
 		return 0;
 	}
 
+	if (!strcmp(var, "gpg.program") || !strcmp(var, "gpg.openpgp.program"))
+		fmtname = "openpgp";
+
+	if (!strcmp(var, "gpg.x509.program"))
+		fmtname = "x509";
+
+	if (fmtname) {
+		fmt = get_format_by_name(fmtname);
+		return git_config_string(&fmt->program, var, value);
+	}
+
 	return 0;
 }
 
@@ -163,7 +368,7 @@ int sign_buffer(struct strbuf *buffer, s
 	struct strbuf gpg_status = STRBUF_INIT;
 
 	argv_array_pushl(&gpg.args,
-			 gpg_program,
+			 use_format->program,
 			 "--status-fd=2",
 			 "-bsau", signing_key,
 			 NULL);
@@ -195,46 +400,3 @@ int sign_buffer(struct strbuf *buffer, s
 
 	return 0;
 }
-
-int verify_signed_buffer(const char *payload, size_t payload_size,
-			 const char *signature, size_t signature_size,
-			 struct strbuf *gpg_output, struct strbuf *gpg_status)
-{
-	struct child_process gpg = CHILD_PROCESS_INIT;
-	struct tempfile *temp;
-	int ret;
-	struct strbuf buf = STRBUF_INIT;
-
-	temp = mks_tempfile_t(".git_vtag_tmpXXXXXX");
-	if (!temp)
-		return error_errno(_("could not create temporary file"));
-	if (write_in_full(temp->fd, signature, signature_size) < 0 ||
-	    close_tempfile_gently(temp) < 0) {
-		error_errno(_("failed writing detached signature to '%s'"),
-			    temp->filename.buf);
-		delete_tempfile(&temp);
-		return -1;
-	}
-
-	argv_array_pushl(&gpg.args,
-			 gpg_program,
-			 "--status-fd=1",
-			 "--keyid-format=long",
-			 "--verify", temp->filename.buf, "-",
-			 NULL);
-
-	if (!gpg_status)
-		gpg_status = &buf;
-
-	sigchain_push(SIGPIPE, SIG_IGN);
-	ret = pipe_command(&gpg, payload, payload_size,
-			   gpg_status, 0, gpg_output, 0);
-	sigchain_pop(SIGPIPE);
-
-	delete_tempfile(&temp);
-
-	ret |= !strstr(gpg_status->buf, "\n[GNUPG:] GOODSIG ");
-	strbuf_release(&buf); /* no matter it was used or not */
-
-	return ret;
-}
diff -pruN 1.2.1+git2.18.0-1/git/gpg-interface.h 1.2.3+git2.25.1-1/git/gpg-interface.h
--- 1.2.1+git2.18.0-1/git/gpg-interface.h	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/gpg-interface.h	2020-02-17 04:47:35.000000000 +0000
@@ -1,6 +1,8 @@
 #ifndef GPG_INTERFACE_H
 #define GPG_INTERFACE_H
 
+struct strbuf;
+
 #define GPG_VERIFY_VERBOSE		1
 #define GPG_VERIFY_RAW			2
 #define GPG_VERIFY_OMIT_STATUS	4
@@ -21,6 +23,8 @@ struct signature_check {
 	char result;
 	char *signer;
 	char *key;
+	char *fingerprint;
+	char *primary_key_fingerprint;
 };
 
 void signature_check_clear(struct signature_check *sigc);
@@ -33,8 +37,6 @@ void signature_check_clear(struct signat
  */
 size_t parse_signature(const char *buf, size_t size);
 
-void parse_gpg_output(struct signature_check *);
-
 /*
  * Create a detached signature for the contents of "buffer" and append
  * it after "signature"; "buffer" and "signature" can be the same
@@ -44,15 +46,6 @@ void parse_gpg_output(struct signature_c
 int sign_buffer(struct strbuf *buffer, struct strbuf *signature,
 		const char *signing_key);
 
-/*
- * Run "gpg" to see if the payload matches the detached signature.
- * gpg_output, when set, receives the diagnostic output from GPG.
- * gpg_status, when set, receives the status output from GPG.
- */
-int verify_signed_buffer(const char *payload, size_t payload_size,
-			 const char *signature, size_t signature_size,
-			 struct strbuf *gpg_output, struct strbuf *gpg_status);
-
 int git_gpg_config(const char *, const char *, void *);
 void set_signing_key(const char *);
 const char *get_signing_key(void);
diff -pruN 1.2.1+git2.18.0-1/git/graph.c 1.2.3+git2.25.1-1/git/graph.c
--- 1.2.1+git2.18.0-1/git/graph.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/graph.c	2020-02-17 04:47:35.000000000 +0000
@@ -34,6 +34,7 @@ static void graph_padding_line(struct gi
  * handle directly. It is assumed that this is the same file handle as the
  * file specified by the graph diff options. This is necessary so that
  * graph_show_strbuf can be called even with a NULL graph.
+ * If a NULL graph is supplied, the strbuf is printed as-is.
  */
 static void graph_show_strbuf(struct git_graph *graph,
 			      FILE *file,
@@ -112,14 +113,42 @@ static const char *column_get_color_code
 	return column_colors[color];
 }
 
-static void strbuf_write_column(struct strbuf *sb, const struct column *c,
-				char col_char)
+struct graph_line {
+	struct strbuf *buf;
+	size_t width;
+};
+
+static inline void graph_line_addch(struct graph_line *line, int c)
+{
+	strbuf_addch(line->buf, c);
+	line->width++;
+}
+
+static inline void graph_line_addchars(struct graph_line *line, int c, size_t n)
+{
+	strbuf_addchars(line->buf, c, n);
+	line->width += n;
+}
+
+static inline void graph_line_addstr(struct graph_line *line, const char *s)
+{
+	strbuf_addstr(line->buf, s);
+	line->width += strlen(s);
+}
+
+static inline void graph_line_addcolor(struct graph_line *line, unsigned short color)
+{
+	strbuf_addstr(line->buf, column_get_color_code(color));
+}
+
+static void graph_line_write_column(struct graph_line *line, const struct column *c,
+				    char col_char)
 {
 	if (c->color < column_colors_max)
-		strbuf_addstr(sb, column_get_color_code(c->color));
-	strbuf_addch(sb, col_char);
+		graph_line_addcolor(line, c->color);
+	graph_line_addch(line, col_char);
 	if (c->color < column_colors_max)
-		strbuf_addstr(sb, column_get_color_code(column_colors_max));
+		graph_line_addcolor(line, column_colors_max);
 }
 
 struct git_graph {
@@ -175,9 +204,63 @@ struct git_graph {
 	 */
 	int prev_commit_index;
 	/*
+	 * Which layout variant to use to display merge commits. If the
+	 * commit's first parent is known to be in a column to the left of the
+	 * merge, then this value is 0 and we use the layout on the left.
+	 * Otherwise, the value is 1 and the layout on the right is used. This
+	 * field tells us how many columns the first parent occupies.
+	 *
+	 * 		0)			1)
+	 *
+	 * 		| | | *-.		| | *---.
+	 * 		| |_|/|\ \		| | |\ \ \
+	 * 		|/| | | | |		| | | | | *
+	 */
+	int merge_layout;
+	/*
+	 * The number of columns added to the graph by the current commit. For
+	 * 2-way and octopus merges, this is usually one less than the
+	 * number of parents:
+	 *
+	 * 		| | |			| |    \
+	 *		| * |			| *---. \
+	 *		| |\ \			| |\ \ \ \
+	 *		| | | |         	| | | | | |
+	 *
+	 *		num_parents: 2		num_parents: 4
+	 *		edges_added: 1		edges_added: 3
+	 *
+	 * For left-skewed merges, the first parent fuses with its neighbor and
+	 * so one less column is added:
+	 *
+	 *		| | |			| |  \
+	 *		| * |			| *-. \
+	 *		|/| |			|/|\ \ \
+	 *		| | |			| | | | |
+	 *
+	 *		num_parents: 2		num_parents: 4
+	 *		edges_added: 0		edges_added: 2
+	 *
+	 * This number determines how edges to the right of the merge are
+	 * displayed in commit and post-merge lines; if no columns have been
+	 * added then a vertical line should be used where a right-tracking
+	 * line would otherwise be used.
+	 *
+	 *		| * \			| * |
+	 *		| |\ \			|/| |
+	 *		| | * \			| * |
+	 */
+	int edges_added;
+	/*
+	 * The number of columns added by the previous commit, which is used to
+	 * smooth edges appearing to the right of a commit in a commit line
+	 * following a post-merge line.
+	 */
+	int prev_edges_added;
+	/*
 	 * The maximum number of columns that can be stored in the columns
 	 * and new_columns arrays.  This is also half the number of entries
-	 * that can be stored in the mapping and new_mapping arrays.
+	 * that can be stored in the mapping and old_mapping arrays.
 	 */
 	int column_capacity;
 	/*
@@ -215,12 +298,12 @@ struct git_graph {
 	 */
 	int *mapping;
 	/*
-	 * A temporary array for computing the next mapping state
-	 * while we are outputting a mapping line.  This is stored as part
-	 * of the git_graph simply so we don't have to allocate a new
-	 * temporary array each time we have to output a collapsing line.
+	 * A copy of the contents of the mapping array from the last commit,
+	 * which we use to improve the display of columns that are tracking
+	 * from right to left through a commit line.  We also use this to
+	 * avoid allocating a fresh array when we compute the next mapping.
 	 */
-	int *new_mapping;
+	int *old_mapping;
 	/*
 	 * The current default column color being used.  This is
 	 * stored as an index into the array column_colors.
@@ -285,6 +368,9 @@ struct git_graph *graph_init(struct rev_
 	graph->prev_state = GRAPH_PADDING;
 	graph->commit_index = 0;
 	graph->prev_commit_index = 0;
+	graph->merge_layout = 0;
+	graph->edges_added = 0;
+	graph->prev_edges_added = 0;
 	graph->num_columns = 0;
 	graph->num_new_columns = 0;
 	graph->mapping_size = 0;
@@ -303,7 +389,7 @@ struct git_graph *graph_init(struct rev_
 	ALLOC_ARRAY(graph->columns, graph->column_capacity);
 	ALLOC_ARRAY(graph->new_columns, graph->column_capacity);
 	ALLOC_ARRAY(graph->mapping, 2 * graph->column_capacity);
-	ALLOC_ARRAY(graph->new_mapping, 2 * graph->column_capacity);
+	ALLOC_ARRAY(graph->old_mapping, 2 * graph->column_capacity);
 
 	/*
 	 * The diff output prefix callback, with this we can make
@@ -333,7 +419,7 @@ static void graph_ensure_capacity(struct
 	REALLOC_ARRAY(graph->columns, graph->column_capacity);
 	REALLOC_ARRAY(graph->new_columns, graph->column_capacity);
 	REALLOC_ARRAY(graph->mapping, graph->column_capacity * 2);
-	REALLOC_ARRAY(graph->new_mapping, graph->column_capacity * 2);
+	REALLOC_ARRAY(graph->old_mapping, graph->column_capacity * 2);
 }
 
 /*
@@ -432,74 +518,76 @@ static unsigned short graph_find_commit_
 	return graph_get_current_column_color(graph);
 }
 
-static void graph_insert_into_new_columns(struct git_graph *graph,
-					  struct commit *commit,
-					  int *mapping_index)
+static int graph_find_new_column_by_commit(struct git_graph *graph,
+					   struct commit *commit)
 {
 	int i;
-
-	/*
-	 * If the commit is already in the new_columns list, we don't need to
-	 * add it.  Just update the mapping correctly.
-	 */
 	for (i = 0; i < graph->num_new_columns; i++) {
-		if (graph->new_columns[i].commit == commit) {
-			graph->mapping[*mapping_index] = i;
-			*mapping_index += 2;
-			return;
-		}
+		if (graph->new_columns[i].commit == commit)
+			return i;
 	}
-
-	/*
-	 * This commit isn't already in new_columns.  Add it.
-	 */
-	graph->new_columns[graph->num_new_columns].commit = commit;
-	graph->new_columns[graph->num_new_columns].color = graph_find_commit_color(graph, commit);
-	graph->mapping[*mapping_index] = graph->num_new_columns;
-	*mapping_index += 2;
-	graph->num_new_columns++;
+	return -1;
 }
 
-static void graph_update_width(struct git_graph *graph,
-			       int is_commit_in_existing_columns)
+static void graph_insert_into_new_columns(struct git_graph *graph,
+					  struct commit *commit,
+					  int idx)
 {
-	/*
-	 * Compute the width needed to display the graph for this commit.
-	 * This is the maximum width needed for any row.  All other rows
-	 * will be padded to this width.
-	 *
-	 * Compute the number of columns in the widest row:
-	 * Count each existing column (graph->num_columns), and each new
-	 * column added by this commit.
-	 */
-	int max_cols = graph->num_columns + graph->num_parents;
+	int i = graph_find_new_column_by_commit(graph, commit);
+	int mapping_idx;
 
 	/*
-	 * Even if the current commit has no parents to be printed, it
-	 * still takes up a column for itself.
+	 * If the commit is not already in the new_columns array, then add it
+	 * and record it as being in the final column.
 	 */
-	if (graph->num_parents < 1)
-		max_cols++;
+	if (i < 0) {
+		i = graph->num_new_columns++;
+		graph->new_columns[i].commit = commit;
+		graph->new_columns[i].color = graph_find_commit_color(graph, commit);
+	}
 
-	/*
-	 * We added a column for the current commit as part of
-	 * graph->num_parents.  If the current commit was already in
-	 * graph->columns, then we have double counted it.
-	 */
-	if (is_commit_in_existing_columns)
-		max_cols--;
+	if (graph->num_parents > 1 && idx > -1 && graph->merge_layout == -1) {
+		/*
+		 * If this is the first parent of a merge, choose a layout for
+		 * the merge line based on whether the parent appears in a
+		 * column to the left of the merge
+		 */
+		int dist, shift;
 
-	/*
-	 * Each column takes up 2 spaces
-	 */
-	graph->width = max_cols * 2;
+		dist = idx - i;
+		shift = (dist > 1) ? 2 * dist - 3 : 1;
+
+		graph->merge_layout = (dist > 0) ? 0 : 1;
+		graph->edges_added = graph->num_parents + graph->merge_layout  - 2;
+
+		mapping_idx = graph->width + (graph->merge_layout - 1) * shift;
+		graph->width += 2 * graph->merge_layout;
+
+	} else if (graph->edges_added > 0 && i == graph->mapping[graph->width - 2]) {
+		/*
+		 * If some columns have been added by a merge, but this commit
+		 * was found in the last existing column, then adjust the
+		 * numbers so that the two edges immediately join, i.e.:
+		 *
+		 *		* |		* |
+		 *		|\ \	=>	|\|
+		 *		| |/		| *
+		 *		| *
+		 */
+		mapping_idx = graph->width - 2;
+		graph->edges_added = -1;
+	} else {
+		mapping_idx = graph->width;
+		graph->width += 2;
+	}
+
+	graph->mapping[mapping_idx] = i;
 }
 
 static void graph_update_columns(struct git_graph *graph)
 {
 	struct commit_list *parent;
 	int max_new_columns;
-	int mapping_idx;
 	int i, seen_this, is_commit_in_columns;
 
 	/*
@@ -532,6 +620,10 @@ static void graph_update_columns(struct
 	for (i = 0; i < graph->mapping_size; i++)
 		graph->mapping[i] = -1;
 
+	graph->width = 0;
+	graph->prev_edges_added = graph->edges_added;
+	graph->edges_added = 0;
+
 	/*
 	 * Populate graph->new_columns and graph->mapping
 	 *
@@ -542,7 +634,6 @@ static void graph_update_columns(struct
 	 * supposed to end up after the collapsing is performed.
 	 */
 	seen_this = 0;
-	mapping_idx = 0;
 	is_commit_in_columns = 1;
 	for (i = 0; i <= graph->num_columns; i++) {
 		struct commit *col_commit;
@@ -556,9 +647,9 @@ static void graph_update_columns(struct
 		}
 
 		if (col_commit == graph->commit) {
-			int old_mapping_idx = mapping_idx;
 			seen_this = 1;
 			graph->commit_index = i;
+			graph->merge_layout = -1;
 			for (parent = first_interesting_parent(graph);
 			     parent;
 			     parent = next_interesting_parent(graph, parent)) {
@@ -571,21 +662,18 @@ static void graph_update_columns(struct
 				    !is_commit_in_columns) {
 					graph_increment_column_color(graph);
 				}
-				graph_insert_into_new_columns(graph,
-							      parent->item,
-							      &mapping_idx);
+				graph_insert_into_new_columns(graph, parent->item, i);
 			}
 			/*
-			 * We always need to increment mapping_idx by at
+			 * We always need to increment graph->width by at
 			 * least 2, even if it has no interesting parents.
 			 * The current commit always takes up at least 2
 			 * spaces.
 			 */
-			if (mapping_idx == old_mapping_idx)
-				mapping_idx += 2;
+			if (graph->num_parents == 0)
+				graph->width += 2;
 		} else {
-			graph_insert_into_new_columns(graph, col_commit,
-						      &mapping_idx);
+			graph_insert_into_new_columns(graph, col_commit, -1);
 		}
 	}
 
@@ -595,11 +683,43 @@ static void graph_update_columns(struct
 	while (graph->mapping_size > 1 &&
 	       graph->mapping[graph->mapping_size - 1] < 0)
 		graph->mapping_size--;
+}
 
+static int graph_num_dashed_parents(struct git_graph *graph)
+{
+	return graph->num_parents + graph->merge_layout - 3;
+}
+
+static int graph_num_expansion_rows(struct git_graph *graph)
+{
 	/*
-	 * Compute graph->width for this commit
+	 * Normally, we need two expansion rows for each dashed parent line from
+	 * an octopus merge:
+	 *
+	 * 		| *
+	 * 		| |\
+	 * 		| | \
+	 * 		| |  \
+	 * 		| *-. \
+	 * 		| |\ \ \
+	 *
+	 * If the merge is skewed to the left, then its parents occupy one less
+	 * column, and we don't need as many expansion rows to route around it;
+	 * in some cases that means we don't need any expansion rows at all:
+	 *
+	 * 		| *
+	 * 		| |\
+	 * 		| * \
+	 * 		|/|\ \
 	 */
-	graph_update_width(graph, is_commit_in_columns);
+	return graph_num_dashed_parents(graph) * 2;
+}
+
+static int graph_needs_pre_commit_line(struct git_graph *graph)
+{
+	return graph->num_parents >= 3 &&
+	       graph->commit_index < (graph->num_columns - 1) &&
+	       graph->expansion_row < graph_num_expansion_rows(graph);
 }
 
 void graph_update(struct git_graph *graph, struct commit *commit)
@@ -657,8 +777,7 @@ void graph_update(struct git_graph *grap
 	 */
 	if (graph->state != GRAPH_PADDING)
 		graph->state = GRAPH_SKIP;
-	else if (graph->num_parents >= 3 &&
-		 graph->commit_index < (graph->num_columns - 1))
+	else if (graph_needs_pre_commit_line(graph))
 		graph->state = GRAPH_PRE_COMMIT;
 	else
 		graph->state = GRAPH_COMMIT;
@@ -686,8 +805,7 @@ static int graph_is_mapping_correct(stru
 	return 1;
 }
 
-static void graph_pad_horizontally(struct git_graph *graph, struct strbuf *sb,
-				   int chars_written)
+static void graph_pad_horizontally(struct git_graph *graph, struct graph_line *line)
 {
 	/*
 	 * Add additional spaces to the end of the strbuf, so that all
@@ -696,34 +814,22 @@ static void graph_pad_horizontally(struc
 	 * This way, fields printed to the right of the graph will remain
 	 * aligned for the entire commit.
 	 */
-	if (chars_written < graph->width)
-		strbuf_addchars(sb, ' ', graph->width - chars_written);
+	if (line->width < graph->width)
+		graph_line_addchars(line, ' ', graph->width - line->width);
 }
 
 static void graph_output_padding_line(struct git_graph *graph,
-				      struct strbuf *sb)
+				      struct graph_line *line)
 {
 	int i;
 
 	/*
-	 * We could conceivable be called with a NULL commit
-	 * if our caller has a bug, and invokes graph_next_line()
-	 * immediately after graph_init(), without first calling
-	 * graph_update().  Return without outputting anything in this
-	 * case.
-	 */
-	if (!graph->commit)
-		return;
-
-	/*
 	 * Output a padding row, that leaves all branch lines unchanged
 	 */
 	for (i = 0; i < graph->num_new_columns; i++) {
-		strbuf_write_column(sb, &graph->new_columns[i], '|');
-		strbuf_addch(sb, ' ');
+		graph_line_write_column(line, &graph->new_columns[i], '|');
+		graph_line_addch(line, ' ');
 	}
-
-	graph_pad_horizontally(graph, sb, graph->num_new_columns * 2);
 }
 
 
@@ -733,28 +839,24 @@ int graph_width(struct git_graph *graph)
 }
 
 
-static void graph_output_skip_line(struct git_graph *graph, struct strbuf *sb)
+static void graph_output_skip_line(struct git_graph *graph, struct graph_line *line)
 {
 	/*
 	 * Output an ellipsis to indicate that a portion
 	 * of the graph is missing.
 	 */
-	strbuf_addstr(sb, "...");
-	graph_pad_horizontally(graph, sb, 3);
+	graph_line_addstr(line, "...");
 
-	if (graph->num_parents >= 3 &&
-	    graph->commit_index < (graph->num_columns - 1))
+	if (graph_needs_pre_commit_line(graph))
 		graph_update_state(graph, GRAPH_PRE_COMMIT);
 	else
 		graph_update_state(graph, GRAPH_COMMIT);
 }
 
 static void graph_output_pre_commit_line(struct git_graph *graph,
-					 struct strbuf *sb)
+					 struct graph_line *line)
 {
-	int num_expansion_rows;
 	int i, seen_this;
-	int chars_written;
 
 	/*
 	 * This function formats a row that increases the space around a commit
@@ -764,27 +866,24 @@ static void graph_output_pre_commit_line
 	 * We need 2 extra rows for every parent over 2.
 	 */
 	assert(graph->num_parents >= 3);
-	num_expansion_rows = (graph->num_parents - 2) * 2;
 
 	/*
 	 * graph->expansion_row tracks the current expansion row we are on.
 	 * It should be in the range [0, num_expansion_rows - 1]
 	 */
 	assert(0 <= graph->expansion_row &&
-	       graph->expansion_row < num_expansion_rows);
+	       graph->expansion_row < graph_num_expansion_rows(graph));
 
 	/*
 	 * Output the row
 	 */
 	seen_this = 0;
-	chars_written = 0;
 	for (i = 0; i < graph->num_columns; i++) {
 		struct column *col = &graph->columns[i];
 		if (col->commit == graph->commit) {
 			seen_this = 1;
-			strbuf_write_column(sb, col, '|');
-			strbuf_addchars(sb, ' ', graph->expansion_row);
-			chars_written += 1 + graph->expansion_row;
+			graph_line_write_column(line, col, '|');
+			graph_line_addchars(line, ' ', graph->expansion_row);
 		} else if (seen_this && (graph->expansion_row == 0)) {
 			/*
 			 * This is the first line of the pre-commit output.
@@ -797,33 +896,27 @@ static void graph_output_pre_commit_line
 			 */
 			if (graph->prev_state == GRAPH_POST_MERGE &&
 			    graph->prev_commit_index < i)
-				strbuf_write_column(sb, col, '\\');
+				graph_line_write_column(line, col, '\\');
 			else
-				strbuf_write_column(sb, col, '|');
-			chars_written++;
+				graph_line_write_column(line, col, '|');
 		} else if (seen_this && (graph->expansion_row > 0)) {
-			strbuf_write_column(sb, col, '\\');
-			chars_written++;
+			graph_line_write_column(line, col, '\\');
 		} else {
-			strbuf_write_column(sb, col, '|');
-			chars_written++;
+			graph_line_write_column(line, col, '|');
 		}
-		strbuf_addch(sb, ' ');
-		chars_written++;
+		graph_line_addch(line, ' ');
 	}
 
-	graph_pad_horizontally(graph, sb, chars_written);
-
 	/*
 	 * Increment graph->expansion_row,
 	 * and move to state GRAPH_COMMIT if necessary
 	 */
 	graph->expansion_row++;
-	if (graph->expansion_row >= num_expansion_rows)
+	if (!graph_needs_pre_commit_line(graph))
 		graph_update_state(graph, GRAPH_COMMIT);
 }
 
-static void graph_output_commit_char(struct git_graph *graph, struct strbuf *sb)
+static void graph_output_commit_char(struct git_graph *graph, struct graph_line *line)
 {
 	/*
 	 * For boundary commits, print 'o'
@@ -831,44 +924,67 @@ static void graph_output_commit_char(str
 	 */
 	if (graph->commit->object.flags & BOUNDARY) {
 		assert(graph->revs->boundary);
-		strbuf_addch(sb, 'o');
+		graph_line_addch(line, 'o');
 		return;
 	}
 
 	/*
 	 * get_revision_mark() handles all other cases without assert()
 	 */
-	strbuf_addstr(sb, get_revision_mark(graph->revs, graph->commit));
+	graph_line_addstr(line, get_revision_mark(graph->revs, graph->commit));
 }
 
 /*
- * Draw an octopus merge and return the number of characters written.
+ * Draw the horizontal dashes of an octopus merge.
  */
-static int graph_draw_octopus_merge(struct git_graph *graph,
-				    struct strbuf *sb)
+static void graph_draw_octopus_merge(struct git_graph *graph, struct graph_line *line)
 {
 	/*
-	 * Here dashless_commits represents the number of parents
-	 * which don't need to have dashes (because their edges fit
-	 * neatly under the commit).
+	 * The parents of a merge commit can be arbitrarily reordered as they
+	 * are mapped onto display columns, for example this is a valid merge:
+	 *
+	 *	| | *---.
+	 *	| | |\ \ \
+	 *	| | |/ / /
+	 *	| |/| | /
+	 *	| |_|_|/
+	 *	|/| | |
+	 *	3 1 0 2
+	 *
+	 * The numbers denote which parent of the merge each visual column
+	 * corresponds to; we can't assume that the parents will initially
+	 * display in the order given by new_columns.
+	 *
+	 * To find the right color for each dash, we need to consult the
+	 * mapping array, starting from the column 2 places to the right of the
+	 * merge commit, and use that to find out which logical column each
+	 * edge will collapse to.
+	 *
+	 * Commits are rendered once all edges have collapsed to their correct
+	 * logcial column, so commit_index gives us the right visual offset for
+	 * the merge commit.
 	 */
-	const int dashless_commits = 2;
-	int col_num, i;
-	int num_dashes =
-		((graph->num_parents - dashless_commits) * 2) - 1;
-	for (i = 0; i < num_dashes; i++) {
-		col_num = (i / 2) + dashless_commits + graph->commit_index;
-		strbuf_write_column(sb, &graph->new_columns[col_num], '-');
+
+	int i, j;
+	struct column *col;
+
+	int dashed_parents = graph_num_dashed_parents(graph);
+
+	for (i = 0; i < dashed_parents; i++) {
+		j = graph->mapping[(graph->commit_index + i + 2) * 2];
+		col = &graph->new_columns[j];
+
+		graph_line_write_column(line, col, '-');
+		graph_line_write_column(line, col, (i == dashed_parents - 1) ? '.' : '-');
 	}
-	col_num = (i / 2) + dashless_commits + graph->commit_index;
-	strbuf_write_column(sb, &graph->new_columns[col_num], '.');
-	return num_dashes + 1;
+
+	return;
 }
 
-static void graph_output_commit_line(struct git_graph *graph, struct strbuf *sb)
+static void graph_output_commit_line(struct git_graph *graph, struct graph_line *line)
 {
 	int seen_this = 0;
-	int i, chars_written;
+	int i;
 
 	/*
 	 * Output the row containing this commit
@@ -878,7 +994,6 @@ static void graph_output_commit_line(str
 	 * children that we have already processed.)
 	 */
 	seen_this = 0;
-	chars_written = 0;
 	for (i = 0; i <= graph->num_columns; i++) {
 		struct column *col = &graph->columns[i];
 		struct commit *col_commit;
@@ -892,19 +1007,17 @@ static void graph_output_commit_line(str
 
 		if (col_commit == graph->commit) {
 			seen_this = 1;
-			graph_output_commit_char(graph, sb);
-			chars_written++;
+			graph_output_commit_char(graph, line);
 
 			if (graph->num_parents > 2)
-				chars_written += graph_draw_octopus_merge(graph,
-									  sb);
-		} else if (seen_this && (graph->num_parents > 2)) {
-			strbuf_write_column(sb, col, '\\');
-			chars_written++;
-		} else if (seen_this && (graph->num_parents == 2)) {
+				graph_draw_octopus_merge(graph, line);
+		} else if (seen_this && (graph->edges_added > 1)) {
+			graph_line_write_column(line, col, '\\');
+		} else if (seen_this && (graph->edges_added == 1)) {
 			/*
-			 * This is a 2-way merge commit.
-			 * There is no GRAPH_PRE_COMMIT stage for 2-way
+			 * This is either a right-skewed 2-way merge
+			 * commit, or a left-skewed 3-way merge.
+			 * There is no GRAPH_PRE_COMMIT stage for such
 			 * merges, so this is the first line of output
 			 * for this commit.  Check to see what the previous
 			 * line of output was.
@@ -916,21 +1029,21 @@ static void graph_output_commit_line(str
 			 * makes the output look nicer.
 			 */
 			if (graph->prev_state == GRAPH_POST_MERGE &&
+			    graph->prev_edges_added > 0 &&
 			    graph->prev_commit_index < i)
-				strbuf_write_column(sb, col, '\\');
+				graph_line_write_column(line, col, '\\');
 			else
-				strbuf_write_column(sb, col, '|');
-			chars_written++;
+				graph_line_write_column(line, col, '|');
+		} else if (graph->prev_state == GRAPH_COLLAPSING &&
+			   graph->old_mapping[2 * i + 1] == i &&
+			   graph->mapping[2 * i] < i) {
+			graph_line_write_column(line, col, '/');
 		} else {
-			strbuf_write_column(sb, col, '|');
-			chars_written++;
+			graph_line_write_column(line, col, '|');
 		}
-		strbuf_addch(sb, ' ');
-		chars_written++;
+		graph_line_addch(line, ' ');
 	}
 
-	graph_pad_horizontally(graph, sb, chars_written);
-
 	/*
 	 * Update graph->state
 	 */
@@ -942,26 +1055,19 @@ static void graph_output_commit_line(str
 		graph_update_state(graph, GRAPH_COLLAPSING);
 }
 
-static struct column *find_new_column_by_commit(struct git_graph *graph,
-						struct commit *commit)
-{
-	int i;
-	for (i = 0; i < graph->num_new_columns; i++) {
-		if (graph->new_columns[i].commit == commit)
-			return &graph->new_columns[i];
-	}
-	return NULL;
-}
+const char merge_chars[] = {'/', '|', '\\'};
 
-static void graph_output_post_merge_line(struct git_graph *graph, struct strbuf *sb)
+static void graph_output_post_merge_line(struct git_graph *graph, struct graph_line *line)
 {
 	int seen_this = 0;
-	int i, j, chars_written;
+	int i, j;
+
+	struct commit_list *first_parent = first_interesting_parent(graph);
+	struct column *parent_col = NULL;
 
 	/*
 	 * Output the post-merge row
 	 */
-	chars_written = 0;
 	for (i = 0; i <= graph->num_columns; i++) {
 		struct column *col = &graph->columns[i];
 		struct commit *col_commit;
@@ -980,37 +1086,49 @@ static void graph_output_post_merge_line
 			 * new_columns and use those to format the
 			 * edges.
 			 */
-			struct commit_list *parents = NULL;
-			struct column *par_column;
+			struct commit_list *parents = first_parent;
+			int par_column;
+			int idx = graph->merge_layout;
+			char c;
 			seen_this = 1;
-			parents = first_interesting_parent(graph);
-			assert(parents);
-			par_column = find_new_column_by_commit(graph, parents->item);
-			assert(par_column);
-
-			strbuf_write_column(sb, par_column, '|');
-			chars_written++;
-			for (j = 0; j < graph->num_parents - 1; j++) {
+
+			for (j = 0; j < graph->num_parents; j++) {
+				par_column = graph_find_new_column_by_commit(graph, parents->item);
+				assert(par_column >= 0);
+
+				c = merge_chars[idx];
+				graph_line_write_column(line, &graph->new_columns[par_column], c);
+				if (idx == 2) {
+					if (graph->edges_added > 0 || j < graph->num_parents - 1)
+						graph_line_addch(line, ' ');
+				} else {
+					idx++;
+				}
 				parents = next_interesting_parent(graph, parents);
-				assert(parents);
-				par_column = find_new_column_by_commit(graph, parents->item);
-				assert(par_column);
-				strbuf_write_column(sb, par_column, '\\');
-				strbuf_addch(sb, ' ');
 			}
-			chars_written += j * 2;
+			if (graph->edges_added == 0)
+				graph_line_addch(line, ' ');
+
 		} else if (seen_this) {
-			strbuf_write_column(sb, col, '\\');
-			strbuf_addch(sb, ' ');
-			chars_written += 2;
+			if (graph->edges_added > 0)
+				graph_line_write_column(line, col, '\\');
+			else
+				graph_line_write_column(line, col, '|');
+			graph_line_addch(line, ' ');
 		} else {
-			strbuf_write_column(sb, col, '|');
-			strbuf_addch(sb, ' ');
-			chars_written += 2;
+			graph_line_write_column(line, col, '|');
+			if (graph->merge_layout != 0 || i != graph->commit_index - 1) {
+				if (parent_col)
+					graph_line_write_column(
+						line, parent_col, '_');
+				else
+					graph_line_addch(line, ' ');
+			}
 		}
-	}
 
-	graph_pad_horizontally(graph, sb, chars_written);
+		if (col_commit == first_parent->item)
+			parent_col = col;
+	}
 
 	/*
 	 * Update graph->state
@@ -1021,7 +1139,7 @@ static void graph_output_post_merge_line
 		graph_update_state(graph, GRAPH_COLLAPSING);
 }
 
-static void graph_output_collapsing_line(struct git_graph *graph, struct strbuf *sb)
+static void graph_output_collapsing_line(struct git_graph *graph, struct graph_line *line)
 {
 	int i;
 	short used_horizontal = 0;
@@ -1029,13 +1147,18 @@ static void graph_output_collapsing_line
 	int horizontal_edge_target = -1;
 
 	/*
-	 * Clear out the new_mapping array
+	 * Swap the mapping and old_mapping arrays
+	 */
+	SWAP(graph->mapping, graph->old_mapping);
+
+	/*
+	 * Clear out the mapping array
 	 */
 	for (i = 0; i < graph->mapping_size; i++)
-		graph->new_mapping[i] = -1;
+		graph->mapping[i] = -1;
 
 	for (i = 0; i < graph->mapping_size; i++) {
-		int target = graph->mapping[i];
+		int target = graph->old_mapping[i];
 		if (target < 0)
 			continue;
 
@@ -1056,14 +1179,14 @@ static void graph_output_collapsing_line
 			 * This column is already in the
 			 * correct place
 			 */
-			assert(graph->new_mapping[i] == -1);
-			graph->new_mapping[i] = target;
-		} else if (graph->new_mapping[i - 1] < 0) {
+			assert(graph->mapping[i] == -1);
+			graph->mapping[i] = target;
+		} else if (graph->mapping[i - 1] < 0) {
 			/*
 			 * Nothing is to the left.
 			 * Move to the left by one
 			 */
-			graph->new_mapping[i - 1] = target;
+			graph->mapping[i - 1] = target;
 			/*
 			 * If there isn't already an edge moving horizontally
 			 * select this one.
@@ -1079,9 +1202,9 @@ static void graph_output_collapsing_line
 				 * line.
 				 */
 				for (j = (target * 2)+3; j < (i - 2); j += 2)
-					graph->new_mapping[j] = target;
+					graph->mapping[j] = target;
 			}
-		} else if (graph->new_mapping[i - 1] == target) {
+		} else if (graph->mapping[i - 1] == target) {
 			/*
 			 * There is a branch line to our left
 			 * already, and it is our target.  We
@@ -1089,7 +1212,7 @@ static void graph_output_collapsing_line
 			 * the same parent commit.
 			 *
 			 * We don't have to add anything to the
-			 * output or new_mapping, since the
+			 * output or mapping, since the
 			 * existing branch line has already taken
 			 * care of it.
 			 */
@@ -1101,14 +1224,10 @@ static void graph_output_collapsing_line
 			 *
 			 * The space just to the left of this
 			 * branch should always be empty.
-			 *
-			 * The branch to the left of that space
-			 * should be our eventual target.
 			 */
-			assert(graph->new_mapping[i - 1] > target);
-			assert(graph->new_mapping[i - 2] < 0);
-			assert(graph->new_mapping[i - 3] == target);
-			graph->new_mapping[i - 2] = target;
+			assert(graph->mapping[i - 1] > target);
+			assert(graph->mapping[i - 2] < 0);
+			graph->mapping[i - 2] = target;
 			/*
 			 * Mark this branch as the horizontal edge to
 			 * prevent any other edges from moving
@@ -1120,20 +1239,25 @@ static void graph_output_collapsing_line
 	}
 
 	/*
+	 * Copy the current mapping array into old_mapping
+	 */
+	COPY_ARRAY(graph->old_mapping, graph->mapping, graph->mapping_size);
+
+	/*
 	 * The new mapping may be 1 smaller than the old mapping
 	 */
-	if (graph->new_mapping[graph->mapping_size - 1] < 0)
+	if (graph->mapping[graph->mapping_size - 1] < 0)
 		graph->mapping_size--;
 
 	/*
 	 * Output out a line based on the new mapping info
 	 */
 	for (i = 0; i < graph->mapping_size; i++) {
-		int target = graph->new_mapping[i];
+		int target = graph->mapping[i];
 		if (target < 0)
-			strbuf_addch(sb, ' ');
+			graph_line_addch(line, ' ');
 		else if (target * 2 == i)
-			strbuf_write_column(sb, &graph->new_columns[target], '|');
+			graph_line_write_column(line, &graph->new_columns[target], '|');
 		else if (target == horizontal_edge_target &&
 			 i != horizontal_edge - 1) {
 				/*
@@ -1142,24 +1266,17 @@ static void graph_output_collapsing_line
 				 * won't continue into the next line.
 				 */
 				if (i != (target * 2)+3)
-					graph->new_mapping[i] = -1;
+					graph->mapping[i] = -1;
 				used_horizontal = 1;
-			strbuf_write_column(sb, &graph->new_columns[target], '_');
+			graph_line_write_column(line, &graph->new_columns[target], '_');
 		} else {
 			if (used_horizontal && i < horizontal_edge)
-				graph->new_mapping[i] = -1;
-			strbuf_write_column(sb, &graph->new_columns[target], '/');
+				graph->mapping[i] = -1;
+			graph_line_write_column(line, &graph->new_columns[target], '/');
 
 		}
 	}
 
-	graph_pad_horizontally(graph, sb, graph->mapping_size);
-
-	/*
-	 * Swap mapping and new_mapping
-	 */
-	SWAP(graph->mapping, graph->new_mapping);
-
 	/*
 	 * If graph->mapping indicates that all of the branch lines
 	 * are already in the correct positions, we are done.
@@ -1171,35 +1288,49 @@ static void graph_output_collapsing_line
 
 int graph_next_line(struct git_graph *graph, struct strbuf *sb)
 {
+	int shown_commit_line = 0;
+	struct graph_line line = { .buf = sb, .width = 0 };
+
+	/*
+	 * We could conceivable be called with a NULL commit
+	 * if our caller has a bug, and invokes graph_next_line()
+	 * immediately after graph_init(), without first calling
+	 * graph_update().  Return without outputting anything in this
+	 * case.
+	 */
+	if (!graph->commit)
+		return -1;
+
 	switch (graph->state) {
 	case GRAPH_PADDING:
-		graph_output_padding_line(graph, sb);
-		return 0;
+		graph_output_padding_line(graph, &line);
+		break;
 	case GRAPH_SKIP:
-		graph_output_skip_line(graph, sb);
-		return 0;
+		graph_output_skip_line(graph, &line);
+		break;
 	case GRAPH_PRE_COMMIT:
-		graph_output_pre_commit_line(graph, sb);
-		return 0;
+		graph_output_pre_commit_line(graph, &line);
+		break;
 	case GRAPH_COMMIT:
-		graph_output_commit_line(graph, sb);
-		return 1;
+		graph_output_commit_line(graph, &line);
+		shown_commit_line = 1;
+		break;
 	case GRAPH_POST_MERGE:
-		graph_output_post_merge_line(graph, sb);
-		return 0;
+		graph_output_post_merge_line(graph, &line);
+		break;
 	case GRAPH_COLLAPSING:
-		graph_output_collapsing_line(graph, sb);
-		return 0;
+		graph_output_collapsing_line(graph, &line);
+		break;
 	}
 
-	assert(0);
-	return 0;
+	graph_pad_horizontally(graph, &line);
+	return shown_commit_line;
 }
 
 static void graph_padding_line(struct git_graph *graph, struct strbuf *sb)
 {
 	int i;
-	int chars_written = 0;
+	struct graph_line line = { .buf = sb, .width = 0 };
 
 	if (graph->state != GRAPH_COMMIT) {
 		graph_next_line(graph, sb);
@@ -1216,20 +1347,17 @@ static void graph_padding_line(struct gi
 	for (i = 0; i < graph->num_columns; i++) {
 		struct column *col = &graph->columns[i];
 
-		strbuf_write_column(sb, col, '|');
-		chars_written++;
+		graph_line_write_column(&line, col, '|');
 
 		if (col->commit == graph->commit && graph->num_parents > 2) {
 			int len = (graph->num_parents - 2) * 2;
-			strbuf_addchars(sb, ' ', len);
-			chars_written += len;
+			graph_line_addchars(&line, ' ', len);
 		} else {
-			strbuf_addch(sb, ' ');
-			chars_written++;
+			graph_line_addch(&line, ' ');
 		}
 	}
 
-	graph_pad_horizontally(graph, sb, chars_written);
+	graph_pad_horizontally(graph, &line);
 
 	/*
 	 * Update graph->prev_state since we have output a padding line
diff -pruN 1.2.1+git2.18.0-1/git/graph.h 1.2.3+git2.25.1-1/git/graph.h
--- 1.2.1+git2.18.0-1/git/graph.h	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/graph.h	2020-02-17 04:47:35.000000000 +0000
@@ -2,6 +2,103 @@
 #define GRAPH_H
 #include "diff.h"
 
+/**
+ * The graph API is used to draw a text-based representation of the commit
+ * history. The API generates the graph in a line-by-line fashion.
+ *
+ * Calling sequence
+ * ----------------
+ *
+ * - Create a `struct git_graph` by calling `graph_init()`.  When using the
+ *   revision walking API, this is done automatically by `setup_revisions()` if
+ *   the '--graph' option is supplied.
+ *
+ * - Use the revision walking API to walk through a group of contiguous commits.
+ *   The `get_revision()` function automatically calls `graph_update()` each time
+ *   it is invoked.
+ *
+ * - For each commit, call `graph_next_line()` repeatedly, until
+ *   `graph_is_commit_finished()` returns non-zero.  Each call to
+ *   `graph_next_line()` will output a single line of the graph.  The resulting
+ *   lines will not contain any newlines.  `graph_next_line()` returns 1 if the
+ *   resulting line contains the current commit, or 0 if this is merely a line
+ *   needed to adjust the graph before or after the current commit.  This return
+ *   value can be used to determine where to print the commit summary information
+ *   alongside the graph output.
+ *
+ * Limitations
+ * -----------
+ * - Check the graph_update() function for its limitations.
+ *
+ * - The graph API does not currently support reverse commit ordering.  In
+ *   order to implement reverse ordering, the graphing API needs an
+ *   (efficient) mechanism to find the children of a commit.
+ *
+ * Sample usage
+ * ------------
+ *
+ * ------------
+ * struct commit *commit;
+ * struct git_graph *graph = graph_init(opts);
+ *
+ * while ((commit = get_revision(opts)) != NULL) {
+ * 	while (!graph_is_commit_finished(graph))
+ * 	{
+ * 		struct strbuf sb;
+ * 		int is_commit_line;
+ *
+ * 		strbuf_init(&sb, 0);
+ * 		is_commit_line = graph_next_line(graph, &sb);
+ * 		fputs(sb.buf, stdout);
+ *
+ * 		if (is_commit_line)
+ * 			log_tree_commit(opts, commit);
+ * 		else
+ * 			putchar(opts->diffopt.line_termination);
+ * 	}
+ * }
+ * ------------
+ * Sample output
+ * -------------
+ *
+ * The following is an example of the output from the graph API.  This output does
+ * not include any commit summary information--callers are responsible for
+ * outputting that information, if desired.
+ * ------------
+ * *
+ * *
+ * *
+ * |\
+ * * |
+ * | | *
+ * | \ \
+ * |  \ \
+ * *-. \ \
+ * |\ \ \ \
+ * | | * | |
+ * | | | | | *
+ * | | | | | *
+ * | | | | | *
+ * | | | | | |\
+ * | | | | | | *
+ * | * | | | | |
+ * | | | | | *  \
+ * | | | | | |\  |
+ * | | | | * | | |
+ * | | | | * | | |
+ * * | | | | | | |
+ * | |/ / / / / /
+ * |/| / / / / /
+ * * | | | | | |
+ * |/ / / / / /
+ * * | | | | |
+ * | | | | | *
+ * | | | | |/
+ * | | | | *
+ * ------------
+ *
+ */
+
 /* A graph is a pointer to this opaque structure */
 struct git_graph;
 
@@ -50,6 +147,21 @@ struct git_graph *graph_init(struct rev_
  * If graph_update() is called before graph_is_commit_finished() returns 1,
  * the next call to graph_next_line() will output an ellipsis ("...")
  * to indicate that a portion of the graph is missing.
+ *
+ * Limitations:
+ * -----------
+ *
+ * - `graph_update()` must be called with commits in topological order.  It should
+ *   not be called on a commit if it has already been invoked with an ancestor of
+ *   that commit, or the graph output will be incorrect.
+ *
+ * - `graph_update()` must be called on a contiguous group of commits.  If
+ *   `graph_update()` is called on a particular commit, it should later be called
+ *   on all parents of that commit.  Parents must not be skipped, or the graph
+ *   output will appear incorrect.
+ *
+ * - `graph_update()` may be used on a pruned set of commits only if the parent list
+ *   has been rewritten so as to include only ancestors from the pruned set.
  */
 void graph_update(struct git_graph *graph, struct commit *commit);
 
@@ -62,6 +174,10 @@ void graph_update(struct git_graph *grap
  * for this commit.  If 0 is returned, graph_next_line() may still be
  * called without calling graph_update(), and it will merely output
  * appropriate "vertical padding" in the graph.
+ *
+ * If `graph_update()` is called before all lines for the current commit have
+ * been printed, the next call to `graph_next_line()` will output an ellipsis,
+ * to indicate that a portion of the graph was omitted.
  */
 int graph_is_commit_finished(struct git_graph const *graph);
 
@@ -112,6 +228,7 @@ void graph_show_padding(struct git_graph
 /*
  * If the graph is non-NULL, print the rest of the history graph for this
  * commit to stdout.  Does not print a terminating newline on the last line.
+ * Returns 1 if output was printed, and 0 if no output was necessary.
  */
 int graph_show_remainder(struct git_graph *graph);
 
@@ -121,6 +238,10 @@ int graph_show_remainder(struct git_grap
  * This is similar to graph_show_strbuf(), but it always prints the
  * remainder of the graph.
  *
+ * It is better than directly calling `graph_show_strbuf()` followed by
+ * `graph_show_remainder()` since it properly handles buffers that do not end in
+ * a terminating newline.
+ *
  * If the strbuf ends with a newline, the output printed by
  * graph_show_commit_msg() will end with a newline.  If the strbuf is
  * missing a terminating newline (including if it is empty), the output
diff -pruN 1.2.1+git2.18.0-1/git/grep.c 1.2.3+git2.25.1-1/git/grep.c
--- 1.2.1+git2.18.0-1/git/grep.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/grep.c	2020-02-17 04:47:35.000000000 +0000
@@ -1,18 +1,47 @@
 #include "cache.h"
 #include "config.h"
 #include "grep.h"
+#include "object-store.h"
 #include "userdiff.h"
 #include "xdiff-interface.h"
 #include "diff.h"
 #include "diffcore.h"
 #include "commit.h"
 #include "quote.h"
+#include "help.h"
 
 static int grep_source_load(struct grep_source *gs);
-static int grep_source_is_binary(struct grep_source *gs);
+static int grep_source_is_binary(struct grep_source *gs,
+				 struct index_state *istate);
 
 static struct grep_opt grep_defaults;
 
+#ifdef USE_LIBPCRE2
+static pcre2_general_context *pcre2_global_context;
+
+static void *pcre2_malloc(PCRE2_SIZE size, MAYBE_UNUSED void *memory_data)
+{
+	return malloc(size);
+}
+
+static void pcre2_free(void *pointer, MAYBE_UNUSED void *memory_data)
+{
+	free(pointer);
+}
+#endif
+
+static const char *color_grep_slots[] = {
+	[GREP_COLOR_CONTEXT]	    = "context",
+	[GREP_COLOR_FILENAME]	    = "filename",
+	[GREP_COLOR_FUNCTION]	    = "function",
+	[GREP_COLOR_LINENO]	    = "lineNumber",
+	[GREP_COLOR_COLUMNNO]	    = "column",
+	[GREP_COLOR_MATCH_CONTEXT]  = "matchContext",
+	[GREP_COLOR_MATCH_SELECTED] = "matchSelected",
+	[GREP_COLOR_SELECTED]	    = "selected",
+	[GREP_COLOR_SEP]	    = "separator",
+};
+
 static void std_output(struct grep_opt *opt, const void *buf, size_t size)
 {
 	fwrite(buf, size, 1, stdout);
@@ -28,7 +57,7 @@ static void color_set(char *dst, const c
  * We could let the compiler do this, but without C99 initializers
  * the code gets unwieldy and unreadable, so...
  */
-void init_grep_defaults(void)
+void init_grep_defaults(struct repository *repo)
 {
 	struct grep_opt *opt = &grep_defaults;
 	static int run_once;
@@ -38,18 +67,21 @@ void init_grep_defaults(void)
 	run_once++;
 
 	memset(opt, 0, sizeof(*opt));
+	opt->repo = repo;
 	opt->relative = 1;
 	opt->pathname = 1;
 	opt->max_depth = -1;
 	opt->pattern_type_option = GREP_PATTERN_TYPE_UNSPECIFIED;
-	color_set(opt->color_context, "");
-	color_set(opt->color_filename, "");
-	color_set(opt->color_function, "");
-	color_set(opt->color_lineno, "");
-	color_set(opt->color_match_context, GIT_COLOR_BOLD_RED);
-	color_set(opt->color_match_selected, GIT_COLOR_BOLD_RED);
-	color_set(opt->color_selected, "");
-	color_set(opt->color_sep, GIT_COLOR_CYAN);
+	color_set(opt->colors[GREP_COLOR_CONTEXT], "");
+	color_set(opt->colors[GREP_COLOR_FILENAME], "");
+	color_set(opt->colors[GREP_COLOR_FUNCTION], "");
+	color_set(opt->colors[GREP_COLOR_LINENO], "");
+	color_set(opt->colors[GREP_COLOR_COLUMNNO], "");
+	color_set(opt->colors[GREP_COLOR_MATCH_CONTEXT], GIT_COLOR_BOLD_RED);
+	color_set(opt->colors[GREP_COLOR_MATCH_SELECTED], GIT_COLOR_BOLD_RED);
+	color_set(opt->colors[GREP_COLOR_SELECTED], "");
+	color_set(opt->colors[GREP_COLOR_SEP], GIT_COLOR_CYAN);
+	opt->only_matching = 0;
 	opt->color = -1;
 	opt->output = std_output;
 }
@@ -69,6 +101,8 @@ static int parse_pattern_type_arg(const
 	die("bad %s argument: %s", opt, arg);
 }
 
+define_list_config_array_extra(color_grep_slots, {"match"});
+
 /*
  * Read the configuration file once and store it in
  * the grep_defaults template.
@@ -76,7 +110,7 @@ static int parse_pattern_type_arg(const
 int grep_config(const char *var, const char *value, void *cb)
 {
 	struct grep_opt *opt = &grep_defaults;
-	char *color = NULL;
+	const char *slot;
 
 	if (userdiff_config(var, value) < 0)
 		return -1;
@@ -95,6 +129,10 @@ int grep_config(const char *var, const c
 		opt->linenum = git_config_bool(var, value);
 		return 0;
 	}
+	if (!strcmp(var, "grep.column")) {
+		opt->columnnum = git_config_bool(var, value);
+		return 0;
+	}
 
 	if (!strcmp(var, "grep.fullname")) {
 		opt->relative = !git_config_bool(var, value);
@@ -103,32 +141,18 @@ int grep_config(const char *var, const c
 
 	if (!strcmp(var, "color.grep"))
 		opt->color = git_config_colorbool(var, value);
-	else if (!strcmp(var, "color.grep.context"))
-		color = opt->color_context;
-	else if (!strcmp(var, "color.grep.filename"))
-		color = opt->color_filename;
-	else if (!strcmp(var, "color.grep.function"))
-		color = opt->color_function;
-	else if (!strcmp(var, "color.grep.linenumber"))
-		color = opt->color_lineno;
-	else if (!strcmp(var, "color.grep.matchcontext"))
-		color = opt->color_match_context;
-	else if (!strcmp(var, "color.grep.matchselected"))
-		color = opt->color_match_selected;
-	else if (!strcmp(var, "color.grep.selected"))
-		color = opt->color_selected;
-	else if (!strcmp(var, "color.grep.separator"))
-		color = opt->color_sep;
-	else if (!strcmp(var, "color.grep.match")) {
-		int rc = 0;
-		if (!value)
-			return config_error_nonbool(var);
-		rc |= color_parse(value, opt->color_match_context);
-		rc |= color_parse(value, opt->color_match_selected);
-		return rc;
-	}
-
-	if (color) {
+	if (!strcmp(var, "color.grep.match")) {
+		if (grep_config("color.grep.matchcontext", value, cb) < 0)
+			return -1;
+		if (grep_config("color.grep.matchselected", value, cb) < 0)
+			return -1;
+	} else if (skip_prefix(var, "color.grep.", &slot)) {
+		int i = LOOKUP_CONFIG(color_grep_slots, slot);
+		char *color;
+
+		if (i < 0)
+			return -1;
+		color = opt->colors[i];
 		if (!value)
 			return config_error_nonbool(var);
 		return color_parse(value, color);
@@ -140,34 +164,55 @@ int grep_config(const char *var, const c
  * Initialize one instance of grep_opt and copy the
  * default values from the template we read the configuration
  * information in an earlier call to git_config(grep_config).
+ *
+ * If using PCRE, make sure that the library is configured
+ * to use the same allocator as Git (e.g. nedmalloc on Windows).
+ *
+ * Any allocated memory needs to be released in grep_destroy().
  */
-void grep_init(struct grep_opt *opt, const char *prefix)
+void grep_init(struct grep_opt *opt, struct repository *repo, const char *prefix)
 {
 	struct grep_opt *def = &grep_defaults;
+	int i;
+
+#if defined(USE_LIBPCRE2)
+	if (!pcre2_global_context)
+		pcre2_global_context = pcre2_general_context_create(
+					pcre2_malloc, pcre2_free, NULL);
+#endif
+
+#ifdef USE_LIBPCRE1
+	pcre_malloc = malloc;
+	pcre_free = free;
+#endif
 
 	memset(opt, 0, sizeof(*opt));
+	opt->repo = repo;
 	opt->prefix = prefix;
 	opt->prefix_length = (prefix && *prefix) ? strlen(prefix) : 0;
 	opt->pattern_tail = &opt->pattern_list;
 	opt->header_tail = &opt->header_list;
 
+	opt->only_matching = def->only_matching;
 	opt->color = def->color;
 	opt->extended_regexp_option = def->extended_regexp_option;
 	opt->pattern_type_option = def->pattern_type_option;
 	opt->linenum = def->linenum;
+	opt->columnnum = def->columnnum;
 	opt->max_depth = def->max_depth;
 	opt->pathname = def->pathname;
 	opt->relative = def->relative;
 	opt->output = def->output;
 
-	color_set(opt->color_context, def->color_context);
-	color_set(opt->color_filename, def->color_filename);
-	color_set(opt->color_function, def->color_function);
-	color_set(opt->color_lineno, def->color_lineno);
-	color_set(opt->color_match_context, def->color_match_context);
-	color_set(opt->color_match_selected, def->color_match_selected);
-	color_set(opt->color_selected, def->color_selected);
-	color_set(opt->color_sep, def->color_sep);
+	for (i = 0; i < NR_GREP_COLORS; i++)
+		color_set(opt->colors[i], def->colors[i]);
+}
+
+void grep_destroy(void)
+{
+#ifdef USE_LIBPCRE2
+	pcre2_general_context_free(pcre2_global_context);
+#endif
 }
 
 static void grep_set_pattern_type_option(enum grep_pattern_type pattern_type, struct grep_opt *opt)
@@ -360,31 +405,20 @@ static int is_fixed(const char *s, size_
 	return 1;
 }
 
-static int has_null(const char *s, size_t len)
-{
-	/*
-	 * regcomp cannot accept patterns with NULs so when using it
-	 * we consider any pattern containing a NUL fixed.
-	 */
-	if (memchr(s, 0, len))
-		return 1;
-
-	return 0;
-}
-
 #ifdef USE_LIBPCRE1
 static void compile_pcre1_regexp(struct grep_pat *p, const struct grep_opt *opt)
 {
 	const char *error;
 	int erroffset;
 	int options = PCRE_MULTILINE;
+	int study_options = 0;
 
 	if (opt->ignore_case) {
-		if (has_non_ascii(p->pattern))
+		if (!opt->ignore_locale && has_non_ascii(p->pattern))
 			p->pcre1_tables = pcre_maketables();
 		options |= PCRE_CASELESS;
 	}
-	if (is_utf8_locale() && has_non_ascii(p->pattern))
+	if (!opt->ignore_locale && is_utf8_locale() && has_non_ascii(p->pattern))
 		options |= PCRE_UTF8;
 
 	p->pcre1_regexp = pcre_compile(p->pattern, options, &error, &erroffset,
@@ -392,44 +426,31 @@ static void compile_pcre1_regexp(struct
 	if (!p->pcre1_regexp)
 		compile_regexp_failed(p, error);
 
-	p->pcre1_extra_info = pcre_study(p->pcre1_regexp, GIT_PCRE_STUDY_JIT_COMPILE, &error);
-	if (!p->pcre1_extra_info && error)
-		die("%s", error);
-
-#ifdef GIT_PCRE1_USE_JIT
+#if defined(PCRE_CONFIG_JIT) && !defined(NO_LIBPCRE1_JIT)
 	pcre_config(PCRE_CONFIG_JIT, &p->pcre1_jit_on);
-	if (p->pcre1_jit_on == 1) {
-		p->pcre1_jit_stack = pcre_jit_stack_alloc(1, 1024 * 1024);
-		if (!p->pcre1_jit_stack)
-			die("Couldn't allocate PCRE JIT stack");
-		pcre_assign_jit_stack(p->pcre1_extra_info, NULL, p->pcre1_jit_stack);
-	} else if (p->pcre1_jit_on != 0) {
-		BUG("The pcre1_jit_on variable should be 0 or 1, not %d",
-		    p->pcre1_jit_on);
-	}
+	if (opt->debug)
+		fprintf(stderr, "pcre1_jit_on=%d\n", p->pcre1_jit_on);
+
+	if (p->pcre1_jit_on)
+		study_options = PCRE_STUDY_JIT_COMPILE;
 #endif
+
+	p->pcre1_extra_info = pcre_study(p->pcre1_regexp, study_options, &error);
+	if (!p->pcre1_extra_info && error)
+		die("%s", error);
 }
 
 static int pcre1match(struct grep_pat *p, const char *line, const char *eol,
 		regmatch_t *match, int eflags)
 {
-	int ovector[30], ret, flags = 0;
+	int ovector[30], ret, flags = PCRE_NO_UTF8_CHECK;
 
 	if (eflags & REG_NOTBOL)
 		flags |= PCRE_NOTBOL;
 
-#ifdef GIT_PCRE1_USE_JIT
-	if (p->pcre1_jit_on) {
-		ret = pcre_jit_exec(p->pcre1_regexp, p->pcre1_extra_info, line,
-				    eol - line, 0, flags, ovector,
-				    ARRAY_SIZE(ovector), p->pcre1_jit_stack);
-	} else
-#endif
-	{
-		ret = pcre_exec(p->pcre1_regexp, p->pcre1_extra_info, line,
-				eol - line, 0, flags, ovector,
-				ARRAY_SIZE(ovector));
-	}
+	ret = pcre_exec(p->pcre1_regexp, p->pcre1_extra_info, line,
+			eol - line, 0, flags, ovector,
+			ARRAY_SIZE(ovector));
 
 	if (ret < 0 && ret != PCRE_ERROR_NOMATCH)
 		die("pcre_exec failed with error code %d", ret);
@@ -445,15 +466,12 @@ static int pcre1match(struct grep_pat *p
 static void free_pcre1_regexp(struct grep_pat *p)
 {
 	pcre_free(p->pcre1_regexp);
-#ifdef GIT_PCRE1_USE_JIT
-	if (p->pcre1_jit_on) {
+#ifdef PCRE_CONFIG_JIT
+	if (p->pcre1_jit_on)
 		pcre_free_study(p->pcre1_extra_info);
-		pcre_jit_stack_free(p->pcre1_jit_stack);
-	} else
+	else
 #endif
-	{
 		pcre_free(p->pcre1_extra_info);
-	}
 	pcre_free((void *)p->pcre1_tables);
 }
 #else /* !USE_LIBPCRE1 */
@@ -480,7 +498,6 @@ static void compile_pcre2_pattern(struct
 	PCRE2_UCHAR errbuf[256];
 	PCRE2_SIZE erroffset;
 	int options = PCRE2_MULTILINE;
-	const uint8_t *character_tables = NULL;
 	int jitret;
 	int patinforet;
 	size_t jitsizearg;
@@ -489,15 +506,20 @@ static void compile_pcre2_pattern(struct
 
 	p->pcre2_compile_context = NULL;
 
+	/* pcre2_global_context is initialized in append_grep_pattern */
 	if (opt->ignore_case) {
-		if (has_non_ascii(p->pattern)) {
-			character_tables = pcre2_maketables(NULL);
+		if (!opt->ignore_locale && has_non_ascii(p->pattern)) {
+			if (!pcre2_global_context)
+				BUG("pcre2_global_context uninitialized");
+			p->pcre2_tables = pcre2_maketables(pcre2_global_context);
 			p->pcre2_compile_context = pcre2_compile_context_create(NULL);
-			pcre2_set_character_tables(p->pcre2_compile_context, character_tables);
+			pcre2_set_character_tables(p->pcre2_compile_context,
+							p->pcre2_tables);
 		}
 		options |= PCRE2_CASELESS;
 	}
-	if (is_utf8_locale() && has_non_ascii(p->pattern))
+	if (!opt->ignore_locale && is_utf8_locale() && has_non_ascii(p->pattern) &&
+	    !(!opt->ignore_case && (p->fixed || p->is_fixed)))
 		options |= PCRE2_UTF;
 
 	p->pcre2_pattern = pcre2_compile((PCRE2_SPTR)p->pattern,
@@ -514,7 +536,9 @@ static void compile_pcre2_pattern(struct
 	}
 
 	pcre2_config(PCRE2_CONFIG_JIT, &p->pcre2_jit_on);
-	if (p->pcre2_jit_on == 1) {
+	if (opt->debug)
+		fprintf(stderr, "pcre2_jit_on=%d\n", p->pcre2_jit_on);
+	if (p->pcre2_jit_on) {
 		jitret = pcre2_jit_compile(p->pcre2_pattern, PCRE2_JIT_COMPLETE);
 		if (jitret)
 			die("Couldn't JIT the PCRE2 pattern '%s', got '%d'\n", p->pattern, jitret);
@@ -539,19 +563,11 @@ static void compile_pcre2_pattern(struct
 			BUG("pcre2_pattern_info() failed: %d", patinforet);
 		if (jitsizearg == 0) {
 			p->pcre2_jit_on = 0;
+			if (opt->debug)
+				fprintf(stderr, "pcre2_jit_on=%d: (*NO_JIT) in regex\n",
+					p->pcre2_jit_on);
 			return;
 		}
-
-		p->pcre2_jit_stack = pcre2_jit_stack_create(1, 1024 * 1024, NULL);
-		if (!p->pcre2_jit_stack)
-			die("Couldn't allocate PCRE2 JIT stack");
-		p->pcre2_match_context = pcre2_match_context_create(NULL);
-		if (!p->pcre2_match_context)
-			die("Couldn't allocate PCRE2 match context");
-		pcre2_jit_stack_assign(p->pcre2_match_context, NULL, p->pcre2_jit_stack);
-	} else if (p->pcre2_jit_on != 0) {
-		BUG("The pcre2_jit_on variable should be 0 or 1, not %d",
-		    p->pcre1_jit_on);
 	}
 }
 
@@ -595,8 +611,7 @@ static void free_pcre2_pattern(struct gr
 	pcre2_compile_context_free(p->pcre2_compile_context);
 	pcre2_code_free(p->pcre2_pattern);
 	pcre2_match_data_free(p->pcre2_match_data);
-	pcre2_jit_stack_free(p->pcre2_jit_stack);
-	pcre2_match_context_free(p->pcre2_match_context);
+	free((void *)p->pcre2_tables);
 }
 #else /* !USE_LIBPCRE2 */
 static void compile_pcre2_pattern(struct grep_pat *p, const struct grep_opt *opt)
@@ -618,7 +633,6 @@ static int pcre2match(struct grep_pat *p
 static void free_pcre2_pattern(struct grep_pat *p)
 {
 }
-#endif /* !USE_LIBPCRE2 */
 
 static void compile_fixed_regexp(struct grep_pat *p, struct grep_opt *opt)
 {
@@ -639,46 +653,66 @@ static void compile_fixed_regexp(struct
 		compile_regexp_failed(p, errbuf);
 	}
 }
+#endif /* !USE_LIBPCRE2 */
 
 static void compile_regexp(struct grep_pat *p, struct grep_opt *opt)
 {
-	int ascii_only;
 	int err;
 	int regflags = REG_NEWLINE;
 
 	p->word_regexp = opt->word_regexp;
 	p->ignore_case = opt->ignore_case;
-	ascii_only     = !has_non_ascii(p->pattern);
+	p->fixed = opt->fixed;
 
-	/*
-	 * Even when -F (fixed) asks us to do a non-regexp search, we
-	 * may not be able to correctly case-fold when -i
-	 * (ignore-case) is asked (in which case, we'll synthesize a
-	 * regexp to match the pattern that matches regexp special
-	 * characters literally, while ignoring case differences).  On
-	 * the other hand, even without -F, if the pattern does not
-	 * have any regexp special characters and there is no need for
-	 * case-folding search, we can internally turn it into a
-	 * simple string match using kws.  p->fixed tells us if we
-	 * want to use kws.
-	 */
-	if (opt->fixed ||
-	    has_null(p->pattern, p->patternlen) ||
-	    is_fixed(p->pattern, p->patternlen))
-		p->fixed = !p->ignore_case || ascii_only;
-
-	if (p->fixed) {
-		p->kws = kwsalloc(p->ignore_case ? tolower_trans_tbl : NULL);
-		kwsincr(p->kws, p->pattern, p->patternlen);
-		kwsprep(p->kws);
-		return;
-	} else if (opt->fixed) {
-		/*
-		 * We come here when the pattern has the non-ascii
-		 * characters we cannot case-fold, and asked to
-		 * ignore-case.
-		 */
+	if (memchr(p->pattern, 0, p->patternlen) && !opt->pcre2)
+		die(_("given pattern contains NULL byte (via -f <file>). This is only supported with -P under PCRE v2"));
+
+	p->is_fixed = is_fixed(p->pattern, p->patternlen);
+#ifdef USE_LIBPCRE2
+       if (!p->fixed && !p->is_fixed) {
+	       const char *no_jit = "(*NO_JIT)";
+	       const int no_jit_len = strlen(no_jit);
+	       if (starts_with(p->pattern, no_jit) &&
+		   is_fixed(p->pattern + no_jit_len,
+			    p->patternlen - no_jit_len))
+		       p->is_fixed = 1;
+       }
+#endif
+	if (p->fixed || p->is_fixed) {
+#ifdef USE_LIBPCRE2
+		opt->pcre2 = 1;
+		if (p->is_fixed) {
+			compile_pcre2_pattern(p, opt);
+		} else {
+			/*
+			 * E.g. t7811-grep-open.sh relies on the
+			 * pattern being restored.
+			 */
+			char *old_pattern = p->pattern;
+			size_t old_patternlen = p->patternlen;
+			struct strbuf sb = STRBUF_INIT;
+
+			/*
+			 * There is the PCRE2_LITERAL flag, but it's
+			 * only in PCRE v2 10.30 and later. Needing to
+			 * ifdef our way around that and dealing with
+			 * it + PCRE2_MULTILINE being an error is more
+			 * complex than just quoting this ourselves.
+			*/
+			strbuf_add(&sb, "\\Q", 2);
+			strbuf_add(&sb, p->pattern, p->patternlen);
+			strbuf_add(&sb, "\\E", 2);
+
+			p->pattern = sb.buf;
+			p->patternlen = sb.len;
+			compile_pcre2_pattern(p, opt);
+			p->pattern = old_pattern;
+			p->patternlen = old_patternlen;
+			strbuf_release(&sb);
+		}
+#else /* !USE_LIBPCRE2 */
 		compile_fixed_regexp(p, opt);
+#endif /* !USE_LIBPCRE2 */
 		return;
 	}
 
@@ -1045,9 +1079,7 @@ void free_grep_patterns(struct grep_opt
 		case GREP_PATTERN: /* atom */
 		case GREP_PATTERN_HEAD:
 		case GREP_PATTERN_BODY:
-			if (p->kws)
-				kwsfree(p->kws);
-			else if (p->pcre1_regexp)
+			if (p->pcre1_regexp)
 				free_pcre1_regexp(p);
 			else if (p->pcre2_pattern)
 				free_pcre2_pattern(p);
@@ -1098,38 +1130,21 @@ static void output_sep(struct grep_opt *
 	if (opt->null_following_name)
 		opt->output(opt, "\0", 1);
 	else
-		output_color(opt, &sign, 1, opt->color_sep);
+		output_color(opt, &sign, 1, opt->colors[GREP_COLOR_SEP]);
 }
 
 static void show_name(struct grep_opt *opt, const char *name)
 {
-	output_color(opt, name, strlen(name), opt->color_filename);
+	output_color(opt, name, strlen(name), opt->colors[GREP_COLOR_FILENAME]);
 	opt->output(opt, opt->null_following_name ? "\0" : "\n", 1);
 }
 
-static int fixmatch(struct grep_pat *p, char *line, char *eol,
-		    regmatch_t *match)
-{
-	struct kwsmatch kwsm;
-	size_t offset = kwsexec(p->kws, line, eol - line, &kwsm);
-	if (offset == -1) {
-		match->rm_so = match->rm_eo = -1;
-		return REG_NOMATCH;
-	} else {
-		match->rm_so = offset;
-		match->rm_eo = match->rm_so + kwsm.size[0];
-		return 0;
-	}
-}
-
 static int patmatch(struct grep_pat *p, char *line, char *eol,
 		    regmatch_t *match, int eflags)
 {
 	int hit;
 
-	if (p->fixed)
-		hit = !fixmatch(p, line, eol, match);
-	else if (p->pcre1_regexp)
+	if (p->pcre1_regexp)
 		hit = !pcre1match(p, line, eol, match, eflags);
 	else if (p->pcre2_pattern)
 		hit = !pcre2match(p, line, eol, match, eflags);
@@ -1248,11 +1263,11 @@ static int match_one_pattern(struct grep
 	return hit;
 }
 
-static int match_expr_eval(struct grep_expr *x, char *bol, char *eol,
-			   enum grep_context ctx, int collect_hits)
+static int match_expr_eval(struct grep_opt *opt, struct grep_expr *x, char *bol,
+			   char *eol, enum grep_context ctx, ssize_t *col,
+			   ssize_t *icol, int collect_hits)
 {
 	int h = 0;
-	regmatch_t match;
 
 	if (!x)
 		die("Not a valid grep expression");
@@ -1261,25 +1276,52 @@ static int match_expr_eval(struct grep_e
 		h = 1;
 		break;
 	case GREP_NODE_ATOM:
-		h = match_one_pattern(x->u.atom, bol, eol, ctx, &match, 0);
+		{
+			regmatch_t tmp;
+			h = match_one_pattern(x->u.atom, bol, eol, ctx,
+					      &tmp, 0);
+			if (h && (*col < 0 || tmp.rm_so < *col))
+				*col = tmp.rm_so;
+		}
 		break;
 	case GREP_NODE_NOT:
-		h = !match_expr_eval(x->u.unary, bol, eol, ctx, 0);
+		/*
+		 * Upon visiting a GREP_NODE_NOT, col and icol become swapped.
+		 */
+		h = !match_expr_eval(opt, x->u.unary, bol, eol, ctx, icol, col,
+				     0);
 		break;
 	case GREP_NODE_AND:
-		if (!match_expr_eval(x->u.binary.left, bol, eol, ctx, 0))
-			return 0;
-		h = match_expr_eval(x->u.binary.right, bol, eol, ctx, 0);
+		h = match_expr_eval(opt, x->u.binary.left, bol, eol, ctx, col,
+				    icol, 0);
+		if (h || opt->columnnum) {
+			/*
+			 * Don't short-circuit AND when given --column, since a
+			 * NOT earlier in the tree may turn this into an OR. In
+			 * this case, see the below comment.
+			 */
+			h &= match_expr_eval(opt, x->u.binary.right, bol, eol,
+					     ctx, col, icol, 0);
+		}
 		break;
 	case GREP_NODE_OR:
-		if (!collect_hits)
-			return (match_expr_eval(x->u.binary.left,
-						bol, eol, ctx, 0) ||
-				match_expr_eval(x->u.binary.right,
-						bol, eol, ctx, 0));
-		h = match_expr_eval(x->u.binary.left, bol, eol, ctx, 0);
-		x->u.binary.left->hit |= h;
-		h |= match_expr_eval(x->u.binary.right, bol, eol, ctx, 1);
+		if (!(collect_hits || opt->columnnum)) {
+			/*
+			 * Don't short-circuit OR when given --column (or
+			 * collecting hits) to ensure we don't skip a later
+			 * child that would produce an earlier match.
+			 */
+			return (match_expr_eval(opt, x->u.binary.left, bol, eol,
+						ctx, col, icol, 0) ||
+				match_expr_eval(opt, x->u.binary.right, bol,
+						eol, ctx, col, icol, 0));
+		}
+		h = match_expr_eval(opt, x->u.binary.left, bol, eol, ctx, col,
+				    icol, 0);
+		if (collect_hits)
+			x->u.binary.left->hit |= h;
+		h |= match_expr_eval(opt, x->u.binary.right, bol, eol, ctx, col,
+				     icol, collect_hits);
 		break;
 	default:
 		die("Unexpected node type (internal error) %d", x->node);
@@ -1290,27 +1332,43 @@ static int match_expr_eval(struct grep_e
 }
 
 static int match_expr(struct grep_opt *opt, char *bol, char *eol,
-		      enum grep_context ctx, int collect_hits)
+		      enum grep_context ctx, ssize_t *col,
+		      ssize_t *icol, int collect_hits)
 {
 	struct grep_expr *x = opt->pattern_expression;
-	return match_expr_eval(x, bol, eol, ctx, collect_hits);
+	return match_expr_eval(opt, x, bol, eol, ctx, col, icol, collect_hits);
 }
 
 static int match_line(struct grep_opt *opt, char *bol, char *eol,
+		      ssize_t *col, ssize_t *icol,
 		      enum grep_context ctx, int collect_hits)
 {
 	struct grep_pat *p;
-	regmatch_t match;
+	int hit = 0;
 
 	if (opt->extended)
-		return match_expr(opt, bol, eol, ctx, collect_hits);
+		return match_expr(opt, bol, eol, ctx, col, icol,
+				  collect_hits);
 
 	/* we do not call with collect_hits without being extended */
 	for (p = opt->pattern_list; p; p = p->next) {
-		if (match_one_pattern(p, bol, eol, ctx, &match, 0))
-			return 1;
+		regmatch_t tmp;
+		if (match_one_pattern(p, bol, eol, ctx, &tmp, 0)) {
+			hit |= 1;
+			if (!opt->columnnum) {
+				/*
+				 * Without --column, any single match on a line
+				 * is enough to know that it needs to be
+				 * printed. With --column, scan _all_ patterns
+				 * to find the earliest.
+				 */
+				break;
+			}
+			if (*col < 0 || tmp.rm_so < *col)
+				*col = tmp.rm_so;
+		}
 	}
-	return 0;
+	return hit;
 }
 
 static int match_next_pattern(struct grep_pat *p, char *bol, char *eol,
@@ -1358,11 +1416,44 @@ static int next_match(struct grep_opt *o
 	return hit;
 }
 
+static void show_line_header(struct grep_opt *opt, const char *name,
+			     unsigned lno, ssize_t cno, char sign)
+{
+	if (opt->heading && opt->last_shown == 0) {
+		output_color(opt, name, strlen(name), opt->colors[GREP_COLOR_FILENAME]);
+		opt->output(opt, "\n", 1);
+	}
+	opt->last_shown = lno;
+
+	if (!opt->heading && opt->pathname) {
+		output_color(opt, name, strlen(name), opt->colors[GREP_COLOR_FILENAME]);
+		output_sep(opt, sign);
+	}
+	if (opt->linenum) {
+		char buf[32];
+		xsnprintf(buf, sizeof(buf), "%d", lno);
+		output_color(opt, buf, strlen(buf), opt->colors[GREP_COLOR_LINENO]);
+		output_sep(opt, sign);
+	}
+	/*
+	 * Treat 'cno' as the 1-indexed offset from the start of a non-context
+	 * line to its first match. Otherwise, 'cno' is 0 indicating that we are
+	 * being called with a context line.
+	 */
+	if (opt->columnnum && cno) {
+		char buf[32];
+		xsnprintf(buf, sizeof(buf), "%"PRIuMAX, (uintmax_t)cno);
+		output_color(opt, buf, strlen(buf), opt->colors[GREP_COLOR_COLUMNNO]);
+		output_sep(opt, sign);
+	}
+}
+
 static void show_line(struct grep_opt *opt, char *bol, char *eol,
-		      const char *name, unsigned lno, char sign)
+		      const char *name, unsigned lno, ssize_t cno, char sign)
 {
 	int rest = eol - bol;
-	const char *match_color, *line_color = NULL;
+	const char *match_color = NULL;
+	const char *line_color = NULL;
 
 	if (opt->file_break && opt->last_shown == 0) {
 		if (opt->show_hunk_mark)
@@ -1370,65 +1461,65 @@ static void show_line(struct grep_opt *o
 	} else if (opt->pre_context || opt->post_context || opt->funcbody) {
 		if (opt->last_shown == 0) {
 			if (opt->show_hunk_mark) {
-				output_color(opt, "--", 2, opt->color_sep);
+				output_color(opt, "--", 2, opt->colors[GREP_COLOR_SEP]);
 				opt->output(opt, "\n", 1);
 			}
 		} else if (lno > opt->last_shown + 1) {
-			output_color(opt, "--", 2, opt->color_sep);
+			output_color(opt, "--", 2, opt->colors[GREP_COLOR_SEP]);
 			opt->output(opt, "\n", 1);
 		}
 	}
-	if (opt->heading && opt->last_shown == 0) {
-		output_color(opt, name, strlen(name), opt->color_filename);
-		opt->output(opt, "\n", 1);
-	}
-	opt->last_shown = lno;
-
-	if (!opt->heading && opt->pathname) {
-		output_color(opt, name, strlen(name), opt->color_filename);
-		output_sep(opt, sign);
-	}
-	if (opt->linenum) {
-		char buf[32];
-		xsnprintf(buf, sizeof(buf), "%d", lno);
-		output_color(opt, buf, strlen(buf), opt->color_lineno);
-		output_sep(opt, sign);
+	if (!opt->only_matching) {
+		/*
+		 * In case the line we're being called with contains more than
+		 * one match, leave printing each header to the loop below.
+		 */
+		show_line_header(opt, name, lno, cno, sign);
 	}
-	if (opt->color) {
+	if (opt->color || opt->only_matching) {
 		regmatch_t match;
 		enum grep_context ctx = GREP_CONTEXT_BODY;
 		int ch = *eol;
 		int eflags = 0;
 
-		if (sign == ':')
-			match_color = opt->color_match_selected;
-		else
-			match_color = opt->color_match_context;
-		if (sign == ':')
-			line_color = opt->color_selected;
-		else if (sign == '-')
-			line_color = opt->color_context;
-		else if (sign == '=')
-			line_color = opt->color_function;
+		if (opt->color) {
+			if (sign == ':')
+				match_color = opt->colors[GREP_COLOR_MATCH_SELECTED];
+			else
+				match_color = opt->colors[GREP_COLOR_MATCH_CONTEXT];
+			if (sign == ':')
+				line_color = opt->colors[GREP_COLOR_SELECTED];
+			else if (sign == '-')
+				line_color = opt->colors[GREP_COLOR_CONTEXT];
+			else if (sign == '=')
+				line_color = opt->colors[GREP_COLOR_FUNCTION];
+		}
 		*eol = '\0';
 		while (next_match(opt, bol, eol, ctx, &match, eflags)) {
 			if (match.rm_so == match.rm_eo)
 				break;
 
-			output_color(opt, bol, match.rm_so, line_color);
+			if (opt->only_matching)
+				show_line_header(opt, name, lno, cno, sign);
+			else
+				output_color(opt, bol, match.rm_so, line_color);
 			output_color(opt, bol + match.rm_so,
 				     match.rm_eo - match.rm_so, match_color);
+			if (opt->only_matching)
+				opt->output(opt, "\n", 1);
 			bol += match.rm_eo;
+			cno += match.rm_eo;
 			rest -= match.rm_eo;
 			eflags = REG_NOTBOL;
 		}
 		*eol = ch;
 	}
-	output_color(opt, bol, rest, line_color);
-	opt->output(opt, "\n", 1);
+	if (!opt->only_matching) {
+		output_color(opt, bol, rest, line_color);
+		opt->output(opt, "\n", 1);
+	}
 }
 
-#ifndef NO_PTHREADS
 int grep_use_locks;
 
 /*
@@ -1454,16 +1545,11 @@ static inline void grep_attr_unlock(void
  */
 pthread_mutex_t grep_read_mutex;
 
-#else
-#define grep_attr_lock()
-#define grep_attr_unlock()
-#endif
-
 static int match_funcname(struct grep_opt *opt, struct grep_source *gs, char *bol, char *eol)
 {
 	xdemitconf_t *xecfg = opt->priv;
 	if (xecfg && !xecfg->find_func) {
-		grep_source_load_driver(gs);
+		grep_source_load_driver(gs, opt->repo->index);
 		if (gs->driver->funcname.pattern) {
 			const struct userdiff_funcname *pe = &gs->driver->funcname;
 			xdiff_set_find_func(xecfg, pe->pattern, pe->cflags);
@@ -1499,7 +1585,7 @@ static void show_funcname_line(struct gr
 			break;
 
 		if (match_funcname(opt, gs, bol, eol)) {
-			show_line(opt, bol, eol, gs->name, lno, '=');
+			show_line(opt, bol, eol, gs->name, lno, 0, '=');
 			break;
 		}
 	}
@@ -1564,7 +1650,7 @@ static void show_pre_context(struct grep
 
 		while (*eol != '\n')
 			eol++;
-		show_line(opt, bol, eol, gs->name, cur, sign);
+		show_line(opt, bol, eol, gs->name, cur, 0, sign);
 		bol = eol + 1;
 		cur++;
 	}
@@ -1626,7 +1712,8 @@ static int look_ahead(struct grep_opt *o
 	return 0;
 }
 
-static int fill_textconv_grep(struct userdiff_driver *driver,
+static int fill_textconv_grep(struct repository *r,
+			      struct userdiff_driver *driver,
 			      struct grep_source *gs)
 {
 	struct diff_filespec *df;
@@ -1659,7 +1746,7 @@ static int fill_textconv_grep(struct use
 	 * structure.
 	 */
 	grep_read_lock();
-	size = fill_textconv(driver, df, &buf);
+	size = fill_textconv(r, driver, df, &buf);
 	grep_read_unlock();
 	free_filespec(df);
 
@@ -1700,6 +1787,10 @@ static int grep_source_1(struct grep_opt
 	enum grep_context ctx = GREP_CONTEXT_HEAD;
 	xdemitconf_t xecfg;
 
+	if (!opt->status_only && gs->name == NULL)
+		BUG("grep call which could print a name requires "
+		    "grep_source.name be non-NULL");
+
 	if (!opt->output)
 		opt->output = std_output;
 
@@ -1719,13 +1810,13 @@ static int grep_source_1(struct grep_opt
 	opt->last_shown = 0;
 
 	if (opt->allow_textconv) {
-		grep_source_load_driver(gs);
+		grep_source_load_driver(gs, opt->repo->index);
 		/*
 		 * We might set up the shared textconv cache data here, which
 		 * is not thread-safe.
 		 */
 		grep_attr_lock();
-		textconv = userdiff_get_textconv(gs->driver);
+		textconv = userdiff_get_textconv(opt->repo, gs->driver);
 		grep_attr_unlock();
 	}
 
@@ -1736,11 +1827,11 @@ static int grep_source_1(struct grep_opt
 	if (!textconv) {
 		switch (opt->binary) {
 		case GREP_BINARY_DEFAULT:
-			if (grep_source_is_binary(gs))
+			if (grep_source_is_binary(gs, opt->repo->index))
 				binary_match_only = 1;
 			break;
 		case GREP_BINARY_NOMATCH:
-			if (grep_source_is_binary(gs))
+			if (grep_source_is_binary(gs, opt->repo->index))
 				return 0; /* Assume unmatch */
 			break;
 		case GREP_BINARY_TEXT:
@@ -1755,7 +1846,7 @@ static int grep_source_1(struct grep_opt
 
 	try_lookahead = should_lookahead(opt);
 
-	if (fill_textconv_grep(textconv, gs) < 0)
+	if (fill_textconv_grep(opt->repo, textconv, gs) < 0)
 		return 0;
 
 	bol = gs->buf;
@@ -1763,6 +1854,8 @@ static int grep_source_1(struct grep_opt
 	while (left) {
 		char *eol, ch;
 		int hit;
+		ssize_t cno;
+		ssize_t col = -1, icol = -1;
 
 		/*
 		 * look_ahead() skips quickly to the line that possibly
@@ -1786,7 +1879,7 @@ static int grep_source_1(struct grep_opt
 		if ((ctx == GREP_CONTEXT_HEAD) && (eol == bol))
 			ctx = GREP_CONTEXT_BODY;
 
-		hit = match_line(opt, bol, eol, ctx, collect_hits);
+		hit = match_line(opt, bol, eol, &col, &icol, ctx, collect_hits);
 		*eol = ch;
 
 		if (collect_hits)
@@ -1816,7 +1909,7 @@ static int grep_source_1(struct grep_opt
 			if (binary_match_only) {
 				opt->output(opt, "Binary file ", 12);
 				output_color(opt, gs->name, strlen(gs->name),
-					     opt->color_filename);
+					     opt->colors[GREP_COLOR_FILENAME]);
 				opt->output(opt, " matches\n", 9);
 				return 1;
 			}
@@ -1827,7 +1920,18 @@ static int grep_source_1(struct grep_opt
 				show_pre_context(opt, gs, bol, eol, lno);
 			else if (opt->funcname)
 				show_funcname_line(opt, gs, bol, lno);
-			show_line(opt, bol, eol, gs->name, lno, ':');
+			cno = opt->invert ? icol : col;
+			if (cno < 0) {
+				/*
+				 * A negative cno indicates that there was no
+				 * match on the line. We are thus inverted and
+				 * being asked to show all lines that _don't_
+				 * match a given expression. Therefore, set cno
+				 * to 0 to suggest the whole line matches.
+				 */
+				cno = 0;
+			}
+			show_line(opt, bol, eol, gs->name, lno, cno + 1, ':');
 			last_hit = lno;
 			if (opt->funcbody)
 				show_function = 1;
@@ -1856,7 +1960,7 @@ static int grep_source_1(struct grep_opt
 			/* If the last hit is within the post context,
 			 * we need to show this line.
 			 */
-			show_line(opt, bol, eol, gs->name, lno, '-');
+			show_line(opt, bol, eol, gs->name, lno, col + 1, '-');
 		}
 
 	next_line:
@@ -1890,7 +1994,7 @@ static int grep_source_1(struct grep_opt
 		char buf[32];
 		if (opt->pathname) {
 			output_color(opt, gs->name, strlen(gs->name),
-				     opt->color_filename);
+				     opt->colors[GREP_COLOR_FILENAME]);
 			output_sep(opt, ':');
 		}
 		xsnprintf(buf, sizeof(buf), "%u\n", count);
@@ -2073,22 +2177,24 @@ static int grep_source_load(struct grep_
 	BUG("invalid grep_source type to load");
 }
 
-void grep_source_load_driver(struct grep_source *gs)
+void grep_source_load_driver(struct grep_source *gs,
+			     struct index_state *istate)
 {
 	if (gs->driver)
 		return;
 
 	grep_attr_lock();
 	if (gs->path)
-		gs->driver = userdiff_find_by_path(gs->path);
+		gs->driver = userdiff_find_by_path(istate, gs->path);
 	if (!gs->driver)
 		gs->driver = userdiff_find_by_name("default");
 	grep_attr_unlock();
 }
 
-static int grep_source_is_binary(struct grep_source *gs)
+static int grep_source_is_binary(struct grep_source *gs,
+				 struct index_state *istate)
 {
-	grep_source_load_driver(gs);
+	grep_source_load_driver(gs, istate);
 	if (gs->driver->binary != -1)
 		return gs->driver->binary;
 
diff -pruN 1.2.1+git2.18.0-1/git/grep.h 1.2.3+git2.25.1-1/git/grep.h
--- 1.2.1+git2.18.0-1/git/grep.h	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/grep.h	2020-02-17 04:47:35.000000000 +0000
@@ -3,24 +3,12 @@
 #include "color.h"
 #ifdef USE_LIBPCRE1
 #include <pcre.h>
-#ifdef PCRE_CONFIG_JIT
-#if PCRE_MAJOR >= 8 && PCRE_MINOR >= 32
-#ifndef NO_LIBPCRE1_JIT
-#define GIT_PCRE1_USE_JIT
-#define GIT_PCRE_STUDY_JIT_COMPILE PCRE_STUDY_JIT_COMPILE
-#endif
-#endif
-#endif
-#ifndef GIT_PCRE_STUDY_JIT_COMPILE
-#define GIT_PCRE_STUDY_JIT_COMPILE 0
-#endif
-#if PCRE_MAJOR <= 8 && PCRE_MINOR < 20
-typedef int pcre_jit_stack;
+#ifndef PCRE_NO_UTF8_CHECK
+#define PCRE_NO_UTF8_CHECK 0
 #endif
 #else
 typedef int pcre;
 typedef int pcre_extra;
-typedef int pcre_jit_stack;
 #endif
 #ifdef USE_LIBPCRE2
 #define PCRE2_CODE_UNIT_WIDTH 8
@@ -29,13 +17,12 @@ typedef int pcre_jit_stack;
 typedef int pcre2_code;
 typedef int pcre2_match_data;
 typedef int pcre2_compile_context;
-typedef int pcre2_match_context;
-typedef int pcre2_jit_stack;
 #endif
-#include "kwset.h"
 #include "thread-utils.h"
 #include "userdiff.h"
 
+struct repository;
+
 enum grep_pat_token {
 	GREP_PATTERN,
 	GREP_PATTERN_HEAD,
@@ -62,6 +49,19 @@ enum grep_header_field {
 	GREP_HEADER_FIELD_MAX
 };
 
+enum grep_color {
+	GREP_COLOR_CONTEXT,
+	GREP_COLOR_FILENAME,
+	GREP_COLOR_FUNCTION,
+	GREP_COLOR_LINENO,
+	GREP_COLOR_COLUMNNO,
+	GREP_COLOR_MATCH_CONTEXT,
+	GREP_COLOR_MATCH_SELECTED,
+	GREP_COLOR_SELECTED,
+	GREP_COLOR_SEP,
+	NR_GREP_COLORS
+};
+
 struct grep_pat {
 	struct grep_pat *next;
 	const char *origin;
@@ -73,17 +73,15 @@ struct grep_pat {
 	regex_t regexp;
 	pcre *pcre1_regexp;
 	pcre_extra *pcre1_extra_info;
-	pcre_jit_stack *pcre1_jit_stack;
 	const unsigned char *pcre1_tables;
 	int pcre1_jit_on;
 	pcre2_code *pcre2_pattern;
 	pcre2_match_data *pcre2_match_data;
 	pcre2_compile_context *pcre2_compile_context;
-	pcre2_match_context *pcre2_match_context;
-	pcre2_jit_stack *pcre2_jit_stack;
+	const uint8_t *pcre2_tables;
 	uint32_t pcre2_jit_on;
-	kwset_t kws;
 	unsigned fixed:1;
+	unsigned is_fixed:1;
 	unsigned ignore_case:1;
 	unsigned word_regexp:1;
 };
@@ -123,10 +121,12 @@ struct grep_opt {
 	struct grep_pat *header_list;
 	struct grep_pat **header_tail;
 	struct grep_expr *pattern_expression;
+	struct repository *repo;
 	const char *prefix;
 	int prefix_length;
 	regex_t regexp;
 	int linenum;
+	int columnnum;
 	int invert;
 	int ignore_case;
 	int status_only;
@@ -149,20 +149,15 @@ struct grep_opt {
 	int relative;
 	int pathname;
 	int null_following_name;
+	int only_matching;
 	int color;
 	int max_depth;
 	int funcname;
 	int funcbody;
 	int extended_regexp_option;
 	int pattern_type_option;
-	char color_context[COLOR_MAXLEN];
-	char color_filename[COLOR_MAXLEN];
-	char color_function[COLOR_MAXLEN];
-	char color_lineno[COLOR_MAXLEN];
-	char color_match_context[COLOR_MAXLEN];
-	char color_match_selected[COLOR_MAXLEN];
-	char color_selected[COLOR_MAXLEN];
-	char color_sep[COLOR_MAXLEN];
+	int ignore_locale;
+	char colors[NR_GREP_COLORS][COLOR_MAXLEN];
 	unsigned pre_context;
 	unsigned post_context;
 	unsigned last_shown;
@@ -175,17 +170,18 @@ struct grep_opt {
 	void *output_priv;
 };
 
-extern void init_grep_defaults(void);
-extern int grep_config(const char *var, const char *value, void *);
-extern void grep_init(struct grep_opt *, const char *prefix);
+void init_grep_defaults(struct repository *);
+int grep_config(const char *var, const char *value, void *);
+void grep_init(struct grep_opt *, struct repository *repo, const char *prefix);
+void grep_destroy(void);
 void grep_commit_pattern_type(enum grep_pattern_type, struct grep_opt *opt);
 
-extern void append_grep_pat(struct grep_opt *opt, const char *pat, size_t patlen, const char *origin, int no, enum grep_pat_token t);
-extern void append_grep_pattern(struct grep_opt *opt, const char *pat, const char *origin, int no, enum grep_pat_token t);
-extern void append_header_grep_pattern(struct grep_opt *, enum grep_header_field, const char *);
-extern void compile_grep_patterns(struct grep_opt *opt);
-extern void free_grep_patterns(struct grep_opt *opt);
-extern int grep_buffer(struct grep_opt *opt, char *buf, unsigned long size);
+void append_grep_pat(struct grep_opt *opt, const char *pat, size_t patlen, const char *origin, int no, enum grep_pat_token t);
+void append_grep_pattern(struct grep_opt *opt, const char *pat, const char *origin, int no, enum grep_pat_token t);
+void append_header_grep_pattern(struct grep_opt *, enum grep_header_field, const char *);
+void compile_grep_patterns(struct grep_opt *opt);
+void free_grep_patterns(struct grep_opt *opt);
+int grep_buffer(struct grep_opt *opt, char *buf, unsigned long size);
 
 struct grep_source {
 	char *name;
@@ -209,15 +205,15 @@ void grep_source_init(struct grep_source
 		      const void *identifier);
 void grep_source_clear_data(struct grep_source *gs);
 void grep_source_clear(struct grep_source *gs);
-void grep_source_load_driver(struct grep_source *gs);
+void grep_source_load_driver(struct grep_source *gs,
+			     struct index_state *istate);
 
 
 int grep_source(struct grep_opt *opt, struct grep_source *gs);
 
-extern struct grep_opt *grep_opt_dup(const struct grep_opt *opt);
-extern int grep_threads_ok(const struct grep_opt *opt);
+struct grep_opt *grep_opt_dup(const struct grep_opt *opt);
+int grep_threads_ok(const struct grep_opt *opt);
 
-#ifndef NO_PTHREADS
 /*
  * Mutex used around access to the attributes machinery if
  * opt->use_threads.  Must be initialized/destroyed by callers!
@@ -238,9 +234,4 @@ static inline void grep_read_unlock(void
 		pthread_mutex_unlock(&grep_read_mutex);
 }
 
-#else
-#define grep_read_lock()
-#define grep_read_unlock()
-#endif
-
 #endif
diff -pruN 1.2.1+git2.18.0-1/git/hash.h 1.2.3+git2.25.1-1/git/hash.h
--- 1.2.1+git2.18.0-1/git/hash.h	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/hash.h	2020-02-17 04:47:35.000000000 +0000
@@ -15,6 +15,14 @@
 #include "block-sha1/sha1.h"
 #endif
 
+#if defined(SHA256_GCRYPT)
+#include "sha256/gcrypt.h"
+#elif defined(SHA256_OPENSSL)
+#include <openssl/sha.h>
+#else
+#include "sha256/block/sha256.h"
+#endif
+
 #ifndef platform_SHA_CTX
 /*
  * platform's underlying implementation of SHA-1; could be OpenSSL,
@@ -34,6 +42,18 @@
 #define git_SHA1_Update		platform_SHA1_Update
 #define git_SHA1_Final		platform_SHA1_Final
 
+#ifndef platform_SHA256_CTX
+#define platform_SHA256_CTX	SHA256_CTX
+#define platform_SHA256_Init	SHA256_Init
+#define platform_SHA256_Update	SHA256_Update
+#define platform_SHA256_Final	SHA256_Final
+#endif
+
+#define git_SHA256_CTX		platform_SHA256_CTX
+#define git_SHA256_Init		platform_SHA256_Init
+#define git_SHA256_Update	platform_SHA256_Update
+#define git_SHA256_Final	platform_SHA256_Final
+
 #ifdef SHA1_MAX_BLOCK_SIZE
 #include "compat/sha1-chunked.h"
 #undef git_SHA1_Update
@@ -52,12 +72,15 @@
 #define GIT_HASH_UNKNOWN 0
 /* SHA-1 */
 #define GIT_HASH_SHA1 1
+/* SHA-256  */
+#define GIT_HASH_SHA256 2
 /* Number of algorithms supported (including unknown). */
-#define GIT_HASH_NALGOS (GIT_HASH_SHA1 + 1)
+#define GIT_HASH_NALGOS (GIT_HASH_SHA256 + 1)
 
 /* A suitably aligned type for stack allocations of hash contexts. */
 union git_hash_ctx {
 	git_SHA_CTX sha1;
+	git_SHA256_CTX sha256;
 };
 typedef union git_hash_ctx git_hash_ctx;
 
@@ -81,6 +104,9 @@ struct git_hash_algo {
 	/* The length of the hash in hex characters. */
 	size_t hexsz;
 
+	/* The block size of the hash. */
+	size_t blksz;
+
 	/* The hash initialization function. */
 	git_hash_init_fn init_fn;
 
@@ -98,4 +124,43 @@ struct git_hash_algo {
 };
 extern const struct git_hash_algo hash_algos[GIT_HASH_NALGOS];
 
+/*
+ * Return a GIT_HASH_* constant based on the name.  Returns GIT_HASH_UNKNOWN if
+ * the name doesn't match a known algorithm.
+ */
+int hash_algo_by_name(const char *name);
+/* Identical, except based on the format ID. */
+int hash_algo_by_id(uint32_t format_id);
+/* Identical, except based on the length. */
+int hash_algo_by_length(int len);
+/* Identical, except for a pointer to struct git_hash_algo. */
+static inline int hash_algo_by_ptr(const struct git_hash_algo *p)
+{
+	return p - hash_algos;
+}
+
+/* The length in bytes and in hex digits of an object name (SHA-1 value). */
+#define GIT_SHA1_RAWSZ 20
+#define GIT_SHA1_HEXSZ (2 * GIT_SHA1_RAWSZ)
+/* The block size of SHA-1. */
+#define GIT_SHA1_BLKSZ 64
+
+/* The length in bytes and in hex digits of an object name (SHA-256 value). */
+#define GIT_SHA256_RAWSZ 32
+#define GIT_SHA256_HEXSZ (2 * GIT_SHA256_RAWSZ)
+/* The block size of SHA-256. */
+#define GIT_SHA256_BLKSZ 64
+
+/* The length in byte and in hex digits of the largest possible hash value. */
+#define GIT_MAX_RAWSZ GIT_SHA256_RAWSZ
+#define GIT_MAX_HEXSZ GIT_SHA256_HEXSZ
+/* The largest possible block size for any supported hash. */
+#define GIT_MAX_BLKSZ GIT_SHA256_BLKSZ
+
+struct object_id {
+	unsigned char hash[GIT_MAX_RAWSZ];
+};
+
+#define the_hash_algo the_repository->hash_algo
+
 #endif
diff -pruN 1.2.1+git2.18.0-1/git/hashmap.c 1.2.3+git2.25.1-1/git/hashmap.c
--- 1.2.1+git2.18.0-1/git/hashmap.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/hashmap.c	2020-02-17 04:47:35.000000000 +0000
@@ -51,7 +51,7 @@ unsigned int memihash(const void *buf, s
 }
 
 /*
- * Incoporate another chunk of data into a memihash
+ * Incorporate another chunk of data into a memihash
  * computation.
  */
 unsigned int memihash_cont(unsigned int hash_seed, const void *buf, size_t len)
@@ -140,8 +140,8 @@ static inline struct hashmap_entry **fin
 }
 
 static int always_equal(const void *unused_cmp_data,
-			const void *unused1,
-			const void *unused2,
+			const struct hashmap_entry *unused1,
+			const struct hashmap_entry *unused2,
 			const void *unused_keydata)
 {
 	return 0;
@@ -171,41 +171,49 @@ void hashmap_init(struct hashmap *map, h
 	map->do_count_items = 1;
 }
 
-void hashmap_free(struct hashmap *map, int free_entries)
+void hashmap_free_(struct hashmap *map, ssize_t entry_offset)
 {
 	if (!map || !map->table)
 		return;
-	if (free_entries) {
+	if (entry_offset >= 0) { /* called by hashmap_free_entries */
 		struct hashmap_iter iter;
 		struct hashmap_entry *e;
+
 		hashmap_iter_init(map, &iter);
 		while ((e = hashmap_iter_next(&iter)))
-			free(e);
+			/*
+			 * like container_of, but using caller-calculated
+			 * offset (caller being hashmap_free_entries)
+			 */
+			free((char *)e - entry_offset);
 	}
 	free(map->table);
 	memset(map, 0, sizeof(*map));
 }
 
-void *hashmap_get(const struct hashmap *map, const void *key, const void *keydata)
+struct hashmap_entry *hashmap_get(const struct hashmap *map,
+				const struct hashmap_entry *key,
+				const void *keydata)
 {
 	return *find_entry_ptr(map, key, keydata);
 }
 
-void *hashmap_get_next(const struct hashmap *map, const void *entry)
+struct hashmap_entry *hashmap_get_next(const struct hashmap *map,
+			const struct hashmap_entry *entry)
 {
-	struct hashmap_entry *e = ((struct hashmap_entry *) entry)->next;
+	struct hashmap_entry *e = entry->next;
 	for (; e; e = e->next)
 		if (entry_equals(map, entry, e, NULL))
 			return e;
 	return NULL;
 }
 
-void hashmap_add(struct hashmap *map, void *entry)
+void hashmap_add(struct hashmap *map, struct hashmap_entry *entry)
 {
 	unsigned int b = bucket(map, entry);
 
 	/* add entry */
-	((struct hashmap_entry *) entry)->next = map->table[b];
+	entry->next = map->table[b];
 	map->table[b] = entry;
 
 	/* fix size and rehash if appropriate */
@@ -216,7 +224,9 @@ void hashmap_add(struct hashmap *map, vo
 	}
 }
 
-void *hashmap_remove(struct hashmap *map, const void *key, const void *keydata)
+struct hashmap_entry *hashmap_remove(struct hashmap *map,
+					const struct hashmap_entry *key,
+					const void *keydata)
 {
 	struct hashmap_entry *old;
 	struct hashmap_entry **e = find_entry_ptr(map, key, keydata);
@@ -238,7 +248,8 @@ void *hashmap_remove(struct hashmap *map
 	return old;
 }
 
-void *hashmap_put(struct hashmap *map, void *entry)
+struct hashmap_entry *hashmap_put(struct hashmap *map,
+				struct hashmap_entry *entry)
 {
 	struct hashmap_entry *old = hashmap_remove(map, entry, NULL);
 	hashmap_add(map, entry);
@@ -252,7 +263,7 @@ void hashmap_iter_init(struct hashmap *m
 	iter->next = NULL;
 }
 
-void *hashmap_iter_next(struct hashmap_iter *iter)
+struct hashmap_entry *hashmap_iter_next(struct hashmap_iter *iter)
 {
 	struct hashmap_entry *current = iter->next;
 	for (;;) {
@@ -275,10 +286,15 @@ struct pool_entry {
 };
 
 static int pool_entry_cmp(const void *unused_cmp_data,
-			  const struct pool_entry *e1,
-			  const struct pool_entry *e2,
-			  const unsigned char *keydata)
+			  const struct hashmap_entry *eptr,
+			  const struct hashmap_entry *entry_or_key,
+			  const void *keydata)
 {
+	const struct pool_entry *e1, *e2;
+
+	e1 = container_of(eptr, const struct pool_entry, ent);
+	e2 = container_of(entry_or_key, const struct pool_entry, ent);
+
 	return e1->data != keydata &&
 	       (e1->len != e2->len || memcmp(e1->data, keydata, e1->len));
 }
@@ -290,18 +306,18 @@ const void *memintern(const void *data,
 
 	/* initialize string pool hashmap */
 	if (!map.tablesize)
-		hashmap_init(&map, (hashmap_cmp_fn) pool_entry_cmp, NULL, 0);
+		hashmap_init(&map, pool_entry_cmp, NULL, 0);
 
 	/* lookup interned string in pool */
-	hashmap_entry_init(&key, memhash(data, len));
+	hashmap_entry_init(&key.ent, memhash(data, len));
 	key.len = len;
-	e = hashmap_get(&map, &key, data);
+	e = hashmap_get_entry(&map, &key, ent, data);
 	if (!e) {
 		/* not found: create it */
 		FLEX_ALLOC_MEM(e, data, data, len);
-		hashmap_entry_init(e, key.ent.hash);
+		hashmap_entry_init(&e->ent, key.ent.hash);
 		e->len = len;
-		hashmap_add(&map, e);
+		hashmap_add(&map, &e->ent);
 	}
 	return e->data;
 }
diff -pruN 1.2.1+git2.18.0-1/git/hashmap.h 1.2.3+git2.25.1-1/git/hashmap.h
--- 1.2.1+git2.18.0-1/git/hashmap.h	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/hashmap.h	2020-02-17 04:47:35.000000000 +0000
@@ -1,6 +1,8 @@
 #ifndef HASHMAP_H
 #define HASHMAP_H
 
+#include "hash.h"
+
 /*
  * Generic implementation of hash-based key-value mappings.
  *
@@ -11,7 +13,7 @@
  *
  * struct hashmap map;
  * struct long2string {
- *     struct hashmap_entry ent; // must be the first member!
+ *     struct hashmap_entry ent;
  *     long key;
  *     char value[FLEX_ARRAY];   // be careful with allocating on stack!
  * };
@@ -19,12 +21,16 @@
  * #define COMPARE_VALUE 1
  *
  * static int long2string_cmp(const void *hashmap_cmp_fn_data,
- *                            const struct long2string *e1,
- *                            const struct long2string *e2,
+ *                            const struct hashmap_entry *eptr,
+ *                            const struct hashmap_entry *entry_or_key,
  *                            const void *keydata)
  * {
  *     const char *string = keydata;
  *     unsigned flags = *(unsigned *)hashmap_cmp_fn_data;
+ *     const struct long2string *e1, *e2;
+ *
+ *     e1 = container_of(eptr, const struct long2string, ent);
+ *     e2 = container_of(entry_or_key, const struct long2string, ent);
  *
  *     if (flags & COMPARE_VALUE)
  *         return e1->key != e2->key ||
@@ -39,54 +45,58 @@
  *     char value[255], action[32];
  *     unsigned flags = 0;
  *
- *     hashmap_init(&map, (hashmap_cmp_fn) long2string_cmp, &flags, 0);
+ *     hashmap_init(&map, long2string_cmp, &flags, 0);
  *
  *     while (scanf("%s %ld %s", action, &key, value)) {
  *
  *         if (!strcmp("add", action)) {
  *             struct long2string *e;
  *             FLEX_ALLOC_STR(e, value, value);
- *             hashmap_entry_init(e, memhash(&key, sizeof(long)));
+ *             hashmap_entry_init(&e->ent, memhash(&key, sizeof(long)));
  *             e->key = key;
- *             hashmap_add(&map, e);
+ *             hashmap_add(&map, &e->ent);
  *         }
  *
  *         if (!strcmp("print_all_by_key", action)) {
  *             struct long2string k, *e;
- *             hashmap_entry_init(&k, memhash(&key, sizeof(long)));
+ *             hashmap_entry_init(&k.ent, memhash(&key, sizeof(long)));
  *             k.key = key;
  *
  *             flags &= ~COMPARE_VALUE;
- *             e = hashmap_get(&map, &k, NULL);
+ *             e = hashmap_get_entry(&map, &k, ent, NULL);
  *             if (e) {
  *                 printf("first: %ld %s\n", e->key, e->value);
- *                 while ((e = hashmap_get_next(&map, e)))
+ *                 while ((e = hashmap_get_next_entry(&map, e,
+ *                                              struct long2string, ent))) {
  *                     printf("found more: %ld %s\n", e->key, e->value);
+ *                 }
  *             }
  *         }
  *
  *         if (!strcmp("has_exact_match", action)) {
  *             struct long2string *e;
  *             FLEX_ALLOC_STR(e, value, value);
- *             hashmap_entry_init(e, memhash(&key, sizeof(long)));
+ *             hashmap_entry_init(&e->ent, memhash(&key, sizeof(long)));
  *             e->key = key;
  *
  *             flags |= COMPARE_VALUE;
- *             printf("%sfound\n", hashmap_get(&map, e, NULL) ? "" : "not ");
+ *             printf("%sfound\n",
+ *                    hashmap_get(&map, &e->ent, NULL) ? "" : "not ");
  *             free(e);
  *         }
  *
  *         if (!strcmp("has_exact_match_no_heap_alloc", action)) {
  *             struct long2string k;
- *             hashmap_entry_init(&k, memhash(&key, sizeof(long)));
+ *             hashmap_entry_init(&k.ent, memhash(&key, sizeof(long)));
  *             k.key = key;
  *
  *             flags |= COMPARE_VALUE;
- *             printf("%sfound\n", hashmap_get(&map, &k, value) ? "" : "not ");
+ *             printf("%sfound\n",
+ *                    hashmap_get(&map, &k.ent, value) ? "" : "not ");
  *         }
  *
  *         if (!strcmp("end", action)) {
- *             hashmap_free(&map, 1);
+ *             hashmap_free_entries(&map, struct long2string, ent);
  *             break;
  *         }
  *     }
@@ -104,11 +114,11 @@
  * `memihash_cont` is a variant of `memihash` that allows a computation to be
  * continued with another chunk of data.
  */
-extern unsigned int strhash(const char *buf);
-extern unsigned int strihash(const char *buf);
-extern unsigned int memhash(const void *buf, size_t len);
-extern unsigned int memihash(const void *buf, size_t len);
-extern unsigned int memihash_cont(unsigned int hash_seed, const void *buf, size_t len);
+unsigned int strhash(const char *buf);
+unsigned int strihash(const char *buf);
+unsigned int memhash(const void *buf, size_t len);
+unsigned int memihash(const void *buf, size_t len);
+unsigned int memihash_cont(unsigned int hash_seed, const void *buf, size_t len);
 
 /*
  * Converts a cryptographic hash (e.g. SHA-1) into an int-sized hash code
@@ -118,20 +128,20 @@ extern unsigned int memihash_cont(unsign
  * the results will be different on big-endian and little-endian
  * platforms, so they should not be stored or transferred over the net.
  */
-static inline unsigned int sha1hash(const unsigned char *sha1)
+static inline unsigned int oidhash(const struct object_id *oid)
 {
 	/*
-	 * Equivalent to 'return *(unsigned int *)sha1;', but safe on
+	 * Equivalent to 'return *(unsigned int *)oid->hash;', but safe on
 	 * platforms that don't support unaligned reads.
 	 */
 	unsigned int hash;
-	memcpy(&hash, sha1, sizeof(hash));
+	memcpy(&hash, oid->hash, sizeof(hash));
 	return hash;
 }
 
 /*
  * struct hashmap_entry is an opaque structure representing an entry in the
- * hash table, which must be used as first member of user data structures.
+ * hash table.
  * Ideally it should be followed by an int-sized member to prevent unused
  * memory on 64-bit systems due to alignment.
  */
@@ -166,7 +176,8 @@ struct hashmap_entry {
  * The `hashmap_cmp_fn_data` entry is the pointer given in the init function.
  */
 typedef int (*hashmap_cmp_fn)(const void *hashmap_cmp_fn_data,
-			      const void *entry, const void *entry_or_key,
+			      const struct hashmap_entry *entry,
+			      const struct hashmap_entry *entry_or_key,
 			      const void *keydata);
 
 /*
@@ -216,18 +227,25 @@ struct hashmap {
  * parameter may be used to preallocate a sufficiently large table and thus
  * prevent expensive resizing. If 0, the table is dynamically resized.
  */
-extern void hashmap_init(struct hashmap *map,
+void hashmap_init(struct hashmap *map,
 			 hashmap_cmp_fn equals_function,
 			 const void *equals_function_data,
 			 size_t initial_size);
 
+/* internal function for freeing hashmap */
+void hashmap_free_(struct hashmap *map, ssize_t offset);
+
 /*
- * Frees a hashmap structure and allocated memory.
- *
- * If `free_entries` is true, each hashmap_entry in the map is freed as well
- * using stdlibs free().
+ * Frees a hashmap structure and allocated memory, leaves entries undisturbed
  */
-extern void hashmap_free(struct hashmap *map, int free_entries);
+#define hashmap_free(map) hashmap_free_(map, -1)
+
+/*
+ * Frees @map and all entries.  @type is the struct type of the entry
+ * where @member is the hashmap_entry struct used to associate with @map
+ */
+#define hashmap_free_entries(map, type, member) \
+	hashmap_free_(map, offsetof(type, member));
 
 /* hashmap_entry functions */
 
@@ -242,9 +260,9 @@ extern void hashmap_free(struct hashmap
  * your structure was allocated with xmalloc(), you can just free(3) it,
  * and if it is on stack, you can just let it go out of scope).
  */
-static inline void hashmap_entry_init(void *entry, unsigned int hash)
+static inline void hashmap_entry_init(struct hashmap_entry *e,
+					unsigned int hash)
 {
-	struct hashmap_entry *e = entry;
 	e->hash = hash;
 	e->next = NULL;
 }
@@ -284,8 +302,9 @@ static inline unsigned int hashmap_get_s
  * If an entry with matching hash code is found, `key` and `keydata` are passed
  * to `hashmap_cmp_fn` to decide whether the entry matches the key.
  */
-extern void *hashmap_get(const struct hashmap *map, const void *key,
-			 const void *keydata);
+struct hashmap_entry *hashmap_get(const struct hashmap *map,
+				const struct hashmap_entry *key,
+				const void *keydata);
 
 /*
  * Returns the hashmap entry for the specified hash code and key data,
@@ -299,9 +318,10 @@ extern void *hashmap_get(const struct ha
  * `entry_or_key` parameter of `hashmap_cmp_fn` points to a hashmap_entry
  * structure that should not be used in the comparison.
  */
-static inline void *hashmap_get_from_hash(const struct hashmap *map,
-					  unsigned int hash,
-					  const void *keydata)
+static inline struct hashmap_entry *hashmap_get_from_hash(
+					const struct hashmap *map,
+					unsigned int hash,
+					const void *keydata)
 {
 	struct hashmap_entry key;
 	hashmap_entry_init(&key, hash);
@@ -316,7 +336,8 @@ static inline void *hashmap_get_from_has
  * `entry` is the hashmap_entry to start the search from, obtained via a previous
  * call to `hashmap_get` or `hashmap_get_next`.
  */
-extern void *hashmap_get_next(const struct hashmap *map, const void *entry);
+struct hashmap_entry *hashmap_get_next(const struct hashmap *map,
+			const struct hashmap_entry *entry);
 
 /*
  * Adds a hashmap entry. This allows to add duplicate entries (i.e.
@@ -325,7 +346,7 @@ extern void *hashmap_get_next(const stru
  * `map` is the hashmap structure.
  * `entry` is the entry to add.
  */
-extern void hashmap_add(struct hashmap *map, void *entry);
+void hashmap_add(struct hashmap *map, struct hashmap_entry *entry);
 
 /*
  * Adds or replaces a hashmap entry. If the hashmap contains duplicate
@@ -335,7 +356,20 @@ extern void hashmap_add(struct hashmap *
  * `entry` is the entry to add or replace.
  * Returns the replaced entry, or NULL if not found (i.e. the entry was added).
  */
-extern void *hashmap_put(struct hashmap *map, void *entry);
+struct hashmap_entry *hashmap_put(struct hashmap *map,
+				struct hashmap_entry *entry);
+
+/*
+ * Adds or replaces a hashmap entry contained within @keyvar,
+ * where @keyvar is a pointer to a struct containing a
+ * "struct hashmap_entry" @member.
+ *
+ * Returns the replaced pointer which is of the same type as @keyvar,
+ * or NULL if not found.
+ */
+#define hashmap_put_entry(map, keyvar, member) \
+	container_of_or_null_offset(hashmap_put(map, &(keyvar)->member), \
+				OFFSETOF_VAR(keyvar, member))
 
 /*
  * Removes a hashmap entry matching the specified key. If the hashmap contains
@@ -344,8 +378,24 @@ extern void *hashmap_put(struct hashmap
  *
  * Argument explanation is the same as in `hashmap_get`.
  */
-extern void *hashmap_remove(struct hashmap *map, const void *key,
-		const void *keydata);
+struct hashmap_entry *hashmap_remove(struct hashmap *map,
+					const struct hashmap_entry *key,
+					const void *keydata);
+
+/*
+ * Removes a hashmap entry contained within @keyvar,
+ * where @keyvar is a pointer to a struct containing a
+ * "struct hashmap_entry" @member.
+ *
+ * See `hashmap_get` for an explanation of @keydata
+ *
+ * Returns the replaced pointer which is of the same type as @keyvar,
+ * or NULL if not found.
+ */
+#define hashmap_remove_entry(map, keyvar, member, keydata) \
+	container_of_or_null_offset( \
+			hashmap_remove(map, &(keyvar)->member, keydata), \
+			OFFSETOF_VAR(keyvar, member))
 
 /*
  * Returns the `bucket` an entry is stored in.
@@ -365,13 +415,13 @@ struct hashmap_iter {
 };
 
 /* Initializes a `hashmap_iter` structure. */
-extern void hashmap_iter_init(struct hashmap *map, struct hashmap_iter *iter);
+void hashmap_iter_init(struct hashmap *map, struct hashmap_iter *iter);
 
 /* Returns the next hashmap_entry, or NULL if there are no more entries. */
-extern void *hashmap_iter_next(struct hashmap_iter *iter);
+struct hashmap_entry *hashmap_iter_next(struct hashmap_iter *iter);
 
 /* Initializes the iterator and returns the first entry, if any. */
-static inline void *hashmap_iter_first(struct hashmap *map,
+static inline struct hashmap_entry *hashmap_iter_first(struct hashmap *map,
 		struct hashmap_iter *iter)
 {
 	hashmap_iter_init(map, iter);
@@ -379,6 +429,64 @@ static inline void *hashmap_iter_first(s
 }
 
 /*
+ * returns the first entry in @map using @iter, where the entry is of
+ * @type (e.g. "struct foo") and @member is the name of the
+ * "struct hashmap_entry" in @type
+ */
+#define hashmap_iter_first_entry(map, iter, type, member) \
+	container_of_or_null(hashmap_iter_first(map, iter), type, member)
+
+/* internal macro for hashmap_for_each_entry */
+#define hashmap_iter_next_entry_offset(iter, offset) \
+	container_of_or_null_offset(hashmap_iter_next(iter), offset)
+
+/* internal macro for hashmap_for_each_entry */
+#define hashmap_iter_first_entry_offset(map, iter, offset) \
+	container_of_or_null_offset(hashmap_iter_first(map, iter), offset)
+
+/*
+ * iterate through @map using @iter, @var is a pointer to a type
+ * containing a @member which is a "struct hashmap_entry"
+ */
+#define hashmap_for_each_entry(map, iter, var, member) \
+	for (var = hashmap_iter_first_entry_offset(map, iter, \
+						OFFSETOF_VAR(var, member)); \
+		var; \
+		var = hashmap_iter_next_entry_offset(iter, \
+						OFFSETOF_VAR(var, member)))
+
+/*
+ * returns a pointer of type matching @keyvar, or NULL if nothing found.
+ * @keyvar is a pointer to a struct containing a
+ * "struct hashmap_entry" @member.
+ */
+#define hashmap_get_entry(map, keyvar, member, keydata) \
+	container_of_or_null_offset( \
+				hashmap_get(map, &(keyvar)->member, keydata), \
+				OFFSETOF_VAR(keyvar, member))
+
+#define hashmap_get_entry_from_hash(map, hash, keydata, type, member) \
+	container_of_or_null(hashmap_get_from_hash(map, hash, keydata), \
+				type, member)
+/*
+ * returns the next equal pointer to @var, or NULL if not found.
+ * @var is a pointer of any type containing "struct hashmap_entry"
+ * @member is the name of the "struct hashmap_entry" field
+ */
+#define hashmap_get_next_entry(map, var, member) \
+	container_of_or_null_offset(hashmap_get_next(map, &(var)->member), \
+				OFFSETOF_VAR(var, member))
+
+/*
+ * iterate @map starting from @var, where @var is a pointer of @type
+ * and @member is the name of the "struct hashmap_entry" field in @type
+ */
+#define hashmap_for_each_entry_from(map, var, member) \
+	for (; \
+		var; \
+		var = hashmap_get_next_entry(map, var, member))
+
+/*
  * Disable item counting and automatic rehashing when adding/removing items.
  *
  * Normally, the hashmap keeps track of the number of items in the map
@@ -394,7 +502,7 @@ static inline void hashmap_disable_item_
 }
 
 /*
- * Re-enable item couting when adding/removing items.
+ * Re-enable item counting when adding/removing items.
  * If counting is currently disabled, it will force count them.
  * It WILL NOT automatically rehash them.
  */
@@ -429,7 +537,7 @@ static inline void hashmap_enable_item_c
  *
  * Uses a hashmap to store the pool of interned strings.
  */
-extern const void *memintern(const void *data, size_t len);
+const void *memintern(const void *data, size_t len);
 static inline const char *strintern(const char *string)
 {
 	return memintern(string, strlen(string));
diff -pruN 1.2.1+git2.18.0-1/git/help.c 1.2.3+git2.25.1-1/git/help.c
--- 1.2.1+git2.18.0-1/git/help.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/help.c	2020-02-17 04:47:35.000000000 +0000
@@ -34,7 +34,7 @@ static struct category_description main_
 	{ CAT_foreignscminterface, N_("Interacting with Others") },
 	{ CAT_plumbingmanipulators, N_("Low-level Commands / Manipulators") },
 	{ CAT_plumbinginterrogators, N_("Low-level Commands / Interrogators") },
-	{ CAT_synchingrepositories, N_("Low-level Commands / Synching Repositories") },
+	{ CAT_synchingrepositories, N_("Low-level Commands / Syncing Repositories") },
 	{ CAT_purehelpers, N_("Low-level Commands / Internal Helpers") },
 	{ 0, NULL }
 };
@@ -83,8 +83,10 @@ static void print_command_list(const str
 
 	for (i = 0; cmds[i].name; i++) {
 		if (cmds[i].category & mask) {
+			size_t len = strlen(cmds[i].name);
 			printf("   %s   ", cmds[i].name);
-			mput_char(' ', longest - strlen(cmds[i].name));
+			if (longest > len)
+				mput_char(' ', longest - len);
 			puts(_(cmds[i].help));
 		}
 	}
@@ -98,7 +100,8 @@ static int cmd_name_cmp(const void *elem
 	return strcmp(e1->name, e2->name);
 }
 
-static void print_cmd_by_category(const struct category_description *catdesc)
+static void print_cmd_by_category(const struct category_description *catdesc,
+				  int *longest_p)
 {
 	struct cmdname_help *cmds;
 	int longest = 0;
@@ -124,6 +127,8 @@ static void print_cmd_by_category(const
 		print_command_list(cmds, mask, longest);
 	}
 	free(cmds);
+	if (longest_p)
+		*longest_p = longest;
 }
 
 void add_cmdname(struct cmdnames *cmds, const char *name, int len)
@@ -307,7 +312,7 @@ void list_commands(unsigned int colopts,
 void list_common_cmds_help(void)
 {
 	puts(_("These are common Git commands used in various situations:"));
-	print_cmd_by_category(common_categories);
+	print_cmd_by_category(common_categories, NULL);
 }
 
 void list_all_main_cmds(struct string_list *list)
@@ -370,13 +375,6 @@ void list_cmds_by_config(struct string_l
 {
 	const char *cmd_list;
 
-	/*
-	 * There's no actual repository setup at this point (and even
-	 * if there is, we don't really care; only global config
-	 * matters). If we accidentally set up a repository, it's ok
-	 * too since the caller (git --list-cmds=) should exit shortly
-	 * anyway.
-	 */
 	if (git_config_get_string_const("completion.commands", &cmd_list))
 		return;
 
@@ -388,8 +386,8 @@ void list_cmds_by_config(struct string_l
 		const char *p = strchrnul(cmd_list, ' ');
 
 		strbuf_add(&sb, cmd_list, p - cmd_list);
-		if (*cmd_list == '-')
-			string_list_remove(list, cmd_list + 1, 0);
+		if (sb.buf[0] == '-')
+			string_list_remove(list, sb.buf + 1, 0);
 		else
 			string_list_insert(list, sb.buf);
 		strbuf_release(&sb);
@@ -405,13 +403,144 @@ void list_common_guides_help(void)
 		{ CAT_guide, N_("The common Git guides are:") },
 		{ 0, NULL }
 	};
-	print_cmd_by_category(catdesc);
+	print_cmd_by_category(catdesc, NULL);
 	putchar('\n');
 }
 
+struct slot_expansion {
+	const char *prefix;
+	const char *placeholder;
+	void (*fn)(struct string_list *list, const char *prefix);
+	int found;
+};
+
+void list_config_help(int for_human)
+{
+	struct slot_expansion slot_expansions[] = {
+		{ "advice", "*", list_config_advices },
+		{ "color.branch", "<slot>", list_config_color_branch_slots },
+		{ "color.decorate", "<slot>", list_config_color_decorate_slots },
+		{ "color.diff", "<slot>", list_config_color_diff_slots },
+		{ "color.grep", "<slot>", list_config_color_grep_slots },
+		{ "color.interactive", "<slot>", list_config_color_interactive_slots },
+		{ "color.remote", "<slot>", list_config_color_sideband_slots },
+		{ "color.status", "<slot>", list_config_color_status_slots },
+		{ "fsck", "<msg-id>", list_config_fsck_msg_ids },
+		{ "receive.fsck", "<msg-id>", list_config_fsck_msg_ids },
+		{ NULL, NULL, NULL }
+	};
+	const char **p;
+	struct slot_expansion *e;
+	struct string_list keys = STRING_LIST_INIT_DUP;
+	int i;
+
+	for (p = config_name_list; *p; p++) {
+		const char *var = *p;
+		struct strbuf sb = STRBUF_INIT;
+
+		for (e = slot_expansions; e->prefix; e++) {
+
+			strbuf_reset(&sb);
+			strbuf_addf(&sb, "%s.%s", e->prefix, e->placeholder);
+			if (!strcasecmp(var, sb.buf)) {
+				e->fn(&keys, e->prefix);
+				e->found++;
+				break;
+			}
+		}
+		strbuf_release(&sb);
+		if (!e->prefix)
+			string_list_append(&keys, var);
+	}
+
+	for (e = slot_expansions; e->prefix; e++)
+		if (!e->found)
+			BUG("slot_expansion %s.%s is not used",
+			    e->prefix, e->placeholder);
+
+	string_list_sort(&keys);
+	for (i = 0; i < keys.nr; i++) {
+		const char *var = keys.items[i].string;
+		const char *wildcard, *tag, *cut;
+
+		if (for_human) {
+			puts(var);
+			continue;
+		}
+
+		wildcard = strchr(var, '*');
+		tag = strchr(var, '<');
+
+		if (!wildcard && !tag) {
+			puts(var);
+			continue;
+		}
+
+		if (wildcard && !tag)
+			cut = wildcard;
+		else if (!wildcard && tag)
+			cut = tag;
+		else
+			cut = wildcard < tag ? wildcard : tag;
+
+		/*
+		 * We may produce duplicates, but that's up to
+		 * git-completion.bash to handle
+		 */
+		printf("%.*s\n", (int)(cut - var), var);
+	}
+	string_list_clear(&keys, 0);
+}
+
+static int get_alias(const char *var, const char *value, void *data)
+{
+	struct string_list *list = data;
+
+	if (skip_prefix(var, "alias.", &var))
+		string_list_append(list, var)->util = xstrdup(value);
+
+	return 0;
+}
+
 void list_all_cmds_help(void)
 {
-	print_cmd_by_category(main_categories);
+	struct string_list others = STRING_LIST_INIT_DUP;
+	struct string_list alias_list = STRING_LIST_INIT_DUP;
+	struct cmdname_help *aliases;
+	int i, longest;
+
+	printf_ln(_("See 'git help <command>' to read about a specific subcommand"));
+	print_cmd_by_category(main_categories, &longest);
+
+	list_all_other_cmds(&others);
+	if (others.nr)
+		printf("\n%s\n", _("External commands"));
+	for (i = 0; i < others.nr; i++)
+		printf("   %s\n", others.items[i].string);
+	string_list_clear(&others, 0);
+
+	git_config(get_alias, &alias_list);
+	string_list_sort(&alias_list);
+
+	for (i = 0; i < alias_list.nr; i++) {
+		size_t len = strlen(alias_list.items[i].string);
+		if (longest < len)
+			longest = len;
+	}
+
+	if (alias_list.nr) {
+		printf("\n%s\n", _("Command aliases"));
+		ALLOC_ARRAY(aliases, alias_list.nr + 1);
+		for (i = 0; i < alias_list.nr; i++) {
+			aliases[i].name = alias_list.items[i].string;
+			aliases[i].help = alias_list.items[i].util;
+			aliases[i].category = 1;
+		}
+		aliases[alias_list.nr].name = NULL;
+		print_command_list(aliases, 1, longest);
+		free(aliases);
+	}
+	string_list_clear(&alias_list, 1);
 }
 
 int is_in_cmdlist(struct cmdnames *c, const char *s)
@@ -609,6 +738,7 @@ int cmd_version(int argc, const char **a
 		else
 			printf("no commit associated with this build\n");
 		printf("sizeof-long: %d\n", (int)sizeof(long));
+		printf("sizeof-size_t: %d\n", (int)sizeof(size_t));
 		/* NEEDSWORK: also save and output GIT-BUILD_OPTIONS? */
 	}
 	return 0;
@@ -624,19 +754,19 @@ static int append_similar_ref(const char
 {
 	struct similar_ref_cb *cb = (struct similar_ref_cb *)(cb_data);
 	char *branch = strrchr(refname, '/') + 1;
-	const char *remote;
 
 	/* A remote branch of the same name is deemed similar */
-	if (skip_prefix(refname, "refs/remotes/", &remote) &&
+	if (starts_with(refname, "refs/remotes/") &&
 	    !strcmp(branch, cb->base_ref))
-		string_list_append(cb->similar_refs, remote);
+		string_list_append_nodup(cb->similar_refs,
+					 shorten_unambiguous_ref(refname, 1));
 	return 0;
 }
 
 static struct string_list guess_refs(const char *ref)
 {
 	struct similar_ref_cb ref_cb;
-	struct string_list similar_refs = STRING_LIST_INIT_NODUP;
+	struct string_list similar_refs = STRING_LIST_INIT_DUP;
 
 	ref_cb.base_ref = ref;
 	ref_cb.similar_refs = &similar_refs;
@@ -644,7 +774,8 @@ static struct string_list guess_refs(con
 	return similar_refs;
 }
 
-void help_unknown_ref(const char *ref, const char *cmd, const char *error)
+NORETURN void help_unknown_ref(const char *ref, const char *cmd,
+			       const char *error)
 {
 	int i;
 	struct string_list suggested_refs = guess_refs(ref);
diff -pruN 1.2.1+git2.18.0-1/git/help.h 1.2.3+git2.25.1-1/git/help.h
--- 1.2.1+git2.18.0-1/git/help.h	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/help.h	2020-02-17 04:47:35.000000000 +0000
@@ -1,7 +1,8 @@
 #ifndef HELP_H
 #define HELP_H
 
-struct string_list;
+#include "string-list.h"
+#include "strbuf.h"
 
 struct cmdnames {
 	int alloc;
@@ -14,32 +15,75 @@ struct cmdnames {
 
 static inline void mput_char(char c, unsigned int num)
 {
-	while(num--)
+	while (num--)
 		putchar(c);
 }
 
-extern void list_common_cmds_help(void);
-extern void list_all_cmds_help(void);
-extern void list_common_guides_help(void);
-
-extern void list_all_main_cmds(struct string_list *list);
-extern void list_all_other_cmds(struct string_list *list);
-extern void list_cmds_by_category(struct string_list *list,
-				  const char *category);
-extern void list_cmds_by_config(struct string_list *list);
-extern const char *help_unknown_cmd(const char *cmd);
-extern void load_command_list(const char *prefix,
-			      struct cmdnames *main_cmds,
-			      struct cmdnames *other_cmds);
-extern void add_cmdname(struct cmdnames *cmds, const char *name, int len);
+void list_common_cmds_help(void);
+void list_all_cmds_help(void);
+void list_common_guides_help(void);
+void list_config_help(int for_human);
+
+void list_all_main_cmds(struct string_list *list);
+void list_all_other_cmds(struct string_list *list);
+void list_cmds_by_category(struct string_list *list,
+			   const char *category);
+void list_cmds_by_config(struct string_list *list);
+const char *help_unknown_cmd(const char *cmd);
+void load_command_list(const char *prefix,
+		       struct cmdnames *main_cmds,
+		       struct cmdnames *other_cmds);
+void add_cmdname(struct cmdnames *cmds, const char *name, int len);
 /* Here we require that excludes is a sorted list. */
-extern void exclude_cmds(struct cmdnames *cmds, struct cmdnames *excludes);
-extern int is_in_cmdlist(struct cmdnames *cmds, const char *name);
-extern void list_commands(unsigned int colopts, struct cmdnames *main_cmds, struct cmdnames *other_cmds);
+void exclude_cmds(struct cmdnames *cmds, struct cmdnames *excludes);
+int is_in_cmdlist(struct cmdnames *cmds, const char *name);
+void list_commands(unsigned int colopts, struct cmdnames *main_cmds, struct cmdnames *other_cmds);
 
 /*
  * call this to die(), when it is suspected that the user mistyped a
  * ref to the command, to give suggested "correct" refs.
  */
-extern void help_unknown_ref(const char *ref, const char *cmd, const char *error);
+NORETURN void help_unknown_ref(const char *ref, const char *cmd, const char *error);
+
+static inline void list_config_item(struct string_list *list,
+				    const char *prefix,
+				    const char *str)
+{
+	string_list_append_nodup(list, xstrfmt("%s.%s", prefix, str));
+}
+
+#define define_list_config_array(array)					\
+void list_config_##array(struct string_list *list, const char *prefix)	\
+{									\
+	int i;								\
+	for (i = 0; i < ARRAY_SIZE(array); i++)				\
+		if (array[i])						\
+			list_config_item(list, prefix, array[i]);	\
+}									\
+struct string_list
+
+#define define_list_config_array_extra(array, values)			\
+void list_config_##array(struct string_list *list, const char *prefix)	\
+{									\
+	int i;								\
+	static const char *extra[] = values;				\
+	for (i = 0; i < ARRAY_SIZE(extra); i++)				\
+		list_config_item(list, prefix, extra[i]);		\
+	for (i = 0; i < ARRAY_SIZE(array); i++)				\
+		if (array[i])						\
+			list_config_item(list, prefix, array[i]);	\
+}									\
+struct string_list
+
+/* These are actually scattered over many C files */
+void list_config_advices(struct string_list *list, const char *prefix);
+void list_config_color_branch_slots(struct string_list *list, const char *prefix);
+void list_config_color_decorate_slots(struct string_list *list, const char *prefix);
+void list_config_color_diff_slots(struct string_list *list, const char *prefix);
+void list_config_color_grep_slots(struct string_list *list, const char *prefix);
+void list_config_color_interactive_slots(struct string_list *list, const char *prefix);
+void list_config_color_status_slots(struct string_list *list, const char *prefix);
+void list_config_color_sideband_slots(struct string_list *list, const char *prefix);
+void list_config_fsck_msg_ids(struct string_list *list, const char *prefix);
+
 #endif /* HELP_H */
diff -pruN 1.2.1+git2.18.0-1/git/hex.c 1.2.3+git2.25.1-1/git/hex.c
--- 1.2.1+git2.18.0-1/git/hex.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/hex.c	2020-02-17 04:47:35.000000000 +0000
@@ -50,7 +50,7 @@ int hex_to_bytes(unsigned char *binary,
 int get_sha1_hex(const char *hex, unsigned char *sha1)
 {
 	int i;
-	for (i = 0; i < GIT_SHA1_RAWSZ; i++) {
+	for (i = 0; i < the_hash_algo->rawsz; i++) {
 		int val = hex2chr(hex);
 		if (val < 0)
 			return -1;
@@ -69,18 +69,19 @@ int parse_oid_hex(const char *hex, struc
 {
 	int ret = get_oid_hex(hex, oid);
 	if (!ret)
-		*end = hex + GIT_SHA1_HEXSZ;
+		*end = hex + the_hash_algo->hexsz;
 	return ret;
 }
 
-char *sha1_to_hex_r(char *buffer, const unsigned char *sha1)
+char *hash_to_hex_algop_r(char *buffer, const unsigned char *hash,
+			  const struct git_hash_algo *algop)
 {
 	static const char hex[] = "0123456789abcdef";
 	char *buf = buffer;
 	int i;
 
-	for (i = 0; i < GIT_SHA1_RAWSZ; i++) {
-		unsigned int val = *sha1++;
+	for (i = 0; i < algop->rawsz; i++) {
+		unsigned int val = *hash++;
 		*buf++ = hex[val >> 4];
 		*buf++ = hex[val & 0xf];
 	}
@@ -91,18 +92,23 @@ char *sha1_to_hex_r(char *buffer, const
 
 char *oid_to_hex_r(char *buffer, const struct object_id *oid)
 {
-	return sha1_to_hex_r(buffer, oid->hash);
+	return hash_to_hex_algop_r(buffer, oid->hash, the_hash_algo);
 }
 
-char *sha1_to_hex(const unsigned char *sha1)
+char *hash_to_hex_algop(const unsigned char *hash, const struct git_hash_algo *algop)
 {
 	static int bufno;
 	static char hexbuffer[4][GIT_MAX_HEXSZ + 1];
 	bufno = (bufno + 1) % ARRAY_SIZE(hexbuffer);
-	return sha1_to_hex_r(hexbuffer[bufno], sha1);
+	return hash_to_hex_algop_r(hexbuffer[bufno], hash, algop);
+}
+
+char *hash_to_hex(const unsigned char *hash)
+{
+	return hash_to_hex_algop(hash, the_hash_algo);
 }
 
 char *oid_to_hex(const struct object_id *oid)
 {
-	return sha1_to_hex(oid->hash);
+	return hash_to_hex_algop(oid->hash, the_hash_algo);
 }
diff -pruN 1.2.1+git2.18.0-1/git/http-backend.c 1.2.3+git2.25.1-1/git/http-backend.c
--- 1.2.1+git2.18.0-1/git/http-backend.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/http-backend.c	2020-02-17 04:47:35.000000000 +0000
@@ -279,12 +279,18 @@ static struct rpc_service *select_servic
 	return svc;
 }
 
+static void write_to_child(int out, const unsigned char *buf, ssize_t len, const char *prog_name)
+{
+	if (write_in_full(out, buf, len) < 0)
+		die("unable to write to '%s'", prog_name);
+}
+
 /*
  * This is basically strbuf_read(), except that if we
  * hit max_request_buffer we die (we'd rather reject a
  * maliciously large request than chew up infinite memory).
  */
-static ssize_t read_request(int fd, unsigned char **out)
+static ssize_t read_request_eof(int fd, unsigned char **out)
 {
 	size_t len = 0, alloc = 8192;
 	unsigned char *buf = xmalloc(alloc);
@@ -321,13 +327,54 @@ static ssize_t read_request(int fd, unsi
 	}
 }
 
-static void inflate_request(const char *prog_name, int out, int buffer_input)
+static ssize_t read_request_fixed_len(int fd, ssize_t req_len, unsigned char **out)
+{
+	unsigned char *buf = NULL;
+	ssize_t cnt = 0;
+
+	if (max_request_buffer < req_len) {
+		die("request was larger than our maximum size (%lu): "
+		    "%" PRIuMAX "; try setting GIT_HTTP_MAX_REQUEST_BUFFER",
+		    max_request_buffer, (uintmax_t)req_len);
+	}
+
+	buf = xmalloc(req_len);
+	cnt = read_in_full(fd, buf, req_len);
+	if (cnt < 0) {
+		free(buf);
+		return -1;
+	}
+	*out = buf;
+	return cnt;
+}
+
+static ssize_t get_content_length(void)
+{
+	ssize_t val = -1;
+	const char *str = getenv("CONTENT_LENGTH");
+
+	if (str && *str && !git_parse_ssize_t(str, &val))
+		die("failed to parse CONTENT_LENGTH: %s", str);
+	return val;
+}
+
+static ssize_t read_request(int fd, unsigned char **out, ssize_t req_len)
+{
+	if (req_len < 0)
+		return read_request_eof(fd, out);
+	else
+		return read_request_fixed_len(fd, req_len, out);
+}
+
+static void inflate_request(const char *prog_name, int out, int buffer_input, ssize_t req_len)
 {
 	git_zstream stream;
 	unsigned char *full_request = NULL;
 	unsigned char in_buf[8192];
 	unsigned char out_buf[8192];
 	unsigned long cnt = 0;
+	int req_len_defined = req_len >= 0;
+	size_t req_remaining_len = req_len;
 
 	memset(&stream, 0, sizeof(stream));
 	git_inflate_init_gzip_only(&stream);
@@ -339,11 +386,18 @@ static void inflate_request(const char *
 			if (full_request)
 				n = 0; /* nothing left to read */
 			else
-				n = read_request(0, &full_request);
+				n = read_request(0, &full_request, req_len);
 			stream.next_in = full_request;
 		} else {
-			n = xread(0, in_buf, sizeof(in_buf));
+			ssize_t buffer_len;
+			if (req_len_defined && req_remaining_len <= sizeof(in_buf))
+				buffer_len = req_remaining_len;
+			else
+				buffer_len = sizeof(in_buf);
+			n = xread(0, in_buf, buffer_len);
 			stream.next_in = in_buf;
+			if (req_len_defined && n > 0)
+				req_remaining_len -= n;
 		}
 
 		if (n <= 0)
@@ -361,9 +415,8 @@ static void inflate_request(const char *
 				die("zlib error inflating request, result %d", ret);
 
 			n = stream.total_out - cnt;
-			if (write_in_full(out, out_buf, n) < 0)
-				die("%s aborted reading request", prog_name);
-			cnt += n;
+			write_to_child(out, out_buf, stream.total_out - cnt, prog_name);
+			cnt = stream.total_out;
 
 			if (ret == Z_STREAM_END)
 				goto done;
@@ -376,18 +429,34 @@ done:
 	free(full_request);
 }
 
-static void copy_request(const char *prog_name, int out)
+static void copy_request(const char *prog_name, int out, ssize_t req_len)
 {
 	unsigned char *buf;
-	ssize_t n = read_request(0, &buf);
+	ssize_t n = read_request(0, &buf, req_len);
 	if (n < 0)
 		die_errno("error reading request body");
-	if (write_in_full(out, buf, n) < 0)
-		die("%s aborted reading request", prog_name);
+	write_to_child(out, buf, n, prog_name);
 	close(out);
 	free(buf);
 }
 
+static void pipe_fixed_length(const char *prog_name, int out, size_t req_len)
+{
+	unsigned char buf[8192];
+	size_t remaining_len = req_len;
+
+	while (remaining_len > 0) {
+		size_t chunk_length = remaining_len > sizeof(buf) ? sizeof(buf) : remaining_len;
+		ssize_t n = xread(0, buf, chunk_length);
+		if (n < 0)
+			die_errno("Reading request failed");
+		write_to_child(out, buf, n, prog_name);
+		remaining_len -= n;
+	}
+
+	close(out);
+}
+
 static void run_service(const char **argv, int buffer_input)
 {
 	const char *encoding = getenv("HTTP_CONTENT_ENCODING");
@@ -395,6 +464,7 @@ static void run_service(const char **arg
 	const char *host = getenv("REMOTE_ADDR");
 	int gzipped_request = 0;
 	struct child_process cld = CHILD_PROCESS_INIT;
+	ssize_t req_len = get_content_length();
 
 	if (encoding && !strcmp(encoding, "gzip"))
 		gzipped_request = 1;
@@ -413,17 +483,21 @@ static void run_service(const char **arg
 				 "GIT_COMMITTER_EMAIL=%s@http.%s", user, host);
 
 	cld.argv = argv;
-	if (buffer_input || gzipped_request)
+	if (buffer_input || gzipped_request || req_len >= 0)
 		cld.in = -1;
 	cld.git_cmd = 1;
+	cld.clean_on_exit = 1;
+	cld.wait_after_clean = 1;
 	if (start_command(&cld))
 		exit(1);
 
 	close(1);
 	if (gzipped_request)
-		inflate_request(argv[0], cld.in, buffer_input);
+		inflate_request(argv[0], cld.in, buffer_input, req_len);
 	else if (buffer_input)
-		copy_request(argv[0], cld.in);
+		copy_request(argv[0], cld.in, req_len);
+	else if (req_len >= 0)
+		pipe_fixed_length(argv[0], cld.in, req_len);
 	else
 		close(0);
 
@@ -436,13 +510,13 @@ static int show_text_ref(const char *nam
 {
 	const char *name_nons = strip_namespace(name);
 	struct strbuf *buf = cb_data;
-	struct object *o = parse_object(oid);
+	struct object *o = parse_object(the_repository, oid);
 	if (!o)
 		return 0;
 
 	strbuf_addf(buf, "%s\t%s\n", oid_to_hex(oid), name_nons);
 	if (o->type == OBJ_TAG) {
-		o = deref_tag(o, name, 0);
+		o = deref_tag(the_repository, o, name, 0);
 		if (!o)
 			return 0;
 		strbuf_addf(buf, "%s\t%s^{}\n", oid_to_hex(&o->oid),
@@ -523,13 +597,13 @@ static void get_info_packs(struct strbuf
 	size_t cnt = 0;
 
 	select_getanyfile(hdr);
-	for (p = get_packed_git(the_repository); p; p = p->next) {
+	for (p = get_all_packs(the_repository); p; p = p->next) {
 		if (p->pack_local)
 			cnt++;
 	}
 
 	strbuf_grow(&buf, cnt * 53 + 2);
-	for (p = get_packed_git(the_repository); p; p = p->next) {
+	for (p = get_all_packs(the_repository); p; p = p->next) {
 		if (p->pack_local)
 			strbuf_addf(&buf, "P %s\n", p->pack_name + objdirlen + 6);
 	}
@@ -637,8 +711,11 @@ static struct service_cmd {
 	{"GET", "/objects/info/http-alternates$", get_text_file},
 	{"GET", "/objects/info/packs$", get_info_packs},
 	{"GET", "/objects/[0-9a-f]{2}/[0-9a-f]{38}$", get_loose_object},
+	{"GET", "/objects/[0-9a-f]{2}/[0-9a-f]{62}$", get_loose_object},
 	{"GET", "/objects/pack/pack-[0-9a-f]{40}\\.pack$", get_pack_file},
+	{"GET", "/objects/pack/pack-[0-9a-f]{64}\\.pack$", get_pack_file},
 	{"GET", "/objects/pack/pack-[0-9a-f]{40}\\.idx$", get_idx_file},
+	{"GET", "/objects/pack/pack-[0-9a-f]{64}\\.idx$", get_idx_file},
 
 	{"POST", "/git-upload-pack$", service_rpc},
 	{"POST", "/git-receive-pack$", service_rpc}
diff -pruN 1.2.1+git2.18.0-1/git/http.c 1.2.3+git2.25.1-1/git/http.c
--- 1.2.1+git2.18.0-1/git/http.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/http.c	2020-02-17 04:47:35.000000000 +0000
@@ -48,6 +48,7 @@ char curl_errorstr[CURL_ERROR_SIZE];
 
 static int curl_ssl_verify = -1;
 static int curl_ssl_try;
+static const char *curl_http_version = NULL;
 static const char *ssl_cert;
 static const char *ssl_cipherlist;
 static const char *ssl_version;
@@ -149,12 +150,22 @@ static unsigned long empty_auth_useless
 
 static struct curl_slist *pragma_header;
 static struct curl_slist *no_pragma_header;
-static struct curl_slist *extra_http_headers;
+static struct string_list extra_http_headers = STRING_LIST_INIT_DUP;
 
 static struct active_request_slot *active_queue_head;
 
 static char *cached_accept_language;
 
+static char *http_ssl_backend;
+
+static int http_schannel_check_revoke = 1;
+/*
+ * With the backend being set to `schannel`, setting sslCAinfo would override
+ * the Certificate Store in cURL v7.60.0 and later, which is not what we want
+ * by default.
+ */
+static int http_schannel_use_ssl_cainfo;
+
 size_t fread_buffer(char *ptr, size_t eltsize, size_t nmemb, void *buffer_)
 {
 	size_t size = eltsize * nmemb;
@@ -165,7 +176,7 @@ size_t fread_buffer(char *ptr, size_t el
 	memcpy(ptr, buffer->buf.buf + buffer->posn, size);
 	buffer->posn += size;
 
-	return size;
+	return size / eltsize;
 }
 
 #ifndef NO_CURL_IOCTL
@@ -193,12 +204,12 @@ size_t fwrite_buffer(char *ptr, size_t e
 	struct strbuf *buffer = buffer_;
 
 	strbuf_add(buffer, ptr, size);
-	return size;
+	return nmemb;
 }
 
 size_t fwrite_null(char *ptr, size_t eltsize, size_t nmemb, void *strbuf)
 {
-	return eltsize * nmemb;
+	return nmemb;
 }
 
 static void closedown_active_slot(struct active_request_slot *slot)
@@ -274,6 +285,9 @@ static void process_curl_messages(void)
 
 static int http_options(const char *var, const char *value, void *cb)
 {
+	if (!strcmp("http.version", var)) {
+		return git_config_string(&curl_http_version, var, value);
+	}
 	if (!strcmp("http.sslverify", var)) {
 		curl_ssl_verify = git_config_bool(var, value);
 		return 0;
@@ -302,6 +316,22 @@ static int http_options(const char *var,
 		curl_ssl_try = git_config_bool(var, value);
 		return 0;
 	}
+	if (!strcmp("http.sslbackend", var)) {
+		free(http_ssl_backend);
+		http_ssl_backend = xstrdup_or_null(value);
+		return 0;
+	}
+
+	if (!strcmp("http.schannelcheckrevoke", var)) {
+		http_schannel_check_revoke = git_config_bool(var, value);
+		return 0;
+	}
+
+	if (!strcmp("http.schannelusesslcainfo", var)) {
+		http_schannel_use_ssl_cainfo = git_config_bool(var, value);
+		return 0;
+	}
+
 	if (!strcmp("http.minsessions", var)) {
 		min_curl_sessions = git_config_int(var, value);
 #ifndef USE_CURL_MULTI
@@ -384,11 +414,9 @@ static int http_options(const char *var,
 		if (!value) {
 			return config_error_nonbool(var);
 		} else if (!*value) {
-			curl_slist_free_all(extra_http_headers);
-			extra_http_headers = NULL;
+			string_list_clear(&extra_http_headers, 0);
 		} else {
-			extra_http_headers =
-				curl_slist_append(extra_http_headers, value);
+			string_list_append(&extra_http_headers, value);
 		}
 		return 0;
 	}
@@ -483,9 +511,11 @@ static void set_proxyauth_name_password(
 #else
 		struct strbuf s = STRBUF_INIT;
 
-		strbuf_addstr_urlencode(&s, proxy_auth.username, 1);
+		strbuf_addstr_urlencode(&s, proxy_auth.username,
+					is_rfc3986_unreserved);
 		strbuf_addch(&s, ':');
-		strbuf_addstr_urlencode(&s, proxy_auth.password, 1);
+		strbuf_addstr_urlencode(&s, proxy_auth.password,
+					is_rfc3986_unreserved);
 		curl_proxyuserpwd = strbuf_detach(&s, NULL);
 		curl_easy_setopt(result, CURLOPT_PROXYUSERPWD, curl_proxyuserpwd);
 #endif
@@ -763,6 +793,31 @@ static long get_curl_allowed_protocols(i
 }
 #endif
 
+#if LIBCURL_VERSION_NUM >=0x072f00
+static int get_curl_http_version_opt(const char *version_string, long *opt)
+{
+	int i;
+	static struct {
+		const char *name;
+		long opt_token;
+	} choice[] = {
+		{ "HTTP/1.1", CURL_HTTP_VERSION_1_1 },
+		{ "HTTP/2", CURL_HTTP_VERSION_2 }
+	};
+
+	for (i = 0; i < ARRAY_SIZE(choice); i++) {
+		if (!strcmp(version_string, choice[i].name)) {
+			*opt = choice[i].opt_token;
+			return 0;
+		}
+	}
+
+	warning("unknown value given to http.version: '%s'", version_string);
+	return -1; /* not found */
+}
+
+#endif
+
 static CURL *get_curl_handle(void)
 {
 	CURL *result = curl_easy_init();
@@ -780,6 +835,16 @@ static CURL *get_curl_handle(void)
 		curl_easy_setopt(result, CURLOPT_SSL_VERIFYHOST, 2);
 	}
 
+#if LIBCURL_VERSION_NUM >= 0x072f00 // 7.47.0
+    if (curl_http_version) {
+		long opt;
+		if (!get_curl_http_version_opt(curl_http_version, &opt)) {
+			/* Set request use http version */
+			curl_easy_setopt(result, CURLOPT_HTTP_VERSION, opt);
+		}
+    }
+#endif
+
 #if LIBCURL_VERSION_NUM >= 0x070907
 	curl_easy_setopt(result, CURLOPT_NETRC, CURL_NETRC_OPTIONAL);
 #endif
@@ -803,6 +868,15 @@ static CURL *get_curl_handle(void)
 	}
 #endif
 
+	if (http_ssl_backend && !strcmp("schannel", http_ssl_backend) &&
+	    !http_schannel_check_revoke) {
+#if LIBCURL_VERSION_NUM >= 0x072c00
+		curl_easy_setopt(result, CURLOPT_SSL_OPTIONS, CURLSSLOPT_NO_REVOKE);
+#else
+		warning(_("CURLSSLOPT_NO_REVOKE not supported with cURL < 7.44.0"));
+#endif
+	}
+
 	if (http_proactive_auth)
 		init_curl_http_auth(result);
 
@@ -844,7 +918,13 @@ static CURL *get_curl_handle(void)
 	if (ssl_pinnedkey != NULL)
 		curl_easy_setopt(result, CURLOPT_PINNEDPUBLICKEY, ssl_pinnedkey);
 #endif
-	if (ssl_cainfo != NULL)
+	if (http_ssl_backend && !strcmp("schannel", http_ssl_backend) &&
+	    !http_schannel_use_ssl_cainfo) {
+		curl_easy_setopt(result, CURLOPT_CAINFO, NULL);
+#if LIBCURL_VERSION_NUM >= 0x073400
+		curl_easy_setopt(result, CURLOPT_PROXY_CAINFO, NULL);
+#endif
+	} else if (ssl_cainfo != NULL)
 		curl_easy_setopt(result, CURLOPT_CAINFO, ssl_cainfo);
 
 	if (curl_low_speed_limit > 0 && curl_low_speed_time > 0) {
@@ -866,8 +946,7 @@ static CURL *get_curl_handle(void)
 	curl_easy_setopt(result, CURLOPT_PROTOCOLS,
 			 get_curl_allowed_protocols(-1));
 #else
-	warning("protocol restrictions not applied to curl redirects because\n"
-		"your curl version is too old (>= 7.19.4)");
+	warning(_("Protocol restrictions not supported with cURL < 7.19.4"));
 #endif
 	if (getenv("GIT_CURL_VERBOSE"))
 		curl_easy_setopt(result, CURLOPT_VERBOSE, 1L);
@@ -994,6 +1073,34 @@ void http_init(struct remote *remote, co
 
 	git_config(urlmatch_config_entry, &config);
 	free(normalized_url);
+	string_list_clear(&config.vars, 1);
+
+#if LIBCURL_VERSION_NUM >= 0x073800
+	if (http_ssl_backend) {
+		const curl_ssl_backend **backends;
+		struct strbuf buf = STRBUF_INIT;
+		int i;
+
+		switch (curl_global_sslset(-1, http_ssl_backend, &backends)) {
+		case CURLSSLSET_UNKNOWN_BACKEND:
+			strbuf_addf(&buf, _("Unsupported SSL backend '%s'. "
+					    "Supported SSL backends:"),
+					    http_ssl_backend);
+			for (i = 0; backends[i]; i++)
+				strbuf_addf(&buf, "\n\t%s", backends[i]->name);
+			die("%s", buf.buf);
+		case CURLSSLSET_NO_BACKENDS:
+			die(_("Could not set SSL backend to '%s': "
+			      "cURL was built without SSL backends"),
+			    http_ssl_backend);
+		case CURLSSLSET_TOO_LATE:
+			die(_("Could not set SSL backend to '%s': already set"),
+			    http_ssl_backend);
+		case CURLSSLSET_OK:
+			break; /* Okay! */
+		}
+	}
+#endif
 
 	if (curl_global_init(CURL_GLOBAL_ALL) != CURLE_OK)
 		die("curl_global_init failed");
@@ -1093,8 +1200,7 @@ void http_cleanup(void)
 #endif
 	curl_global_cleanup();
 
-	curl_slist_free_all(extra_http_headers);
-	extra_http_headers = NULL;
+	string_list_clear(&extra_http_headers, 0);
 
 	curl_slist_free_all(pragma_header);
 	pragma_header = NULL;
@@ -1438,7 +1544,8 @@ char *get_remote_object_url(const char *
 	return strbuf_detach(&buf, NULL);
 }
 
-static int handle_curl_result(struct slot_results *results)
+void normalize_curl_result(CURLcode *result, long http_code,
+			   char *errorstr, size_t errorlen)
 {
 	/*
 	 * If we see a failing http code with CURLE_OK, we have turned off
@@ -1448,19 +1555,24 @@ static int handle_curl_result(struct slo
 	 * Likewise, if we see a redirect (30x code), that means we turned off
 	 * redirect-following, and we should treat the result as an error.
 	 */
-	if (results->curl_result == CURLE_OK &&
-	    results->http_code >= 300) {
-		results->curl_result = CURLE_HTTP_RETURNED_ERROR;
+	if (*result == CURLE_OK && http_code >= 300) {
+		*result = CURLE_HTTP_RETURNED_ERROR;
 		/*
 		 * Normally curl will already have put the "reason phrase"
 		 * from the server into curl_errorstr; unfortunately without
 		 * FAILONERROR it is lost, so we can give only the numeric
 		 * status code.
 		 */
-		xsnprintf(curl_errorstr, sizeof(curl_errorstr),
+		xsnprintf(errorstr, errorlen,
 			  "The requested URL returned error: %ld",
-			  results->http_code);
+			  http_code);
 	}
+}
+
+static int handle_curl_result(struct slot_results *results)
+{
+	normalize_curl_result(&results->curl_result, results->http_code,
+			      curl_errorstr, sizeof(curl_errorstr));
 
 	if (results->curl_result == CURLE_OK) {
 		credential_approve(&http_auth);
@@ -1512,10 +1624,11 @@ int run_one_slot(struct active_request_s
 
 struct curl_slist *http_copy_default_headers(void)
 {
-	struct curl_slist *headers = NULL, *h;
+	struct curl_slist *headers = NULL;
+	const struct string_list_item *item;
 
-	for (h = extra_http_headers; h; h = h->next)
-		headers = curl_slist_append(headers, h->data);
+	for_each_string_list_item(item, &extra_http_headers)
+		headers = curl_slist_append(headers, item->string);
 
 	return headers;
 }
@@ -1770,8 +1883,6 @@ static int http_request(const char *url,
 	strbuf_addstr(&buf, "Pragma:");
 	if (options && options->no_cache)
 		strbuf_addstr(&buf, " no-cache");
-	if (options && options->keep_error)
-		curl_easy_setopt(slot->curl, CURLOPT_FAILONERROR, 0);
 	if (options && options->initial_request &&
 	    http_follow_config == HTTP_FOLLOW_INITIAL)
 		curl_easy_setopt(slot->curl, CURLOPT_FOLLOWLOCATION, 1);
@@ -1789,6 +1900,7 @@ static int http_request(const char *url,
 	curl_easy_setopt(slot->curl, CURLOPT_URL, url);
 	curl_easy_setopt(slot->curl, CURLOPT_HTTPHEADER, headers);
 	curl_easy_setopt(slot->curl, CURLOPT_ENCODING, "");
+	curl_easy_setopt(slot->curl, CURLOPT_FAILONERROR, 0);
 
 	ret = run_one_slot(slot, &results);
 
@@ -1883,19 +1995,26 @@ static int http_request_reauth(const cha
 		return ret;
 
 	/*
-	 * If we are using KEEP_ERROR, the previous request may have
-	 * put cruft into our output stream; we should clear it out before
-	 * making our next request. We only know how to do this for
-	 * the strbuf case, but that is enough to satisfy current callers.
+	 * The previous request may have put cruft into our output stream; we
+	 * should clear it out before making our next request.
 	 */
-	if (options && options->keep_error) {
-		switch (target) {
-		case HTTP_REQUEST_STRBUF:
-			strbuf_reset(result);
-			break;
-		default:
-			BUG("HTTP_KEEP_ERROR is only supported with strbufs");
+	switch (target) {
+	case HTTP_REQUEST_STRBUF:
+		strbuf_reset(result);
+		break;
+	case HTTP_REQUEST_FILE:
+		if (fflush(result)) {
+			error_errno("unable to flush a file");
+			return HTTP_START_FAILED;
+		}
+		rewind(result);
+		if (ftruncate(fileno(result), 0) < 0) {
+			error_errno("unable to truncate a file");
+			return HTTP_START_FAILED;
 		}
+		break;
+	default:
+		BUG("Unknown http_request target");
 	}
 
 	credential_fill(&http_auth);
@@ -1953,7 +2072,7 @@ int http_fetch_ref(const char *base, str
 	url = quote_ref_url(base, ref->name);
 	if (http_get_strbuf(url, &buffer, &options) == HTTP_OK) {
 		strbuf_rtrim(&buffer);
-		if (buffer.len == 40)
+		if (buffer.len == the_hash_algo->hexsz)
 			ret = get_oid_hex(buffer.buf, &ref->old_oid);
 		else if (starts_with(buffer.buf, "ref: ")) {
 			ref->symref = xstrdup(buffer.buf + 5);
@@ -1967,19 +2086,19 @@ int http_fetch_ref(const char *base, str
 }
 
 /* Helpers for fetching packs */
-static char *fetch_pack_index(unsigned char *sha1, const char *base_url)
+static char *fetch_pack_index(unsigned char *hash, const char *base_url)
 {
 	char *url, *tmp;
 	struct strbuf buf = STRBUF_INIT;
 
 	if (http_is_verbose)
-		fprintf(stderr, "Getting index for pack %s\n", sha1_to_hex(sha1));
+		fprintf(stderr, "Getting index for pack %s\n", hash_to_hex(hash));
 
 	end_url_with_slash(&buf, base_url);
-	strbuf_addf(&buf, "objects/pack/pack-%s.idx", sha1_to_hex(sha1));
+	strbuf_addf(&buf, "objects/pack/pack-%s.idx", hash_to_hex(hash));
 	url = strbuf_detach(&buf, NULL);
 
-	strbuf_addf(&buf, "%s.temp", sha1_pack_index_name(sha1));
+	strbuf_addf(&buf, "%s.temp", sha1_pack_index_name(hash));
 	tmp = strbuf_detach(&buf, NULL);
 
 	if (http_get_file(url, tmp, NULL) != HTTP_OK) {
@@ -2035,11 +2154,11 @@ add_pack:
 int http_get_info_packs(const char *base_url, struct packed_git **packs_head)
 {
 	struct http_get_options options = {0};
-	int ret = 0, i = 0;
-	char *url, *data;
+	int ret = 0;
+	char *url;
+	const char *data;
 	struct strbuf buf = STRBUF_INIT;
-	unsigned char hash[GIT_MAX_RAWSZ];
-	const unsigned hexsz = the_hash_algo->hexsz;
+	struct object_id oid;
 
 	end_url_with_slash(&buf, base_url);
 	strbuf_addstr(&buf, "objects/info/packs");
@@ -2051,24 +2170,17 @@ int http_get_info_packs(const char *base
 		goto cleanup;
 
 	data = buf.buf;
-	while (i < buf.len) {
-		switch (data[i]) {
-		case 'P':
-			i++;
-			if (i + hexsz + 12 <= buf.len &&
-			    starts_with(data + i, " pack-") &&
-			    starts_with(data + i + hexsz + 6, ".pack\n")) {
-				get_sha1_hex(data + i + 6, hash);
-				fetch_and_setup_pack_index(packs_head, hash,
-						      base_url);
-				i += hexsz + 11;
-				break;
-			}
-		default:
-			while (i < buf.len && data[i] != '\n')
-				i++;
+	while (*data) {
+		if (skip_prefix(data, "P pack-", &data) &&
+		    !parse_oid_hex(data, &oid, &data) &&
+		    skip_prefix(data, ".pack", &data) &&
+		    (*data == '\n' || *data == '\0')) {
+			fetch_and_setup_pack_index(packs_head, oid.hash, base_url);
+		} else {
+			data = strchrnul(data, '\n');
 		}
-		i++;
+		if (*data)
+			data++; /* skip past newline */
 	}
 
 cleanup:
@@ -2124,10 +2236,10 @@ int finish_http_pack_request(struct http
 		return -1;
 	}
 
-	unlink(sha1_pack_index_name(p->sha1));
+	unlink(sha1_pack_index_name(p->hash));
 
-	if (finalize_object_file(preq->tmpfile.buf, sha1_pack_name(p->sha1))
-	 || finalize_object_file(tmp_idx, sha1_pack_index_name(p->sha1))) {
+	if (finalize_object_file(preq->tmpfile.buf, sha1_pack_name(p->hash))
+	 || finalize_object_file(tmp_idx, sha1_pack_index_name(p->hash))) {
 		free(tmp_idx);
 		return -1;
 	}
@@ -2150,10 +2262,10 @@ struct http_pack_request *new_http_pack_
 
 	end_url_with_slash(&buf, base_url);
 	strbuf_addf(&buf, "objects/pack/pack-%s.pack",
-		sha1_to_hex(target->sha1));
+		hash_to_hex(target->hash));
 	preq->url = strbuf_detach(&buf, NULL);
 
-	strbuf_addf(&preq->tmpfile, "%s.temp", sha1_pack_name(target->sha1));
+	strbuf_addf(&preq->tmpfile, "%s.temp", sha1_pack_name(target->hash));
 	preq->packfile = fopen(preq->tmpfile.buf, "a");
 	if (!preq->packfile) {
 		error("Unable to open local file %s for pack",
@@ -2177,7 +2289,8 @@ struct http_pack_request *new_http_pack_
 		if (http_is_verbose)
 			fprintf(stderr,
 				"Resuming fetch of pack %s at byte %"PRIuMAX"\n",
-				sha1_to_hex(target->sha1), (uintmax_t)prev_posn);
+				hash_to_hex(target->hash),
+				(uintmax_t)prev_posn);
 		http_opt_request_remainder(preq->slot->curl, prev_posn);
 	}
 
@@ -2207,14 +2320,14 @@ static size_t fwrite_sha1_file(char *ptr
 			BUG("curl_easy_getinfo for HTTP code failed: %s",
 				curl_easy_strerror(c));
 		if (slot->http_code >= 300)
-			return size;
+			return nmemb;
 	}
 
 	do {
 		ssize_t retval = xwrite(freq->localfile,
 					(char *) ptr + posn, size - posn);
 		if (retval < 0)
-			return posn;
+			return posn / eltsize;
 		posn += retval;
 	} while (posn < size);
 
@@ -2224,16 +2337,16 @@ static size_t fwrite_sha1_file(char *ptr
 		freq->stream.next_out = expn;
 		freq->stream.avail_out = sizeof(expn);
 		freq->zret = git_inflate(&freq->stream, Z_SYNC_FLUSH);
-		git_SHA1_Update(&freq->c, expn,
-				sizeof(expn) - freq->stream.avail_out);
+		the_hash_algo->update_fn(&freq->c, expn,
+					 sizeof(expn) - freq->stream.avail_out);
 	} while (freq->stream.avail_in && freq->zret == Z_OK);
-	return size;
+	return nmemb;
 }
 
 struct http_object_request *new_http_object_request(const char *base_url,
-	unsigned char *sha1)
+						    const struct object_id *oid)
 {
-	char *hex = sha1_to_hex(sha1);
+	char *hex = oid_to_hex(oid);
 	struct strbuf filename = STRBUF_INIT;
 	struct strbuf prevfile = STRBUF_INIT;
 	int prevlocal;
@@ -2244,10 +2357,10 @@ struct http_object_request *new_http_obj
 
 	freq = xcalloc(1, sizeof(*freq));
 	strbuf_init(&freq->tmpfile, 0);
-	hashcpy(freq->sha1, sha1);
+	oidcpy(&freq->oid, oid);
 	freq->localfile = -1;
 
-	sha1_file_name(the_repository, &filename, sha1);
+	loose_object_path(the_repository, &filename, oid);
 	strbuf_addf(&freq->tmpfile, "%s.temp", filename.buf);
 
 	strbuf_addf(&prevfile, "%s.prev", filename.buf);
@@ -2283,7 +2396,7 @@ struct http_object_request *new_http_obj
 
 	git_inflate_init(&freq->stream);
 
-	git_SHA1_Init(&freq->c);
+	the_hash_algo->init_fn(&freq->c);
 
 	freq->url = get_remote_object_url(base_url, hex, 0);
 
@@ -2318,7 +2431,7 @@ struct http_object_request *new_http_obj
 	if (prev_read == -1) {
 		memset(&freq->stream, 0, sizeof(freq->stream));
 		git_inflate_init(&freq->stream);
-		git_SHA1_Init(&freq->c);
+		the_hash_algo->init_fn(&freq->c);
 		if (prev_posn>0) {
 			prev_posn = 0;
 			lseek(freq->localfile, 0, SEEK_SET);
@@ -2389,16 +2502,16 @@ int finish_http_object_request(struct ht
 	}
 
 	git_inflate_end(&freq->stream);
-	git_SHA1_Final(freq->real_sha1, &freq->c);
+	the_hash_algo->final_fn(freq->real_oid.hash, &freq->c);
 	if (freq->zret != Z_STREAM_END) {
 		unlink_or_warn(freq->tmpfile.buf);
 		return -1;
 	}
-	if (hashcmp(freq->sha1, freq->real_sha1)) {
+	if (!oideq(&freq->oid, &freq->real_oid)) {
 		unlink_or_warn(freq->tmpfile.buf);
 		return -1;
 	}
-	sha1_file_name(the_repository, &filename, freq->sha1);
+	loose_object_path(the_repository, &filename, &freq->oid);
 	freq->rename = finalize_object_file(freq->tmpfile.buf, filename.buf);
 	strbuf_release(&filename);
 
@@ -2418,9 +2531,7 @@ void release_http_object_request(struct
 		close(freq->localfile);
 		freq->localfile = -1;
 	}
-	if (freq->url != NULL) {
-		FREE_AND_NULL(freq->url);
-	}
+	FREE_AND_NULL(freq->url);
 	if (freq->slot != NULL) {
 		freq->slot->callback_func = NULL;
 		freq->slot->callback_data = NULL;
diff -pruN 1.2.1+git2.18.0-1/git/http.h 1.2.3+git2.25.1-1/git/http.h
--- 1.2.1+git2.18.0-1/git/http.h	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/http.h	2020-02-17 04:47:35.000000000 +0000
@@ -25,8 +25,12 @@
 #if LIBCURL_VERSION_NUM < 0x070704
 #define curl_global_cleanup() do { /* nothing */ } while (0)
 #endif
+
 #if LIBCURL_VERSION_NUM < 0x070800
 #define curl_global_init(a) do { /* nothing */ } while (0)
+#elif LIBCURL_VERSION_NUM >= 0x070c00
+#define curl_global_init(a) curl_global_init_mem(a, xmalloc, free, \
+						xrealloc, xstrdup, xcalloc)
 #endif
 
 #if (LIBCURL_VERSION_NUM < 0x070c04) || (LIBCURL_VERSION_NUM == 0x071000)
@@ -75,18 +79,18 @@ struct buffer {
 };
 
 /* Curl request read/write callbacks */
-extern size_t fread_buffer(char *ptr, size_t eltsize, size_t nmemb, void *strbuf);
-extern size_t fwrite_buffer(char *ptr, size_t eltsize, size_t nmemb, void *strbuf);
-extern size_t fwrite_null(char *ptr, size_t eltsize, size_t nmemb, void *strbuf);
+size_t fread_buffer(char *ptr, size_t eltsize, size_t nmemb, void *strbuf);
+size_t fwrite_buffer(char *ptr, size_t eltsize, size_t nmemb, void *strbuf);
+size_t fwrite_null(char *ptr, size_t eltsize, size_t nmemb, void *strbuf);
 #ifndef NO_CURL_IOCTL
-extern curlioerr ioctl_buffer(CURL *handle, int cmd, void *clientp);
+curlioerr ioctl_buffer(CURL *handle, int cmd, void *clientp);
 #endif
 
 /* Slot lifecycle functions */
-extern struct active_request_slot *get_active_slot(void);
-extern int start_active_slot(struct active_request_slot *slot);
-extern void run_active_slot(struct active_request_slot *slot);
-extern void finish_all_active_slots(void);
+struct active_request_slot *get_active_slot(void);
+int start_active_slot(struct active_request_slot *slot);
+void run_active_slot(struct active_request_slot *slot);
+void finish_all_active_slots(void);
 
 /*
  * This will run one slot to completion in a blocking manner, similar to how
@@ -98,15 +102,15 @@ int run_one_slot(struct active_request_s
 		 struct slot_results *results);
 
 #ifdef USE_CURL_MULTI
-extern void fill_active_slots(void);
-extern void add_fill_function(void *data, int (*fill)(void *));
-extern void step_active_slots(void);
+void fill_active_slots(void);
+void add_fill_function(void *data, int (*fill)(void *));
+void step_active_slots(void);
 #endif
 
-extern void http_init(struct remote *remote, const char *url,
-		      int proactive_auth);
-extern void http_cleanup(void);
-extern struct curl_slist *http_copy_default_headers(void);
+void http_init(struct remote *remote, const char *url,
+	       int proactive_auth);
+void http_cleanup(void);
+struct curl_slist *http_copy_default_headers(void);
 
 extern long int git_curl_ipresolve;
 extern int active_requests;
@@ -136,17 +140,25 @@ static inline int missing__target(int co
 
 #define missing_target(a) missing__target((a)->http_code, (a)->curl_result)
 
+/*
+ * Normalize curl results to handle CURL_FAILONERROR (or lack thereof). Failing
+ * http codes have their "result" converted to CURLE_HTTP_RETURNED_ERROR, and
+ * an appropriate string placed in the errorstr buffer (pass curl_errorstr if
+ * you don't have a custom buffer).
+ */
+void normalize_curl_result(CURLcode *result, long http_code, char *errorstr,
+			   size_t errorlen);
+
 /* Helpers for modifying and creating URLs */
-extern void append_remote_object_url(struct strbuf *buf, const char *url,
-				     const char *hex,
-				     int only_two_digit_prefix);
-extern char *get_remote_object_url(const char *url, const char *hex,
-				   int only_two_digit_prefix);
+void append_remote_object_url(struct strbuf *buf, const char *url,
+			      const char *hex,
+			      int only_two_digit_prefix);
+char *get_remote_object_url(const char *url, const char *hex,
+			    int only_two_digit_prefix);
 
 /* Options for http_get_*() */
 struct http_get_options {
 	unsigned no_cache:1,
-		 keep_error:1,
 		 initial_request:1;
 
 	/* If non-NULL, returns the content-type of the response. */
@@ -196,11 +208,11 @@ struct http_get_options {
  */
 int http_get_strbuf(const char *url, struct strbuf *result, struct http_get_options *options);
 
-extern int http_fetch_ref(const char *base, struct ref *ref);
+int http_fetch_ref(const char *base, struct ref *ref);
 
 /* Helpers for fetching packs */
-extern int http_get_info_packs(const char *base_url,
-	struct packed_git **packs_head);
+int http_get_info_packs(const char *base_url,
+			struct packed_git **packs_head);
 
 struct http_pack_request {
 	char *url;
@@ -211,10 +223,10 @@ struct http_pack_request {
 	struct active_request_slot *slot;
 };
 
-extern struct http_pack_request *new_http_pack_request(
+struct http_pack_request *new_http_pack_request(
 	struct packed_git *target, const char *base_url);
-extern int finish_http_pack_request(struct http_pack_request *preq);
-extern void release_http_pack_request(struct http_pack_request *preq);
+int finish_http_pack_request(struct http_pack_request *preq);
+void release_http_pack_request(struct http_pack_request *preq);
 
 /* Helpers for fetching object */
 struct http_object_request {
@@ -224,21 +236,21 @@ struct http_object_request {
 	CURLcode curl_result;
 	char errorstr[CURL_ERROR_SIZE];
 	long http_code;
-	unsigned char sha1[20];
-	unsigned char real_sha1[20];
-	git_SHA_CTX c;
+	struct object_id oid;
+	struct object_id real_oid;
+	git_hash_ctx c;
 	git_zstream stream;
 	int zret;
 	int rename;
 	struct active_request_slot *slot;
 };
 
-extern struct http_object_request *new_http_object_request(
-	const char *base_url, unsigned char *sha1);
-extern void process_http_object_request(struct http_object_request *freq);
-extern int finish_http_object_request(struct http_object_request *freq);
-extern void abort_http_object_request(struct http_object_request *freq);
-extern void release_http_object_request(struct http_object_request *freq);
+struct http_object_request *new_http_object_request(
+	const char *base_url, const struct object_id *oid);
+void process_http_object_request(struct http_object_request *freq);
+int finish_http_object_request(struct http_object_request *freq);
+void abort_http_object_request(struct http_object_request *freq);
+void release_http_object_request(struct http_object_request *freq);
 
 /* setup routine for curl_easy_setopt CURLOPT_DEBUGFUNCTION */
 void setup_curl_trace(CURL *handle);
diff -pruN 1.2.1+git2.18.0-1/git/http-push.c 1.2.3+git2.25.1-1/git/http-push.c
--- 1.2.1+git2.18.0-1/git/http-push.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/http-push.c	2020-02-17 04:47:35.000000000 +0000
@@ -1,4 +1,5 @@
 #include "cache.h"
+#include "repository.h"
 #include "commit.h"
 #include "tag.h"
 #include "blob.h"
@@ -13,6 +14,7 @@
 #include "argv-array.h"
 #include "packfile.h"
 #include "object-store.h"
+#include "commit-reach.h"
 
 #ifdef EXPAT_NEEDS_XMLPARSE_H
 #include <xmlparse.h>
@@ -143,7 +145,7 @@ struct remote_lock {
 	char *url;
 	char *owner;
 	char *token;
-	char tmpfile_suffix[41];
+	char tmpfile_suffix[GIT_MAX_HEXSZ + 1];
 	time_t start_time;
 	long timeout;
 	int refreshing;
@@ -253,7 +255,7 @@ static void start_fetch_loose(struct tra
 	struct active_request_slot *slot;
 	struct http_object_request *obj_req;
 
-	obj_req = new_http_object_request(repo->url, request->obj->oid.hash);
+	obj_req = new_http_object_request(repo->url, &request->obj->oid);
 	if (obj_req == NULL) {
 		request->state = ABORTED;
 		return;
@@ -313,7 +315,8 @@ static void start_fetch_packed(struct tr
 		return;
 	}
 
-	fprintf(stderr,	"Fetching pack %s\n", sha1_to_hex(target->sha1));
+	fprintf(stderr,	"Fetching pack %s\n",
+		hash_to_hex(target->hash));
 	fprintf(stderr, " which contains %s\n", oid_to_hex(&request->obj->oid));
 
 	preq = new_http_pack_request(target, repo->url);
@@ -363,7 +366,7 @@ static void start_put(struct transfer_re
 	git_zstream stream;
 
 	unpacked = read_object_file(&request->obj->oid, &type, &len);
-	hdrlen = xsnprintf(hdr, sizeof(hdr), "%s %lu", type_name(type), len) + 1;
+	hdrlen = xsnprintf(hdr, sizeof(hdr), "%s %"PRIuMAX , type_name(type), (uintmax_t)len) + 1;
 
 	/* Set it up */
 	git_deflate_init(&stream, zlib_compression_level);
@@ -396,7 +399,7 @@ static void start_put(struct transfer_re
 	request->dest = strbuf_detach(&buf, NULL);
 
 	append_remote_object_url(&buf, repo->url, hex, 0);
-	strbuf_add(&buf, request->lock->tmpfile_suffix, 41);
+	strbuf_add(&buf, request->lock->tmpfile_suffix, the_hash_algo->hexsz + 1);
 	request->url = strbuf_detach(&buf, NULL);
 
 	slot = get_active_slot();
@@ -498,10 +501,10 @@ static void release_request(struct trans
 	if (request == request_queue_head) {
 		request_queue_head = request->next;
 	} else {
-		while (entry->next != NULL && entry->next != request)
+		while (entry && entry->next != request)
 			entry = entry->next;
-		if (entry->next == request)
-			entry->next = entry->next->next;
+		if (entry)
+			entry->next = request->next;
 	}
 
 	free(request->url);
@@ -523,8 +526,8 @@ static void finish_request(struct transf
 	if (request->headers != NULL)
 		curl_slist_free_all(request->headers);
 
-	/* URL is reused for MOVE after PUT */
-	if (request->state != RUN_PUT) {
+	/* URL is reused for MOVE after PUT and used during FETCH */
+	if (request->state != RUN_PUT && request->state != RUN_FETCH_PACKED) {
 		FREE_AND_NULL(request->url);
 	}
 
@@ -720,9 +723,9 @@ static void one_remote_object(const stru
 {
 	struct object *obj;
 
-	obj = lookup_object(oid->hash);
+	obj = lookup_object(the_repository, oid);
 	if (!obj)
-		obj = parse_object(oid);
+		obj = parse_object(the_repository, oid);
 
 	/* Ignore remote objects that don't exist locally */
 	if (!obj)
@@ -755,8 +758,8 @@ static void handle_lockprop_ctx(struct x
 static void handle_new_lock_ctx(struct xml_ctx *ctx, int tag_closed)
 {
 	struct remote_lock *lock = (struct remote_lock *)ctx->userData;
-	git_SHA_CTX sha_ctx;
-	unsigned char lock_token_sha1[20];
+	git_hash_ctx hash_ctx;
+	unsigned char lock_token_hash[GIT_MAX_RAWSZ];
 
 	if (tag_closed && ctx->cdata) {
 		if (!strcmp(ctx->name, DAV_ACTIVELOCK_OWNER)) {
@@ -768,12 +771,12 @@ static void handle_new_lock_ctx(struct x
 		} else if (!strcmp(ctx->name, DAV_ACTIVELOCK_TOKEN)) {
 			lock->token = xstrdup(ctx->cdata);
 
-			git_SHA1_Init(&sha_ctx);
-			git_SHA1_Update(&sha_ctx, lock->token, strlen(lock->token));
-			git_SHA1_Final(lock_token_sha1, &sha_ctx);
+			the_hash_algo->init_fn(&hash_ctx);
+			the_hash_algo->update_fn(&hash_ctx, lock->token, strlen(lock->token));
+			the_hash_algo->final_fn(lock_token_hash, &hash_ctx);
 
 			lock->tmpfile_suffix[0] = '_';
-			memcpy(lock->tmpfile_suffix + 1, sha1_to_hex(lock_token_sha1), 40);
+			memcpy(lock->tmpfile_suffix + 1, hash_to_hex(lock_token_hash), the_hash_algo->hexsz);
 		}
 	}
 }
@@ -978,7 +981,7 @@ static int unlock_remote(struct remote_l
 		while (prev && prev->next != lock)
 			prev = prev->next;
 		if (prev)
-			prev->next = prev->next->next;
+			prev->next = lock->next;
 	}
 
 	free(lock->owner);
@@ -1015,7 +1018,7 @@ static void remote_ls(const char *path,
 /* extract hex from sharded "xx/x{38}" filename */
 static int get_oid_hex_from_objpath(const char *path, struct object_id *oid)
 {
-	if (strlen(path) != GIT_SHA1_HEXSZ + 1)
+	if (strlen(path) != the_hash_algo->hexsz + 1)
 		return -1;
 
 	if (hex_to_bytes(oid->hash, path, 1))
@@ -1023,7 +1026,7 @@ static int get_oid_hex_from_objpath(cons
 	path += 2;
 	path++; /* skip '/' */
 
-	return hex_to_bytes(oid->hash + 1, path, GIT_SHA1_RAWSZ - 1);
+	return hex_to_bytes(oid->hash + 1, path, the_hash_algo->rawsz - 1);
 }
 
 static void process_ls_object(struct remote_ls_ctx *ls)
@@ -1309,10 +1312,12 @@ static struct object_list **process_tree
 	while (tree_entry(&desc, &entry))
 		switch (object_type(entry.mode)) {
 		case OBJ_TREE:
-			p = process_tree(lookup_tree(entry.oid), p);
+			p = process_tree(lookup_tree(the_repository, &entry.oid),
+					 p);
 			break;
 		case OBJ_BLOB:
-			p = process_blob(lookup_blob(entry.oid), p);
+			p = process_blob(lookup_blob(the_repository, &entry.oid),
+					 p);
 			break;
 		default:
 			/* Subproject commit - not in this repository */
@@ -1369,7 +1374,7 @@ static int get_delta(struct rev_info *re
 	return count;
 }
 
-static int update_remote(unsigned char *sha1, struct remote_lock *lock)
+static int update_remote(const struct object_id *oid, struct remote_lock *lock)
 {
 	struct active_request_slot *slot;
 	struct slot_results results;
@@ -1378,7 +1383,7 @@ static int update_remote(unsigned char *
 
 	dav_headers = get_dav_token_headers(lock, DAV_HEADER_IF);
 
-	strbuf_addf(&out_buffer.buf, "%s\n", sha1_to_hex(sha1));
+	strbuf_addf(&out_buffer.buf, "%s\n", oid_to_hex(oid));
 
 	slot = get_active_slot();
 	slot->results = &results;
@@ -1427,7 +1432,7 @@ static void one_remote_ref(const char *r
 	 * may be required for updating server info later.
 	 */
 	if (repo->can_update_info_refs && !has_object_file(&ref->old_oid)) {
-		obj = lookup_unknown_object(ref->old_oid.hash);
+		obj = lookup_unknown_object(&ref->old_oid);
 		fprintf(stderr,	"  fetch %s for %s\n",
 			oid_to_hex(&ref->old_oid), refname);
 		add_fetch_request(obj);
@@ -1459,7 +1464,7 @@ static void add_remote_info_ref(struct r
 		return;
 	}
 
-	o = parse_object(&ref->old_oid);
+	o = parse_object(the_repository, &ref->old_oid);
 	if (!o) {
 		fprintf(stderr,
 			"Unable to parse object %s for remote ref %s\n",
@@ -1473,7 +1478,7 @@ static void add_remote_info_ref(struct r
 		    oid_to_hex(&ref->old_oid), ls->dentry_name);
 
 	if (o->type == OBJ_TAG) {
-		o = deref_tag(o, ls->dentry_name, 0);
+		o = deref_tag(the_repository, o, ls->dentry_name, 0);
 		if (o)
 			strbuf_addf(buf, "%s\t%s^{}\n",
 				    oid_to_hex(&o->oid), ls->dentry_name);
@@ -1855,7 +1860,7 @@ int cmd_main(int argc, const char **argv
 			continue;
 		}
 
-		if (!oidcmp(&ref->old_oid, &ref->peer_ref->new_oid)) {
+		if (oideq(&ref->old_oid, &ref->peer_ref->new_oid)) {
 			if (push_verbosely)
 				fprintf(stderr, "'%s': up-to-date\n", ref->name);
 			if (helper_status)
@@ -1921,7 +1926,7 @@ int cmd_main(int argc, const char **argv
 		if (!push_all && !is_null_oid(&ref->old_oid))
 			argv_array_pushf(&commit_argv, "^%s",
 					 oid_to_hex(&ref->old_oid));
-		init_revisions(&revs, setup_git_directory());
+		repo_init_revisions(the_repository, &revs, setup_git_directory());
 		setup_revisions(commit_argv.argc, commit_argv.argv, &revs, NULL);
 		revs.edge_hint = 0; /* just in case */
 
@@ -1929,7 +1934,7 @@ int cmd_main(int argc, const char **argv
 		pushing = 0;
 		if (prepare_revision_walk(&revs))
 			die("revision walk setup failed");
-		mark_edges_uninteresting(&revs, NULL);
+		mark_edges_uninteresting(&revs, NULL, 0);
 		objects_to_send = get_delta(&revs, ref_lock);
 		finish_all_active_slots();
 
@@ -1943,7 +1948,7 @@ int cmd_main(int argc, const char **argv
 		run_request_queue();
 
 		/* Update the remote branch if all went well */
-		if (aborted || !update_remote(ref->new_oid.hash, ref_lock))
+		if (aborted || !update_remote(&ref->new_oid, ref_lock))
 			rc = 1;
 
 		if (!rc)
diff -pruN 1.2.1+git2.18.0-1/git/http-walker.c 1.2.3+git2.25.1-1/git/http-walker.c
--- 1.2.1+git2.18.0-1/git/http-walker.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/http-walker.c	2020-02-17 04:47:35.000000000 +0000
@@ -58,7 +58,7 @@ static void start_object_request(struct
 	struct active_request_slot *slot;
 	struct http_object_request *req;
 
-	req = new_http_object_request(obj_req->repo->base, obj_req->oid.hash);
+	req = new_http_object_request(obj_req->repo->base, &obj_req->oid);
 	if (req == NULL) {
 		obj_req->state = ABORTED;
 		return;
@@ -98,6 +98,11 @@ static void process_object_response(void
 	process_http_object_request(obj_req->req);
 	obj_req->state = COMPLETE;
 
+	normalize_curl_result(&obj_req->req->curl_result,
+			      obj_req->req->http_code,
+			      obj_req->req->errorstr,
+			      sizeof(obj_req->req->errorstr));
+
 	/* Use alternates if necessary */
 	if (missing_target(obj_req->req)) {
 		fetch_alternates(walker, alt->base);
@@ -131,7 +136,7 @@ static int fill_active_slot(struct walke
 	list_for_each_safe(pos, tmp, head) {
 		obj_req = list_entry(pos, struct object_request, node);
 		if (obj_req->state == WAITING) {
-			if (has_sha1_file(obj_req->oid.hash))
+			if (has_object_file(&obj_req->oid))
 				obj_req->state = COMPLETE;
 			else {
 				start_object_request(walker, obj_req);
@@ -208,6 +213,9 @@ static void process_alternates_response(
 	char *data;
 	int i = 0;
 
+	normalize_curl_result(&slot->curl_result, slot->http_code,
+			      curl_errorstr, sizeof(curl_errorstr));
+
 	if (alt_req->http_specific) {
 		if (slot->curl_result != CURLE_OK ||
 		    !alt_req->buffer->len) {
@@ -434,9 +442,9 @@ static int http_fetch_pack(struct walker
 
 	if (walker->get_verbosely) {
 		fprintf(stderr, "Getting pack %s\n",
-			sha1_to_hex(target->sha1));
+			hash_to_hex(target->hash));
 		fprintf(stderr, " which contains %s\n",
-			sha1_to_hex(sha1));
+			hash_to_hex(sha1));
 	}
 
 	preq = new_http_pack_request(target, repo->base);
@@ -473,9 +481,9 @@ static void abort_object_request(struct
 	release_object_request(obj_req);
 }
 
-static int fetch_object(struct walker *walker, unsigned char *sha1)
+static int fetch_object(struct walker *walker, unsigned char *hash)
 {
-	char *hex = sha1_to_hex(sha1);
+	char *hex = hash_to_hex(hash);
 	int ret = 0;
 	struct object_request *obj_req = NULL;
 	struct http_object_request *req;
@@ -483,13 +491,13 @@ static int fetch_object(struct walker *w
 
 	list_for_each(pos, head) {
 		obj_req = list_entry(pos, struct object_request, node);
-		if (!hashcmp(obj_req->oid.hash, sha1))
+		if (hasheq(obj_req->oid.hash, hash))
 			break;
 	}
 	if (obj_req == NULL)
 		return error("Couldn't find request for %s in the queue", hex);
 
-	if (has_sha1_file(obj_req->oid.hash)) {
+	if (has_object_file(&obj_req->oid)) {
 		if (obj_req->req != NULL)
 			abort_http_object_request(obj_req->req);
 		abort_object_request(obj_req);
@@ -518,17 +526,8 @@ static int fetch_object(struct walker *w
 		req->localfile = -1;
 	}
 
-	/*
-	 * we turned off CURLOPT_FAILONERROR to avoid losing a
-	 * persistent connection and got CURLE_OK.
-	 */
-	if (req->http_code >= 300 && req->curl_result == CURLE_OK &&
-			(starts_with(req->url, "http://") ||
-			 starts_with(req->url, "https://"))) {
-		req->curl_result = CURLE_HTTP_RETURNED_ERROR;
-		xsnprintf(req->errorstr, sizeof(req->errorstr),
-			  "HTTP request failed");
-	}
+	normalize_curl_result(&req->curl_result, req->http_code,
+			      req->errorstr, sizeof(req->errorstr));
 
 	if (obj_req->state == ABORTED) {
 		ret = error("Request for %s aborted", hex);
@@ -543,11 +542,11 @@ static int fetch_object(struct walker *w
 	} else if (req->zret != Z_STREAM_END) {
 		walker->corrupt_object_found++;
 		ret = error("File %s (%s) corrupt", hex, req->url);
-	} else if (hashcmp(obj_req->oid.hash, req->real_sha1)) {
+	} else if (!oideq(&obj_req->oid, &req->real_oid)) {
 		ret = error("File %s has bad hash", hex);
 	} else if (req->rename < 0) {
 		struct strbuf buf = STRBUF_INIT;
-		sha1_file_name(the_repository, &buf, req->sha1);
+		loose_object_path(the_repository, &buf, &req->oid);
 		ret = error("unable to write sha1 filename %s", buf.buf);
 		strbuf_release(&buf);
 	}
@@ -557,20 +556,20 @@ static int fetch_object(struct walker *w
 	return ret;
 }
 
-static int fetch(struct walker *walker, unsigned char *sha1)
+static int fetch(struct walker *walker, unsigned char *hash)
 {
 	struct walker_data *data = walker->data;
 	struct alt_base *altbase = data->alt;
 
-	if (!fetch_object(walker, sha1))
+	if (!fetch_object(walker, hash))
 		return 0;
 	while (altbase) {
-		if (!http_fetch_pack(walker, altbase, sha1))
+		if (!http_fetch_pack(walker, altbase, hash))
 			return 0;
 		fetch_alternates(walker, data->alt->base);
 		altbase = altbase->next;
 	}
-	return error("Unable to find %s under %s", sha1_to_hex(sha1),
+	return error("Unable to find %s under %s", hash_to_hex(hash),
 		     data->alt->base);
 }
 
diff -pruN 1.2.1+git2.18.0-1/git/ident.c 1.2.3+git2.25.1-1/git/ident.c
--- 1.2.1+git2.18.0-1/git/ident.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/ident.c	2020-02-17 04:47:35.000000000 +0000
@@ -11,6 +11,10 @@
 static struct strbuf git_default_name = STRBUF_INIT;
 static struct strbuf git_default_email = STRBUF_INIT;
 static struct strbuf git_default_date = STRBUF_INIT;
+static struct strbuf git_author_name = STRBUF_INIT;
+static struct strbuf git_author_email = STRBUF_INIT;
+static struct strbuf git_committer_name = STRBUF_INIT;
+static struct strbuf git_committer_email = STRBUF_INIT;
 static int default_email_is_bogus;
 static int default_name_is_bogus;
 
@@ -168,6 +172,9 @@ const char *ident_default_email(void)
 			strbuf_addstr(&git_default_email, email);
 			committer_ident_explicitly_given |= IDENT_MAIL_GIVEN;
 			author_ident_explicitly_given |= IDENT_MAIL_GIVEN;
+		} else if ((email = query_user_email()) && email[0]) {
+			strbuf_addstr(&git_default_email, email);
+			free((char *)email);
 		} else
 			copy_email(xgetpwuid_self(&default_email_is_bogus),
 				   &git_default_email, &default_email_is_bogus);
@@ -352,7 +359,7 @@ N_("\n"
    "\n");
 
 const char *fmt_ident(const char *name, const char *email,
-		      const char *date_str, int flag)
+		      enum want_ident whose_ident, const char *date_str, int flag)
 {
 	static struct strbuf ident = STRBUF_INIT;
 	int strict = (flag & IDENT_STRICT);
@@ -360,6 +367,12 @@ const char *fmt_ident(const char *name,
 	int want_name = !(flag & IDENT_NO_NAME);
 
 	if (!email) {
+		if (whose_ident == WANT_AUTHOR_IDENT && git_author_email.len)
+			email = git_author_email.buf;
+		else if (whose_ident == WANT_COMMITTER_IDENT && git_committer_email.len)
+			email = git_committer_email.buf;
+	}
+	if (!email) {
 		if (strict && ident_use_config_only
 		    && !(ident_config_given & IDENT_MAIL_GIVEN)) {
 			fputs(_(env_hint), stderr);
@@ -375,6 +388,13 @@ const char *fmt_ident(const char *name,
 	if (want_name) {
 		int using_default = 0;
 		if (!name) {
+			if (whose_ident == WANT_AUTHOR_IDENT && git_author_name.len)
+				name = git_author_name.buf;
+			else if (whose_ident == WANT_COMMITTER_IDENT &&
+					git_committer_name.len)
+				name = git_committer_name.buf;
+		}
+		if (!name) {
 			if (strict && ident_use_config_only
 			    && !(ident_config_given & IDENT_NAME_GIVEN)) {
 				fputs(_(env_hint), stderr);
@@ -422,9 +442,25 @@ const char *fmt_ident(const char *name,
 	return ident.buf;
 }
 
-const char *fmt_name(const char *name, const char *email)
+const char *fmt_name(enum want_ident whose_ident)
 {
-	return fmt_ident(name, email, NULL, IDENT_STRICT | IDENT_NO_DATE);
+	char *name = NULL;
+	char *email = NULL;
+
+	switch (whose_ident) {
+	case WANT_BLANK_IDENT:
+		break;
+	case WANT_AUTHOR_IDENT:
+		name = getenv("GIT_AUTHOR_NAME");
+		email = getenv("GIT_AUTHOR_EMAIL");
+		break;
+	case WANT_COMMITTER_IDENT:
+		name = getenv("GIT_COMMITTER_NAME");
+		email = getenv("GIT_COMMITTER_EMAIL");
+		break;
+	}
+	return fmt_ident(name, email, whose_ident, NULL,
+			IDENT_STRICT | IDENT_NO_DATE);
 }
 
 const char *git_author_info(int flag)
@@ -435,6 +471,7 @@ const char *git_author_info(int flag)
 		author_ident_explicitly_given |= IDENT_MAIL_GIVEN;
 	return fmt_ident(getenv("GIT_AUTHOR_NAME"),
 			 getenv("GIT_AUTHOR_EMAIL"),
+			 WANT_AUTHOR_IDENT,
 			 getenv("GIT_AUTHOR_DATE"),
 			 flag);
 }
@@ -447,6 +484,7 @@ const char *git_committer_info(int flag)
 		committer_ident_explicitly_given |= IDENT_MAIL_GIVEN;
 	return fmt_ident(getenv("GIT_COMMITTER_NAME"),
 			 getenv("GIT_COMMITTER_EMAIL"),
+			 WANT_COMMITTER_IDENT,
 			 getenv("GIT_COMMITTER_DATE"),
 			 flag);
 }
@@ -470,10 +508,45 @@ int author_ident_sufficiently_given(void
 	return ident_is_sufficient(author_ident_explicitly_given);
 }
 
-int git_ident_config(const char *var, const char *value, void *data)
+static int set_ident(const char *var, const char *value)
 {
-	if (!strcmp(var, "user.useconfigonly")) {
-		ident_use_config_only = git_config_bool(var, value);
+	if (!strcmp(var, "author.name")) {
+		if (!value)
+			return config_error_nonbool(var);
+		strbuf_reset(&git_author_name);
+		strbuf_addstr(&git_author_name, value);
+		author_ident_explicitly_given |= IDENT_NAME_GIVEN;
+		ident_config_given |= IDENT_NAME_GIVEN;
+		return 0;
+	}
+
+	if (!strcmp(var, "author.email")) {
+		if (!value)
+			return config_error_nonbool(var);
+		strbuf_reset(&git_author_email);
+		strbuf_addstr(&git_author_email, value);
+		author_ident_explicitly_given |= IDENT_MAIL_GIVEN;
+		ident_config_given |= IDENT_MAIL_GIVEN;
+		return 0;
+	}
+
+	if (!strcmp(var, "committer.name")) {
+		if (!value)
+			return config_error_nonbool(var);
+		strbuf_reset(&git_committer_name);
+		strbuf_addstr(&git_committer_name, value);
+		committer_ident_explicitly_given |= IDENT_NAME_GIVEN;
+		ident_config_given |= IDENT_NAME_GIVEN;
+		return 0;
+	}
+
+	if (!strcmp(var, "committer.email")) {
+		if (!value)
+			return config_error_nonbool(var);
+		strbuf_reset(&git_committer_email);
+		strbuf_addstr(&git_committer_email, value);
+		committer_ident_explicitly_given |= IDENT_MAIL_GIVEN;
+		ident_config_given |= IDENT_MAIL_GIVEN;
 		return 0;
 	}
 
@@ -502,6 +575,36 @@ int git_ident_config(const char *var, co
 	return 0;
 }
 
+int git_ident_config(const char *var, const char *value, void *data)
+{
+	if (!strcmp(var, "user.useconfigonly")) {
+		ident_use_config_only = git_config_bool(var, value);
+		return 0;
+	}
+
+	return set_ident(var, value);
+}
+
+static void set_env_if(const char *key, const char *value, int *given, int bit)
+{
+	if ((*given & bit) || getenv(key))
+		return; /* nothing to do */
+	setenv(key, value, 0);
+	*given |= bit;
+}
+
+void prepare_fallback_ident(const char *name, const char *email)
+{
+	set_env_if("GIT_AUTHOR_NAME", name,
+		   &author_ident_explicitly_given, IDENT_NAME_GIVEN);
+	set_env_if("GIT_AUTHOR_EMAIL", email,
+		   &author_ident_explicitly_given, IDENT_MAIL_GIVEN);
+	set_env_if("GIT_COMMITTER_NAME", name,
+		   &committer_ident_explicitly_given, IDENT_NAME_GIVEN);
+	set_env_if("GIT_COMMITTER_EMAIL", email,
+		   &committer_ident_explicitly_given, IDENT_MAIL_GIVEN);
+}
+
 static int buf_cmp(const char *a_begin, const char *a_end,
 		   const char *b_begin, const char *b_end)
 {
diff -pruN 1.2.1+git2.18.0-1/git/imap-send.c 1.2.3+git2.25.1-1/git/imap-send.c
--- 1.2.1+git2.18.0-1/git/imap-send.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/imap-send.c	2020-02-17 04:47:35.000000000 +0000
@@ -1114,7 +1114,7 @@ static struct imap_store *imap_open_stor
 
 			if (!strcmp(srvc->auth_method, "CRAM-MD5")) {
 				if (!CAP(AUTH_CRAM_MD5)) {
-					fprintf(stderr, "You specified"
+					fprintf(stderr, "You specified "
 						"CRAM-MD5 as authentication method, "
 						"but %s doesn't support it.\n", srvc->host);
 					goto bail;
@@ -1471,7 +1471,8 @@ static CURL *setup_curl(struct imap_serv
 }
 
 static int curl_append_msgs_to_imap(struct imap_server_conf *server,
-				    struct strbuf* all_msgs, int total) {
+				    struct strbuf* all_msgs, int total)
+{
 	int ofs = 0;
 	int n = 0;
 	struct buffer msgbuf = { STRBUF_INIT, 0 };
diff -pruN 1.2.1+git2.18.0-1/git/INSTALL 1.2.3+git2.25.1-1/git/INSTALL
--- 1.2.1+git2.18.0-1/git/INSTALL	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/INSTALL	2020-02-17 04:47:35.000000000 +0000
@@ -109,15 +109,15 @@ Issues of note:
 
  - Git is reasonably self-sufficient, but does depend on a few external
    programs and libraries.  Git can be used without most of them by adding
-   the approriate "NO_<LIBRARY>=YesPlease" to the make command line or
+   the appropriate "NO_<LIBRARY>=YesPlease" to the make command line or
    config.mak file.
 
 	- "zlib", the compression library. Git won't build without it.
 
 	- "ssh" is used to push and pull over the net.
 
-	- A POSIX-compliant shell is required to run many scripts needed
-	  for everyday use (e.g. "bisect", "pull").
+	- A POSIX-compliant shell is required to run some scripts needed
+	  for everyday use (e.g. "bisect", "request-pull").
 
 	- "Perl" version 5.8 or later is needed to use some of the
 	  features (e.g. preparing a partial commit using "git add -i/-p",
diff -pruN 1.2.1+git2.18.0-1/git/interdiff.c 1.2.3+git2.25.1-1/git/interdiff.c
--- 1.2.1+git2.18.0-1/git/interdiff.c	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/interdiff.c	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,28 @@
+#include "cache.h"
+#include "commit.h"
+#include "revision.h"
+#include "interdiff.h"
+
+static struct strbuf *idiff_prefix_cb(struct diff_options *opt, void *data)
+{
+	return data;
+}
+
+void show_interdiff(struct rev_info *rev, int indent)
+{
+	struct diff_options opts;
+	struct strbuf prefix = STRBUF_INIT;
+
+	memcpy(&opts, &rev->diffopt, sizeof(opts));
+	opts.output_format = DIFF_FORMAT_PATCH;
+	opts.output_prefix = idiff_prefix_cb;
+	strbuf_addchars(&prefix, ' ', indent);
+	opts.output_prefix_data = &prefix;
+	diff_setup_done(&opts);
+
+	diff_tree_oid(rev->idiff_oid1, rev->idiff_oid2, "", &opts);
+	diffcore_std(&opts);
+	diff_flush(&opts);
+
+	strbuf_release(&prefix);
+}
diff -pruN 1.2.1+git2.18.0-1/git/interdiff.h 1.2.3+git2.25.1-1/git/interdiff.h
--- 1.2.1+git2.18.0-1/git/interdiff.h	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/interdiff.h	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,8 @@
+#ifndef INTERDIFF_H
+#define INTERDIFF_H
+
+struct rev_info;
+
+void show_interdiff(struct rev_info *, int indent);
+
+#endif
diff -pruN 1.2.1+git2.18.0-1/git/json-writer.c 1.2.3+git2.25.1-1/git/json-writer.c
--- 1.2.1+git2.18.0-1/git/json-writer.c	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/json-writer.c	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,414 @@
+#include "cache.h"
+#include "json-writer.h"
+
+void jw_init(struct json_writer *jw)
+{
+	strbuf_init(&jw->json, 0);
+	strbuf_init(&jw->open_stack, 0);
+	jw->need_comma = 0;
+	jw->pretty = 0;
+}
+
+void jw_release(struct json_writer *jw)
+{
+	strbuf_release(&jw->json);
+	strbuf_release(&jw->open_stack);
+}
+
+/*
+ * Append JSON-quoted version of the given string to 'out'.
+ */
+static void append_quoted_string(struct strbuf *out, const char *in)
+{
+	unsigned char c;
+
+	strbuf_addch(out, '"');
+	while ((c = *in++) != '\0') {
+		if (c == '"')
+			strbuf_addstr(out, "\\\"");
+		else if (c == '\\')
+			strbuf_addstr(out, "\\\\");
+		else if (c == '\n')
+			strbuf_addstr(out, "\\n");
+		else if (c == '\r')
+			strbuf_addstr(out, "\\r");
+		else if (c == '\t')
+			strbuf_addstr(out, "\\t");
+		else if (c == '\f')
+			strbuf_addstr(out, "\\f");
+		else if (c == '\b')
+			strbuf_addstr(out, "\\b");
+		else if (c < 0x20)
+			strbuf_addf(out, "\\u%04x", c);
+		else
+			strbuf_addch(out, c);
+	}
+	strbuf_addch(out, '"');
+}
+
+static void indent_pretty(struct json_writer *jw)
+{
+	int k;
+
+	for (k = 0; k < jw->open_stack.len; k++)
+		strbuf_addstr(&jw->json, "  ");
+}
+
+/*
+ * Begin an object or array (either top-level or nested within the currently
+ * open object or array).
+ */
+static void begin(struct json_writer *jw, char ch_open, int pretty)
+{
+	jw->pretty = pretty;
+
+	strbuf_addch(&jw->json, ch_open);
+
+	strbuf_addch(&jw->open_stack, ch_open);
+	jw->need_comma = 0;
+}
+
+/*
+ * Assert that the top of the open-stack is an object.
+ */
+static void assert_in_object(const struct json_writer *jw, const char *key)
+{
+	if (!jw->open_stack.len)
+		BUG("json-writer: object: missing jw_object_begin(): '%s'", key);
+	if (jw->open_stack.buf[jw->open_stack.len - 1] != '{')
+		BUG("json-writer: object: not in object: '%s'", key);
+}
+
+/*
+ * Assert that the top of the open-stack is an array.
+ */
+static void assert_in_array(const struct json_writer *jw)
+{
+	if (!jw->open_stack.len)
+		BUG("json-writer: array: missing jw_array_begin()");
+	if (jw->open_stack.buf[jw->open_stack.len - 1] != '[')
+		BUG("json-writer: array: not in array");
+}
+
+/*
+ * Add comma if we have already seen a member at this level.
+ */
+static void maybe_add_comma(struct json_writer *jw)
+{
+	if (jw->need_comma)
+		strbuf_addch(&jw->json, ',');
+	else
+		jw->need_comma = 1;
+}
+
+static void fmt_double(struct json_writer *jw, int precision,
+			      double value)
+{
+	if (precision < 0) {
+		strbuf_addf(&jw->json, "%f", value);
+	} else {
+		struct strbuf fmt = STRBUF_INIT;
+		strbuf_addf(&fmt, "%%.%df", precision);
+		strbuf_addf(&jw->json, fmt.buf, value);
+		strbuf_release(&fmt);
+	}
+}
+
+static void object_common(struct json_writer *jw, const char *key)
+{
+	assert_in_object(jw, key);
+	maybe_add_comma(jw);
+
+	if (jw->pretty) {
+		strbuf_addch(&jw->json, '\n');
+		indent_pretty(jw);
+	}
+
+	append_quoted_string(&jw->json, key);
+	strbuf_addch(&jw->json, ':');
+	if (jw->pretty)
+		strbuf_addch(&jw->json, ' ');
+}
+
+static void array_common(struct json_writer *jw)
+{
+	assert_in_array(jw);
+	maybe_add_comma(jw);
+
+	if (jw->pretty) {
+		strbuf_addch(&jw->json, '\n');
+		indent_pretty(jw);
+	}
+}
+
+/*
+ * Assert that the given JSON object or JSON array has been properly
+ * terminated.  (Has closing bracket.)
+ */
+static void assert_is_terminated(const struct json_writer *jw)
+{
+	if (jw->open_stack.len)
+		BUG("json-writer: object: missing jw_end(): '%s'",
+		    jw->json.buf);
+}
+
+void jw_object_begin(struct json_writer *jw, int pretty)
+{
+	begin(jw, '{', pretty);
+}
+
+void jw_object_string(struct json_writer *jw, const char *key, const char *value)
+{
+	object_common(jw, key);
+	append_quoted_string(&jw->json, value);
+}
+
+void jw_object_intmax(struct json_writer *jw, const char *key, intmax_t value)
+{
+	object_common(jw, key);
+	strbuf_addf(&jw->json, "%"PRIdMAX, value);
+}
+
+void jw_object_double(struct json_writer *jw, const char *key, int precision,
+		      double value)
+{
+	object_common(jw, key);
+	fmt_double(jw, precision, value);
+}
+
+void jw_object_true(struct json_writer *jw, const char *key)
+{
+	object_common(jw, key);
+	strbuf_addstr(&jw->json, "true");
+}
+
+void jw_object_false(struct json_writer *jw, const char *key)
+{
+	object_common(jw, key);
+	strbuf_addstr(&jw->json, "false");
+}
+
+void jw_object_bool(struct json_writer *jw, const char *key, int value)
+{
+	if (value)
+		jw_object_true(jw, key);
+	else
+		jw_object_false(jw, key);
+}
+
+void jw_object_null(struct json_writer *jw, const char *key)
+{
+	object_common(jw, key);
+	strbuf_addstr(&jw->json, "null");
+}
+
+static void increase_indent(struct strbuf *sb,
+			    const struct json_writer *jw,
+			    int indent)
+{
+	int k;
+
+	strbuf_reset(sb);
+	for (k = 0; k < jw->json.len; k++) {
+		char ch = jw->json.buf[k];
+		strbuf_addch(sb, ch);
+		if (ch == '\n')
+			strbuf_addchars(sb, ' ', indent);
+	}
+}
+
+static void kill_indent(struct strbuf *sb,
+			const struct json_writer *jw)
+{
+	int k;
+	int eat_it = 0;
+
+	strbuf_reset(sb);
+	for (k = 0; k < jw->json.len; k++) {
+		char ch = jw->json.buf[k];
+		if (eat_it && ch == ' ')
+			continue;
+		if (ch == '\n') {
+			eat_it = 1;
+			continue;
+		}
+		eat_it = 0;
+		strbuf_addch(sb, ch);
+	}
+}
+
+static void append_sub_jw(struct json_writer *jw,
+			  const struct json_writer *value)
+{
+	/*
+	 * If both are pretty, increase the indentation of the sub_jw
+	 * to better fit under the super.
+	 *
+	 * If the super is pretty, but the sub_jw is compact, leave the
+	 * sub_jw compact.  (We don't want to parse and rebuild the sub_jw
+	 * for this debug-ish feature.)
+	 *
+	 * If the super is compact, and the sub_jw is pretty, convert
+	 * the sub_jw to compact.
+	 *
+	 * If both are compact, keep the sub_jw compact.
+	 */
+	if (jw->pretty && jw->open_stack.len && value->pretty) {
+		struct strbuf sb = STRBUF_INIT;
+		increase_indent(&sb, value, jw->open_stack.len * 2);
+		strbuf_addbuf(&jw->json, &sb);
+		strbuf_release(&sb);
+		return;
+	}
+	if (!jw->pretty && value->pretty) {
+		struct strbuf sb = STRBUF_INIT;
+		kill_indent(&sb, value);
+		strbuf_addbuf(&jw->json, &sb);
+		strbuf_release(&sb);
+		return;
+	}
+
+	strbuf_addbuf(&jw->json, &value->json);
+}
+
+/*
+ * Append existing (properly terminated) JSON sub-data (object or array)
+ * as-is onto the given JSON data.
+ */
+void jw_object_sub_jw(struct json_writer *jw, const char *key,
+		      const struct json_writer *value)
+{
+	assert_is_terminated(value);
+
+	object_common(jw, key);
+	append_sub_jw(jw, value);
+}
+
+void jw_object_inline_begin_object(struct json_writer *jw, const char *key)
+{
+	object_common(jw, key);
+
+	jw_object_begin(jw, jw->pretty);
+}
+
+void jw_object_inline_begin_array(struct json_writer *jw, const char *key)
+{
+	object_common(jw, key);
+
+	jw_array_begin(jw, jw->pretty);
+}
+
+void jw_array_begin(struct json_writer *jw, int pretty)
+{
+	begin(jw, '[', pretty);
+}
+
+void jw_array_string(struct json_writer *jw, const char *value)
+{
+	array_common(jw);
+	append_quoted_string(&jw->json, value);
+}
+
+void jw_array_intmax(struct json_writer *jw, intmax_t value)
+{
+	array_common(jw);
+	strbuf_addf(&jw->json, "%"PRIdMAX, value);
+}
+
+void jw_array_double(struct json_writer *jw, int precision, double value)
+{
+	array_common(jw);
+	fmt_double(jw, precision, value);
+}
+
+void jw_array_true(struct json_writer *jw)
+{
+	array_common(jw);
+	strbuf_addstr(&jw->json, "true");
+}
+
+void jw_array_false(struct json_writer *jw)
+{
+	array_common(jw);
+	strbuf_addstr(&jw->json, "false");
+}
+
+void jw_array_bool(struct json_writer *jw, int value)
+{
+	if (value)
+		jw_array_true(jw);
+	else
+		jw_array_false(jw);
+}
+
+void jw_array_null(struct json_writer *jw)
+{
+	array_common(jw);
+	strbuf_addstr(&jw->json, "null");
+}
+
+void jw_array_sub_jw(struct json_writer *jw, const struct json_writer *value)
+{
+	assert_is_terminated(value);
+
+	array_common(jw);
+	append_sub_jw(jw, value);
+}
+
+void jw_array_argc_argv(struct json_writer *jw, int argc, const char **argv)
+{
+	int k;
+
+	for (k = 0; k < argc; k++)
+		jw_array_string(jw, argv[k]);
+}
+
+void jw_array_argv(struct json_writer *jw, const char **argv)
+{
+	while (*argv)
+		jw_array_string(jw, *argv++);
+}
+
+void jw_array_inline_begin_object(struct json_writer *jw)
+{
+	array_common(jw);
+
+	jw_object_begin(jw, jw->pretty);
+}
+
+void jw_array_inline_begin_array(struct json_writer *jw)
+{
+	array_common(jw);
+
+	jw_array_begin(jw, jw->pretty);
+}
+
+int jw_is_terminated(const struct json_writer *jw)
+{
+	return !jw->open_stack.len;
+}
+
+void jw_end(struct json_writer *jw)
+{
+	char ch_open;
+	int len;
+
+	if (!jw->open_stack.len)
+		BUG("json-writer: too many jw_end(): '%s'", jw->json.buf);
+
+	len = jw->open_stack.len - 1;
+	ch_open = jw->open_stack.buf[len];
+
+	strbuf_setlen(&jw->open_stack, len);
+	jw->need_comma = 1;
+
+	if (jw->pretty) {
+		strbuf_addch(&jw->json, '\n');
+		indent_pretty(jw);
+	}
+
+	if (ch_open == '{')
+		strbuf_addch(&jw->json, '}');
+	else
+		strbuf_addch(&jw->json, ']');
+}
diff -pruN 1.2.1+git2.18.0-1/git/json-writer.h 1.2.3+git2.25.1-1/git/json-writer.h
--- 1.2.1+git2.18.0-1/git/json-writer.h	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/json-writer.h	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,107 @@
+#ifndef JSON_WRITER_H
+#define JSON_WRITER_H
+
+/*
+ * JSON data structures are defined at:
+ * [1] http://www.ietf.org/rfc/rfc7159.txt
+ * [2] http://json.org/
+ *
+ * The JSON-writer API allows one to build JSON data structures using a
+ * simple wrapper around a "struct strbuf" buffer.  It is intended as a
+ * simple API to build output strings; it is not intended to be a general
+ * object model for JSON data.  In particular, it does not re-order keys
+ * in an object (dictionary), it does not de-dup keys in an object, and
+ * it does not allow lookup or parsing of JSON data.
+ *
+ * All string values (both keys and string r-values) are properly quoted
+ * and escaped if they contain special characters.
+ *
+ * These routines create compact JSON data (with no unnecessary whitespace,
+ * newlines, or indenting).  If you get an unexpected response, verify
+ * that you're not expecting a pretty JSON string.
+ *
+ * Both "JSON objects" (aka sets of k/v pairs) and "JSON array" can be
+ * constructed using a 'begin append* end' model.
+ *
+ * Nested objects and arrays can either be constructed bottom up (by
+ * creating sub object/arrays first and appending them to the super
+ * object/array) -or- by building them inline in one pass.  This is a
+ * personal style and/or data shape choice.
+ *
+ * See t/helper/test-json-writer.c for various usage examples.
+ *
+ * LIMITATIONS:
+ * ============
+ *
+ * The JSON specification [1,2] defines string values as Unicode data
+ * and probably UTF-8 encoded.  The current json-writer API does not
+ * enforce this and will write any string as received.  However, it will
+ * properly quote and backslash-escape them as necessary.  It is up to
+ * the caller to UTF-8 encode their strings *before* passing them to this
+ * API.  This layer should not have to try to guess the encoding or locale
+ * of the given strings.
+ */
+
+#include "strbuf.h"
+
+struct json_writer
+{
+	/*
+	 * Buffer of the in-progress JSON currently being composed.
+	 */
+	struct strbuf json;
+
+	/*
+	 * Simple stack of the currently open array and object forms.
+	 * This is a string of '{' and '[' characters indicating the
+	 * currently unterminated forms.  This is used to ensure the
+	 * properly closing character is used when popping a level and
+	 * to know when the JSON is completely closed.
+	 */
+	struct strbuf open_stack;
+
+	unsigned int need_comma:1;
+	unsigned int pretty:1;
+};
+
+#define JSON_WRITER_INIT { STRBUF_INIT, STRBUF_INIT, 0, 0 }
+
+void jw_init(struct json_writer *jw);
+void jw_release(struct json_writer *jw);
+
+void jw_object_begin(struct json_writer *jw, int pretty);
+void jw_array_begin(struct json_writer *jw, int pretty);
+
+void jw_object_string(struct json_writer *jw, const char *key,
+		      const char *value);
+void jw_object_intmax(struct json_writer *jw, const char *key, intmax_t value);
+void jw_object_double(struct json_writer *jw, const char *key, int precision,
+		      double value);
+void jw_object_true(struct json_writer *jw, const char *key);
+void jw_object_false(struct json_writer *jw, const char *key);
+void jw_object_bool(struct json_writer *jw, const char *key, int value);
+void jw_object_null(struct json_writer *jw, const char *key);
+void jw_object_sub_jw(struct json_writer *jw, const char *key,
+		      const struct json_writer *value);
+
+void jw_object_inline_begin_object(struct json_writer *jw, const char *key);
+void jw_object_inline_begin_array(struct json_writer *jw, const char *key);
+
+void jw_array_string(struct json_writer *jw, const char *value);
+void jw_array_intmax(struct json_writer *jw, intmax_t value);
+void jw_array_double(struct json_writer *jw, int precision, double value);
+void jw_array_true(struct json_writer *jw);
+void jw_array_false(struct json_writer *jw);
+void jw_array_bool(struct json_writer *jw, int value);
+void jw_array_null(struct json_writer *jw);
+void jw_array_sub_jw(struct json_writer *jw, const struct json_writer *value);
+void jw_array_argc_argv(struct json_writer *jw, int argc, const char **argv);
+void jw_array_argv(struct json_writer *jw, const char **argv);
+
+void jw_array_inline_begin_object(struct json_writer *jw);
+void jw_array_inline_begin_array(struct json_writer *jw);
+
+int jw_is_terminated(const struct json_writer *jw);
+void jw_end(struct json_writer *jw);
+
+#endif /* JSON_WRITER_H */
diff -pruN 1.2.1+git2.18.0-1/git/khash.h 1.2.3+git2.25.1-1/git/khash.h
--- 1.2.1+git2.18.0-1/git/khash.h	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/khash.h	2020-02-17 04:47:35.000000000 +0000
@@ -26,6 +26,9 @@
 #ifndef __AC_KHASH_H
 #define __AC_KHASH_H
 
+#include "cache.h"
+#include "hashmap.h"
+
 #define AC_VERSION_KHASH_H "0.2.8"
 
 typedef uint32_t khint32_t;
@@ -66,24 +69,29 @@ static const double __ac_HASH_UPPER = 0.
 		khval_t *vals; \
 	} kh_##name##_t;
 
-#define __KHASH_PROTOTYPES(name, khkey_t, khval_t)	 					\
-	extern kh_##name##_t *kh_init_##name(void);							\
-	extern void kh_destroy_##name(kh_##name##_t *h);					\
-	extern void kh_clear_##name(kh_##name##_t *h);						\
-	extern khint_t kh_get_##name(const kh_##name##_t *h, khkey_t key); 	\
-	extern int kh_resize_##name(kh_##name##_t *h, khint_t new_n_buckets); \
-	extern khint_t kh_put_##name(kh_##name##_t *h, khkey_t key, int *ret); \
-	extern void kh_del_##name(kh_##name##_t *h, khint_t x);
+#define __KHASH_PROTOTYPES(name, khkey_t, khval_t)	 			\
+	kh_##name##_t *kh_init_##name(void);						\
+	void kh_destroy_##name(kh_##name##_t *h);					\
+	void kh_clear_##name(kh_##name##_t *h);						\
+	khint_t kh_get_##name(const kh_##name##_t *h, khkey_t key); \
+	int kh_resize_##name(kh_##name##_t *h, khint_t new_n_buckets); \
+	khint_t kh_put_##name(kh_##name##_t *h, khkey_t key, int *ret); \
+	void kh_del_##name(kh_##name##_t *h, khint_t x);
 
 #define __KHASH_IMPL(name, SCOPE, khkey_t, khval_t, kh_is_map, __hash_func, __hash_equal) \
 	SCOPE kh_##name##_t *kh_init_##name(void) {							\
 		return (kh_##name##_t*)xcalloc(1, sizeof(kh_##name##_t));		\
 	}																	\
+	SCOPE void kh_release_##name(kh_##name##_t *h)						\
+	{																	\
+		free(h->flags);													\
+		free((void *)h->keys);											\
+		free((void *)h->vals);											\
+	}																	\
 	SCOPE void kh_destroy_##name(kh_##name##_t *h)						\
 	{																	\
 		if (h) {														\
-			free((void *)h->keys); free(h->flags);					\
-			free((void *)h->vals);										\
+			kh_release_##name(h);										\
 			free(h);													\
 		}																\
 	}																	\
@@ -226,7 +234,7 @@ static const double __ac_HASH_UPPER = 0.
 	__KHASH_IMPL(name, SCOPE, khkey_t, khval_t, kh_is_map, __hash_func, __hash_equal)
 
 #define KHASH_INIT(name, khkey_t, khval_t, kh_is_map, __hash_func, __hash_equal) \
-	KHASH_INIT2(name, static inline, khkey_t, khval_t, kh_is_map, __hash_func, __hash_equal)
+	KHASH_INIT2(name, MAYBE_UNUSED static inline, khkey_t, khval_t, kh_is_map, __hash_func, __hash_equal)
 
 /* Other convenient macros... */
 
@@ -316,12 +324,20 @@ static const double __ac_HASH_UPPER = 0.
 		code;												\
 	} }
 
-#define __kh_oid_cmp(a, b) (hashcmp(a, b) == 0)
+static inline unsigned int oidhash_by_value(struct object_id oid)
+{
+	return oidhash(&oid);
+}
+
+static inline int oideq_by_value(struct object_id a, struct object_id b)
+{
+	return oideq(&a, &b);
+}
+
+KHASH_INIT(oid_set, struct object_id, int, 0, oidhash_by_value, oideq_by_value)
 
-KHASH_INIT(sha1, const unsigned char *, void *, 1, sha1hash, __kh_oid_cmp)
-typedef kh_sha1_t khash_sha1;
+KHASH_INIT(oid_map, struct object_id, void *, 1, oidhash_by_value, oideq_by_value)
 
-KHASH_INIT(sha1_pos, const unsigned char *, int, 1, sha1hash, __kh_oid_cmp)
-typedef kh_sha1_pos_t khash_sha1_pos;
+KHASH_INIT(oid_pos, struct object_id, int, 1, oidhash_by_value, oideq_by_value)
 
 #endif /* __AC_KHASH_H */
diff -pruN 1.2.1+git2.18.0-1/git/kwset.c 1.2.3+git2.25.1-1/git/kwset.c
--- 1.2.1+git2.18.0-1/git/kwset.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/kwset.c	2020-02-17 04:47:35.000000000 +0000
@@ -38,7 +38,13 @@
 #include "compat/obstack.h"
 
 #define NCHAR (UCHAR_MAX + 1)
-#define obstack_chunk_alloc xmalloc
+/* adapter for `xmalloc()`, which takes `size_t`, not `long` */
+static void *obstack_chunk_alloc(long size)
+{
+	if (size < 0)
+		BUG("Cannot allocate a negative amount: %ld", size);
+	return xmalloc(size);
+}
 #define obstack_chunk_free free
 
 #define U(c) ((unsigned char) (c))
@@ -475,7 +481,7 @@ kwsprep (kwset_t kws)
 	for (i = 0; i < NCHAR; ++i)
 	  kwset->next[i] = next[U(trans[i])];
       else
-	memcpy(kwset->next, next, NCHAR * sizeof(struct trie *));
+	COPY_ARRAY(kwset->next, next, NCHAR);
     }
 
   /* Fix things up for any translation table. */
diff -pruN 1.2.1+git2.18.0-1/git/kwset.h 1.2.3+git2.25.1-1/git/kwset.h
--- 1.2.1+git2.18.0-1/git/kwset.h	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/kwset.h	2020-02-17 04:47:35.000000000 +0000
@@ -1,3 +1,6 @@
+#ifndef KWSET_H
+#define KWSET_H
+
 /* This file has been copied from commit e7ac713d^ in the GNU grep git
  * repository. A few small changes have been made to adapt the code to
  * Git.
@@ -37,16 +40,16 @@ typedef struct kwset_t* kwset_t;
    if enough memory cannot be obtained.  The argument if non-NULL
    specifies a table of character translations to be applied to all
    pattern and search text. */
-extern kwset_t kwsalloc(unsigned char const *);
+kwset_t kwsalloc(unsigned char const *);
 
 /* Incrementally extend the keyword set to include the given string.
    Return NULL for success, or an error message.  Remember an index
    number for each keyword included in the set. */
-extern const char *kwsincr(kwset_t, char const *, size_t);
+const char *kwsincr(kwset_t, char const *, size_t);
 
 /* When the keyword set has been completely built, prepare it for
    use.  Return NULL for success, or an error message. */
-extern const char *kwsprep(kwset_t);
+const char *kwsprep(kwset_t);
 
 /* Search through the given buffer for a member of the keyword set.
    Return a pointer to the leftmost longest match found, or NULL if
@@ -54,8 +57,9 @@ extern const char *kwsprep(kwset_t);
    the matching substring in the integer it points to.  Similarly,
    if foundindex is non-NULL, store the index of the particular
    keyword found therein. */
-extern size_t kwsexec(kwset_t, char const *, size_t, struct kwsmatch *);
+size_t kwsexec(kwset_t, char const *, size_t, struct kwsmatch *);
 
 /* Deallocate the given keyword set and all its associated storage. */
-extern void kwsfree(kwset_t);
+void kwsfree(kwset_t);
 
+#endif /* KWSET_H */
diff -pruN 1.2.1+git2.18.0-1/git/linear-assignment.c 1.2.3+git2.25.1-1/git/linear-assignment.c
--- 1.2.1+git2.18.0-1/git/linear-assignment.c	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/linear-assignment.c	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,207 @@
+/*
+ * Based on: Jonker, R., & Volgenant, A. (1987). <i>A shortest augmenting path
+ * algorithm for dense and sparse linear assignment problems</i>. Computing,
+ * 38(4), 325-340.
+ */
+#include "cache.h"
+#include "linear-assignment.h"
+
+#define COST(column, row) cost[(column) + column_count * (row)]
+
+/*
+ * The parameter `cost` is the cost matrix: the cost to assign column j to row
+ * i is `cost[j + column_count * i].
+ */
+void compute_assignment(int column_count, int row_count, int *cost,
+			int *column2row, int *row2column)
+{
+	int *v, *d;
+	int *free_row, free_count = 0, saved_free_count, *pred, *col;
+	int i, j, phase;
+
+	if (column_count < 2) {
+		memset(column2row, 0, sizeof(int) * column_count);
+		memset(row2column, 0, sizeof(int) * row_count);
+		return;
+	}
+
+	memset(column2row, -1, sizeof(int) * column_count);
+	memset(row2column, -1, sizeof(int) * row_count);
+	ALLOC_ARRAY(v, column_count);
+
+	/* column reduction */
+	for (j = column_count - 1; j >= 0; j--) {
+		int i1 = 0;
+
+		for (i = 1; i < row_count; i++)
+			if (COST(j, i1) > COST(j, i))
+				i1 = i;
+		v[j] = COST(j, i1);
+		if (row2column[i1] == -1) {
+			/* row i1 unassigned */
+			row2column[i1] = j;
+			column2row[j] = i1;
+		} else {
+			if (row2column[i1] >= 0)
+				row2column[i1] = -2 - row2column[i1];
+			column2row[j] = -1;
+		}
+	}
+
+	/* reduction transfer */
+	ALLOC_ARRAY(free_row, row_count);
+	for (i = 0; i < row_count; i++) {
+		int j1 = row2column[i];
+		if (j1 == -1)
+			free_row[free_count++] = i;
+		else if (j1 < -1)
+			row2column[i] = -2 - j1;
+		else {
+			int min = COST(!j1, i) - v[!j1];
+			for (j = 1; j < column_count; j++)
+				if (j != j1 && min > COST(j, i) - v[j])
+					min = COST(j, i) - v[j];
+			v[j1] -= min;
+		}
+	}
+
+	if (free_count ==
+	    (column_count < row_count ? row_count - column_count : 0)) {
+		free(v);
+		free(free_row);
+		return;
+	}
+
+	/* augmenting row reduction */
+	for (phase = 0; phase < 2; phase++) {
+		int k = 0;
+
+		saved_free_count = free_count;
+		free_count = 0;
+		while (k < saved_free_count) {
+			int u1, u2;
+			int j1 = 0, j2, i0;
+
+			i = free_row[k++];
+			u1 = COST(j1, i) - v[j1];
+			j2 = -1;
+			u2 = INT_MAX;
+			for (j = 1; j < column_count; j++) {
+				int c = COST(j, i) - v[j];
+				if (u2 > c) {
+					if (u1 < c) {
+						u2 = c;
+						j2 = j;
+					} else {
+						u2 = u1;
+						u1 = c;
+						j2 = j1;
+						j1 = j;
+					}
+				}
+			}
+			if (j2 < 0) {
+				j2 = j1;
+				u2 = u1;
+			}
+
+			i0 = column2row[j1];
+			if (u1 < u2)
+				v[j1] -= u2 - u1;
+			else if (i0 >= 0) {
+				j1 = j2;
+				i0 = column2row[j1];
+			}
+
+			if (i0 >= 0) {
+				if (u1 < u2)
+					free_row[--k] = i0;
+				else
+					free_row[free_count++] = i0;
+			}
+			row2column[i] = j1;
+			column2row[j1] = i;
+		}
+	}
+
+	/* augmentation */
+	saved_free_count = free_count;
+	ALLOC_ARRAY(d, column_count);
+	ALLOC_ARRAY(pred, column_count);
+	ALLOC_ARRAY(col, column_count);
+	for (free_count = 0; free_count < saved_free_count; free_count++) {
+		int i1 = free_row[free_count], low = 0, up = 0, last, k;
+		int min, c, u1;
+
+		for (j = 0; j < column_count; j++) {
+			d[j] = COST(j, i1) - v[j];
+			pred[j] = i1;
+			col[j] = j;
+		}
+
+		j = -1;
+		do {
+			last = low;
+			min = d[col[up++]];
+			for (k = up; k < column_count; k++) {
+				j = col[k];
+				c = d[j];
+				if (c <= min) {
+					if (c < min) {
+						up = low;
+						min = c;
+					}
+					col[k] = col[up];
+					col[up++] = j;
+				}
+			}
+			for (k = low; k < up; k++)
+				if (column2row[col[k]] == -1)
+					goto update;
+
+			/* scan a row */
+			do {
+				int j1 = col[low++];
+
+				i = column2row[j1];
+				u1 = COST(j1, i) - v[j1] - min;
+				for (k = up; k < column_count; k++) {
+					j = col[k];
+					c = COST(j, i) - v[j] - u1;
+					if (c < d[j]) {
+						d[j] = c;
+						pred[j] = i;
+						if (c == min) {
+							if (column2row[j] == -1)
+								goto update;
+							col[k] = col[up];
+							col[up++] = j;
+						}
+					}
+				}
+			} while (low != up);
+		} while (low == up);
+
+update:
+		/* updating of the column pieces */
+		for (k = 0; k < last; k++) {
+			int j1 = col[k];
+			v[j1] += d[j1] - min;
+		}
+
+		/* augmentation */
+		do {
+			if (j < 0)
+				BUG("negative j: %d", j);
+			i = pred[j];
+			column2row[j] = i;
+			SWAP(j, row2column[i]);
+		} while (i1 != i);
+	}
+
+	free(col);
+	free(pred);
+	free(d);
+	free(v);
+	free(free_row);
+}
diff -pruN 1.2.1+git2.18.0-1/git/linear-assignment.h 1.2.3+git2.25.1-1/git/linear-assignment.h
--- 1.2.1+git2.18.0-1/git/linear-assignment.h	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/linear-assignment.h	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,22 @@
+#ifndef LINEAR_ASSIGNMENT_H
+#define LINEAR_ASSIGNMENT_H
+
+/*
+ * Compute an assignment of columns -> rows (and vice versa) such that every
+ * column is assigned to at most one row (and vice versa) minimizing the
+ * overall cost.
+ *
+ * The parameter `cost` is the cost matrix: the cost to assign column j to row
+ * i is `cost[j + column_count * i].
+ *
+ * The arrays column2row and row2column will be populated with the respective
+ * assignments (-1 for unassigned, which can happen only if column_count !=
+ * row_count).
+ */
+void compute_assignment(int column_count, int row_count, int *cost,
+			int *column2row, int *row2column);
+
+/* The maximal cost in the cost matrix (to prevent integer overflows). */
+#define COST_MAX (1<<16)
+
+#endif
diff -pruN 1.2.1+git2.18.0-1/git/line-log.c 1.2.3+git2.25.1-1/git/line-log.c
--- 1.2.1+git2.18.0-1/git/line-log.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/line-log.c	2020-02-17 04:47:35.000000000 +0000
@@ -479,7 +479,7 @@ static struct commit *check_single_commi
 		struct object *obj = revs->pending.objects[i].item;
 		if (obj->flags & UNINTERESTING)
 			continue;
-		obj = deref_tag(obj, NULL, 0);
+		obj = deref_tag(revs->repo, obj, NULL, 0);
 		if (obj->type != OBJ_COMMIT)
 			die("Non commit %s?", revs->pending.objects[i].name);
 		if (commit)
@@ -496,19 +496,22 @@ static struct commit *check_single_commi
 	return (struct commit *) commit;
 }
 
-static void fill_blob_sha1(struct commit *commit, struct diff_filespec *spec)
+static void fill_blob_sha1(struct repository *r, struct commit *commit,
+			   struct diff_filespec *spec)
 {
-	unsigned mode;
+	unsigned short mode;
 	struct object_id oid;
 
-	if (get_tree_entry(&commit->object.oid, spec->path, &oid, &mode))
+	if (get_tree_entry(r, &commit->object.oid, spec->path, &oid, &mode))
 		die("There is no path %s in the commit", spec->path);
 	fill_filespec(spec, &oid, 1, mode);
 
 	return;
 }
 
-static void fill_line_ends(struct diff_filespec *spec, long *lines,
+static void fill_line_ends(struct repository *r,
+			   struct diff_filespec *spec,
+			   long *lines,
 			   unsigned long **line_ends)
 {
 	int num = 0, size = 50;
@@ -516,7 +519,7 @@ static void fill_line_ends(struct diff_f
 	unsigned long *ends = NULL;
 	char *data = NULL;
 
-	if (diff_populate_filespec(spec, 0))
+	if (diff_populate_filespec(r, spec, 0))
 		die("Cannot read blob %s", oid_to_hex(&spec->oid));
 
 	ALLOC_ARRAY(ends, size);
@@ -555,7 +558,8 @@ static const char *nth_line(void *data,
 }
 
 static struct line_log_data *
-parse_lines(struct commit *commit, const char *prefix, struct string_list *args)
+parse_lines(struct repository *r, struct commit *commit,
+	    const char *prefix, struct string_list *args)
 {
 	long lines = 0;
 	unsigned long *ends = NULL;
@@ -571,7 +575,7 @@ parse_lines(struct commit *commit, const
 		long begin = 0, end = 0;
 		long anchor;
 
-		name_part = skip_range_arg(item->string);
+		name_part = skip_range_arg(item->string, r->index);
 		if (!name_part || *name_part != ':' || !name_part[1])
 			die("-L argument not 'start,end:file' or ':funcname:file': %s",
 			    item->string);
@@ -582,8 +586,8 @@ parse_lines(struct commit *commit, const
 					name_part);
 
 		spec = alloc_filespec(full_name);
-		fill_blob_sha1(commit, spec);
-		fill_line_ends(spec, &lines, &ends);
+		fill_blob_sha1(r, commit, spec);
+		fill_line_ends(r, spec, &lines, &ends);
 		cb_data.spec = spec;
 		cb_data.lines = lines;
 		cb_data.line_ends = ends;
@@ -596,13 +600,13 @@ parse_lines(struct commit *commit, const
 
 		if (parse_range_arg(range_part, nth_line, &cb_data,
 				    lines, anchor, &begin, &end,
-				    full_name))
+				    full_name, r->index))
 			die("malformed -L argument '%s'", range_part);
-		if (lines < end || ((lines || begin) && lines < begin))
+		if ((!lines && (begin || end)) || lines < begin)
 			die("file %s has only %lu lines", name_part, lines);
 		if (begin < 1)
 			begin = 1;
-		if (end < 1)
+		if (end < 1 || lines < end)
 			end = lines;
 		begin--;
 		line_log_data_insert(&ranges, full_name, begin, end);
@@ -733,29 +737,48 @@ static struct line_log_data *lookup_line
 	return ret;
 }
 
+static int same_paths_in_pathspec_and_range(struct pathspec *pathspec,
+					    struct line_log_data *range)
+{
+	int i;
+	struct line_log_data *r;
+
+	for (i = 0, r = range; i < pathspec->nr && r; i++, r = r->next)
+		if (strcmp(pathspec->items[i].match, r->path))
+			return 0;
+	if (i < pathspec->nr || r)
+		/* different number of pathspec items and ranges */
+		return 0;
+
+	return 1;
+}
+
+static void parse_pathspec_from_ranges(struct pathspec *pathspec,
+				       struct line_log_data *range)
+{
+	struct line_log_data *r;
+	struct argv_array array = ARGV_ARRAY_INIT;
+	const char **paths;
+
+	for (r = range; r; r = r->next)
+		argv_array_push(&array, r->path);
+	paths = argv_array_detach(&array);
+
+	parse_pathspec(pathspec, 0, PATHSPEC_PREFER_FULL, "", paths);
+	/* strings are now owned by pathspec */
+	free(paths);
+}
+
 void line_log_init(struct rev_info *rev, const char *prefix, struct string_list *args)
 {
 	struct commit *commit = NULL;
 	struct line_log_data *range;
 
 	commit = check_single_commit(rev);
-	range = parse_lines(commit, prefix, args);
+	range = parse_lines(rev->diffopt.repo, commit, prefix, args);
 	add_line_range(rev, commit, range);
 
-	if (!rev->diffopt.detect_rename) {
-		struct line_log_data *r;
-		struct argv_array array = ARGV_ARRAY_INIT;
-		const char **paths;
-
-		for (r = range; r; r = r->next)
-			argv_array_push(&array, r->path);
-		paths = argv_array_detach(&array);
-
-		parse_pathspec(&rev->diffopt.pathspec, 0,
-			       PATHSPEC_PREFER_FULL, "", paths);
-		/* strings are now owned by pathspec */
-		free(paths);
-	}
+	parse_pathspec_from_ranges(&rev->diffopt.pathspec, range);
 }
 
 static void move_diff_queue(struct diff_queue_struct *dst,
@@ -813,15 +836,29 @@ static void queue_diffs(struct line_log_
 			struct diff_queue_struct *queue,
 			struct commit *commit, struct commit *parent)
 {
+	struct object_id *tree_oid, *parent_tree_oid;
+
 	assert(commit);
 
+	tree_oid = get_commit_tree_oid(commit);
+	parent_tree_oid = parent ? get_commit_tree_oid(parent) : NULL;
+
+	if (opt->detect_rename &&
+	    !same_paths_in_pathspec_and_range(&opt->pathspec, range)) {
+		clear_pathspec(&opt->pathspec);
+		parse_pathspec_from_ranges(&opt->pathspec, range);
+	}
 	DIFF_QUEUE_CLEAR(&diff_queued_diff);
-	diff_tree_oid(parent ? get_commit_tree_oid(parent) : NULL,
-		      get_commit_tree_oid(commit), "", opt);
-	if (opt->detect_rename) {
+	diff_tree_oid(parent_tree_oid, tree_oid, "", opt);
+	if (opt->detect_rename && diff_might_be_rename()) {
+		/* must look at the full tree diff to detect renames */
+		clear_pathspec(&opt->pathspec);
+		DIFF_QUEUE_CLEAR(&diff_queued_diff);
+
+		diff_tree_oid(parent_tree_oid, tree_oid, "", opt);
+
 		filter_diffs_for_paths(range, 1);
-		if (diff_might_be_rename())
-			diffcore_std(opt);
+		diffcore_std(opt);
 		filter_diffs_for_paths(range, 0);
 	}
 	move_diff_queue(queue, &diff_queued_diff);
@@ -891,8 +928,8 @@ static void dump_diff_hacky_one(struct r
 		return;
 
 	if (pair->one->oid_valid)
-		fill_line_ends(pair->one, &p_lines, &p_ends);
-	fill_line_ends(pair->two, &t_lines, &t_ends);
+		fill_line_ends(rev->diffopt.repo, pair->one, &p_lines, &p_ends);
+	fill_line_ends(rev->diffopt.repo, pair->two, &t_lines, &t_ends);
 
 	fprintf(opt->file, "%s%sdiff --git a/%s b/%s%s\n", prefix, c_meta, pair->one->path, pair->two->path, c_reset);
 	fprintf(opt->file, "%s%s--- %s%s%s\n", prefix, c_meta,
@@ -1008,12 +1045,12 @@ static int process_diff_filepair(struct
 		return 0;
 
 	assert(pair->two->oid_valid);
-	diff_populate_filespec(pair->two, 0);
+	diff_populate_filespec(rev->diffopt.repo, pair->two, 0);
 	file_target.ptr = pair->two->data;
 	file_target.size = pair->two->size;
 
 	if (pair->one->oid_valid) {
-		diff_populate_filespec(pair->one, 0);
+		diff_populate_filespec(rev->diffopt.repo, pair->one, 0);
 		file_parent.ptr = pair->one->data;
 		file_parent.size = pair->one->size;
 	} else {
@@ -1100,10 +1137,12 @@ static int process_all_files(struct line
 
 int line_log_print(struct rev_info *rev, struct commit *commit)
 {
-	struct line_log_data *range = lookup_line_range(rev, commit);
 
 	show_log(rev);
-	dump_diff_hacky(rev, range);
+	if (!(rev->diffopt.output_format & DIFF_FORMAT_NO_OUTPUT)) {
+		struct line_log_data *range = lookup_line_range(rev, commit);
+		dump_diff_hacky(rev, range);
+	}
 	return 1;
 }
 
diff -pruN 1.2.1+git2.18.0-1/git/line-log.h 1.2.3+git2.25.1-1/git/line-log.h
--- 1.2.1+git2.18.0-1/git/line-log.h	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/line-log.h	2020-02-17 04:47:35.000000000 +0000
@@ -25,17 +25,17 @@ struct diff_ranges {
 	struct range_set target;
 };
 
-extern void range_set_init(struct range_set *, size_t prealloc);
-extern void range_set_release(struct range_set *);
+void range_set_init(struct range_set *, size_t prealloc);
+void range_set_release(struct range_set *);
 /* Range includes start; excludes end */
-extern void range_set_append_unsafe(struct range_set *, long start, long end);
+void range_set_append_unsafe(struct range_set *, long start, long end);
 /* New range must begin at or after end of last added range */
-extern void range_set_append(struct range_set *, long start, long end);
+void range_set_append(struct range_set *, long start, long end);
 /*
  * In-place pass of sorting and merging the ranges in the range set,
  * to sort and make the ranges disjoint.
  */
-extern void sort_and_merge_range_set(struct range_set *);
+void sort_and_merge_range_set(struct range_set *);
 
 /* Linked list of interesting files and their associated ranges.  The
  * list must be kept sorted by path.
@@ -54,10 +54,10 @@ struct line_log_data {
 	struct diff_ranges diff;
 };
 
-extern void line_log_init(struct rev_info *rev, const char *prefix, struct string_list *args);
+void line_log_init(struct rev_info *rev, const char *prefix, struct string_list *args);
 
-extern int line_log_filter(struct rev_info *rev);
+int line_log_filter(struct rev_info *rev);
 
-extern int line_log_print(struct rev_info *rev, struct commit *commit);
+int line_log_print(struct rev_info *rev, struct commit *commit);
 
 #endif /* LINE_LOG_H */
diff -pruN 1.2.1+git2.18.0-1/git/line-range.c 1.2.3+git2.25.1-1/git/line-range.c
--- 1.2.1+git2.18.0-1/git/line-range.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/line-range.c	2020-02-17 04:47:35.000000000 +0000
@@ -47,7 +47,7 @@ static const char *parse_loc(const char
 			else if (!num)
 				*ret = begin;
 			else
-				*ret = begin + num;
+				*ret = begin + num > 0 ? begin + num : 1;
 			return term;
 		}
 		return spec;
@@ -163,9 +163,10 @@ static const char *find_funcname_matchin
 	}
 }
 
-static const char *parse_range_funcname(const char *arg, nth_line_fn_t nth_line_cb,
-					void *cb_data, long lines, long anchor, long *begin, long *end,
-					const char *path)
+static const char *parse_range_funcname(
+	const char *arg, nth_line_fn_t nth_line_cb,
+	void *cb_data, long lines, long anchor, long *begin, long *end,
+	const char *path, struct index_state *istate)
 {
 	char *pattern;
 	const char *term;
@@ -198,7 +199,7 @@ static const char *parse_range_funcname(
 	anchor--; /* input is in human terms */
 	start = nth_line_cb(cb_data, anchor);
 
-	drv = userdiff_find_by_path(path);
+	drv = userdiff_find_by_path(istate, path);
 	if (drv && drv->funcname.pattern) {
 		const struct userdiff_funcname *pe = &drv->funcname;
 		xecfg = xcalloc(1, sizeof(*xecfg));
@@ -244,7 +245,8 @@ static const char *parse_range_funcname(
 
 int parse_range_arg(const char *arg, nth_line_fn_t nth_line_cb,
 		    void *cb_data, long lines, long anchor,
-		    long *begin, long *end, const char *path)
+		    long *begin, long *end,
+		    const char *path, struct index_state *istate)
 {
 	*begin = *end = 0;
 
@@ -254,7 +256,9 @@ int parse_range_arg(const char *arg, nth
 		anchor = lines + 1;
 
 	if (*arg == ':' || (*arg == '^' && *(arg + 1) == ':')) {
-		arg = parse_range_funcname(arg, nth_line_cb, cb_data, lines, anchor, begin, end, path);
+		arg = parse_range_funcname(arg, nth_line_cb, cb_data,
+					   lines, anchor, begin, end,
+					   path, istate);
 		if (!arg || *arg)
 			return -1;
 		return 0;
@@ -275,10 +279,12 @@ int parse_range_arg(const char *arg, nth
 	return 0;
 }
 
-const char *skip_range_arg(const char *arg)
+const char *skip_range_arg(const char *arg, struct index_state *istate)
 {
 	if (*arg == ':' || (*arg == '^' && *(arg + 1) == ':'))
-		return parse_range_funcname(arg, NULL, NULL, 0, 0, NULL, NULL, NULL);
+		return parse_range_funcname(arg, NULL, NULL,
+					    0, 0, NULL, NULL,
+					    NULL, istate);
 
 	arg = parse_loc(arg, NULL, NULL, 0, -1, NULL);
 
diff -pruN 1.2.1+git2.18.0-1/git/line-range.h 1.2.3+git2.25.1-1/git/line-range.h
--- 1.2.1+git2.18.0-1/git/line-range.h	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/line-range.h	2020-02-17 04:47:35.000000000 +0000
@@ -1,6 +1,8 @@
 #ifndef LINE_RANGE_H
 #define LINE_RANGE_H
 
+struct index_state;
+
 /*
  * Parse one item in an -L begin,end option w.r.t. the notional file
  * object 'cb_data' consisting of 'lines' lines.
@@ -19,11 +21,11 @@
 
 typedef const char *(*nth_line_fn_t)(void *data, long lno);
 
-extern int parse_range_arg(const char *arg,
-			   nth_line_fn_t nth_line_cb,
-			   void *cb_data, long lines, long anchor,
-			   long *begin, long *end,
-			   const char *path);
+int parse_range_arg(const char *arg,
+		    nth_line_fn_t nth_line_cb,
+		    void *cb_data, long lines, long anchor,
+		    long *begin, long *end,
+		    const char *path, struct index_state *istate);
 
 /*
  * Scan past a range argument that could be parsed by
@@ -34,6 +36,6 @@ extern int parse_range_arg(const char *a
  * NULL in case the argument is obviously malformed.
  */
 
-extern const char *skip_range_arg(const char *arg);
+const char *skip_range_arg(const char *arg, struct index_state *istate);
 
 #endif /* LINE_RANGE_H */
diff -pruN 1.2.1+git2.18.0-1/git/list-objects.c 1.2.3+git2.25.1-1/git/list-objects.c
--- 1.2.1+git2.18.0-1/git/list-objects.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/list-objects.c	2020-02-17 04:47:35.000000000 +0000
@@ -10,21 +10,27 @@
 #include "list-objects-filter.h"
 #include "list-objects-filter-options.h"
 #include "packfile.h"
+#include "object-store.h"
+#include "trace.h"
 
-static void process_blob(struct rev_info *revs,
+struct traversal_context {
+	struct rev_info *revs;
+	show_object_fn show_object;
+	show_commit_fn show_commit;
+	void *show_data;
+	struct filter *filter;
+};
+
+static void process_blob(struct traversal_context *ctx,
 			 struct blob *blob,
-			 show_object_fn show,
 			 struct strbuf *path,
-			 const char *name,
-			 void *cb_data,
-			 filter_object_fn filter_fn,
-			 void *filter_data)
+			 const char *name)
 {
 	struct object *obj = &blob->object;
 	size_t pathlen;
-	enum list_objects_filter_result r = LOFR_MARK_SEEN | LOFR_DO_SHOW;
+	enum list_objects_filter_result r;
 
-	if (!revs->blob_objects)
+	if (!ctx->revs->blob_objects)
 		return;
 	if (!obj)
 		die("bad blob object");
@@ -40,21 +46,21 @@ static void process_blob(struct rev_info
 	 * may cause the actual filter to report an incomplete list
 	 * of missing objects.
 	 */
-	if (revs->exclude_promisor_objects &&
+	if (ctx->revs->exclude_promisor_objects &&
 	    !has_object_file(&obj->oid) &&
 	    is_promisor_object(&obj->oid))
 		return;
 
 	pathlen = path->len;
 	strbuf_addstr(path, name);
-	if (filter_fn)
-		r = filter_fn(LOFS_BLOB, obj,
-			      path->buf, &path->buf[pathlen],
-			      filter_data);
+	r = list_objects_filter__filter_object(ctx->revs->repo,
+					       LOFS_BLOB, obj,
+					       path->buf, &path->buf[pathlen],
+					       ctx->filter);
 	if (r & LOFR_MARK_SEEN)
 		obj->flags |= SEEN;
 	if (r & LOFR_DO_SHOW)
-		show(obj, path->buf, cb_data);
+		ctx->show_object(obj, path->buf, ctx->show_data);
 	strbuf_setlen(path, pathlen);
 }
 
@@ -80,34 +86,77 @@ static void process_blob(struct rev_info
  * the link, and how to do it. Whether it necessarily makes
  * any sense what-so-ever to ever do that is another issue.
  */
-static void process_gitlink(struct rev_info *revs,
+static void process_gitlink(struct traversal_context *ctx,
 			    const unsigned char *sha1,
-			    show_object_fn show,
 			    struct strbuf *path,
-			    const char *name,
-			    void *cb_data)
+			    const char *name)
 {
 	/* Nothing to do */
 }
 
-static void process_tree(struct rev_info *revs,
+static void process_tree(struct traversal_context *ctx,
 			 struct tree *tree,
-			 show_object_fn show,
 			 struct strbuf *base,
-			 const char *name,
-			 void *cb_data,
-			 filter_object_fn filter_fn,
-			 void *filter_data)
+			 const char *name);
+
+static void process_tree_contents(struct traversal_context *ctx,
+				  struct tree *tree,
+				  struct strbuf *base)
 {
-	struct object *obj = &tree->object;
 	struct tree_desc desc;
 	struct name_entry entry;
-	enum interesting match = revs->diffopt.pathspec.nr == 0 ?
-		all_entries_interesting: entry_not_interesting;
+	enum interesting match = ctx->revs->diffopt.pathspec.nr == 0 ?
+		all_entries_interesting : entry_not_interesting;
+
+	init_tree_desc(&desc, tree->buffer, tree->size);
+
+	while (tree_entry(&desc, &entry)) {
+		if (match != all_entries_interesting) {
+			match = tree_entry_interesting(ctx->revs->repo->index,
+						       &entry, base, 0,
+						       &ctx->revs->diffopt.pathspec);
+			if (match == all_entries_not_interesting)
+				break;
+			if (match == entry_not_interesting)
+				continue;
+		}
+
+		if (S_ISDIR(entry.mode)) {
+			struct tree *t = lookup_tree(ctx->revs->repo, &entry.oid);
+			if (!t) {
+				die(_("entry '%s' in tree %s has tree mode, "
+				      "but is not a tree"),
+				    entry.path, oid_to_hex(&tree->object.oid));
+			}
+			t->object.flags |= NOT_USER_GIVEN;
+			process_tree(ctx, t, base, entry.path);
+		}
+		else if (S_ISGITLINK(entry.mode))
+			process_gitlink(ctx, entry.oid.hash,
+					base, entry.path);
+		else {
+			struct blob *b = lookup_blob(ctx->revs->repo, &entry.oid);
+			if (!b) {
+				die(_("entry '%s' in tree %s has blob mode, "
+				      "but is not a blob"),
+				    entry.path, oid_to_hex(&tree->object.oid));
+			}
+			b->object.flags |= NOT_USER_GIVEN;
+			process_blob(ctx, b, base, entry.path);
+		}
+	}
+}
+
+static void process_tree(struct traversal_context *ctx,
+			 struct tree *tree,
+			 struct strbuf *base,
+			 const char *name)
+{
+	struct object *obj = &tree->object;
+	struct rev_info *revs = ctx->revs;
 	int baselen = base->len;
-	enum list_objects_filter_result r = LOFR_MARK_SEEN | LOFR_DO_SHOW;
-	int gently = revs->ignore_missing_links ||
-		     revs->exclude_promisor_objects;
+	enum list_objects_filter_result r;
+	int failed_parse;
 
 	if (!revs->tree_objects)
 		return;
@@ -115,7 +164,9 @@ static void process_tree(struct rev_info
 		die("bad tree object");
 	if (obj->flags & (UNINTERESTING | SEEN))
 		return;
-	if (parse_tree_gently(tree, gently) < 0) {
+
+	failed_parse = parse_tree_gently(tree, 1);
+	if (failed_parse) {
 		if (revs->ignore_missing_links)
 			return;
 
@@ -128,58 +179,35 @@ static void process_tree(struct rev_info
 		    is_promisor_object(&obj->oid))
 			return;
 
-		die("bad tree object %s", oid_to_hex(&obj->oid));
+		if (!revs->do_not_die_on_missing_tree)
+			die("bad tree object %s", oid_to_hex(&obj->oid));
 	}
 
 	strbuf_addstr(base, name);
-	if (filter_fn)
-		r = filter_fn(LOFS_BEGIN_TREE, obj,
-			      base->buf, &base->buf[baselen],
-			      filter_data);
+	r = list_objects_filter__filter_object(ctx->revs->repo,
+					       LOFS_BEGIN_TREE, obj,
+					       base->buf, &base->buf[baselen],
+					       ctx->filter);
 	if (r & LOFR_MARK_SEEN)
 		obj->flags |= SEEN;
 	if (r & LOFR_DO_SHOW)
-		show(obj, base->buf, cb_data);
+		ctx->show_object(obj, base->buf, ctx->show_data);
 	if (base->len)
 		strbuf_addch(base, '/');
 
-	init_tree_desc(&desc, tree->buffer, tree->size);
-
-	while (tree_entry(&desc, &entry)) {
-		if (match != all_entries_interesting) {
-			match = tree_entry_interesting(&entry, base, 0,
-						       &revs->diffopt.pathspec);
-			if (match == all_entries_not_interesting)
-				break;
-			if (match == entry_not_interesting)
-				continue;
-		}
-
-		if (S_ISDIR(entry.mode))
-			process_tree(revs,
-				     lookup_tree(entry.oid),
-				     show, base, entry.path,
-				     cb_data, filter_fn, filter_data);
-		else if (S_ISGITLINK(entry.mode))
-			process_gitlink(revs, entry.oid->hash,
-					show, base, entry.path,
-					cb_data);
-		else
-			process_blob(revs,
-				     lookup_blob(entry.oid),
-				     show, base, entry.path,
-				     cb_data, filter_fn, filter_data);
-	}
-
-	if (filter_fn) {
-		r = filter_fn(LOFS_END_TREE, obj,
-			      base->buf, &base->buf[baselen],
-			      filter_data);
-		if (r & LOFR_MARK_SEEN)
-			obj->flags |= SEEN;
-		if (r & LOFR_DO_SHOW)
-			show(obj, base->buf, cb_data);
-	}
+	if (r & LOFR_SKIP_TREE)
+		trace_printf("Skipping contents of tree %s...\n", base->buf);
+	else if (!failed_parse)
+		process_tree_contents(ctx, tree, base);
+
+	r = list_objects_filter__filter_object(ctx->revs->repo,
+					       LOFS_END_TREE, obj,
+					       base->buf, &base->buf[baselen],
+					       ctx->filter);
+	if (r & LOFR_MARK_SEEN)
+		obj->flags |= SEEN;
+	if (r & LOFR_DO_SHOW)
+		ctx->show_object(obj, base->buf, ctx->show_data);
 
 	strbuf_setlen(base, baselen);
 	free_tree_buffer(tree);
@@ -195,7 +223,34 @@ static void mark_edge_parents_uninterest
 		struct commit *parent = parents->item;
 		if (!(parent->object.flags & UNINTERESTING))
 			continue;
-		mark_tree_uninteresting(get_commit_tree(parent));
+		mark_tree_uninteresting(revs->repo, get_commit_tree(parent));
+		if (revs->edge_hint && !(parent->object.flags & SHOWN)) {
+			parent->object.flags |= SHOWN;
+			show_edge(parent);
+		}
+	}
+}
+
+static void add_edge_parents(struct commit *commit,
+			     struct rev_info *revs,
+			     show_edge_fn show_edge,
+			     struct oidset *set)
+{
+	struct commit_list *parents;
+
+	for (parents = commit->parents; parents; parents = parents->next) {
+		struct commit *parent = parents->item;
+		struct tree *tree = get_commit_tree(parent);
+
+		if (!tree)
+			continue;
+
+		oidset_insert(set, &tree->object.oid);
+
+		if (!(parent->object.flags & UNINTERESTING))
+			continue;
+		tree->object.flags |= UNINTERESTING;
+
 		if (revs->edge_hint && !(parent->object.flags & SHOWN)) {
 			parent->object.flags |= SHOWN;
 			show_edge(parent);
@@ -203,31 +258,54 @@ static void mark_edge_parents_uninterest
 	}
 }
 
-void mark_edges_uninteresting(struct rev_info *revs, show_edge_fn show_edge)
+void mark_edges_uninteresting(struct rev_info *revs,
+			      show_edge_fn show_edge,
+			      int sparse)
 {
 	struct commit_list *list;
 	int i;
 
-	for (list = revs->commits; list; list = list->next) {
-		struct commit *commit = list->item;
+	if (sparse) {
+		struct oidset set;
+		oidset_init(&set, 16);
+
+		for (list = revs->commits; list; list = list->next) {
+			struct commit *commit = list->item;
+			struct tree *tree = get_commit_tree(commit);
 
-		if (commit->object.flags & UNINTERESTING) {
-			mark_tree_uninteresting(get_commit_tree(commit));
-			if (revs->edge_hint_aggressive && !(commit->object.flags & SHOWN)) {
-				commit->object.flags |= SHOWN;
-				show_edge(commit);
+			if (commit->object.flags & UNINTERESTING)
+				tree->object.flags |= UNINTERESTING;
+
+			oidset_insert(&set, &tree->object.oid);
+			add_edge_parents(commit, revs, show_edge, &set);
+		}
+
+		mark_trees_uninteresting_sparse(revs->repo, &set);
+		oidset_clear(&set);
+	} else {
+		for (list = revs->commits; list; list = list->next) {
+			struct commit *commit = list->item;
+			if (commit->object.flags & UNINTERESTING) {
+				mark_tree_uninteresting(revs->repo,
+							get_commit_tree(commit));
+				if (revs->edge_hint_aggressive && !(commit->object.flags & SHOWN)) {
+					commit->object.flags |= SHOWN;
+					show_edge(commit);
+				}
+				continue;
 			}
-			continue;
+			mark_edge_parents_uninteresting(commit, revs, show_edge);
 		}
-		mark_edge_parents_uninteresting(commit, revs, show_edge);
 	}
+
 	if (revs->edge_hint_aggressive) {
 		for (i = 0; i < revs->cmdline.nr; i++) {
 			struct object *obj = revs->cmdline.rev[i].item;
 			struct commit *commit = (struct commit *)obj;
 			if (obj->type != OBJ_COMMIT || !(obj->flags & UNINTERESTING))
 				continue;
-			mark_tree_uninteresting(get_commit_tree(commit));
+			mark_tree_uninteresting(revs->repo,
+						get_commit_tree(commit));
 			if (!(obj->flags & SHOWN)) {
 				obj->flags |= SHOWN;
 				show_edge(commit);
@@ -241,19 +319,15 @@ static void add_pending_tree(struct rev_
 	add_pending_object(revs, &tree->object, "");
 }
 
-static void traverse_trees_and_blobs(struct rev_info *revs,
-				     struct strbuf *base,
-				     show_object_fn show_object,
-				     void *show_data,
-				     filter_object_fn filter_fn,
-				     void *filter_data)
+static void traverse_trees_and_blobs(struct traversal_context *ctx,
+				     struct strbuf *base)
 {
 	int i;
 
 	assert(base->len == 0);
 
-	for (i = 0; i < revs->pending.nr; i++) {
-		struct object_array_entry *pending = revs->pending.objects + i;
+	for (i = 0; i < ctx->revs->pending.nr; i++) {
+		struct object_array_entry *pending = ctx->revs->pending.objects + i;
 		struct object *obj = pending->item;
 		const char *name = pending->name;
 		const char *path = pending->path;
@@ -261,62 +335,57 @@ static void traverse_trees_and_blobs(str
 			continue;
 		if (obj->type == OBJ_TAG) {
 			obj->flags |= SEEN;
-			show_object(obj, name, show_data);
+			ctx->show_object(obj, name, ctx->show_data);
 			continue;
 		}
 		if (!path)
 			path = "";
 		if (obj->type == OBJ_TREE) {
-			process_tree(revs, (struct tree *)obj, show_object,
-				     base, path, show_data,
-				     filter_fn, filter_data);
+			process_tree(ctx, (struct tree *)obj, base, path);
 			continue;
 		}
 		if (obj->type == OBJ_BLOB) {
-			process_blob(revs, (struct blob *)obj, show_object,
-				     base, path, show_data,
-				     filter_fn, filter_data);
+			process_blob(ctx, (struct blob *)obj, base, path);
 			continue;
 		}
 		die("unknown pending object %s (%s)",
 		    oid_to_hex(&obj->oid), name);
 	}
-	object_array_clear(&revs->pending);
+	object_array_clear(&ctx->revs->pending);
 }
 
-static void do_traverse(struct rev_info *revs,
-			show_commit_fn show_commit,
-			show_object_fn show_object,
-			void *show_data,
-			filter_object_fn filter_fn,
-			void *filter_data)
+static void do_traverse(struct traversal_context *ctx)
 {
 	struct commit *commit;
 	struct strbuf csp; /* callee's scratch pad */
 	strbuf_init(&csp, PATH_MAX);
 
-	while ((commit = get_revision(revs)) != NULL) {
+	while ((commit = get_revision(ctx->revs)) != NULL) {
 		/*
 		 * an uninteresting boundary commit may not have its tree
 		 * parsed yet, but we are not going to show them anyway
 		 */
-		if (get_commit_tree(commit))
-			add_pending_tree(revs, get_commit_tree(commit));
-		show_commit(commit, show_data);
+		if (!ctx->revs->tree_objects)
+			; /* do not bother loading tree */
+		else if (get_commit_tree(commit)) {
+			struct tree *tree = get_commit_tree(commit);
+			tree->object.flags |= NOT_USER_GIVEN;
+			add_pending_tree(ctx->revs, tree);
+		} else if (commit->object.parsed) {
+			die(_("unable to load root tree for commit %s"),
+			      oid_to_hex(&commit->object.oid));
+		}
+		ctx->show_commit(commit, ctx->show_data);
 
-		if (revs->tree_blobs_in_commit_order)
+		if (ctx->revs->tree_blobs_in_commit_order)
 			/*
 			 * NEEDSWORK: Adding the tree and then flushing it here
 			 * needs a reallocation for each commit. Can we pass the
 			 * tree directory without allocation churn?
 			 */
-			traverse_trees_and_blobs(revs, &csp,
-						 show_object, show_data,
-						 filter_fn, filter_data);
+			traverse_trees_and_blobs(ctx, &csp);
 	}
-	traverse_trees_and_blobs(revs, &csp,
-				 show_object, show_data,
-				 filter_fn, filter_data);
+	traverse_trees_and_blobs(ctx, &csp);
 	strbuf_release(&csp);
 }
 
@@ -325,7 +394,13 @@ void traverse_commit_list(struct rev_inf
 			  show_object_fn show_object,
 			  void *show_data)
 {
-	do_traverse(revs, show_commit, show_object, show_data, NULL, NULL);
+	struct traversal_context ctx;
+	ctx.revs = revs;
+	ctx.show_commit = show_commit;
+	ctx.show_object = show_object;
+	ctx.show_data = show_data;
+	ctx.filter = NULL;
+	do_traverse(&ctx);
 }
 
 void traverse_commit_list_filtered(
@@ -336,14 +411,13 @@ void traverse_commit_list_filtered(
 	void *show_data,
 	struct oidset *omitted)
 {
-	filter_object_fn filter_fn = NULL;
-	filter_free_fn filter_free_fn = NULL;
-	void *filter_data = NULL;
-
-	filter_data = list_objects_filter__init(omitted, filter_options,
-						&filter_fn, &filter_free_fn);
-	do_traverse(revs, show_commit, show_object, show_data,
-		    filter_fn, filter_data);
-	if (filter_data && filter_free_fn)
-		filter_free_fn(filter_data);
+	struct traversal_context ctx;
+
+	ctx.revs = revs;
+	ctx.show_object = show_object;
+	ctx.show_commit = show_commit;
+	ctx.show_data = show_data;
+	ctx.filter = list_objects_filter__init(omitted, filter_options);
+	do_traverse(&ctx);
+	list_objects_filter__free(ctx.filter);
 }
diff -pruN 1.2.1+git2.18.0-1/git/list-objects-filter.c 1.2.3+git2.25.1-1/git/list-objects-filter.c
--- 1.2.1+git2.18.0-1/git/list-objects-filter.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/list-objects-filter.c	2020-02-17 04:47:35.000000000 +0000
@@ -10,7 +10,9 @@
 #include "list-objects.h"
 #include "list-objects-filter.h"
 #include "list-objects-filter-options.h"
+#include "oidmap.h"
 #include "oidset.h"
+#include "object-store.h"
 
 /* Remember to update object flag allocation in object.h */
 /*
@@ -24,27 +26,61 @@
  */
 #define FILTER_SHOWN_BUT_REVISIT (1<<21)
 
-/*
- * A filter for list-objects to omit ALL blobs from the traversal.
- * And to OPTIONALLY collect a list of the omitted OIDs.
- */
-struct filter_blobs_none_data {
+struct subfilter {
+	struct filter *filter;
+	struct oidset seen;
+	struct oidset omits;
+	struct object_id skip_tree;
+	unsigned is_skipping_tree : 1;
+};
+
+struct filter {
+	enum list_objects_filter_result (*filter_object_fn)(
+		struct repository *r,
+		enum list_objects_filter_situation filter_situation,
+		struct object *obj,
+		const char *pathname,
+		const char *filename,
+		struct oidset *omits,
+		void *filter_data);
+
+	/*
+	 * Optional. If this function is supplied and the filter needs
+	 * to collect omits, then this function is called once before
+	 * free_fn is called.
+	 *
+	 * This is required because the following two conditions hold:
+	 *
+	 *   a. A tree filter can add and remove objects as an object
+	 *      graph is traversed.
+	 *   b. A combine filter's omit set is the union of all its
+	 *      subfilters, which may include tree: filters.
+	 *
+	 * As such, the omits sets must be separate sets, and can only
+	 * be unioned after the traversal is completed.
+	 */
+	void (*finalize_omits_fn)(struct oidset *omits, void *filter_data);
+
+	void (*free_fn)(void *filter_data);
+
+	void *filter_data;
+
+	/* If non-NULL, the filter collects a list of the omitted OIDs here. */
 	struct oidset *omits;
 };
 
 static enum list_objects_filter_result filter_blobs_none(
+	struct repository *r,
 	enum list_objects_filter_situation filter_situation,
 	struct object *obj,
 	const char *pathname,
 	const char *filename,
+	struct oidset *omits,
 	void *filter_data_)
 {
-	struct filter_blobs_none_data *filter_data = filter_data_;
-
 	switch (filter_situation) {
 	default:
-		die("unknown filter_situation");
-		return LOFR_ZERO;
+		BUG("unknown filter_situation: %d", filter_situation);
 
 	case LOFS_BEGIN_TREE:
 		assert(obj->type == OBJ_TREE);
@@ -59,24 +95,151 @@ static enum list_objects_filter_result f
 		assert(obj->type == OBJ_BLOB);
 		assert((obj->flags & SEEN) == 0);
 
-		if (filter_data->omits)
-			oidset_insert(filter_data->omits, &obj->oid);
+		if (omits)
+			oidset_insert(omits, &obj->oid);
 		return LOFR_MARK_SEEN; /* but not LOFR_DO_SHOW (hard omit) */
 	}
 }
 
-static void *filter_blobs_none__init(
-	struct oidset *omitted,
+static void filter_blobs_none__init(
 	struct list_objects_filter_options *filter_options,
-	filter_object_fn *filter_fn,
-	filter_free_fn *filter_free_fn)
+	struct filter *filter)
+{
+	filter->filter_object_fn = filter_blobs_none;
+	filter->free_fn = free;
+}
+
+/*
+ * A filter for list-objects to omit ALL trees and blobs from the traversal.
+ * Can OPTIONALLY collect a list of the omitted OIDs.
+ */
+struct filter_trees_depth_data {
+	/*
+	 * Maps trees to the minimum depth at which they were seen. It is not
+	 * necessary to re-traverse a tree at deeper or equal depths than it has
+	 * already been traversed.
+	 *
+	 * We can't use LOFR_MARK_SEEN for tree objects since this will prevent
+	 * it from being traversed at shallower depths.
+	 */
+	struct oidmap seen_at_depth;
+
+	unsigned long exclude_depth;
+	unsigned long current_depth;
+};
+
+struct seen_map_entry {
+	struct oidmap_entry base;
+	size_t depth;
+};
+
+/* Returns 1 if the oid was in the omits set before it was invoked. */
+static int filter_trees_update_omits(
+	struct object *obj,
+	struct oidset *omits,
+	int include_it)
+{
+	if (!omits)
+		return 0;
+
+	if (include_it)
+		return oidset_remove(omits, &obj->oid);
+	else
+		return oidset_insert(omits, &obj->oid);
+}
+
+static enum list_objects_filter_result filter_trees_depth(
+	struct repository *r,
+	enum list_objects_filter_situation filter_situation,
+	struct object *obj,
+	const char *pathname,
+	const char *filename,
+	struct oidset *omits,
+	void *filter_data_)
 {
-	struct filter_blobs_none_data *d = xcalloc(1, sizeof(*d));
-	d->omits = omitted;
+	struct filter_trees_depth_data *filter_data = filter_data_;
+	struct seen_map_entry *seen_info;
+	int include_it = filter_data->current_depth <
+		filter_data->exclude_depth;
+	int filter_res;
+	int already_seen;
+
+	/*
+	 * Note that we do not use _MARK_SEEN in order to allow re-traversal in
+	 * case we encounter a tree or blob again at a shallower depth.
+	 */
+
+	switch (filter_situation) {
+	default:
+		BUG("unknown filter_situation: %d", filter_situation);
+
+	case LOFS_END_TREE:
+		assert(obj->type == OBJ_TREE);
+		filter_data->current_depth--;
+		return LOFR_ZERO;
+
+	case LOFS_BLOB:
+		filter_trees_update_omits(obj, omits, include_it);
+		return include_it ? LOFR_MARK_SEEN | LOFR_DO_SHOW : LOFR_ZERO;
 
-	*filter_fn = filter_blobs_none;
-	*filter_free_fn = free;
-	return d;
+	case LOFS_BEGIN_TREE:
+		seen_info = oidmap_get(
+			&filter_data->seen_at_depth, &obj->oid);
+		if (!seen_info) {
+			seen_info = xcalloc(1, sizeof(*seen_info));
+			oidcpy(&seen_info->base.oid, &obj->oid);
+			seen_info->depth = filter_data->current_depth;
+			oidmap_put(&filter_data->seen_at_depth, seen_info);
+			already_seen = 0;
+		} else {
+			already_seen =
+				filter_data->current_depth >= seen_info->depth;
+		}
+
+		if (already_seen) {
+			filter_res = LOFR_SKIP_TREE;
+		} else {
+			int been_omitted = filter_trees_update_omits(
+				obj, omits, include_it);
+			seen_info->depth = filter_data->current_depth;
+
+			if (include_it)
+				filter_res = LOFR_DO_SHOW;
+			else if (omits && !been_omitted)
+				/*
+				 * Must update omit information of children
+				 * recursively; they have not been omitted yet.
+				 */
+				filter_res = LOFR_ZERO;
+			else
+				filter_res = LOFR_SKIP_TREE;
+		}
+
+		filter_data->current_depth++;
+		return filter_res;
+	}
+}
+
+static void filter_trees_free(void *filter_data) {
+	struct filter_trees_depth_data *d = filter_data;
+	if (!d)
+		return;
+	oidmap_free(&d->seen_at_depth, 1);
+	free(d);
+}
+
+static void filter_trees_depth__init(
+	struct list_objects_filter_options *filter_options,
+	struct filter *filter)
+{
+	struct filter_trees_depth_data *d = xcalloc(1, sizeof(*d));
+	oidmap_init(&d->seen_at_depth, 0);
+	d->exclude_depth = filter_options->tree_exclude_depth;
+	d->current_depth = 0;
+
+	filter->filter_data = d;
+	filter->filter_object_fn = filter_trees_depth;
+	filter->free_fn = filter_trees_free;
 }
 
 /*
@@ -84,15 +247,16 @@ static void *filter_blobs_none__init(
  * And to OPTIONALLY collect a list of the omitted OIDs.
  */
 struct filter_blobs_limit_data {
-	struct oidset *omits;
 	unsigned long max_bytes;
 };
 
 static enum list_objects_filter_result filter_blobs_limit(
+	struct repository *r,
 	enum list_objects_filter_situation filter_situation,
 	struct object *obj,
 	const char *pathname,
 	const char *filename,
+	struct oidset *omits,
 	void *filter_data_)
 {
 	struct filter_blobs_limit_data *filter_data = filter_data_;
@@ -101,8 +265,7 @@ static enum list_objects_filter_result f
 
 	switch (filter_situation) {
 	default:
-		die("unknown filter_situation");
-		return LOFR_ZERO;
+		BUG("unknown filter_situation: %d", filter_situation);
 
 	case LOFS_BEGIN_TREE:
 		assert(obj->type == OBJ_TREE);
@@ -117,7 +280,7 @@ static enum list_objects_filter_result f
 		assert(obj->type == OBJ_BLOB);
 		assert((obj->flags & SEEN) == 0);
 
-		t = oid_object_info(the_repository, &obj->oid, &object_length);
+		t = oid_object_info(r, &obj->oid, &object_length);
 		if (t != OBJ_BLOB) { /* probably OBJ_NONE */
 			/*
 			 * We DO NOT have the blob locally, so we cannot
@@ -131,30 +294,27 @@ static enum list_objects_filter_result f
 		if (object_length < filter_data->max_bytes)
 			goto include_it;
 
-		if (filter_data->omits)
-			oidset_insert(filter_data->omits, &obj->oid);
+		if (omits)
+			oidset_insert(omits, &obj->oid);
 		return LOFR_MARK_SEEN; /* but not LOFR_DO_SHOW (hard omit) */
 	}
 
 include_it:
-	if (filter_data->omits)
-		oidset_remove(filter_data->omits, &obj->oid);
+	if (omits)
+		oidset_remove(omits, &obj->oid);
 	return LOFR_MARK_SEEN | LOFR_DO_SHOW;
 }
 
-static void *filter_blobs_limit__init(
-	struct oidset *omitted,
+static void filter_blobs_limit__init(
 	struct list_objects_filter_options *filter_options,
-	filter_object_fn *filter_fn,
-	filter_free_fn *filter_free_fn)
+	struct filter *filter)
 {
 	struct filter_blobs_limit_data *d = xcalloc(1, sizeof(*d));
-	d->omits = omitted;
 	d->max_bytes = filter_options->blob_limit_value;
 
-	*filter_fn = filter_blobs_limit;
-	*filter_free_fn = free;
-	return d;
+	filter->filter_data = d;
+	filter->filter_object_fn = filter_blobs_limit;
+	filter->free_fn = free;
 }
 
 /*
@@ -168,12 +328,12 @@ static void *filter_blobs_limit__init(
  */
 struct frame {
 	/*
-	 * defval is the usual default include/exclude value that
+	 * default_match is the usual default include/exclude value that
 	 * should be inherited as we recurse into directories based
 	 * upon pattern matching of the directory itself or of a
 	 * containing directory.
 	 */
-	int defval;
+	enum pattern_match_result default_match;
 
 	/*
 	 * 1 if the directory (recursively) contains any provisionally
@@ -187,43 +347,44 @@ struct frame {
 };
 
 struct filter_sparse_data {
-	struct oidset *omits;
-	struct exclude_list el;
+	struct pattern_list pl;
 
 	size_t nr, alloc;
 	struct frame *array_frame;
 };
 
 static enum list_objects_filter_result filter_sparse(
+	struct repository *r,
 	enum list_objects_filter_situation filter_situation,
 	struct object *obj,
 	const char *pathname,
 	const char *filename,
+	struct oidset *omits,
 	void *filter_data_)
 {
 	struct filter_sparse_data *filter_data = filter_data_;
-	int val, dtype;
+	int dtype;
 	struct frame *frame;
+	enum pattern_match_result match;
 
 	switch (filter_situation) {
 	default:
-		die("unknown filter_situation");
-		return LOFR_ZERO;
+		BUG("unknown filter_situation: %d", filter_situation);
 
 	case LOFS_BEGIN_TREE:
 		assert(obj->type == OBJ_TREE);
 		dtype = DT_DIR;
-		val = is_excluded_from_list(pathname, strlen(pathname),
-					    filename, &dtype, &filter_data->el,
-					    &the_index);
-		if (val < 0)
-			val = filter_data->array_frame[filter_data->nr].defval;
+		match = path_matches_pattern_list(pathname, strlen(pathname),
+						  filename, &dtype, &filter_data->pl,
+						  r->index);
+		if (match == UNDECIDED)
+			match = filter_data->array_frame[filter_data->nr - 1].default_match;
 
 		ALLOC_GROW(filter_data->array_frame, filter_data->nr + 1,
 			   filter_data->alloc);
-		filter_data->nr++;
-		filter_data->array_frame[filter_data->nr].defval = val;
+		filter_data->array_frame[filter_data->nr].default_match = match;
 		filter_data->array_frame[filter_data->nr].child_prov_omit = 0;
+		filter_data->nr++;
 
 		/*
 		 * A directory with this tree OID may appear in multiple
@@ -248,16 +409,15 @@ static enum list_objects_filter_result f
 
 	case LOFS_END_TREE:
 		assert(obj->type == OBJ_TREE);
-		assert(filter_data->nr > 0);
+		assert(filter_data->nr > 1);
 
-		frame = &filter_data->array_frame[filter_data->nr];
-		filter_data->nr--;
+		frame = &filter_data->array_frame[--filter_data->nr];
 
 		/*
 		 * Tell our parent directory if any of our children were
 		 * provisionally omitted.
 		 */
-		filter_data->array_frame[filter_data->nr].child_prov_omit |=
+		filter_data->array_frame[filter_data->nr - 1].child_prov_omit |=
 			frame->child_prov_omit;
 
 		/*
@@ -273,17 +433,17 @@ static enum list_objects_filter_result f
 		assert(obj->type == OBJ_BLOB);
 		assert((obj->flags & SEEN) == 0);
 
-		frame = &filter_data->array_frame[filter_data->nr];
+		frame = &filter_data->array_frame[filter_data->nr - 1];
 
 		dtype = DT_REG;
-		val = is_excluded_from_list(pathname, strlen(pathname),
-					    filename, &dtype, &filter_data->el,
-					    &the_index);
-		if (val < 0)
-			val = frame->defval;
-		if (val > 0) {
-			if (filter_data->omits)
-				oidset_remove(filter_data->omits, &obj->oid);
+		match = path_matches_pattern_list(pathname, strlen(pathname),
+					    filename, &dtype, &filter_data->pl,
+					    r->index);
+		if (match == UNDECIDED)
+			match = frame->default_match;
+		if (match == MATCHED) {
+			if (omits)
+				oidset_remove(omits, &obj->oid);
 			return LOFR_MARK_SEEN | LOFR_DO_SHOW;
 		}
 
@@ -297,8 +457,8 @@ static enum list_objects_filter_result f
 		 * Leave the LOFR_ bits unset so that if the blob appears
 		 * again in the traversal, we will be asked again.
 		 */
-		if (filter_data->omits)
-			oidset_insert(filter_data->omits, &obj->oid);
+		if (omits)
+			oidset_insert(omits, &obj->oid);
 
 		/*
 		 * Remember that at least 1 blob in this tree was
@@ -314,57 +474,173 @@ static enum list_objects_filter_result f
 static void filter_sparse_free(void *filter_data)
 {
 	struct filter_sparse_data *d = filter_data;
-	/* TODO free contents of 'd' */
+	free(d->array_frame);
 	free(d);
 }
 
-static void *filter_sparse_oid__init(
-	struct oidset *omitted,
+static void filter_sparse_oid__init(
 	struct list_objects_filter_options *filter_options,
-	filter_object_fn *filter_fn,
-	filter_free_fn *filter_free_fn)
+	struct filter *filter)
 {
 	struct filter_sparse_data *d = xcalloc(1, sizeof(*d));
-	d->omits = omitted;
-	if (add_excludes_from_blob_to_list(filter_options->sparse_oid_value,
-					   NULL, 0, &d->el) < 0)
-		die("could not load filter specification");
+	struct object_context oc;
+	struct object_id sparse_oid;
+
+	if (get_oid_with_context(the_repository,
+				 filter_options->sparse_oid_name,
+				 GET_OID_BLOB, &sparse_oid, &oc))
+		die(_("unable to access sparse blob in '%s'"),
+		    filter_options->sparse_oid_name);
+	if (add_patterns_from_blob_to_list(&sparse_oid, "", 0, &d->pl) < 0)
+		die(_("unable to parse sparse filter data in %s"),
+		    oid_to_hex(&sparse_oid));
 
 	ALLOC_GROW(d->array_frame, d->nr + 1, d->alloc);
-	d->array_frame[d->nr].defval = 0; /* default to include */
+	d->array_frame[d->nr].default_match = 0; /* default to include */
 	d->array_frame[d->nr].child_prov_omit = 0;
+	d->nr++;
 
-	*filter_fn = filter_sparse;
-	*filter_free_fn = filter_sparse_free;
-	return d;
+	filter->filter_data = d;
+	filter->filter_object_fn = filter_sparse;
+	filter->free_fn = filter_sparse_free;
 }
 
-static void *filter_sparse_path__init(
-	struct oidset *omitted,
-	struct list_objects_filter_options *filter_options,
-	filter_object_fn *filter_fn,
-	filter_free_fn *filter_free_fn)
+/* A filter which only shows objects shown by all sub-filters. */
+struct combine_filter_data {
+	struct subfilter *sub;
+	size_t nr;
+};
+
+static enum list_objects_filter_result process_subfilter(
+	struct repository *r,
+	enum list_objects_filter_situation filter_situation,
+	struct object *obj,
+	const char *pathname,
+	const char *filename,
+	struct subfilter *sub)
 {
-	struct filter_sparse_data *d = xcalloc(1, sizeof(*d));
-	d->omits = omitted;
-	if (add_excludes_from_file_to_list(filter_options->sparse_path_value,
-					   NULL, 0, &d->el, NULL) < 0)
-		die("could not load filter specification");
+	enum list_objects_filter_result result;
 
-	ALLOC_GROW(d->array_frame, d->nr + 1, d->alloc);
-	d->array_frame[d->nr].defval = 0; /* default to include */
-	d->array_frame[d->nr].child_prov_omit = 0;
+	/*
+	 * Check and update is_skipping_tree before oidset_contains so
+	 * that is_skipping_tree gets unset even when the object is
+	 * marked as seen.  As of this writing, no filter uses
+	 * LOFR_MARK_SEEN on trees that also uses LOFR_SKIP_TREE, so the
+	 * ordering is only theoretically important. Be cautious if you
+	 * change the order of the below checks and more filters have
+	 * been added!
+	 */
+	if (sub->is_skipping_tree) {
+		if (filter_situation == LOFS_END_TREE &&
+		    oideq(&obj->oid, &sub->skip_tree))
+			sub->is_skipping_tree = 0;
+		else
+			return LOFR_ZERO;
+	}
+	if (oidset_contains(&sub->seen, &obj->oid))
+		return LOFR_ZERO;
+
+	result = list_objects_filter__filter_object(
+		r, filter_situation, obj, pathname, filename, sub->filter);
+
+	if (result & LOFR_MARK_SEEN)
+		oidset_insert(&sub->seen, &obj->oid);
+
+	if (result & LOFR_SKIP_TREE) {
+		sub->is_skipping_tree = 1;
+		sub->skip_tree = obj->oid;
+	}
 
-	*filter_fn = filter_sparse;
-	*filter_free_fn = filter_sparse_free;
-	return d;
+	return result;
 }
 
-typedef void *(*filter_init_fn)(
-	struct oidset *omitted,
+static enum list_objects_filter_result filter_combine(
+	struct repository *r,
+	enum list_objects_filter_situation filter_situation,
+	struct object *obj,
+	const char *pathname,
+	const char *filename,
+	struct oidset *omits,
+	void *filter_data)
+{
+	struct combine_filter_data *d = filter_data;
+	enum list_objects_filter_result combined_result =
+		LOFR_DO_SHOW | LOFR_MARK_SEEN | LOFR_SKIP_TREE;
+	size_t sub;
+
+	for (sub = 0; sub < d->nr; sub++) {
+		enum list_objects_filter_result sub_result = process_subfilter(
+			r, filter_situation, obj, pathname, filename,
+			&d->sub[sub]);
+		if (!(sub_result & LOFR_DO_SHOW))
+			combined_result &= ~LOFR_DO_SHOW;
+		if (!(sub_result & LOFR_MARK_SEEN))
+			combined_result &= ~LOFR_MARK_SEEN;
+		if (!d->sub[sub].is_skipping_tree)
+			combined_result &= ~LOFR_SKIP_TREE;
+	}
+
+	return combined_result;
+}
+
+static void filter_combine__free(void *filter_data)
+{
+	struct combine_filter_data *d = filter_data;
+	size_t sub;
+	for (sub = 0; sub < d->nr; sub++) {
+		list_objects_filter__free(d->sub[sub].filter);
+		oidset_clear(&d->sub[sub].seen);
+		if (d->sub[sub].omits.set.size)
+			BUG("expected oidset to be cleared already");
+	}
+	free(d->sub);
+}
+
+static void add_all(struct oidset *dest, struct oidset *src) {
+	struct oidset_iter iter;
+	struct object_id *src_oid;
+
+	oidset_iter_init(src, &iter);
+	while ((src_oid = oidset_iter_next(&iter)) != NULL)
+		oidset_insert(dest, src_oid);
+}
+
+static void filter_combine__finalize_omits(
+	struct oidset *omits,
+	void *filter_data)
+{
+	struct combine_filter_data *d = filter_data;
+	size_t sub;
+
+	for (sub = 0; sub < d->nr; sub++) {
+		add_all(omits, &d->sub[sub].omits);
+		oidset_clear(&d->sub[sub].omits);
+	}
+}
+
+static void filter_combine__init(
 	struct list_objects_filter_options *filter_options,
-	filter_object_fn *filter_fn,
-	filter_free_fn *filter_free_fn);
+	struct filter* filter)
+{
+	struct combine_filter_data *d = xcalloc(1, sizeof(*d));
+	size_t sub;
+
+	d->nr = filter_options->sub_nr;
+	d->sub = xcalloc(d->nr, sizeof(*d->sub));
+	for (sub = 0; sub < d->nr; sub++)
+		d->sub[sub].filter = list_objects_filter__init(
+			filter->omits ? &d->sub[sub].omits : NULL,
+			&filter_options->sub[sub]);
+
+	filter->filter_data = d;
+	filter->filter_object_fn = filter_combine;
+	filter->free_fn = filter_combine__free;
+	filter->finalize_omits_fn = filter_combine__finalize_omits;
+}
+
+typedef void (*filter_init_fn)(
+	struct list_objects_filter_options *filter_options,
+	struct filter *filter);
 
 /*
  * Must match "enum list_objects_filter_choice".
@@ -373,29 +649,63 @@ static filter_init_fn s_filters[] = {
 	NULL,
 	filter_blobs_none__init,
 	filter_blobs_limit__init,
+	filter_trees_depth__init,
 	filter_sparse_oid__init,
-	filter_sparse_path__init,
+	filter_combine__init,
 };
 
-void *list_objects_filter__init(
+struct filter *list_objects_filter__init(
 	struct oidset *omitted,
-	struct list_objects_filter_options *filter_options,
-	filter_object_fn *filter_fn,
-	filter_free_fn *filter_free_fn)
+	struct list_objects_filter_options *filter_options)
 {
+	struct filter *filter;
 	filter_init_fn init_fn;
 
 	assert((sizeof(s_filters) / sizeof(s_filters[0])) == LOFC__COUNT);
 
 	if (filter_options->choice >= LOFC__COUNT)
-		die("invalid list-objects filter choice: %d",
+		BUG("invalid list-objects filter choice: %d",
 		    filter_options->choice);
 
 	init_fn = s_filters[filter_options->choice];
-	if (init_fn)
-		return init_fn(omitted, filter_options,
-			       filter_fn, filter_free_fn);
-	*filter_fn = NULL;
-	*filter_free_fn = NULL;
-	return NULL;
+	if (!init_fn)
+		return NULL;
+
+	filter = xcalloc(1, sizeof(*filter));
+	filter->omits = omitted;
+	init_fn(filter_options, filter);
+	return filter;
+}
+
+enum list_objects_filter_result list_objects_filter__filter_object(
+	struct repository *r,
+	enum list_objects_filter_situation filter_situation,
+	struct object *obj,
+	const char *pathname,
+	const char *filename,
+	struct filter *filter)
+{
+	if (filter && (obj->flags & NOT_USER_GIVEN))
+		return filter->filter_object_fn(r, filter_situation, obj,
+						pathname, filename,
+						filter->omits,
+						filter->filter_data);
+	/*
+	 * No filter is active or user gave object explicitly. In this case,
+	 * always show the object (except when LOFS_END_TREE, since this tree
+	 * had already been shown when LOFS_BEGIN_TREE).
+	 */
+	if (filter_situation == LOFS_END_TREE)
+		return 0;
+	return LOFR_MARK_SEEN | LOFR_DO_SHOW;
+}
+
+void list_objects_filter__free(struct filter *filter)
+{
+	if (!filter)
+		return;
+	if (filter->finalize_omits_fn && filter->omits)
+		filter->finalize_omits_fn(filter->omits, filter->filter_data);
+	filter->free_fn(filter->filter_data);
+	free(filter);
 }
diff -pruN 1.2.1+git2.18.0-1/git/list-objects-filter.h 1.2.3+git2.25.1-1/git/list-objects-filter.h
--- 1.2.1+git2.18.0-1/git/list-objects-filter.h	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/list-objects-filter.h	2020-02-17 04:47:35.000000000 +0000
@@ -1,6 +1,11 @@
 #ifndef LIST_OBJECTS_FILTER_H
 #define LIST_OBJECTS_FILTER_H
 
+struct list_objects_filter_options;
+struct object;
+struct oidset;
+struct repository;
+
 /*
  * During list-object traversal we allow certain objects to be
  * filtered (omitted) from the result.  The active filter uses
@@ -20,6 +25,11 @@
  *              In general, objects should only be shown once, but
  *              this result DOES NOT imply that we mark it SEEN.
  *
+ * _SKIP_TREE : Used in LOFS_BEGIN_TREE situation - indicates that
+ *              the tree's children should not be iterated over. This
+ *              is used as an optimization when all children will
+ *              definitely be ignored.
+ *
  * Most of the time, you want the combination (_MARK_SEEN | _DO_SHOW)
  * but they can be used independently, such as when sparse-checkout
  * pattern matching is being applied.
@@ -41,6 +51,7 @@ enum list_objects_filter_result {
 	LOFR_ZERO      = 0,
 	LOFR_MARK_SEEN = 1<<0,
 	LOFR_DO_SHOW   = 1<<1,
+	LOFR_SKIP_TREE = 1<<2,
 };
 
 enum list_objects_filter_situation {
@@ -49,29 +60,36 @@ enum list_objects_filter_situation {
 	LOFS_BLOB
 };
 
-typedef enum list_objects_filter_result (*filter_object_fn)(
+struct filter;
+
+/*
+ * Constructor for the set of defined list-objects filters.
+ * The `omitted` set is optional. It is populated with objects that the
+ * filter excludes. This set should not be considered finalized until
+ * after list_objects_filter__free is called on the returned `struct
+ * filter *`.
+ */
+struct filter *list_objects_filter__init(
+	struct oidset *omitted,
+	struct list_objects_filter_options *filter_options);
+
+/*
+ * Lets `filter` decide how to handle the `obj`. If `filter` is NULL, this
+ * function behaves as expected if no filter is configured: all objects are
+ * included.
+ */
+enum list_objects_filter_result list_objects_filter__filter_object(
+	struct repository *r,
 	enum list_objects_filter_situation filter_situation,
 	struct object *obj,
 	const char *pathname,
 	const char *filename,
-	void *filter_data);
-
-typedef void (*filter_free_fn)(void *filter_data);
+	struct filter *filter);
 
 /*
- * Constructor for the set of defined list-objects filters.
- * Returns a generic "void *filter_data".
- *
- * The returned "filter_fn" will be used by traverse_commit_list()
- * to filter the results.
- *
- * The returned "filter_free_fn" is a destructor for the
- * filter_data.
+ * Destroys `filter` and finalizes the `omitted` set, if present. Does
+ * nothing if `filter` is null.
  */
-void *list_objects_filter__init(
-	struct oidset *omitted,
-	struct list_objects_filter_options *filter_options,
-	filter_object_fn *filter_fn,
-	filter_free_fn *filter_free_fn);
+void list_objects_filter__free(struct filter *filter);
 
 #endif /* LIST_OBJECTS_FILTER_H */
diff -pruN 1.2.1+git2.18.0-1/git/list-objects-filter-options.c 1.2.3+git2.25.1-1/git/list-objects-filter-options.c
--- 1.2.1+git2.18.0-1/git/list-objects-filter-options.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/list-objects-filter-options.c	2020-02-17 04:47:35.000000000 +0000
@@ -6,6 +6,14 @@
 #include "list-objects.h"
 #include "list-objects-filter.h"
 #include "list-objects-filter-options.h"
+#include "promisor-remote.h"
+#include "trace.h"
+#include "url.h"
+
+static int parse_combine_filter(
+	struct list_objects_filter_options *filter_options,
+	const char *arg,
+	struct strbuf *errbuf);
 
 /*
  * Parse value of the argument to the "filter" keyword.
@@ -18,8 +26,9 @@
  * See Documentation/rev-list-options.txt for allowed values for <arg>.
  *
  * Capture the given arg as the "filter_spec".  This can be forwarded to
- * subordinate commands when necessary.  We also "intern" the arg for
- * the convenience of the current command.
+ * subordinate commands when necessary (although it's better to pass it through
+ * expand_list_objects_filter_spec() first).  We also "intern" the arg for the
+ * convenience of the current command.
  */
 static int gently_parse_list_objects_filter(
 	struct list_objects_filter_options *filter_options,
@@ -28,17 +37,11 @@ static int gently_parse_list_objects_fil
 {
 	const char *v0;
 
-	if (filter_options->choice) {
-		if (errbuf) {
-			strbuf_init(errbuf, 0);
-			strbuf_addstr(
-				errbuf,
-				_("multiple filter-specs cannot be combined"));
-		}
-		return 1;
-	}
+	if (!arg)
+		return 0;
 
-	filter_options->filter_spec = strdup(arg);
+	if (filter_options->choice)
+		BUG("filter_options already populated");
 
 	if (!strcmp(arg, "blob:none")) {
 		filter_options->choice = LOFC_BLOB_NONE;
@@ -50,103 +53,318 @@ static int gently_parse_list_objects_fil
 			return 0;
 		}
 
-	} else if (skip_prefix(arg, "sparse:oid=", &v0)) {
-		struct object_context oc;
-		struct object_id sparse_oid;
+	} else if (skip_prefix(arg, "tree:", &v0)) {
+		if (!git_parse_ulong(v0, &filter_options->tree_exclude_depth)) {
+			strbuf_addstr(errbuf, _("expected 'tree:<depth>'"));
+			return 1;
+		}
+		filter_options->choice = LOFC_TREE_DEPTH;
+		return 0;
 
-		/*
-		 * Try to parse <oid-expression> into an OID for the current
-		 * command, but DO NOT complain if we don't have the blob or
-		 * ref locally.
-		 */
-		if (!get_oid_with_context(v0, GET_OID_BLOB,
-					  &sparse_oid, &oc))
-			filter_options->sparse_oid_value = oiddup(&sparse_oid);
+	} else if (skip_prefix(arg, "sparse:oid=", &v0)) {
+		filter_options->sparse_oid_name = xstrdup(v0);
 		filter_options->choice = LOFC_SPARSE_OID;
 		return 0;
 
 	} else if (skip_prefix(arg, "sparse:path=", &v0)) {
-		filter_options->choice = LOFC_SPARSE_PATH;
-		filter_options->sparse_path_value = strdup(v0);
-		return 0;
-	}
+		if (errbuf) {
+			strbuf_addstr(
+				errbuf,
+				_("sparse:path filters support has been dropped"));
+		}
+		return 1;
+
+	} else if (skip_prefix(arg, "combine:", &v0)) {
+		return parse_combine_filter(filter_options, v0, errbuf);
 
-	if (errbuf) {
-		strbuf_init(errbuf, 0);
-		strbuf_addf(errbuf, "invalid filter-spec '%s'", arg);
 	}
+	/*
+	 * Please update _git_fetch() in git-completion.bash when you
+	 * add new filters
+	 */
+
+	strbuf_addf(errbuf, _("invalid filter-spec '%s'"), arg);
+
 	memset(filter_options, 0, sizeof(*filter_options));
 	return 1;
 }
 
-int parse_list_objects_filter(struct list_objects_filter_options *filter_options,
-			      const char *arg)
+static const char *RESERVED_NON_WS = "~`!@#$^&*()[]{}\\;'\",<>?";
+
+static int has_reserved_character(
+	struct strbuf *sub_spec, struct strbuf *errbuf)
 {
-	struct strbuf buf = STRBUF_INIT;
-	if (gently_parse_list_objects_filter(filter_options, arg, &buf))
-		die("%s", buf.buf);
+	const char *c = sub_spec->buf;
+	while (*c) {
+		if (*c <= ' ' || strchr(RESERVED_NON_WS, *c)) {
+			strbuf_addf(
+				errbuf,
+				_("must escape char in sub-filter-spec: '%c'"),
+				*c);
+			return 1;
+		}
+		c++;
+	}
+
 	return 0;
 }
 
+static int parse_combine_subfilter(
+	struct list_objects_filter_options *filter_options,
+	struct strbuf *subspec,
+	struct strbuf *errbuf)
+{
+	size_t new_index = filter_options->sub_nr;
+	char *decoded;
+	int result;
+
+	ALLOC_GROW_BY(filter_options->sub, filter_options->sub_nr, 1,
+		      filter_options->sub_alloc);
+
+	decoded = url_percent_decode(subspec->buf);
+
+	result = has_reserved_character(subspec, errbuf) ||
+		gently_parse_list_objects_filter(
+			&filter_options->sub[new_index], decoded, errbuf);
+
+	free(decoded);
+	return result;
+}
+
+static int parse_combine_filter(
+	struct list_objects_filter_options *filter_options,
+	const char *arg,
+	struct strbuf *errbuf)
+{
+	struct strbuf **subspecs = strbuf_split_str(arg, '+', 0);
+	size_t sub;
+	int result = 0;
+
+	if (!subspecs[0]) {
+		strbuf_addstr(errbuf, _("expected something after combine:"));
+		result = 1;
+		goto cleanup;
+	}
+
+	for (sub = 0; subspecs[sub] && !result; sub++) {
+		if (subspecs[sub + 1]) {
+			/*
+			 * This is not the last subspec. Remove trailing "+" so
+			 * we can parse it.
+			 */
+			size_t last = subspecs[sub]->len - 1;
+			assert(subspecs[sub]->buf[last] == '+');
+			strbuf_remove(subspecs[sub], last, 1);
+		}
+		result = parse_combine_subfilter(
+			filter_options, subspecs[sub], errbuf);
+	}
+
+	filter_options->choice = LOFC_COMBINE;
+
+cleanup:
+	strbuf_list_free(subspecs);
+	if (result) {
+		list_objects_filter_release(filter_options);
+		memset(filter_options, 0, sizeof(*filter_options));
+	}
+	return result;
+}
+
+static int allow_unencoded(char ch)
+{
+	if (ch <= ' ' || ch == '%' || ch == '+')
+		return 0;
+	return !strchr(RESERVED_NON_WS, ch);
+}
+
+static void filter_spec_append_urlencode(
+	struct list_objects_filter_options *filter, const char *raw)
+{
+	struct strbuf buf = STRBUF_INIT;
+	strbuf_addstr_urlencode(&buf, raw, allow_unencoded);
+	trace_printf("Add to combine filter-spec: %s\n", buf.buf);
+	string_list_append(&filter->filter_spec, strbuf_detach(&buf, NULL));
+}
+
+/*
+ * Changes filter_options into an equivalent LOFC_COMBINE filter options
+ * instance. Does not do anything if filter_options is already LOFC_COMBINE.
+ */
+static void transform_to_combine_type(
+	struct list_objects_filter_options *filter_options)
+{
+	assert(filter_options->choice);
+	if (filter_options->choice == LOFC_COMBINE)
+		return;
+	{
+		const int initial_sub_alloc = 2;
+		struct list_objects_filter_options *sub_array =
+			xcalloc(initial_sub_alloc, sizeof(*sub_array));
+		sub_array[0] = *filter_options;
+		memset(filter_options, 0, sizeof(*filter_options));
+		filter_options->sub = sub_array;
+		filter_options->sub_alloc = initial_sub_alloc;
+	}
+	filter_options->sub_nr = 1;
+	filter_options->choice = LOFC_COMBINE;
+	string_list_append(&filter_options->filter_spec, xstrdup("combine:"));
+	filter_spec_append_urlencode(
+		filter_options,
+		list_objects_filter_spec(&filter_options->sub[0]));
+	/*
+	 * We don't need the filter_spec strings for subfilter specs, only the
+	 * top level.
+	 */
+	string_list_clear(&filter_options->sub[0].filter_spec, /*free_util=*/0);
+}
+
+void list_objects_filter_die_if_populated(
+	struct list_objects_filter_options *filter_options)
+{
+	if (filter_options->choice)
+		die(_("multiple filter-specs cannot be combined"));
+}
+
+void parse_list_objects_filter(
+	struct list_objects_filter_options *filter_options,
+	const char *arg)
+{
+	struct strbuf errbuf = STRBUF_INIT;
+	int parse_error;
+
+	if (!filter_options->choice) {
+		string_list_append(&filter_options->filter_spec, xstrdup(arg));
+
+		parse_error = gently_parse_list_objects_filter(
+			filter_options, arg, &errbuf);
+	} else {
+		/*
+		 * Make filter_options an LOFC_COMBINE spec so we can trivially
+		 * add subspecs to it.
+		 */
+		transform_to_combine_type(filter_options);
+
+		string_list_append(&filter_options->filter_spec, xstrdup("+"));
+		filter_spec_append_urlencode(filter_options, arg);
+		ALLOC_GROW_BY(filter_options->sub, filter_options->sub_nr, 1,
+			      filter_options->sub_alloc);
+
+		parse_error = gently_parse_list_objects_filter(
+			&filter_options->sub[filter_options->sub_nr - 1], arg,
+			&errbuf);
+	}
+	if (parse_error)
+		die("%s", errbuf.buf);
+}
+
 int opt_parse_list_objects_filter(const struct option *opt,
 				  const char *arg, int unset)
 {
 	struct list_objects_filter_options *filter_options = opt->value;
 
-	if (unset || !arg) {
+	if (unset || !arg)
 		list_objects_filter_set_no_filter(filter_options);
-		return 0;
+	else
+		parse_list_objects_filter(filter_options, arg);
+	return 0;
+}
+
+const char *list_objects_filter_spec(struct list_objects_filter_options *filter)
+{
+	if (!filter->filter_spec.nr)
+		BUG("no filter_spec available for this filter");
+	if (filter->filter_spec.nr != 1) {
+		struct strbuf concatted = STRBUF_INIT;
+		strbuf_add_separated_string_list(
+			&concatted, "", &filter->filter_spec);
+		string_list_clear(&filter->filter_spec, /*free_util=*/0);
+		string_list_append(
+			&filter->filter_spec, strbuf_detach(&concatted, NULL));
 	}
 
-	return parse_list_objects_filter(filter_options, arg);
+	return filter->filter_spec.items[0].string;
+}
+
+const char *expand_list_objects_filter_spec(
+	struct list_objects_filter_options *filter)
+{
+	if (filter->choice == LOFC_BLOB_LIMIT) {
+		struct strbuf expanded_spec = STRBUF_INIT;
+		strbuf_addf(&expanded_spec, "blob:limit=%lu",
+			    filter->blob_limit_value);
+		string_list_clear(&filter->filter_spec, /*free_util=*/0);
+		string_list_append(
+			&filter->filter_spec,
+			strbuf_detach(&expanded_spec, NULL));
+	}
+
+	return list_objects_filter_spec(filter);
 }
 
 void list_objects_filter_release(
 	struct list_objects_filter_options *filter_options)
 {
-	free(filter_options->filter_spec);
-	free(filter_options->sparse_oid_value);
-	free(filter_options->sparse_path_value);
+	size_t sub;
+
+	if (!filter_options)
+		return;
+	string_list_clear(&filter_options->filter_spec, /*free_util=*/0);
+	free(filter_options->sparse_oid_name);
+	for (sub = 0; sub < filter_options->sub_nr; sub++)
+		list_objects_filter_release(&filter_options->sub[sub]);
+	free(filter_options->sub);
 	memset(filter_options, 0, sizeof(*filter_options));
 }
 
 void partial_clone_register(
 	const char *remote,
-	const struct list_objects_filter_options *filter_options)
+	struct list_objects_filter_options *filter_options)
 {
-	/*
-	 * Record the name of the partial clone remote in the
-	 * config and in the global variable -- the latter is
-	 * used throughout to indicate that partial clone is
-	 * enabled and to expect missing objects.
-	 */
-	if (repository_format_partial_clone &&
-	    *repository_format_partial_clone &&
-	    strcmp(remote, repository_format_partial_clone))
-		die(_("cannot change partial clone promisor remote"));
-
-	git_config_set("core.repositoryformatversion", "1");
-	git_config_set("extensions.partialclone", remote);
+	char *cfg_name;
+	char *filter_name;
 
-	repository_format_partial_clone = xstrdup(remote);
+	/* Check if it is already registered */
+	if (!promisor_remote_find(remote)) {
+		git_config_set("core.repositoryformatversion", "1");
+
+		/* Add promisor config for the remote */
+		cfg_name = xstrfmt("remote.%s.promisor", remote);
+		git_config_set(cfg_name, "true");
+		free(cfg_name);
+	}
 
 	/*
 	 * Record the initial filter-spec in the config as
 	 * the default for subsequent fetches from this remote.
 	 */
-	core_partial_clone_filter_default =
-		xstrdup(filter_options->filter_spec);
-	git_config_set("core.partialclonefilter",
-		       core_partial_clone_filter_default);
+	filter_name = xstrfmt("remote.%s.partialclonefilter", remote);
+	/* NEEDSWORK: 'expand' result leaking??? */
+	git_config_set(filter_name,
+		       expand_list_objects_filter_spec(filter_options));
+	free(filter_name);
+
+	/* Make sure the config info are reset */
+	promisor_remote_reinit();
 }
 
 void partial_clone_get_default_filter_spec(
-	struct list_objects_filter_options *filter_options)
+	struct list_objects_filter_options *filter_options,
+	const char *remote)
 {
+	struct promisor_remote *promisor = promisor_remote_find(remote);
+	struct strbuf errbuf = STRBUF_INIT;
+
 	/*
 	 * Parse default value, but silently ignore it if it is invalid.
 	 */
+	if (!promisor)
+		return;
+
+	string_list_append(&filter_options->filter_spec,
+			   promisor->partial_clone_filter);
 	gently_parse_list_objects_filter(filter_options,
-					 core_partial_clone_filter_default,
-					 NULL);
+					 promisor->partial_clone_filter,
+					 &errbuf);
+	strbuf_release(&errbuf);
 }
diff -pruN 1.2.1+git2.18.0-1/git/list-objects-filter-options.h 1.2.3+git2.25.1-1/git/list-objects-filter-options.h
--- 1.2.1+git2.18.0-1/git/list-objects-filter-options.h	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/list-objects-filter-options.h	2020-02-17 04:47:35.000000000 +0000
@@ -2,6 +2,7 @@
 #define LIST_OBJECTS_FILTER_OPTIONS_H
 
 #include "parse-options.h"
+#include "string-list.h"
 
 /*
  * The list of defined filters for list-objects.
@@ -10,8 +11,9 @@ enum list_objects_filter_choice {
 	LOFC_DISABLED = 0,
 	LOFC_BLOB_NONE,
 	LOFC_BLOB_LIMIT,
+	LOFC_TREE_DEPTH,
 	LOFC_SPARSE_OID,
-	LOFC_SPARSE_PATH,
+	LOFC_COMBINE,
 	LOFC__COUNT /* must be last */
 };
 
@@ -19,10 +21,13 @@ struct list_objects_filter_options {
 	/*
 	 * 'filter_spec' is the raw argument value given on the command line
 	 * or protocol request.  (The part after the "--keyword=".)  For
-	 * commands that launch filtering sub-processes, this value should be
-	 * passed to them as received by the current process.
+	 * commands that launch filtering sub-processes, or for communication
+	 * over the network, don't use this value; use the result of
+	 * expand_list_objects_filter_spec() instead.
+	 * To get the raw filter spec given by the user, use the result of
+	 * list_objects_filter_spec().
 	 */
-	char *filter_spec;
+	struct string_list filter_spec;
 
 	/*
 	 * 'choice' is determined by parsing the filter-spec.  This indicates
@@ -36,19 +41,40 @@ struct list_objects_filter_options {
 	unsigned int no_filter : 1;
 
 	/*
-	 * Parsed values (fields) from within the filter-spec.  These are
-	 * choice-specific; not all values will be defined for any given
-	 * choice.
+	 * BEGIN choice-specific parsed values from within the filter-spec. Only
+	 * some values will be defined for any given choice.
 	 */
-	struct object_id *sparse_oid_value;
-	char *sparse_path_value;
+
+	char *sparse_oid_name;
 	unsigned long blob_limit_value;
+	unsigned long tree_exclude_depth;
+
+	/* LOFC_COMBINE values */
+
+	/* This array contains all the subfilters which this filter combines. */
+	size_t sub_nr, sub_alloc;
+	struct list_objects_filter_options *sub;
+
+	/*
+	 * END choice-specific parsed values.
+	 */
 };
 
 /* Normalized command line arguments */
 #define CL_ARG__FILTER "filter"
 
-int parse_list_objects_filter(
+void list_objects_filter_die_if_populated(
+	struct list_objects_filter_options *filter_options);
+
+/*
+ * Parses the filter spec string given by arg and either (1) simply places the
+ * result in filter_options if it is not yet populated or (2) combines it with
+ * the filter already in filter_options if it is already populated. In the case
+ * of (2), the filter specs are combined as if specified with 'combine:'.
+ *
+ * Dies and prints a user-facing message if an error occurs.
+ */
+void parse_list_objects_filter(
 	struct list_objects_filter_options *filter_options,
 	const char *arg);
 
@@ -60,6 +86,26 @@ int opt_parse_list_objects_filter(const
 	  N_("object filtering"), 0, \
 	  opt_parse_list_objects_filter }
 
+/*
+ * Translates abbreviated numbers in the filter's filter_spec into their
+ * fully-expanded forms (e.g., "limit:blob=1k" becomes "limit:blob=1024").
+ * Returns a string owned by the list_objects_filter_options object.
+ *
+ * This form should be used instead of the raw list_objects_filter_spec()
+ * value when communicating with a remote process or subprocess.
+ */
+const char *expand_list_objects_filter_spec(
+	struct list_objects_filter_options *filter);
+
+/*
+ * Returns the filter spec string more or less in the form as the user
+ * entered it. This form of the filter_spec can be used in user-facing
+ * messages.  Returns a string owned by the list_objects_filter_options
+ * object.
+ */
+const char *list_objects_filter_spec(
+	struct list_objects_filter_options *filter);
+
 void list_objects_filter_release(
 	struct list_objects_filter_options *filter_options);
 
@@ -72,8 +118,9 @@ static inline void list_objects_filter_s
 
 void partial_clone_register(
 	const char *remote,
-	const struct list_objects_filter_options *filter_options);
-void partial_clone_get_default_filter_spec(
 	struct list_objects_filter_options *filter_options);
+void partial_clone_get_default_filter_spec(
+	struct list_objects_filter_options *filter_options,
+	const char *remote);
 
 #endif /* LIST_OBJECTS_FILTER_OPTIONS_H */
diff -pruN 1.2.1+git2.18.0-1/git/list-objects.h 1.2.3+git2.25.1-1/git/list-objects.h
--- 1.2.1+git2.18.0-1/git/list-objects.h	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/list-objects.h	2020-02-17 04:47:35.000000000 +0000
@@ -1,12 +1,18 @@
 #ifndef LIST_OBJECTS_H
 #define LIST_OBJECTS_H
 
+struct commit;
+struct object;
+struct rev_info;
+
 typedef void (*show_commit_fn)(struct commit *, void *);
 typedef void (*show_object_fn)(struct object *, const char *, void *);
 void traverse_commit_list(struct rev_info *, show_commit_fn, show_object_fn, void *);
 
 typedef void (*show_edge_fn)(struct commit *);
-void mark_edges_uninteresting(struct rev_info *, show_edge_fn);
+void mark_edges_uninteresting(struct rev_info *revs,
+			      show_edge_fn show_edge,
+			      int sparse);
 
 struct oidset;
 struct list_objects_filter_options;
diff -pruN 1.2.1+git2.18.0-1/git/ll-merge.c 1.2.3+git2.25.1-1/git/ll-merge.c
--- 1.2.1+git2.18.0-1/git/ll-merge.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/ll-merge.c	2020-02-17 04:47:35.000000000 +0000
@@ -32,6 +32,20 @@ struct ll_merge_driver {
 	char *cmdline;
 };
 
+static struct attr_check *merge_attributes;
+static struct attr_check *load_merge_attributes(void)
+{
+	if (!merge_attributes)
+		merge_attributes = attr_check_initl("merge", "conflict-marker-size", NULL);
+	return merge_attributes;
+}
+
+void reset_merge_attributes(void)
+{
+	attr_check_free(merge_attributes);
+	merge_attributes = NULL;
+}
+
 /*
  * Built-in low-levels
  */
@@ -336,10 +350,10 @@ static const struct ll_merge_driver *fin
 	return &ll_merge_drv[LL_TEXT_MERGE];
 }
 
-static void normalize_file(mmfile_t *mm, const char *path)
+static void normalize_file(mmfile_t *mm, const char *path, struct index_state *istate)
 {
 	struct strbuf strbuf = STRBUF_INIT;
-	if (renormalize_buffer(&the_index, path, mm->ptr, mm->size, &strbuf)) {
+	if (renormalize_buffer(istate, path, mm->ptr, mm->size, &strbuf)) {
 		free(mm->ptr);
 		mm->size = strbuf.len;
 		mm->ptr = strbuf_detach(&strbuf, NULL);
@@ -351,9 +365,10 @@ int ll_merge(mmbuffer_t *result_buf,
 	     mmfile_t *ancestor, const char *ancestor_label,
 	     mmfile_t *ours, const char *our_label,
 	     mmfile_t *theirs, const char *their_label,
+	     struct index_state *istate,
 	     const struct ll_merge_options *opts)
 {
-	static struct attr_check *check;
+	struct attr_check *check = load_merge_attributes();
 	static const struct ll_merge_options default_opts;
 	const char *ll_driver_name = NULL;
 	int marker_size = DEFAULT_CONFLICT_MARKER_SIZE;
@@ -363,42 +378,41 @@ int ll_merge(mmbuffer_t *result_buf,
 		opts = &default_opts;
 
 	if (opts->renormalize) {
-		normalize_file(ancestor, path);
-		normalize_file(ours, path);
-		normalize_file(theirs, path);
+		normalize_file(ancestor, path, istate);
+		normalize_file(ours, path, istate);
+		normalize_file(theirs, path, istate);
 	}
 
-	if (!check)
-		check = attr_check_initl("merge", "conflict-marker-size", NULL);
-
-	if (!git_check_attr(path, check)) {
-		ll_driver_name = check->items[0].value;
-		if (check->items[1].value) {
-			marker_size = atoi(check->items[1].value);
-			if (marker_size <= 0)
-				marker_size = DEFAULT_CONFLICT_MARKER_SIZE;
-		}
+	git_check_attr(istate, path, check);
+	ll_driver_name = check->items[0].value;
+	if (check->items[1].value) {
+		marker_size = atoi(check->items[1].value);
+		if (marker_size <= 0)
+			marker_size = DEFAULT_CONFLICT_MARKER_SIZE;
 	}
 	driver = find_ll_merge_driver(ll_driver_name);
 
 	if (opts->virtual_ancestor) {
 		if (driver->recursive)
 			driver = find_ll_merge_driver(driver->recursive);
-		marker_size += 2;
+	}
+	if (opts->extra_marker_size) {
+		marker_size += opts->extra_marker_size;
 	}
 	return driver->fn(driver, result_buf, path, ancestor, ancestor_label,
 			  ours, our_label, theirs, their_label,
 			  opts, marker_size);
 }
 
-int ll_merge_marker_size(const char *path)
+int ll_merge_marker_size(struct index_state *istate, const char *path)
 {
 	static struct attr_check *check;
 	int marker_size = DEFAULT_CONFLICT_MARKER_SIZE;
 
 	if (!check)
 		check = attr_check_initl("conflict-marker-size", NULL);
-	if (!git_check_attr(path, check) && check->items[0].value) {
+	git_check_attr(istate, path, check);
+	if (check->items[0].value) {
 		marker_size = atoi(check->items[0].value);
 		if (marker_size <= 0)
 			marker_size = DEFAULT_CONFLICT_MARKER_SIZE;
diff -pruN 1.2.1+git2.18.0-1/git/ll-merge.h 1.2.3+git2.25.1-1/git/ll-merge.h
--- 1.2.1+git2.18.0-1/git/ll-merge.h	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/ll-merge.h	2020-02-17 04:47:35.000000000 +0000
@@ -5,20 +5,98 @@
 #ifndef LL_MERGE_H
 #define LL_MERGE_H
 
+#include "xdiff/xdiff.h"
+
+/**
+ *
+ * Calling sequence:
+ * ----------------
+ *
+ * - Prepare a `struct ll_merge_options` to record options.
+ *   If you have no special requests, skip this and pass `NULL`
+ *   as the `opts` parameter to use the default options.
+ *
+ * - Allocate an mmbuffer_t variable for the result.
+ *
+ * - Allocate and fill variables with the file's original content
+ *   and two modified versions (using `read_mmfile`, for example).
+ *
+ * - Call `ll_merge()`.
+ *
+ * - Read the merged content from `result_buf.ptr` and `result_buf.size`.
+ *
+ * - Release buffers when finished.  A simple
+ *   `free(ancestor.ptr); free(ours.ptr); free(theirs.ptr);
+ *   free(result_buf.ptr);` will do.
+ *
+ * If the modifications do not merge cleanly, `ll_merge` will return a
+ * nonzero value and `result_buf` will generally include a description of
+ * the conflict bracketed by markers such as the traditional `<<<<<<<`
+ * and `>>>>>>>`.
+ *
+ * The `ancestor_label`, `our_label`, and `their_label` parameters are
+ * used to label the different sides of a conflict if the merge driver
+ * supports this.
+ */
+
+
+struct index_state;
+
+/**
+ * This describes the set of options the calling program wants to affect
+ * the operation of a low-level (single file) merge.
+ */
 struct ll_merge_options {
+
+	/**
+	 * Behave as though this were part of a merge between common ancestors in
+	 * a recursive merge (merges of binary files may need to be handled
+	 * differently in such cases, for example). If a helper program is
+	 * specified by the `[merge "<driver>"] recursive` configuration, it will
+	 * be used.
+	 */
 	unsigned virtual_ancestor : 1;
-	unsigned variant : 2;	/* favor ours, favor theirs, or union merge */
+
+	/**
+	 * Resolve local conflicts automatically in favor of one side or the other
+	 * (as in 'git merge-file' `--ours`/`--theirs`/`--union`).  Can be `0`,
+	 * `XDL_MERGE_FAVOR_OURS`, `XDL_MERGE_FAVOR_THEIRS`,
+	 * or `XDL_MERGE_FAVOR_UNION`.
+	 */
+	unsigned variant : 2;
+
+	/**
+	 * Resmudge and clean the "base", "theirs" and "ours" files before merging.
+	 * Use this when the merge is likely to have overlapped with a change in
+	 * smudge/clean or end-of-line normalization rules.
+	 */
 	unsigned renormalize : 1;
+
+	/**
+	 * Increase the length of conflict markers so that nested conflicts
+	 * can be differentiated.
+	 */
+	unsigned extra_marker_size;
+
+	/* Extra xpparam_t flags as defined in xdiff/xdiff.h. */
 	long xdl_opts;
 };
 
+/**
+ * Perform a three-way single-file merge in core.  This is a thin wrapper
+ * around `xdl_merge` that takes the path and any merge backend specified in
+ * `.gitattributes` or `.git/info/attributes` into account.
+ * Returns 0 for a clean merge.
+ */
 int ll_merge(mmbuffer_t *result_buf,
 	     const char *path,
 	     mmfile_t *ancestor, const char *ancestor_label,
 	     mmfile_t *ours, const char *our_label,
 	     mmfile_t *theirs, const char *their_label,
+	     struct index_state *istate,
 	     const struct ll_merge_options *opts);
 
-int ll_merge_marker_size(const char *path);
+int ll_merge_marker_size(struct index_state *istate, const char *path);
+void reset_merge_attributes(void);
 
 #endif
diff -pruN 1.2.1+git2.18.0-1/git/lockfile.h 1.2.3+git2.25.1-1/git/lockfile.h
--- 1.2.1+git2.18.0-1/git/lockfile.h	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/lockfile.h	2020-02-17 04:47:35.000000000 +0000
@@ -159,7 +159,7 @@ struct lock_file {
  * timeout_ms is -1, retry indefinitely. The flags argument and error
  * handling are described above.
  */
-extern int hold_lock_file_for_update_timeout(
+int hold_lock_file_for_update_timeout(
 		struct lock_file *lk, const char *path,
 		int flags, long timeout_ms);
 
@@ -188,8 +188,8 @@ static inline int is_lock_file_locked(st
  * of `hold_lock_file_for_update()` to lock `path`. `err` should be the
  * `errno` set by the failing call.
  */
-extern void unable_to_lock_message(const char *path, int err,
-				   struct strbuf *buf);
+void unable_to_lock_message(const char *path, int err,
+			    struct strbuf *buf);
 
 /*
  * Emit an appropriate error message and `die()` following the failure
@@ -197,7 +197,7 @@ extern void unable_to_lock_message(const
  * `errno` set by the failing
  * call.
  */
-extern NORETURN void unable_to_lock_die(const char *path, int err);
+NORETURN void unable_to_lock_die(const char *path, int err);
 
 /*
  * Associate a stdio stream with the lockfile (which must still be
@@ -234,7 +234,7 @@ static inline FILE *get_lock_file_fp(str
  * Return the path of the file that is locked by the specified
  * lock_file object. The caller must free the memory.
  */
-extern char *get_locked_file_path(struct lock_file *lk);
+char *get_locked_file_path(struct lock_file *lk);
 
 /*
  * If the lockfile is still open, close it (and the file pointer if it
@@ -263,8 +263,8 @@ static inline int close_lock_file_gently
  *   nobody else) to inspect the contents you wrote, while still
  *   holding the lock yourself.
  *
- * * `reopen_lock_file()` to reopen the lockfile. Make further updates
- *   to the contents.
+ * * `reopen_lock_file()` to reopen the lockfile, truncating the existing
+ *   contents. Write out the new contents.
  *
  * * `commit_lock_file()` to make the final version permanent.
  */
@@ -282,7 +282,7 @@ static inline int reopen_lock_file(struc
  * call `commit_lock_file()` for a `lock_file` object that is not
  * currently locked.
  */
-extern int commit_lock_file(struct lock_file *lk);
+int commit_lock_file(struct lock_file *lk);
 
 /*
  * Like `commit_lock_file()`, but rename the lockfile to the provided
diff -pruN 1.2.1+git2.18.0-1/git/log-tree.c 1.2.3+git2.25.1-1/git/log-tree.c
--- 1.2.1+git2.18.0-1/git/log-tree.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/log-tree.c	2020-02-17 04:47:35.000000000 +0000
@@ -1,6 +1,8 @@
 #include "cache.h"
 #include "config.h"
 #include "diff.h"
+#include "object-store.h"
+#include "repository.h"
 #include "commit.h"
 #include "tag.h"
 #include "graph.h"
@@ -12,6 +14,9 @@
 #include "gpg-interface.h"
 #include "sequencer.h"
 #include "line-log.h"
+#include "help.h"
+#include "interdiff.h"
+#include "range-diff.h"
 
 static struct decoration name_decoration = { "object names" };
 static int decoration_loaded;
@@ -27,6 +32,15 @@ static char decoration_colors[][COLOR_MA
 	GIT_COLOR_BOLD_BLUE,	/* GRAFTED */
 };
 
+static const char *color_decorate_slots[] = {
+	[DECORATION_REF_LOCAL]	= "branch",
+	[DECORATION_REF_REMOTE] = "remoteBranch",
+	[DECORATION_REF_TAG]	= "tag",
+	[DECORATION_REF_STASH]	= "stash",
+	[DECORATION_REF_HEAD]	= "HEAD",
+	[DECORATION_GRAFTED]	= "grafted",
+};
+
 static const char *decorate_get_color(int decorate_use_color, enum decoration_type ix)
 {
 	if (want_color(decorate_use_color))
@@ -34,34 +48,11 @@ static const char *decorate_get_color(in
 	return "";
 }
 
-static int parse_decorate_color_slot(const char *slot)
-{
-	/*
-	 * We're comparing with 'ignore-case' on
-	 * (because config.c sets them all tolower),
-	 * but let's match the letters in the literal
-	 * string values here with how they are
-	 * documented in Documentation/config.txt, for
-	 * consistency.
-	 *
-	 * We love being consistent, don't we?
-	 */
-	if (!strcasecmp(slot, "branch"))
-		return DECORATION_REF_LOCAL;
-	if (!strcasecmp(slot, "remoteBranch"))
-		return DECORATION_REF_REMOTE;
-	if (!strcasecmp(slot, "tag"))
-		return DECORATION_REF_TAG;
-	if (!strcasecmp(slot, "stash"))
-		return DECORATION_REF_STASH;
-	if (!strcasecmp(slot, "HEAD"))
-		return DECORATION_REF_HEAD;
-	return -1;
-}
+define_list_config_array(color_decorate_slots);
 
 int parse_decorate_color_config(const char *var, const char *slot_name, const char *value)
 {
-	int slot = parse_decorate_color_slot(slot_name);
+	int slot = LOOKUP_CONFIG(color_decorate_slots, slot_name);
 	if (slot < 0)
 		return 0;
 	if (!value)
@@ -86,6 +77,7 @@ void add_name_decoration(enum decoration
 
 const struct name_decoration *get_name_decoration(const struct object *obj)
 {
+	load_ref_decorations(NULL, DECORATE_SHORT_REFS);
 	return lookup_decoration(&name_decoration, obj);
 }
 
@@ -103,20 +95,20 @@ static int add_ref_decoration(const char
 
 	if (starts_with(refname, git_replace_ref_base)) {
 		struct object_id original_oid;
-		if (!check_replace_refs)
+		if (!read_replace_refs)
 			return 0;
 		if (get_oid_hex(refname + strlen(git_replace_ref_base),
 				&original_oid)) {
 			warning("invalid replace ref %s", refname);
 			return 0;
 		}
-		obj = parse_object(&original_oid);
+		obj = parse_object(the_repository, &original_oid);
 		if (obj)
 			add_name_decoration(DECORATION_GRAFTED, "replaced", obj);
 		return 0;
 	}
 
-	obj = parse_object(oid);
+	obj = parse_object(the_repository, oid);
 	if (!obj)
 		return 0;
 
@@ -137,7 +129,7 @@ static int add_ref_decoration(const char
 		if (!obj)
 			break;
 		if (!obj->parsed)
-			parse_object(&obj->oid);
+			parse_object(the_repository, &obj->oid);
 		add_name_decoration(DECORATION_REF_TAG, refname, obj);
 	}
 	return 0;
@@ -145,7 +137,7 @@ static int add_ref_decoration(const char
 
 static int add_graft_decoration(const struct commit_graft *graft, void *cb_data)
 {
-	struct commit *commit = lookup_commit(&graft->oid);
+	struct commit *commit = lookup_commit(the_repository, &graft->oid);
 	if (!commit)
 		return 0;
 	add_name_decoration(DECORATION_GRAFTED, "grafted", &commit->object);
@@ -295,8 +287,12 @@ void show_decorations(struct rev_info *o
 {
 	struct strbuf sb = STRBUF_INIT;
 
-	if (opt->show_source && commit->util)
-		fprintf(opt->diffopt.file, "\t%s", (char *) commit->util);
+	if (opt->sources) {
+		char **slot = revision_sources_peek(opt->sources, commit);
+
+		if (slot && *slot)
+			fprintf(opt->diffopt.file, "\t%s", *slot);
+	}
 	if (!opt->show_decorations)
 		return;
 	format_decorations(&sb, commit, opt->diffopt.use_color);
@@ -453,22 +449,22 @@ static void show_signature(struct rev_in
 {
 	struct strbuf payload = STRBUF_INIT;
 	struct strbuf signature = STRBUF_INIT;
-	struct strbuf gpg_output = STRBUF_INIT;
+	struct signature_check sigc = { 0 };
 	int status;
 
 	if (parse_signed_commit(commit, &payload, &signature) <= 0)
 		goto out;
 
-	status = verify_signed_buffer(payload.buf, payload.len,
-				      signature.buf, signature.len,
-				      &gpg_output, NULL);
-	if (status && !gpg_output.len)
-		strbuf_addstr(&gpg_output, "No signature\n");
-
-	show_sig_lines(opt, status, gpg_output.buf);
+	status = check_signature(payload.buf, payload.len, signature.buf,
+				 signature.len, &sigc);
+	if (status && sigc.result == 'N')
+		show_sig_lines(opt, status, "No signature\n");
+	else {
+		show_sig_lines(opt, status, sigc.gpg_output);
+		signature_check_clear(&sigc);
+	}
 
  out:
-	strbuf_release(&gpg_output);
 	strbuf_release(&payload);
 	strbuf_release(&signature);
 }
@@ -479,7 +475,7 @@ static int which_parent(const struct obj
 	const struct commit_list *parent;
 
 	for (nth = 0, parent = commit->parents; parent; parent = parent->next) {
-		if (!oidcmp(&parent->item->object.oid, oid))
+		if (oideq(&parent->item->object.oid, oid))
 			return nth;
 		nth++;
 	}
@@ -501,20 +497,21 @@ static int show_one_mergetag(struct comm
 	struct object_id oid;
 	struct tag *tag;
 	struct strbuf verify_message;
+	struct signature_check sigc = { 0 };
 	int status, nth;
 	size_t payload_size, gpg_message_offset;
 
 	hash_object_file(extra->value, extra->len, type_name(OBJ_TAG), &oid);
-	tag = lookup_tag(&oid);
+	tag = lookup_tag(the_repository, &oid);
 	if (!tag)
 		return -1; /* error message already given */
 
 	strbuf_init(&verify_message, 256);
-	if (parse_tag_buffer(tag, extra->value, extra->len))
+	if (parse_tag_buffer(the_repository, tag, extra->value, extra->len))
 		strbuf_addstr(&verify_message, "malformed mergetag\n");
 	else if (is_common_merge(commit) &&
-		 !oidcmp(&tag->tagged->oid,
-			  &commit->parents->next->item->object.oid))
+		 oideq(&tag->tagged->oid,
+		       &commit->parents->next->item->object.oid))
 		strbuf_addf(&verify_message,
 			    "merged tag '%s'\n", tag->tag);
 	else if ((nth = which_parent(&tag->tagged->oid, commit)) < 0)
@@ -529,12 +526,13 @@ static int show_one_mergetag(struct comm
 	status = -1;
 	if (extra->len > payload_size) {
 		/* could have a good signature */
-		if (!verify_signed_buffer(extra->value, payload_size,
-					  extra->value + payload_size,
-					  extra->len - payload_size,
-					  &verify_message, NULL))
+		if (!check_signature(extra->value, payload_size,
+				     extra->value + payload_size,
+				     extra->len - payload_size, &sigc)) {
+			strbuf_addstr(&verify_message, sigc.gpg_output);
+			signature_check_clear(&sigc);
 			status = 0; /* good */
-		else if (verify_message.len <= gpg_message_offset)
+		} else if (verify_message.len <= gpg_message_offset)
 			strbuf_addstr(&verify_message, "No signature\n");
 		/* otherwise we couldn't verify, which is shown as bad */
 	}
@@ -549,12 +547,22 @@ static int show_mergetag(struct rev_info
 	return for_each_mergetag(show_one_mergetag, commit, opt);
 }
 
+static void next_commentary_block(struct rev_info *opt, struct strbuf *sb)
+{
+	const char *x = opt->shown_dashes ? "\n" : "---\n";
+	if (sb)
+		strbuf_addstr(sb, x);
+	else
+		fputs(x, opt->diffopt.file);
+	opt->shown_dashes = 1;
+}
+
 void show_log(struct rev_info *opt)
 {
 	struct strbuf msgbuf = STRBUF_INIT;
 	struct log_info *log = opt->loginfo;
 	struct commit *commit = log->commit, *parent = log->parent;
-	int abbrev_commit = opt->abbrev_commit ? opt->abbrev : GIT_SHA1_HEXSZ;
+	int abbrev_commit = opt->abbrev_commit ? opt->abbrev : the_hash_algo->hexsz;
 	const char *extra_headers = opt->extra_headers;
 	struct pretty_print_context ctx = {0};
 
@@ -672,9 +680,7 @@ void show_log(struct rev_info *opt)
 		raw = (opt->commit_format == CMIT_FMT_USERFORMAT);
 		format_display_notes(&commit->object.oid, &notebuf,
 				     get_log_output_encoding(), raw);
-		ctx.notes_message = notebuf.len
-			? strbuf_detach(&notebuf, NULL)
-			: xcalloc(1, 1);
+		ctx.notes_message = strbuf_detach(&notebuf, NULL);
 	}
 
 	/*
@@ -682,8 +688,7 @@ void show_log(struct rev_info *opt)
 	 */
 	if (ctx.need_8bit_cte >= 0 && opt->add_signoff)
 		ctx.need_8bit_cte =
-			has_non_ascii(fmt_name(getenv("GIT_COMMITTER_NAME"),
-					       getenv("GIT_COMMITTER_EMAIL")));
+			has_non_ascii(fmt_name(WANT_COMMITTER_IDENT));
 	ctx.date_mode = opt->date_mode;
 	ctx.date_mode_explicit = opt->date_mode_explicit;
 	ctx.abbrev = opt->diffopt.abbrev;
@@ -695,6 +700,7 @@ void show_log(struct rev_info *opt)
 	ctx.color = opt->diffopt.use_color;
 	ctx.expand_tabs_in_log = opt->expand_tabs_in_log;
 	ctx.output_encoding = get_log_output_encoding();
+	ctx.rev = opt;
 	if (opt->from_ident.mail_begin && opt->from_ident.name_begin)
 		ctx.from_ident = &opt->from_ident;
 	if (opt->graph)
@@ -706,10 +712,8 @@ void show_log(struct rev_info *opt)
 
 	if ((ctx.fmt != CMIT_FMT_USERFORMAT) &&
 	    ctx.notes_message && *ctx.notes_message) {
-		if (cmit_fmt_is_mail(ctx.fmt)) {
-			strbuf_addstr(&msgbuf, "---\n");
-			opt->shown_dashes = 1;
-		}
+		if (cmit_fmt_is_mail(ctx.fmt))
+			next_commentary_block(opt, &msgbuf);
 		strbuf_addstr(&msgbuf, ctx.notes_message);
 	}
 
@@ -736,6 +740,42 @@ void show_log(struct rev_info *opt)
 
 	strbuf_release(&msgbuf);
 	free(ctx.notes_message);
+
+	if (cmit_fmt_is_mail(ctx.fmt) && opt->idiff_oid1) {
+		struct diff_queue_struct dq;
+
+		memcpy(&dq, &diff_queued_diff, sizeof(diff_queued_diff));
+		DIFF_QUEUE_CLEAR(&diff_queued_diff);
+
+		next_commentary_block(opt, NULL);
+		fprintf_ln(opt->diffopt.file, "%s", opt->idiff_title);
+		show_interdiff(opt, 2);
+
+		memcpy(&diff_queued_diff, &dq, sizeof(diff_queued_diff));
+	}
+
+	if (cmit_fmt_is_mail(ctx.fmt) && opt->rdiff1) {
+		struct diff_queue_struct dq;
+		struct diff_options opts;
+
+		memcpy(&dq, &diff_queued_diff, sizeof(diff_queued_diff));
+		DIFF_QUEUE_CLEAR(&diff_queued_diff);
+
+		next_commentary_block(opt, NULL);
+		fprintf_ln(opt->diffopt.file, "%s", opt->rdiff_title);
+		/*
+		 * Pass minimum required diff-options to range-diff; others
+		 * can be added later if deemed desirable.
+		 */
+		diff_setup(&opts);
+		opts.file = opt->diffopt.file;
+		opts.use_color = opt->diffopt.use_color;
+		diff_setup_done(&opts);
+		show_range_diff(opt->rdiff1, opt->rdiff2,
+				opt->creation_factor, 1, &opts, NULL);
+
+		memcpy(&diff_queued_diff, &dq, sizeof(diff_queued_diff));
+	}
 }
 
 int log_tree_diff_flush(struct rev_info *opt)
@@ -773,9 +813,10 @@ int log_tree_diff_flush(struct rev_info
 
 			/*
 			 * We may have shown three-dashes line early
-			 * between notes and the log message, in which
-			 * case we only want a blank line after the
-			 * notes without (an extra) three-dashes line.
+			 * between generated commentary (notes, etc.)
+			 * and the log message, in which case we only
+			 * want a blank line after the commentary
+			 * without (an extra) three-dashes line.
 			 * Otherwise, we show the three-dashes line if
 			 * we are showing the patch with diffstat, but
 			 * in that case, there is no extra blank line
diff -pruN 1.2.1+git2.18.0-1/git/ls-refs.c 1.2.3+git2.25.1-1/git/ls-refs.c
--- 1.2.1+git2.18.0-1/git/ls-refs.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/ls-refs.c	2020-02-17 04:47:35.000000000 +0000
@@ -5,6 +5,7 @@
 #include "argv-array.h"
 #include "ls-refs.h"
 #include "pkt-line.h"
+#include "config.h"
 
 /*
  * Check if one of the prefixes is a prefix of the ref.
@@ -40,7 +41,10 @@ static int send_ref(const char *refname,
 	const char *refname_nons = strip_namespace(refname);
 	struct strbuf refline = STRBUF_INIT;
 
-	if (!ref_match(&data->prefixes, refname))
+	if (ref_is_hidden(refname_nons, refname))
+		return 0;
+
+	if (!ref_match(&data->prefixes, refname_nons))
 		return 0;
 
 	strbuf_addf(&refline, "%s %s", oid_to_hex(oid), refname_nons);
@@ -53,7 +57,8 @@ static int send_ref(const char *refname,
 		if (!symref_target)
 			die("'%s' is a symref but it is not?", refname);
 
-		strbuf_addf(&refline, " symref-target:%s", symref_target);
+		strbuf_addf(&refline, " symref-target:%s",
+			    strip_namespace(symref_target));
 	}
 
 	if (data->peel) {
@@ -69,6 +74,16 @@ static int send_ref(const char *refname,
 	return 0;
 }
 
+static int ls_refs_config(const char *var, const char *value, void *data)
+{
+	/*
+	 * We only serve fetches over v2 for now, so respect only "uploadpack"
+	 * config. This may need to eventually be expanded to "receive", but we
+	 * don't yet know how that information will be passed to ls-refs.
+	 */
+	return parse_hide_refs_config(var, value, "uploadpack");
+}
+
 int ls_refs(struct repository *r, struct argv_array *keys,
 	    struct packet_reader *request)
 {
@@ -76,6 +91,8 @@ int ls_refs(struct repository *r, struct
 
 	memset(&data, 0, sizeof(data));
 
+	git_config(ls_refs_config, NULL);
+
 	while (packet_reader_read(request) != PACKET_READ_FLUSH) {
 		const char *arg = request->line;
 		const char *out;
diff -pruN 1.2.1+git2.18.0-1/git/ls-refs.h 1.2.3+git2.25.1-1/git/ls-refs.h
--- 1.2.1+git2.18.0-1/git/ls-refs.h	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/ls-refs.h	2020-02-17 04:47:35.000000000 +0000
@@ -4,7 +4,7 @@
 struct repository;
 struct argv_array;
 struct packet_reader;
-extern int ls_refs(struct repository *r, struct argv_array *keys,
-		   struct packet_reader *request);
+int ls_refs(struct repository *r, struct argv_array *keys,
+	    struct packet_reader *request);
 
 #endif /* LS_REFS_H */
diff -pruN 1.2.1+git2.18.0-1/git/mailinfo.c 1.2.3+git2.25.1-1/git/mailinfo.c
--- 1.2.1+git2.18.0-1/git/mailinfo.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/mailinfo.c	2020-02-17 04:47:35.000000000 +0000
@@ -237,11 +237,22 @@ static int slurp_attr(const char *line,
 	return 1;
 }
 
+static int has_attr_value(const char *line, const char *name, const char *value)
+{
+	struct strbuf sb = STRBUF_INIT;
+	int rc = slurp_attr(line, name, &sb) && !strcasecmp(sb.buf, value);
+	strbuf_release(&sb);
+	return rc;
+}
+
 static void handle_content_type(struct mailinfo *mi, struct strbuf *line)
 {
 	struct strbuf *boundary = xmalloc(sizeof(struct strbuf));
 	strbuf_init(boundary, line->len);
 
+	mi->format_flowed = has_attr_value(line->buf, "format=", "flowed");
+	mi->delsp = has_attr_value(line->buf, "delsp=", "yes");
+
 	if (slurp_attr(line->buf, "boundary=", boundary)) {
 		strbuf_insert(boundary, 0, "--", 2);
 		if (++mi->content_top >= &mi->content[MAX_BOUNDARIES]) {
@@ -964,6 +975,52 @@ again:
 	return 1;
 }
 
+static void handle_filter_flowed(struct mailinfo *mi, struct strbuf *line,
+				 struct strbuf *prev)
+{
+	size_t len = line->len;
+	const char *rest;
+
+	if (!mi->format_flowed) {
+		handle_filter(mi, line);
+		return;
+	}
+
+	if (line->buf[len - 1] == '\n') {
+		len--;
+		if (len && line->buf[len - 1] == '\r')
+			len--;
+	}
+
+	/* Keep signature separator as-is. */
+	if (skip_prefix(line->buf, "-- ", &rest) && rest - line->buf == len) {
+		if (prev->len) {
+			handle_filter(mi, prev);
+			strbuf_reset(prev);
+		}
+		handle_filter(mi, line);
+		return;
+	}
+
+	/* Unstuff space-stuffed line. */
+	if (len && line->buf[0] == ' ') {
+		strbuf_remove(line, 0, 1);
+		len--;
+	}
+
+	/* Save flowed line for later, but without the soft line break. */
+	if (len && line->buf[len - 1] == ' ') {
+		strbuf_add(prev, line->buf, len - !!mi->delsp);
+		return;
+	}
+
+	/* Prepend any previous partial lines */
+	strbuf_insert(line, 0, prev->buf, prev->len);
+	strbuf_reset(prev);
+
+	handle_filter(mi, line);
+}
+
 static void handle_body(struct mailinfo *mi, struct strbuf *line)
 {
 	struct strbuf prev = STRBUF_INIT;
@@ -1012,7 +1069,7 @@ static void handle_body(struct mailinfo
 						strbuf_addbuf(&prev, sb);
 						break;
 					}
-				handle_filter(mi, sb);
+				handle_filter_flowed(mi, sb, &prev);
 			}
 			/*
 			 * The partial chunk is saved in "prev" and will be
@@ -1022,13 +1079,16 @@ static void handle_body(struct mailinfo
 			break;
 		}
 		default:
-			handle_filter(mi, line);
+			handle_filter_flowed(mi, line, &prev);
 		}
 
 		if (mi->input_error)
 			break;
 	} while (!strbuf_getwholeline(line, mi->input, '\n'));
 
+	if (prev.len)
+		handle_filter(mi, &prev);
+
 	flush_inbody_header_accum(mi);
 
 handle_body_out:
diff -pruN 1.2.1+git2.18.0-1/git/mailinfo.h 1.2.3+git2.25.1-1/git/mailinfo.h
--- 1.2.1+git2.18.0-1/git/mailinfo.h	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/mailinfo.h	2020-02-17 04:47:35.000000000 +0000
@@ -1,6 +1,8 @@
 #ifndef MAILINFO_H
 #define MAILINFO_H
 
+#include "strbuf.h"
+
 #define MAX_BOUNDARIES 5
 
 struct mailinfo {
@@ -20,6 +22,8 @@ struct mailinfo {
 	struct strbuf *content[MAX_BOUNDARIES];
 	struct strbuf **content_top;
 	struct strbuf charset;
+	unsigned int format_flowed:1;
+	unsigned int delsp:1;
 	char *message_id;
 	enum  {
 		TE_DONTCARE, TE_QP, TE_BASE64
@@ -35,8 +39,8 @@ struct mailinfo {
 	int input_error;
 };
 
-extern void setup_mailinfo(struct mailinfo *);
-extern int mailinfo(struct mailinfo *, const char *msg, const char *patch);
-extern void clear_mailinfo(struct mailinfo *);
+void setup_mailinfo(struct mailinfo *);
+int mailinfo(struct mailinfo *, const char *msg, const char *patch);
+void clear_mailinfo(struct mailinfo *);
 
 #endif /* MAILINFO_H */
diff -pruN 1.2.1+git2.18.0-1/git/.mailmap 1.2.3+git2.25.1-1/git/.mailmap
--- 1.2.1+git2.18.0-1/git/.mailmap	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/.mailmap	2020-02-17 04:47:35.000000000 +0000
@@ -18,28 +18,37 @@ Alexey Shumkin <alex.crezoff@gmail.com>
 Alexey Shumkin <alex.crezoff@gmail.com> <Alex.Crezoff@gmail.com>
 Anders Kaseorg <andersk@MIT.EDU> <andersk@ksplice.com>
 Anders Kaseorg <andersk@MIT.EDU> <andersk@mit.edu>
+Andrey Mazo <ahippo@yandex.com> Mazo, Andrey <amazo@checkvideo.com>
 Aneesh Kumar K.V <aneesh.kumar@gmail.com>
 Amos Waterland <apw@debian.org> <apw@rossby.metr.ou.edu>
 Amos Waterland <apw@debian.org> <apw@us.ibm.com>
+Ben Peart <benpeart@microsoft.com> <Ben.Peart@microsoft.com>
+Ben Peart <benpeart@microsoft.com> <peartben@gmail.com>
 Ben Walton <bdwalton@gmail.com> <bwalton@artsci.utoronto.ca>
 Benoit Sigoure <tsunanet@gmail.com> <tsuna@lrde.epita.fr>
 Bernt Hansen <bernt@norang.ca> <bernt@alumni.uwaterloo.ca>
 Brandon Casey <drafnel@gmail.com> <casey@nrlssc.navy.mil>
-brian m. carlson <sandals@crustytoothpaste.net> Brian M. Carlson <sandals@crustytoothpaste.ath.cx>
+Brandon Williams <bwilliams.eng@gmail.com> <bmwill@google.com>
+brian m. carlson <sandals@crustytoothpaste.net>
 brian m. carlson <sandals@crustytoothpaste.net> <sandals@crustytoothpaste.ath.cx>
 Bryan Larsen <bryan@larsen.st> <bryan.larsen@gmail.com>
 Bryan Larsen <bryan@larsen.st> <bryanlarsen@yahoo.com>
 Cheng Renquan <crquan@gmail.com>
 Chris Shoemaker <c.shoemaker@cox.net>
 Chris Wright <chrisw@sous-sol.org> <chrisw@osdl.org>
+Christian Ludwig <chrissicool@gmail.com> <chrissicool@googlemail.com>
 Cord Seele <cowose@gmail.com> <cowose@googlemail.com>
 Christian Couder <chriscool@tuxfamily.org> <christian.couder@gmail.com>
 Christian Stimming <stimming@tuhh.de> <chs@ckiste.goetheallee>
+Christopher Díaz Riveros <chrisadr@gentoo.org> Christopher Diaz Riveros
+Clemens Buchacher <drizzd@gmx.net> <drizzd@aon.at>
+Clemens Buchacher <drizzd@gmx.net> <clemens.buchacher@intel.com>
 Csaba Henk <csaba@gluster.com> <csaba@lowlife.hu>
 Dan Johnson <computerdruid@gmail.com>
 Dana L. How <danahow@gmail.com> <how@deathvalley.cswitch.com>
 Dana L. How <danahow@gmail.com> Dana How
 Daniel Barkalow <barkalow@iabervon.org>
+Daniel Knittl-Frank <knittl89@googlemail.com> knittl
 Daniel Trstenjak <daniel.trstenjak@gmail.com> <daniel.trstenjak@online.de>
 Daniel Trstenjak <daniel.trstenjak@gmail.com> <trsten@science-computing.de>
 David Brown <git@davidb.org> <davidb@quicinc.com>
@@ -49,7 +58,10 @@ David Reiss <dreiss@facebook.com> <dreis
 David S. Miller <davem@davemloft.net>
 David Turner <novalis@novalis.org> <dturner@twopensource.com>
 David Turner <novalis@novalis.org> <dturner@twosigma.com>
+Derrick Stolee <dstolee@microsoft.com> <stolee@gmail.com>
+Derrick Stolee <dstolee@microsoft.com> Derrick Stolee via GitGitGadget <gitgitgadget@gmail.com>
 Deskin Miller <deskinm@umich.edu>
+Đoàn Trần Công Danh <congdanhqx@gmail.com> Doan Tran Cong Danh
 Dirk Süsserott <newsletter@dirk.my1.cc>
 Eric Blake <eblake@redhat.com> <ebb9@byu.net>
 Eric Hanchrow <eric.hanchrow@gmail.com> <offby1@blarg.net>
@@ -57,6 +69,7 @@ Eric S. Raymond <esr@thyrsus.com>
 Eric Wong <e@80x24.org> <normalperson@yhbt.net>
 Erik Faye-Lund <kusmabite@gmail.com> <kusmabite@googlemail.com>
 Eyvind Bernhardsen <eyvind.bernhardsen@gmail.com> <eyvind-git@orakel.ntnu.no>
+Fangyi Zhou <fangyi.zhou@yuriko.moe> Zhou Fangyi
 Florian Achleitner <florian.achleitner.2.6.31@gmail.com> <florian.achleitner2.6.31@gmail.com>
 Franck Bui-Huu <vagabon.xyz@gmail.com> <fbuihuu@gmail.com>
 Frank Lichtenheld <frank@lichtenheld.de> <djpig@debian.org>
@@ -86,6 +99,8 @@ Jason McMullan <mcmullan@netapp.com>
 Jason Riedy <ejr@eecs.berkeley.edu> <ejr@EECS.Berkeley.EDU>
 Jason Riedy <ejr@eecs.berkeley.edu> <ejr@cs.berkeley.edu>
 Jay Soffian <jaysoffian@gmail.com> <jaysoffian+git@gmail.com>
+Jean-Noël Avila <jn.avila@free.fr> Jean-Noel Avila
+Jean-Noël Avila <jn.avila@free.fr> Jean-Noël AVILA
 Jeff King <peff@peff.net> <peff@github.com>
 Jeff Muizelaar <jmuizelaar@mozilla.com> <jeff@infidigm.net>
 Jens Axboe <axboe@kernel.dk> <axboe@suse.de>
@@ -93,7 +108,9 @@ Jens Axboe <axboe@kernel.dk> <jens.axboe
 Jens Lindström <jl@opera.com> Jens Lindstrom <jl@opera.com>
 Jim Meyering <jim@meyering.net> <meyering@redhat.com>
 Joachim Berdal Haga <cjhaga@fys.uio.no>
+Joachim Jablon <joachim.jablon@people-doc.com> <ewjoachim@gmail.com>
 Johannes Schindelin <Johannes.Schindelin@gmx.de> <johannes.schindelin@gmx.de>
+Johannes Schindelin <Johannes.Schindelin@gmx.de> Johannes Schindelin via GitGitGadget <gitgitgadget@gmail.com>
 Johannes Sixt <j6t@kdbg.org> <J.Sixt@eudaptics.com>
 Johannes Sixt <j6t@kdbg.org> <j.sixt@viscovery.net>
 Johannes Sixt <j6t@kdbg.org> <johannes.sixt@telecom.at>
@@ -145,12 +162,15 @@ Mark Levedahl <mdl123@verizon.net> <mlev
 Mark Rada <marada@uwaterloo.ca>
 Martin Langhoff <martin@laptop.org> <martin@catalyst.net.nz>
 Martin von Zweigbergk <martinvonz@gmail.com> <martin.von.zweigbergk@gmail.com>
+Masaya Suzuki <masayasuzuki@google.com> <draftcode@gmail.com>
 Matt Draisey <matt@draisey.ca> <mattdraisey@sympatico.ca>
 Matt Kraai <kraai@ftbfs.org> <matt.kraai@amo.abbott.com>
 Matt McCutchen <matt@mattmccutchen.net> <hashproduct@gmail.com>
 Matthias Kestenholz <matthias@spinlock.ch> <mk@spinlock.ch>
+Matthias Rüster <matthias.ruester@gmail.com> Matthias Ruester
 Matthias Urlichs <matthias@urlichs.de> <smurf@kiste.(none)>
 Matthias Urlichs <matthias@urlichs.de> <smurf@smurf.noris.de>
+Matthieu Moy <git@matthieu-moy.fr> <Matthieu.Moy@imag.fr>
 Michael Coleman <tutufan@gmail.com>
 Michael J Gruber <git@grubix.eu> <michaeljgruber+gmane@fastmail.fm>
 Michael J Gruber <git@grubix.eu> <git@drmicha.warpmail.net>
@@ -174,7 +194,11 @@ Nick Stokoe <nick@noodlefactory.co.uk> N
 Nick Stokoe <nick@noodlefactory.co.uk> Nick Woolley <nickwoolley@yahoo.co.uk>
 Nicolas Morey-Chaisemartin <devel-git@morey-chaisemartin.com> <nicolas.morey@free.fr>
 Nicolas Morey-Chaisemartin <devel-git@morey-chaisemartin.com> <nmorey@kalray.eu>
+Nicolas Morey-Chaisemartin <devel-git@morey-chaisemartin.com> <nicolas@morey-chaisemartin.com>
+Nicolas Morey-Chaisemartin <devel-git@morey-chaisemartin.com> <NMoreyChaisemartin@suse.com>
+Nicolas Morey-Chaisemartin <devel-git@morey-chaisemartin.com> <nmoreychaisemartin@suse.com>
 Nicolas Sebrecht <nicolas.s.dev@gmx.fr> <ni.s@laposte.net>
+Orgad Shaneh <orgads@gmail.com> <orgad.shaneh@audiocodes.com>
 Paolo Bonzini <bonzini@gnu.org> <paolo.bonzini@lu.unisi.ch>
 Pascal Obry <pascal@obry.net> <pascal.obry@gmail.com>
 Pascal Obry <pascal@obry.net> <pascal.obry@wanadoo.fr>
@@ -190,10 +214,12 @@ Petr Baudis <pasky@ucw.cz> <pasky@suse.c
 Petr Baudis <pasky@ucw.cz> <xpasky@machine>
 Phil Hord <hordp@cisco.com> <phil.hord@gmail.com>
 Philip Jägenstedt <philip@foolip.org> <philip.jagenstedt@gmail.com>
+Philip Oakley <philipoakley@iee.email> <philipoakley@iee.org> # secondary <philipoakley@dunelm.org.uk>
 Philipp A. Hartmann <pah@qo.cx> <ph@sorgh.de>
 Philippe Bruhat <book@cpan.org>
 Ralf Thielow <ralf.thielow@gmail.com> <ralf.thielow@googlemail.com>
 Ramsay Jones <ramsay@ramsayjones.plus.com> <ramsay@ramsay1.demon.co.uk>
+Randall S. Becker <randall.becker@nexbridge.ca> <rsbecker@nexbridge.com>
 René Scharfe <l.s.r@web.de> <rene.scharfe@lsrfire.ath.cx>
 René Scharfe <l.s.r@web.de> Rene Scharfe
 Richard Hansen <rhansen@rhansen.org> <hansenr@google.com>
@@ -213,6 +239,8 @@ Sean Estabrooks <seanlkml@sympatico.ca>
 Sebastian Schuberth <sschuberth@gmail.com> <sschuberth@visageimaging.com>
 Seth Falcon <seth@userprimary.net> <sfalcon@fhcrc.org>
 Shawn O. Pearce <spearce@spearce.org>
+Wei Shuyu <wsy@dogben.com> Shuyu Wei
+Sidhant Sharma <tigerkid001@gmail.com> Sidhant Sharma [:tk]
 Simon Hausmann <hausmann@kde.org> <simon@lst.de>
 Simon Hausmann <hausmann@kde.org> <shausman@trolltech.com>
 Stefan Beller <stefanbeller@gmail.com> <stefanbeller@googlemail.com>
@@ -230,6 +258,7 @@ Steven Walter <stevenrwalter@gmail.com>
 Sven Verdoolaege <skimo@kotnet.org> <Sven.Verdoolaege@cs.kuleuven.ac.be>
 Sven Verdoolaege <skimo@kotnet.org> <skimo@liacs.nl>
 SZEDER Gábor <szeder.dev@gmail.com> <szeder@ira.uka.de>
+Tao Qingyun <taoqy@ls-a.me> <845767657@qq.com>
 Tay Ray Chuan <rctay89@gmail.com>
 Ted Percival <ted@midg3t.net> <ted.percival@quest.com>
 Theodore Ts'o <tytso@mit.edu>
@@ -253,12 +282,14 @@ Uwe Kleine-König <u.kleine-koenig@pengu
 Uwe Kleine-König <u.kleine-koenig@pengutronix.de> <uzeisberger@io.fsforth.de>
 Uwe Kleine-König <u.kleine-koenig@pengutronix.de> <zeisberg@informatik.uni-freiburg.de>
 Ville Skyttä <ville.skytta@iki.fi> <scop@xemacs.org>
-Vitaly "_Vi" Shukela <public_vi@tut.by>
+Vitaly "_Vi" Shukela <vi0oss@gmail.com> <public_vi@tut.by>
+Vitaly "_Vi" Shukela <vi0oss@gmail.com> Vitaly _Vi Shukela
 W. Trevor King <wking@tremily.us> <wking@drexel.edu>
 William Pursell <bill.pursell@gmail.com>
 YONETANI Tomokazu <y0n3t4n1@gmail.com> <qhwt+git@les.ath.cx>
 YONETANI Tomokazu <y0n3t4n1@gmail.com> <y0netan1@dragonflybsd.org>
 YOSHIFUJI Hideaki <yoshfuji@linux-ipv6.org>
+Yi-Jyun Pan <pan93412@gmail.com>
 # the two anonymous contributors are different persons:
 anonymous <linux@horizon.com>
 anonymous <linux@horizon.net>
diff -pruN 1.2.1+git2.18.0-1/git/mailmap.c 1.2.3+git2.25.1-1/git/mailmap.c
--- 1.2.1+git2.18.0-1/git/mailmap.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/mailmap.c	2020-02-17 04:47:35.000000000 +0000
@@ -1,6 +1,7 @@
 #include "cache.h"
 #include "string-list.h"
 #include "mailmap.h"
+#include "object-store.h"
 
 #define DEBUG_MAILMAP 0
 #if DEBUG_MAILMAP
diff -pruN 1.2.1+git2.18.0-1/git/mailmap.h 1.2.3+git2.25.1-1/git/mailmap.h
--- 1.2.1+git2.18.0-1/git/mailmap.h	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/mailmap.h	2020-02-17 04:47:35.000000000 +0000
@@ -1,6 +1,8 @@
 #ifndef MAILMAP_H
 #define MAILMAP_H
 
+struct string_list;
+
 int read_mailmap(struct string_list *map, char **repo_abbrev);
 void clear_mailmap(struct string_list *map);
 
diff -pruN 1.2.1+git2.18.0-1/git/Makefile 1.2.3+git2.25.1-1/git/Makefile
--- 1.2.1+git2.18.0-1/git/Makefile	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/Makefile	2020-02-17 04:47:35.000000000 +0000
@@ -34,13 +34,8 @@ all::
 # library. Support for version 1 will likely be removed in some future
 # release of Git, as upstream has all but abandoned it.
 #
-# When using USE_LIBPCRE1, define NO_LIBPCRE1_JIT if the PCRE v1
-# library is compiled without --enable-jit. We will auto-detect
-# whether the version of the PCRE v1 library in use has JIT support at
-# all, but we unfortunately can't auto-detect whether JIT support
-# hasn't been compiled in in an otherwise JIT-supporting version. If
-# you have link-time errors about a missing `pcre_jit_exec` define
-# this, or recompile PCRE v1 with --enable-jit.
+# When using USE_LIBPCRE1, define NO_LIBPCRE1_JIT if you want to
+# disable JIT even if supported by your library.
 #
 # Define LIBPCREDIR=/foo/bar if your PCRE header and library files are
 # in /foo/bar/include and /foo/bar/lib directories. Which version of
@@ -59,6 +54,13 @@ all::
 # Define CURL_CONFIG to curl's configuration program that prints information
 # about the library (e.g., its version number).  The default is 'curl-config'.
 #
+# Define CURL_LDFLAGS to specify flags that you need to link when using libcurl,
+# if you do not want to rely on the libraries provided by CURL_CONFIG.  The
+# default value is a result of `curl-config --libs`.  An example value for
+# CURL_LDFLAGS is as follows:
+#
+#     CURL_LDFLAGS=-lcurl
+#
 # Define NO_EXPAT if you do not have expat installed.  git-http-push is
 # not built, and you cannot push using http:// and https:// transports (dumb).
 #
@@ -179,13 +181,15 @@ all::
 # in one call to the platform's SHA1_Update(). e.g. APPLE_COMMON_CRYPTO
 # wants 'SHA1_MAX_BLOCK_SIZE=1024L*1024L*1024L' defined.
 #
-# Define NEEDS_CRYPTO_WITH_SSL if you need -lcrypto when using -lssl (Darwin).
+# Define BLK_SHA256 to use the built-in SHA-256 routines.
 #
-# Define NEEDS_SSL_WITH_CRYPTO if you need -lssl when using -lcrypto (Darwin).
+# Define GCRYPT_SHA256 to use the SHA-256 routines in libgcrypt.
 #
-# Define NEEDS_SSL_WITH_CURL if you need -lssl with -lcurl (Minix).
+# Define OPENSSL_SHA256 to use the SHA-256 routines in OpenSSL.
 #
-# Define NEEDS_IDN_WITH_CURL if you need -lidn when using -lcurl (Minix).
+# Define NEEDS_CRYPTO_WITH_SSL if you need -lcrypto when using -lssl (Darwin).
+#
+# Define NEEDS_SSL_WITH_CRYPTO if you need -lssl when using -lcrypto (Darwin).
 #
 # Define NEEDS_LIBICONV if linking with libc is not enough (Darwin).
 #
@@ -207,10 +211,12 @@ all::
 # Define MMAP_PREVENTS_DELETE if a file that is currently mmapped cannot be
 # deleted or cannot be replaced using rename().
 #
+# Define NO_POLL_H if you don't have poll.h.
+#
 # Define NO_SYS_POLL_H if you don't have sys/poll.h.
 #
 # Define NO_POLL if you do not have or don't want to use poll().
-# This also implies NO_SYS_POLL_H.
+# This also implies NO_POLL_H and NO_SYS_POLL_H.
 #
 # Define NEEDS_SYS_PARAM_H if you need to include sys/param.h to compile,
 # *PLEASE* REPORT to git@vger.kernel.org if your platform needs this;
@@ -248,11 +254,11 @@ all::
 # Define OLD_ICONV if your library has an old iconv(), where the second
 # (input buffer pointer) parameter is declared with type (const char **).
 #
-# Define NO_DEFLATE_BOUND if your zlib does not have deflateBound.
+# Define ICONV_OMITS_BOM if your iconv implementation does not write a
+# byte-order mark (BOM) when writing UTF-16 or UTF-32 and always writes in
+# big-endian format.
 #
-# Define NO_R_TO_GCC_LINKER if your gcc does not like "-R/path/lib"
-# that tells runtime paths to dynamic libraries;
-# "-Wl,-rpath=/path/lib" is used instead.
+# Define NO_DEFLATE_BOUND if your zlib does not have deflateBound.
 #
 # Define NO_NORETURN if using buggy versions of gcc 4.6+ and profile feedback,
 # as the compiler can crash (http://gcc.gnu.org/bugzilla/show_bug.cgi?id=49299)
@@ -362,11 +368,6 @@ all::
 # Define HAVE_DEV_TTY if your system can open /dev/tty to interact with the
 # user.
 #
-# Define GETTEXT_POISON if you are debugging the choice of strings marked
-# for translation.  In a GETTEXT_POISON build, you can turn all strings marked
-# for translation into gibberish by setting the GIT_GETTEXT_POISON variable
-# (to any value) in your environment.
-#
 # Define JSMIN to point to JavaScript minifier that functions as
 # a filter to have gitweb.js minified.
 #
@@ -400,7 +401,7 @@ all::
 # (defaults to "man") if you want to have a different default when
 # "git help" is called without a parameter specifying the format.
 #
-# Define TEST_GIT_INDEX_VERSION to 2, 3 or 4 to run the test suite
+# Define GIT_TEST_INDEX_VERSION to 2, 3 or 4 to run the test suite
 # with a different indexfile format version.  If it isn't set the index
 # file format used is index-v[23].
 #
@@ -427,6 +428,11 @@ all::
 #
 # Define HAVE_GETDELIM if your system has the getdelim() function.
 #
+# Define FILENO_IS_A_MACRO if fileno() is a macro, not a real function.
+#
+# Define NEED_ACCESS_ROOT_HANDLER if access() under root may success for X_OK
+# even if execution permission isn't granted for any user.
+#
 # Define PAGER_ENV to a SP separated VAR=VAL pairs to define
 # default environment variables to be passed when a pager is spawned, e.g.
 #
@@ -467,11 +473,15 @@ all::
 #
 # Define DEVELOPER to enable more compiler warnings. Compiler version
 # and family are auto detected, but could be overridden by defining
-# COMPILER_FEATURES (see config.mak.dev)
+# COMPILER_FEATURES (see config.mak.dev). You can still set
+# CFLAGS="..." in combination with DEVELOPER enables, whether that's
+# for tweaking something unrelated (e.g. optimization level), or for
+# selectively overriding something DEVELOPER or one of the DEVOPTS
+# (see just below) brings in.
 #
 # When DEVELOPER is set, DEVOPTS can be used to control compiler
 # options.  This variable contains keywords separated by
-# whitespace. The following keywords are are recognized:
+# whitespace. The following keywords are recognized:
 #
 #    no-error:
 #
@@ -484,22 +494,18 @@ all::
 #        The DEVELOPER mode enables -Wextra with a few exceptions. By
 #        setting this flag the exceptions are removed, and all of
 #        -Wextra is used.
+#
+#    pedantic:
+#
+#        Enable -pedantic compilation. This also disables
+#        USE_PARENS_AROUND_GETTEXT_N to produce only relevant warnings.
 
 GIT-VERSION-FILE: FORCE
 	@$(SHELL_PATH) ./GIT-VERSION-GEN
 -include GIT-VERSION-FILE
 
-# CFLAGS and LDFLAGS are for the users to override from the command line.
-
-CFLAGS = -g -O2 -Wall
-LDFLAGS =
-ALL_CFLAGS = $(CPPFLAGS) $(CFLAGS)
-ALL_LDFLAGS = $(LDFLAGS)
-STRIP ?= strip
-
-# Create as necessary, replace existing, make ranlib unneeded.
-ARFLAGS = rcs
-
+# Set our default configuration.
+#
 # Among the variables below, these:
 #   gitexecdir
 #   template_dir
@@ -544,6 +550,7 @@ perllibdir_relative = $(patsubst $(prefi
 
 export prefix bindir sharedir sysconfdir gitwebdir perllibdir localedir
 
+# Set our default programs
 CC = cc
 AR = ar
 RM = rm -f
@@ -556,25 +563,14 @@ TCLTK_PATH = wish
 XGETTEXT = xgettext
 MSGFMT = msgfmt
 CURL_CONFIG = curl-config
-PTHREAD_LIBS = -lpthread
-PTHREAD_CFLAGS =
 GCOV = gcov
+STRIP = strip
 SPATCH = spatch
 
 export TCL_PATH TCLTK_PATH
 
-SPARSE_FLAGS =
-SPATCH_FLAGS = --all-includes
-
-
-
-### --- END CONFIGURATION SECTION ---
-
-# Those must not be GNU-specific; they are shared with perl/ which may
-# be built by a different compiler. (Note that this is an artifact now
-# but it still might be nice to keep that distinction.)
-BASIC_CFLAGS = -I.
-BASIC_LDFLAGS =
+# Set our default LIBS variables
+PTHREAD_LIBS = -lpthread
 
 # Guard against environment variables
 BUILTIN_OBJS =
@@ -585,15 +581,19 @@ XDIFF_OBJS =
 VCSSVN_OBJS =
 GENERATED_H =
 EXTRA_CPPFLAGS =
+FUZZ_OBJS =
+FUZZ_PROGRAMS =
 LIB_OBJS =
 PROGRAM_OBJS =
 PROGRAMS =
+EXCLUDED_PROGRAMS =
 SCRIPT_PERL =
 SCRIPT_PYTHON =
 SCRIPT_SH =
 SCRIPT_LIB =
 TEST_BUILTINS_OBJS =
 TEST_PROGRAMS_NEED_X =
+THIRD_PARTY_SOURCES =
 
 # Having this variable in your environment would break pipelines because
 # you cause "cd" to echo its destination to stdout.  It can also take
@@ -609,18 +609,14 @@ SCRIPT_SH += git-merge-one-file.sh
 SCRIPT_SH += git-merge-resolve.sh
 SCRIPT_SH += git-mergetool.sh
 SCRIPT_SH += git-quiltimport.sh
-SCRIPT_SH += git-rebase.sh
-SCRIPT_SH += git-remote-testgit.sh
+SCRIPT_SH += git-legacy-stash.sh
 SCRIPT_SH += git-request-pull.sh
-SCRIPT_SH += git-stash.sh
 SCRIPT_SH += git-submodule.sh
 SCRIPT_SH += git-web--browse.sh
 
 SCRIPT_LIB += git-mergetool--lib
 SCRIPT_LIB += git-parse-remote
-SCRIPT_LIB += git-rebase--am
-SCRIPT_LIB += git-rebase--interactive
-SCRIPT_LIB += git-rebase--merge
+SCRIPT_LIB += git-rebase--preserve-merges
 SCRIPT_LIB += git-sh-setup
 SCRIPT_LIB += git-sh-i18n
 
@@ -634,17 +630,11 @@ SCRIPT_PERL += git-svn.perl
 
 SCRIPT_PYTHON += git-p4.py
 
-NO_INSTALL += git-remote-testgit
-
 # Generated files for scripts
 SCRIPT_SH_GEN = $(patsubst %.sh,%,$(SCRIPT_SH))
 SCRIPT_PERL_GEN = $(patsubst %.perl,%,$(SCRIPT_PERL))
 SCRIPT_PYTHON_GEN = $(patsubst %.py,%,$(SCRIPT_PYTHON))
 
-SCRIPT_SH_INS = $(filter-out $(NO_INSTALL),$(SCRIPT_SH_GEN))
-SCRIPT_PERL_INS = $(filter-out $(NO_INSTALL),$(SCRIPT_PERL_GEN))
-SCRIPT_PYTHON_INS = $(filter-out $(NO_INSTALL),$(SCRIPT_PYTHON_GEN))
-
 # Individual rules to allow e.g.
 # "make -C ../.. SCRIPT_PERL=contrib/foo/bar.perl build-perl-script"
 # from subdirectories like contrib/*/
@@ -654,11 +644,11 @@ build-sh-script: $(SCRIPT_SH_GEN)
 build-python-script: $(SCRIPT_PYTHON_GEN)
 
 .PHONY: install-perl-script install-sh-script install-python-script
-install-sh-script: $(SCRIPT_SH_INS)
+install-sh-script: $(SCRIPT_SH_GEN)
 	$(INSTALL) $^ '$(DESTDIR_SQ)$(gitexec_instdir_SQ)'
-install-perl-script: $(SCRIPT_PERL_INS)
+install-perl-script: $(SCRIPT_PERL_GEN)
 	$(INSTALL) $^ '$(DESTDIR_SQ)$(gitexec_instdir_SQ)'
-install-python-script: $(SCRIPT_PYTHON_INS)
+install-python-script: $(SCRIPT_PYTHON_GEN)
 	$(INSTALL) $^ '$(DESTDIR_SQ)$(gitexec_instdir_SQ)'
 
 .PHONY: clean-perl-script clean-sh-script clean-python-script
@@ -669,13 +659,22 @@ clean-perl-script:
 clean-python-script:
 	$(RM) $(SCRIPT_PYTHON_GEN)
 
-SCRIPTS = $(SCRIPT_SH_INS) \
-	  $(SCRIPT_PERL_INS) \
-	  $(SCRIPT_PYTHON_INS) \
+SCRIPTS = $(SCRIPT_SH_GEN) \
+	  $(SCRIPT_PERL_GEN) \
+	  $(SCRIPT_PYTHON_GEN) \
 	  git-instaweb
 
 ETAGS_TARGET = TAGS
 
+FUZZ_OBJS += fuzz-commit-graph.o
+FUZZ_OBJS += fuzz-pack-headers.o
+FUZZ_OBJS += fuzz-pack-idx.o
+
+# Always build fuzz objects even if not testing, to prevent bit-rot.
+all:: $(FUZZ_OBJS)
+
+FUZZ_PROGRAMS += $(patsubst %.o,%,$(FUZZ_OBJS))
+
 # Empty...
 EXTRA_PROGRAMS =
 
@@ -689,7 +688,6 @@ PROGRAM_OBJS += http-backend.o
 PROGRAM_OBJS += imap-send.o
 PROGRAM_OBJS += sh-i18n--envsubst.o
 PROGRAM_OBJS += shell.o
-PROGRAM_OBJS += show-index.o
 PROGRAM_OBJS += remote-testsvn.o
 
 # Binary suffix, set to .exe for Windows builds
@@ -702,43 +700,62 @@ TEST_BUILTINS_OBJS += test-config.o
 TEST_BUILTINS_OBJS += test-ctype.o
 TEST_BUILTINS_OBJS += test-date.o
 TEST_BUILTINS_OBJS += test-delta.o
+TEST_BUILTINS_OBJS += test-dir-iterator.o
 TEST_BUILTINS_OBJS += test-drop-caches.o
 TEST_BUILTINS_OBJS += test-dump-cache-tree.o
+TEST_BUILTINS_OBJS += test-dump-fsmonitor.o
 TEST_BUILTINS_OBJS += test-dump-split-index.o
+TEST_BUILTINS_OBJS += test-dump-untracked-cache.o
 TEST_BUILTINS_OBJS += test-example-decorate.o
 TEST_BUILTINS_OBJS += test-genrandom.o
+TEST_BUILTINS_OBJS += test-genzeros.o
+TEST_BUILTINS_OBJS += test-hash.o
 TEST_BUILTINS_OBJS += test-hashmap.o
+TEST_BUILTINS_OBJS += test-hash-speed.o
 TEST_BUILTINS_OBJS += test-index-version.o
+TEST_BUILTINS_OBJS += test-json-writer.o
 TEST_BUILTINS_OBJS += test-lazy-init-name-hash.o
 TEST_BUILTINS_OBJS += test-match-trees.o
 TEST_BUILTINS_OBJS += test-mergesort.o
 TEST_BUILTINS_OBJS += test-mktemp.o
+TEST_BUILTINS_OBJS += test-oidmap.o
 TEST_BUILTINS_OBJS += test-online-cpus.o
+TEST_BUILTINS_OBJS += test-parse-options.o
 TEST_BUILTINS_OBJS += test-path-utils.o
+TEST_BUILTINS_OBJS += test-pkt-line.o
 TEST_BUILTINS_OBJS += test-prio-queue.o
+TEST_BUILTINS_OBJS += test-progress.o
+TEST_BUILTINS_OBJS += test-reach.o
 TEST_BUILTINS_OBJS += test-read-cache.o
+TEST_BUILTINS_OBJS += test-read-graph.o
+TEST_BUILTINS_OBJS += test-read-midx.o
 TEST_BUILTINS_OBJS += test-ref-store.o
 TEST_BUILTINS_OBJS += test-regex.o
+TEST_BUILTINS_OBJS += test-repository.o
 TEST_BUILTINS_OBJS += test-revision-walking.o
 TEST_BUILTINS_OBJS += test-run-command.o
 TEST_BUILTINS_OBJS += test-scrap-cache-tree.o
-TEST_BUILTINS_OBJS += test-sha1-array.o
+TEST_BUILTINS_OBJS += test-serve-v2.o
 TEST_BUILTINS_OBJS += test-sha1.o
+TEST_BUILTINS_OBJS += test-sha1-array.o
+TEST_BUILTINS_OBJS += test-sha256.o
 TEST_BUILTINS_OBJS += test-sigchain.o
 TEST_BUILTINS_OBJS += test-strcmp-offset.o
 TEST_BUILTINS_OBJS += test-string-list.o
 TEST_BUILTINS_OBJS += test-submodule-config.o
+TEST_BUILTINS_OBJS += test-submodule-nested-repo-config.o
 TEST_BUILTINS_OBJS += test-subprocess.o
+TEST_BUILTINS_OBJS += test-trace2.o
 TEST_BUILTINS_OBJS += test-urlmatch-normalization.o
+TEST_BUILTINS_OBJS += test-xml-encode.o
 TEST_BUILTINS_OBJS += test-wildmatch.o
+TEST_BUILTINS_OBJS += test-windows-named-pipe.o
 TEST_BUILTINS_OBJS += test-write-cache.o
 
-TEST_PROGRAMS_NEED_X += test-dump-fsmonitor
-TEST_PROGRAMS_NEED_X += test-dump-untracked-cache
+# Do not add more tests here unless they have extra dependencies. Add
+# them in TEST_BUILTINS_OBJS above.
 TEST_PROGRAMS_NEED_X += test-fake-ssh
 TEST_PROGRAMS_NEED_X += test-line-buffer
-TEST_PROGRAMS_NEED_X += test-parse-options
-TEST_PROGRAMS_NEED_X += test-pkt-line
 TEST_PROGRAMS_NEED_X += test-svn-fe
 TEST_PROGRAMS_NEED_X += test-tool
 
@@ -754,9 +771,11 @@ BUILT_INS += git-format-patch$X
 BUILT_INS += git-fsck-objects$X
 BUILT_INS += git-init$X
 BUILT_INS += git-merge-subtree$X
+BUILT_INS += git-restore$X
 BUILT_INS += git-show$X
 BUILT_INS += git-stage$X
 BUILT_INS += git-status$X
+BUILT_INS += git-switch$X
 BUILT_INS += git-whatchanged$X
 
 # what 'all' will build and 'install' will install in gitexecdir,
@@ -797,13 +816,16 @@ VCSSVN_LIB = vcs-svn/lib.a
 
 GENERATED_H += command-list.h
 
-LIB_H = $(shell $(FIND) . \
+LIB_H := $(sort $(patsubst ./%,%,$(shell git ls-files '*.h' ':!t/' ':!Documentation/' 2>/dev/null || \
+	$(FIND) . \
 	-name .git -prune -o \
 	-name t -prune -o \
 	-name Documentation -prune -o \
-	-name '*.h' -print)
+	-name '*.h' -print)))
 
 LIB_OBJS += abspath.o
+LIB_OBJS += add-interactive.o
+LIB_OBJS += add-patch.o
 LIB_OBJS += advice.o
 LIB_OBJS += alias.o
 LIB_OBJS += alloc.o
@@ -828,6 +850,7 @@ LIB_OBJS += column.o
 LIB_OBJS += combine-diff.o
 LIB_OBJS += commit.o
 LIB_OBJS += commit-graph.o
+LIB_OBJS += commit-reach.o
 LIB_OBJS += compat/obstack.o
 LIB_OBJS += compat/terminal.o
 LIB_OBJS += config.o
@@ -840,6 +863,7 @@ LIB_OBJS += csum-file.o
 LIB_OBJS += ctype.o
 LIB_OBJS += date.o
 LIB_OBJS += decorate.o
+LIB_OBJS += delta-islands.o
 LIB_OBJS += diffcore-break.o
 LIB_OBJS += diffcore-delta.o
 LIB_OBJS += diffcore-order.o
@@ -859,7 +883,7 @@ LIB_OBJS += ewah/ewah_bitmap.o
 LIB_OBJS += ewah/ewah_io.o
 LIB_OBJS += ewah/ewah_rlw.o
 LIB_OBJS += exec-cmd.o
-LIB_OBJS += fetch-object.o
+LIB_OBJS += fetch-negotiator.o
 LIB_OBJS += fetch-pack.o
 LIB_OBJS += fsck.o
 LIB_OBJS += fsmonitor.o
@@ -868,9 +892,12 @@ LIB_OBJS += gpg-interface.o
 LIB_OBJS += graph.o
 LIB_OBJS += grep.o
 LIB_OBJS += hashmap.o
+LIB_OBJS += linear-assignment.o
 LIB_OBJS += help.o
 LIB_OBJS += hex.o
 LIB_OBJS += ident.o
+LIB_OBJS += interdiff.o
+LIB_OBJS += json-writer.o
 LIB_OBJS += kwset.o
 LIB_OBJS += levenshtein.o
 LIB_OBJS += line-log.o
@@ -890,7 +917,10 @@ LIB_OBJS += merge.o
 LIB_OBJS += merge-blobs.o
 LIB_OBJS += merge-recursive.o
 LIB_OBJS += mergesort.o
+LIB_OBJS += midx.o
 LIB_OBJS += name-hash.o
+LIB_OBJS += negotiator/default.o
+LIB_OBJS += negotiator/skipping.o
 LIB_OBJS += notes.o
 LIB_OBJS += notes-cache.o
 LIB_OBJS += notes-merge.o
@@ -917,11 +947,14 @@ LIB_OBJS += preload-index.o
 LIB_OBJS += pretty.o
 LIB_OBJS += prio-queue.o
 LIB_OBJS += progress.o
+LIB_OBJS += promisor-remote.o
 LIB_OBJS += prompt.o
 LIB_OBJS += protocol.o
 LIB_OBJS += quote.o
+LIB_OBJS += range-diff.o
 LIB_OBJS += reachable.o
 LIB_OBJS += read-cache.o
+LIB_OBJS += rebase-interactive.o
 LIB_OBJS += reflog-walk.o
 LIB_OBJS += refs.o
 LIB_OBJS += refs/files-backend.o
@@ -932,6 +965,7 @@ LIB_OBJS += refspec.o
 LIB_OBJS += ref-filter.o
 LIB_OBJS += remote.o
 LIB_OBJS += replace-object.o
+LIB_OBJS += repo-settings.o
 LIB_OBJS += repository.o
 LIB_OBJS += rerere.o
 LIB_OBJS += resolve-undo.o
@@ -950,6 +984,7 @@ LIB_OBJS += shallow.o
 LIB_OBJS += sideband.o
 LIB_OBJS += sigchain.o
 LIB_OBJS += split-index.o
+LIB_OBJS += stable-qsort.o
 LIB_OBJS += strbuf.o
 LIB_OBJS += streaming.o
 LIB_OBJS += string-list.o
@@ -959,8 +994,20 @@ LIB_OBJS += sub-process.o
 LIB_OBJS += symlinks.o
 LIB_OBJS += tag.o
 LIB_OBJS += tempfile.o
+LIB_OBJS += thread-utils.o
 LIB_OBJS += tmp-objdir.o
 LIB_OBJS += trace.o
+LIB_OBJS += trace2.o
+LIB_OBJS += trace2/tr2_cfg.o
+LIB_OBJS += trace2/tr2_cmd_name.o
+LIB_OBJS += trace2/tr2_dst.o
+LIB_OBJS += trace2/tr2_sid.o
+LIB_OBJS += trace2/tr2_sysenv.o
+LIB_OBJS += trace2/tr2_tbuf.o
+LIB_OBJS += trace2/tr2_tgt_event.o
+LIB_OBJS += trace2/tr2_tgt_normal.o
+LIB_OBJS += trace2/tr2_tgt_perf.o
+LIB_OBJS += trace2/tr2_tls.o
 LIB_OBJS += trailer.o
 LIB_OBJS += transport.o
 LIB_OBJS += transport-helper.o
@@ -1018,6 +1065,7 @@ BUILTIN_OBJS += builtin/diff-index.o
 BUILTIN_OBJS += builtin/diff-tree.o
 BUILTIN_OBJS += builtin/diff.o
 BUILTIN_OBJS += builtin/difftool.o
+BUILTIN_OBJS += builtin/env--helper.o
 BUILTIN_OBJS += builtin/fast-export.o
 BUILTIN_OBJS += builtin/fetch-pack.o
 BUILTIN_OBJS += builtin/fetch.o
@@ -1047,6 +1095,7 @@ BUILTIN_OBJS += builtin/merge-recursive.
 BUILTIN_OBJS += builtin/merge-tree.o
 BUILTIN_OBJS += builtin/mktag.o
 BUILTIN_OBJS += builtin/mktree.o
+BUILTIN_OBJS += builtin/multi-pack-index.o
 BUILTIN_OBJS += builtin/mv.o
 BUILTIN_OBJS += builtin/name-rev.o
 BUILTIN_OBJS += builtin/notes.o
@@ -1058,8 +1107,9 @@ BUILTIN_OBJS += builtin/prune-packed.o
 BUILTIN_OBJS += builtin/prune.o
 BUILTIN_OBJS += builtin/pull.o
 BUILTIN_OBJS += builtin/push.o
+BUILTIN_OBJS += builtin/range-diff.o
 BUILTIN_OBJS += builtin/read-tree.o
-BUILTIN_OBJS += builtin/rebase--helper.o
+BUILTIN_OBJS += builtin/rebase.o
 BUILTIN_OBJS += builtin/receive-pack.o
 BUILTIN_OBJS += builtin/reflog.o
 BUILTIN_OBJS += builtin/remote.o
@@ -1074,10 +1124,12 @@ BUILTIN_OBJS += builtin/rev-parse.o
 BUILTIN_OBJS += builtin/revert.o
 BUILTIN_OBJS += builtin/rm.o
 BUILTIN_OBJS += builtin/send-pack.o
-BUILTIN_OBJS += builtin/serve.o
 BUILTIN_OBJS += builtin/shortlog.o
 BUILTIN_OBJS += builtin/show-branch.o
+BUILTIN_OBJS += builtin/show-index.o
 BUILTIN_OBJS += builtin/show-ref.o
+BUILTIN_OBJS += builtin/sparse-checkout.o
+BUILTIN_OBJS += builtin/stash.o
 BUILTIN_OBJS += builtin/stripspace.o
 BUILTIN_OBJS += builtin/submodule--helper.o
 BUILTIN_OBJS += builtin/symbolic-ref.o
@@ -1096,6 +1148,20 @@ BUILTIN_OBJS += builtin/verify-tag.o
 BUILTIN_OBJS += builtin/worktree.o
 BUILTIN_OBJS += builtin/write-tree.o
 
+# THIRD_PARTY_SOURCES is a list of patterns compatible with the
+# $(filter) and $(filter-out) family of functions. They specify source
+# files which are taken from some third-party source where we want to be
+# less strict about issues such as coding style so we don't diverge from
+# upstream unnecessarily (making merging in future changes easier).
+THIRD_PARTY_SOURCES += compat/inet_ntop.c
+THIRD_PARTY_SOURCES += compat/inet_pton.c
+THIRD_PARTY_SOURCES += compat/nedmalloc/%
+THIRD_PARTY_SOURCES += compat/obstack.%
+THIRD_PARTY_SOURCES += compat/poll/%
+THIRD_PARTY_SOURCES += compat/regex/%
+THIRD_PARTY_SOURCES += sha1collisiondetection/%
+THIRD_PARTY_SOURCES += sha1dc/%
+
 GITLIBS = common-main.o $(LIB_FILE) $(XDIFF_LIB)
 EXTLIBS =
 
@@ -1105,6 +1171,29 @@ ifeq ($(wildcard sha1collisiondetection/
 DC_SHA1_SUBMODULE = auto
 endif
 
+# Set CFLAGS, LDFLAGS and other *FLAGS variables. These might be
+# tweaked by config.* below as well as the command-line, both of
+# which'll override these defaults.
+CFLAGS = -g -O2 -Wall
+LDFLAGS =
+CC_LD_DYNPATH = -Wl,-rpath,
+BASIC_CFLAGS = -I.
+BASIC_LDFLAGS =
+
+# library flags
+ARFLAGS = rcs
+PTHREAD_CFLAGS =
+
+# For the 'sparse' target
+SPARSE_FLAGS ?=
+SP_EXTRA_FLAGS =
+
+# For the 'coccicheck' target; setting SPATCH_BATCH_SIZE higher will
+# usually result in less CPU usage at the cost of higher peak memory.
+# Setting it to 0 will feed all files in a single spatch invocation.
+SPATCH_FLAGS = --all-includes --patch .
+SPATCH_BATCH_SIZE = 1
+
 include config.mak.uname
 -include config.mak.autogen
 -include config.mak
@@ -1113,6 +1202,9 @@ ifdef DEVELOPER
 include config.mak.dev
 endif
 
+ALL_CFLAGS = $(DEVELOPER_CFLAGS) $(CPPFLAGS) $(CFLAGS)
+ALL_LDFLAGS = $(LDFLAGS)
+
 comma := ,
 empty :=
 space := $(empty) $(empty)
@@ -1123,10 +1215,14 @@ BASIC_CFLAGS += -fsanitize=$(SANITIZE) -
 BASIC_CFLAGS += -fno-omit-frame-pointer
 ifneq ($(filter undefined,$(SANITIZERS)),)
 BASIC_CFLAGS += -DNO_UNALIGNED_LOADS
+BASIC_CFLAGS += -DSHA1DC_FORCE_ALIGNED_ACCESS
 endif
 ifneq ($(filter leak,$(SANITIZERS)),)
 BASIC_CFLAGS += -DSUPPRESS_ANNOTATED_LEAKS
 endif
+ifneq ($(filter address,$(SANITIZERS)),)
+NO_REGEX = NeededForASAN
+endif
 endif
 
 ifndef sysconfdir
@@ -1164,7 +1260,7 @@ endif
 
 ifdef SANE_TOOL_PATH
 SANE_TOOL_PATH_SQ = $(subst ','\'',$(SANE_TOOL_PATH))
-BROKEN_PATH_FIX = 's|^\# @@BROKEN_PATH_FIX@@$$|git_broken_path_fix $(SANE_TOOL_PATH_SQ)|'
+BROKEN_PATH_FIX = 's|^\# @@BROKEN_PATH_FIX@@$$|git_broken_path_fix "$(SANE_TOOL_PATH_SQ)"|'
 PATH := $(SANE_TOOL_PATH):${PATH}
 else
 BROKEN_PATH_FIX = '/^\# @@BROKEN_PATH_FIX@@$$/d'
@@ -1214,16 +1310,6 @@ ifeq ($(uname_S),Darwin)
 	PTHREAD_LIBS =
 endif
 
-ifndef CC_LD_DYNPATH
-	ifdef NO_R_TO_GCC_LINKER
-		# Some gcc does not accept and pass -R to the linker to specify
-		# the runtime dynamic library path.
-		CC_LD_DYNPATH = -Wl,-rpath,
-	else
-		CC_LD_DYNPATH = -R
-	endif
-endif
-
 ifdef NO_LIBGEN_H
 	COMPAT_CFLAGS += -DNO_LIBGEN_H
 	COMPAT_OBJS += compat/basename.o
@@ -1266,24 +1352,22 @@ ifdef NO_CURL
 	REMOTE_CURL_PRIMARY =
 	REMOTE_CURL_ALIASES =
 	REMOTE_CURL_NAMES =
+	EXCLUDED_PROGRAMS += git-http-fetch git-http-push
 else
 	ifdef CURLDIR
 		# Try "-Wl,-rpath=$(CURLDIR)/$(lib)" in such a case.
 		BASIC_CFLAGS += -I$(CURLDIR)/include
-		CURL_LIBCURL = -L$(CURLDIR)/$(lib) $(CC_LD_DYNPATH)$(CURLDIR)/$(lib) -lcurl
+		CURL_LIBCURL = -L$(CURLDIR)/$(lib) $(CC_LD_DYNPATH)$(CURLDIR)/$(lib)
 	else
-		CURL_LIBCURL = -lcurl
-	endif
-	ifdef NEEDS_SSL_WITH_CURL
-		CURL_LIBCURL += -lssl
-		ifdef NEEDS_CRYPTO_WITH_SSL
-			CURL_LIBCURL += -lcrypto
-		endif
-	endif
-	ifdef NEEDS_IDN_WITH_CURL
-		CURL_LIBCURL += -lidn
+		CURL_LIBCURL =
 	endif
 
+ifdef CURL_LDFLAGS
+	CURL_LIBCURL += $(CURL_LDFLAGS)
+else
+	CURL_LIBCURL += $(shell $(CURL_CONFIG) --libs)
+endif
+
 	REMOTE_CURL_PRIMARY = git-remote-http$X
 	REMOTE_CURL_ALIASES = git-remote-https$X git-remote-ftp$X git-remote-ftps$X
 	REMOTE_CURL_NAMES = $(REMOTE_CURL_PRIMARY) $(REMOTE_CURL_ALIASES)
@@ -1293,7 +1377,11 @@ else
 	ifeq "$(curl_check)" "070908"
 		ifndef NO_EXPAT
 			PROGRAM_OBJS += http-push.o
+		else
+			EXCLUDED_PROGRAMS += git-http-push
 		endif
+	else
+		EXCLUDED_PROGRAMS += git-http-push
 	endif
 	curl_check := $(shell (echo 072200; $(CURL_CONFIG) --vernum | sed -e '/^70[BC]/s/^/0/') 2>/dev/null | sort -r | sed -ne 2p)
 	ifeq "$(curl_check)" "072200"
@@ -1365,6 +1453,9 @@ ifndef NO_ICONV
 		EXTLIBS += $(ICONV_LINK) -liconv
 	endif
 endif
+ifdef ICONV_OMITS_BOM
+	BASIC_CFLAGS += -DICONV_OMITS_BOM
+endif
 ifdef NEEDS_LIBGEN
 	EXTLIBS += -lgen
 endif
@@ -1415,13 +1506,14 @@ ifdef NO_SYMLINK_HEAD
 	BASIC_CFLAGS += -DNO_SYMLINK_HEAD
 endif
 ifdef GETTEXT_POISON
-	BASIC_CFLAGS += -DGETTEXT_POISON
+$(warning The GETTEXT_POISON option has been removed in favor of runtime GIT_TEST_GETTEXT_POISON. See t/README!)
 endif
 ifdef NO_GETTEXT
 	BASIC_CFLAGS += -DNO_GETTEXT
 	USE_GETTEXT_SCHEME ?= fallthrough
 endif
 ifdef NO_POLL
+	NO_POLL_H = YesPlease
 	NO_SYS_POLL_H = YesPlease
 	COMPAT_CFLAGS += -DNO_POLL -Icompat/poll
 	COMPAT_OBJS += compat/poll/poll.o
@@ -1460,6 +1552,9 @@ endif
 ifdef NO_SYS_SELECT_H
 	BASIC_CFLAGS += -DNO_SYS_SELECT_H
 endif
+ifdef NO_POLL_H
+	BASIC_CFLAGS += -DNO_POLL_H
+endif
 ifdef NO_SYS_POLL_H
 	BASIC_CFLAGS += -DNO_SYS_POLL_H
 endif
@@ -1532,7 +1627,10 @@ ifdef NO_INET_PTON
 	LIB_OBJS += compat/inet_pton.o
 	BASIC_CFLAGS += -DNO_INET_PTON
 endif
-ifndef NO_UNIX_SOCKETS
+ifdef NO_UNIX_SOCKETS
+	BASIC_CFLAGS += -DNO_UNIX_SOCKETS
+	EXCLUDED_PROGRAMS += git-credential-cache git-credential-cache--daemon
+else
 	LIB_OBJS += unix-socket.o
 	PROGRAM_OBJS += credential-cache.o
 	PROGRAM_OBJS += credential-cache--daemon.o
@@ -1606,6 +1704,19 @@ endif
 endif
 endif
 
+ifdef OPENSSL_SHA256
+	EXTLIBS += $(LIB_4_CRYPTO)
+	BASIC_CFLAGS += -DSHA256_OPENSSL
+else
+ifdef GCRYPT_SHA256
+	BASIC_CFLAGS += -DSHA256_GCRYPT
+	EXTLIBS += -lgcrypt
+else
+	LIB_OBJS += sha256/block/sha256.o
+	BASIC_CFLAGS += -DSHA256_BLK
+endif
+endif
+
 ifdef SHA1_MAX_BLOCK_SIZE
 	LIB_OBJS += compat/sha1-chunked.o
 	BASIC_CFLAGS += -DSHA1_MAX_BLOCK_SIZE="$(SHA1_MAX_BLOCK_SIZE)"
@@ -1623,7 +1734,6 @@ ifdef NO_GETPAGESIZE
 endif
 ifdef INTERNAL_QSORT
 	COMPAT_CFLAGS += -DINTERNAL_QSORT
-	COMPAT_OBJS += compat/qsort.o
 endif
 ifdef HAVE_ISO_QSORT_S
 	COMPAT_CFLAGS += -DHAVE_ISO_QSORT_S
@@ -1639,7 +1749,6 @@ ifdef NO_PTHREADS
 else
 	BASIC_CFLAGS += $(PTHREAD_CFLAGS)
 	EXTLIBS += $(PTHREAD_LIBS)
-	LIB_OBJS += thread-utils.o
 endif
 
 ifdef HAVE_PATHS_H
@@ -1734,6 +1843,16 @@ ifdef HAVE_WPGMPTR
 	BASIC_CFLAGS += -DHAVE_WPGMPTR
 endif
 
+ifdef FILENO_IS_A_MACRO
+	COMPAT_CFLAGS += -DFILENO_IS_A_MACRO
+	COMPAT_OBJS += compat/fileno.o
+endif
+
+ifdef NEED_ACCESS_ROOT_HANDLER
+	COMPAT_CFLAGS += -DNEED_ACCESS_ROOT_HANDLER
+	COMPAT_OBJS += compat/access.o
+endif
+
 ifeq ($(TCLTK_PATH),)
 NO_TCLTK = NoThanks
 endif
@@ -1771,7 +1890,9 @@ ifndef V
 	QUIET_MSGFMT   = @echo '   ' MSGFMT $@;
 	QUIET_GCOV     = @echo '   ' GCOV $@;
 	QUIET_SP       = @echo '   ' SP $<;
+	QUIET_HDR      = @echo '   ' HDR $(<:hcc=h);
 	QUIET_RC       = @echo '   ' RC $@;
+	QUIET_SPATCH   = @echo '   ' SPATCH $<;
 	QUIET_SUBDIR0  = +@subdir=
 	QUIET_SUBDIR1  = ;$(NO_SUBDIR) echo '   ' SUBDIR $$subdir; \
 			 $(MAKE) $(PRINT_DIR) -C $$subdir
@@ -2020,8 +2141,9 @@ version.sp version.s version.o: GIT-VERS
 version.sp version.s version.o: EXTRA_CPPFLAGS = \
 	'-DGIT_VERSION="$(GIT_VERSION)"' \
 	'-DGIT_USER_AGENT=$(GIT_USER_AGENT_CQ_SQ)' \
-	'-DGIT_BUILT_FROM_COMMIT="$(shell GIT_CEILING_DIRECTORIES=\"$(CURDIR)/..\" \
-		git rev-parse -q --verify HEAD || :)"'
+	'-DGIT_BUILT_FROM_COMMIT="$(shell \
+		GIT_CEILING_DIRECTORIES="$(CURDIR)/.." \
+		git rev-parse -q --verify HEAD 2>/dev/null)"'
 
 $(BUILT_INS): git$X
 	$(QUIET_BUILT_IN)$(RM) $@ && \
@@ -2031,8 +2153,10 @@ $(BUILT_INS): git$X
 
 command-list.h: generate-cmdlist.sh command-list.txt
 
-command-list.h: $(wildcard Documentation/git*.txt)
-	$(QUIET_GEN)$(SHELL_PATH) ./generate-cmdlist.sh command-list.txt >$@+ && mv $@+ $@
+command-list.h: $(wildcard Documentation/git*.txt) Documentation/*config.txt Documentation/config/*.txt
+	$(QUIET_GEN)$(SHELL_PATH) ./generate-cmdlist.sh \
+		$(patsubst %,--exclude-program %,$(EXCLUDED_PROGRAMS)) \
+		command-list.txt >$@+ && mv $@+ $@
 
 SCRIPT_DEFINES = $(SHELL_PATH_SQ):$(DIFF_SQ):$(GIT_VERSION):\
 	$(localedir_SQ):$(NO_CURL):$(USE_GETTEXT_SCHEME):$(SANE_TOOL_PATH_SQ):\
@@ -2071,7 +2195,7 @@ $(SCRIPT_LIB) : % : %.sh GIT-SCRIPT-DEFI
 	$(QUIET_GEN)$(cmd_munge_script) && \
 	mv $@+ $@
 
-git.res: git.rc GIT-VERSION-FILE
+git.res: git.rc GIT-VERSION-FILE GIT-PREFIX
 	$(QUIET_RC)$(RC) \
 	  $(join -DMAJOR= -DMINOR= -DMICRO= -DPATCHLEVEL=, $(wordlist 1, 4, \
 	    $(shell echo $(GIT_VERSION) 0 0 0 0 | tr '.a-zA-Z-' ' '))) \
@@ -2109,7 +2233,7 @@ $(SCRIPT_PERL_GEN): % : %.perl GIT-PERL-
 	$(QUIET_GEN)$(RM) $@ $@+ && \
 	sed -e '1{' \
 	    -e '	s|#!.*perl|#!$(PERL_PATH_SQ)|' \
-	    -e '	rGIT-PERL-HEADER' \
+	    -e '	r GIT-PERL-HEADER' \
 	    -e '	G' \
 	    -e '}' \
 	    -e 's/@@GIT_VERSION@@/$(GIT_VERSION)/g' \
@@ -2226,6 +2350,7 @@ TEST_OBJS := $(patsubst %$X,%.o,$(TEST_P
 OBJECTS := $(LIB_OBJS) $(BUILTIN_OBJS) $(PROGRAM_OBJS) $(TEST_OBJS) \
 	$(XDIFF_OBJS) \
 	$(VCSSVN_OBJS) \
+	$(FUZZ_OBJS) \
 	common-main.o \
 	git.o
 ifndef NO_CURL
@@ -2279,7 +2404,7 @@ else
 # should _not_ be included here, since they are necessary even when
 # building an object for the first time.
 
-$(OBJECTS): $(LIB_H)
+$(OBJECTS): $(LIB_H) $(GENERATED_H)
 endif
 
 exec-cmd.sp exec-cmd.s exec-cmd.o: GIT-PREFIX
@@ -2305,10 +2430,10 @@ gettext.sp gettext.s gettext.o: GIT-PREF
 gettext.sp gettext.s gettext.o: EXTRA_CPPFLAGS = \
 	-DGIT_LOCALE_PATH='"$(localedir_relative_SQ)"'
 
-http-push.sp http.sp http-walker.sp remote-curl.sp imap-send.sp: SPARSE_FLAGS += \
+http-push.sp http.sp http-walker.sp remote-curl.sp imap-send.sp: SP_EXTRA_FLAGS += \
 	-DCURL_DISABLE_TYPECHECK
 
-pack-revindex.sp: SPARSE_FLAGS += -Wno-memcpy-max-count
+pack-revindex.sp: SP_EXTRA_FLAGS += -Wno-memcpy-max-count
 
 ifdef NO_EXPAT
 http-walker.sp http-walker.s http-walker.o: EXTRA_CPPFLAGS = -DNO_EXPAT
@@ -2322,7 +2447,7 @@ endif
 ifdef USE_NED_ALLOCATOR
 compat/nedmalloc/nedmalloc.sp compat/nedmalloc/nedmalloc.o: EXTRA_CPPFLAGS = \
 	-DNDEBUG -DREPLACE_SYSTEM_ALLOCATOR
-compat/nedmalloc/nedmalloc.sp: SPARSE_FLAGS += -Wno-non-pointer-null
+compat/nedmalloc/nedmalloc.sp: SP_EXTRA_FLAGS += -Wno-non-pointer-null
 endif
 
 git-%$X: %.o GIT-LDFLAGS $(GITLIBS)
@@ -2364,6 +2489,14 @@ $(VCSSVN_LIB): $(VCSSVN_OBJS)
 
 export DEFAULT_EDITOR DEFAULT_PAGER
 
+Documentation/GIT-EXCLUDED-PROGRAMS: FORCE
+	@EXCLUDED='EXCLUDED_PROGRAMS := $(EXCLUDED_PROGRAMS)'; \
+	    if test x"$$EXCLUDED" != \
+		x"`cat Documentation/GIT-EXCLUDED-PROGRAMS 2>/dev/null`" ; then \
+		echo >&2 "    * new documentation flags"; \
+		echo "$$EXCLUDED" >Documentation/GIT-EXCLUDED-PROGRAMS; \
+            fi
+
 .PHONY: doc man man-perl html info pdf
 doc: man-perl
 	$(MAKE) -C Documentation all
@@ -2396,7 +2529,7 @@ XGETTEXT_FLAGS_PERL = $(XGETTEXT_FLAGS)
 LOCALIZED_C = $(C_OBJ:o=c) $(LIB_H) $(GENERATED_H)
 LOCALIZED_SH = $(SCRIPT_SH)
 LOCALIZED_SH += git-parse-remote.sh
-LOCALIZED_SH += git-rebase--interactive.sh
+LOCALIZED_SH += git-rebase--preserve-merges.sh
 LOCALIZED_SH += git-sh-setup.sh
 LOCALIZED_PERL = $(SCRIPT_PERL)
 
@@ -2486,6 +2619,7 @@ FIND_SOURCE_FILES = ( \
 		-o \( -name 'trash*' -type d -prune \) \
 		-o \( -name '*.[hcS]' -type f -print \) \
 		-o \( -name '*.sh' -type f -print \) \
+		| sed -e 's|^\./||' \
 	)
 
 $(ETAGS_TARGET): FORCE
@@ -2550,6 +2684,7 @@ GIT-BUILD-OPTIONS: FORCE
 	@echo NO_UNIX_SOCKETS=\''$(subst ','\'',$(subst ','\'',$(NO_UNIX_SOCKETS)))'\' >>$@+
 	@echo PAGER_ENV=\''$(subst ','\'',$(subst ','\'',$(PAGER_ENV)))'\' >>$@+
 	@echo DC_SHA1=\''$(subst ','\'',$(subst ','\'',$(DC_SHA1)))'\' >>$@+
+	@echo X=\'$(X)\' >>$@+
 ifdef TEST_OUTPUT_DIRECTORY
 	@echo TEST_OUTPUT_DIRECTORY=\''$(subst ','\'',$(subst ','\'',$(TEST_OUTPUT_DIRECTORY)))'\' >>$@+
 endif
@@ -2563,7 +2698,6 @@ ifdef GIT_TEST_CMP_USE_COPIED_CONTEXT
 	@echo GIT_TEST_CMP_USE_COPIED_CONTEXT=YesPlease >>$@+
 endif
 	@echo NO_GETTEXT=\''$(subst ','\'',$(subst ','\'',$(NO_GETTEXT)))'\' >>$@+
-	@echo GETTEXT_POISON=\''$(subst ','\'',$(subst ','\'',$(GETTEXT_POISON)))'\' >>$@+
 ifdef GIT_PERF_REPEAT_COUNT
 	@echo GIT_PERF_REPEAT_COUNT=\''$(subst ','\'',$(subst ','\'',$(GIT_PERF_REPEAT_COUNT)))'\' >>$@+
 endif
@@ -2582,8 +2716,8 @@ endif
 ifdef GIT_INTEROP_MAKE_OPTS
 	@echo GIT_INTEROP_MAKE_OPTS=\''$(subst ','\'',$(subst ','\'',$(GIT_INTEROP_MAKE_OPTS)))'\' >>$@+
 endif
-ifdef TEST_GIT_INDEX_VERSION
-	@echo TEST_GIT_INDEX_VERSION=\''$(subst ','\'',$(subst ','\'',$(TEST_GIT_INDEX_VERSION)))'\' >>$@+
+ifdef GIT_TEST_INDEX_VERSION
+	@echo GIT_TEST_INDEX_VERSION=\''$(subst ','\'',$(subst ','\'',$(GIT_TEST_INDEX_VERSION)))'\' >>$@+
 endif
 	@if cmp $@+ $@ >/dev/null 2>&1; then $(RM) $@+; else mv $@+ $@; fi
 
@@ -2602,13 +2736,12 @@ endif
 test_bindir_programs := $(patsubst %,bin-wrappers/%,$(BINDIR_PROGRAMS_NEED_X) $(BINDIR_PROGRAMS_NO_X) $(TEST_PROGRAMS_NEED_X))
 
 all:: $(TEST_PROGRAMS) $(test_bindir_programs)
-all:: $(NO_INSTALL)
 
 bin-wrappers/%: wrap-for-bin.sh
 	@mkdir -p bin-wrappers
 	$(QUIET_GEN)sed -e '1s|#!.*/sh|#!$(SHELL_PATH_SQ)|' \
 	     -e 's|@@BUILD_DIR@@|$(shell pwd)|' \
-	     -e 's|@@PROG@@|$(patsubst test-%,t/helper/test-%,$(@F))|' < $< > $@ && \
+	     -e 's|@@PROG@@|$(patsubst test-%,t/helper/test-%$(X),$(@F))$(patsubst git%,$(X),$(filter $(@F),$(BINDIR_PROGRAMS_NEED_X)))|' < $< > $@ && \
 	chmod +x $@
 
 # GNU make supports exporting all variables by "export" without parameters.
@@ -2646,11 +2779,29 @@ SP_OBJ = $(patsubst %.o,%.sp,$(C_OBJ))
 
 $(SP_OBJ): %.sp: %.c GIT-CFLAGS FORCE
 	$(QUIET_SP)cgcc -no-compile $(ALL_CFLAGS) $(EXTRA_CPPFLAGS) \
-		$(SPARSE_FLAGS) $<
+		$(SPARSE_FLAGS) $(SP_EXTRA_FLAGS) $<
 
 .PHONY: sparse $(SP_OBJ)
 sparse: $(SP_OBJ)
 
+EXCEPT_HDRS := command-list.h unicode-width.h compat/% xdiff/%
+ifndef GCRYPT_SHA256
+	EXCEPT_HDRS += sha256/gcrypt.h
+endif
+CHK_HDRS = $(filter-out $(EXCEPT_HDRS),$(LIB_H))
+HCO = $(patsubst %.h,%.hco,$(CHK_HDRS))
+HCC = $(HCO:hco=hcc)
+
+%.hcc: %.h
+	@echo '#include "git-compat-util.h"' >$@
+	@echo '#include "$<"' >>$@
+
+$(HCO): %.hco: %.hcc FORCE
+	$(QUIET_HDR)$(CC) $(ALL_CFLAGS) -o /dev/null -c -xc $<
+
+.PHONY: hdr-check $(HCO)
+hdr-check: $(HCO)
+
 .PHONY: style
 style:
 	git clang-format --style file --diff --extensions c,h
@@ -2665,15 +2816,19 @@ check: command-list.h
 		exit 1; \
 	fi
 
-C_SOURCES = $(patsubst %.o,%.c,$(C_OBJ))
-%.cocci.patch: %.cocci $(C_SOURCES)
-	@echo '    ' SPATCH $<; \
-	ret=0; \
-	for f in $(C_SOURCES); do \
-		$(SPATCH) --sp-file $< $$f $(SPATCH_FLAGS) || \
-			{ ret=$$?; break; }; \
-	done >$@+ 2>$@.log; \
-	if test $$ret != 0; \
+FOUND_C_SOURCES = $(filter %.c,$(shell $(FIND_SOURCE_FILES)))
+COCCI_SOURCES = $(filter-out $(THIRD_PARTY_SOURCES),$(FOUND_C_SOURCES))
+
+%.cocci.patch: %.cocci $(COCCI_SOURCES)
+	$(QUIET_SPATCH) \
+	if test $(SPATCH_BATCH_SIZE) = 0; then \
+		limit=; \
+	else \
+		limit='-n $(SPATCH_BATCH_SIZE)'; \
+	fi; \
+	if ! echo $(COCCI_SOURCES) | xargs $$limit \
+		$(SPATCH) --sp-file $< $(SPATCH_FLAGS) \
+		>$@+ 2>$@.log; \
 	then \
 		cat $@.log; \
 		exit 1; \
@@ -2683,7 +2838,12 @@ C_SOURCES = $(patsubst %.o,%.c,$(C_OBJ))
 	then \
 		echo '    ' SPATCH result: $@; \
 	fi
-coccicheck: $(patsubst %.cocci,%.cocci.patch,$(wildcard contrib/coccinelle/*.cocci))
+coccicheck: $(addsuffix .patch,$(filter-out %.pending.cocci,$(wildcard contrib/coccinelle/*.cocci)))
+
+# See contrib/coccinelle/README
+coccicheck-pending: $(addsuffix .patch,$(wildcard contrib/coccinelle/*.pending.cocci))
+
+.PHONY: coccicheck coccicheck-pending
 
 ### Installation rules
 
@@ -2724,6 +2884,33 @@ install: all
 	$(INSTALL) $(ALL_PROGRAMS) '$(DESTDIR_SQ)$(gitexec_instdir_SQ)'
 	$(INSTALL) -m 644 $(SCRIPT_LIB) '$(DESTDIR_SQ)$(gitexec_instdir_SQ)'
 	$(INSTALL) $(install_bindir_programs) '$(DESTDIR_SQ)$(bindir_SQ)'
+ifdef MSVC
+	# We DO NOT install the individual foo.o.pdb files because they
+	# have already been rolled up into the exe's pdb file.
+	# We DO NOT have pdb files for the builtin commands (like git-status.exe)
+	# because it is just a copy/hardlink of git.exe, rather than a unique binary.
+	$(INSTALL) git.pdb '$(DESTDIR_SQ)$(bindir_SQ)'
+	$(INSTALL) git-shell.pdb '$(DESTDIR_SQ)$(bindir_SQ)'
+	$(INSTALL) git-upload-pack.pdb '$(DESTDIR_SQ)$(bindir_SQ)'
+	$(INSTALL) git-credential-store.pdb '$(DESTDIR_SQ)$(gitexec_instdir_SQ)'
+	$(INSTALL) git-daemon.pdb '$(DESTDIR_SQ)$(gitexec_instdir_SQ)'
+	$(INSTALL) git-fast-import.pdb '$(DESTDIR_SQ)$(gitexec_instdir_SQ)'
+	$(INSTALL) git-http-backend.pdb '$(DESTDIR_SQ)$(gitexec_instdir_SQ)'
+	$(INSTALL) git-http-fetch.pdb '$(DESTDIR_SQ)$(gitexec_instdir_SQ)'
+	$(INSTALL) git-http-push.pdb '$(DESTDIR_SQ)$(gitexec_instdir_SQ)'
+	$(INSTALL) git-imap-send.pdb '$(DESTDIR_SQ)$(gitexec_instdir_SQ)'
+	$(INSTALL) git-remote-http.pdb '$(DESTDIR_SQ)$(gitexec_instdir_SQ)'
+	$(INSTALL) git-remote-testsvn.pdb '$(DESTDIR_SQ)$(gitexec_instdir_SQ)'
+	$(INSTALL) git-sh-i18n--envsubst.pdb '$(DESTDIR_SQ)$(gitexec_instdir_SQ)'
+	$(INSTALL) git-show-index.pdb '$(DESTDIR_SQ)$(gitexec_instdir_SQ)'
+ifndef DEBUG
+	$(INSTALL) $(vcpkg_rel_bin)/*.dll '$(DESTDIR_SQ)$(bindir_SQ)'
+	$(INSTALL) $(vcpkg_rel_bin)/*.pdb '$(DESTDIR_SQ)$(bindir_SQ)'
+else
+	$(INSTALL) $(vcpkg_dbg_bin)/*.dll '$(DESTDIR_SQ)$(bindir_SQ)'
+	$(INSTALL) $(vcpkg_dbg_bin)/*.pdb '$(DESTDIR_SQ)$(bindir_SQ)'
+endif
+endif
 	$(MAKE) -C templates DESTDIR='$(DESTDIR_SQ)' install
 	$(INSTALL) -d -m 755 '$(DESTDIR_SQ)$(mergetools_instdir_SQ)'
 	$(INSTALL) -m 644 mergetools/* '$(DESTDIR_SQ)$(mergetools_instdir_SQ)'
@@ -2862,6 +3049,20 @@ rpm::
 	@false
 .PHONY: rpm
 
+ifneq ($(INCLUDE_DLLS_IN_ARTIFACTS),)
+OTHER_PROGRAMS += $(shell echo *.dll t/helper/*.dll)
+endif
+
+artifacts-tar:: $(ALL_PROGRAMS) $(SCRIPT_LIB) $(BUILT_INS) $(OTHER_PROGRAMS) \
+		GIT-BUILD-OPTIONS $(TEST_PROGRAMS) $(test_bindir_programs) \
+		$(MOFILES)
+	$(QUIET_SUBDIR0)templates $(QUIET_SUBDIR1) \
+		SHELL_PATH='$(SHELL_PATH_SQ)' PERL_PATH='$(PERL_PATH_SQ)'
+	test -n "$(ARTIFACTS_DIRECTORY)"
+	mkdir -p "$(ARTIFACTS_DIRECTORY)"
+	$(TAR) czf "$(ARTIFACTS_DIRECTORY)/artifacts.tar.gz" $^ templates/blt/
+.PHONY: artifacts-tar
+
 htmldocs = git-htmldocs-$(GIT_VERSION)
 manpages = git-manpages-$(GIT_VERSION)
 .PHONY: dist-doc distclean
@@ -2895,20 +3096,25 @@ profile-clean:
 	$(RM) $(addsuffix *.gcda,$(addprefix $(PROFILE_DIR)/, $(object_dirs)))
 	$(RM) $(addsuffix *.gcno,$(addprefix $(PROFILE_DIR)/, $(object_dirs)))
 
-clean: profile-clean coverage-clean
+cocciclean:
+	$(RM) contrib/coccinelle/*.cocci.patch*
+
+clean: profile-clean coverage-clean cocciclean
 	$(RM) *.res
 	$(RM) $(OBJECTS)
 	$(RM) $(LIB_FILE) $(XDIFF_LIB) $(VCSSVN_LIB)
 	$(RM) $(ALL_PROGRAMS) $(SCRIPT_LIB) $(BUILT_INS) git$X
-	$(RM) $(TEST_PROGRAMS) $(NO_INSTALL)
+	$(RM) $(TEST_PROGRAMS)
+	$(RM) $(FUZZ_PROGRAMS)
+	$(RM) $(HCC)
 	$(RM) -r bin-wrappers $(dep_dirs)
 	$(RM) -r po/build/
-	$(RM) *.pyc *.pyo */*.pyc */*.pyo command-list.h $(ETAGS_TARGET) tags cscope*
+	$(RM) *.pyc *.pyo */*.pyc */*.pyo $(GENERATED_H) $(ETAGS_TARGET) tags cscope*
 	$(RM) -r $(GIT_TARNAME) .doc-tmp-dir
 	$(RM) $(GIT_TARNAME).tar.gz git-core_$(GIT_VERSION)-*.tar.gz
 	$(RM) $(htmldocs).tar.gz $(manpages).tar.gz
-	$(RM) contrib/coccinelle/*.cocci.patch*
 	$(MAKE) -C Documentation/ clean
+	$(RM) Documentation/GIT-EXCLUDED-PROGRAMS
 ifndef NO_PERL
 	$(MAKE) -C gitweb clean
 	$(RM) -r perl/build/
@@ -2922,8 +3128,21 @@ endif
 	$(RM) GIT-VERSION-FILE GIT-CFLAGS GIT-LDFLAGS GIT-BUILD-OPTIONS
 	$(RM) GIT-USER-AGENT GIT-PREFIX
 	$(RM) GIT-SCRIPT-DEFINES GIT-PERL-DEFINES GIT-PERL-HEADER GIT-PYTHON-VARS
+ifdef MSVC
+	$(RM) $(patsubst %.o,%.o.pdb,$(OBJECTS))
+	$(RM) $(patsubst %.exe,%.pdb,$(OTHER_PROGRAMS))
+	$(RM) $(patsubst %.exe,%.iobj,$(OTHER_PROGRAMS))
+	$(RM) $(patsubst %.exe,%.ipdb,$(OTHER_PROGRAMS))
+	$(RM) $(patsubst %.exe,%.pdb,$(PROGRAMS))
+	$(RM) $(patsubst %.exe,%.iobj,$(PROGRAMS))
+	$(RM) $(patsubst %.exe,%.ipdb,$(PROGRAMS))
+	$(RM) $(patsubst %.exe,%.pdb,$(TEST_PROGRAMS))
+	$(RM) $(patsubst %.exe,%.iobj,$(TEST_PROGRAMS))
+	$(RM) $(patsubst %.exe,%.ipdb,$(TEST_PROGRAMS))
+	$(RM) compat/vcbuild/MSVC-DEFS-GEN
+endif
 
-.PHONY: all install profile-clean clean strip
+.PHONY: all install profile-clean cocciclean clean strip
 .PHONY: shell_compatibility_test please_set_SHELL_PATH_to_a_more_modern_shell
 .PHONY: FORCE cscope
 
@@ -2938,13 +3157,13 @@ ALL_COMMANDS += git-gui git-citool
 .PHONY: check-docs
 check-docs::
 	$(MAKE) -C Documentation lint-docs
-	@(for v in $(ALL_COMMANDS); \
+	@(for v in $(patsubst %$X,%,$(ALL_COMMANDS)); \
 	do \
 		case "$$v" in \
 		git-merge-octopus | git-merge-ours | git-merge-recursive | \
 		git-merge-resolve | git-merge-subtree | \
 		git-fsck-objects | git-init-db | \
-		git-remote-* | git-stage | \
+		git-remote-* | git-stage | git-legacy-* | \
 		git-?*--?* ) continue ;; \
 		esac ; \
 		test -f "Documentation/$$v.txt" || \
@@ -2959,15 +3178,16 @@ check-docs::
 	( \
 		sed -e '1,/^### command list/d' \
 		    -e '/^#/d' \
+		    -e '/guide$$/d' \
 		    -e 's/[ 	].*//' \
 		    -e 's/^/listed /' command-list.txt; \
 		$(MAKE) -C Documentation print-man1 | \
 		grep '\.txt$$' | \
-		sed -e 's|Documentation/|documented |' \
+		sed -e 's|^|documented |' \
 		    -e 's/\.txt//'; \
 	) | while read how cmd; \
 	do \
-		case " $(ALL_COMMANDS) " in \
+		case " $(patsubst %$X,%,$(ALL_COMMANDS) $(EXCLUDED_PROGRAMS)) " in \
 		*" $$cmd "*)	;; \
 		*) echo "removed but $$how: $$cmd" ;; \
 		esac; \
@@ -3010,6 +3230,11 @@ coverage-test: coverage-clean-results co
 	$(MAKE) CFLAGS="$(COVERAGE_CFLAGS)" LDFLAGS="$(COVERAGE_LDFLAGS)" \
 		DEFAULT_TEST_TARGET=test -j1 test
 
+coverage-prove: coverage-clean-results coverage-compile
+	$(MAKE) CFLAGS="$(COVERAGE_CFLAGS)" LDFLAGS="$(COVERAGE_LDFLAGS)" \
+		DEFAULT_TEST_TARGET=prove GIT_PROVE_OPTS="$(GIT_PROVE_OPTS) -j1" \
+		-j1 test
+
 coverage-report:
 	$(QUIET_GCOV)for dir in $(object_dirs); do \
 		$(GCOV) $(GCOVFLAGS) --object-directory=$$dir $$dir*.c || exit; \
@@ -3026,3 +3251,26 @@ cover_db: coverage-report
 cover_db_html: cover_db
 	cover -report html -outputdir cover_db_html cover_db
 
+
+### Fuzz testing
+#
+# Building fuzz targets generally requires a special set of compiler flags that
+# are not necessarily appropriate for general builds, and that vary greatly
+# depending on the compiler version used.
+#
+# An example command to build against libFuzzer from LLVM 4.0.0:
+#
+# make CC=clang CXX=clang++ \
+#      CFLAGS="-fsanitize-coverage=trace-pc-guard -fsanitize=address" \
+#      LIB_FUZZING_ENGINE=/usr/lib/llvm-4.0/lib/libFuzzer.a \
+#      fuzz-all
+#
+FUZZ_CXXFLAGS ?= $(CFLAGS)
+
+.PHONY: fuzz-all
+
+$(FUZZ_PROGRAMS): all
+	$(QUIET_LINK)$(CXX) $(FUZZ_CXXFLAGS) $(LIB_OBJS) $(BUILTIN_OBJS) \
+		$(XDIFF_OBJS) $(EXTLIBS) git.o $@.o $(LIB_FUZZING_ENGINE) -o $@
+
+fuzz-all: $(FUZZ_PROGRAMS)
diff -pruN 1.2.1+git2.18.0-1/git/match-trees.c 1.2.3+git2.25.1-1/git/match-trees.c
--- 1.2.1+git2.18.0-1/git/match-trees.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/match-trees.c	2020-02-17 04:47:35.000000000 +0000
@@ -1,8 +1,9 @@
 #include "cache.h"
 #include "tree.h"
 #include "tree-walk.h"
+#include "object-store.h"
 
-static int score_missing(unsigned mode, const char *path)
+static int score_missing(unsigned mode)
 {
 	int score;
 
@@ -15,7 +16,7 @@ static int score_missing(unsigned mode,
 	return score;
 }
 
-static int score_differs(unsigned mode1, unsigned mode2, const char *path)
+static int score_differs(unsigned mode1, unsigned mode2)
 {
 	int score;
 
@@ -28,7 +29,7 @@ static int score_differs(unsigned mode1,
 	return score;
 }
 
-static int score_matches(unsigned mode1, unsigned mode2, const char *path)
+static int score_matches(unsigned mode1, unsigned mode2)
 {
 	int score;
 
@@ -82,34 +83,41 @@ static int score_trees(const struct obje
 	int score = 0;
 
 	for (;;) {
-		struct name_entry e1, e2;
-		int got_entry_from_one = tree_entry(&one, &e1);
-		int got_entry_from_two = tree_entry(&two, &e2);
 		int cmp;
 
-		if (got_entry_from_one && got_entry_from_two)
-			cmp = base_name_entries_compare(&e1, &e2);
-		else if (got_entry_from_one)
+		if (one.size && two.size)
+			cmp = base_name_entries_compare(&one.entry, &two.entry);
+		else if (one.size)
 			/* two lacks this entry */
 			cmp = -1;
-		else if (got_entry_from_two)
+		else if (two.size)
 			/* two has more entries */
 			cmp = 1;
 		else
 			break;
 
-		if (cmp < 0)
+		if (cmp < 0) {
 			/* path1 does not appear in two */
-			score += score_missing(e1.mode, e1.path);
-		else if (cmp > 0)
+			score += score_missing(one.entry.mode);
+			update_tree_entry(&one);
+		} else if (cmp > 0) {
 			/* path2 does not appear in one */
-			score += score_missing(e2.mode, e2.path);
-		else if (oidcmp(e1.oid, e2.oid))
-			/* they are different */
-			score += score_differs(e1.mode, e2.mode, e1.path);
-		else
-			/* same subtree or blob */
-			score += score_matches(e1.mode, e2.mode, e1.path);
+			score += score_missing(two.entry.mode);
+			update_tree_entry(&two);
+		} else {
+			/* path appears in both */
+			if (!oideq(&one.entry.oid, &two.entry.oid)) {
+				/* they are different */
+				score += score_differs(one.entry.mode,
+						       two.entry.mode);
+			} else {
+				/* same subtree or blob */
+				score += score_matches(one.entry.mode,
+						       two.entry.mode);
+			}
+			update_tree_entry(&one);
+			update_tree_entry(&two);
+		}
 	}
 	free(one_buf);
 	free(two_buf);
@@ -132,7 +140,7 @@ static void match_trees(const struct obj
 	while (one.size) {
 		const char *path;
 		const struct object_id *elem;
-		unsigned mode;
+		unsigned short mode;
 		int score;
 
 		elem = tree_entry_extract(&one, &path, &mode);
@@ -169,7 +177,7 @@ static int splice_tree(const struct obje
 	char *buf;
 	unsigned long sz;
 	struct tree_desc desc;
-	struct object_id *rewrite_here;
+	unsigned char *rewrite_here;
 	const struct object_id *rewrite_with;
 	struct object_id subtree;
 	enum object_type type;
@@ -188,16 +196,27 @@ static int splice_tree(const struct obje
 	rewrite_here = NULL;
 	while (desc.size) {
 		const char *name;
-		unsigned mode;
-		const struct object_id *oid;
+		unsigned short mode;
 
-		oid = tree_entry_extract(&desc, &name, &mode);
+		tree_entry_extract(&desc, &name, &mode);
 		if (strlen(name) == toplen &&
 		    !memcmp(name, prefix, toplen)) {
 			if (!S_ISDIR(mode))
 				die("entry %s in tree %s is not a tree", name,
 				    oid_to_hex(oid1));
-			rewrite_here = (struct object_id *)oid;
+
+			/*
+			 * We cast here for two reasons:
+			 *
+			 *   - to flip the "char *" (for the path) to "unsigned
+			 *     char *" (for the hash stored after it)
+			 *
+			 *   - to discard the "const"; this is OK because we
+			 *     know it points into our non-const "buf"
+			 */
+			rewrite_here = (unsigned char *)(desc.entry.path +
+							 strlen(desc.entry.path) +
+							 1);
 			break;
 		}
 		update_tree_entry(&desc);
@@ -206,14 +225,16 @@ static int splice_tree(const struct obje
 		die("entry %.*s not found in tree %s", toplen, prefix,
 		    oid_to_hex(oid1));
 	if (*subpath) {
-		status = splice_tree(rewrite_here, subpath, oid2, &subtree);
+		struct object_id tree_oid;
+		hashcpy(tree_oid.hash, rewrite_here);
+		status = splice_tree(&tree_oid, subpath, oid2, &subtree);
 		if (status)
 			return status;
 		rewrite_with = &subtree;
 	} else {
 		rewrite_with = oid2;
 	}
-	oidcpy(rewrite_here, rewrite_with);
+	hashcpy(rewrite_here, rewrite_with->hash);
 	status = write_object_file(buf, sz, tree_type, result);
 	free(buf);
 	return status;
@@ -227,7 +248,8 @@ static int splice_tree(const struct obje
  * other hand, it could cover tree one and we might need to pick a
  * subtree of it.
  */
-void shift_tree(const struct object_id *hash1,
+void shift_tree(struct repository *r,
+		const struct object_id *hash1,
 		const struct object_id *hash2,
 		struct object_id *shifted,
 		int depth_limit)
@@ -264,12 +286,12 @@ void shift_tree(const struct object_id *
 
 	if (add_score < del_score) {
 		/* We need to pick a subtree of two */
-		unsigned mode;
+		unsigned short mode;
 
 		if (!*del_prefix)
 			return;
 
-		if (get_tree_entry(hash2, del_prefix, shifted, &mode))
+		if (get_tree_entry(r, hash2, del_prefix, shifted, &mode))
 			die("cannot find path %s in tree %s",
 			    del_prefix, oid_to_hex(hash2));
 		return;
@@ -286,22 +308,23 @@ void shift_tree(const struct object_id *
  * Unfortunately we cannot fundamentally tell which one to
  * be prefixed, as recursive merge can work in either direction.
  */
-void shift_tree_by(const struct object_id *hash1,
+void shift_tree_by(struct repository *r,
+		   const struct object_id *hash1,
 		   const struct object_id *hash2,
 		   struct object_id *shifted,
 		   const char *shift_prefix)
 {
 	struct object_id sub1, sub2;
-	unsigned mode1, mode2;
+	unsigned short mode1, mode2;
 	unsigned candidate = 0;
 
 	/* Can hash2 be a tree at shift_prefix in tree hash1? */
-	if (!get_tree_entry(hash1, shift_prefix, &sub1, &mode1) &&
+	if (!get_tree_entry(r, hash1, shift_prefix, &sub1, &mode1) &&
 	    S_ISDIR(mode1))
 		candidate |= 1;
 
 	/* Can hash1 be a tree at shift_prefix in tree hash2? */
-	if (!get_tree_entry(hash2, shift_prefix, &sub2, &mode2) &&
+	if (!get_tree_entry(r, hash2, shift_prefix, &sub2, &mode2) &&
 	    S_ISDIR(mode2))
 		candidate |= 2;
 
diff -pruN 1.2.1+git2.18.0-1/git/mem-pool.c 1.2.3+git2.25.1-1/git/mem-pool.c
--- 1.2.1+git2.18.0-1/git/mem-pool.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/mem-pool.c	2020-02-17 04:47:35.000000000 +0000
@@ -5,40 +5,88 @@
 #include "cache.h"
 #include "mem-pool.h"
 
-static struct mp_block *mem_pool_alloc_block(struct mem_pool *mem_pool, size_t block_alloc)
+#define BLOCK_GROWTH_SIZE 1024*1024 - sizeof(struct mp_block);
+
+/*
+ * Allocate a new mp_block and insert it after the block specified in
+ * `insert_after`. If `insert_after` is NULL, then insert block at the
+ * head of the linked list.
+ */
+static struct mp_block *mem_pool_alloc_block(struct mem_pool *mem_pool, size_t block_alloc, struct mp_block *insert_after)
 {
 	struct mp_block *p;
 
 	mem_pool->pool_alloc += sizeof(struct mp_block) + block_alloc;
 	p = xmalloc(st_add(sizeof(struct mp_block), block_alloc));
-	p->next_block = mem_pool->mp_block;
+
 	p->next_free = (char *)p->space;
 	p->end = p->next_free + block_alloc;
-	mem_pool->mp_block = p;
+
+	if (insert_after) {
+		p->next_block = insert_after->next_block;
+		insert_after->next_block = p;
+	} else {
+		p->next_block = mem_pool->mp_block;
+		mem_pool->mp_block = p;
+	}
 
 	return p;
 }
 
+void mem_pool_init(struct mem_pool **mem_pool, size_t initial_size)
+{
+	struct mem_pool *pool;
+
+	if (*mem_pool)
+		return;
+
+	pool = xcalloc(1, sizeof(*pool));
+
+	pool->block_alloc = BLOCK_GROWTH_SIZE;
+
+	if (initial_size > 0)
+		mem_pool_alloc_block(pool, initial_size, NULL);
+
+	*mem_pool = pool;
+}
+
+void mem_pool_discard(struct mem_pool *mem_pool, int invalidate_memory)
+{
+	struct mp_block *block, *block_to_free;
+
+	block = mem_pool->mp_block;
+	while (block)
+	{
+		block_to_free = block;
+		block = block->next_block;
+
+		if (invalidate_memory)
+			memset(block_to_free->space, 0xDD, ((char *)block_to_free->end) - ((char *)block_to_free->space));
+
+		free(block_to_free);
+	}
+
+	free(mem_pool);
+}
+
 void *mem_pool_alloc(struct mem_pool *mem_pool, size_t len)
 {
-	struct mp_block *p;
+	struct mp_block *p = NULL;
 	void *r;
 
 	/* round up to a 'uintmax_t' alignment */
 	if (len & (sizeof(uintmax_t) - 1))
 		len += sizeof(uintmax_t) - (len & (sizeof(uintmax_t) - 1));
 
-	for (p = mem_pool->mp_block; p; p = p->next_block)
-		if (p->end - p->next_free >= len)
-			break;
+	if (mem_pool->mp_block &&
+	    mem_pool->mp_block->end - mem_pool->mp_block->next_free >= len)
+		p = mem_pool->mp_block;
 
 	if (!p) {
-		if (len >= (mem_pool->block_alloc / 2)) {
-			mem_pool->pool_alloc += len;
-			return xmalloc(len);
-		}
+		if (len >= (mem_pool->block_alloc / 2))
+			return mem_pool_alloc_block(mem_pool, len, mem_pool->mp_block);
 
-		p = mem_pool_alloc_block(mem_pool, mem_pool->block_alloc);
+		p = mem_pool_alloc_block(mem_pool, mem_pool->block_alloc, NULL);
 	}
 
 	r = p->next_free;
@@ -53,3 +101,45 @@ void *mem_pool_calloc(struct mem_pool *m
 	memset(r, 0, len);
 	return r;
 }
+
+int mem_pool_contains(struct mem_pool *mem_pool, void *mem)
+{
+	struct mp_block *p;
+
+	/* Check if memory is allocated in a block */
+	for (p = mem_pool->mp_block; p; p = p->next_block)
+		if ((mem >= ((void *)p->space)) &&
+		    (mem < ((void *)p->end)))
+			return 1;
+
+	return 0;
+}
+
+void mem_pool_combine(struct mem_pool *dst, struct mem_pool *src)
+{
+	struct mp_block *p;
+
+	/* Append the blocks from src to dst */
+	if (dst->mp_block && src->mp_block) {
+		/*
+		 * src and dst have blocks, append
+		 * blocks from src to dst.
+		 */
+		p = dst->mp_block;
+		while (p->next_block)
+			p = p->next_block;
+
+		p->next_block = src->mp_block;
+	} else if (src->mp_block) {
+		/*
+		 * src has blocks, dst is empty.
+		 */
+		dst->mp_block = src->mp_block;
+	} else {
+		/* src is empty, nothing to do. */
+	}
+
+	dst->pool_alloc += src->pool_alloc;
+	src->pool_alloc = 0;
+	src->mp_block = NULL;
+}
diff -pruN 1.2.1+git2.18.0-1/git/mem-pool.h 1.2.3+git2.25.1-1/git/mem-pool.h
--- 1.2.1+git2.18.0-1/git/mem-pool.h	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/mem-pool.h	2020-02-17 04:47:35.000000000 +0000
@@ -22,6 +22,16 @@ struct mem_pool {
 };
 
 /*
+ * Initialize mem_pool with specified initial size.
+ */
+void mem_pool_init(struct mem_pool **mem_pool, size_t initial_size);
+
+/*
+ * Discard a memory pool and free all the memory it is responsible for.
+ */
+void mem_pool_discard(struct mem_pool *mem_pool, int invalidate_memory);
+
+/*
  * Alloc memory from the mem_pool.
  */
 void *mem_pool_alloc(struct mem_pool *pool, size_t len);
@@ -31,4 +41,17 @@ void *mem_pool_alloc(struct mem_pool *po
  */
 void *mem_pool_calloc(struct mem_pool *pool, size_t count, size_t size);
 
+/*
+ * Move the memory associated with the 'src' pool to the 'dst' pool. The 'src'
+ * pool will be empty and not contain any memory. It still needs to be free'd
+ * with a call to `mem_pool_discard`.
+ */
+void mem_pool_combine(struct mem_pool *dst, struct mem_pool *src);
+
+/*
+ * Check if a memory pointed at by 'mem' is part of the range of
+ * memory managed by the specified mem_pool.
+ */
+int mem_pool_contains(struct mem_pool *mem_pool, void *mem);
+
 #endif
diff -pruN 1.2.1+git2.18.0-1/git/merge-blobs.c 1.2.3+git2.25.1-1/git/merge-blobs.c
--- 1.2.1+git2.18.0-1/git/merge-blobs.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/merge-blobs.c	2020-02-17 04:47:35.000000000 +0000
@@ -4,6 +4,7 @@
 #include "ll-merge.h"
 #include "blob.h"
 #include "merge-blobs.h"
+#include "object-store.h"
 
 static int fill_mmfile_blob(mmfile_t *f, struct blob *obj)
 {
@@ -28,7 +29,12 @@ static void free_mmfile(mmfile_t *f)
 	free(f->ptr);
 }
 
-static void *three_way_filemerge(const char *path, mmfile_t *base, mmfile_t *our, mmfile_t *their, unsigned long *size)
+static void *three_way_filemerge(struct index_state *istate,
+				 const char *path,
+				 mmfile_t *base,
+				 mmfile_t *our,
+				 mmfile_t *their,
+				 unsigned long *size)
 {
 	int merge_status;
 	mmbuffer_t res;
@@ -40,7 +46,8 @@ static void *three_way_filemerge(const c
 	 * common ancestor.
 	 */
 	merge_status = ll_merge(&res, path, base, NULL,
-				our, ".our", their, ".their", NULL);
+				our, ".our", their, ".their",
+				istate, NULL);
 	if (merge_status < 0)
 		return NULL;
 
@@ -48,7 +55,9 @@ static void *three_way_filemerge(const c
 	return res.ptr;
 }
 
-void *merge_blobs(const char *path, struct blob *base, struct blob *our, struct blob *their, unsigned long *size)
+void *merge_blobs(struct index_state *istate, const char *path,
+		  struct blob *base, struct blob *our,
+		  struct blob *their, unsigned long *size)
 {
 	void *res = NULL;
 	mmfile_t f1, f2, common;
@@ -81,7 +90,7 @@ void *merge_blobs(const char *path, stru
 		common.ptr = xstrdup("");
 		common.size = 0;
 	}
-	res = three_way_filemerge(path, &common, &f1, &f2, size);
+	res = three_way_filemerge(istate, path, &common, &f1, &f2, size);
 	free_mmfile(&common);
 out_free_f2_f1:
 	free_mmfile(&f2);
diff -pruN 1.2.1+git2.18.0-1/git/merge-blobs.h 1.2.3+git2.25.1-1/git/merge-blobs.h
--- 1.2.1+git2.18.0-1/git/merge-blobs.h	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/merge-blobs.h	2020-02-17 04:47:35.000000000 +0000
@@ -1,8 +1,11 @@
 #ifndef MERGE_BLOBS_H
 #define MERGE_BLOBS_H
 
-#include "blob.h"
+struct blob;
+struct index_state;
 
-extern void *merge_blobs(const char *, struct blob *, struct blob *, struct blob *, unsigned long *);
+void *merge_blobs(struct index_state *, const char *,
+		  struct blob *, struct blob *,
+		  struct blob *, unsigned long *);
 
 #endif /* MERGE_BLOBS_H */
diff -pruN 1.2.1+git2.18.0-1/git/merge.c 1.2.3+git2.25.1-1/git/merge.c
--- 1.2.1+git2.18.0-1/git/merge.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/merge.c	2020-02-17 04:47:35.000000000 +0000
@@ -14,38 +14,8 @@ static const char *merge_argument(struct
 	return oid_to_hex(commit ? &commit->object.oid : the_hash_algo->empty_tree);
 }
 
-int index_has_changes(struct strbuf *sb)
-{
-	struct object_id head;
-	int i;
-
-	if (!get_oid_tree("HEAD", &head)) {
-		struct diff_options opt;
-
-		diff_setup(&opt);
-		opt.flags.exit_with_status = 1;
-		if (!sb)
-			opt.flags.quick = 1;
-		do_diff_cache(&head, &opt);
-		diffcore_std(&opt);
-		for (i = 0; sb && i < diff_queued_diff.nr; i++) {
-			if (i)
-				strbuf_addch(sb, ' ');
-			strbuf_addstr(sb, diff_queued_diff.queue[i]->two->path);
-		}
-		diff_flush(&opt);
-		return opt.flags.has_changes != 0;
-	} else {
-		for (i = 0; sb && i < active_nr; i++) {
-			if (i)
-				strbuf_addch(sb, ' ');
-			strbuf_addstr(sb, active_cache[i]->name);
-		}
-		return !!active_nr;
-	}
-}
-
-int try_merge_command(const char *strategy, size_t xopts_nr,
+int try_merge_command(struct repository *r,
+		      const char *strategy, size_t xopts_nr,
 		      const char **xopts, struct commit_list *common,
 		      const char *head_arg, struct commit_list *remotes)
 {
@@ -66,15 +36,16 @@ int try_merge_command(const char *strate
 	ret = run_command_v_opt(args.argv, RUN_GIT_CMD);
 	argv_array_clear(&args);
 
-	discard_cache();
-	if (read_cache() < 0)
+	discard_index(r->index);
+	if (repo_read_index(r) < 0)
 		die(_("failed to read the cache"));
-	resolve_undo_clear();
+	resolve_undo_clear_index(r->index);
 
 	return ret;
 }
 
-int checkout_fast_forward(const struct object_id *head,
+int checkout_fast_forward(struct repository *r,
+			  const struct object_id *head,
 			  const struct object_id *remote,
 			  int overwrite_ignore)
 {
@@ -85,9 +56,9 @@ int checkout_fast_forward(const struct o
 	struct dir_struct dir;
 	struct lock_file lock_file = LOCK_INIT;
 
-	refresh_cache(REFRESH_QUIET);
+	refresh_index(r->index, REFRESH_QUIET, NULL, NULL, NULL);
 
-	if (hold_locked_index(&lock_file, LOCK_REPORT_ON_ERROR) < 0)
+	if (repo_hold_locked_index(r, &lock_file, LOCK_REPORT_ON_ERROR) < 0)
 		return -1;
 
 	memset(&trees, 0, sizeof(trees));
@@ -117,8 +88,8 @@ int checkout_fast_forward(const struct o
 	}
 
 	opts.head_idx = 1;
-	opts.src_index = &the_index;
-	opts.dst_index = &the_index;
+	opts.src_index = r->index;
+	opts.dst_index = r->index;
 	opts.update = 1;
 	opts.verbose_update = 1;
 	opts.merge = 1;
@@ -132,7 +103,7 @@ int checkout_fast_forward(const struct o
 	}
 	clear_unpack_trees_porcelain(&opts);
 
-	if (write_locked_index(&the_index, &lock_file, COMMIT_LOCK))
+	if (write_locked_index(r->index, &lock_file, COMMIT_LOCK))
 		return error(_("unable to write new index file"));
 	return 0;
 }
diff -pruN 1.2.1+git2.18.0-1/git/merge-recursive.c 1.2.3+git2.25.1-1/git/merge-recursive.c
--- 1.2.1+git2.18.0-1/git/merge-recursive.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/merge-recursive.c	2020-02-17 04:47:35.000000000 +0000
@@ -4,26 +4,40 @@
  * The thieves were Alex Riesen and Johannes Schindelin, in June/July 2006
  */
 #include "cache.h"
-#include "config.h"
+#include "merge-recursive.h"
+
 #include "advice.h"
-#include "lockfile.h"
-#include "cache-tree.h"
-#include "commit.h"
+#include "alloc.h"
+#include "attr.h"
 #include "blob.h"
 #include "builtin.h"
-#include "tree-walk.h"
+#include "cache-tree.h"
+#include "commit.h"
+#include "commit-reach.h"
+#include "config.h"
 #include "diff.h"
 #include "diffcore.h"
+#include "dir.h"
+#include "ll-merge.h"
+#include "lockfile.h"
+#include "object-store.h"
+#include "repository.h"
+#include "revision.h"
+#include "string-list.h"
+#include "submodule.h"
 #include "tag.h"
+#include "tree-walk.h"
 #include "unpack-trees.h"
-#include "string-list.h"
 #include "xdiff-interface.h"
-#include "ll-merge.h"
-#include "attr.h"
-#include "merge-recursive.h"
-#include "dir.h"
-#include "submodule.h"
-#include "revision.h"
+
+struct merge_options_internal {
+	int call_depth;
+	int needed_rename_limit;
+	struct hashmap current_file_dir_set;
+	struct string_list df_conflict_file_set;
+	struct unpack_trees_options unpack_opts;
+	struct index_state orig_index;
+};
 
 struct path_hashmap_entry {
 	struct hashmap_entry e;
@@ -31,14 +45,16 @@ struct path_hashmap_entry {
 };
 
 static int path_hashmap_cmp(const void *cmp_data,
-			    const void *entry,
-			    const void *entry_or_key,
+			    const struct hashmap_entry *eptr,
+			    const struct hashmap_entry *entry_or_key,
 			    const void *keydata)
 {
-	const struct path_hashmap_entry *a = entry;
-	const struct path_hashmap_entry *b = entry_or_key;
+	const struct path_hashmap_entry *a, *b;
 	const char *key = keydata;
 
+	a = container_of(eptr, const struct path_hashmap_entry, e);
+	b = container_of(entry_or_key, const struct path_hashmap_entry, e);
+
 	if (ignore_case)
 		return strcasecmp(a->path, key ? key : b->path);
 	else
@@ -50,6 +66,24 @@ static unsigned int path_hash(const char
 	return ignore_case ? strihash(path) : strhash(path);
 }
 
+/*
+ * For dir_rename_entry, directory names are stored as a full path from the
+ * toplevel of the repository and do not include a trailing '/'.  Also:
+ *
+ *   dir:                original name of directory being renamed
+ *   non_unique_new_dir: if true, could not determine new_dir
+ *   new_dir:            final name of directory being renamed
+ *   possible_new_dirs:  temporary used to help determine new_dir; see comments
+ *                       in get_directory_renames() for details
+ */
+struct dir_rename_entry {
+	struct hashmap_entry ent;
+	char *dir;
+	unsigned non_unique_new_dir:1;
+	struct strbuf new_dir;
+	struct string_list possible_new_dirs;
+};
+
 static struct dir_rename_entry *dir_rename_find_entry(struct hashmap *hashmap,
 						      char *dir)
 {
@@ -57,18 +91,20 @@ static struct dir_rename_entry *dir_rena
 
 	if (dir == NULL)
 		return NULL;
-	hashmap_entry_init(&key, strhash(dir));
+	hashmap_entry_init(&key.ent, strhash(dir));
 	key.dir = dir;
-	return hashmap_get(hashmap, &key, NULL);
+	return hashmap_get_entry(hashmap, &key, ent, NULL);
 }
 
 static int dir_rename_cmp(const void *unused_cmp_data,
-			  const void *entry,
-			  const void *entry_or_key,
+			  const struct hashmap_entry *eptr,
+			  const struct hashmap_entry *entry_or_key,
 			  const void *unused_keydata)
 {
-	const struct dir_rename_entry *e1 = entry;
-	const struct dir_rename_entry *e2 = entry_or_key;
+	const struct dir_rename_entry *e1, *e2;
+
+	e1 = container_of(eptr, const struct dir_rename_entry, ent);
+	e2 = container_of(entry_or_key, const struct dir_rename_entry, ent);
 
 	return strcmp(e1->dir, e2->dir);
 }
@@ -81,264 +117,293 @@ static void dir_rename_init(struct hashm
 static void dir_rename_entry_init(struct dir_rename_entry *entry,
 				  char *directory)
 {
-	hashmap_entry_init(entry, strhash(directory));
+	hashmap_entry_init(&entry->ent, strhash(directory));
 	entry->dir = directory;
 	entry->non_unique_new_dir = 0;
 	strbuf_init(&entry->new_dir, 0);
 	string_list_init(&entry->possible_new_dirs, 0);
 }
 
+struct collision_entry {
+	struct hashmap_entry ent;
+	char *target_file;
+	struct string_list source_files;
+	unsigned reported_already:1;
+};
+
 static struct collision_entry *collision_find_entry(struct hashmap *hashmap,
 						    char *target_file)
 {
 	struct collision_entry key;
 
-	hashmap_entry_init(&key, strhash(target_file));
+	hashmap_entry_init(&key.ent, strhash(target_file));
 	key.target_file = target_file;
-	return hashmap_get(hashmap, &key, NULL);
+	return hashmap_get_entry(hashmap, &key, ent, NULL);
 }
 
-static int collision_cmp(void *unused_cmp_data,
-			 const struct collision_entry *e1,
-			 const struct collision_entry *e2,
+static int collision_cmp(const void *unused_cmp_data,
+			 const struct hashmap_entry *eptr,
+			 const struct hashmap_entry *entry_or_key,
 			 const void *unused_keydata)
 {
+	const struct collision_entry *e1, *e2;
+
+	e1 = container_of(eptr, const struct collision_entry, ent);
+	e2 = container_of(entry_or_key, const struct collision_entry, ent);
+
 	return strcmp(e1->target_file, e2->target_file);
 }
 
 static void collision_init(struct hashmap *map)
 {
-	hashmap_init(map, (hashmap_cmp_fn) collision_cmp, NULL, 0);
+	hashmap_init(map, collision_cmp, NULL, 0);
 }
 
-static void flush_output(struct merge_options *o)
+static void flush_output(struct merge_options *opt)
 {
-	if (o->buffer_output < 2 && o->obuf.len) {
-		fputs(o->obuf.buf, stdout);
-		strbuf_reset(&o->obuf);
+	if (opt->buffer_output < 2 && opt->obuf.len) {
+		fputs(opt->obuf.buf, stdout);
+		strbuf_reset(&opt->obuf);
 	}
 }
 
-static int err(struct merge_options *o, const char *err, ...)
+static int err(struct merge_options *opt, const char *err, ...)
 {
 	va_list params;
 
-	if (o->buffer_output < 2)
-		flush_output(o);
+	if (opt->buffer_output < 2)
+		flush_output(opt);
 	else {
-		strbuf_complete(&o->obuf, '\n');
-		strbuf_addstr(&o->obuf, "error: ");
+		strbuf_complete(&opt->obuf, '\n');
+		strbuf_addstr(&opt->obuf, "error: ");
 	}
 	va_start(params, err);
-	strbuf_vaddf(&o->obuf, err, params);
+	strbuf_vaddf(&opt->obuf, err, params);
 	va_end(params);
-	if (o->buffer_output > 1)
-		strbuf_addch(&o->obuf, '\n');
+	if (opt->buffer_output > 1)
+		strbuf_addch(&opt->obuf, '\n');
 	else {
-		error("%s", o->obuf.buf);
-		strbuf_reset(&o->obuf);
+		error("%s", opt->obuf.buf);
+		strbuf_reset(&opt->obuf);
 	}
 
 	return -1;
 }
 
-static struct tree *shift_tree_object(struct tree *one, struct tree *two,
+static struct tree *shift_tree_object(struct repository *repo,
+				      struct tree *one, struct tree *two,
 				      const char *subtree_shift)
 {
 	struct object_id shifted;
 
 	if (!*subtree_shift) {
-		shift_tree(&one->object.oid, &two->object.oid, &shifted, 0);
+		shift_tree(repo, &one->object.oid, &two->object.oid, &shifted, 0);
 	} else {
-		shift_tree_by(&one->object.oid, &two->object.oid, &shifted,
+		shift_tree_by(repo, &one->object.oid, &two->object.oid, &shifted,
 			      subtree_shift);
 	}
-	if (!oidcmp(&two->object.oid, &shifted))
+	if (oideq(&two->object.oid, &shifted))
 		return two;
-	return lookup_tree(&shifted);
+	return lookup_tree(repo, &shifted);
 }
 
-static struct commit *make_virtual_commit(struct tree *tree, const char *comment)
+static inline void set_commit_tree(struct commit *c, struct tree *t)
 {
-	struct commit *commit = alloc_commit_node();
+	c->maybe_tree = t;
+}
+
+static struct commit *make_virtual_commit(struct repository *repo,
+					  struct tree *tree,
+					  const char *comment)
+{
+	struct commit *commit = alloc_commit_node(repo);
 
 	set_merge_remote_desc(commit, comment, (struct object *)commit);
-	commit->maybe_tree = tree;
+	set_commit_tree(commit, tree);
 	commit->object.parsed = 1;
 	return commit;
 }
 
-/*
- * Since we use get_tree_entry(), which does not put the read object into
- * the object pool, we cannot rely on a == b.
- */
-static int oid_eq(const struct object_id *a, const struct object_id *b)
-{
-	if (!a && !b)
-		return 2;
-	return a && b && oidcmp(a, b) == 0;
-}
-
 enum rename_type {
 	RENAME_NORMAL = 0,
-	RENAME_DIR,
+	RENAME_VIA_DIR,
+	RENAME_ADD,
 	RENAME_DELETE,
 	RENAME_ONE_FILE_TO_ONE,
 	RENAME_ONE_FILE_TO_TWO,
 	RENAME_TWO_FILES_TO_ONE
 };
 
-struct rename_conflict_info {
-	enum rename_type rename_type;
-	struct diff_filepair *pair1;
-	struct diff_filepair *pair2;
-	const char *branch1;
-	const char *branch2;
-	struct stage_data *dst_entry1;
-	struct stage_data *dst_entry2;
-	struct diff_filespec ren1_other;
-	struct diff_filespec ren2_other;
-};
-
 /*
  * Since we want to write the index eventually, we cannot reuse the index
  * for these (temporary) data.
  */
 struct stage_data {
-	struct {
-		unsigned mode;
-		struct object_id oid;
-	} stages[4];
+	struct diff_filespec stages[4]; /* mostly for oid & mode; maybe path */
 	struct rename_conflict_info *rename_conflict_info;
 	unsigned processed:1;
 };
 
+struct rename {
+	unsigned processed:1;
+	struct diff_filepair *pair;
+	const char *branch; /* branch that the rename occurred on */
+	/*
+	 * If directory rename detection affected this rename, what was its
+	 * original type ('A' or 'R') and it's original destination before
+	 * the directory rename (otherwise, '\0' and NULL for these two vars).
+	 */
+	char dir_rename_original_type;
+	char *dir_rename_original_dest;
+	/*
+	 * Purpose of src_entry and dst_entry:
+	 *
+	 * If 'before' is renamed to 'after' then src_entry will contain
+	 * the versions of 'before' from the merge_base, HEAD, and MERGE in
+	 * stages 1, 2, and 3; dst_entry will contain the respective
+	 * versions of 'after' in corresponding locations.  Thus, we have a
+	 * total of six modes and oids, though some will be null.  (Stage 0
+	 * is ignored; we're interested in handling conflicts.)
+	 *
+	 * Since we don't turn on break-rewrites by default, neither
+	 * src_entry nor dst_entry can have all three of their stages have
+	 * non-null oids, meaning at most four of the six will be non-null.
+	 * Also, since this is a rename, both src_entry and dst_entry will
+	 * have at least one non-null oid, meaning at least two will be
+	 * non-null.  Of the six oids, a typical rename will have three be
+	 * non-null.  Only two implies a rename/delete, and four implies a
+	 * rename/add.
+	 */
+	struct stage_data *src_entry;
+	struct stage_data *dst_entry;
+};
+
+struct rename_conflict_info {
+	enum rename_type rename_type;
+	struct rename *ren1;
+	struct rename *ren2;
+};
+
 static inline void setup_rename_conflict_info(enum rename_type rename_type,
-					      struct diff_filepair *pair1,
-					      struct diff_filepair *pair2,
-					      const char *branch1,
-					      const char *branch2,
-					      struct stage_data *dst_entry1,
-					      struct stage_data *dst_entry2,
-					      struct merge_options *o,
-					      struct stage_data *src_entry1,
-					      struct stage_data *src_entry2)
+					      struct merge_options *opt,
+					      struct rename *ren1,
+					      struct rename *ren2)
 {
-	struct rename_conflict_info *ci = xcalloc(1, sizeof(struct rename_conflict_info));
-	ci->rename_type = rename_type;
-	ci->pair1 = pair1;
-	ci->branch1 = branch1;
-	ci->branch2 = branch2;
-
-	ci->dst_entry1 = dst_entry1;
-	dst_entry1->rename_conflict_info = ci;
-	dst_entry1->processed = 0;
+	struct rename_conflict_info *ci;
 
-	assert(!pair2 == !dst_entry2);
-	if (dst_entry2) {
-		ci->dst_entry2 = dst_entry2;
-		ci->pair2 = pair2;
-		dst_entry2->rename_conflict_info = ci;
+	/*
+	 * When we have two renames involved, it's easiest to get the
+	 * correct things into stage 2 and 3, and to make sure that the
+	 * content merge puts HEAD before the other branch if we just
+	 * ensure that branch1 == opt->branch1.  So, simply flip arguments
+	 * around if we don't have that.
+	 */
+	if (ren2 && ren1->branch != opt->branch1) {
+		setup_rename_conflict_info(rename_type, opt, ren2, ren1);
+		return;
 	}
 
-	if (rename_type == RENAME_TWO_FILES_TO_ONE) {
-		/*
-		 * For each rename, there could have been
-		 * modifications on the side of history where that
-		 * file was not renamed.
-		 */
-		int ostage1 = o->branch1 == branch1 ? 3 : 2;
-		int ostage2 = ostage1 ^ 1;
-
-		ci->ren1_other.path = pair1->one->path;
-		oidcpy(&ci->ren1_other.oid, &src_entry1->stages[ostage1].oid);
-		ci->ren1_other.mode = src_entry1->stages[ostage1].mode;
+	ci = xcalloc(1, sizeof(struct rename_conflict_info));
+	ci->rename_type = rename_type;
+	ci->ren1 = ren1;
+	ci->ren2 = ren2;
 
-		ci->ren2_other.path = pair2->one->path;
-		oidcpy(&ci->ren2_other.oid, &src_entry2->stages[ostage2].oid);
-		ci->ren2_other.mode = src_entry2->stages[ostage2].mode;
+	ci->ren1->dst_entry->processed = 0;
+	ci->ren1->dst_entry->rename_conflict_info = ci;
+	if (ren2) {
+		ci->ren2->dst_entry->rename_conflict_info = ci;
 	}
 }
 
-static int show(struct merge_options *o, int v)
+static int show(struct merge_options *opt, int v)
 {
-	return (!o->call_depth && o->verbosity >= v) || o->verbosity >= 5;
+	return (!opt->priv->call_depth && opt->verbosity >= v) ||
+		opt->verbosity >= 5;
 }
 
 __attribute__((format (printf, 3, 4)))
-static void output(struct merge_options *o, int v, const char *fmt, ...)
+static void output(struct merge_options *opt, int v, const char *fmt, ...)
 {
 	va_list ap;
 
-	if (!show(o, v))
+	if (!show(opt, v))
 		return;
 
-	strbuf_addchars(&o->obuf, ' ', o->call_depth * 2);
+	strbuf_addchars(&opt->obuf, ' ', opt->priv->call_depth * 2);
 
 	va_start(ap, fmt);
-	strbuf_vaddf(&o->obuf, fmt, ap);
+	strbuf_vaddf(&opt->obuf, fmt, ap);
 	va_end(ap);
 
-	strbuf_addch(&o->obuf, '\n');
-	if (!o->buffer_output)
-		flush_output(o);
+	strbuf_addch(&opt->obuf, '\n');
+	if (!opt->buffer_output)
+		flush_output(opt);
 }
 
-static void output_commit_title(struct merge_options *o, struct commit *commit)
+static void output_commit_title(struct merge_options *opt, struct commit *commit)
 {
-	strbuf_addchars(&o->obuf, ' ', o->call_depth * 2);
-	if (commit->util)
-		strbuf_addf(&o->obuf, "virtual %s\n",
-			merge_remote_util(commit)->name);
+	struct merge_remote_desc *desc;
+
+	strbuf_addchars(&opt->obuf, ' ', opt->priv->call_depth * 2);
+	desc = merge_remote_util(commit);
+	if (desc)
+		strbuf_addf(&opt->obuf, "virtual %s\n", desc->name);
 	else {
-		strbuf_add_unique_abbrev(&o->obuf, &commit->object.oid,
+		strbuf_add_unique_abbrev(&opt->obuf, &commit->object.oid,
 					 DEFAULT_ABBREV);
-		strbuf_addch(&o->obuf, ' ');
+		strbuf_addch(&opt->obuf, ' ');
 		if (parse_commit(commit) != 0)
-			strbuf_addstr(&o->obuf, _("(bad commit)\n"));
+			strbuf_addstr(&opt->obuf, _("(bad commit)\n"));
 		else {
 			const char *title;
 			const char *msg = get_commit_buffer(commit, NULL);
 			int len = find_commit_subject(msg, &title);
 			if (len)
-				strbuf_addf(&o->obuf, "%.*s\n", len, title);
+				strbuf_addf(&opt->obuf, "%.*s\n", len, title);
 			unuse_commit_buffer(commit, msg);
 		}
 	}
-	flush_output(o);
+	flush_output(opt);
 }
 
-static int add_cacheinfo(struct merge_options *o,
-		unsigned int mode, const struct object_id *oid,
-		const char *path, int stage, int refresh, int options)
+static int add_cacheinfo(struct merge_options *opt,
+			 const struct diff_filespec *blob,
+			 const char *path, int stage, int refresh, int options)
 {
+	struct index_state *istate = opt->repo->index;
 	struct cache_entry *ce;
 	int ret;
 
-	ce = make_cache_entry(mode, oid ? oid->hash : null_sha1, path, stage, 0);
+	ce = make_cache_entry(istate, blob->mode, &blob->oid, path, stage, 0);
 	if (!ce)
-		return err(o, _("add_cacheinfo failed for path '%s'; merge aborting."), path);
+		return err(opt, _("add_cacheinfo failed for path '%s'; merge aborting."), path);
 
-	ret = add_cache_entry(ce, options);
+	ret = add_index_entry(istate, ce, options);
 	if (refresh) {
 		struct cache_entry *nce;
 
-		nce = refresh_cache_entry(ce, CE_MATCH_REFRESH | CE_MATCH_IGNORE_MISSING);
+		nce = refresh_cache_entry(istate, ce,
+					  CE_MATCH_REFRESH | CE_MATCH_IGNORE_MISSING);
 		if (!nce)
-			return err(o, _("add_cacheinfo failed to refresh for path '%s'; merge aborting."), path);
+			return err(opt, _("add_cacheinfo failed to refresh for path '%s'; merge aborting."), path);
 		if (nce != ce)
-			ret = add_cache_entry(nce, options);
+			ret = add_index_entry(istate, nce, options);
 	}
 	return ret;
 }
 
+static inline int merge_detect_rename(struct merge_options *opt)
+{
+	return (opt->detect_renames >= 0) ? opt->detect_renames : 1;
+}
+
 static void init_tree_desc_from_tree(struct tree_desc *desc, struct tree *tree)
 {
 	parse_tree(tree);
 	init_tree_desc(desc, tree->buffer, tree->size);
 }
 
-static int unpack_trees_start(struct merge_options *o,
+static int unpack_trees_start(struct merge_options *opt,
 			      struct tree *common,
 			      struct tree *head,
 			      struct tree *merge)
@@ -347,111 +412,82 @@ static int unpack_trees_start(struct mer
 	struct tree_desc t[3];
 	struct index_state tmp_index = { NULL };
 
-	memset(&o->unpack_opts, 0, sizeof(o->unpack_opts));
-	if (o->call_depth)
-		o->unpack_opts.index_only = 1;
+	memset(&opt->priv->unpack_opts, 0, sizeof(opt->priv->unpack_opts));
+	if (opt->priv->call_depth)
+		opt->priv->unpack_opts.index_only = 1;
 	else
-		o->unpack_opts.update = 1;
-	o->unpack_opts.merge = 1;
-	o->unpack_opts.head_idx = 2;
-	o->unpack_opts.fn = threeway_merge;
-	o->unpack_opts.src_index = &the_index;
-	o->unpack_opts.dst_index = &tmp_index;
-	o->unpack_opts.aggressive = !merge_detect_rename(o);
-	setup_unpack_trees_porcelain(&o->unpack_opts, "merge");
+		opt->priv->unpack_opts.update = 1;
+	opt->priv->unpack_opts.merge = 1;
+	opt->priv->unpack_opts.head_idx = 2;
+	opt->priv->unpack_opts.fn = threeway_merge;
+	opt->priv->unpack_opts.src_index = opt->repo->index;
+	opt->priv->unpack_opts.dst_index = &tmp_index;
+	opt->priv->unpack_opts.aggressive = !merge_detect_rename(opt);
+	setup_unpack_trees_porcelain(&opt->priv->unpack_opts, "merge");
 
 	init_tree_desc_from_tree(t+0, common);
 	init_tree_desc_from_tree(t+1, head);
 	init_tree_desc_from_tree(t+2, merge);
 
-	rc = unpack_trees(3, t, &o->unpack_opts);
-	cache_tree_free(&active_cache_tree);
+	rc = unpack_trees(3, t, &opt->priv->unpack_opts);
+	cache_tree_free(&opt->repo->index->cache_tree);
 
 	/*
-	 * Update the_index to match the new results, AFTER saving a copy
-	 * in o->orig_index.  Update src_index to point to the saved copy.
-	 * (verify_uptodate() checks src_index, and the original index is
-	 * the one that had the necessary modification timestamps.)
-	 */
-	o->orig_index = the_index;
-	the_index = tmp_index;
-	o->unpack_opts.src_index = &o->orig_index;
+	 * Update opt->repo->index to match the new results, AFTER saving a
+	 * copy in opt->priv->orig_index.  Update src_index to point to the
+	 * saved copy.  (verify_uptodate() checks src_index, and the original
+	 * index is the one that had the necessary modification timestamps.)
+	 */
+	opt->priv->orig_index = *opt->repo->index;
+	*opt->repo->index = tmp_index;
+	opt->priv->unpack_opts.src_index = &opt->priv->orig_index;
 
 	return rc;
 }
 
-static void unpack_trees_finish(struct merge_options *o)
+static void unpack_trees_finish(struct merge_options *opt)
 {
-	discard_index(&o->orig_index);
-	clear_unpack_trees_porcelain(&o->unpack_opts);
-}
-
-struct tree *write_tree_from_memory(struct merge_options *o)
-{
-	struct tree *result = NULL;
-
-	if (unmerged_cache()) {
-		int i;
-		fprintf(stderr, "BUG: There are unmerged index entries:\n");
-		for (i = 0; i < active_nr; i++) {
-			const struct cache_entry *ce = active_cache[i];
-			if (ce_stage(ce))
-				fprintf(stderr, "BUG: %d %.*s\n", ce_stage(ce),
-					(int)ce_namelen(ce), ce->name);
-		}
-		BUG("unmerged index entries in merge-recursive.c");
-	}
-
-	if (!active_cache_tree)
-		active_cache_tree = cache_tree();
-
-	if (!cache_tree_fully_valid(active_cache_tree) &&
-	    cache_tree_update(&the_index, 0) < 0) {
-		err(o, _("error building trees"));
-		return NULL;
-	}
-
-	result = lookup_tree(&active_cache_tree->oid);
-
-	return result;
+	discard_index(&opt->priv->orig_index);
+	clear_unpack_trees_porcelain(&opt->priv->unpack_opts);
 }
 
 static int save_files_dirs(const struct object_id *oid,
-		struct strbuf *base, const char *path,
-		unsigned int mode, int stage, void *context)
+			   struct strbuf *base, const char *path,
+			   unsigned int mode, int stage, void *context)
 {
 	struct path_hashmap_entry *entry;
 	int baselen = base->len;
-	struct merge_options *o = context;
+	struct merge_options *opt = context;
 
 	strbuf_addstr(base, path);
 
 	FLEX_ALLOC_MEM(entry, path, base->buf, base->len);
-	hashmap_entry_init(entry, path_hash(entry->path));
-	hashmap_add(&o->current_file_dir_set, entry);
+	hashmap_entry_init(&entry->e, path_hash(entry->path));
+	hashmap_add(&opt->priv->current_file_dir_set, &entry->e);
 
 	strbuf_setlen(base, baselen);
 	return (S_ISDIR(mode) ? READ_TREE_RECURSIVE : 0);
 }
 
-static void get_files_dirs(struct merge_options *o, struct tree *tree)
+static void get_files_dirs(struct merge_options *opt, struct tree *tree)
 {
 	struct pathspec match_all;
 	memset(&match_all, 0, sizeof(match_all));
-	read_tree_recursive(tree, "", 0, 0, &match_all, save_files_dirs, o);
+	read_tree_recursive(opt->repo, tree, "", 0, 0,
+			    &match_all, save_files_dirs, opt);
 }
 
-static int get_tree_entry_if_blob(const struct object_id *tree,
+static int get_tree_entry_if_blob(struct repository *r,
+				  const struct object_id *tree,
 				  const char *path,
-				  struct object_id *hashy,
-				  unsigned int *mode_o)
+				  struct diff_filespec *dfs)
 {
 	int ret;
 
-	ret = get_tree_entry(tree, path, hashy, mode_o);
-	if (S_ISDIR(*mode_o)) {
-		oidcpy(hashy, &null_oid);
-		*mode_o = 0;
+	ret = get_tree_entry(r, tree, path, &dfs->oid, &dfs->mode);
+	if (S_ISDIR(dfs->mode)) {
+		oidcpy(&dfs->oid, &null_oid);
+		dfs->mode = 0;
 	}
 	return ret;
 }
@@ -460,18 +496,16 @@ static int get_tree_entry_if_blob(const
  * Returns an index_entry instance which doesn't have to correspond to
  * a real cache entry in Git's index.
  */
-static struct stage_data *insert_stage_data(const char *path,
+static struct stage_data *insert_stage_data(struct repository *r,
+		const char *path,
 		struct tree *o, struct tree *a, struct tree *b,
 		struct string_list *entries)
 {
 	struct string_list_item *item;
 	struct stage_data *e = xcalloc(1, sizeof(struct stage_data));
-	get_tree_entry_if_blob(&o->object.oid, path,
-			       &e->stages[1].oid, &e->stages[1].mode);
-	get_tree_entry_if_blob(&a->object.oid, path,
-			       &e->stages[2].oid, &e->stages[2].mode);
-	get_tree_entry_if_blob(&b->object.oid, path,
-			       &e->stages[3].oid, &e->stages[3].mode);
+	get_tree_entry_if_blob(r, &o->object.oid, path, &e->stages[1]);
+	get_tree_entry_if_blob(r, &a->object.oid, path, &e->stages[2]);
+	get_tree_entry_if_blob(r, &b->object.oid, path, &e->stages[3]);
 	item = string_list_insert(entries, path);
 	item->util = e;
 	return e;
@@ -481,17 +515,17 @@ static struct stage_data *insert_stage_d
  * Create a dictionary mapping file names to stage_data objects. The
  * dictionary contains one entry for every path with a non-zero stage entry.
  */
-static struct string_list *get_unmerged(void)
+static struct string_list *get_unmerged(struct index_state *istate)
 {
 	struct string_list *unmerged = xcalloc(1, sizeof(struct string_list));
 	int i;
 
 	unmerged->strdup_strings = 1;
 
-	for (i = 0; i < active_nr; i++) {
+	for (i = 0; i < istate->cache_nr; i++) {
 		struct string_list_item *item;
 		struct stage_data *e;
-		const struct cache_entry *ce = active_cache[i];
+		const struct cache_entry *ce = istate->cache[i];
 		if (!ce_stage(ce))
 			continue;
 
@@ -535,11 +569,11 @@ static int string_list_df_name_compare(c
 	return onelen - twolen;
 }
 
-static void record_df_conflict_files(struct merge_options *o,
+static void record_df_conflict_files(struct merge_options *opt,
 				     struct string_list *entries)
 {
 	/* If there is a D/F conflict and the file for such a conflict
-	 * currently exist in the working tree, we want to allow it to be
+	 * currently exists in the working tree, we want to allow it to be
 	 * removed to make room for the corresponding directory if needed.
 	 * The files underneath the directories of such D/F conflicts will
 	 * be processed before the corresponding file involved in the D/F
@@ -560,7 +594,7 @@ static void record_df_conflict_files(str
 	 * If we're merging merge-bases, we don't want to bother with
 	 * any working directory changes.
 	 */
-	if (o->call_depth)
+	if (opt->priv->call_depth)
 		return;
 
 	/* Ensure D/F conflicts are adjacent in the entries list. */
@@ -572,7 +606,7 @@ static void record_df_conflict_files(str
 	df_sorted_entries.cmp = string_list_df_name_compare;
 	string_list_sort(&df_sorted_entries);
 
-	string_list_clear(&o->df_conflict_file_set, 1);
+	string_list_clear(&opt->priv->df_conflict_file_set, 1);
 	for (i = 0; i < df_sorted_entries.nr; i++) {
 		const char *path = df_sorted_entries.items[i].string;
 		int len = strlen(path);
@@ -588,7 +622,7 @@ static void record_df_conflict_files(str
 		    len > last_len &&
 		    memcmp(path, last_file, last_len) == 0 &&
 		    path[last_len] == '/') {
-			string_list_insert(&o->df_conflict_file_set, last_file);
+			string_list_insert(&opt->priv->df_conflict_file_set, last_file);
 		}
 
 		/*
@@ -607,33 +641,6 @@ static void record_df_conflict_files(str
 	string_list_clear(&df_sorted_entries, 0);
 }
 
-struct rename {
-	struct diff_filepair *pair;
-	/*
-	 * Purpose of src_entry and dst_entry:
-	 *
-	 * If 'before' is renamed to 'after' then src_entry will contain
-	 * the versions of 'before' from the merge_base, HEAD, and MERGE in
-	 * stages 1, 2, and 3; dst_entry will contain the respective
-	 * versions of 'after' in corresponding locations.  Thus, we have a
-	 * total of six modes and oids, though some will be null.  (Stage 0
-	 * is ignored; we're interested in handling conflicts.)
-	 *
-	 * Since we don't turn on break-rewrites by default, neither
-	 * src_entry nor dst_entry can have all three of their stages have
-	 * non-null oids, meaning at most four of the six will be non-null.
-	 * Also, since this is a rename, both src_entry and dst_entry will
-	 * have at least one non-null oid, meaning at least two will be
-	 * non-null.  Of the six oids, a typical rename will have three be
-	 * non-null.  Only two implies a rename/delete, and four implies a
-	 * rename/add.
-	 */
-	struct stage_data *src_entry;
-	struct stage_data *dst_entry;
-	unsigned add_turned_into_rename:1;
-	unsigned processed:1;
-};
-
 static int update_stages(struct merge_options *opt, const char *path,
 			 const struct diff_filespec *o,
 			 const struct diff_filespec *a,
@@ -651,41 +658,20 @@ static int update_stages(struct merge_op
 	int clear = 1;
 	int options = ADD_CACHE_OK_TO_ADD | ADD_CACHE_SKIP_DFCHECK;
 	if (clear)
-		if (remove_file_from_cache(path))
+		if (remove_file_from_index(opt->repo->index, path))
 			return -1;
 	if (o)
-		if (add_cacheinfo(opt, o->mode, &o->oid, path, 1, 0, options))
+		if (add_cacheinfo(opt, o, path, 1, 0, options))
 			return -1;
 	if (a)
-		if (add_cacheinfo(opt, a->mode, &a->oid, path, 2, 0, options))
+		if (add_cacheinfo(opt, a, path, 2, 0, options))
 			return -1;
 	if (b)
-		if (add_cacheinfo(opt, b->mode, &b->oid, path, 3, 0, options))
+		if (add_cacheinfo(opt, b, path, 3, 0, options))
 			return -1;
 	return 0;
 }
 
-static int update_stages_for_stage_data(struct merge_options *opt,
-					const char *path,
-					const struct stage_data *stage_data)
-{
-	struct diff_filespec o, a, b;
-
-	o.mode = stage_data->stages[1].mode;
-	oidcpy(&o.oid, &stage_data->stages[1].oid);
-
-	a.mode = stage_data->stages[2].mode;
-	oidcpy(&a.oid, &stage_data->stages[2].oid);
-
-	b.mode = stage_data->stages[3].mode;
-	oidcpy(&b.oid, &stage_data->stages[3].oid);
-
-	return update_stages(opt, path,
-			     is_null_oid(&o.oid) ? NULL : &o,
-			     is_null_oid(&a.oid) ? NULL : &a,
-			     is_null_oid(&b.oid) ? NULL : &b);
-}
-
 static void update_entry(struct stage_data *entry,
 			 struct diff_filespec *o,
 			 struct diff_filespec *a,
@@ -700,20 +686,21 @@ static void update_entry(struct stage_da
 	oidcpy(&entry->stages[3].oid, &b->oid);
 }
 
-static int remove_file(struct merge_options *o, int clean,
+static int remove_file(struct merge_options *opt, int clean,
 		       const char *path, int no_wd)
 {
-	int update_cache = o->call_depth || clean;
-	int update_working_directory = !o->call_depth && !no_wd;
+	int update_cache = opt->priv->call_depth || clean;
+	int update_working_directory = !opt->priv->call_depth && !no_wd;
 
 	if (update_cache) {
-		if (remove_file_from_cache(path))
+		if (remove_file_from_index(opt->repo->index, path))
 			return -1;
 	}
 	if (update_working_directory) {
 		if (ignore_case) {
 			struct cache_entry *ce;
-			ce = cache_file_exists(path, strlen(path), ignore_case);
+			ce = index_file_exists(opt->repo->index, path, strlen(path),
+					       ignore_case);
 			if (ce && ce_stage(ce) == 0 && strcmp(path, ce->name))
 				return 0;
 		}
@@ -733,7 +720,9 @@ static void add_flattened_path(struct st
 			out->buf[i] = '_';
 }
 
-static char *unique_path(struct merge_options *o, const char *path, const char *branch)
+static char *unique_path(struct merge_options *opt,
+			 const char *path,
+			 const char *branch)
 {
 	struct path_hashmap_entry *entry;
 	struct strbuf newpath = STRBUF_INIT;
@@ -744,16 +733,16 @@ static char *unique_path(struct merge_op
 	add_flattened_path(&newpath, branch);
 
 	base_len = newpath.len;
-	while (hashmap_get_from_hash(&o->current_file_dir_set,
+	while (hashmap_get_from_hash(&opt->priv->current_file_dir_set,
 				     path_hash(newpath.buf), newpath.buf) ||
-	       (!o->call_depth && file_exists(newpath.buf))) {
+	       (!opt->priv->call_depth && file_exists(newpath.buf))) {
 		strbuf_setlen(&newpath, base_len);
 		strbuf_addf(&newpath, "_%d", suffix++);
 	}
 
 	FLEX_ALLOC_MEM(entry, path, newpath.buf, newpath.len);
-	hashmap_entry_init(entry, path_hash(entry->path));
-	hashmap_add(&o->current_file_dir_set, entry);
+	hashmap_entry_init(&entry->e, path_hash(entry->path));
+	hashmap_add(&opt->priv->current_file_dir_set, &entry->e);
 	return strbuf_detach(&newpath, NULL);
 }
 
@@ -763,7 +752,8 @@ static char *unique_path(struct merge_op
  * check the working directory.  If empty_ok is non-zero, also return
  * 0 in the case where the working-tree dir exists but is empty.
  */
-static int dir_in_way(const char *path, int check_working_copy, int empty_ok)
+static int dir_in_way(struct index_state *istate, const char *path,
+		      int check_working_copy, int empty_ok)
 {
 	int pos;
 	struct strbuf dirpath = STRBUF_INIT;
@@ -772,29 +762,30 @@ static int dir_in_way(const char *path,
 	strbuf_addstr(&dirpath, path);
 	strbuf_addch(&dirpath, '/');
 
-	pos = cache_name_pos(dirpath.buf, dirpath.len);
+	pos = index_name_pos(istate, dirpath.buf, dirpath.len);
 
 	if (pos < 0)
 		pos = -1 - pos;
-	if (pos < active_nr &&
-	    !strncmp(dirpath.buf, active_cache[pos]->name, dirpath.len)) {
+	if (pos < istate->cache_nr &&
+	    !strncmp(dirpath.buf, istate->cache[pos]->name, dirpath.len)) {
 		strbuf_release(&dirpath);
 		return 1;
 	}
 
 	strbuf_release(&dirpath);
 	return check_working_copy && !lstat(path, &st) && S_ISDIR(st.st_mode) &&
-		!(empty_ok && is_empty_dir(path));
+		!(empty_ok && is_empty_dir(path)) &&
+		!has_symlink_leading_path(path, strlen(path));
 }
 
 /*
  * Returns whether path was tracked in the index before the merge started,
  * and its oid and mode match the specified values
  */
-static int was_tracked_and_matches(struct merge_options *o, const char *path,
-				   const struct object_id *oid, unsigned mode)
+static int was_tracked_and_matches(struct merge_options *opt, const char *path,
+				   const struct diff_filespec *blob)
 {
-	int pos = index_name_pos(&o->orig_index, path, strlen(path));
+	int pos = index_name_pos(&opt->priv->orig_index, path, strlen(path));
 	struct cache_entry *ce;
 
 	if (0 > pos)
@@ -802,16 +793,16 @@ static int was_tracked_and_matches(struc
 		return 0;
 
 	/* See if the file we were tracking before matches */
-	ce = o->orig_index.cache[pos];
-	return (oid_eq(&ce->oid, oid) && ce->ce_mode == mode);
+	ce = opt->priv->orig_index.cache[pos];
+	return (oideq(&ce->oid, &blob->oid) && ce->ce_mode == blob->mode);
 }
 
 /*
  * Returns whether path was tracked in the index before the merge started
  */
-static int was_tracked(struct merge_options *o, const char *path)
+static int was_tracked(struct merge_options *opt, const char *path)
 {
-	int pos = index_name_pos(&o->orig_index, path, strlen(path));
+	int pos = index_name_pos(&opt->priv->orig_index, path, strlen(path));
 
 	if (0 <= pos)
 		/* we were tracking this path before the merge */
@@ -820,11 +811,13 @@ static int was_tracked(struct merge_opti
 	return 0;
 }
 
-static int would_lose_untracked(const char *path)
+static int would_lose_untracked(struct merge_options *opt, const char *path)
 {
+	struct index_state *istate = opt->repo->index;
+
 	/*
 	 * This may look like it can be simplified to:
-	 *   return !was_tracked(o, path) && file_exists(path)
+	 *   return !was_tracked(opt, path) && file_exists(path)
 	 * but it can't.  This function needs to know whether path was in
 	 * the working tree due to EITHER having been tracked in the index
 	 * before the merge OR having been put into the working copy and
@@ -839,19 +832,19 @@ static int would_lose_untracked(const ch
 	 * update_file()/would_lose_untracked(); see every comment in this
 	 * file which mentions "update_stages".
 	 */
-	int pos = cache_name_pos(path, strlen(path));
+	int pos = index_name_pos(istate, path, strlen(path));
 
 	if (pos < 0)
 		pos = -1 - pos;
-	while (pos < active_nr &&
-	       !strcmp(path, active_cache[pos]->name)) {
+	while (pos < istate->cache_nr &&
+	       !strcmp(path, istate->cache[pos]->name)) {
 		/*
 		 * If stage #0, it is definitely tracked.
 		 * If it has stage #2 then it was tracked
 		 * before this merge started.  All other
 		 * cases the path was not tracked.
 		 */
-		switch (ce_stage(active_cache[pos])) {
+		switch (ce_stage(istate->cache[pos])) {
 		case 0:
 		case 2:
 			return 0;
@@ -861,38 +854,38 @@ static int would_lose_untracked(const ch
 	return file_exists(path);
 }
 
-static int was_dirty(struct merge_options *o, const char *path)
+static int was_dirty(struct merge_options *opt, const char *path)
 {
 	struct cache_entry *ce;
 	int dirty = 1;
 
-	if (o->call_depth || !was_tracked(o, path))
+	if (opt->priv->call_depth || !was_tracked(opt, path))
 		return !dirty;
 
-	ce = index_file_exists(o->unpack_opts.src_index,
+	ce = index_file_exists(opt->priv->unpack_opts.src_index,
 			       path, strlen(path), ignore_case);
-	dirty = verify_uptodate(ce, &o->unpack_opts) != 0;
+	dirty = verify_uptodate(ce, &opt->priv->unpack_opts) != 0;
 	return dirty;
 }
 
-static int make_room_for_path(struct merge_options *o, const char *path)
+static int make_room_for_path(struct merge_options *opt, const char *path)
 {
 	int status, i;
 	const char *msg = _("failed to create path '%s'%s");
 
 	/* Unlink any D/F conflict files that are in the way */
-	for (i = 0; i < o->df_conflict_file_set.nr; i++) {
-		const char *df_path = o->df_conflict_file_set.items[i].string;
+	for (i = 0; i < opt->priv->df_conflict_file_set.nr; i++) {
+		const char *df_path = opt->priv->df_conflict_file_set.items[i].string;
 		size_t pathlen = strlen(path);
 		size_t df_pathlen = strlen(df_path);
 		if (df_pathlen < pathlen &&
 		    path[df_pathlen] == '/' &&
 		    strncmp(path, df_path, df_pathlen) == 0) {
-			output(o, 3,
+			output(opt, 3,
 			       _("Removing %s to make room for subdirectory\n"),
 			       df_path);
 			unlink(df_path);
-			unsorted_string_list_delete_item(&o->df_conflict_file_set,
+			unsorted_string_list_delete_item(&opt->priv->df_conflict_file_set,
 							 i, 0);
 			break;
 		}
@@ -903,17 +896,17 @@ static int make_room_for_path(struct mer
 	if (status) {
 		if (status == SCLD_EXISTS)
 			/* something else exists */
-			return err(o, msg, path, _(": perhaps a D/F conflict?"));
-		return err(o, msg, path, "");
+			return err(opt, msg, path, _(": perhaps a D/F conflict?"));
+		return err(opt, msg, path, "");
 	}
 
 	/*
 	 * Do not unlink a file in the work tree if we are not
 	 * tracking it.
 	 */
-	if (would_lose_untracked(path))
-		return err(o, _("refusing to lose untracked file at '%s'"),
-			     path);
+	if (would_lose_untracked(opt, path))
+		return err(opt, _("refusing to lose untracked file at '%s'"),
+			   path);
 
 	/* Successful unlink is good.. */
 	if (!unlink(path))
@@ -922,19 +915,18 @@ static int make_room_for_path(struct mer
 	if (errno == ENOENT)
 		return 0;
 	/* .. but not some other error (who really cares what?) */
-	return err(o, msg, path, _(": perhaps a D/F conflict?"));
+	return err(opt, msg, path, _(": perhaps a D/F conflict?"));
 }
 
-static int update_file_flags(struct merge_options *o,
-			     const struct object_id *oid,
-			     unsigned mode,
+static int update_file_flags(struct merge_options *opt,
+			     const struct diff_filespec *contents,
 			     const char *path,
 			     int update_cache,
 			     int update_wd)
 {
 	int ret = 0;
 
-	if (o->call_depth)
+	if (opt->priv->call_depth)
 		update_wd = 0;
 
 	if (update_wd) {
@@ -942,7 +934,7 @@ static int update_file_flags(struct merg
 		void *buf;
 		unsigned long size;
 
-		if (S_ISGITLINK(mode)) {
+		if (S_ISGITLINK(contents->mode)) {
 			/*
 			 * We may later decide to recursively descend into
 			 * the submodule directory and update its index
@@ -952,106 +944,111 @@ static int update_file_flags(struct merg
 			goto update_index;
 		}
 
-		buf = read_object_file(oid, &type, &size);
-		if (!buf)
-			return err(o, _("cannot read object %s '%s'"), oid_to_hex(oid), path);
+		buf = read_object_file(&contents->oid, &type, &size);
+		if (!buf) {
+			ret = err(opt, _("cannot read object %s '%s'"),
+				  oid_to_hex(&contents->oid), path);
+			goto free_buf;
+		}
 		if (type != OBJ_BLOB) {
-			ret = err(o, _("blob expected for %s '%s'"), oid_to_hex(oid), path);
+			ret = err(opt, _("blob expected for %s '%s'"),
+				  oid_to_hex(&contents->oid), path);
 			goto free_buf;
 		}
-		if (S_ISREG(mode)) {
+		if (S_ISREG(contents->mode)) {
 			struct strbuf strbuf = STRBUF_INIT;
-			if (convert_to_working_tree(path, buf, size, &strbuf)) {
+			if (convert_to_working_tree(opt->repo->index,
+						    path, buf, size, &strbuf)) {
 				free(buf);
 				size = strbuf.len;
 				buf = strbuf_detach(&strbuf, NULL);
 			}
 		}
 
-		if (make_room_for_path(o, path) < 0) {
+		if (make_room_for_path(opt, path) < 0) {
 			update_wd = 0;
 			goto free_buf;
 		}
-		if (S_ISREG(mode) || (!has_symlinks && S_ISLNK(mode))) {
+		if (S_ISREG(contents->mode) ||
+		    (!has_symlinks && S_ISLNK(contents->mode))) {
 			int fd;
-			if (mode & 0100)
-				mode = 0777;
-			else
-				mode = 0666;
+			int mode = (contents->mode & 0100 ? 0777 : 0666);
+
 			fd = open(path, O_WRONLY | O_TRUNC | O_CREAT, mode);
 			if (fd < 0) {
-				ret = err(o, _("failed to open '%s': %s"),
+				ret = err(opt, _("failed to open '%s': %s"),
 					  path, strerror(errno));
 				goto free_buf;
 			}
 			write_in_full(fd, buf, size);
 			close(fd);
-		} else if (S_ISLNK(mode)) {
+		} else if (S_ISLNK(contents->mode)) {
 			char *lnk = xmemdupz(buf, size);
 			safe_create_leading_directories_const(path);
 			unlink(path);
 			if (symlink(lnk, path))
-				ret = err(o, _("failed to symlink '%s': %s"),
-					path, strerror(errno));
+				ret = err(opt, _("failed to symlink '%s': %s"),
+					  path, strerror(errno));
 			free(lnk);
 		} else
-			ret = err(o,
+			ret = err(opt,
 				  _("do not know what to do with %06o %s '%s'"),
-				  mode, oid_to_hex(oid), path);
- free_buf:
+				  contents->mode, oid_to_hex(&contents->oid), path);
+	free_buf:
 		free(buf);
 	}
- update_index:
+update_index:
 	if (!ret && update_cache)
-		if (add_cacheinfo(o, mode, oid, path, 0, update_wd,
+		if (add_cacheinfo(opt, contents, path, 0, update_wd,
 				  ADD_CACHE_OK_TO_ADD))
 			return -1;
 	return ret;
 }
 
-static int update_file(struct merge_options *o,
+static int update_file(struct merge_options *opt,
 		       int clean,
-		       const struct object_id *oid,
-		       unsigned mode,
+		       const struct diff_filespec *contents,
 		       const char *path)
 {
-	return update_file_flags(o, oid, mode, path, o->call_depth || clean, !o->call_depth);
+	return update_file_flags(opt, contents, path,
+				 opt->priv->call_depth || clean, !opt->priv->call_depth);
 }
 
 /* Low level file merging, update and removal */
 
 struct merge_file_info {
-	struct object_id oid;
-	unsigned mode;
+	struct diff_filespec blob; /* mostly use oid & mode; sometimes path */
 	unsigned clean:1,
 		 merge:1;
 };
 
-static int merge_3way(struct merge_options *o,
+static int merge_3way(struct merge_options *opt,
 		      mmbuffer_t *result_buf,
-		      const struct diff_filespec *one,
+		      const struct diff_filespec *o,
 		      const struct diff_filespec *a,
 		      const struct diff_filespec *b,
 		      const char *branch1,
-		      const char *branch2)
+		      const char *branch2,
+		      const int extra_marker_size)
 {
 	mmfile_t orig, src1, src2;
 	struct ll_merge_options ll_opts = {0};
-	char *base_name, *name1, *name2;
+	char *base, *name1, *name2;
 	int merge_status;
 
-	ll_opts.renormalize = o->renormalize;
-	ll_opts.xdl_opts = o->xdl_opts;
+	ll_opts.renormalize = opt->renormalize;
+	ll_opts.extra_marker_size = extra_marker_size;
+	ll_opts.xdl_opts = opt->xdl_opts;
 
-	if (o->call_depth) {
+	if (opt->priv->call_depth) {
 		ll_opts.virtual_ancestor = 1;
 		ll_opts.variant = 0;
 	} else {
-		switch (o->recursive_variant) {
-		case MERGE_RECURSIVE_OURS:
+		switch (opt->recursive_variant) {
+		case MERGE_VARIANT_OURS:
 			ll_opts.variant = XDL_MERGE_FAVOR_OURS;
 			break;
-		case MERGE_RECURSIVE_THEIRS:
+		case MERGE_VARIANT_THEIRS:
 			ll_opts.variant = XDL_MERGE_FAVOR_THEIRS;
 			break;
 		default:
@@ -1060,27 +1057,26 @@ static int merge_3way(struct merge_optio
 		}
 	}
 
-	if (strcmp(a->path, b->path) ||
-	    (o->ancestor != NULL && strcmp(a->path, one->path) != 0)) {
-		base_name = o->ancestor == NULL ? NULL :
-			mkpathdup("%s:%s", o->ancestor, one->path);
+	assert(a->path && b->path && o->path && opt->ancestor);
+	if (strcmp(a->path, b->path) || strcmp(a->path, o->path) != 0) {
+		base  = mkpathdup("%s:%s", opt->ancestor, o->path);
 		name1 = mkpathdup("%s:%s", branch1, a->path);
 		name2 = mkpathdup("%s:%s", branch2, b->path);
 	} else {
-		base_name = o->ancestor == NULL ? NULL :
-			mkpathdup("%s", o->ancestor);
+		base  = mkpathdup("%s", opt->ancestor);
 		name1 = mkpathdup("%s", branch1);
 		name2 = mkpathdup("%s", branch2);
 	}
 
-	read_mmblob(&orig, &one->oid);
+	read_mmblob(&orig, &o->oid);
 	read_mmblob(&src1, &a->oid);
 	read_mmblob(&src2, &b->oid);
 
-	merge_status = ll_merge(result_buf, a->path, &orig, base_name,
-				&src1, name1, &src2, name2, &ll_opts);
+	merge_status = ll_merge(result_buf, a->path, &orig, base,
+				&src1, name1, &src2, name2,
+				opt->repo->index, &ll_opts);
 
-	free(base_name);
+	free(base);
 	free(name1);
 	free(name2);
 	free(orig.ptr);
@@ -1089,15 +1085,16 @@ static int merge_3way(struct merge_optio
 	return merge_status;
 }
 
-static int find_first_merges(struct object_array *result, const char *path,
-		struct commit *a, struct commit *b)
+static int find_first_merges(struct repository *repo,
+			     struct object_array *result, const char *path,
+			     struct commit *a, struct commit *b)
 {
 	int i, j;
 	struct object_array merges = OBJECT_ARRAY_INIT;
 	struct commit *commit;
 	int contains_another;
 
-	char merged_revision[42];
+	char merged_revision[GIT_MAX_HEXSZ + 2];
 	const char *rev_args[] = { "rev-list", "--merges", "--ancestry-path",
 				   "--all", merged_revision, NULL };
 	struct rev_info revs;
@@ -1108,8 +1105,8 @@ static int find_first_merges(struct obje
 
 	/* get all revisions that merge commit a */
 	xsnprintf(merged_revision, sizeof(merged_revision), "^%s",
-			oid_to_hex(&a->object.oid));
-	init_revisions(&revs, NULL);
+		  oid_to_hex(&a->object.oid));
+	repo_init_revisions(repo, &revs, NULL);
 	rev_opts.submodule = path;
 	/* FIXME: can't handle linked worktrees in submodules yet */
 	revs.single_worktree = path != NULL;
@@ -1159,7 +1156,12 @@ static void print_commit(struct commit *
 	strbuf_release(&sb);
 }
 
-static int merge_submodule(struct merge_options *o,
+static int is_valid(const struct diff_filespec *dfs)
+{
+	return dfs->mode != 0 && !is_null_oid(&dfs->oid);
+}
+
+static int merge_submodule(struct merge_options *opt,
 			   struct object_id *result, const char *path,
 			   const struct object_id *base, const struct object_id *a,
 			   const struct object_id *b)
@@ -1169,7 +1171,7 @@ static int merge_submodule(struct merge_
 	struct object_array merges;
 
 	int i;
-	int search = !o->call_depth;
+	int search = !opt->priv->call_depth;
 
 	/* store a in result in case we fail */
 	oidcpy(result, a);
@@ -1183,32 +1185,32 @@ static int merge_submodule(struct merge_
 		return 0;
 
 	if (add_submodule_odb(path)) {
-		output(o, 1, _("Failed to merge submodule %s (not checked out)"), path);
+		output(opt, 1, _("Failed to merge submodule %s (not checked out)"), path);
 		return 0;
 	}
 
-	if (!(commit_base = lookup_commit_reference(base)) ||
-	    !(commit_a = lookup_commit_reference(a)) ||
-	    !(commit_b = lookup_commit_reference(b))) {
-		output(o, 1, _("Failed to merge submodule %s (commits not present)"), path);
+	if (!(commit_base = lookup_commit_reference(opt->repo, base)) ||
+	    !(commit_a = lookup_commit_reference(opt->repo, a)) ||
+	    !(commit_b = lookup_commit_reference(opt->repo, b))) {
+		output(opt, 1, _("Failed to merge submodule %s (commits not present)"), path);
 		return 0;
 	}
 
 	/* check whether both changes are forward */
 	if (!in_merge_bases(commit_base, commit_a) ||
 	    !in_merge_bases(commit_base, commit_b)) {
-		output(o, 1, _("Failed to merge submodule %s (commits don't follow merge-base)"), path);
+		output(opt, 1, _("Failed to merge submodule %s (commits don't follow merge-base)"), path);
 		return 0;
 	}
 
 	/* Case #1: a is contained in b or vice versa */
 	if (in_merge_bases(commit_a, commit_b)) {
 		oidcpy(result, b);
-		if (show(o, 3)) {
-			output(o, 3, _("Fast-forwarding submodule %s to the following commit:"), path);
-			output_commit_title(o, commit_b);
-		} else if (show(o, 2))
-			output(o, 2, _("Fast-forwarding submodule %s"), path);
+		if (show(opt, 3)) {
+			output(opt, 3, _("Fast-forwarding submodule %s to the following commit:"), path);
+			output_commit_title(opt, commit_b);
+		} else if (show(opt, 2))
+			output(opt, 2, _("Fast-forwarding submodule %s"), path);
 		else
 			; /* no output */
 
@@ -1216,11 +1218,11 @@ static int merge_submodule(struct merge_
 	}
 	if (in_merge_bases(commit_b, commit_a)) {
 		oidcpy(result, a);
-		if (show(o, 3)) {
-			output(o, 3, _("Fast-forwarding submodule %s to the following commit:"), path);
-			output_commit_title(o, commit_a);
-		} else if (show(o, 2))
-			output(o, 2, _("Fast-forwarding submodule %s"), path);
+		if (show(opt, 3)) {
+			output(opt, 3, _("Fast-forwarding submodule %s to the following commit:"), path);
+			output_commit_title(opt, commit_a);
+		} else if (show(opt, 2))
+			output(opt, 2, _("Fast-forwarding submodule %s"), path);
 		else
 			; /* no output */
 
@@ -1239,27 +1241,28 @@ static int merge_submodule(struct merge_
 		return 0;
 
 	/* find commit which merges them */
-	parent_count = find_first_merges(&merges, path, commit_a, commit_b);
+	parent_count = find_first_merges(opt->repo, &merges, path,
+					 commit_a, commit_b);
 	switch (parent_count) {
 	case 0:
-		output(o, 1, _("Failed to merge submodule %s (merge following commits not found)"), path);
+		output(opt, 1, _("Failed to merge submodule %s (merge following commits not found)"), path);
 		break;
 
 	case 1:
-		output(o, 1, _("Failed to merge submodule %s (not fast-forward)"), path);
-		output(o, 2, _("Found a possible merge resolution for the submodule:\n"));
+		output(opt, 1, _("Failed to merge submodule %s (not fast-forward)"), path);
+		output(opt, 2, _("Found a possible merge resolution for the submodule:\n"));
 		print_commit((struct commit *) merges.objects[0].item);
-		output(o, 2, _(
-			"If this is correct simply add it to the index "
-			"for example\n"
-			"by using:\n\n"
-			"  git update-index --cacheinfo 160000 %s \"%s\"\n\n"
-			"which will accept this suggestion.\n"),
-			oid_to_hex(&merges.objects[0].item->oid), path);
+		output(opt, 2, _(
+		       "If this is correct simply add it to the index "
+		       "for example\n"
+		       "by using:\n\n"
+		       "  git update-index --cacheinfo 160000 %s \"%s\"\n\n"
+		       "which will accept this suggestion.\n"),
+		       oid_to_hex(&merges.objects[0].item->oid), path);
 		break;
 
 	default:
-		output(o, 1, _("Failed to merge submodule %s (multiple merges found)"), path);
+		output(opt, 1, _("Failed to merge submodule %s (multiple merges found)"), path);
 		for (i = 0; i < merges.nr; i++)
 			print_commit((struct commit *) merges.objects[i].item);
 	}
@@ -1268,62 +1271,76 @@ static int merge_submodule(struct merge_
 	return 0;
 }
 
-static int merge_file_1(struct merge_options *o,
-			const struct diff_filespec *one,
-			const struct diff_filespec *a,
-			const struct diff_filespec *b,
-			const char *filename,
-			const char *branch1,
-			const char *branch2,
-			struct merge_file_info *result)
-{
+static int merge_mode_and_contents(struct merge_options *opt,
+				   const struct diff_filespec *o,
+				   const struct diff_filespec *a,
+				   const struct diff_filespec *b,
+				   const char *filename,
+				   const char *branch1,
+				   const char *branch2,
+				   const int extra_marker_size,
+				   struct merge_file_info *result)
+{
+	if (opt->branch1 != branch1) {
+		/*
+		 * It's weird getting a reverse merge with HEAD on the bottom
+		 * side of the conflict markers and the other branch on the
+		 * top.  Fix that.
+		 */
+		return merge_mode_and_contents(opt, o, b, a,
+					       filename,
+					       branch2, branch1,
+					       extra_marker_size, result);
+	}
+
 	result->merge = 0;
 	result->clean = 1;
 
 	if ((S_IFMT & a->mode) != (S_IFMT & b->mode)) {
 		result->clean = 0;
 		if (S_ISREG(a->mode)) {
-			result->mode = a->mode;
-			oidcpy(&result->oid, &a->oid);
+			result->blob.mode = a->mode;
+			oidcpy(&result->blob.oid, &a->oid);
 		} else {
-			result->mode = b->mode;
-			oidcpy(&result->oid, &b->oid);
+			result->blob.mode = b->mode;
+			oidcpy(&result->blob.oid, &b->oid);
 		}
 	} else {
-		if (!oid_eq(&a->oid, &one->oid) && !oid_eq(&b->oid, &one->oid))
+		if (!oideq(&a->oid, &o->oid) && !oideq(&b->oid, &o->oid))
 			result->merge = 1;
 
 		/*
 		 * Merge modes
 		 */
-		if (a->mode == b->mode || a->mode == one->mode)
-			result->mode = b->mode;
+		if (a->mode == b->mode || a->mode == o->mode)
+			result->blob.mode = b->mode;
 		else {
-			result->mode = a->mode;
-			if (b->mode != one->mode) {
+			result->blob.mode = a->mode;
+			if (b->mode != o->mode) {
 				result->clean = 0;
 				result->merge = 1;
 			}
 		}
 
-		if (oid_eq(&a->oid, &b->oid) || oid_eq(&a->oid, &one->oid))
-			oidcpy(&result->oid, &b->oid);
-		else if (oid_eq(&b->oid, &one->oid))
-			oidcpy(&result->oid, &a->oid);
+		if (oideq(&a->oid, &b->oid) || oideq(&a->oid, &o->oid))
+			oidcpy(&result->blob.oid, &b->oid);
+		else if (oideq(&b->oid, &o->oid))
+			oidcpy(&result->blob.oid, &a->oid);
 		else if (S_ISREG(a->mode)) {
 			mmbuffer_t result_buf;
 			int ret = 0, merge_status;
 
-			merge_status = merge_3way(o, &result_buf, one, a, b,
-						  branch1, branch2);
+			merge_status = merge_3way(opt, &result_buf, o, a, b,
+						  branch1, branch2,
+						  extra_marker_size);
 
 			if ((merge_status < 0) || !result_buf.ptr)
-				ret = err(o, _("Failed to execute internal merge"));
+				ret = err(opt, _("Failed to execute internal merge"));
 
 			if (!ret &&
 			    write_object_file(result_buf.ptr, result_buf.size,
-					      blob_type, &result->oid))
-				ret = err(o, _("Unable to add %s to database"),
+					      blob_type, &result->blob.oid))
+				ret = err(opt, _("Unable to add %s to database"),
 					  a->path);
 
 			free(result_buf.ptr);
@@ -1331,23 +1348,23 @@ static int merge_file_1(struct merge_opt
 				return ret;
 			result->clean = (merge_status == 0);
 		} else if (S_ISGITLINK(a->mode)) {
-			result->clean = merge_submodule(o, &result->oid,
-						       one->path,
-						       &one->oid,
-						       &a->oid,
-						       &b->oid);
+			result->clean = merge_submodule(opt, &result->blob.oid,
+							o->path,
+							&o->oid,
+							&a->oid,
+							&b->oid);
 		} else if (S_ISLNK(a->mode)) {
-			switch (o->recursive_variant) {
-			case MERGE_RECURSIVE_NORMAL:
-				oidcpy(&result->oid, &a->oid);
-				if (!oid_eq(&a->oid, &b->oid))
+			switch (opt->recursive_variant) {
+			case MERGE_VARIANT_NORMAL:
+				oidcpy(&result->blob.oid, &a->oid);
+				if (!oideq(&a->oid, &b->oid))
 					result->clean = 0;
 				break;
-			case MERGE_RECURSIVE_OURS:
-				oidcpy(&result->oid, &a->oid);
+			case MERGE_VARIANT_OURS:
+				oidcpy(&result->blob.oid, &a->oid);
 				break;
-			case MERGE_RECURSIVE_THEIRS:
-				oidcpy(&result->oid, &b->oid);
+			case MERGE_VARIANT_THEIRS:
+				oidcpy(&result->blob.oid, &b->oid);
 				break;
 			}
 		} else
@@ -1355,141 +1372,120 @@ static int merge_file_1(struct merge_opt
 	}
 
 	if (result->merge)
-		output(o, 2, _("Auto-merging %s"), filename);
+		output(opt, 2, _("Auto-merging %s"), filename);
 
 	return 0;
 }
 
-static int merge_file_special_markers(struct merge_options *o,
-				      const struct diff_filespec *one,
-				      const struct diff_filespec *a,
-				      const struct diff_filespec *b,
-				      const char *target_filename,
-				      const char *branch1,
-				      const char *filename1,
-				      const char *branch2,
-				      const char *filename2,
-				      struct merge_file_info *mfi)
+static int handle_rename_via_dir(struct merge_options *opt,
+				 struct rename_conflict_info *ci)
 {
-	char *side1 = NULL;
-	char *side2 = NULL;
-	int ret;
-
-	if (filename1)
-		side1 = xstrfmt("%s:%s", branch1, filename1);
-	if (filename2)
-		side2 = xstrfmt("%s:%s", branch2, filename2);
-
-	ret = merge_file_1(o, one, a, b, target_filename,
-			   side1 ? side1 : branch1,
-			   side2 ? side2 : branch2, mfi);
+	/*
+	 * Handle file adds that need to be renamed due to directory rename
+	 * detection.  This differs from handle_rename_normal, because
+	 * there is no content merge to do; just move the file into the
+	 * desired final location.
+	 */
+	const struct rename *ren = ci->ren1;
+	const struct diff_filespec *dest = ren->pair->two;
+	char *file_path = dest->path;
+	int mark_conflicted = (opt->detect_directory_renames ==
+			       MERGE_DIRECTORY_RENAMES_CONFLICT);
+	assert(ren->dir_rename_original_dest);
 
-	free(side1);
-	free(side2);
-	return ret;
-}
+	if (!opt->priv->call_depth && would_lose_untracked(opt, dest->path)) {
+		mark_conflicted = 1;
+		file_path = unique_path(opt, dest->path, ren->branch);
+		output(opt, 1, _("Error: Refusing to lose untracked file at %s; "
+				 "writing to %s instead."),
+		       dest->path, file_path);
+	}
 
-static int merge_file_one(struct merge_options *o,
-			  const char *path,
-			  const struct object_id *o_oid, int o_mode,
-			  const struct object_id *a_oid, int a_mode,
-			  const struct object_id *b_oid, int b_mode,
-			  const char *branch1,
-			  const char *branch2,
-			  struct merge_file_info *mfi)
-{
-	struct diff_filespec one, a, b;
-
-	one.path = a.path = b.path = (char *)path;
-	oidcpy(&one.oid, o_oid);
-	one.mode = o_mode;
-	oidcpy(&a.oid, a_oid);
-	a.mode = a_mode;
-	oidcpy(&b.oid, b_oid);
-	b.mode = b_mode;
-	return merge_file_1(o, &one, &a, &b, path, branch1, branch2, mfi);
-}
-
-static int conflict_rename_dir(struct merge_options *o,
-			       struct diff_filepair *pair,
-			       const char *rename_branch,
-			       const char *other_branch)
-{
-	const struct diff_filespec *dest = pair->two;
-
-	if (!o->call_depth && would_lose_untracked(dest->path)) {
-		char *alt_path = unique_path(o, dest->path, rename_branch);
-
-		output(o, 1, _("Error: Refusing to lose untracked file at %s; "
-			       "writing to %s instead."),
-		       dest->path, alt_path);
-		/*
-		 * Write the file in worktree at alt_path, but not in the
-		 * index.  Instead, write to dest->path for the index but
-		 * only at the higher appropriate stage.
+	if (mark_conflicted) {
+		/*
+		 * Write the file in worktree at file_path.  In the index,
+		 * only record the file at dest->path in the appropriate
+		 * higher stage.
 		 */
-		if (update_file(o, 0, &dest->oid, dest->mode, alt_path))
+		if (update_file(opt, 0, dest, file_path))
+			return -1;
+		if (file_path != dest->path)
+			free(file_path);
+		if (update_stages(opt, dest->path, NULL,
+				  ren->branch == opt->branch1 ? dest : NULL,
+				  ren->branch == opt->branch1 ? NULL : dest))
 			return -1;
-		free(alt_path);
-		return update_stages(o, dest->path, NULL,
-				     rename_branch == o->branch1 ? dest : NULL,
-				     rename_branch == o->branch1 ? NULL : dest);
+		return 0; /* not clean, but conflicted */
+	} else {
+		/* Update dest->path both in index and in worktree */
+		if (update_file(opt, 1, dest, dest->path))
+			return -1;
+		return 1; /* clean */
 	}
-
-	/* Update dest->path both in index and in worktree */
-	if (update_file(o, 1, &dest->oid, dest->mode, dest->path))
-		return -1;
-	return 0;
 }
 
-static int handle_change_delete(struct merge_options *o,
-				 const char *path, const char *old_path,
-				 const struct object_id *o_oid, int o_mode,
-				 const struct object_id *changed_oid,
-				 int changed_mode,
-				 const char *change_branch,
-				 const char *delete_branch,
-				 const char *change, const char *change_past)
+static int handle_change_delete(struct merge_options *opt,
+				const char *path, const char *old_path,
+				const struct diff_filespec *o,
+				const struct diff_filespec *changed,
+				const char *change_branch,
+				const char *delete_branch,
+				const char *change, const char *change_past)
 {
 	char *alt_path = NULL;
 	const char *update_path = path;
 	int ret = 0;
 
-	if (dir_in_way(path, !o->call_depth, 0) ||
-	    (!o->call_depth && would_lose_untracked(path))) {
-		update_path = alt_path = unique_path(o, path, change_branch);
+	if (dir_in_way(opt->repo->index, path, !opt->priv->call_depth, 0) ||
+	    (!opt->priv->call_depth && would_lose_untracked(opt, path))) {
+		update_path = alt_path = unique_path(opt, path, change_branch);
 	}
 
-	if (o->call_depth) {
+	if (opt->priv->call_depth) {
 		/*
 		 * We cannot arbitrarily accept either a_sha or b_sha as
 		 * correct; since there is no true "middle point" between
 		 * them, simply reuse the base version for virtual merge base.
 		 */
-		ret = remove_file_from_cache(path);
+		ret = remove_file_from_index(opt->repo->index, path);
 		if (!ret)
-			ret = update_file(o, 0, o_oid, o_mode, update_path);
+			ret = update_file(opt, 0, o, update_path);
 	} else {
+		/*
+		 * Despite the four nearly duplicate messages and argument
+		 * lists below and the ugliness of the nested if-statements,
+		 * having complete messages makes the job easier for
+		 * translators.
+		 *
+		 * The slight variance among the cases is due to the fact
+		 * that:
+		 *   1) directory/file conflicts (in effect if
+		 *      !alt_path) could cause us to need to write the
+		 *      file to a different path.
+		 *   2) renames (in effect if !old_path) could mean that
+		 *      there are two names for the path that the user
+		 *      may know the file by.
+		 */
 		if (!alt_path) {
 			if (!old_path) {
-				output(o, 1, _("CONFLICT (%s/delete): %s deleted in %s "
+				output(opt, 1, _("CONFLICT (%s/delete): %s deleted in %s "
 				       "and %s in %s. Version %s of %s left in tree."),
 				       change, path, delete_branch, change_past,
 				       change_branch, change_branch, path);
 			} else {
-				output(o, 1, _("CONFLICT (%s/delete): %s deleted in %s "
+				output(opt, 1, _("CONFLICT (%s/delete): %s deleted in %s "
 				       "and %s to %s in %s. Version %s of %s left in tree."),
 				       change, old_path, delete_branch, change_past, path,
 				       change_branch, change_branch, path);
 			}
 		} else {
 			if (!old_path) {
-				output(o, 1, _("CONFLICT (%s/delete): %s deleted in %s "
+				output(opt, 1, _("CONFLICT (%s/delete): %s deleted in %s "
 				       "and %s in %s. Version %s of %s left in tree at %s."),
 				       change, path, delete_branch, change_past,
 				       change_branch, change_branch, path, alt_path);
 			} else {
-				output(o, 1, _("CONFLICT (%s/delete): %s deleted in %s "
+				output(opt, 1, _("CONFLICT (%s/delete): %s deleted in %s "
 				       "and %s to %s in %s. Version %s of %s left in tree at %s."),
 				       change, old_path, delete_branch, change_past, path,
 				       change_branch, change_branch, path, alt_path);
@@ -1497,155 +1493,259 @@ static int handle_change_delete(struct m
 		}
 		/*
 		 * No need to call update_file() on path when change_branch ==
-		 * o->branch1 && !alt_path, since that would needlessly touch
+		 * opt->branch1 && !alt_path, since that would needlessly touch
 		 * path.  We could call update_file_flags() with update_cache=0
 		 * and update_wd=0, but that's a no-op.
 		 */
-		if (change_branch != o->branch1 || alt_path)
-			ret = update_file(o, 0, changed_oid, changed_mode, update_path);
+		if (change_branch != opt->branch1 || alt_path)
+			ret = update_file(opt, 0, changed, update_path);
 	}
 	free(alt_path);
 
 	return ret;
 }
 
-static int conflict_rename_delete(struct merge_options *o,
-				   struct diff_filepair *pair,
-				   const char *rename_branch,
-				   const char *delete_branch)
-{
-	const struct diff_filespec *orig = pair->one;
-	const struct diff_filespec *dest = pair->two;
-
-	if (handle_change_delete(o,
-				 o->call_depth ? orig->path : dest->path,
-				 o->call_depth ? NULL : orig->path,
-				 &orig->oid, orig->mode,
-				 &dest->oid, dest->mode,
+static int handle_rename_delete(struct merge_options *opt,
+				struct rename_conflict_info *ci)
+{
+	const struct rename *ren = ci->ren1;
+	const struct diff_filespec *orig = ren->pair->one;
+	const struct diff_filespec *dest = ren->pair->two;
+	const char *rename_branch = ren->branch;
+	const char *delete_branch = (opt->branch1 == ren->branch ?
+				     opt->branch2 : opt->branch1);
+
+	if (handle_change_delete(opt,
+				 opt->priv->call_depth ? orig->path : dest->path,
+				 opt->priv->call_depth ? NULL : orig->path,
+				 orig, dest,
 				 rename_branch, delete_branch,
 				 _("rename"), _("renamed")))
 		return -1;
 
-	if (o->call_depth)
-		return remove_file_from_cache(dest->path);
+	if (opt->priv->call_depth)
+		return remove_file_from_index(opt->repo->index, dest->path);
 	else
-		return update_stages(o, dest->path, NULL,
-				     rename_branch == o->branch1 ? dest : NULL,
-				     rename_branch == o->branch1 ? NULL : dest);
-}
-
-static struct diff_filespec *filespec_from_entry(struct diff_filespec *target,
-						 struct stage_data *entry,
-						 int stage)
-{
-	struct object_id *oid = &entry->stages[stage].oid;
-	unsigned mode = entry->stages[stage].mode;
-	if (mode == 0 || is_null_oid(oid))
-		return NULL;
-	oidcpy(&target->oid, oid);
-	target->mode = mode;
-	return target;
+		return update_stages(opt, dest->path, NULL,
+				     rename_branch == opt->branch1 ? dest : NULL,
+				     rename_branch == opt->branch1 ? NULL : dest);
 }
 
-static int handle_file(struct merge_options *o,
-			struct diff_filespec *rename,
-			int stage,
-			struct rename_conflict_info *ci)
+static int handle_file_collision(struct merge_options *opt,
+				 const char *collide_path,
+				 const char *prev_path1,
+				 const char *prev_path2,
+				 const char *branch1, const char *branch2,
+				 struct diff_filespec *a,
+				 struct diff_filespec *b)
 {
-	char *dst_name = rename->path;
-	struct stage_data *dst_entry;
-	const char *cur_branch, *other_branch;
-	struct diff_filespec other;
-	struct diff_filespec *add;
-	int ret;
+	struct merge_file_info mfi;
+	struct diff_filespec null;
+	char *alt_path = NULL;
+	const char *update_path = collide_path;
 
-	if (stage == 2) {
-		dst_entry = ci->dst_entry1;
-		cur_branch = ci->branch1;
-		other_branch = ci->branch2;
-	} else {
-		dst_entry = ci->dst_entry2;
-		cur_branch = ci->branch2;
-		other_branch = ci->branch1;
+	/*
+	 * It's easiest to get the correct things into stage 2 and 3, and
+	 * to make sure that the content merge puts HEAD before the other
+	 * branch if we just ensure that branch1 == opt->branch1.  So, simply
+	 * flip arguments around if we don't have that.
+	 */
+	if (branch1 != opt->branch1) {
+		return handle_file_collision(opt, collide_path,
+					     prev_path2, prev_path1,
+					     branch2, branch1,
+					     b, a);
 	}
 
-	add = filespec_from_entry(&other, dst_entry, stage ^ 1);
-	if (add) {
-		int ren_src_was_dirty = was_dirty(o, rename->path);
-		char *add_name = unique_path(o, rename->path, other_branch);
-		if (update_file(o, 0, &add->oid, add->mode, add_name))
-			return -1;
+	/*
+	 * In the recursive case, we just opt to undo renames
+	 */
+	if (opt->priv->call_depth && (prev_path1 || prev_path2)) {
+		/* Put first file (a->oid, a->mode) in its original spot */
+		if (prev_path1) {
+			if (update_file(opt, 1, a, prev_path1))
+				return -1;
+		} else {
+			if (update_file(opt, 1, a, collide_path))
+				return -1;
+		}
 
-		if (ren_src_was_dirty) {
-			output(o, 1, _("Refusing to lose dirty file at %s"),
-			       rename->path);
+		/* Put second file (b->oid, b->mode) in its original spot */
+		if (prev_path2) {
+			if (update_file(opt, 1, b, prev_path2))
+				return -1;
+		} else {
+			if (update_file(opt, 1, b, collide_path))
+				return -1;
 		}
-		/*
-		 * Because the double negatives somehow keep confusing me...
-		 *    1) update_wd iff !ren_src_was_dirty.
-		 *    2) no_wd iff !update_wd
-		 *    3) so, no_wd == !!ren_src_was_dirty == ren_src_was_dirty
-		 */
-		remove_file(o, 0, rename->path, ren_src_was_dirty);
-		dst_name = unique_path(o, rename->path, cur_branch);
+
+		/* Don't leave something at collision path if unrenaming both */
+		if (prev_path1 && prev_path2)
+			remove_file(opt, 1, collide_path, 0);
+
+		return 0;
+	}
+
+	/* Remove rename sources if rename/add or rename/rename(2to1) */
+	if (prev_path1)
+		remove_file(opt, 1, prev_path1,
+			    opt->priv->call_depth || would_lose_untracked(opt, prev_path1));
+	if (prev_path2)
+		remove_file(opt, 1, prev_path2,
+			    opt->priv->call_depth || would_lose_untracked(opt, prev_path2));
+
+	/*
+	 * Remove the collision path, if it wouldn't cause dirty contents
+	 * or an untracked file to get lost.  We'll either overwrite with
+	 * merged contents, or just write out to differently named files.
+	 */
+	if (was_dirty(opt, collide_path)) {
+		output(opt, 1, _("Refusing to lose dirty file at %s"),
+		       collide_path);
+		update_path = alt_path = unique_path(opt, collide_path, "merged");
+	} else if (would_lose_untracked(opt, collide_path)) {
+		/*
+		 * Only way we get here is if both renames were from
+		 * a directory rename AND user had an untracked file
+		 * at the location where both files end up after the
+		 * two directory renames.  See testcase 10d of t6043.
+		 */
+		output(opt, 1, _("Refusing to lose untracked file at "
+			       "%s, even though it's in the way."),
+		       collide_path);
+		update_path = alt_path = unique_path(opt, collide_path, "merged");
 	} else {
-		if (dir_in_way(rename->path, !o->call_depth, 0)) {
-			dst_name = unique_path(o, rename->path, cur_branch);
-			output(o, 1, _("%s is a directory in %s adding as %s instead"),
-			       rename->path, other_branch, dst_name);
-		} else if (!o->call_depth &&
-			   would_lose_untracked(rename->path)) {
-			dst_name = unique_path(o, rename->path, cur_branch);
-			output(o, 1, _("Refusing to lose untracked file at %s; "
-				       "adding as %s instead"),
-			       rename->path, dst_name);
-		}
-	}
-	if ((ret = update_file(o, 0, &rename->oid, rename->mode, dst_name)))
-		; /* fall through, do allow dst_name to be released */
-	else if (stage == 2)
-		ret = update_stages(o, rename->path, NULL, rename, add);
-	else
-		ret = update_stages(o, rename->path, NULL, add, rename);
+		/*
+		 * FIXME: It's possible that the two files are identical
+		 * and that the current working copy happens to match, in
+		 * which case we are unnecessarily touching the working
+		 * tree file.  It's not a likely enough scenario that I
+		 * want to code up the checks for it and a better fix is
+		 * available if we restructure how unpack_trees() and
+		 * merge-recursive interoperate anyway, so punting for
+		 * now...
+		 */
+		remove_file(opt, 0, collide_path, 0);
+	}
+
+	/* Store things in diff_filespecs for functions that need it */
+	null.path = (char *)collide_path;
+	oidcpy(&null.oid, &null_oid);
+	null.mode = 0;
+
+	if (merge_mode_and_contents(opt, &null, a, b, collide_path,
+				    branch1, branch2, opt->priv->call_depth * 2, &mfi))
+		return -1;
+	mfi.clean &= !alt_path;
+	if (update_file(opt, mfi.clean, &mfi.blob, update_path))
+		return -1;
+	if (!mfi.clean && !opt->priv->call_depth &&
+	    update_stages(opt, collide_path, NULL, a, b))
+		return -1;
+	free(alt_path);
+	/*
+	 * FIXME: If both a & b both started with conflicts (only possible
+	 * if they came from a rename/rename(2to1)), but had IDENTICAL
+	 * contents including those conflicts, then in the next line we claim
+	 * it was clean.  If someone cares about this case, we should have the
+	 * caller notify us if we started with conflicts.
+	 */
+	return mfi.clean;
+}
+
+static int handle_rename_add(struct merge_options *opt,
+			     struct rename_conflict_info *ci)
+{
+	/* a was renamed to c, and a separate c was added. */
+	struct diff_filespec *a = ci->ren1->pair->one;
+	struct diff_filespec *c = ci->ren1->pair->two;
+	char *path = c->path;
+	char *prev_path_desc;
+	struct merge_file_info mfi;
 
-	if (dst_name != rename->path)
-		free(dst_name);
+	const char *rename_branch = ci->ren1->branch;
+	const char *add_branch = (opt->branch1 == rename_branch ?
+				  opt->branch2 : opt->branch1);
+	int other_stage = (ci->ren1->branch == opt->branch1 ? 3 : 2);
+
+	output(opt, 1, _("CONFLICT (rename/add): "
+	       "Rename %s->%s in %s.  Added %s in %s"),
+	       a->path, c->path, rename_branch,
+	       c->path, add_branch);
+
+	prev_path_desc = xstrfmt("version of %s from %s", path, a->path);
+	ci->ren1->src_entry->stages[other_stage].path = a->path;
+	if (merge_mode_and_contents(opt, a, c,
+				    &ci->ren1->src_entry->stages[other_stage],
+				    prev_path_desc,
+				    opt->branch1, opt->branch2,
+				    1 + opt->priv->call_depth * 2, &mfi))
+		return -1;
+	free(prev_path_desc);
 
-	return ret;
+	ci->ren1->dst_entry->stages[other_stage].path = mfi.blob.path = c->path;
+	return handle_file_collision(opt,
+				     c->path, a->path, NULL,
+				     rename_branch, add_branch,
+				     &mfi.blob,
+				     &ci->ren1->dst_entry->stages[other_stage]);
 }
 
-static int conflict_rename_rename_1to2(struct merge_options *o,
-					struct rename_conflict_info *ci)
+static char *find_path_for_conflict(struct merge_options *opt,
+				    const char *path,
+				    const char *branch1,
+				    const char *branch2)
+{
+	char *new_path = NULL;
+	if (dir_in_way(opt->repo->index, path, !opt->priv->call_depth, 0)) {
+		new_path = unique_path(opt, path, branch1);
+		output(opt, 1, _("%s is a directory in %s adding "
+			       "as %s instead"),
+		       path, branch2, new_path);
+	} else if (would_lose_untracked(opt, path)) {
+		new_path = unique_path(opt, path, branch1);
+		output(opt, 1, _("Refusing to lose untracked file"
+			       " at %s; adding as %s instead"),
+		       path, new_path);
+	}
+
+	return new_path;
+}
+
+static int handle_rename_rename_1to2(struct merge_options *opt,
+				     struct rename_conflict_info *ci)
 {
 	/* One file was renamed in both branches, but to different names. */
-	struct diff_filespec *one = ci->pair1->one;
-	struct diff_filespec *a = ci->pair1->two;
-	struct diff_filespec *b = ci->pair2->two;
+	struct merge_file_info mfi;
+	struct diff_filespec *add;
+	struct diff_filespec *o = ci->ren1->pair->one;
+	struct diff_filespec *a = ci->ren1->pair->two;
+	struct diff_filespec *b = ci->ren2->pair->two;
+	char *path_desc;
 
-	output(o, 1, _("CONFLICT (rename/rename): "
+	output(opt, 1, _("CONFLICT (rename/rename): "
 	       "Rename \"%s\"->\"%s\" in branch \"%s\" "
 	       "rename \"%s\"->\"%s\" in \"%s\"%s"),
-	       one->path, a->path, ci->branch1,
-	       one->path, b->path, ci->branch2,
-	       o->call_depth ? _(" (left unresolved)") : "");
-	if (o->call_depth) {
-		struct merge_file_info mfi;
-		struct diff_filespec other;
-		struct diff_filespec *add;
-		if (merge_file_one(o, one->path,
-				 &one->oid, one->mode,
-				 &a->oid, a->mode,
-				 &b->oid, b->mode,
-				 ci->branch1, ci->branch2, &mfi))
-			return -1;
+	       o->path, a->path, ci->ren1->branch,
+	       o->path, b->path, ci->ren2->branch,
+	       opt->priv->call_depth ? _(" (left unresolved)") : "");
+
+	path_desc = xstrfmt("%s and %s, both renamed from %s",
+			    a->path, b->path, o->path);
+	if (merge_mode_and_contents(opt, o, a, b, path_desc,
+				    ci->ren1->branch, ci->ren2->branch,
+				    opt->priv->call_depth * 2, &mfi))
+		return -1;
+	free(path_desc);
 
+	if (opt->priv->call_depth) {
 		/*
 		 * FIXME: For rename/add-source conflicts (if we could detect
 		 * such), this is wrong.  We should instead find a unique
 		 * pathname and then either rename the add-source file to that
 		 * unique path, or use that unique path instead of src here.
 		 */
-		if (update_file(o, 0, &mfi.oid, mfi.mode, one->path))
+		if (update_file(opt, 0, &mfi.blob, o->path))
 			return -1;
 
 		/*
@@ -1656,140 +1756,134 @@ static int conflict_rename_rename_1to2(s
 		 * such cases, we should keep the added file around,
 		 * resolving the conflict at that path in its favor.
 		 */
-		add = filespec_from_entry(&other, ci->dst_entry1, 2 ^ 1);
-		if (add) {
-			if (update_file(o, 0, &add->oid, add->mode, a->path))
+		add = &ci->ren1->dst_entry->stages[2 ^ 1];
+		if (is_valid(add)) {
+			if (update_file(opt, 0, add, a->path))
 				return -1;
 		}
 		else
-			remove_file_from_cache(a->path);
-		add = filespec_from_entry(&other, ci->dst_entry2, 3 ^ 1);
-		if (add) {
-			if (update_file(o, 0, &add->oid, add->mode, b->path))
+			remove_file_from_index(opt->repo->index, a->path);
+		add = &ci->ren2->dst_entry->stages[3 ^ 1];
+		if (is_valid(add)) {
+			if (update_file(opt, 0, add, b->path))
 				return -1;
 		}
 		else
-			remove_file_from_cache(b->path);
-	} else if (handle_file(o, a, 2, ci) || handle_file(o, b, 3, ci))
-		return -1;
+			remove_file_from_index(opt->repo->index, b->path);
+	} else {
+		/*
+		 * For each destination path, we need to see if there is a
+		 * rename/add collision.  If not, we can write the file out
+		 * to the specified location.
+		 */
+		add = &ci->ren1->dst_entry->stages[2 ^ 1];
+		if (is_valid(add)) {
+			add->path = mfi.blob.path = a->path;
+			if (handle_file_collision(opt, a->path,
+						  NULL, NULL,
+						  ci->ren1->branch,
+						  ci->ren2->branch,
+						  &mfi.blob, add) < 0)
+				return -1;
+		} else {
+			char *new_path = find_path_for_conflict(opt, a->path,
+								ci->ren1->branch,
+								ci->ren2->branch);
+			if (update_file(opt, 0, &mfi.blob,
+					new_path ? new_path : a->path))
+				return -1;
+			free(new_path);
+			if (update_stages(opt, a->path, NULL, a, NULL))
+				return -1;
+		}
+
+		add = &ci->ren2->dst_entry->stages[3 ^ 1];
+		if (is_valid(add)) {
+			add->path = mfi.blob.path = b->path;
+			if (handle_file_collision(opt, b->path,
+						  NULL, NULL,
+						  ci->ren1->branch,
+						  ci->ren2->branch,
+						  add, &mfi.blob) < 0)
+				return -1;
+		} else {
+			char *new_path = find_path_for_conflict(opt, b->path,
+								ci->ren2->branch,
+								ci->ren1->branch);
+			if (update_file(opt, 0, &mfi.blob,
+					new_path ? new_path : b->path))
+				return -1;
+			free(new_path);
+			if (update_stages(opt, b->path, NULL, NULL, b))
+				return -1;
+		}
+	}
 
 	return 0;
 }
 
-static int conflict_rename_rename_2to1(struct merge_options *o,
-					struct rename_conflict_info *ci)
+static int handle_rename_rename_2to1(struct merge_options *opt,
+				     struct rename_conflict_info *ci)
 {
 	/* Two files, a & b, were renamed to the same thing, c. */
-	struct diff_filespec *a = ci->pair1->one;
-	struct diff_filespec *b = ci->pair2->one;
-	struct diff_filespec *c1 = ci->pair1->two;
-	struct diff_filespec *c2 = ci->pair2->two;
+	struct diff_filespec *a = ci->ren1->pair->one;
+	struct diff_filespec *b = ci->ren2->pair->one;
+	struct diff_filespec *c1 = ci->ren1->pair->two;
+	struct diff_filespec *c2 = ci->ren2->pair->two;
 	char *path = c1->path; /* == c2->path */
 	char *path_side_1_desc;
 	char *path_side_2_desc;
 	struct merge_file_info mfi_c1;
 	struct merge_file_info mfi_c2;
-	int ret;
+	int ostage1, ostage2;
 
-	output(o, 1, _("CONFLICT (rename/rename): "
+	output(opt, 1, _("CONFLICT (rename/rename): "
 	       "Rename %s->%s in %s. "
 	       "Rename %s->%s in %s"),
-	       a->path, c1->path, ci->branch1,
-	       b->path, c2->path, ci->branch2);
+	       a->path, c1->path, ci->ren1->branch,
+	       b->path, c2->path, ci->ren2->branch);
 
-	remove_file(o, 1, a->path, o->call_depth || would_lose_untracked(a->path));
-	remove_file(o, 1, b->path, o->call_depth || would_lose_untracked(b->path));
-
-	path_side_1_desc = xstrfmt("%s (was %s)", path, a->path);
-	path_side_2_desc = xstrfmt("%s (was %s)", path, b->path);
-	if (merge_file_special_markers(o, a, c1, &ci->ren1_other,
-				       path_side_1_desc,
-				       o->branch1, c1->path,
-				       o->branch2, ci->ren1_other.path, &mfi_c1) ||
-	    merge_file_special_markers(o, b, &ci->ren2_other, c2,
-				       path_side_2_desc,
-				       o->branch1, ci->ren2_other.path,
-				       o->branch2, c2->path, &mfi_c2))
+	path_side_1_desc = xstrfmt("version of %s from %s", path, a->path);
+	path_side_2_desc = xstrfmt("version of %s from %s", path, b->path);
+	ostage1 = ci->ren1->branch == opt->branch1 ? 3 : 2;
+	ostage2 = ostage1 ^ 1;
+	ci->ren1->src_entry->stages[ostage1].path = a->path;
+	ci->ren2->src_entry->stages[ostage2].path = b->path;
+	if (merge_mode_and_contents(opt, a, c1,
+				    &ci->ren1->src_entry->stages[ostage1],
+				    path_side_1_desc,
+				    opt->branch1, opt->branch2,
+				    1 + opt->priv->call_depth * 2, &mfi_c1) ||
+	    merge_mode_and_contents(opt, b,
+				    &ci->ren2->src_entry->stages[ostage2],
+				    c2, path_side_2_desc,
+				    opt->branch1, opt->branch2,
+				    1 + opt->priv->call_depth * 2, &mfi_c2))
 		return -1;
 	free(path_side_1_desc);
 	free(path_side_2_desc);
+	mfi_c1.blob.path = path;
+	mfi_c2.blob.path = path;
 
-	if (o->call_depth) {
-		/*
-		 * If mfi_c1.clean && mfi_c2.clean, then it might make
-		 * sense to do a two-way merge of those results.  But, I
-		 * think in all cases, it makes sense to have the virtual
-		 * merge base just undo the renames; they can be detected
-		 * again later for the non-recursive merge.
-		 */
-		remove_file(o, 0, path, 0);
-		ret = update_file(o, 0, &mfi_c1.oid, mfi_c1.mode, a->path);
-		if (!ret)
-			ret = update_file(o, 0, &mfi_c2.oid, mfi_c2.mode,
-					  b->path);
-	} else {
-		char *new_path1 = unique_path(o, path, ci->branch1);
-		char *new_path2 = unique_path(o, path, ci->branch2);
-		output(o, 1, _("Renaming %s to %s and %s to %s instead"),
-		       a->path, new_path1, b->path, new_path2);
-		if (was_dirty(o, path))
-			output(o, 1, _("Refusing to lose dirty file at %s"),
-			       path);
-		else if (would_lose_untracked(path))
-			/*
-			 * Only way we get here is if both renames were from
-			 * a directory rename AND user had an untracked file
-			 * at the location where both files end up after the
-			 * two directory renames.  See testcase 10d of t6043.
-			 */
-			output(o, 1, _("Refusing to lose untracked file at "
-				       "%s, even though it's in the way."),
-			       path);
-		else
-			remove_file(o, 0, path, 0);
-		ret = update_file(o, 0, &mfi_c1.oid, mfi_c1.mode, new_path1);
-		if (!ret)
-			ret = update_file(o, 0, &mfi_c2.oid, mfi_c2.mode,
-					  new_path2);
-		/*
-		 * unpack_trees() actually populates the index for us for
-		 * "normal" rename/rename(2to1) situtations so that the
-		 * correct entries are at the higher stages, which would
-		 * make the call below to update_stages_for_stage_data
-		 * unnecessary.  However, if either of the renames came
-		 * from a directory rename, then unpack_trees() will not
-		 * have gotten the right data loaded into the index, so we
-		 * need to do so now.  (While it'd be tempting to move this
-		 * call to update_stages_for_stage_data() to
-		 * apply_directory_rename_modifications(), that would break
-		 * our intermediate calls to would_lose_untracked() since
-		 * those rely on the current in-memory index.  See also the
-		 * big "NOTE" in update_stages()).
-		 */
-		if (update_stages_for_stage_data(o, path, ci->dst_entry1))
-			ret = -1;
-
-		free(new_path2);
-		free(new_path1);
-	}
-
-	return ret;
+	return handle_file_collision(opt, path, a->path, b->path,
+				     ci->ren1->branch, ci->ren2->branch,
+				     &mfi_c1.blob, &mfi_c2.blob);
 }
 
 /*
  * Get the diff_filepairs changed between o_tree and tree.
  */
-static struct diff_queue_struct *get_diffpairs(struct merge_options *o,
+static struct diff_queue_struct *get_diffpairs(struct merge_options *opt,
 					       struct tree *o_tree,
 					       struct tree *tree)
 {
 	struct diff_queue_struct *ret;
 	struct diff_options opts;
 
-	diff_setup(&opts);
+	repo_diff_setup(opt->repo, &opts);
 	opts.flags.recursive = 1;
 	opts.flags.rename_empty = 0;
-	opts.detect_rename = merge_detect_rename(o);
+	opts.detect_rename = merge_detect_rename(opt);
 	/*
 	 * We do not have logic to handle the detection of copies.  In
 	 * fact, it may not even make sense to add such logic: would we
@@ -1798,17 +1892,15 @@ static struct diff_queue_struct *get_dif
 	 */
 	if (opts.detect_rename > DIFF_DETECT_RENAME)
 		opts.detect_rename = DIFF_DETECT_RENAME;
-	opts.rename_limit = o->merge_rename_limit >= 0 ? o->merge_rename_limit :
-			    o->diff_rename_limit >= 0 ? o->diff_rename_limit :
-			    1000;
-	opts.rename_score = o->rename_score;
-	opts.show_rename_progress = o->show_rename_progress;
+	opts.rename_limit = (opt->rename_limit >= 0) ? opt->rename_limit : 1000;
+	opts.rename_score = opt->rename_score;
+	opts.show_rename_progress = opt->show_rename_progress;
 	opts.output_format = DIFF_FORMAT_NO_OUTPUT;
 	diff_setup_done(&opts);
 	diff_tree_oid(&o_tree->object.oid, &tree->object.oid, "", &opts);
 	diffcore_std(&opts);
-	if (opts.needed_rename_limit > o->needed_rename_limit)
-		o->needed_rename_limit = opts.needed_rename_limit;
+	if (opts.needed_rename_limit > opt->priv->needed_rename_limit)
+		opt->priv->needed_rename_limit = opts.needed_rename_limit;
 
 	ret = xmalloc(sizeof(*ret));
 	*ret = diff_queued_diff;
@@ -1820,12 +1912,14 @@ static struct diff_queue_struct *get_dif
 	return ret;
 }
 
-static int tree_has_path(struct tree *tree, const char *path)
+static int tree_has_path(struct repository *r, struct tree *tree,
+			 const char *path)
 {
 	struct object_id hashy;
-	unsigned int mode_o;
+	unsigned short mode_o;
 
-	return !get_tree_entry(&tree->object.oid, path,
+	return !get_tree_entry(r,
+			       &tree->object.oid, path,
 			       &hashy, &mode_o);
 }
 
@@ -1846,6 +1940,16 @@ static char *apply_dir_rename(struct dir
 		return NULL;
 
 	oldlen = strlen(entry->dir);
+	if (entry->new_dir.len == 0)
+		/*
+		 * If someone renamed/merged a subdirectory into the root
+		 * directory (e.g. 'some/subdir' -> ''), then we want to
+		 * avoid returning
+		 *     '' + '/filename'
+		 * as the rename; we need to make old_path + oldlen advance
+		 * past the '/' character.
+		 */
+		oldlen++;
 	newlen = entry->new_dir.len + (strlen(old_path) - oldlen) + 1;
 	strbuf_grow(&new_path, newlen);
 	strbuf_addbuf(&new_path, &entry->new_dir);
@@ -1858,8 +1962,8 @@ static void get_renamed_dir_portion(cons
 				    char **old_dir, char **new_dir)
 {
 	char *end_of_old, *end_of_new;
-	int old_len, new_len;
 
+	/* Default return values: NULL, meaning no rename */
 	*old_dir = NULL;
 	*new_dir = NULL;
 
@@ -1870,43 +1974,91 @@ static void get_renamed_dir_portion(cons
 	 *    "a/b/c/d" was renamed to "a/b/some/thing/else"
 	 * so, for this example, this function returns "a/b/c/d" in
 	 * *old_dir and "a/b/some/thing/else" in *new_dir.
-	 *
-	 * Also, if the basename of the file changed, we don't care.  We
-	 * want to know which portion of the directory, if any, changed.
+	 */
+
+	/*
+	 * If the basename of the file changed, we don't care.  We want
+	 * to know which portion of the directory, if any, changed.
 	 */
 	end_of_old = strrchr(old_path, '/');
 	end_of_new = strrchr(new_path, '/');
 
-	if (end_of_old == NULL || end_of_new == NULL)
+	/*
+	 * If end_of_old is NULL, old_path wasn't in a directory, so there
+	 * could not be a directory rename (our rule elsewhere that a
+	 * directory which still exists is not considered to have been
+	 * renamed means the root directory can never be renamed -- because
+	 * the root directory always exists).
+	 */
+	if (end_of_old == NULL)
+		return; /* Note: *old_dir and *new_dir are still NULL */
+
+	/*
+	 * If new_path contains no directory (end_of_new is NULL), then we
+	 * have a rename of old_path's directory to the root directory.
+	 */
+	if (end_of_new == NULL) {
+		*old_dir = xstrndup(old_path, end_of_old - old_path);
+		*new_dir = xstrdup("");
 		return;
+	}
+
+	/* Find the first non-matching character traversing backwards */
 	while (*--end_of_new == *--end_of_old &&
 	       end_of_old != old_path &&
 	       end_of_new != new_path)
 		; /* Do nothing; all in the while loop */
+
 	/*
-	 * We've found the first non-matching character in the directory
-	 * paths.  That means the current directory we were comparing
-	 * represents the rename.  Move end_of_old and end_of_new back
-	 * to the full directory name.
-	 */
-	if (*end_of_old == '/')
-		end_of_old++;
-	if (*end_of_old != '/')
-		end_of_new++;
-	end_of_old = strchr(end_of_old, '/');
-	end_of_new = strchr(end_of_new, '/');
-
-	/*
-	 * It may have been the case that old_path and new_path were the same
-	 * directory all along.  Don't claim a rename if they're the same.
-	 */
-	old_len = end_of_old - old_path;
-	new_len = end_of_new - new_path;
-
-	if (old_len != new_len || strncmp(old_path, new_path, old_len)) {
-		*old_dir = xstrndup(old_path, old_len);
-		*new_dir = xstrndup(new_path, new_len);
+	 * If both got back to the beginning of their strings, then the
+	 * directory didn't change at all, only the basename did.
+	 */
+	if (end_of_old == old_path && end_of_new == new_path &&
+	    *end_of_old == *end_of_new)
+		return; /* Note: *old_dir and *new_dir are still NULL */
+
+	/*
+	 * If end_of_new got back to the beginning of its string, and
+	 * end_of_old got back to the beginning of some subdirectory, then
+	 * we have a rename/merge of a subdirectory into the root, which
+	 * needs slightly special handling.
+	 *
+	 * Note: There is no need to consider the opposite case, with a
+	 * rename/merge of the root directory into some subdirectory
+	 * because as noted above the root directory always exists so it
+	 * cannot be considered to be renamed.
+	 */
+	if (end_of_new == new_path &&
+	    end_of_old != old_path && end_of_old[-1] == '/') {
+		*old_dir = xstrndup(old_path, --end_of_old - old_path);
+		*new_dir = xstrdup("");
+		return;
 	}
+
+	/*
+	 * We've found the first non-matching character in the directory
+	 * paths.  That means the current characters we were looking at
+	 * were part of the first non-matching subdir name going back from
+	 * the end of the strings.  Get the whole name by advancing both
+	 * end_of_old and end_of_new to the NEXT '/' character.  That will
+	 * represent the entire directory rename.
+	 *
+	 * The reason for the increment is cases like
+	 *    a/b/star/foo/whatever.c -> a/b/tar/foo/random.c
+	 * After dropping the basename and going back to the first
+	 * non-matching character, we're now comparing:
+	 *    a/b/s          and         a/b/
+	 * and we want to be comparing:
+	 *    a/b/star/      and         a/b/tar/
+	 * but without the pre-increment, the one on the right would stay
+	 * a/b/.
+	 */
+	end_of_old = strchr(++end_of_old, '/');
+	end_of_new = strchr(++end_of_new, '/');
+
+	/* Copy the old and new directories into *old_dir and *new_dir. */
+	*old_dir = xstrndup(old_path, end_of_old - old_path);
+	*new_dir = xstrndup(new_path, end_of_new - new_path);
 }
 
 static void remove_hashmap_entries(struct hashmap *dir_renames,
@@ -1917,7 +2069,7 @@ static void remove_hashmap_entries(struc
 
 	for (i = 0; i < items_to_remove->nr; i++) {
 		entry = items_to_remove->items[i].util;
-		hashmap_remove(dir_renames, entry, NULL);
+		hashmap_remove(dir_renames, &entry->ent, NULL);
 	}
 	string_list_clear(items_to_remove, 0);
 }
@@ -1927,7 +2079,7 @@ static void remove_hashmap_entries(struc
  * level conflicts for the renamed location.  If there is a rename and
  * there are no conflicts, return the new name.  Otherwise, return NULL.
  */
-static char *handle_path_level_conflicts(struct merge_options *o,
+static char *handle_path_level_conflicts(struct merge_options *opt,
 					 const char *path,
 					 struct dir_rename_entry *entry,
 					 struct hashmap *collisions,
@@ -1948,7 +2100,7 @@ static char *handle_path_level_conflicts
 		/* This should only happen when entry->non_unique_new_dir set */
 		if (!entry->non_unique_new_dir)
 			BUG("entry->non_unqiue_dir not set and !new_path");
-		output(o, 1, _("CONFLICT (directory rename split): "
+		output(opt, 1, _("CONFLICT (directory rename split): "
 			       "Unclear where to place %s because directory "
 			       "%s was renamed to multiple other directories, "
 			       "with no destination getting a majority of the "
@@ -1976,11 +2128,11 @@ static char *handle_path_level_conflicts
 	 */
 	if (collision_ent->reported_already) {
 		clean = 0;
-	} else if (tree_has_path(tree, new_path)) {
+	} else if (tree_has_path(opt->repo, tree, new_path)) {
 		collision_ent->reported_already = 1;
 		strbuf_add_separated_string_list(&collision_paths, ", ",
 						 &collision_ent->source_files);
-		output(o, 1, _("CONFLICT (implicit dir rename): Existing "
+		output(opt, 1, _("CONFLICT (implicit dir rename): Existing "
 			       "file/dir at %s in the way of implicit "
 			       "directory rename(s) putting the following "
 			       "path(s) there: %s."),
@@ -1990,7 +2142,7 @@ static char *handle_path_level_conflicts
 		collision_ent->reported_already = 1;
 		strbuf_add_separated_string_list(&collision_paths, ", ",
 						 &collision_ent->source_files);
-		output(o, 1, _("CONFLICT (implicit dir rename): Cannot map "
+		output(opt, 1, _("CONFLICT (implicit dir rename): Cannot map "
 			       "more than one path to %s; implicit directory "
 			       "renames tried to put these paths there: %s"),
 		       new_path, collision_paths.buf);
@@ -2027,7 +2179,7 @@ static char *handle_path_level_conflicts
  *         causes conflicts for files within those merged directories, then
  *         that should be detected at the individual path level.
  */
-static void handle_directory_level_conflicts(struct merge_options *o,
+static void handle_directory_level_conflicts(struct merge_options *opt,
 					     struct hashmap *dir_re_head,
 					     struct tree *head,
 					     struct hashmap *dir_re_merge,
@@ -2040,8 +2192,8 @@ static void handle_directory_level_confl
 	struct string_list remove_from_head = STRING_LIST_INIT_NODUP;
 	struct string_list remove_from_merge = STRING_LIST_INIT_NODUP;
 
-	hashmap_iter_init(dir_re_head, &iter);
-	while ((head_ent = hashmap_iter_next(&iter))) {
+	hashmap_for_each_entry(dir_re_head, &iter, head_ent,
+				ent /* member name */) {
 		merge_ent = dir_rename_find_entry(dir_re_merge, head_ent->dir);
 		if (merge_ent &&
 		    !head_ent->non_unique_new_dir &&
@@ -2054,7 +2206,7 @@ static void handle_directory_level_confl
 			string_list_append(&remove_from_merge,
 					   merge_ent->dir)->util = merge_ent;
 			strbuf_release(&merge_ent->new_dir);
-		} else if (tree_has_path(head, head_ent->dir)) {
+		} else if (tree_has_path(opt->repo, head, head_ent->dir)) {
 			/* 2. This wasn't a directory rename after all */
 			string_list_append(&remove_from_head,
 					   head_ent->dir)->util = head_ent;
@@ -2065,10 +2217,10 @@ static void handle_directory_level_confl
 	remove_hashmap_entries(dir_re_head, &remove_from_head);
 	remove_hashmap_entries(dir_re_merge, &remove_from_merge);
 
-	hashmap_iter_init(dir_re_merge, &iter);
-	while ((merge_ent = hashmap_iter_next(&iter))) {
+	hashmap_for_each_entry(dir_re_merge, &iter, merge_ent,
+				ent /* member name */) {
 		head_ent = dir_rename_find_entry(dir_re_head, merge_ent->dir);
-		if (tree_has_path(merge, merge_ent->dir)) {
+		if (tree_has_path(opt->repo, merge, merge_ent->dir)) {
 			/* 2. This wasn't a directory rename after all */
 			string_list_append(&remove_from_merge,
 					   merge_ent->dir)->util = merge_ent;
@@ -2082,11 +2234,11 @@ static void handle_directory_level_confl
 			 * know that head_ent->new_dir and merge_ent->new_dir
 			 * are different strings.
 			 */
-			output(o, 1, _("CONFLICT (rename/rename): "
+			output(opt, 1, _("CONFLICT (rename/rename): "
 				       "Rename directory %s->%s in %s. "
 				       "Rename directory %s->%s in %s"),
-			       head_ent->dir, head_ent->new_dir.buf, o->branch1,
-			       head_ent->dir, merge_ent->new_dir.buf, o->branch2);
+			       head_ent->dir, head_ent->new_dir.buf, opt->branch1,
+			       head_ent->dir, merge_ent->new_dir.buf, opt->branch2);
 			string_list_append(&remove_from_head,
 					   head_ent->dir)->util = head_ent;
 			strbuf_release(&head_ent->new_dir);
@@ -2100,8 +2252,7 @@ static void handle_directory_level_confl
 	remove_hashmap_entries(dir_re_merge, &remove_from_merge);
 }
 
-static struct hashmap *get_directory_renames(struct diff_queue_struct *pairs,
-					     struct tree *tree)
+static struct hashmap *get_directory_renames(struct diff_queue_struct *pairs)
 {
 	struct hashmap *dir_renames;
 	struct hashmap_iter iter;
@@ -2146,7 +2297,7 @@ static struct hashmap *get_directory_ren
 		if (!entry) {
 			entry = xmalloc(sizeof(*entry));
 			dir_rename_entry_init(entry, old_dir);
-			hashmap_put(dir_renames, entry);
+			hashmap_put(dir_renames, &entry->ent);
 		} else {
 			free(old_dir);
 		}
@@ -2171,8 +2322,8 @@ static struct hashmap *get_directory_ren
 	 * we set non_unique_new_dir.  Once we've determined the winner (or
 	 * that there is no winner), we no longer need possible_new_dirs.
 	 */
-	hashmap_iter_init(dir_renames, &iter);
-	while ((entry = hashmap_iter_next(&iter))) {
+	hashmap_for_each_entry(dir_renames, &iter, entry,
+				ent /* member name */) {
 		int max = 0;
 		int bad_max = 0;
 		char *best = NULL;
@@ -2213,7 +2364,7 @@ static struct dir_rename_entry *check_di
 {
 	char *temp = xstrdup(path);
 	char *end;
-	struct dir_rename_entry *entry = NULL;;
+	struct dir_rename_entry *entry = NULL;
 
 	while ((end = strrchr(temp, '/'))) {
 		*end = '\0';
@@ -2275,8 +2426,9 @@ static void compute_collisions(struct ha
 		if (!collision_ent) {
 			collision_ent = xcalloc(1,
 						sizeof(struct collision_entry));
-			hashmap_entry_init(collision_ent, strhash(new_path));
-			hashmap_put(collisions, collision_ent);
+			hashmap_entry_init(&collision_ent->ent,
+						strhash(new_path));
+			hashmap_put(collisions, &collision_ent->ent);
 			collision_ent->target_file = new_path;
 		} else {
 			free(new_path);
@@ -2286,7 +2438,7 @@ static void compute_collisions(struct ha
 	}
 }
 
-static char *check_for_directory_rename(struct merge_options *o,
+static char *check_for_directory_rename(struct merge_options *opt,
 					const char *path,
 					struct tree *tree,
 					struct hashmap *dir_renames,
@@ -2327,11 +2479,11 @@ static char *check_for_directory_rename(
 	 */
 	oentry = dir_rename_find_entry(dir_rename_exclusions, entry->new_dir.buf);
 	if (oentry) {
-		output(o, 1, _("WARNING: Avoiding applying %s -> %s rename "
+		output(opt, 1, _("WARNING: Avoiding applying %s -> %s rename "
 			       "to %s, because %s itself was renamed."),
 		       entry->dir, entry->new_dir.buf, path, entry->new_dir.buf);
 	} else {
-		new_path = handle_path_level_conflicts(o, path, entry,
+		new_path = handle_path_level_conflicts(opt, path, entry,
 						       collisions, tree);
 		*clean_merge &= (new_path != NULL);
 	}
@@ -2339,7 +2491,7 @@ static char *check_for_directory_rename(
 	return new_path;
 }
 
-static void apply_directory_rename_modifications(struct merge_options *o,
+static void apply_directory_rename_modifications(struct merge_options *opt,
 						 struct diff_filepair *pair,
 						 char *new_path,
 						 struct rename *re,
@@ -2347,8 +2499,7 @@ static void apply_directory_rename_modif
 						 struct tree *o_tree,
 						 struct tree *a_tree,
 						 struct tree *b_tree,
-						 struct string_list *entries,
-						 int *clean)
+						 struct string_list *entries)
 {
 	struct string_list_item *item;
 	int stage = (tree == a_tree ? 2 : 3);
@@ -2363,11 +2514,11 @@ static void apply_directory_rename_modif
 	 * saying the file would have been overwritten), but it might
 	 * be dirty, though.
 	 */
-	update_wd = !was_dirty(o, pair->two->path);
+	update_wd = !was_dirty(opt, pair->two->path);
 	if (!update_wd)
-		output(o, 1, _("Refusing to lose dirty file at %s"),
+		output(opt, 1, _("Refusing to lose dirty file at %s"),
 		       pair->two->path);
-	remove_file(o, 1, pair->two->path, !update_wd);
+	remove_file(opt, 1, pair->two->path, !update_wd);
 
 	/* Find or create a new re->dst_entry */
 	item = string_list_lookup(entries, new_path);
@@ -2399,7 +2550,7 @@ static void apply_directory_rename_modif
 		if (pair->status == 'R')
 			re->dst_entry->processed = 1;
 
-		re->dst_entry = insert_stage_data(new_path,
+		re->dst_entry = insert_stage_data(opt->repo, new_path,
 						  o_tree, a_tree, b_tree,
 						  entries);
 		item = string_list_insert(entries, new_path);
@@ -2419,24 +2570,27 @@ static void apply_directory_rename_modif
 	 * "NOTE" in update_stages(), doing so will modify the current
 	 * in-memory index which will break calls to would_lose_untracked()
 	 * that we need to make.  Instead, we need to just make sure that
-	 * the various conflict_rename_*() functions update the index
+	 * the various handle_rename_*() functions update the index
 	 * explicitly rather than relying on unpack_trees() to have done it.
 	 */
-	get_tree_entry(&tree->object.oid,
+	get_tree_entry(opt->repo,
+		       &tree->object.oid,
 		       pair->two->path,
 		       &re->dst_entry->stages[stage].oid,
 		       &re->dst_entry->stages[stage].mode);
 
-	/* Update pair status */
-	if (pair->status == 'A') {
-		/*
-		 * Recording rename information for this add makes it look
-		 * like a rename/delete conflict.  Make sure we can
-		 * correctly handle this as an add that was moved to a new
-		 * directory instead of reporting a rename/delete conflict.
-		 */
-		re->add_turned_into_rename = 1;
-	}
+	/*
+	 * Record the original change status (or 'type' of change).  If it
+	 * was originally an add ('A'), this lets us differentiate later
+	 * between a RENAME_DELETE conflict and RENAME_VIA_DIR (they
+	 * otherwise look the same).  If it was originally a rename ('R'),
+	 * this lets us remember and report accurately about the transitive
+	 * renaming that occurred via the directory rename detection.  Also,
+	 * record the original destination name.
+	 */
+	re->dir_rename_original_type = pair->status;
+	re->dir_rename_original_dest = pair->two->path;
+
 	/*
 	 * We don't actually look at pair->status again, but it seems
 	 * pedagogically correct to adjust it.
@@ -2456,7 +2610,8 @@ static void apply_directory_rename_modif
  * to be able to associate the correct cache entries with the rename
  * information; tree is always equal to either a_tree or b_tree.
  */
-static struct string_list *get_renames(struct merge_options *o,
+static struct string_list *get_renames(struct merge_options *opt,
+				       const char *branch,
 				       struct diff_queue_struct *pairs,
 				       struct hashmap *dir_renames,
 				       struct hashmap *dir_rename_exclusions,
@@ -2486,7 +2641,7 @@ static struct string_list *get_renames(s
 			diff_free_filepair(pair);
 			continue;
 		}
-		new_path = check_for_directory_rename(o, pair->two->path, tree,
+		new_path = check_for_directory_rename(opt, pair->two->path, tree,
 						      dir_renames,
 						      dir_rename_exclusions,
 						      &collisions,
@@ -2498,41 +2653,44 @@ static struct string_list *get_renames(s
 
 		re = xmalloc(sizeof(*re));
 		re->processed = 0;
-		re->add_turned_into_rename = 0;
 		re->pair = pair;
+		re->branch = branch;
+		re->dir_rename_original_type = '\0';
+		re->dir_rename_original_dest = NULL;
 		item = string_list_lookup(entries, re->pair->one->path);
 		if (!item)
-			re->src_entry = insert_stage_data(re->pair->one->path,
+			re->src_entry = insert_stage_data(opt->repo,
+					re->pair->one->path,
 					o_tree, a_tree, b_tree, entries);
 		else
 			re->src_entry = item->util;
 
 		item = string_list_lookup(entries, re->pair->two->path);
 		if (!item)
-			re->dst_entry = insert_stage_data(re->pair->two->path,
+			re->dst_entry = insert_stage_data(opt->repo,
+					re->pair->two->path,
 					o_tree, a_tree, b_tree, entries);
 		else
 			re->dst_entry = item->util;
 		item = string_list_insert(renames, pair->one->path);
 		item->util = re;
 		if (new_path)
-			apply_directory_rename_modifications(o, pair, new_path,
+			apply_directory_rename_modifications(opt, pair, new_path,
 							     re, tree, o_tree,
 							     a_tree, b_tree,
-							     entries,
-							     clean_merge);
+							     entries);
 	}
 
-	hashmap_iter_init(&collisions, &iter);
-	while ((e = hashmap_iter_next(&iter))) {
+	hashmap_for_each_entry(&collisions, &iter, e,
+				ent /* member name */) {
 		free(e->target_file);
 		string_list_clear(&e->source_files, 0);
 	}
-	hashmap_free(&collisions, 1);
+	hashmap_free_entries(&collisions, struct collision_entry, ent);
 	return renames;
 }
 
-static int process_renames(struct merge_options *o,
+static int process_renames(struct merge_options *opt,
 			   struct string_list *a_renames,
 			   struct string_list *b_renames)
 {
@@ -2555,7 +2713,6 @@ static int process_renames(struct merge_
 	for (i = 0, j = 0; i < a_renames->nr || j < b_renames->nr;) {
 		struct string_list *renames1, *renames2Dst;
 		struct rename *ren1 = NULL, *ren2 = NULL;
-		const char *branch1, *branch2;
 		const char *ren1_src, *ren1_dst;
 		struct string_list_item *lookup;
 
@@ -2576,13 +2733,9 @@ static int process_renames(struct merge_
 		if (ren1) {
 			renames1 = a_renames;
 			renames2Dst = &b_by_dst;
-			branch1 = o->branch1;
-			branch2 = o->branch2;
 		} else {
 			renames1 = b_renames;
 			renames2Dst = &a_by_dst;
-			branch1 = o->branch2;
-			branch2 = o->branch1;
 			SWAP(ren2, ren1);
 		}
 
@@ -2616,22 +2769,13 @@ static int process_renames(struct merge_
 				 * the base stage (think of rename +
 				 * add-source cases).
 				 */
-				remove_file(o, 1, ren1_src, 1);
+				remove_file(opt, 1, ren1_src, 1);
 				update_entry(ren1->dst_entry,
 					     ren1->pair->one,
 					     ren1->pair->two,
 					     ren2->pair->two);
 			}
-			setup_rename_conflict_info(rename_type,
-						   ren1->pair,
-						   ren2->pair,
-						   branch1,
-						   branch2,
-						   ren1->dst_entry,
-						   ren2->dst_entry,
-						   o,
-						   NULL,
-						   NULL);
+			setup_rename_conflict_info(rename_type, opt, ren1, ren2);
 		} else if ((lookup = string_list_lookup(renames2Dst, ren1_dst))) {
 			/* Two different files renamed to the same thing */
 			char *ren2_dst;
@@ -2650,16 +2794,7 @@ static int process_renames(struct merge_
 			ren2->src_entry->processed = 1;
 
 			setup_rename_conflict_info(RENAME_TWO_FILES_TO_ONE,
-						   ren1->pair,
-						   ren2->pair,
-						   branch1,
-						   branch2,
-						   ren1->dst_entry,
-						   ren2->dst_entry,
-						   o,
-						   ren1->src_entry,
-						   ren2->src_entry);
-
+						   opt, ren1, ren2);
 		} else {
 			/* Renamed in 1, maybe changed in 2 */
 			/* we only use sha1 and mode of these */
@@ -2679,8 +2814,8 @@ static int process_renames(struct merge_
 			 * stage and in other_stage (think of rename +
 			 * add-source case).
 			 */
-			remove_file(o, 1, ren1_src,
-				    renamed_stage == 2 || !was_tracked(o, ren1_src));
+			remove_file(opt, 1, ren1_src,
+				    renamed_stage == 2 || !was_tracked(opt, ren1_src));
 
 			oidcpy(&src_other.oid,
 			       &ren1->src_entry->stages[other_stage].oid);
@@ -2690,31 +2825,15 @@ static int process_renames(struct merge_
 			dst_other.mode = ren1->dst_entry->stages[other_stage].mode;
 			try_merge = 0;
 
-			if (oid_eq(&src_other.oid, &null_oid) &&
-			    ren1->add_turned_into_rename) {
-				setup_rename_conflict_info(RENAME_DIR,
-							   ren1->pair,
-							   NULL,
-							   branch1,
-							   branch2,
-							   ren1->dst_entry,
-							   NULL,
-							   o,
-							   NULL,
-							   NULL);
-			} else if (oid_eq(&src_other.oid, &null_oid)) {
+			if (oideq(&src_other.oid, &null_oid) &&
+			    ren1->dir_rename_original_type == 'A') {
+				setup_rename_conflict_info(RENAME_VIA_DIR,
+							   opt, ren1, NULL);
+			} else if (oideq(&src_other.oid, &null_oid)) {
 				setup_rename_conflict_info(RENAME_DELETE,
-							   ren1->pair,
-							   NULL,
-							   branch1,
-							   branch2,
-							   ren1->dst_entry,
-							   NULL,
-							   o,
-							   NULL,
-							   NULL);
+							   opt, ren1, NULL);
 			} else if ((dst_other.mode == ren1->pair->two->mode) &&
-				   oid_eq(&dst_other.oid, &ren1->pair->two->oid)) {
+				   oideq(&dst_other.oid, &ren1->pair->two->oid)) {
 				/*
 				 * Added file on the other side identical to
 				 * the file being renamed: clean merge.
@@ -2723,54 +2842,32 @@ static int process_renames(struct merge_
 				 * update_file_flags() instead of
 				 * update_file().
 				 */
-				if (update_file_flags(o,
-						      &ren1->pair->two->oid,
-						      ren1->pair->two->mode,
+				if (update_file_flags(opt,
+						      ren1->pair->two,
 						      ren1_dst,
 						      1, /* update_cache */
 						      0  /* update_wd    */))
 					clean_merge = -1;
-			} else if (!oid_eq(&dst_other.oid, &null_oid)) {
-				clean_merge = 0;
-				try_merge = 1;
-				output(o, 1, _("CONFLICT (rename/add): Rename %s->%s in %s. "
-				       "%s added in %s"),
-				       ren1_src, ren1_dst, branch1,
-				       ren1_dst, branch2);
-				if (o->call_depth) {
-					struct merge_file_info mfi;
-					if (merge_file_one(o, ren1_dst, &null_oid, 0,
-							   &ren1->pair->two->oid,
-							   ren1->pair->two->mode,
-							   &dst_other.oid,
-							   dst_other.mode,
-							   branch1, branch2, &mfi)) {
-						clean_merge = -1;
-						goto cleanup_and_return;
-					}
-					output(o, 1, _("Adding merged %s"), ren1_dst);
-					if (update_file(o, 0, &mfi.oid,
-							mfi.mode, ren1_dst))
-						clean_merge = -1;
-					try_merge = 0;
-				} else {
-					char *new_path = unique_path(o, ren1_dst, branch2);
-					output(o, 1, _("Adding as %s instead"), new_path);
-					if (update_file(o, 0, &dst_other.oid,
-							dst_other.mode, new_path))
-						clean_merge = -1;
-					free(new_path);
-				}
+			} else if (!oideq(&dst_other.oid, &null_oid)) {
+				/*
+				 * Probably not a clean merge, but it's
+				 * premature to set clean_merge to 0 here,
+				 * because if the rename merges cleanly and
+				 * the merge exactly matches the newly added
+				 * file, then the merge will be clean.
+				 */
+				setup_rename_conflict_info(RENAME_ADD,
+							   opt, ren1, NULL);
 			} else
 				try_merge = 1;
 
 			if (clean_merge < 0)
 				goto cleanup_and_return;
 			if (try_merge) {
-				struct diff_filespec *one, *a, *b;
+				struct diff_filespec *o, *a, *b;
 				src_other.path = (char *)ren1_src;
 
-				one = ren1->pair->one;
+				o = ren1->pair->one;
 				if (a_renames == renames1) {
 					a = ren1->pair->two;
 					b = &src_other;
@@ -2778,17 +2875,9 @@ static int process_renames(struct merge_
 					b = ren1->pair->two;
 					a = &src_other;
 				}
-				update_entry(ren1->dst_entry, one, a, b);
+				update_entry(ren1->dst_entry, o, a, b);
 				setup_rename_conflict_info(RENAME_NORMAL,
-							   ren1->pair,
-							   NULL,
-							   branch1,
-							   NULL,
-							   ren1->dst_entry,
-							   NULL,
-							   o,
-							   NULL,
-							   NULL);
+							   opt, ren1, NULL);
 			}
 		}
 	}
@@ -2810,25 +2899,25 @@ static void initial_cleanup_rename(struc
 	struct hashmap_iter iter;
 	struct dir_rename_entry *e;
 
-	hashmap_iter_init(dir_renames, &iter);
-	while ((e = hashmap_iter_next(&iter))) {
+	hashmap_for_each_entry(dir_renames, &iter, e,
+				ent /* member name */) {
 		free(e->dir);
 		strbuf_release(&e->new_dir);
 		/* possible_new_dirs already cleared in get_directory_renames */
 	}
-	hashmap_free(dir_renames, 1);
+	hashmap_free_entries(dir_renames, struct dir_rename_entry, ent);
 	free(dir_renames);
 
 	free(pairs->queue);
 	free(pairs);
 }
 
-static int handle_renames(struct merge_options *o,
-			  struct tree *common,
-			  struct tree *head,
-			  struct tree *merge,
-			  struct string_list *entries,
-			  struct rename_info *ri)
+static int detect_and_process_renames(struct merge_options *opt,
+				      struct tree *common,
+				      struct tree *head,
+				      struct tree *merge,
+				      struct string_list *entries,
+				      struct rename_info *ri)
 {
 	struct diff_queue_struct *head_pairs, *merge_pairs;
 	struct hashmap *dir_re_head, *dir_re_merge;
@@ -2837,32 +2926,41 @@ static int handle_renames(struct merge_o
 	ri->head_renames = NULL;
 	ri->merge_renames = NULL;
 
-	if (!merge_detect_rename(o))
+	if (!merge_detect_rename(opt))
 		return 1;
 
-	head_pairs = get_diffpairs(o, common, head);
-	merge_pairs = get_diffpairs(o, common, merge);
+	head_pairs = get_diffpairs(opt, common, head);
+	merge_pairs = get_diffpairs(opt, common, merge);
 
-	dir_re_head = get_directory_renames(head_pairs, head);
-	dir_re_merge = get_directory_renames(merge_pairs, merge);
-
-	handle_directory_level_conflicts(o,
-					 dir_re_head, head,
-					 dir_re_merge, merge);
+	if ((opt->detect_directory_renames == MERGE_DIRECTORY_RENAMES_TRUE) ||
+	    (opt->detect_directory_renames == MERGE_DIRECTORY_RENAMES_CONFLICT &&
+	     !opt->priv->call_depth)) {
+		dir_re_head = get_directory_renames(head_pairs);
+		dir_re_merge = get_directory_renames(merge_pairs);
+
+		handle_directory_level_conflicts(opt,
+						 dir_re_head, head,
+						 dir_re_merge, merge);
+	} else {
+		dir_re_head  = xmalloc(sizeof(*dir_re_head));
+		dir_re_merge = xmalloc(sizeof(*dir_re_merge));
+		dir_rename_init(dir_re_head);
+		dir_rename_init(dir_re_merge);
+	}
 
-	ri->head_renames  = get_renames(o, head_pairs,
+	ri->head_renames  = get_renames(opt, opt->branch1, head_pairs,
 					dir_re_merge, dir_re_head, head,
 					common, head, merge, entries,
 					&clean);
 	if (clean < 0)
 		goto cleanup;
-	ri->merge_renames = get_renames(o, merge_pairs,
+	ri->merge_renames = get_renames(opt, opt->branch2, merge_pairs,
 					dir_re_head, dir_re_merge, merge,
 					common, head, merge, entries,
 					&clean);
 	if (clean < 0)
 		goto cleanup;
-	clean &= process_renames(o, ri->head_renames, ri->merge_renames);
+	clean &= process_renames(opt, ri->head_renames, ri->merge_renames);
 
 cleanup:
 	/*
@@ -2898,140 +2996,108 @@ static void final_cleanup_renames(struct
 	final_cleanup_rename(re_info->merge_renames);
 }
 
-static struct object_id *stage_oid(const struct object_id *oid, unsigned mode)
-{
-	return (is_null_oid(oid) || mode == 0) ? NULL: (struct object_id *)oid;
-}
-
-static int read_oid_strbuf(struct merge_options *o,
-	const struct object_id *oid, struct strbuf *dst)
+static int read_oid_strbuf(struct merge_options *opt,
+			   const struct object_id *oid,
+			   struct strbuf *dst)
 {
 	void *buf;
 	enum object_type type;
 	unsigned long size;
 	buf = read_object_file(oid, &type, &size);
 	if (!buf)
-		return err(o, _("cannot read object %s"), oid_to_hex(oid));
+		return err(opt, _("cannot read object %s"), oid_to_hex(oid));
 	if (type != OBJ_BLOB) {
 		free(buf);
-		return err(o, _("object %s is not a blob"), oid_to_hex(oid));
+		return err(opt, _("object %s is not a blob"), oid_to_hex(oid));
 	}
 	strbuf_attach(dst, buf, size, size + 1);
 	return 0;
 }
 
 static int blob_unchanged(struct merge_options *opt,
-			  const struct object_id *o_oid,
-			  unsigned o_mode,
-			  const struct object_id *a_oid,
-			  unsigned a_mode,
+			  const struct diff_filespec *o,
+			  const struct diff_filespec *a,
 			  int renormalize, const char *path)
 {
-	struct strbuf o = STRBUF_INIT;
-	struct strbuf a = STRBUF_INIT;
+	struct strbuf obuf = STRBUF_INIT;
+	struct strbuf abuf = STRBUF_INIT;
 	int ret = 0; /* assume changed for safety */
+	const struct index_state *idx = opt->repo->index;
 
-	if (a_mode != o_mode)
+	if (a->mode != o->mode)
 		return 0;
-	if (oid_eq(o_oid, a_oid))
+	if (oideq(&o->oid, &a->oid))
 		return 1;
 	if (!renormalize)
 		return 0;
 
-	assert(o_oid && a_oid);
-	if (read_oid_strbuf(opt, o_oid, &o) || read_oid_strbuf(opt, a_oid, &a))
+	if (read_oid_strbuf(opt, &o->oid, &obuf) ||
+	    read_oid_strbuf(opt, &a->oid, &abuf))
 		goto error_return;
 	/*
 	 * Note: binary | is used so that both renormalizations are
 	 * performed.  Comparison can be skipped if both files are
 	 * unchanged since their sha1s have already been compared.
 	 */
-	if (renormalize_buffer(&the_index, path, o.buf, o.len, &o) |
-	    renormalize_buffer(&the_index, path, a.buf, a.len, &a))
-		ret = (o.len == a.len && !memcmp(o.buf, a.buf, o.len));
+	if (renormalize_buffer(idx, path, obuf.buf, obuf.len, &obuf) |
+	    renormalize_buffer(idx, path, abuf.buf, abuf.len, &abuf))
+		ret = (obuf.len == abuf.len && !memcmp(obuf.buf, abuf.buf, obuf.len));
 
 error_return:
-	strbuf_release(&o);
-	strbuf_release(&a);
+	strbuf_release(&obuf);
+	strbuf_release(&abuf);
 	return ret;
 }
 
-static int handle_modify_delete(struct merge_options *o,
-				 const char *path,
-				 struct object_id *o_oid, int o_mode,
-				 struct object_id *a_oid, int a_mode,
-				 struct object_id *b_oid, int b_mode)
+static int handle_modify_delete(struct merge_options *opt,
+				const char *path,
+				const struct diff_filespec *o,
+				const struct diff_filespec *a,
+				const struct diff_filespec *b)
 {
 	const char *modify_branch, *delete_branch;
-	struct object_id *changed_oid;
-	int changed_mode;
+	const struct diff_filespec *changed;
 
-	if (a_oid) {
-		modify_branch = o->branch1;
-		delete_branch = o->branch2;
-		changed_oid = a_oid;
-		changed_mode = a_mode;
+	if (is_valid(a)) {
+		modify_branch = opt->branch1;
+		delete_branch = opt->branch2;
+		changed = a;
 	} else {
-		modify_branch = o->branch2;
-		delete_branch = o->branch1;
-		changed_oid = b_oid;
-		changed_mode = b_mode;
+		modify_branch = opt->branch2;
+		delete_branch = opt->branch1;
+		changed = b;
 	}
 
-	return handle_change_delete(o,
+	return handle_change_delete(opt,
 				    path, NULL,
-				    o_oid, o_mode,
-				    changed_oid, changed_mode,
+				    o, changed,
 				    modify_branch, delete_branch,
 				    _("modify"), _("modified"));
 }
 
-static int merge_content(struct merge_options *o,
-			 const char *path,
-			 int is_dirty,
-			 struct object_id *o_oid, int o_mode,
-			 struct object_id *a_oid, int a_mode,
-			 struct object_id *b_oid, int b_mode,
-			 struct rename_conflict_info *rename_conflict_info)
+static int handle_content_merge(struct merge_file_info *mfi,
+				struct merge_options *opt,
+				const char *path,
+				int is_dirty,
+				const struct diff_filespec *o,
+				const struct diff_filespec *a,
+				const struct diff_filespec *b,
+				struct rename_conflict_info *ci)
 {
 	const char *reason = _("content");
-	const char *path1 = NULL, *path2 = NULL;
-	struct merge_file_info mfi;
-	struct diff_filespec one, a, b;
 	unsigned df_conflict_remains = 0;
 
-	if (!o_oid) {
+	if (!is_valid(o))
 		reason = _("add/add");
-		o_oid = (struct object_id *)&null_oid;
-	}
-	one.path = a.path = b.path = (char *)path;
-	oidcpy(&one.oid, o_oid);
-	one.mode = o_mode;
-	oidcpy(&a.oid, a_oid);
-	a.mode = a_mode;
-	oidcpy(&b.oid, b_oid);
-	b.mode = b_mode;
-
-	if (rename_conflict_info) {
-		struct diff_filepair *pair1 = rename_conflict_info->pair1;
-
-		path1 = (o->branch1 == rename_conflict_info->branch1) ?
-			pair1->two->path : pair1->one->path;
-		/* If rename_conflict_info->pair2 != NULL, we are in
-		 * RENAME_ONE_FILE_TO_ONE case.  Otherwise, we have a
-		 * normal rename.
-		 */
-		path2 = (rename_conflict_info->pair2 ||
-			 o->branch2 == rename_conflict_info->branch1) ?
-			pair1->two->path : pair1->one->path;
-
-		if (dir_in_way(path, !o->call_depth,
-			       S_ISGITLINK(pair1->two->mode)))
-			df_conflict_remains = 1;
-	}
-	if (merge_file_special_markers(o, &one, &a, &b, path,
-				       o->branch1, path1,
-				       o->branch2, path2, &mfi))
+
+	assert(o->path && a->path && b->path);
+	if (ci && dir_in_way(opt->repo->index, path, !opt->priv->call_depth,
+			     S_ISGITLINK(ci->ren1->pair->two->mode)))
+		df_conflict_remains = 1;
+
+	if (merge_mode_and_contents(opt, o, a, b, path,
+				    opt->branch1, opt->branch2,
+				    opt->priv->call_depth * 2, mfi))
 		return -1;
 
 	/*
@@ -3040,251 +3106,385 @@ static int merge_content(struct merge_op
 	 *   b) The merge matches what was in HEAD (content, mode, pathname)
 	 *   c) The target path is usable (i.e. not involved in D/F conflict)
 	 */
-	if (mfi.clean &&
-	    was_tracked_and_matches(o, path, &mfi.oid, mfi.mode) &&
+	if (mfi->clean && was_tracked_and_matches(opt, path, &mfi->blob) &&
 	    !df_conflict_remains) {
-		output(o, 3, _("Skipped %s (merged same as existing)"), path);
-		if (add_cacheinfo(o, mfi.mode, &mfi.oid, path,
-				  0, (!o->call_depth && !is_dirty), 0))
+		int pos;
+		struct cache_entry *ce;
+
+		output(opt, 3, _("Skipped %s (merged same as existing)"), path);
+		if (add_cacheinfo(opt, &mfi->blob, path,
+				  0, (!opt->priv->call_depth && !is_dirty), 0))
 			return -1;
-		return mfi.clean;
+		/*
+		 * However, add_cacheinfo() will delete the old cache entry
+		 * and add a new one.  We need to copy over any skip_worktree
+		 * flag to avoid making the file appear as if it were
+		 * deleted by the user.
+		 */
+		pos = index_name_pos(&opt->priv->orig_index, path, strlen(path));
+		ce = opt->priv->orig_index.cache[pos];
+		if (ce_skip_worktree(ce)) {
+			pos = index_name_pos(opt->repo->index, path, strlen(path));
+			ce = opt->repo->index->cache[pos];
+			ce->ce_flags |= CE_SKIP_WORKTREE;
+		}
+		return mfi->clean;
 	}
 
-	if (!mfi.clean) {
-		if (S_ISGITLINK(mfi.mode))
+	if (!mfi->clean) {
+		if (S_ISGITLINK(mfi->blob.mode))
 			reason = _("submodule");
-		output(o, 1, _("CONFLICT (%s): Merge conflict in %s"),
+		output(opt, 1, _("CONFLICT (%s): Merge conflict in %s"),
 				reason, path);
-		if (rename_conflict_info && !df_conflict_remains)
-			if (update_stages(o, path, &one, &a, &b))
+		if (ci && !df_conflict_remains)
+			if (update_stages(opt, path, o, a, b))
 				return -1;
 	}
 
 	if (df_conflict_remains || is_dirty) {
 		char *new_path;
-		if (o->call_depth) {
-			remove_file_from_cache(path);
+		if (opt->priv->call_depth) {
+			remove_file_from_index(opt->repo->index, path);
 		} else {
-			if (!mfi.clean) {
-				if (update_stages(o, path, &one, &a, &b))
+			if (!mfi->clean) {
+				if (update_stages(opt, path, o, a, b))
 					return -1;
 			} else {
-				int file_from_stage2 = was_tracked(o, path);
-				struct diff_filespec merged;
-				oidcpy(&merged.oid, &mfi.oid);
-				merged.mode = mfi.mode;
-
-				if (update_stages(o, path, NULL,
-						  file_from_stage2 ? &merged : NULL,
-						  file_from_stage2 ? NULL : &merged))
+				int file_from_stage2 = was_tracked(opt, path);
+
+				if (update_stages(opt, path, NULL,
+						  file_from_stage2 ? &mfi->blob : NULL,
+						  file_from_stage2 ? NULL : &mfi->blob))
 					return -1;
 			}
 
 		}
-		new_path = unique_path(o, path, rename_conflict_info->branch1);
+		new_path = unique_path(opt, path, ci->ren1->branch);
 		if (is_dirty) {
-			output(o, 1, _("Refusing to lose dirty file at %s"),
+			output(opt, 1, _("Refusing to lose dirty file at %s"),
 			       path);
 		}
-		output(o, 1, _("Adding as %s instead"), new_path);
-		if (update_file(o, 0, &mfi.oid, mfi.mode, new_path)) {
+		output(opt, 1, _("Adding as %s instead"), new_path);
+		if (update_file(opt, 0, &mfi->blob, new_path)) {
 			free(new_path);
 			return -1;
 		}
 		free(new_path);
-		mfi.clean = 0;
-	} else if (update_file(o, mfi.clean, &mfi.oid, mfi.mode, path))
+		mfi->clean = 0;
+	} else if (update_file(opt, mfi->clean, &mfi->blob, path))
 		return -1;
-	return !is_dirty && mfi.clean;
+	return !is_dirty && mfi->clean;
 }
 
-static int conflict_rename_normal(struct merge_options *o,
-				  const char *path,
-				  struct object_id *o_oid, unsigned int o_mode,
-				  struct object_id *a_oid, unsigned int a_mode,
-				  struct object_id *b_oid, unsigned int b_mode,
-				  struct rename_conflict_info *ci)
+static int handle_rename_normal(struct merge_options *opt,
+				const char *path,
+				const struct diff_filespec *o,
+				const struct diff_filespec *a,
+				const struct diff_filespec *b,
+				struct rename_conflict_info *ci)
 {
+	struct rename *ren = ci->ren1;
+	struct merge_file_info mfi;
+	int clean;
+	int side = (ren->branch == opt->branch1 ? 2 : 3);
+
 	/* Merge the content and write it out */
-	return merge_content(o, path, was_dirty(o, path),
-			     o_oid, o_mode, a_oid, a_mode, b_oid, b_mode,
-			     ci);
+	clean = handle_content_merge(&mfi, opt, path, was_dirty(opt, path),
+				     o, a, b, ci);
+
+	if (clean &&
+	    opt->detect_directory_renames == MERGE_DIRECTORY_RENAMES_CONFLICT &&
+	    ren->dir_rename_original_dest) {
+		if (update_stages(opt, path,
+				  NULL,
+				  side == 2 ? &mfi.blob : NULL,
+				  side == 2 ? NULL : &mfi.blob))
+			return -1;
+		clean = 0; /* not clean, but conflicted */
+	}
+	return clean;
+}
+
+static void dir_rename_warning(const char *msg,
+			       int is_add,
+			       int clean,
+			       struct merge_options *opt,
+			       struct rename *ren)
+{
+	const char *other_branch;
+	other_branch = (ren->branch == opt->branch1 ?
+			opt->branch2 : opt->branch1);
+	if (is_add) {
+		output(opt, clean ? 2 : 1, msg,
+		       ren->pair->one->path, ren->branch,
+		       other_branch, ren->pair->two->path);
+		return;
+	}
+	output(opt, clean ? 2 : 1, msg,
+	       ren->pair->one->path, ren->dir_rename_original_dest, ren->branch,
+	       other_branch, ren->pair->two->path);
+}
+static int warn_about_dir_renamed_entries(struct merge_options *opt,
+					  struct rename *ren)
+{
+	const char *msg;
+	int clean = 1, is_add;
+
+	if (!ren)
+		return clean;
+
+	/* Return early if ren was not affected/created by a directory rename */
+	if (!ren->dir_rename_original_dest)
+		return clean;
+
+	/* Sanity checks */
+	assert(opt->detect_directory_renames > MERGE_DIRECTORY_RENAMES_NONE);
+	assert(ren->dir_rename_original_type == 'A' ||
+	       ren->dir_rename_original_type == 'R');
+
+	/* Check whether to treat directory renames as a conflict */
+	clean = (opt->detect_directory_renames == MERGE_DIRECTORY_RENAMES_TRUE);
+
+	is_add = (ren->dir_rename_original_type == 'A');
+	if (ren->dir_rename_original_type == 'A' && clean) {
+		msg = _("Path updated: %s added in %s inside a "
+			"directory that was renamed in %s; moving it to %s.");
+	} else if (ren->dir_rename_original_type == 'A' && !clean) {
+		msg = _("CONFLICT (file location): %s added in %s "
+			"inside a directory that was renamed in %s, "
+			"suggesting it should perhaps be moved to %s.");
+	} else if (ren->dir_rename_original_type == 'R' && clean) {
+		msg = _("Path updated: %s renamed to %s in %s, inside a "
+			"directory that was renamed in %s; moving it to %s.");
+	} else if (ren->dir_rename_original_type == 'R' && !clean) {
+		msg = _("CONFLICT (file location): %s renamed to %s in %s, "
+			"inside a directory that was renamed in %s, "
+			"suggesting it should perhaps be moved to %s.");
+	} else {
+		BUG("Impossible dir_rename_original_type/clean combination");
+	}
+	dir_rename_warning(msg, is_add, clean, opt, ren);
+
+	return clean;
 }
 
 /* Per entry merge function */
-static int process_entry(struct merge_options *o,
+static int process_entry(struct merge_options *opt,
 			 const char *path, struct stage_data *entry)
 {
 	int clean_merge = 1;
-	int normalize = o->renormalize;
-	unsigned o_mode = entry->stages[1].mode;
-	unsigned a_mode = entry->stages[2].mode;
-	unsigned b_mode = entry->stages[3].mode;
-	struct object_id *o_oid = stage_oid(&entry->stages[1].oid, o_mode);
-	struct object_id *a_oid = stage_oid(&entry->stages[2].oid, a_mode);
-	struct object_id *b_oid = stage_oid(&entry->stages[3].oid, b_mode);
+	int normalize = opt->renormalize;
+
+	struct diff_filespec *o = &entry->stages[1];
+	struct diff_filespec *a = &entry->stages[2];
+	struct diff_filespec *b = &entry->stages[3];
+	int o_valid = is_valid(o);
+	int a_valid = is_valid(a);
+	int b_valid = is_valid(b);
+	o->path = a->path = b->path = (char*)path;
 
 	entry->processed = 1;
 	if (entry->rename_conflict_info) {
-		struct rename_conflict_info *conflict_info = entry->rename_conflict_info;
-		switch (conflict_info->rename_type) {
+		struct rename_conflict_info *ci = entry->rename_conflict_info;
+		struct diff_filespec *temp;
+		int path_clean;
+
+		path_clean = warn_about_dir_renamed_entries(opt, ci->ren1);
+		path_clean &= warn_about_dir_renamed_entries(opt, ci->ren2);
+
+		/*
+		 * For cases with a single rename, {o,a,b}->path have all been
+		 * set to the rename target path; we need to set two of these
+		 * back to the rename source.
+		 * For rename/rename conflicts, we'll manually fix paths below.
+		 */
+		temp = (opt->branch1 == ci->ren1->branch) ? b : a;
+		o->path = temp->path = ci->ren1->pair->one->path;
+		if (ci->ren2) {
+			assert(opt->branch1 == ci->ren1->branch);
+		}
+
+		switch (ci->rename_type) {
 		case RENAME_NORMAL:
 		case RENAME_ONE_FILE_TO_ONE:
-			clean_merge = conflict_rename_normal(o,
-							     path,
-							     o_oid, o_mode,
-							     a_oid, a_mode,
-							     b_oid, b_mode,
-							     conflict_info);
+			clean_merge = handle_rename_normal(opt, path, o, a, b,
+							   ci);
 			break;
-		case RENAME_DIR:
-			clean_merge = 1;
-			if (conflict_rename_dir(o,
-						conflict_info->pair1,
-						conflict_info->branch1,
-						conflict_info->branch2))
-				clean_merge = -1;
+		case RENAME_VIA_DIR:
+			clean_merge = handle_rename_via_dir(opt, ci);
+			break;
+		case RENAME_ADD:
+			/*
+			 * Probably unclean merge, but if the renamed file
+			 * merges cleanly and the result can then be
+			 * two-way merged cleanly with the added file, I
+			 * guess it's a clean merge?
+			 */
+			clean_merge = handle_rename_add(opt, ci);
 			break;
 		case RENAME_DELETE:
 			clean_merge = 0;
-			if (conflict_rename_delete(o,
-						   conflict_info->pair1,
-						   conflict_info->branch1,
-						   conflict_info->branch2))
+			if (handle_rename_delete(opt, ci))
 				clean_merge = -1;
 			break;
 		case RENAME_ONE_FILE_TO_TWO:
+			/*
+			 * Manually fix up paths; note:
+			 * ren[12]->pair->one->path are equal.
+			 */
+			o->path = ci->ren1->pair->one->path;
+			a->path = ci->ren1->pair->two->path;
+			b->path = ci->ren2->pair->two->path;
+
 			clean_merge = 0;
-			if (conflict_rename_rename_1to2(o, conflict_info))
+			if (handle_rename_rename_1to2(opt, ci))
 				clean_merge = -1;
 			break;
 		case RENAME_TWO_FILES_TO_ONE:
-			clean_merge = 0;
-			if (conflict_rename_rename_2to1(o, conflict_info))
-				clean_merge = -1;
+			/*
+			 * Manually fix up paths; note,
+			 * ren[12]->pair->two->path are actually equal.
+			 */
+			o->path = NULL;
+			a->path = ci->ren1->pair->two->path;
+			b->path = ci->ren2->pair->two->path;
+
+			/*
+			 * Probably unclean merge, but if the two renamed
+			 * files merge cleanly and the two resulting files
+			 * can then be two-way merged cleanly, I guess it's
+			 * a clean merge?
+			 */
+			clean_merge = handle_rename_rename_2to1(opt, ci);
 			break;
 		default:
 			entry->processed = 0;
 			break;
 		}
-	} else if (o_oid && (!a_oid || !b_oid)) {
+		if (path_clean < clean_merge)
+			clean_merge = path_clean;
+	} else if (o_valid && (!a_valid || !b_valid)) {
 		/* Case A: Deleted in one */
-		if ((!a_oid && !b_oid) ||
-		    (!b_oid && blob_unchanged(o, o_oid, o_mode, a_oid, a_mode, normalize, path)) ||
-		    (!a_oid && blob_unchanged(o, o_oid, o_mode, b_oid, b_mode, normalize, path))) {
+		if ((!a_valid && !b_valid) ||
+		    (!b_valid && blob_unchanged(opt, o, a, normalize, path)) ||
+		    (!a_valid && blob_unchanged(opt, o, b, normalize, path))) {
 			/* Deleted in both or deleted in one and
 			 * unchanged in the other */
-			if (a_oid)
-				output(o, 2, _("Removing %s"), path);
+			if (a_valid)
+				output(opt, 2, _("Removing %s"), path);
 			/* do not touch working file if it did not exist */
-			remove_file(o, 1, path, !a_oid);
+			remove_file(opt, 1, path, !a_valid);
 		} else {
 			/* Modify/delete; deleted side may have put a directory in the way */
 			clean_merge = 0;
-			if (handle_modify_delete(o, path, o_oid, o_mode,
-						 a_oid, a_mode, b_oid, b_mode))
+			if (handle_modify_delete(opt, path, o, a, b))
 				clean_merge = -1;
 		}
-	} else if ((!o_oid && a_oid && !b_oid) ||
-		   (!o_oid && !a_oid && b_oid)) {
+	} else if ((!o_valid && a_valid && !b_valid) ||
+		   (!o_valid && !a_valid && b_valid)) {
 		/* Case B: Added in one. */
 		/* [nothing|directory] -> ([nothing|directory], file) */
 
 		const char *add_branch;
 		const char *other_branch;
-		unsigned mode;
-		const struct object_id *oid;
 		const char *conf;
+		const struct diff_filespec *contents;
 
-		if (a_oid) {
-			add_branch = o->branch1;
-			other_branch = o->branch2;
-			mode = a_mode;
-			oid = a_oid;
+		if (a_valid) {
+			add_branch = opt->branch1;
+			other_branch = opt->branch2;
+			contents = a;
 			conf = _("file/directory");
 		} else {
-			add_branch = o->branch2;
-			other_branch = o->branch1;
-			mode = b_mode;
-			oid = b_oid;
+			add_branch = opt->branch2;
+			other_branch = opt->branch1;
+			contents = b;
 			conf = _("directory/file");
 		}
-		if (dir_in_way(path,
-			       !o->call_depth && !S_ISGITLINK(a_mode),
+		if (dir_in_way(opt->repo->index, path,
+			       !opt->priv->call_depth && !S_ISGITLINK(a->mode),
 			       0)) {
-			char *new_path = unique_path(o, path, add_branch);
+			char *new_path = unique_path(opt, path, add_branch);
 			clean_merge = 0;
-			output(o, 1, _("CONFLICT (%s): There is a directory with name %s in %s. "
+			output(opt, 1, _("CONFLICT (%s): There is a directory with name %s in %s. "
 			       "Adding %s as %s"),
 			       conf, path, other_branch, path, new_path);
-			if (update_file(o, 0, oid, mode, new_path))
+			if (update_file(opt, 0, contents, new_path))
 				clean_merge = -1;
-			else if (o->call_depth)
-				remove_file_from_cache(path);
+			else if (opt->priv->call_depth)
+				remove_file_from_index(opt->repo->index, path);
 			free(new_path);
 		} else {
-			output(o, 2, _("Adding %s"), path);
+			output(opt, 2, _("Adding %s"), path);
 			/* do not overwrite file if already present */
-			if (update_file_flags(o, oid, mode, path, 1, !a_oid))
+			if (update_file_flags(opt, contents, path, 1, !a_valid))
 				clean_merge = -1;
 		}
-	} else if (a_oid && b_oid) {
-		/* Case C: Added in both (check for same permissions) and */
-		/* case D: Modified in both, but differently. */
-		int is_dirty = 0; /* unpack_trees would have bailed if dirty */
-		clean_merge = merge_content(o, path, is_dirty,
-					    o_oid, o_mode, a_oid, a_mode, b_oid, b_mode,
-					    NULL);
-	} else if (!o_oid && !a_oid && !b_oid) {
+	} else if (a_valid && b_valid) {
+		if (!o_valid) {
+			/* Case C: Added in both (check for same permissions) */
+			output(opt, 1,
+			       _("CONFLICT (add/add): Merge conflict in %s"),
+			       path);
+			clean_merge = handle_file_collision(opt,
+							    path, NULL, NULL,
+							    opt->branch1,
+							    opt->branch2,
+							    a, b);
+		} else {
+			/* case D: Modified in both, but differently. */
+			struct merge_file_info mfi;
+			int is_dirty = 0; /* unpack_trees would have bailed if dirty */
+			clean_merge = handle_content_merge(&mfi, opt, path,
+							   is_dirty,
+							   o, a, b, NULL);
+		}
+	} else if (!o_valid && !a_valid && !b_valid) {
 		/*
 		 * this entry was deleted altogether. a_mode == 0 means
 		 * we had that path and want to actively remove it.
 		 */
-		remove_file(o, 1, path, !a_mode);
+		remove_file(opt, 1, path, !a->mode);
 	} else
 		BUG("fatal merge failure, shouldn't happen.");
 
 	return clean_merge;
 }
 
-int merge_trees(struct merge_options *o,
-		struct tree *head,
-		struct tree *merge,
-		struct tree *common,
-		struct tree **result)
+static int merge_trees_internal(struct merge_options *opt,
+				struct tree *head,
+				struct tree *merge,
+				struct tree *merge_base,
+				struct tree **result)
 {
+	struct index_state *istate = opt->repo->index;
 	int code, clean;
 
-	if (o->subtree_shift) {
-		merge = shift_tree_object(head, merge, o->subtree_shift);
-		common = shift_tree_object(head, common, o->subtree_shift);
+	if (opt->subtree_shift) {
+		merge = shift_tree_object(opt->repo, head, merge,
+					  opt->subtree_shift);
+		merge_base = shift_tree_object(opt->repo, head, merge_base,
+					       opt->subtree_shift);
 	}
 
-	if (oid_eq(&common->object.oid, &merge->object.oid)) {
-		struct strbuf sb = STRBUF_INIT;
-
-		if (!o->call_depth && index_has_changes(&sb)) {
-			err(o, _("Dirty index: cannot merge (dirty: %s)"),
-			    sb.buf);
-			return 0;
-		}
-		output(o, 0, _("Already up to date!"));
+	if (oideq(&merge_base->object.oid, &merge->object.oid)) {
+		output(opt, 0, _("Already up to date!"));
 		*result = head;
 		return 1;
 	}
 
-	code = unpack_trees_start(o, common, head, merge);
+	code = unpack_trees_start(opt, merge_base, head, merge);
 
 	if (code != 0) {
-		if (show(o, 4) || o->call_depth)
-			err(o, _("merging of trees %s and %s failed"),
+		if (show(opt, 4) || opt->priv->call_depth)
+			err(opt, _("merging of trees %s and %s failed"),
 			    oid_to_hex(&head->object.oid),
 			    oid_to_hex(&merge->object.oid));
-		unpack_trees_finish(o);
+		unpack_trees_finish(opt);
 		return -1;
 	}
 
-	if (unmerged_cache()) {
+	if (unmerged_index(istate)) {
 		struct string_list *entries;
 		struct rename_info re_info;
 		int i;
@@ -3295,21 +3495,22 @@ int merge_trees(struct merge_options *o,
 		 * opposed to decaring a local hashmap is for convenience
 		 * so that we don't have to pass it to around.
 		 */
-		hashmap_init(&o->current_file_dir_set, path_hashmap_cmp, NULL, 512);
-		get_files_dirs(o, head);
-		get_files_dirs(o, merge);
-
-		entries = get_unmerged();
-		clean = handle_renames(o, common, head, merge, entries,
-				       &re_info);
-		record_df_conflict_files(o, entries);
+		hashmap_init(&opt->priv->current_file_dir_set, path_hashmap_cmp,
+			     NULL, 512);
+		get_files_dirs(opt, head);
+		get_files_dirs(opt, merge);
+
+		entries = get_unmerged(opt->repo->index);
+		clean = detect_and_process_renames(opt, merge_base, head, merge,
+						   entries, &re_info);
+		record_df_conflict_files(opt, entries);
 		if (clean < 0)
 			goto cleanup;
 		for (i = entries->nr-1; 0 <= i; i--) {
 			const char *path = entries->items[i].string;
 			struct stage_data *e = entries->items[i].util;
 			if (!e->processed) {
-				int ret = process_entry(o, path, e);
+				int ret = process_entry(opt, path, e);
 				if (!ret)
 					clean = 0;
 				else if (ret < 0) {
@@ -3325,25 +3526,27 @@ int merge_trees(struct merge_options *o,
 				    entries->items[i].string);
 		}
 
-cleanup:
+	cleanup:
 		final_cleanup_renames(&re_info);
 
 		string_list_clear(entries, 1);
 		free(entries);
 
-		hashmap_free(&o->current_file_dir_set, 1);
+		hashmap_free_entries(&opt->priv->current_file_dir_set,
+					struct path_hashmap_entry, e);
 
 		if (clean < 0) {
-			unpack_trees_finish(o);
+			unpack_trees_finish(opt);
 			return clean;
 		}
 	}
 	else
 		clean = 1;
 
-	unpack_trees_finish(o);
+	unpack_trees_finish(opt);
 
-	if (o->call_depth && !(*result = write_tree_from_memory(o)))
+	if (opt->priv->call_depth &&
+	    !(*result = write_in_core_index_as_tree(opt->repo)))
 		return -1;
 
 	return clean;
@@ -3364,49 +3567,62 @@ static struct commit_list *reverse_commi
  * Merge the commits h1 and h2, return the resulting virtual
  * commit object and a flag indicating the cleanness of the merge.
  */
-int merge_recursive(struct merge_options *o,
-		    struct commit *h1,
-		    struct commit *h2,
-		    struct commit_list *ca,
-		    struct commit **result)
+static int merge_recursive_internal(struct merge_options *opt,
+				    struct commit *h1,
+				    struct commit *h2,
+				    struct commit_list *merge_bases,
+				    struct commit **result)
 {
 	struct commit_list *iter;
-	struct commit *merged_common_ancestors;
-	struct tree *mrtree;
+	struct commit *merged_merge_bases;
+	struct tree *result_tree;
 	int clean;
+	const char *ancestor_name;
+	struct strbuf merge_base_abbrev = STRBUF_INIT;
 
-	if (show(o, 4)) {
-		output(o, 4, _("Merging:"));
-		output_commit_title(o, h1);
-		output_commit_title(o, h2);
+	if (show(opt, 4)) {
+		output(opt, 4, _("Merging:"));
+		output_commit_title(opt, h1);
+		output_commit_title(opt, h2);
 	}
 
-	if (!ca) {
-		ca = get_merge_bases(h1, h2);
-		ca = reverse_commit_list(ca);
+	if (!merge_bases) {
+		merge_bases = get_merge_bases(h1, h2);
+		merge_bases = reverse_commit_list(merge_bases);
 	}
 
-	if (show(o, 5)) {
-		unsigned cnt = commit_list_count(ca);
+	if (show(opt, 5)) {
+		unsigned cnt = commit_list_count(merge_bases);
 
-		output(o, 5, Q_("found %u common ancestor:",
+		output(opt, 5, Q_("found %u common ancestor:",
 				"found %u common ancestors:", cnt), cnt);
-		for (iter = ca; iter; iter = iter->next)
-			output_commit_title(o, iter->item);
+		for (iter = merge_bases; iter; iter = iter->next)
+			output_commit_title(opt, iter->item);
 	}
 
-	merged_common_ancestors = pop_commit(&ca);
-	if (merged_common_ancestors == NULL) {
+	merged_merge_bases = pop_commit(&merge_bases);
+	if (merged_merge_bases == NULL) {
 		/* if there is no common ancestor, use an empty tree */
 		struct tree *tree;
 
-		tree = lookup_tree(the_hash_algo->empty_tree);
-		merged_common_ancestors = make_virtual_commit(tree, "ancestor");
+		tree = lookup_tree(opt->repo, opt->repo->hash_algo->empty_tree);
+		merged_merge_bases = make_virtual_commit(opt->repo, tree,
+							 "ancestor");
+		ancestor_name = "empty tree";
+	} else if (opt->ancestor && !opt->priv->call_depth) {
+		ancestor_name = opt->ancestor;
+	} else if (merge_bases) {
+		ancestor_name = "merged common ancestors";
+	} else {
+		strbuf_add_unique_abbrev(&merge_base_abbrev,
+					 &merged_merge_bases->object.oid,
+					 DEFAULT_ABBREV);
+		ancestor_name = merge_base_abbrev.buf;
 	}
 
-	for (iter = ca; iter; iter = iter->next) {
+	for (iter = merge_bases; iter; iter = iter->next) {
 		const char *saved_b1, *saved_b2;
-		o->call_depth++;
+		opt->priv->call_depth++;
 		/*
 		 * When the merge fails, the result contains files
 		 * with conflict markers. The cleanness flag is
@@ -3415,58 +3631,149 @@ int merge_recursive(struct merge_options
 		 * overwritten it: the committed "conflicts" were
 		 * already resolved.
 		 */
-		discard_cache();
-		saved_b1 = o->branch1;
-		saved_b2 = o->branch2;
-		o->branch1 = "Temporary merge branch 1";
-		o->branch2 = "Temporary merge branch 2";
-		if (merge_recursive(o, merged_common_ancestors, iter->item,
-				    NULL, &merged_common_ancestors) < 0)
+		discard_index(opt->repo->index);
+		saved_b1 = opt->branch1;
+		saved_b2 = opt->branch2;
+		opt->branch1 = "Temporary merge branch 1";
+		opt->branch2 = "Temporary merge branch 2";
+		if (merge_recursive_internal(opt, merged_merge_bases, iter->item,
+					     NULL, &merged_merge_bases) < 0)
 			return -1;
-		o->branch1 = saved_b1;
-		o->branch2 = saved_b2;
-		o->call_depth--;
-
-		if (!merged_common_ancestors)
-			return err(o, _("merge returned no commit"));
-	}
-
-	discard_cache();
-	if (!o->call_depth)
-		read_cache();
-
-	o->ancestor = "merged common ancestors";
-	clean = merge_trees(o, get_commit_tree(h1), get_commit_tree(h2),
-			    get_commit_tree(merged_common_ancestors),
-			    &mrtree);
+		opt->branch1 = saved_b1;
+		opt->branch2 = saved_b2;
+		opt->priv->call_depth--;
+
+		if (!merged_merge_bases)
+			return err(opt, _("merge returned no commit"));
+	}
+
+	discard_index(opt->repo->index);
+	if (!opt->priv->call_depth)
+		repo_read_index(opt->repo);
+
+	opt->ancestor = ancestor_name;
+	clean = merge_trees_internal(opt,
+				     repo_get_commit_tree(opt->repo, h1),
+				     repo_get_commit_tree(opt->repo, h2),
+				     repo_get_commit_tree(opt->repo,
+							  merged_merge_bases),
+				     &result_tree);
+	strbuf_release(&merge_base_abbrev);
+	opt->ancestor = NULL;  /* avoid accidental re-use of opt->ancestor */
 	if (clean < 0) {
-		flush_output(o);
+		flush_output(opt);
 		return clean;
 	}
 
-	if (o->call_depth) {
-		*result = make_virtual_commit(mrtree, "merged tree");
+	if (opt->priv->call_depth) {
+		*result = make_virtual_commit(opt->repo, result_tree,
+					      "merged tree");
 		commit_list_insert(h1, &(*result)->parents);
 		commit_list_insert(h2, &(*result)->parents->next);
 	}
-	flush_output(o);
-	if (!o->call_depth && o->buffer_output < 2)
-		strbuf_release(&o->obuf);
-	if (show(o, 2))
+	return clean;
+}
+
+static int merge_start(struct merge_options *opt, struct tree *head)
+{
+	struct strbuf sb = STRBUF_INIT;
+
+	/* Sanity checks on opt */
+	assert(opt->repo);
+
+	assert(opt->branch1 && opt->branch2);
+
+	assert(opt->detect_renames >= -1 &&
+	       opt->detect_renames <= DIFF_DETECT_COPY);
+	assert(opt->detect_directory_renames >= MERGE_DIRECTORY_RENAMES_NONE &&
+	       opt->detect_directory_renames <= MERGE_DIRECTORY_RENAMES_TRUE);
+	assert(opt->rename_limit >= -1);
+	assert(opt->rename_score >= 0 && opt->rename_score <= MAX_SCORE);
+	assert(opt->show_rename_progress >= 0 && opt->show_rename_progress <= 1);
+
+	assert(opt->xdl_opts >= 0);
+	assert(opt->recursive_variant >= MERGE_VARIANT_NORMAL &&
+	       opt->recursive_variant <= MERGE_VARIANT_THEIRS);
+
+	assert(opt->verbosity >= 0 && opt->verbosity <= 5);
+	assert(opt->buffer_output <= 2);
+	assert(opt->obuf.len == 0);
+
+	assert(opt->priv == NULL);
+
+	/* Sanity check on repo state; index must match head */
+	if (repo_index_has_changes(opt->repo, head, &sb)) {
+		err(opt, _("Your local changes to the following files would be overwritten by merge:\n  %s"),
+		    sb.buf);
+		strbuf_release(&sb);
+		return -1;
+	}
+
+	opt->priv = xcalloc(1, sizeof(*opt->priv));
+	string_list_init(&opt->priv->df_conflict_file_set, 1);
+	return 0;
+}
+
+static void merge_finalize(struct merge_options *opt)
+{
+	flush_output(opt);
+	if (!opt->priv->call_depth && opt->buffer_output < 2)
+		strbuf_release(&opt->obuf);
+	if (show(opt, 2))
 		diff_warn_rename_limit("merge.renamelimit",
-				       o->needed_rename_limit, 0);
+				       opt->priv->needed_rename_limit, 0);
+	FREE_AND_NULL(opt->priv);
+}
+
+int merge_trees(struct merge_options *opt,
+		struct tree *head,
+		struct tree *merge,
+		struct tree *merge_base)
+{
+	int clean;
+	struct tree *ignored;
+
+	assert(opt->ancestor != NULL);
+
+	if (merge_start(opt, head))
+		return -1;
+	clean = merge_trees_internal(opt, head, merge, merge_base, &ignored);
+	merge_finalize(opt);
+
 	return clean;
 }
 
-static struct commit *get_ref(const struct object_id *oid, const char *name)
+int merge_recursive(struct merge_options *opt,
+		    struct commit *h1,
+		    struct commit *h2,
+		    struct commit_list *merge_bases,
+		    struct commit **result)
+{
+	int clean;
+
+	assert(opt->ancestor == NULL ||
+	       !strcmp(opt->ancestor, "constructed merge base"));
+
+	if (merge_start(opt, repo_get_commit_tree(opt->repo, h1)))
+		return -1;
+	clean = merge_recursive_internal(opt, h1, h2, merge_bases, result);
+	merge_finalize(opt);
+
+	return clean;
+}
+
+static struct commit *get_ref(struct repository *repo,
+			      const struct object_id *oid,
+			      const char *name)
 {
 	struct object *object;
 
-	object = deref_tag(parse_object(oid), name, strlen(name));
+	object = deref_tag(repo, parse_object(repo, oid),
+			   name, strlen(name));
 	if (!object)
 		return NULL;
 	if (object->type == OBJ_TREE)
-		return make_virtual_commit((struct tree*)object, name);
+		return make_virtual_commit(repo, (struct tree*)object, name);
 	if (object->type != OBJ_COMMIT)
 		return NULL;
 	if (parse_commit((struct commit *)object))
@@ -3474,134 +3781,158 @@ static struct commit *get_ref(const stru
 	return (struct commit *)object;
 }
 
-int merge_recursive_generic(struct merge_options *o,
+int merge_recursive_generic(struct merge_options *opt,
 			    const struct object_id *head,
 			    const struct object_id *merge,
-			    int num_base_list,
-			    const struct object_id **base_list,
+			    int num_merge_bases,
+			    const struct object_id **merge_bases,
 			    struct commit **result)
 {
 	int clean;
 	struct lock_file lock = LOCK_INIT;
-	struct commit *head_commit = get_ref(head, o->branch1);
-	struct commit *next_commit = get_ref(merge, o->branch2);
+	struct commit *head_commit = get_ref(opt->repo, head, opt->branch1);
+	struct commit *next_commit = get_ref(opt->repo, merge, opt->branch2);
 	struct commit_list *ca = NULL;
 
-	if (base_list) {
+	if (merge_bases) {
 		int i;
-		for (i = 0; i < num_base_list; ++i) {
+		for (i = 0; i < num_merge_bases; ++i) {
 			struct commit *base;
-			if (!(base = get_ref(base_list[i], oid_to_hex(base_list[i]))))
-				return err(o, _("Could not parse object '%s'"),
-					oid_to_hex(base_list[i]));
+			if (!(base = get_ref(opt->repo, merge_bases[i],
+					     oid_to_hex(merge_bases[i]))))
+				return err(opt, _("Could not parse object '%s'"),
+					   oid_to_hex(merge_bases[i]));
 			commit_list_insert(base, &ca);
 		}
+		if (num_merge_bases == 1)
+			opt->ancestor = "constructed merge base";
 	}
 
-	hold_locked_index(&lock, LOCK_DIE_ON_ERROR);
-	clean = merge_recursive(o, head_commit, next_commit, ca,
-			result);
+	repo_hold_locked_index(opt->repo, &lock, LOCK_DIE_ON_ERROR);
+	clean = merge_recursive(opt, head_commit, next_commit, ca,
+				result);
 	if (clean < 0) {
 		rollback_lock_file(&lock);
 		return clean;
 	}
 
-	if (write_locked_index(&the_index, &lock,
+	if (write_locked_index(opt->repo->index, &lock,
 			       COMMIT_LOCK | SKIP_IF_UNCHANGED))
-		return err(o, _("Unable to write index."));
+		return err(opt, _("Unable to write index."));
 
 	return clean ? 0 : 1;
 }
 
-static void merge_recursive_config(struct merge_options *o)
+static void merge_recursive_config(struct merge_options *opt)
 {
 	char *value = NULL;
-	git_config_get_int("merge.verbosity", &o->verbosity);
-	git_config_get_int("diff.renamelimit", &o->diff_rename_limit);
-	git_config_get_int("merge.renamelimit", &o->merge_rename_limit);
+	git_config_get_int("merge.verbosity", &opt->verbosity);
+	git_config_get_int("diff.renamelimit", &opt->rename_limit);
+	git_config_get_int("merge.renamelimit", &opt->rename_limit);
 	if (!git_config_get_string("diff.renames", &value)) {
-		o->diff_detect_rename = git_config_rename("diff.renames", value);
+		opt->detect_renames = git_config_rename("diff.renames", value);
 		free(value);
 	}
 	if (!git_config_get_string("merge.renames", &value)) {
-		o->merge_detect_rename = git_config_rename("merge.renames", value);
+		opt->detect_renames = git_config_rename("merge.renames", value);
+		free(value);
+	}
+	if (!git_config_get_string("merge.directoryrenames", &value)) {
+		int boolval = git_parse_maybe_bool(value);
+		if (0 <= boolval) {
+			opt->detect_directory_renames = boolval ?
+				MERGE_DIRECTORY_RENAMES_TRUE :
+				MERGE_DIRECTORY_RENAMES_NONE;
+		} else if (!strcasecmp(value, "conflict")) {
+			opt->detect_directory_renames =
+				MERGE_DIRECTORY_RENAMES_CONFLICT;
+		} /* avoid erroring on values from future versions of git */
 		free(value);
 	}
 	git_config(git_xmerge_config, NULL);
 }
 
-void init_merge_options(struct merge_options *o)
+void init_merge_options(struct merge_options *opt,
+			struct repository *repo)
 {
 	const char *merge_verbosity;
-	memset(o, 0, sizeof(struct merge_options));
-	o->verbosity = 2;
-	o->buffer_output = 1;
-	o->diff_rename_limit = -1;
-	o->merge_rename_limit = -1;
-	o->renormalize = 0;
-	o->diff_detect_rename = -1;
-	o->merge_detect_rename = -1;
-	merge_recursive_config(o);
+	memset(opt, 0, sizeof(struct merge_options));
+
+	opt->repo = repo;
+
+	opt->detect_renames = -1;
+	opt->detect_directory_renames = MERGE_DIRECTORY_RENAMES_CONFLICT;
+	opt->rename_limit = -1;
+
+	opt->verbosity = 2;
+	opt->buffer_output = 1;
+	strbuf_init(&opt->obuf, 0);
+
+	opt->renormalize = 0;
+
+	merge_recursive_config(opt);
 	merge_verbosity = getenv("GIT_MERGE_VERBOSITY");
 	if (merge_verbosity)
-		o->verbosity = strtol(merge_verbosity, NULL, 10);
-	if (o->verbosity >= 5)
-		o->buffer_output = 0;
-	strbuf_init(&o->obuf, 0);
-	string_list_init(&o->df_conflict_file_set, 1);
+		opt->verbosity = strtol(merge_verbosity, NULL, 10);
+	if (opt->verbosity >= 5)
+		opt->buffer_output = 0;
 }
 
-int parse_merge_opt(struct merge_options *o, const char *s)
+int parse_merge_opt(struct merge_options *opt, const char *s)
 {
 	const char *arg;
 
 	if (!s || !*s)
 		return -1;
 	if (!strcmp(s, "ours"))
-		o->recursive_variant = MERGE_RECURSIVE_OURS;
+		opt->recursive_variant = MERGE_VARIANT_OURS;
 	else if (!strcmp(s, "theirs"))
-		o->recursive_variant = MERGE_RECURSIVE_THEIRS;
+		opt->recursive_variant = MERGE_VARIANT_THEIRS;
 	else if (!strcmp(s, "subtree"))
-		o->subtree_shift = "";
+		opt->subtree_shift = "";
 	else if (skip_prefix(s, "subtree=", &arg))
-		o->subtree_shift = arg;
+		opt->subtree_shift = arg;
 	else if (!strcmp(s, "patience"))
-		o->xdl_opts = DIFF_WITH_ALG(o, PATIENCE_DIFF);
+		opt->xdl_opts = DIFF_WITH_ALG(opt, PATIENCE_DIFF);
 	else if (!strcmp(s, "histogram"))
-		o->xdl_opts = DIFF_WITH_ALG(o, HISTOGRAM_DIFF);
+		opt->xdl_opts = DIFF_WITH_ALG(opt, HISTOGRAM_DIFF);
 	else if (skip_prefix(s, "diff-algorithm=", &arg)) {
 		long value = parse_algorithm_value(arg);
 		if (value < 0)
 			return -1;
 		/* clear out previous settings */
-		DIFF_XDL_CLR(o, NEED_MINIMAL);
-		o->xdl_opts &= ~XDF_DIFF_ALGORITHM_MASK;
-		o->xdl_opts |= value;
+		DIFF_XDL_CLR(opt, NEED_MINIMAL);
+		opt->xdl_opts &= ~XDF_DIFF_ALGORITHM_MASK;
+		opt->xdl_opts |= value;
 	}
 	else if (!strcmp(s, "ignore-space-change"))
-		DIFF_XDL_SET(o, IGNORE_WHITESPACE_CHANGE);
+		DIFF_XDL_SET(opt, IGNORE_WHITESPACE_CHANGE);
 	else if (!strcmp(s, "ignore-all-space"))
-		DIFF_XDL_SET(o, IGNORE_WHITESPACE);
+		DIFF_XDL_SET(opt, IGNORE_WHITESPACE);
 	else if (!strcmp(s, "ignore-space-at-eol"))
-		DIFF_XDL_SET(o, IGNORE_WHITESPACE_AT_EOL);
+		DIFF_XDL_SET(opt, IGNORE_WHITESPACE_AT_EOL);
 	else if (!strcmp(s, "ignore-cr-at-eol"))
-		DIFF_XDL_SET(o, IGNORE_CR_AT_EOL);
+		DIFF_XDL_SET(opt, IGNORE_CR_AT_EOL);
 	else if (!strcmp(s, "renormalize"))
-		o->renormalize = 1;
+		opt->renormalize = 1;
 	else if (!strcmp(s, "no-renormalize"))
-		o->renormalize = 0;
+		opt->renormalize = 0;
 	else if (!strcmp(s, "no-renames"))
-		o->merge_detect_rename = 0;
+		opt->detect_renames = 0;
 	else if (!strcmp(s, "find-renames")) {
-		o->merge_detect_rename = 1;
-		o->rename_score = 0;
+		opt->detect_renames = 1;
+		opt->rename_score = 0;
 	}
 	else if (skip_prefix(s, "find-renames=", &arg) ||
 		 skip_prefix(s, "rename-threshold=", &arg)) {
-		if ((o->rename_score = parse_rename_score(&arg)) == -1 || *arg != 0)
+		if ((opt->rename_score = parse_rename_score(&arg)) == -1 || *arg != 0)
 			return -1;
-		o->merge_detect_rename = 1;
+		opt->detect_renames = 1;
 	}
+	/*
+	 * Please update $__git_merge_strategy_options in
+	 * git-completion.bash when you add new options
+	 */
 	else
 		return -1;
 	return 0;
diff -pruN 1.2.1+git2.18.0-1/git/merge-recursive.h 1.2.3+git2.25.1-1/git/merge-recursive.h
--- 1.2.1+git2.18.0-1/git/merge-recursive.h	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/merge-recursive.h	2020-02-17 04:47:35.000000000 +0000
@@ -1,97 +1,124 @@
 #ifndef MERGE_RECURSIVE_H
 #define MERGE_RECURSIVE_H
 
-#include "unpack-trees.h"
-#include "string-list.h"
+#include "strbuf.h"
 
+struct commit;
+struct commit_list;
+struct object_id;
+struct repository;
+struct tree;
+
+struct merge_options_internal;
 struct merge_options {
+	struct repository *repo;
+
+	/* ref names used in console messages and conflict markers */
 	const char *ancestor;
 	const char *branch1;
 	const char *branch2;
+
+	/* rename related options */
+	int detect_renames;
+	enum {
+		MERGE_DIRECTORY_RENAMES_NONE = 0,
+		MERGE_DIRECTORY_RENAMES_CONFLICT = 1,
+		MERGE_DIRECTORY_RENAMES_TRUE = 2
+	} detect_directory_renames;
+	int rename_limit;
+	int rename_score;
+	int show_rename_progress;
+
+	/* xdiff-related options (patience, ignore whitespace, ours/theirs) */
+	long xdl_opts;
 	enum {
-		MERGE_RECURSIVE_NORMAL = 0,
-		MERGE_RECURSIVE_OURS,
-		MERGE_RECURSIVE_THEIRS
+		MERGE_VARIANT_NORMAL = 0,
+		MERGE_VARIANT_OURS,
+		MERGE_VARIANT_THEIRS
 	} recursive_variant;
-	const char *subtree_shift;
+
+	/* console output related options */
+	int verbosity;
 	unsigned buffer_output; /* 1: output at end, 2: keep buffered */
+	struct strbuf obuf;     /* output buffer; if buffer_output == 2, caller
+				 * must handle and call strbuf_release */
+
+	/* miscellaneous control options */
+	const char *subtree_shift;
 	unsigned renormalize : 1;
-	long xdl_opts;
-	int verbosity;
-	int diff_detect_rename;
-	int merge_detect_rename;
-	int diff_rename_limit;
-	int merge_rename_limit;
-	int rename_score;
-	int needed_rename_limit;
-	int show_rename_progress;
-	int call_depth;
-	struct strbuf obuf;
-	struct hashmap current_file_dir_set;
-	struct string_list df_conflict_file_set;
-	struct unpack_trees_options unpack_opts;
-	struct index_state orig_index;
+
+	/* internal fields used by the implementation */
+	struct merge_options_internal *priv;
 };
 
+void init_merge_options(struct merge_options *opt, struct repository *repo);
+
+/* parse the option in s and update the relevant field of opt */
+int parse_merge_opt(struct merge_options *opt, const char *s);
+
 /*
- * For dir_rename_entry, directory names are stored as a full path from the
- * toplevel of the repository and do not include a trailing '/'.  Also:
- *
- *   dir:                original name of directory being renamed
- *   non_unique_new_dir: if true, could not determine new_dir
- *   new_dir:            final name of directory being renamed
- *   possible_new_dirs:  temporary used to help determine new_dir; see comments
- *                       in get_directory_renames() for details
+ * RETURN VALUES: All the merge_* functions below return a value as follows:
+ *   > 0     Merge was clean
+ *   = 0     Merge had conflicts
+ *   < 0     Merge hit an unexpected and unrecoverable problem (e.g. disk
+ *             full) and aborted merge part-way through.
  */
-struct dir_rename_entry {
-	struct hashmap_entry ent; /* must be the first member! */
-	char *dir;
-	unsigned non_unique_new_dir:1;
-	struct strbuf new_dir;
-	struct string_list possible_new_dirs;
-};
 
-struct collision_entry {
-	struct hashmap_entry ent; /* must be the first member! */
-	char *target_file;
-	struct string_list source_files;
-	unsigned reported_already:1;
-};
-
-static inline int merge_detect_rename(struct merge_options *o)
-{
-	return o->merge_detect_rename >= 0 ? o->merge_detect_rename :
-		o->diff_detect_rename >= 0 ? o->diff_detect_rename : 1;
-}
+/*
+ * rename-detecting three-way merge, no recursion.
+ *
+ * Outputs:
+ *   - See RETURN VALUES above
+ *   - No commit is created
+ *   - opt->repo->index has the new index
+ *   - $GIT_INDEX_FILE is not updated
+ *   - The working tree is updated with results of the merge
+ */
+int merge_trees(struct merge_options *opt,
+		struct tree *head,
+		struct tree *merge,
+		struct tree *merge_base);
 
-/* merge_trees() but with recursive ancestor consolidation */
-int merge_recursive(struct merge_options *o,
+/*
+ * merge_recursive is like merge_trees() but with recursive ancestor
+ * consolidation and, if the commit is clean, creation of a commit.
+ *
+ * NOTE: empirically, about a decade ago it was determined that with more
+ *       than two merge bases, optimal behavior was found when the
+ *       merge_bases were passed in the order of oldest commit to newest
+ *       commit.  Also, merge_bases will be consumed (emptied) so make a
+ *       copy if you need it.
+ *
+ * Outputs:
+ *   - See RETURN VALUES above
+ *   - If merge is clean, a commit is created and its address written to *result
+ *   - opt->repo->index has the new index
+ *   - $GIT_INDEX_FILE is not updated
+ *   - The working tree is updated with results of the merge
+ */
+int merge_recursive(struct merge_options *opt,
 		    struct commit *h1,
 		    struct commit *h2,
-		    struct commit_list *ancestors,
+		    struct commit_list *merge_bases,
 		    struct commit **result);
 
-/* rename-detecting three-way merge, no recursion */
-int merge_trees(struct merge_options *o,
-		struct tree *head,
-		struct tree *merge,
-		struct tree *common,
-		struct tree **result);
-
 /*
- * "git-merge-recursive" can be fed trees; wrap them into
- * virtual commits and call merge_recursive() proper.
+ * merge_recursive_generic can operate on trees instead of commits, by
+ * wrapping the trees into virtual commits, and calling merge_recursive().
+ * It also writes out the in-memory index to disk if the merge is successful.
+ *
+ * Outputs:
+ *   - See RETURN VALUES above
+ *   - If merge is clean, a commit is created and its address written to *result
+ *   - opt->repo->index has the new index
+ *   - $GIT_INDEX_FILE is updated
+ *   - The working tree is updated with results of the merge
  */
-int merge_recursive_generic(struct merge_options *o,
+int merge_recursive_generic(struct merge_options *opt,
 			    const struct object_id *head,
 			    const struct object_id *merge,
-			    int num_ca,
-			    const struct object_id **ca,
+			    int num_merge_bases,
+			    const struct object_id **merge_bases,
 			    struct commit **result);
 
-void init_merge_options(struct merge_options *o);
-struct tree *write_tree_from_memory(struct merge_options *o);
-
-int parse_merge_opt(struct merge_options *out, const char *s);
-
 #endif
diff -pruN 1.2.1+git2.18.0-1/git/mergetools/smerge 1.2.3+git2.25.1-1/git/mergetools/smerge
--- 1.2.1+git2.18.0-1/git/mergetools/smerge	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/mergetools/smerge	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,12 @@
+diff_cmd () {
+	"$merge_tool_path" mergetool "$LOCAL" "$REMOTE" -o "$MERGED"
+}
+
+merge_cmd () {
+	if $base_present
+	then
+		"$merge_tool_path" mergetool "$BASE" "$LOCAL" "$REMOTE" -o "$MERGED"
+	else
+		"$merge_tool_path" mergetool "$LOCAL" "$REMOTE" -o "$MERGED"
+	fi
+}
diff -pruN 1.2.1+git2.18.0-1/git/midx.c 1.2.3+git2.25.1-1/git/midx.c
--- 1.2.1+git2.18.0-1/git/midx.c	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/midx.c	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,1420 @@
+#include "cache.h"
+#include "config.h"
+#include "csum-file.h"
+#include "dir.h"
+#include "lockfile.h"
+#include "packfile.h"
+#include "object-store.h"
+#include "sha1-lookup.h"
+#include "midx.h"
+#include "progress.h"
+#include "trace2.h"
+#include "run-command.h"
+
+#define MIDX_SIGNATURE 0x4d494458 /* "MIDX" */
+#define MIDX_VERSION 1
+#define MIDX_BYTE_FILE_VERSION 4
+#define MIDX_BYTE_HASH_VERSION 5
+#define MIDX_BYTE_NUM_CHUNKS 6
+#define MIDX_BYTE_NUM_PACKS 8
+#define MIDX_HASH_VERSION 1
+#define MIDX_HEADER_SIZE 12
+#define MIDX_MIN_SIZE (MIDX_HEADER_SIZE + the_hash_algo->rawsz)
+
+#define MIDX_MAX_CHUNKS 5
+#define MIDX_CHUNK_ALIGNMENT 4
+#define MIDX_CHUNKID_PACKNAMES 0x504e414d /* "PNAM" */
+#define MIDX_CHUNKID_OIDFANOUT 0x4f494446 /* "OIDF" */
+#define MIDX_CHUNKID_OIDLOOKUP 0x4f49444c /* "OIDL" */
+#define MIDX_CHUNKID_OBJECTOFFSETS 0x4f4f4646 /* "OOFF" */
+#define MIDX_CHUNKID_LARGEOFFSETS 0x4c4f4646 /* "LOFF" */
+#define MIDX_CHUNKLOOKUP_WIDTH (sizeof(uint32_t) + sizeof(uint64_t))
+#define MIDX_CHUNK_FANOUT_SIZE (sizeof(uint32_t) * 256)
+#define MIDX_CHUNK_OFFSET_WIDTH (2 * sizeof(uint32_t))
+#define MIDX_CHUNK_LARGE_OFFSET_WIDTH (sizeof(uint64_t))
+#define MIDX_LARGE_OFFSET_NEEDED 0x80000000
+
+#define PACK_EXPIRED UINT_MAX
+
+static char *get_midx_filename(const char *object_dir)
+{
+	return xstrfmt("%s/pack/multi-pack-index", object_dir);
+}
+
+struct multi_pack_index *load_multi_pack_index(const char *object_dir, int local)
+{
+	struct multi_pack_index *m = NULL;
+	int fd;
+	struct stat st;
+	size_t midx_size;
+	void *midx_map = NULL;
+	uint32_t hash_version;
+	char *midx_name = get_midx_filename(object_dir);
+	uint32_t i;
+	const char *cur_pack_name;
+
+	fd = git_open(midx_name);
+
+	if (fd < 0)
+		goto cleanup_fail;
+	if (fstat(fd, &st)) {
+		error_errno(_("failed to read %s"), midx_name);
+		goto cleanup_fail;
+	}
+
+	midx_size = xsize_t(st.st_size);
+
+	if (midx_size < MIDX_MIN_SIZE) {
+		error(_("multi-pack-index file %s is too small"), midx_name);
+		goto cleanup_fail;
+	}
+
+	FREE_AND_NULL(midx_name);
+
+	midx_map = xmmap(NULL, midx_size, PROT_READ, MAP_PRIVATE, fd, 0);
+
+	FLEX_ALLOC_STR(m, object_dir, object_dir);
+	m->fd = fd;
+	m->data = midx_map;
+	m->data_len = midx_size;
+	m->local = local;
+
+	m->signature = get_be32(m->data);
+	if (m->signature != MIDX_SIGNATURE)
+		die(_("multi-pack-index signature 0x%08x does not match signature 0x%08x"),
+		      m->signature, MIDX_SIGNATURE);
+
+	m->version = m->data[MIDX_BYTE_FILE_VERSION];
+	if (m->version != MIDX_VERSION)
+		die(_("multi-pack-index version %d not recognized"),
+		      m->version);
+
+	hash_version = m->data[MIDX_BYTE_HASH_VERSION];
+	if (hash_version != MIDX_HASH_VERSION)
+		die(_("hash version %u does not match"), hash_version);
+	m->hash_len = the_hash_algo->rawsz;
+
+	m->num_chunks = m->data[MIDX_BYTE_NUM_CHUNKS];
+
+	m->num_packs = get_be32(m->data + MIDX_BYTE_NUM_PACKS);
+
+	for (i = 0; i < m->num_chunks; i++) {
+		uint32_t chunk_id = get_be32(m->data + MIDX_HEADER_SIZE +
+					     MIDX_CHUNKLOOKUP_WIDTH * i);
+		uint64_t chunk_offset = get_be64(m->data + MIDX_HEADER_SIZE + 4 +
+						 MIDX_CHUNKLOOKUP_WIDTH * i);
+
+		if (chunk_offset >= m->data_len)
+			die(_("invalid chunk offset (too large)"));
+
+		switch (chunk_id) {
+			case MIDX_CHUNKID_PACKNAMES:
+				m->chunk_pack_names = m->data + chunk_offset;
+				break;
+
+			case MIDX_CHUNKID_OIDFANOUT:
+				m->chunk_oid_fanout = (uint32_t *)(m->data + chunk_offset);
+				break;
+
+			case MIDX_CHUNKID_OIDLOOKUP:
+				m->chunk_oid_lookup = m->data + chunk_offset;
+				break;
+
+			case MIDX_CHUNKID_OBJECTOFFSETS:
+				m->chunk_object_offsets = m->data + chunk_offset;
+				break;
+
+			case MIDX_CHUNKID_LARGEOFFSETS:
+				m->chunk_large_offsets = m->data + chunk_offset;
+				break;
+
+			case 0:
+				die(_("terminating multi-pack-index chunk id appears earlier than expected"));
+				break;
+
+			default:
+				/*
+				 * Do nothing on unrecognized chunks, allowing future
+				 * extensions to add optional chunks.
+				 */
+				break;
+		}
+	}
+
+	if (!m->chunk_pack_names)
+		die(_("multi-pack-index missing required pack-name chunk"));
+	if (!m->chunk_oid_fanout)
+		die(_("multi-pack-index missing required OID fanout chunk"));
+	if (!m->chunk_oid_lookup)
+		die(_("multi-pack-index missing required OID lookup chunk"));
+	if (!m->chunk_object_offsets)
+		die(_("multi-pack-index missing required object offsets chunk"));
+
+	m->num_objects = ntohl(m->chunk_oid_fanout[255]);
+
+	m->pack_names = xcalloc(m->num_packs, sizeof(*m->pack_names));
+	m->packs = xcalloc(m->num_packs, sizeof(*m->packs));
+
+	cur_pack_name = (const char *)m->chunk_pack_names;
+	for (i = 0; i < m->num_packs; i++) {
+		m->pack_names[i] = cur_pack_name;
+
+		cur_pack_name += strlen(cur_pack_name) + 1;
+
+		if (i && strcmp(m->pack_names[i], m->pack_names[i - 1]) <= 0)
+			die(_("multi-pack-index pack names out of order: '%s' before '%s'"),
+			      m->pack_names[i - 1],
+			      m->pack_names[i]);
+	}
+
+	trace2_data_intmax("midx", the_repository, "load/num_packs", m->num_packs);
+	trace2_data_intmax("midx", the_repository, "load/num_objects", m->num_objects);
+
+	return m;
+
+cleanup_fail:
+	free(m);
+	free(midx_name);
+	if (midx_map)
+		munmap(midx_map, midx_size);
+	if (0 <= fd)
+		close(fd);
+	return NULL;
+}
+
+void close_midx(struct multi_pack_index *m)
+{
+	uint32_t i;
+
+	if (!m)
+		return;
+
+	munmap((unsigned char *)m->data, m->data_len);
+	close(m->fd);
+	m->fd = -1;
+
+	for (i = 0; i < m->num_packs; i++) {
+		if (m->packs[i])
+			m->packs[i]->multi_pack_index = 0;
+	}
+	FREE_AND_NULL(m->packs);
+	FREE_AND_NULL(m->pack_names);
+}
+
+int prepare_midx_pack(struct repository *r, struct multi_pack_index *m, uint32_t pack_int_id)
+{
+	struct strbuf pack_name = STRBUF_INIT;
+	struct packed_git *p;
+
+	if (pack_int_id >= m->num_packs)
+		die(_("bad pack-int-id: %u (%u total packs)"),
+		    pack_int_id, m->num_packs);
+
+	if (m->packs[pack_int_id])
+		return 0;
+
+	strbuf_addf(&pack_name, "%s/pack/%s", m->object_dir,
+		    m->pack_names[pack_int_id]);
+
+	p = add_packed_git(pack_name.buf, pack_name.len, m->local);
+	strbuf_release(&pack_name);
+
+	if (!p)
+		return 1;
+
+	p->multi_pack_index = 1;
+	m->packs[pack_int_id] = p;
+	install_packed_git(r, p);
+	list_add_tail(&p->mru, &r->objects->packed_git_mru);
+
+	return 0;
+}
+
+int bsearch_midx(const struct object_id *oid, struct multi_pack_index *m, uint32_t *result)
+{
+	return bsearch_hash(oid->hash, m->chunk_oid_fanout, m->chunk_oid_lookup,
+			    the_hash_algo->rawsz, result);
+}
+
+struct object_id *nth_midxed_object_oid(struct object_id *oid,
+					struct multi_pack_index *m,
+					uint32_t n)
+{
+	if (n >= m->num_objects)
+		return NULL;
+
+	hashcpy(oid->hash, m->chunk_oid_lookup + m->hash_len * n);
+	return oid;
+}
+
+static off_t nth_midxed_offset(struct multi_pack_index *m, uint32_t pos)
+{
+	const unsigned char *offset_data;
+	uint32_t offset32;
+
+	offset_data = m->chunk_object_offsets + pos * MIDX_CHUNK_OFFSET_WIDTH;
+	offset32 = get_be32(offset_data + sizeof(uint32_t));
+
+	if (m->chunk_large_offsets && offset32 & MIDX_LARGE_OFFSET_NEEDED) {
+		if (sizeof(off_t) < sizeof(uint64_t))
+			die(_("multi-pack-index stores a 64-bit offset, but off_t is too small"));
+
+		offset32 ^= MIDX_LARGE_OFFSET_NEEDED;
+		return get_be64(m->chunk_large_offsets + sizeof(uint64_t) * offset32);
+	}
+
+	return offset32;
+}
+
+static uint32_t nth_midxed_pack_int_id(struct multi_pack_index *m, uint32_t pos)
+{
+	return get_be32(m->chunk_object_offsets + pos * MIDX_CHUNK_OFFSET_WIDTH);
+}
+
+static int nth_midxed_pack_entry(struct repository *r,
+				 struct multi_pack_index *m,
+				 struct pack_entry *e,
+				 uint32_t pos)
+{
+	uint32_t pack_int_id;
+	struct packed_git *p;
+
+	if (pos >= m->num_objects)
+		return 0;
+
+	pack_int_id = nth_midxed_pack_int_id(m, pos);
+
+	if (prepare_midx_pack(r, m, pack_int_id))
+		die(_("error preparing packfile from multi-pack-index"));
+	p = m->packs[pack_int_id];
+
+	/*
+	* We are about to tell the caller where they can locate the
+	* requested object.  We better make sure the packfile is
+	* still here and can be accessed before supplying that
+	* answer, as it may have been deleted since the MIDX was
+	* loaded!
+	*/
+	if (!is_pack_valid(p))
+		return 0;
+
+	if (p->num_bad_objects) {
+		uint32_t i;
+		struct object_id oid;
+		nth_midxed_object_oid(&oid, m, pos);
+		for (i = 0; i < p->num_bad_objects; i++)
+			if (hasheq(oid.hash,
+				   p->bad_object_sha1 + the_hash_algo->rawsz * i))
+				return 0;
+	}
+
+	e->offset = nth_midxed_offset(m, pos);
+	e->p = p;
+
+	return 1;
+}
+
+int fill_midx_entry(struct repository * r,
+		    const struct object_id *oid,
+		    struct pack_entry *e,
+		    struct multi_pack_index *m)
+{
+	uint32_t pos;
+
+	if (!bsearch_midx(oid, m, &pos))
+		return 0;
+
+	return nth_midxed_pack_entry(r, m, e, pos);
+}
+
+/* Match "foo.idx" against either "foo.pack" _or_ "foo.idx". */
+static int cmp_idx_or_pack_name(const char *idx_or_pack_name,
+				const char *idx_name)
+{
+	/* Skip past any initial matching prefix. */
+	while (*idx_name && *idx_name == *idx_or_pack_name) {
+		idx_name++;
+		idx_or_pack_name++;
+	}
+
+	/*
+	 * If we didn't match completely, we may have matched "pack-1234." and
+	 * be left with "idx" and "pack" respectively, which is also OK. We do
+	 * not have to check for "idx" and "idx", because that would have been
+	 * a complete match (and in that case these strcmps will be false, but
+	 * we'll correctly return 0 from the final strcmp() below.
+	 *
+	 * Technically this matches "fooidx" and "foopack", but we'd never have
+	 * such names in the first place.
+	 */
+	if (!strcmp(idx_name, "idx") && !strcmp(idx_or_pack_name, "pack"))
+		return 0;
+
+	/*
+	 * This not only checks for a complete match, but also orders based on
+	 * the first non-identical character, which means our ordering will
+	 * match a raw strcmp(). That makes it OK to use this to binary search
+	 * a naively-sorted list.
+	 */
+	return strcmp(idx_or_pack_name, idx_name);
+}
+
+int midx_contains_pack(struct multi_pack_index *m, const char *idx_or_pack_name)
+{
+	uint32_t first = 0, last = m->num_packs;
+
+	while (first < last) {
+		uint32_t mid = first + (last - first) / 2;
+		const char *current;
+		int cmp;
+
+		current = m->pack_names[mid];
+		cmp = cmp_idx_or_pack_name(idx_or_pack_name, current);
+		if (!cmp)
+			return 1;
+		if (cmp > 0) {
+			first = mid + 1;
+			continue;
+		}
+		last = mid;
+	}
+
+	return 0;
+}
+
+int prepare_multi_pack_index_one(struct repository *r, const char *object_dir, int local)
+{
+	struct multi_pack_index *m;
+	struct multi_pack_index *m_search;
+	int config_value;
+	static int env_value = -1;
+
+	if (env_value < 0)
+		env_value = git_env_bool(GIT_TEST_MULTI_PACK_INDEX, 0);
+
+	if (!env_value &&
+	    (repo_config_get_bool(r, "core.multipackindex", &config_value) ||
+	    !config_value))
+		return 0;
+
+	for (m_search = r->objects->multi_pack_index; m_search; m_search = m_search->next)
+		if (!strcmp(object_dir, m_search->object_dir))
+			return 1;
+
+	m = load_multi_pack_index(object_dir, local);
+
+	if (m) {
+		m->next = r->objects->multi_pack_index;
+		r->objects->multi_pack_index = m;
+		return 1;
+	}
+
+	return 0;
+}
+
+static size_t write_midx_header(struct hashfile *f,
+				unsigned char num_chunks,
+				uint32_t num_packs)
+{
+	unsigned char byte_values[4];
+
+	hashwrite_be32(f, MIDX_SIGNATURE);
+	byte_values[0] = MIDX_VERSION;
+	byte_values[1] = MIDX_HASH_VERSION;
+	byte_values[2] = num_chunks;
+	byte_values[3] = 0; /* unused */
+	hashwrite(f, byte_values, sizeof(byte_values));
+	hashwrite_be32(f, num_packs);
+
+	return MIDX_HEADER_SIZE;
+}
+
+struct pack_info {
+	uint32_t orig_pack_int_id;
+	char *pack_name;
+	struct packed_git *p;
+	unsigned expired : 1;
+};
+
+static int pack_info_compare(const void *_a, const void *_b)
+{
+	struct pack_info *a = (struct pack_info *)_a;
+	struct pack_info *b = (struct pack_info *)_b;
+	return strcmp(a->pack_name, b->pack_name);
+}
+
+struct pack_list {
+	struct pack_info *info;
+	uint32_t nr;
+	uint32_t alloc;
+	struct multi_pack_index *m;
+	struct progress *progress;
+	unsigned pack_paths_checked;
+};
+
+static void add_pack_to_midx(const char *full_path, size_t full_path_len,
+			     const char *file_name, void *data)
+{
+	struct pack_list *packs = (struct pack_list *)data;
+
+	if (ends_with(file_name, ".idx")) {
+		display_progress(packs->progress, ++packs->pack_paths_checked);
+		if (packs->m && midx_contains_pack(packs->m, file_name))
+			return;
+
+		ALLOC_GROW(packs->info, packs->nr + 1, packs->alloc);
+
+		packs->info[packs->nr].p = add_packed_git(full_path,
+							  full_path_len,
+							  0);
+
+		if (!packs->info[packs->nr].p) {
+			warning(_("failed to add packfile '%s'"),
+				full_path);
+			return;
+		}
+
+		if (open_pack_index(packs->info[packs->nr].p)) {
+			warning(_("failed to open pack-index '%s'"),
+				full_path);
+			close_pack(packs->info[packs->nr].p);
+			FREE_AND_NULL(packs->info[packs->nr].p);
+			return;
+		}
+
+		packs->info[packs->nr].pack_name = xstrdup(file_name);
+		packs->info[packs->nr].orig_pack_int_id = packs->nr;
+		packs->info[packs->nr].expired = 0;
+		packs->nr++;
+	}
+}
+
+struct pack_midx_entry {
+	struct object_id oid;
+	uint32_t pack_int_id;
+	time_t pack_mtime;
+	uint64_t offset;
+};
+
+static int midx_oid_compare(const void *_a, const void *_b)
+{
+	const struct pack_midx_entry *a = (const struct pack_midx_entry *)_a;
+	const struct pack_midx_entry *b = (const struct pack_midx_entry *)_b;
+	int cmp = oidcmp(&a->oid, &b->oid);
+
+	if (cmp)
+		return cmp;
+
+	if (a->pack_mtime > b->pack_mtime)
+		return -1;
+	else if (a->pack_mtime < b->pack_mtime)
+		return 1;
+
+	return a->pack_int_id - b->pack_int_id;
+}
+
+static int nth_midxed_pack_midx_entry(struct multi_pack_index *m,
+				      struct pack_midx_entry *e,
+				      uint32_t pos)
+{
+	if (pos >= m->num_objects)
+		return 1;
+
+	nth_midxed_object_oid(&e->oid, m, pos);
+	e->pack_int_id = nth_midxed_pack_int_id(m, pos);
+	e->offset = nth_midxed_offset(m, pos);
+
+	/* consider objects in midx to be from "old" packs */
+	e->pack_mtime = 0;
+	return 0;
+}
+
+static void fill_pack_entry(uint32_t pack_int_id,
+			    struct packed_git *p,
+			    uint32_t cur_object,
+			    struct pack_midx_entry *entry)
+{
+	if (!nth_packed_object_oid(&entry->oid, p, cur_object))
+		die(_("failed to locate object %d in packfile"), cur_object);
+
+	entry->pack_int_id = pack_int_id;
+	entry->pack_mtime = p->mtime;
+
+	entry->offset = nth_packed_object_offset(p, cur_object);
+}
+
+/*
+ * It is possible to artificially get into a state where there are many
+ * duplicate copies of objects. That can create high memory pressure if
+ * we are to create a list of all objects before de-duplication. To reduce
+ * this memory pressure without a significant performance drop, automatically
+ * group objects by the first byte of their object id. Use the IDX fanout
+ * tables to group the data, copy to a local array, then sort.
+ *
+ * Copy only the de-duplicated entries (selected by most-recent modified time
+ * of a packfile containing the object).
+ */
+static struct pack_midx_entry *get_sorted_entries(struct multi_pack_index *m,
+						  struct pack_info *info,
+						  uint32_t nr_packs,
+						  uint32_t *nr_objects)
+{
+	uint32_t cur_fanout, cur_pack, cur_object;
+	uint32_t alloc_fanout, alloc_objects, total_objects = 0;
+	struct pack_midx_entry *entries_by_fanout = NULL;
+	struct pack_midx_entry *deduplicated_entries = NULL;
+	uint32_t start_pack = m ? m->num_packs : 0;
+
+	for (cur_pack = start_pack; cur_pack < nr_packs; cur_pack++)
+		total_objects += info[cur_pack].p->num_objects;
+
+	/*
+	 * As we de-duplicate by fanout value, we expect the fanout
+	 * slices to be evenly distributed, with some noise. Hence,
+	 * allocate slightly more than one 256th.
+	 */
+	alloc_objects = alloc_fanout = total_objects > 3200 ? total_objects / 200 : 16;
+
+	ALLOC_ARRAY(entries_by_fanout, alloc_fanout);
+	ALLOC_ARRAY(deduplicated_entries, alloc_objects);
+	*nr_objects = 0;
+
+	for (cur_fanout = 0; cur_fanout < 256; cur_fanout++) {
+		uint32_t nr_fanout = 0;
+
+		if (m) {
+			uint32_t start = 0, end;
+
+			if (cur_fanout)
+				start = ntohl(m->chunk_oid_fanout[cur_fanout - 1]);
+			end = ntohl(m->chunk_oid_fanout[cur_fanout]);
+
+			for (cur_object = start; cur_object < end; cur_object++) {
+				ALLOC_GROW(entries_by_fanout, nr_fanout + 1, alloc_fanout);
+				nth_midxed_pack_midx_entry(m,
+							   &entries_by_fanout[nr_fanout],
+							   cur_object);
+				nr_fanout++;
+			}
+		}
+
+		for (cur_pack = start_pack; cur_pack < nr_packs; cur_pack++) {
+			uint32_t start = 0, end;
+
+			if (cur_fanout)
+				start = get_pack_fanout(info[cur_pack].p, cur_fanout - 1);
+			end = get_pack_fanout(info[cur_pack].p, cur_fanout);
+
+			for (cur_object = start; cur_object < end; cur_object++) {
+				ALLOC_GROW(entries_by_fanout, nr_fanout + 1, alloc_fanout);
+				fill_pack_entry(cur_pack, info[cur_pack].p, cur_object, &entries_by_fanout[nr_fanout]);
+				nr_fanout++;
+			}
+		}
+
+		QSORT(entries_by_fanout, nr_fanout, midx_oid_compare);
+
+		/*
+		 * The batch is now sorted by OID and then mtime (descending).
+		 * Take only the first duplicate.
+		 */
+		for (cur_object = 0; cur_object < nr_fanout; cur_object++) {
+			if (cur_object && oideq(&entries_by_fanout[cur_object - 1].oid,
+						&entries_by_fanout[cur_object].oid))
+				continue;
+
+			ALLOC_GROW(deduplicated_entries, *nr_objects + 1, alloc_objects);
+			memcpy(&deduplicated_entries[*nr_objects],
+			       &entries_by_fanout[cur_object],
+			       sizeof(struct pack_midx_entry));
+			(*nr_objects)++;
+		}
+	}
+
+	free(entries_by_fanout);
+	return deduplicated_entries;
+}
+
+static size_t write_midx_pack_names(struct hashfile *f,
+				    struct pack_info *info,
+				    uint32_t num_packs)
+{
+	uint32_t i;
+	unsigned char padding[MIDX_CHUNK_ALIGNMENT];
+	size_t written = 0;
+
+	for (i = 0; i < num_packs; i++) {
+		size_t writelen;
+
+		if (info[i].expired)
+			continue;
+
+		if (i && strcmp(info[i].pack_name, info[i - 1].pack_name) <= 0)
+			BUG("incorrect pack-file order: %s before %s",
+			    info[i - 1].pack_name,
+			    info[i].pack_name);
+
+		writelen = strlen(info[i].pack_name) + 1;
+		hashwrite(f, info[i].pack_name, writelen);
+		written += writelen;
+	}
+
+	/* add padding to be aligned */
+	i = MIDX_CHUNK_ALIGNMENT - (written % MIDX_CHUNK_ALIGNMENT);
+	if (i < MIDX_CHUNK_ALIGNMENT) {
+		memset(padding, 0, sizeof(padding));
+		hashwrite(f, padding, i);
+		written += i;
+	}
+
+	return written;
+}
+
+static size_t write_midx_oid_fanout(struct hashfile *f,
+				    struct pack_midx_entry *objects,
+				    uint32_t nr_objects)
+{
+	struct pack_midx_entry *list = objects;
+	struct pack_midx_entry *last = objects + nr_objects;
+	uint32_t count = 0;
+	uint32_t i;
+
+	/*
+	* Write the first-level table (the list is sorted,
+	* but we use a 256-entry lookup to be able to avoid
+	* having to do eight extra binary search iterations).
+	*/
+	for (i = 0; i < 256; i++) {
+		struct pack_midx_entry *next = list;
+
+		while (next < last && next->oid.hash[0] == i) {
+			count++;
+			next++;
+		}
+
+		hashwrite_be32(f, count);
+		list = next;
+	}
+
+	return MIDX_CHUNK_FANOUT_SIZE;
+}
+
+static size_t write_midx_oid_lookup(struct hashfile *f, unsigned char hash_len,
+				    struct pack_midx_entry *objects,
+				    uint32_t nr_objects)
+{
+	struct pack_midx_entry *list = objects;
+	uint32_t i;
+	size_t written = 0;
+
+	for (i = 0; i < nr_objects; i++) {
+		struct pack_midx_entry *obj = list++;
+
+		if (i < nr_objects - 1) {
+			struct pack_midx_entry *next = list;
+			if (oidcmp(&obj->oid, &next->oid) >= 0)
+				BUG("OIDs not in order: %s >= %s",
+				    oid_to_hex(&obj->oid),
+				    oid_to_hex(&next->oid));
+		}
+
+		hashwrite(f, obj->oid.hash, (int)hash_len);
+		written += hash_len;
+	}
+
+	return written;
+}
+
+static size_t write_midx_object_offsets(struct hashfile *f, int large_offset_needed,
+					uint32_t *perm,
+					struct pack_midx_entry *objects, uint32_t nr_objects)
+{
+	struct pack_midx_entry *list = objects;
+	uint32_t i, nr_large_offset = 0;
+	size_t written = 0;
+
+	for (i = 0; i < nr_objects; i++) {
+		struct pack_midx_entry *obj = list++;
+
+		if (perm[obj->pack_int_id] == PACK_EXPIRED)
+			BUG("object %s is in an expired pack with int-id %d",
+			    oid_to_hex(&obj->oid),
+			    obj->pack_int_id);
+
+		hashwrite_be32(f, perm[obj->pack_int_id]);
+
+		if (large_offset_needed && obj->offset >> 31)
+			hashwrite_be32(f, MIDX_LARGE_OFFSET_NEEDED | nr_large_offset++);
+		else if (!large_offset_needed && obj->offset >> 32)
+			BUG("object %s requires a large offset (%"PRIx64") but the MIDX is not writing large offsets!",
+			    oid_to_hex(&obj->oid),
+			    obj->offset);
+		else
+			hashwrite_be32(f, (uint32_t)obj->offset);
+
+		written += MIDX_CHUNK_OFFSET_WIDTH;
+	}
+
+	return written;
+}
+
+static size_t write_midx_large_offsets(struct hashfile *f, uint32_t nr_large_offset,
+				       struct pack_midx_entry *objects, uint32_t nr_objects)
+{
+	struct pack_midx_entry *list = objects, *end = objects + nr_objects;
+	size_t written = 0;
+
+	while (nr_large_offset) {
+		struct pack_midx_entry *obj;
+		uint64_t offset;
+
+		if (list >= end)
+			BUG("too many large-offset objects");
+
+		obj = list++;
+		offset = obj->offset;
+
+		if (!(offset >> 31))
+			continue;
+
+		hashwrite_be32(f, offset >> 32);
+		hashwrite_be32(f, offset & 0xffffffffUL);
+		written += 2 * sizeof(uint32_t);
+
+		nr_large_offset--;
+	}
+
+	return written;
+}
+
+static int write_midx_internal(const char *object_dir, struct multi_pack_index *m,
+			       struct string_list *packs_to_drop, unsigned flags)
+{
+	unsigned char cur_chunk, num_chunks = 0;
+	char *midx_name;
+	uint32_t i;
+	struct hashfile *f = NULL;
+	struct lock_file lk;
+	struct pack_list packs;
+	uint32_t *pack_perm = NULL;
+	uint64_t written = 0;
+	uint32_t chunk_ids[MIDX_MAX_CHUNKS + 1];
+	uint64_t chunk_offsets[MIDX_MAX_CHUNKS + 1];
+	uint32_t nr_entries, num_large_offsets = 0;
+	struct pack_midx_entry *entries = NULL;
+	struct progress *progress = NULL;
+	int large_offsets_needed = 0;
+	int pack_name_concat_len = 0;
+	int dropped_packs = 0;
+	int result = 0;
+
+	midx_name = get_midx_filename(object_dir);
+	if (safe_create_leading_directories(midx_name)) {
+		UNLEAK(midx_name);
+		die_errno(_("unable to create leading directories of %s"),
+			  midx_name);
+	}
+
+	if (m)
+		packs.m = m;
+	else
+		packs.m = load_multi_pack_index(object_dir, 1);
+
+	packs.nr = 0;
+	packs.alloc = packs.m ? packs.m->num_packs : 16;
+	packs.info = NULL;
+	ALLOC_ARRAY(packs.info, packs.alloc);
+
+	if (packs.m) {
+		for (i = 0; i < packs.m->num_packs; i++) {
+			ALLOC_GROW(packs.info, packs.nr + 1, packs.alloc);
+
+			packs.info[packs.nr].orig_pack_int_id = i;
+			packs.info[packs.nr].pack_name = xstrdup(packs.m->pack_names[i]);
+			packs.info[packs.nr].p = NULL;
+			packs.info[packs.nr].expired = 0;
+			packs.nr++;
+		}
+	}
+
+	packs.pack_paths_checked = 0;
+	if (flags & MIDX_PROGRESS)
+		packs.progress = start_progress(_("Adding packfiles to multi-pack-index"), 0);
+	else
+		packs.progress = NULL;
+
+	for_each_file_in_pack_dir(object_dir, add_pack_to_midx, &packs);
+	stop_progress(&packs.progress);
+
+	if (packs.m && packs.nr == packs.m->num_packs && !packs_to_drop)
+		goto cleanup;
+
+	entries = get_sorted_entries(packs.m, packs.info, packs.nr, &nr_entries);
+
+	for (i = 0; i < nr_entries; i++) {
+		if (entries[i].offset > 0x7fffffff)
+			num_large_offsets++;
+		if (entries[i].offset > 0xffffffff)
+			large_offsets_needed = 1;
+	}
+
+	QSORT(packs.info, packs.nr, pack_info_compare);
+
+	if (packs_to_drop && packs_to_drop->nr) {
+		int drop_index = 0;
+		int missing_drops = 0;
+
+		for (i = 0; i < packs.nr && drop_index < packs_to_drop->nr; i++) {
+			int cmp = strcmp(packs.info[i].pack_name,
+					 packs_to_drop->items[drop_index].string);
+
+			if (!cmp) {
+				drop_index++;
+				packs.info[i].expired = 1;
+			} else if (cmp > 0) {
+				error(_("did not see pack-file %s to drop"),
+				      packs_to_drop->items[drop_index].string);
+				drop_index++;
+				missing_drops++;
+				i--;
+			} else {
+				packs.info[i].expired = 0;
+			}
+		}
+
+		if (missing_drops) {
+			result = 1;
+			goto cleanup;
+		}
+	}
+
+	/*
+	 * pack_perm stores a permutation between pack-int-ids from the
+	 * previous multi-pack-index to the new one we are writing:
+	 *
+	 * pack_perm[old_id] = new_id
+	 */
+	ALLOC_ARRAY(pack_perm, packs.nr);
+	for (i = 0; i < packs.nr; i++) {
+		if (packs.info[i].expired) {
+			dropped_packs++;
+			pack_perm[packs.info[i].orig_pack_int_id] = PACK_EXPIRED;
+		} else {
+			pack_perm[packs.info[i].orig_pack_int_id] = i - dropped_packs;
+		}
+	}
+
+	for (i = 0; i < packs.nr; i++) {
+		if (!packs.info[i].expired)
+			pack_name_concat_len += strlen(packs.info[i].pack_name) + 1;
+	}
+
+	if (pack_name_concat_len % MIDX_CHUNK_ALIGNMENT)
+		pack_name_concat_len += MIDX_CHUNK_ALIGNMENT -
+					(pack_name_concat_len % MIDX_CHUNK_ALIGNMENT);
+
+	hold_lock_file_for_update(&lk, midx_name, LOCK_DIE_ON_ERROR);
+	f = hashfd(lk.tempfile->fd, lk.tempfile->filename.buf);
+	FREE_AND_NULL(midx_name);
+
+	if (packs.m)
+		close_midx(packs.m);
+
+	cur_chunk = 0;
+	num_chunks = large_offsets_needed ? 5 : 4;
+
+	written = write_midx_header(f, num_chunks, packs.nr - dropped_packs);
+
+	chunk_ids[cur_chunk] = MIDX_CHUNKID_PACKNAMES;
+	chunk_offsets[cur_chunk] = written + (num_chunks + 1) * MIDX_CHUNKLOOKUP_WIDTH;
+
+	cur_chunk++;
+	chunk_ids[cur_chunk] = MIDX_CHUNKID_OIDFANOUT;
+	chunk_offsets[cur_chunk] = chunk_offsets[cur_chunk - 1] + pack_name_concat_len;
+
+	cur_chunk++;
+	chunk_ids[cur_chunk] = MIDX_CHUNKID_OIDLOOKUP;
+	chunk_offsets[cur_chunk] = chunk_offsets[cur_chunk - 1] + MIDX_CHUNK_FANOUT_SIZE;
+
+	cur_chunk++;
+	chunk_ids[cur_chunk] = MIDX_CHUNKID_OBJECTOFFSETS;
+	chunk_offsets[cur_chunk] = chunk_offsets[cur_chunk - 1] + nr_entries * the_hash_algo->rawsz;
+
+	cur_chunk++;
+	chunk_offsets[cur_chunk] = chunk_offsets[cur_chunk - 1] + nr_entries * MIDX_CHUNK_OFFSET_WIDTH;
+	if (large_offsets_needed) {
+		chunk_ids[cur_chunk] = MIDX_CHUNKID_LARGEOFFSETS;
+
+		cur_chunk++;
+		chunk_offsets[cur_chunk] = chunk_offsets[cur_chunk - 1] +
+					   num_large_offsets * MIDX_CHUNK_LARGE_OFFSET_WIDTH;
+	}
+
+	chunk_ids[cur_chunk] = 0;
+
+	for (i = 0; i <= num_chunks; i++) {
+		if (i && chunk_offsets[i] < chunk_offsets[i - 1])
+			BUG("incorrect chunk offsets: %"PRIu64" before %"PRIu64,
+			    chunk_offsets[i - 1],
+			    chunk_offsets[i]);
+
+		if (chunk_offsets[i] % MIDX_CHUNK_ALIGNMENT)
+			BUG("chunk offset %"PRIu64" is not properly aligned",
+			    chunk_offsets[i]);
+
+		hashwrite_be32(f, chunk_ids[i]);
+		hashwrite_be32(f, chunk_offsets[i] >> 32);
+		hashwrite_be32(f, chunk_offsets[i]);
+
+		written += MIDX_CHUNKLOOKUP_WIDTH;
+	}
+
+	if (flags & MIDX_PROGRESS)
+		progress = start_progress(_("Writing chunks to multi-pack-index"),
+					  num_chunks);
+	for (i = 0; i < num_chunks; i++) {
+		if (written != chunk_offsets[i])
+			BUG("incorrect chunk offset (%"PRIu64" != %"PRIu64") for chunk id %"PRIx32,
+			    chunk_offsets[i],
+			    written,
+			    chunk_ids[i]);
+
+		switch (chunk_ids[i]) {
+			case MIDX_CHUNKID_PACKNAMES:
+				written += write_midx_pack_names(f, packs.info, packs.nr);
+				break;
+
+			case MIDX_CHUNKID_OIDFANOUT:
+				written += write_midx_oid_fanout(f, entries, nr_entries);
+				break;
+
+			case MIDX_CHUNKID_OIDLOOKUP:
+				written += write_midx_oid_lookup(f, the_hash_algo->rawsz, entries, nr_entries);
+				break;
+
+			case MIDX_CHUNKID_OBJECTOFFSETS:
+				written += write_midx_object_offsets(f, large_offsets_needed, pack_perm, entries, nr_entries);
+				break;
+
+			case MIDX_CHUNKID_LARGEOFFSETS:
+				written += write_midx_large_offsets(f, num_large_offsets, entries, nr_entries);
+				break;
+
+			default:
+				BUG("trying to write unknown chunk id %"PRIx32,
+				    chunk_ids[i]);
+		}
+
+		display_progress(progress, i + 1);
+	}
+	stop_progress(&progress);
+
+	if (written != chunk_offsets[num_chunks])
+		BUG("incorrect final offset %"PRIu64" != %"PRIu64,
+		    written,
+		    chunk_offsets[num_chunks]);
+
+	finalize_hashfile(f, NULL, CSUM_FSYNC | CSUM_HASH_IN_STREAM);
+	commit_lock_file(&lk);
+
+cleanup:
+	for (i = 0; i < packs.nr; i++) {
+		if (packs.info[i].p) {
+			close_pack(packs.info[i].p);
+			free(packs.info[i].p);
+		}
+		free(packs.info[i].pack_name);
+	}
+
+	free(packs.info);
+	free(entries);
+	free(pack_perm);
+	free(midx_name);
+	return result;
+}
+
+int write_midx_file(const char *object_dir, unsigned flags)
+{
+	return write_midx_internal(object_dir, NULL, NULL, flags);
+}
+
+void clear_midx_file(struct repository *r)
+{
+	char *midx = get_midx_filename(r->objects->odb->path);
+
+	if (r->objects && r->objects->multi_pack_index) {
+		close_midx(r->objects->multi_pack_index);
+		r->objects->multi_pack_index = NULL;
+	}
+
+	if (remove_path(midx)) {
+		UNLEAK(midx);
+		die(_("failed to clear multi-pack-index at %s"), midx);
+	}
+
+	free(midx);
+}
+
+static int verify_midx_error;
+
+static void midx_report(const char *fmt, ...)
+{
+	va_list ap;
+	verify_midx_error = 1;
+	va_start(ap, fmt);
+	vfprintf(stderr, fmt, ap);
+	fprintf(stderr, "\n");
+	va_end(ap);
+}
+
+struct pair_pos_vs_id
+{
+	uint32_t pos;
+	uint32_t pack_int_id;
+};
+
+static int compare_pair_pos_vs_id(const void *_a, const void *_b)
+{
+	struct pair_pos_vs_id *a = (struct pair_pos_vs_id *)_a;
+	struct pair_pos_vs_id *b = (struct pair_pos_vs_id *)_b;
+
+	return b->pack_int_id - a->pack_int_id;
+}
+
+/*
+ * Limit calls to display_progress() for performance reasons.
+ * The interval here was arbitrarily chosen.
+ */
+#define SPARSE_PROGRESS_INTERVAL (1 << 12)
+#define midx_display_sparse_progress(progress, n) \
+	do { \
+		uint64_t _n = (n); \
+		if ((_n & (SPARSE_PROGRESS_INTERVAL - 1)) == 0) \
+			display_progress(progress, _n); \
+	} while (0)
+
+int verify_midx_file(struct repository *r, const char *object_dir, unsigned flags)
+{
+	struct pair_pos_vs_id *pairs = NULL;
+	uint32_t i;
+	struct progress *progress = NULL;
+	struct multi_pack_index *m = load_multi_pack_index(object_dir, 1);
+	verify_midx_error = 0;
+
+	if (!m)
+		return 0;
+
+	if (flags & MIDX_PROGRESS)
+		progress = start_progress(_("Looking for referenced packfiles"),
+					  m->num_packs);
+	for (i = 0; i < m->num_packs; i++) {
+		if (prepare_midx_pack(r, m, i))
+			midx_report("failed to load pack in position %d", i);
+
+		display_progress(progress, i + 1);
+	}
+	stop_progress(&progress);
+
+	for (i = 0; i < 255; i++) {
+		uint32_t oid_fanout1 = ntohl(m->chunk_oid_fanout[i]);
+		uint32_t oid_fanout2 = ntohl(m->chunk_oid_fanout[i + 1]);
+
+		if (oid_fanout1 > oid_fanout2)
+			midx_report(_("oid fanout out of order: fanout[%d] = %"PRIx32" > %"PRIx32" = fanout[%d]"),
+				    i, oid_fanout1, oid_fanout2, i + 1);
+	}
+
+	if (flags & MIDX_PROGRESS)
+		progress = start_sparse_progress(_("Verifying OID order in multi-pack-index"),
+						 m->num_objects - 1);
+	for (i = 0; i < m->num_objects - 1; i++) {
+		struct object_id oid1, oid2;
+
+		nth_midxed_object_oid(&oid1, m, i);
+		nth_midxed_object_oid(&oid2, m, i + 1);
+
+		if (oidcmp(&oid1, &oid2) >= 0)
+			midx_report(_("oid lookup out of order: oid[%d] = %s >= %s = oid[%d]"),
+				    i, oid_to_hex(&oid1), oid_to_hex(&oid2), i + 1);
+
+		midx_display_sparse_progress(progress, i + 1);
+	}
+	stop_progress(&progress);
+
+	/*
+	 * Create an array mapping each object to its packfile id.  Sort it
+	 * to group the objects by packfile.  Use this permutation to visit
+	 * each of the objects and only require 1 packfile to be open at a
+	 * time.
+	 */
+	ALLOC_ARRAY(pairs, m->num_objects);
+	for (i = 0; i < m->num_objects; i++) {
+		pairs[i].pos = i;
+		pairs[i].pack_int_id = nth_midxed_pack_int_id(m, i);
+	}
+
+	if (flags & MIDX_PROGRESS)
+		progress = start_sparse_progress(_("Sorting objects by packfile"),
+						 m->num_objects);
+	display_progress(progress, 0); /* TODO: Measure QSORT() progress */
+	QSORT(pairs, m->num_objects, compare_pair_pos_vs_id);
+	stop_progress(&progress);
+
+	if (flags & MIDX_PROGRESS)
+		progress = start_sparse_progress(_("Verifying object offsets"), m->num_objects);
+	for (i = 0; i < m->num_objects; i++) {
+		struct object_id oid;
+		struct pack_entry e;
+		off_t m_offset, p_offset;
+
+		if (i > 0 && pairs[i-1].pack_int_id != pairs[i].pack_int_id &&
+		    m->packs[pairs[i-1].pack_int_id])
+		{
+			close_pack_fd(m->packs[pairs[i-1].pack_int_id]);
+			close_pack_index(m->packs[pairs[i-1].pack_int_id]);
+		}
+
+		nth_midxed_object_oid(&oid, m, pairs[i].pos);
+
+		if (!fill_midx_entry(r, &oid, &e, m)) {
+			midx_report(_("failed to load pack entry for oid[%d] = %s"),
+				    pairs[i].pos, oid_to_hex(&oid));
+			continue;
+		}
+
+		if (open_pack_index(e.p)) {
+			midx_report(_("failed to load pack-index for packfile %s"),
+				    e.p->pack_name);
+			break;
+		}
+
+		m_offset = e.offset;
+		p_offset = find_pack_entry_one(oid.hash, e.p);
+
+		if (m_offset != p_offset)
+			midx_report(_("incorrect object offset for oid[%d] = %s: %"PRIx64" != %"PRIx64),
+				    pairs[i].pos, oid_to_hex(&oid), m_offset, p_offset);
+
+		midx_display_sparse_progress(progress, i + 1);
+	}
+	stop_progress(&progress);
+
+	free(pairs);
+
+	return verify_midx_error;
+}
+
+int expire_midx_packs(struct repository *r, const char *object_dir, unsigned flags)
+{
+	uint32_t i, *count, result = 0;
+	struct string_list packs_to_drop = STRING_LIST_INIT_DUP;
+	struct multi_pack_index *m = load_multi_pack_index(object_dir, 1);
+	struct progress *progress = NULL;
+
+	if (!m)
+		return 0;
+
+	count = xcalloc(m->num_packs, sizeof(uint32_t));
+
+	if (flags & MIDX_PROGRESS)
+		progress = start_progress(_("Counting referenced objects"),
+					  m->num_objects);
+	for (i = 0; i < m->num_objects; i++) {
+		int pack_int_id = nth_midxed_pack_int_id(m, i);
+		count[pack_int_id]++;
+		display_progress(progress, i + 1);
+	}
+	stop_progress(&progress);
+
+	if (flags & MIDX_PROGRESS)
+		progress = start_progress(_("Finding and deleting unreferenced packfiles"),
+					  m->num_packs);
+	for (i = 0; i < m->num_packs; i++) {
+		char *pack_name;
+		display_progress(progress, i + 1);
+
+		if (count[i])
+			continue;
+
+		if (prepare_midx_pack(r, m, i))
+			continue;
+
+		if (m->packs[i]->pack_keep)
+			continue;
+
+		pack_name = xstrdup(m->packs[i]->pack_name);
+		close_pack(m->packs[i]);
+
+		string_list_insert(&packs_to_drop, m->pack_names[i]);
+		unlink_pack_path(pack_name, 0);
+		free(pack_name);
+	}
+	stop_progress(&progress);
+
+	free(count);
+
+	if (packs_to_drop.nr)
+		result = write_midx_internal(object_dir, m, &packs_to_drop, flags);
+
+	string_list_clear(&packs_to_drop, 0);
+	return result;
+}
+
+struct repack_info {
+	timestamp_t mtime;
+	uint32_t referenced_objects;
+	uint32_t pack_int_id;
+};
+
+static int compare_by_mtime(const void *a_, const void *b_)
+{
+	const struct repack_info *a, *b;
+
+	a = (const struct repack_info *)a_;
+	b = (const struct repack_info *)b_;
+
+	if (a->mtime < b->mtime)
+		return -1;
+	if (a->mtime > b->mtime)
+		return 1;
+	return 0;
+}
+
+static int fill_included_packs_all(struct multi_pack_index *m,
+				   unsigned char *include_pack)
+{
+	uint32_t i;
+
+	for (i = 0; i < m->num_packs; i++)
+		include_pack[i] = 1;
+
+	return m->num_packs < 2;
+}
+
+static int fill_included_packs_batch(struct repository *r,
+				     struct multi_pack_index *m,
+				     unsigned char *include_pack,
+				     size_t batch_size)
+{
+	uint32_t i, packs_to_repack;
+	size_t total_size;
+	struct repack_info *pack_info = xcalloc(m->num_packs, sizeof(struct repack_info));
+
+	for (i = 0; i < m->num_packs; i++) {
+		pack_info[i].pack_int_id = i;
+
+		if (prepare_midx_pack(r, m, i))
+			continue;
+
+		pack_info[i].mtime = m->packs[i]->mtime;
+	}
+
+	for (i = 0; batch_size && i < m->num_objects; i++) {
+		uint32_t pack_int_id = nth_midxed_pack_int_id(m, i);
+		pack_info[pack_int_id].referenced_objects++;
+	}
+
+	QSORT(pack_info, m->num_packs, compare_by_mtime);
+
+	total_size = 0;
+	packs_to_repack = 0;
+	for (i = 0; total_size < batch_size && i < m->num_packs; i++) {
+		int pack_int_id = pack_info[i].pack_int_id;
+		struct packed_git *p = m->packs[pack_int_id];
+		size_t expected_size;
+
+		if (!p)
+			continue;
+		if (open_pack_index(p) || !p->num_objects)
+			continue;
+
+		expected_size = (size_t)(p->pack_size
+					 * pack_info[i].referenced_objects);
+		expected_size /= p->num_objects;
+
+		if (expected_size >= batch_size)
+			continue;
+
+		packs_to_repack++;
+		total_size += expected_size;
+		include_pack[pack_int_id] = 1;
+	}
+
+	free(pack_info);
+
+	if (total_size < batch_size || packs_to_repack < 2)
+		return 1;
+
+	return 0;
+}
+
+int midx_repack(struct repository *r, const char *object_dir, size_t batch_size, unsigned flags)
+{
+	int result = 0;
+	uint32_t i;
+	unsigned char *include_pack;
+	struct child_process cmd = CHILD_PROCESS_INIT;
+	struct strbuf base_name = STRBUF_INIT;
+	struct multi_pack_index *m = load_multi_pack_index(object_dir, 1);
+
+	if (!m)
+		return 0;
+
+	include_pack = xcalloc(m->num_packs, sizeof(unsigned char));
+
+	if (batch_size) {
+		if (fill_included_packs_batch(r, m, include_pack, batch_size))
+			goto cleanup;
+	} else if (fill_included_packs_all(m, include_pack))
+		goto cleanup;
+
+	argv_array_push(&cmd.args, "pack-objects");
+
+	strbuf_addstr(&base_name, object_dir);
+	strbuf_addstr(&base_name, "/pack/pack");
+	argv_array_push(&cmd.args, base_name.buf);
+
+	if (flags & MIDX_PROGRESS)
+		argv_array_push(&cmd.args, "--progress");
+	else
+		argv_array_push(&cmd.args, "-q");
+
+	strbuf_release(&base_name);
+
+	cmd.git_cmd = 1;
+	cmd.in = cmd.out = -1;
+
+	if (start_command(&cmd)) {
+		error(_("could not start pack-objects"));
+		result = 1;
+		goto cleanup;
+	}
+
+	for (i = 0; i < m->num_objects; i++) {
+		struct object_id oid;
+		uint32_t pack_int_id = nth_midxed_pack_int_id(m, i);
+
+		if (!include_pack[pack_int_id])
+			continue;
+
+		nth_midxed_object_oid(&oid, m, i);
+		xwrite(cmd.in, oid_to_hex(&oid), the_hash_algo->hexsz);
+		xwrite(cmd.in, "\n", 1);
+	}
+	close(cmd.in);
+
+	if (finish_command(&cmd)) {
+		error(_("could not finish pack-objects"));
+		result = 1;
+		goto cleanup;
+	}
+
+	result = write_midx_internal(object_dir, m, NULL, flags);
+	m = NULL;
+
+cleanup:
+	if (m)
+		close_midx(m);
+	free(include_pack);
+	return result;
+}
diff -pruN 1.2.1+git2.18.0-1/git/midx.h 1.2.3+git2.25.1-1/git/midx.h
--- 1.2.1+git2.18.0-1/git/midx.h	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/midx.h	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,60 @@
+#ifndef MIDX_H
+#define MIDX_H
+
+#include "repository.h"
+
+struct object_id;
+struct pack_entry;
+struct repository;
+
+#define GIT_TEST_MULTI_PACK_INDEX "GIT_TEST_MULTI_PACK_INDEX"
+
+struct multi_pack_index {
+	struct multi_pack_index *next;
+
+	int fd;
+
+	const unsigned char *data;
+	size_t data_len;
+
+	uint32_t signature;
+	unsigned char version;
+	unsigned char hash_len;
+	unsigned char num_chunks;
+	uint32_t num_packs;
+	uint32_t num_objects;
+
+	int local;
+
+	const unsigned char *chunk_pack_names;
+	const uint32_t *chunk_oid_fanout;
+	const unsigned char *chunk_oid_lookup;
+	const unsigned char *chunk_object_offsets;
+	const unsigned char *chunk_large_offsets;
+
+	const char **pack_names;
+	struct packed_git **packs;
+	char object_dir[FLEX_ARRAY];
+};
+
+#define MIDX_PROGRESS     (1 << 0)
+
+struct multi_pack_index *load_multi_pack_index(const char *object_dir, int local);
+int prepare_midx_pack(struct repository *r, struct multi_pack_index *m, uint32_t pack_int_id);
+int bsearch_midx(const struct object_id *oid, struct multi_pack_index *m, uint32_t *result);
+struct object_id *nth_midxed_object_oid(struct object_id *oid,
+					struct multi_pack_index *m,
+					uint32_t n);
+int fill_midx_entry(struct repository *r, const struct object_id *oid, struct pack_entry *e, struct multi_pack_index *m);
+int midx_contains_pack(struct multi_pack_index *m, const char *idx_or_pack_name);
+int prepare_multi_pack_index_one(struct repository *r, const char *object_dir, int local);
+
+int write_midx_file(const char *object_dir, unsigned flags);
+void clear_midx_file(struct repository *r);
+int verify_midx_file(struct repository *r, const char *object_dir, unsigned flags);
+int expire_midx_packs(struct repository *r, const char *object_dir, unsigned flags);
+int midx_repack(struct repository *r, const char *object_dir, size_t batch_size, unsigned flags);
+
+void close_midx(struct multi_pack_index *m);
+
+#endif
diff -pruN 1.2.1+git2.18.0-1/git/name-hash.c 1.2.3+git2.25.1-1/git/name-hash.c
--- 1.2.1+git2.18.0-1/git/name-hash.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/name-hash.c	2020-02-17 04:47:35.000000000 +0000
@@ -5,8 +5,8 @@
  *
  * Copyright (C) 2008 Linus Torvalds
  */
-#define NO_THE_INDEX_COMPATIBILITY_MACROS
 #include "cache.h"
+#include "thread-utils.h"
 
 struct dir_entry {
 	struct hashmap_entry ent;
@@ -17,14 +17,16 @@ struct dir_entry {
 };
 
 static int dir_entry_cmp(const void *unused_cmp_data,
-			 const void *entry,
-			 const void *entry_or_key,
+			 const struct hashmap_entry *eptr,
+			 const struct hashmap_entry *entry_or_key,
 			 const void *keydata)
 {
-	const struct dir_entry *e1 = entry;
-	const struct dir_entry *e2 = entry_or_key;
+	const struct dir_entry *e1, *e2;
 	const char *name = keydata;
 
+	e1 = container_of(eptr, const struct dir_entry, ent);
+	e2 = container_of(entry_or_key, const struct dir_entry, ent);
+
 	return e1->namelen != e2->namelen || strncasecmp(e1->name,
 			name ? name : e2->name, e1->namelen);
 }
@@ -33,9 +35,9 @@ static struct dir_entry *find_dir_entry_
 		const char *name, unsigned int namelen, unsigned int hash)
 {
 	struct dir_entry key;
-	hashmap_entry_init(&key, hash);
+	hashmap_entry_init(&key.ent, hash);
 	key.namelen = namelen;
-	return hashmap_get(&istate->dir_hash, &key, name);
+	return hashmap_get_entry(&istate->dir_hash, &key, ent, name);
 }
 
 static struct dir_entry *find_dir_entry(struct index_state *istate,
@@ -68,9 +70,9 @@ static struct dir_entry *hash_dir_entry(
 	if (!dir) {
 		/* not found, create it and add to hash table */
 		FLEX_ALLOC_MEM(dir, name, ce->name, namelen);
-		hashmap_entry_init(dir, memihash(ce->name, namelen));
+		hashmap_entry_init(&dir->ent, memihash(ce->name, namelen));
 		dir->namelen = namelen;
-		hashmap_add(&istate->dir_hash, dir);
+		hashmap_add(&istate->dir_hash, &dir->ent);
 
 		/* recursively add missing parent directories */
 		dir->parent = hash_dir_entry(istate, ce, namelen);
@@ -95,7 +97,7 @@ static void remove_dir_entry(struct inde
 	struct dir_entry *dir = hash_dir_entry(istate, ce, ce_namelen(ce));
 	while (dir && !(--dir->nr)) {
 		struct dir_entry *parent = dir->parent;
-		hashmap_remove(&istate->dir_hash, dir, NULL);
+		hashmap_remove(&istate->dir_hash, &dir->ent, NULL);
 		free(dir);
 		dir = parent;
 	}
@@ -106,20 +108,23 @@ static void hash_index_entry(struct inde
 	if (ce->ce_flags & CE_HASHED)
 		return;
 	ce->ce_flags |= CE_HASHED;
-	hashmap_entry_init(ce, memihash(ce->name, ce_namelen(ce)));
-	hashmap_add(&istate->name_hash, ce);
+	hashmap_entry_init(&ce->ent, memihash(ce->name, ce_namelen(ce)));
+	hashmap_add(&istate->name_hash, &ce->ent);
 
 	if (ignore_case)
 		add_dir_entry(istate, ce);
 }
 
 static int cache_entry_cmp(const void *unused_cmp_data,
-			   const void *entry,
-			   const void *entry_or_key,
+			   const struct hashmap_entry *eptr,
+			   const struct hashmap_entry *entry_or_key,
 			   const void *remove)
 {
-	const struct cache_entry *ce1 = entry;
-	const struct cache_entry *ce2 = entry_or_key;
+	const struct cache_entry *ce1, *ce2;
+
+	ce1 = container_of(eptr, const struct cache_entry, ent);
+	ce2 = container_of(entry_or_key, const struct cache_entry, ent);
+
 	/*
 	 * For remove_name_hash, find the exact entry (pointer equality); for
 	 * index_file_exists, find all entries with matching hash code and
@@ -131,25 +136,9 @@ static int cache_entry_cmp(const void *u
 static int lazy_try_threaded = 1;
 static int lazy_nr_dir_threads;
 
-#ifdef NO_PTHREADS
-
-static inline int lookup_lazy_params(struct index_state *istate)
-{
-	return 0;
-}
-
-static inline void threaded_lazy_init_name_hash(
-	struct index_state *istate)
-{
-}
-
-#else
-
-#include "thread-utils.h"
-
 /*
  * Set a minimum number of cache_entries that we will handle per
- * thread and use that to decide how many threads to run (upto
+ * thread and use that to decide how many threads to run (up to
  * the number on the system).
  *
  * For guidance setting the lower per-thread bound, see:
@@ -229,7 +218,7 @@ static int lookup_lazy_params(struct ind
  * However, the hashmap is going to put items into bucket
  * chains based on their hash values.  Use that to create n
  * mutexes and lock on mutex[bucket(hash) % n].  This will
- * decrease the collision rate by (hopefully) by a factor of n.
+ * decrease the collision rate by (hopefully) a factor of n.
  */
 static void init_dir_mutex(void)
 {
@@ -296,10 +285,10 @@ static struct dir_entry *hash_dir_entry_
 	dir = find_dir_entry__hash(istate, prefix->buf, prefix->len, hash);
 	if (!dir) {
 		FLEX_ALLOC_MEM(dir, name, prefix->buf, prefix->len);
-		hashmap_entry_init(dir, hash);
+		hashmap_entry_init(&dir->ent, hash);
 		dir->namelen = prefix->len;
 		dir->parent = parent;
-		hashmap_add(&istate->dir_hash, dir);
+		hashmap_add(&istate->dir_hash, &dir->ent);
 
 		if (parent) {
 			unlock_dir_mutex(lock_nr);
@@ -361,8 +350,9 @@ static int handle_range_dir(
 	else {
 		int begin = k_start;
 		int end = k_end;
+		assert(begin >= 0);
 		while (begin < end) {
-			int mid = (begin + end) >> 1;
+			int mid = begin + ((end - begin) >> 1);
 			int cmp = strncmp(istate->cache[mid]->name, prefix->buf, prefix->len);
 			if (cmp == 0) /* mid has same prefix; look in second part */
 				begin = mid + 1;
@@ -487,8 +477,8 @@ static void *lazy_name_thread_proc(void
 	for (k = 0; k < d->istate->cache_nr; k++) {
 		struct cache_entry *ce_k = d->istate->cache[k];
 		ce_k->ce_flags |= CE_HASHED;
-		hashmap_entry_init(ce_k, d->lazy_entries[k].hash_name);
-		hashmap_add(&d->istate->name_hash, ce_k);
+		hashmap_entry_init(&ce_k->ent, d->lazy_entries[k].hash_name);
+		hashmap_add(&d->istate->name_hash, &ce_k->ent);
 	}
 
 	return NULL;
@@ -509,6 +499,7 @@ static inline void lazy_update_dir_ref_c
 static void threaded_lazy_init_name_hash(
 	struct index_state *istate)
 {
+	int err;
 	int nr_each;
 	int k_start;
 	int t;
@@ -516,6 +507,9 @@ static void threaded_lazy_init_name_hash
 	struct lazy_dir_thread_data *td_dir;
 	struct lazy_name_thread_data *td_name;
 
+	if (!HAVE_THREADS)
+		return;
+
 	k_start = 0;
 	nr_each = DIV_ROUND_UP(istate->cache_nr, lazy_nr_dir_threads);
 
@@ -538,8 +532,9 @@ static void threaded_lazy_init_name_hash
 		if (k_start > istate->cache_nr)
 			k_start = istate->cache_nr;
 		td_dir_t->k_end = k_start;
-		if (pthread_create(&td_dir_t->pthread, NULL, lazy_dir_thread_proc, td_dir_t))
-			die("unable to create lazy_dir_thread");
+		err = pthread_create(&td_dir_t->pthread, NULL, lazy_dir_thread_proc, td_dir_t);
+		if (err)
+			die(_("unable to create lazy_dir thread: %s"), strerror(err));
 	}
 	for (t = 0; t < lazy_nr_dir_threads; t++) {
 		struct lazy_dir_thread_data *td_dir_t = td_dir + t;
@@ -559,13 +554,15 @@ static void threaded_lazy_init_name_hash
 	 */
 	td_name->istate = istate;
 	td_name->lazy_entries = lazy_entries;
-	if (pthread_create(&td_name->pthread, NULL, lazy_name_thread_proc, td_name))
-		die("unable to create lazy_name_thread");
+	err = pthread_create(&td_name->pthread, NULL, lazy_name_thread_proc, td_name);
+	if (err)
+		die(_("unable to create lazy_name thread: %s"), strerror(err));
 
 	lazy_update_dir_ref_counts(istate, lazy_entries);
 
-	if (pthread_join(td_name->pthread, NULL))
-		die("unable to join lazy_name_thread");
+	err = pthread_join(td_name->pthread, NULL);
+	if (err)
+		die(_("unable to join lazy_name thread: %s"), strerror(err));
 
 	cleanup_dir_mutex();
 
@@ -574,14 +571,12 @@ static void threaded_lazy_init_name_hash
 	free(lazy_entries);
 }
 
-#endif
-
 static void lazy_init_name_hash(struct index_state *istate)
 {
-	uint64_t start = getnanotime();
 
 	if (istate->name_hash_initialized)
 		return;
+	trace_performance_enter();
 	hashmap_init(&istate->name_hash, cache_entry_cmp, NULL, istate->cache_nr);
 	hashmap_init(&istate->dir_hash, dir_entry_cmp, NULL, istate->cache_nr);
 
@@ -602,7 +597,7 @@ static void lazy_init_name_hash(struct i
 	}
 
 	istate->name_hash_initialized = 1;
-	trace_performance_since(start, "initialize name hash");
+	trace_performance_leave("initialize name hash");
 }
 
 /*
@@ -635,7 +630,7 @@ void remove_name_hash(struct index_state
 	if (!istate->name_hash_initialized || !(ce->ce_flags & CE_HASHED))
 		return;
 	ce->ce_flags &= ~CE_HASHED;
-	hashmap_remove(&istate->name_hash, ce, ce);
+	hashmap_remove(&istate->name_hash, &ce->ent, ce);
 
 	if (ignore_case)
 		remove_dir_entry(istate, ce);
@@ -712,15 +707,15 @@ void adjust_dirname_case(struct index_st
 struct cache_entry *index_file_exists(struct index_state *istate, const char *name, int namelen, int icase)
 {
 	struct cache_entry *ce;
+	unsigned int hash = memihash(name, namelen);
 
 	lazy_init_name_hash(istate);
 
-	ce = hashmap_get_from_hash(&istate->name_hash,
-				   memihash(name, namelen), NULL);
-	while (ce) {
+	ce = hashmap_get_entry_from_hash(&istate->name_hash, hash, NULL,
+					 struct cache_entry, ent);
+	hashmap_for_each_entry_from(&istate->name_hash, ce, ent) {
 		if (same_name(ce, name, namelen, icase))
 			return ce;
-		ce = hashmap_get_next(&istate->name_hash, ce);
 	}
 	return NULL;
 }
@@ -731,6 +726,6 @@ void free_name_hash(struct index_state *
 		return;
 	istate->name_hash_initialized = 0;
 
-	hashmap_free(&istate->name_hash, 0);
-	hashmap_free(&istate->dir_hash, 1);
+	hashmap_free(&istate->name_hash);
+	hashmap_free_entries(&istate->dir_hash, struct dir_entry, ent);
 }
diff -pruN 1.2.1+git2.18.0-1/git/negotiator/default.c 1.2.3+git2.25.1-1/git/negotiator/default.c
--- 1.2.1+git2.18.0-1/git/negotiator/default.c	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/negotiator/default.c	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,176 @@
+#include "cache.h"
+#include "default.h"
+#include "../commit.h"
+#include "../fetch-negotiator.h"
+#include "../prio-queue.h"
+#include "../refs.h"
+#include "../tag.h"
+
+/* Remember to update object flag allocation in object.h */
+#define COMMON		(1U << 2)
+#define COMMON_REF	(1U << 3)
+#define SEEN		(1U << 4)
+#define POPPED		(1U << 5)
+
+static int marked;
+
+struct negotiation_state {
+	struct prio_queue rev_list;
+	int non_common_revs;
+};
+
+static void rev_list_push(struct negotiation_state *ns,
+			  struct commit *commit, int mark)
+{
+	if (!(commit->object.flags & mark)) {
+		commit->object.flags |= mark;
+
+		if (parse_commit(commit))
+			return;
+
+		prio_queue_put(&ns->rev_list, commit);
+
+		if (!(commit->object.flags & COMMON))
+			ns->non_common_revs++;
+	}
+}
+
+static int clear_marks(const char *refname, const struct object_id *oid,
+		       int flag, void *cb_data)
+{
+	struct object *o = deref_tag(the_repository, parse_object(the_repository, oid), refname, 0);
+
+	if (o && o->type == OBJ_COMMIT)
+		clear_commit_marks((struct commit *)o,
+				   COMMON | COMMON_REF | SEEN | POPPED);
+	return 0;
+}
+
+/*
+ * This function marks a rev and its ancestors as common.
+ * In some cases, it is desirable to mark only the ancestors (for example
+ * when only the server does not yet know that they are common).
+ */
+static void mark_common(struct negotiation_state *ns, struct commit *commit,
+		int ancestors_only, int dont_parse)
+{
+	if (commit != NULL && !(commit->object.flags & COMMON)) {
+		struct object *o = (struct object *)commit;
+
+		if (!ancestors_only)
+			o->flags |= COMMON;
+
+		if (!(o->flags & SEEN))
+			rev_list_push(ns, commit, SEEN);
+		else {
+			struct commit_list *parents;
+
+			if (!ancestors_only && !(o->flags & POPPED))
+				ns->non_common_revs--;
+			if (!o->parsed && !dont_parse)
+				if (parse_commit(commit))
+					return;
+
+			for (parents = commit->parents;
+					parents;
+					parents = parents->next)
+				mark_common(ns, parents->item, 0,
+					    dont_parse);
+		}
+	}
+}
+
+/*
+ * Get the next rev to send, ignoring the common.
+ */
+static const struct object_id *get_rev(struct negotiation_state *ns)
+{
+	struct commit *commit = NULL;
+
+	while (commit == NULL) {
+		unsigned int mark;
+		struct commit_list *parents;
+
+		if (ns->rev_list.nr == 0 || ns->non_common_revs == 0)
+			return NULL;
+
+		commit = prio_queue_get(&ns->rev_list);
+		parse_commit(commit);
+		parents = commit->parents;
+
+		commit->object.flags |= POPPED;
+		if (!(commit->object.flags & COMMON))
+			ns->non_common_revs--;
+
+		if (commit->object.flags & COMMON) {
+			/* do not send "have", and ignore ancestors */
+			commit = NULL;
+			mark = COMMON | SEEN;
+		} else if (commit->object.flags & COMMON_REF)
+			/* send "have", and ignore ancestors */
+			mark = COMMON | SEEN;
+		else
+			/* send "have", also for its ancestors */
+			mark = SEEN;
+
+		while (parents) {
+			if (!(parents->item->object.flags & SEEN))
+				rev_list_push(ns, parents->item, mark);
+			if (mark & COMMON)
+				mark_common(ns, parents->item, 1, 0);
+			parents = parents->next;
+		}
+	}
+
+	return &commit->object.oid;
+}
+
+static void known_common(struct fetch_negotiator *n, struct commit *c)
+{
+	if (!(c->object.flags & SEEN)) {
+		rev_list_push(n->data, c, COMMON_REF | SEEN);
+		mark_common(n->data, c, 1, 1);
+	}
+}
+
+static void add_tip(struct fetch_negotiator *n, struct commit *c)
+{
+	n->known_common = NULL;
+	rev_list_push(n->data, c, SEEN);
+}
+
+static const struct object_id *next(struct fetch_negotiator *n)
+{
+	n->known_common = NULL;
+	n->add_tip = NULL;
+	return get_rev(n->data);
+}
+
+static int ack(struct fetch_negotiator *n, struct commit *c)
+{
+	int known_to_be_common = !!(c->object.flags & COMMON);
+	mark_common(n->data, c, 0, 1);
+	return known_to_be_common;
+}
+
+static void release(struct fetch_negotiator *n)
+{
+	clear_prio_queue(&((struct negotiation_state *)n->data)->rev_list);
+	FREE_AND_NULL(n->data);
+}
+
+void default_negotiator_init(struct fetch_negotiator *negotiator)
+{
+	struct negotiation_state *ns;
+	negotiator->known_common = known_common;
+	negotiator->add_tip = add_tip;
+	negotiator->next = next;
+	negotiator->ack = ack;
+	negotiator->release = release;
+	negotiator->data = ns = xcalloc(1, sizeof(*ns));
+	ns->rev_list.compare = compare_commits_by_commit_date;
+
+	if (marked)
+		for_each_ref(clear_marks, NULL);
+	marked = 1;
+}
diff -pruN 1.2.1+git2.18.0-1/git/negotiator/default.h 1.2.3+git2.25.1-1/git/negotiator/default.h
--- 1.2.1+git2.18.0-1/git/negotiator/default.h	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/negotiator/default.h	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,8 @@
+#ifndef NEGOTIATOR_DEFAULT_H
+#define NEGOTIATOR_DEFAULT_H
+
+struct fetch_negotiator;
+
+void default_negotiator_init(struct fetch_negotiator *negotiator);
+
+#endif
diff -pruN 1.2.1+git2.18.0-1/git/negotiator/skipping.c 1.2.3+git2.25.1-1/git/negotiator/skipping.c
--- 1.2.1+git2.18.0-1/git/negotiator/skipping.c	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/negotiator/skipping.c	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,250 @@
+#include "cache.h"
+#include "skipping.h"
+#include "../commit.h"
+#include "../fetch-negotiator.h"
+#include "../prio-queue.h"
+#include "../refs.h"
+#include "../tag.h"
+
+/* Remember to update object flag allocation in object.h */
+/*
+ * Both us and the server know that both parties have this object.
+ */
+#define COMMON		(1U << 2)
+/*
+ * The server has told us that it has this object. We still need to tell the
+ * server that we have this object (or one of its descendants), but since we are
+ * going to do that, we do not need to tell the server about its ancestors.
+ */
+#define ADVERTISED	(1U << 3)
+/*
+ * This commit has entered the priority queue.
+ */
+#define SEEN		(1U << 4)
+/*
+ * This commit has left the priority queue.
+ */
+#define POPPED		(1U << 5)
+
+static int marked;
+
+/*
+ * An entry in the priority queue.
+ */
+struct entry {
+	struct commit *commit;
+
+	/*
+	 * Used only if commit is not COMMON.
+	 */
+	uint16_t original_ttl;
+	uint16_t ttl;
+};
+
+struct data {
+	struct prio_queue rev_list;
+
+	/*
+	 * The number of non-COMMON commits in rev_list.
+	 */
+	int non_common_revs;
+};
+
+static int compare(const void *a_, const void *b_, void *unused)
+{
+	const struct entry *a = a_;
+	const struct entry *b = b_;
+	return compare_commits_by_commit_date(a->commit, b->commit, NULL);
+}
+
+static struct entry *rev_list_push(struct data *data, struct commit *commit, int mark)
+{
+	struct entry *entry;
+	commit->object.flags |= mark | SEEN;
+
+	entry = xcalloc(1, sizeof(*entry));
+	entry->commit = commit;
+	prio_queue_put(&data->rev_list, entry);
+
+	if (!(mark & COMMON))
+		data->non_common_revs++;
+	return entry;
+}
+
+static int clear_marks(const char *refname, const struct object_id *oid,
+		       int flag, void *cb_data)
+{
+	struct object *o = deref_tag(the_repository, parse_object(the_repository, oid), refname, 0);
+
+	if (o && o->type == OBJ_COMMIT)
+		clear_commit_marks((struct commit *)o,
+				   COMMON | ADVERTISED | SEEN | POPPED);
+	return 0;
+}
+
+/*
+ * Mark this SEEN commit and all its SEEN ancestors as COMMON.
+ */
+static void mark_common(struct data *data, struct commit *c)
+{
+	struct commit_list *p;
+
+	if (c->object.flags & COMMON)
+		return;
+	c->object.flags |= COMMON;
+	if (!(c->object.flags & POPPED))
+		data->non_common_revs--;
+
+	if (!c->object.parsed)
+		return;
+	for (p = c->parents; p; p = p->next) {
+		if (p->item->object.flags & SEEN)
+			mark_common(data, p->item);
+	}
+}
+
+/*
+ * Ensure that the priority queue has an entry for to_push, and ensure that the
+ * entry has the correct flags and ttl.
+ *
+ * This function returns 1 if an entry was found or created, and 0 otherwise
+ * (because the entry for this commit had already been popped).
+ */
+static int push_parent(struct data *data, struct entry *entry,
+		       struct commit *to_push)
+{
+	struct entry *parent_entry;
+
+	if (to_push->object.flags & SEEN) {
+		int i;
+		if (to_push->object.flags & POPPED)
+			/*
+			 * The entry for this commit has already been popped,
+			 * due to clock skew. Pretend that this parent does not
+			 * exist.
+			 */
+			return 0;
+		/*
+		 * Find the existing entry and use it.
+		 */
+		for (i = 0; i < data->rev_list.nr; i++) {
+			parent_entry = data->rev_list.array[i].data;
+			if (parent_entry->commit == to_push)
+				goto parent_found;
+		}
+		BUG("missing parent in priority queue");
+parent_found:
+		;
+	} else {
+		parent_entry = rev_list_push(data, to_push, 0);
+	}
+
+	if (entry->commit->object.flags & (COMMON | ADVERTISED)) {
+		mark_common(data, to_push);
+	} else {
+		uint16_t new_original_ttl = entry->ttl
+			? entry->original_ttl : entry->original_ttl * 3 / 2 + 1;
+		uint16_t new_ttl = entry->ttl
+			? entry->ttl - 1 : new_original_ttl;
+		if (parent_entry->original_ttl < new_original_ttl) {
+			parent_entry->original_ttl = new_original_ttl;
+			parent_entry->ttl = new_ttl;
+		}
+	}
+
+	return 1;
+}
+
+static const struct object_id *get_rev(struct data *data)
+{
+	struct commit *to_send = NULL;
+
+	while (to_send == NULL) {
+		struct entry *entry;
+		struct commit *commit;
+		struct commit_list *p;
+		int parent_pushed = 0;
+
+		if (data->rev_list.nr == 0 || data->non_common_revs == 0)
+			return NULL;
+
+		entry = prio_queue_get(&data->rev_list);
+		commit = entry->commit;
+		commit->object.flags |= POPPED;
+		if (!(commit->object.flags & COMMON))
+			data->non_common_revs--;
+
+		if (!(commit->object.flags & COMMON) && !entry->ttl)
+			to_send = commit;
+
+		parse_commit(commit);
+		for (p = commit->parents; p; p = p->next)
+			parent_pushed |= push_parent(data, entry, p->item);
+
+		if (!(commit->object.flags & COMMON) && !parent_pushed)
+			/*
+			 * This commit has no parents, or all of its parents
+			 * have already been popped (due to clock skew), so send
+			 * it anyway.
+			 */
+			to_send = commit;
+
+		free(entry);
+	}
+
+	return &to_send->object.oid;
+}
+
+static void known_common(struct fetch_negotiator *n, struct commit *c)
+{
+	if (c->object.flags & SEEN)
+		return;
+	rev_list_push(n->data, c, ADVERTISED);
+}
+
+static void add_tip(struct fetch_negotiator *n, struct commit *c)
+{
+	n->known_common = NULL;
+	if (c->object.flags & SEEN)
+		return;
+	rev_list_push(n->data, c, 0);
+}
+
+static const struct object_id *next(struct fetch_negotiator *n)
+{
+	n->known_common = NULL;
+	n->add_tip = NULL;
+	return get_rev(n->data);
+}
+
+static int ack(struct fetch_negotiator *n, struct commit *c)
+{
+	int known_to_be_common = !!(c->object.flags & COMMON);
+	if (!(c->object.flags & SEEN))
+		die("received ack for commit %s not sent as 'have'\n",
+		    oid_to_hex(&c->object.oid));
+	mark_common(n->data, c);
+	return known_to_be_common;
+}
+
+static void release(struct fetch_negotiator *n)
+{
+	clear_prio_queue(&((struct data *)n->data)->rev_list);
+	FREE_AND_NULL(n->data);
+}
+
+void skipping_negotiator_init(struct fetch_negotiator *negotiator)
+{
+	struct data *data;
+	negotiator->known_common = known_common;
+	negotiator->add_tip = add_tip;
+	negotiator->next = next;
+	negotiator->ack = ack;
+	negotiator->release = release;
+	negotiator->data = data = xcalloc(1, sizeof(*data));
+	data->rev_list.compare = compare;
+
+	if (marked)
+		for_each_ref(clear_marks, NULL);
+	marked = 1;
+}
diff -pruN 1.2.1+git2.18.0-1/git/negotiator/skipping.h 1.2.3+git2.25.1-1/git/negotiator/skipping.h
--- 1.2.1+git2.18.0-1/git/negotiator/skipping.h	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/negotiator/skipping.h	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,8 @@
+#ifndef NEGOTIATOR_SKIPPING_H
+#define NEGOTIATOR_SKIPPING_H
+
+struct fetch_negotiator;
+
+void skipping_negotiator_init(struct fetch_negotiator *negotiator);
+
+#endif
diff -pruN 1.2.1+git2.18.0-1/git/notes.c 1.2.3+git2.25.1-1/git/notes.c
--- 1.2.1+git2.18.0-1/git/notes.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/notes.c	2020-02-17 04:47:35.000000000 +0000
@@ -1,6 +1,7 @@
 #include "cache.h"
 #include "config.h"
 #include "notes.h"
+#include "object-store.h"
 #include "blob.h"
 #include "tree.h"
 #include "utf8.h"
@@ -66,8 +67,9 @@ struct non_note {
 
 #define GET_NIBBLE(n, sha1) ((((sha1)[(n) >> 1]) >> ((~(n) & 0x01) << 2)) & 0x0f)
 
-#define KEY_INDEX (GIT_SHA1_RAWSZ - 1)
-#define FANOUT_PATH_SEPARATORS ((GIT_SHA1_HEXSZ / 2) - 1)
+#define KEY_INDEX (the_hash_algo->rawsz - 1)
+#define FANOUT_PATH_SEPARATORS (the_hash_algo->rawsz - 1)
+#define FANOUT_PATH_SEPARATORS_MAX ((GIT_MAX_HEXSZ / 2) - 1)
 #define SUBTREE_SHA1_PREFIXCMP(key_sha1, subtree_sha1) \
 	(memcmp(key_sha1, subtree_sha1, subtree_sha1[KEY_INDEX]))
 
@@ -146,7 +148,7 @@ static struct leaf_node *note_tree_find(
 	void **p = note_tree_search(t, &tree, &n, key_sha1);
 	if (GET_PTR_TYPE(*p) == PTR_TYPE_NOTE) {
 		struct leaf_node *l = (struct leaf_node *) CLR_PTR_TYPE(*p);
-		if (!hashcmp(key_sha1, l->key_oid.hash))
+		if (hasheq(key_sha1, l->key_oid.hash))
 			return l;
 	}
 	return NULL;
@@ -197,7 +199,7 @@ static void note_tree_remove(struct note
 		struct leaf_node *entry)
 {
 	struct leaf_node *l;
-	struct int_node *parent_stack[GIT_SHA1_RAWSZ];
+	struct int_node *parent_stack[GIT_MAX_RAWSZ];
 	unsigned char i, j;
 	void **p = note_tree_search(t, &tree, &n, entry->key_oid.hash);
 
@@ -205,7 +207,7 @@ static void note_tree_remove(struct note
 	if (GET_PTR_TYPE(*p) != PTR_TYPE_NOTE)
 		return; /* type mismatch, nothing to remove */
 	l = (struct leaf_node *) CLR_PTR_TYPE(*p);
-	if (oidcmp(&l->key_oid, &entry->key_oid))
+	if (!oideq(&l->key_oid, &entry->key_oid))
 		return; /* key mismatch, nothing to remove */
 
 	/* we have found a matching entry */
@@ -265,10 +267,12 @@ static int note_tree_insert(struct notes
 	case PTR_TYPE_NOTE:
 		switch (type) {
 		case PTR_TYPE_NOTE:
-			if (!oidcmp(&l->key_oid, &entry->key_oid)) {
+			if (oideq(&l->key_oid, &entry->key_oid)) {
 				/* skip concatenation if l == entry */
-				if (!oidcmp(&l->val_oid, &entry->val_oid))
+				if (oideq(&l->val_oid, &entry->val_oid)) {
+					free(entry);
 					return 0;
+				}
 
 				ret = combine_notes(&l->val_oid,
 						    &entry->val_oid);
@@ -393,14 +397,15 @@ static void load_subtree(struct notes_tr
 	void *buf;
 	struct tree_desc desc;
 	struct name_entry entry;
+	const unsigned hashsz = the_hash_algo->rawsz;
 
-	buf = fill_tree_descriptor(&desc, &subtree->val_oid);
+	buf = fill_tree_descriptor(the_repository, &desc, &subtree->val_oid);
 	if (!buf)
 		die("Could not read %s for notes-index",
 		     oid_to_hex(&subtree->val_oid));
 
 	prefix_len = subtree->key_oid.hash[KEY_INDEX];
-	if (prefix_len >= GIT_SHA1_RAWSZ)
+	if (prefix_len >= hashsz)
 		BUG("prefix_len (%"PRIuMAX") is out of range", (uintmax_t)prefix_len);
 	if (prefix_len * 2 < n)
 		BUG("prefix_len (%"PRIuMAX") is too small", (uintmax_t)prefix_len);
@@ -410,7 +415,7 @@ static void load_subtree(struct notes_tr
 		struct leaf_node *l;
 		size_t path_len = strlen(entry.path);
 
-		if (path_len == 2 * (GIT_SHA1_RAWSZ - prefix_len)) {
+		if (path_len == 2 * (hashsz - prefix_len)) {
 			/* This is potentially the remainder of the SHA-1 */
 
 			if (!S_ISREG(entry.mode))
@@ -418,7 +423,7 @@ static void load_subtree(struct notes_tr
 				goto handle_non_note;
 
 			if (hex_to_bytes(object_oid.hash + prefix_len, entry.path,
-					 GIT_SHA1_RAWSZ - prefix_len))
+					 hashsz - prefix_len))
 				goto handle_non_note; /* entry.path is not a SHA1 */
 
 			type = PTR_TYPE_NOTE;
@@ -438,7 +443,7 @@ static void load_subtree(struct notes_tr
 			 * except for the last byte, where we write
 			 * the length:
 			 */
-			memset(object_oid.hash + len, 0, GIT_SHA1_RAWSZ - len - 1);
+			memset(object_oid.hash + len, 0, hashsz - len - 1);
 			object_oid.hash[KEY_INDEX] = (unsigned char)len;
 
 			type = PTR_TYPE_SUBTREE;
@@ -449,13 +454,13 @@ static void load_subtree(struct notes_tr
 
 		l = xcalloc(1, sizeof(*l));
 		oidcpy(&l->key_oid, &object_oid);
-		oidcpy(&l->val_oid, entry.oid);
+		oidcpy(&l->val_oid, &entry.oid);
 		if (note_tree_insert(t, node, n, l, type,
 				     combine_notes_concatenate))
 			die("Failed to load %s %s into notes tree "
 			    "from %s",
 			    type == PTR_TYPE_NOTE ? "note" : "subtree",
-			    oid_to_hex(&l->key_oid), t->ref);
+			    oid_to_hex(&object_oid), t->ref);
 
 		continue;
 
@@ -480,7 +485,7 @@ handle_non_note:
 			}
 			strbuf_addstr(&non_note_path, entry.path);
 			add_non_note(t, strbuf_detach(&non_note_path, NULL),
-				     entry.mode, entry.oid->hash);
+				     entry.mode, entry.oid.hash);
 		}
 	}
 	free(buf);
@@ -526,22 +531,22 @@ static unsigned char determine_fanout(st
 	return fanout + 1;
 }
 
-/* hex SHA1 + 19 * '/' + NUL */
-#define FANOUT_PATH_MAX GIT_SHA1_HEXSZ + FANOUT_PATH_SEPARATORS + 1
+/* hex oid + '/' between each pair of hex digits + NUL */
+#define FANOUT_PATH_MAX GIT_MAX_HEXSZ + FANOUT_PATH_SEPARATORS_MAX + 1
 
-static void construct_path_with_fanout(const unsigned char *sha1,
+static void construct_path_with_fanout(const unsigned char *hash,
 		unsigned char fanout, char *path)
 {
 	unsigned int i = 0, j = 0;
-	const char *hex_sha1 = sha1_to_hex(sha1);
-	assert(fanout < GIT_SHA1_RAWSZ);
+	const char *hex_hash = hash_to_hex(hash);
+	assert(fanout < the_hash_algo->rawsz);
 	while (fanout) {
-		path[i++] = hex_sha1[j++];
-		path[i++] = hex_sha1[j++];
+		path[i++] = hex_hash[j++];
+		path[i++] = hex_hash[j++];
 		path[i++] = '/';
 		fanout--;
 	}
-	xsnprintf(path + i, FANOUT_PATH_MAX - i, "%s", hex_sha1 + j);
+	xsnprintf(path + i, FANOUT_PATH_MAX - i, "%s", hex_hash + j);
 }
 
 static int for_each_note_helper(struct notes_tree *t, struct int_node *tree,
@@ -636,10 +641,10 @@ static inline int matches_tree_write_sta
 
 static void write_tree_entry(struct strbuf *buf, unsigned int mode,
 		const char *path, unsigned int path_len, const
-		unsigned char *sha1)
+		unsigned char *hash)
 {
 	strbuf_addf(buf, "%o %.*s%c", mode, path_len, path, '\0');
-	strbuf_add(buf, sha1, GIT_SHA1_RAWSZ);
+	strbuf_add(buf, hash, the_hash_algo->rawsz);
 }
 
 static void tree_write_stack_init_subtree(struct tree_write_stack *tws,
@@ -651,7 +656,7 @@ static void tree_write_stack_init_subtre
 	n = (struct tree_write_stack *)
 		xmalloc(sizeof(struct tree_write_stack));
 	n->next = NULL;
-	strbuf_init(&n->buf, 256 * (32 + GIT_SHA1_HEXSZ)); /* assume 256 entries per tree */
+	strbuf_init(&n->buf, 256 * (32 + the_hash_algo->hexsz)); /* assume 256 entries per tree */
 	n->path[0] = n->path[1] = '\0';
 	tws->next = n;
 	tws->path[0] = path[0];
@@ -756,7 +761,7 @@ static int write_each_note(const struct
 		note_path[note_path_len] = '\0';
 		mode = 040000;
 	}
-	assert(note_path_len <= GIT_SHA1_HEXSZ + FANOUT_PATH_SEPARATORS);
+	assert(note_path_len <= GIT_MAX_HEXSZ + FANOUT_PATH_SEPARATORS);
 
 	/* Weave non-note entries into note entries */
 	return  write_each_non_note_until(note_path, d) ||
@@ -985,7 +990,7 @@ void init_notes(struct notes_tree *t, co
 		combine_notes_fn combine_notes, int flags)
 {
 	struct object_id oid, object_oid;
-	unsigned mode;
+	unsigned short mode;
 	struct leaf_node root_tree;
 
 	if (!t)
@@ -1012,7 +1017,7 @@ void init_notes(struct notes_tree *t, co
 		return;
 	if (flags & NOTES_INIT_WRITABLE && read_ref(notes_ref, &object_oid))
 		die("Cannot use notes ref %s", notes_ref);
-	if (get_tree_entry(&object_oid, "", &oid, &mode))
+	if (get_tree_entry(the_repository, &object_oid, "", &oid, &mode))
 		die("Failed to read notes tree referenced by %s (%s)",
 		    notes_ref, oid_to_hex(&object_oid));
 
@@ -1038,6 +1043,39 @@ struct notes_tree **load_notes_trees(str
 
 void init_display_notes(struct display_notes_opt *opt)
 {
+	memset(opt, 0, sizeof(*opt));
+	opt->use_default_notes = -1;
+}
+
+void enable_default_display_notes(struct display_notes_opt *opt, int *show_notes)
+{
+	opt->use_default_notes = 1;
+	*show_notes = 1;
+}
+
+void enable_ref_display_notes(struct display_notes_opt *opt, int *show_notes,
+		const char *ref) {
+	struct strbuf buf = STRBUF_INIT;
+	strbuf_addstr(&buf, ref);
+	expand_notes_ref(&buf);
+	string_list_append(&opt->extra_notes_refs,
+			strbuf_detach(&buf, NULL));
+	*show_notes = 1;
+}
+
+void disable_display_notes(struct display_notes_opt *opt, int *show_notes)
+{
+	opt->use_default_notes = -1;
+	/* we have been strdup'ing ourselves, so trick
+	 * string_list into free()ing strings */
+	opt->extra_notes_refs.strdup_strings = 1;
+	string_list_clear(&opt->extra_notes_refs, 0);
+	opt->extra_notes_refs.strdup_strings = 0;
+	*show_notes = 0;
+}
+
+void load_display_notes(struct display_notes_opt *opt)
+{
 	char *display_ref_env;
 	int load_config_refs = 0;
 	display_notes_refs.strdup_strings = 1;
@@ -1136,7 +1174,7 @@ int write_notes_tree(struct notes_tree *
 
 	/* Prepare for traversal of current notes tree */
 	root.next = NULL; /* last forward entry in list is grounded */
-	strbuf_init(&root.buf, 256 * (32 + GIT_SHA1_HEXSZ)); /* assume 256 entries */
+	strbuf_init(&root.buf, 256 * (32 + the_hash_algo->hexsz)); /* assume 256 entries */
 	root.path[0] = root.path[1] = '\0';
 	cb_data.root = &root;
 	cb_data.next_non_note = t->first_non_note;
@@ -1164,7 +1202,7 @@ void prune_notes(struct notes_tree *t, i
 
 	while (l) {
 		if (flags & NOTES_PRUNE_VERBOSE)
-			printf("%s\n", sha1_to_hex(l->sha1));
+			printf("%s\n", hash_to_hex(l->sha1));
 		if (!(flags & NOTES_PRUNE_DRYRUN))
 			remove_note(t, l->sha1);
 		l = l->next;
diff -pruN 1.2.1+git2.18.0-1/git/notes-cache.c 1.2.3+git2.25.1-1/git/notes-cache.c
--- 1.2.1+git2.18.0-1/git/notes-cache.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/notes-cache.c	2020-02-17 04:47:35.000000000 +0000
@@ -1,9 +1,13 @@
 #include "cache.h"
 #include "notes-cache.h"
+#include "object-store.h"
+#include "repository.h"
 #include "commit.h"
 #include "refs.h"
 
-static int notes_cache_match_validity(const char *ref, const char *validity)
+static int notes_cache_match_validity(struct repository *r,
+				      const char *ref,
+				      const char *validity)
 {
 	struct object_id oid;
 	struct commit *commit;
@@ -14,7 +18,7 @@ static int notes_cache_match_validity(co
 	if (read_ref(ref, &oid) < 0)
 		return 0;
 
-	commit = lookup_commit_reference_gently(&oid, 1);
+	commit = lookup_commit_reference_gently(r, &oid, 1);
 	if (!commit)
 		return 0;
 
@@ -28,8 +32,8 @@ static int notes_cache_match_validity(co
 	return ret;
 }
 
-void notes_cache_init(struct notes_cache *c, const char *name,
-		     const char *validity)
+void notes_cache_init(struct repository *r, struct notes_cache *c,
+		      const char *name, const char *validity)
 {
 	struct strbuf ref = STRBUF_INIT;
 	int flags = NOTES_INIT_WRITABLE;
@@ -38,7 +42,7 @@ void notes_cache_init(struct notes_cache
 	c->validity = xstrdup(validity);
 
 	strbuf_addf(&ref, "refs/notes/%s", name);
-	if (!notes_cache_match_validity(ref.buf, validity))
+	if (!notes_cache_match_validity(r, ref.buf, validity))
 		flags |= NOTES_INIT_EMPTY;
 	init_notes(&c->tree, ref.buf, combine_notes_overwrite, flags);
 	strbuf_release(&ref);
diff -pruN 1.2.1+git2.18.0-1/git/notes-cache.h 1.2.3+git2.25.1-1/git/notes-cache.h
--- 1.2.1+git2.18.0-1/git/notes-cache.h	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/notes-cache.h	2020-02-17 04:47:35.000000000 +0000
@@ -3,13 +3,15 @@
 
 #include "notes.h"
 
+struct repository;
+
 struct notes_cache {
 	struct notes_tree tree;
 	char *validity;
 };
 
-void notes_cache_init(struct notes_cache *c, const char *name,
-		     const char *validity);
+void notes_cache_init(struct repository *r, struct notes_cache *c,
+		      const char *name, const char *validity);
 int notes_cache_write(struct notes_cache *c);
 
 char *notes_cache_get(struct notes_cache *c, struct object_id *oid, size_t
diff -pruN 1.2.1+git2.18.0-1/git/notes.h 1.2.3+git2.25.1-1/git/notes.h
--- 1.2.1+git2.18.0-1/git/notes.h	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/notes.h	2020-02-17 04:47:35.000000000 +0000
@@ -3,6 +3,9 @@
 
 #include "string-list.h"
 
+struct object_id;
+struct strbuf;
+
 /*
  * Function type for combining two notes annotating the same object.
  *
@@ -258,6 +261,26 @@ struct display_notes_opt {
 };
 
 /*
+ * Initialize a display_notes_opt to its default value.
+ */
+void init_display_notes(struct display_notes_opt *opt);
+
+/*
+ * This family of functions enables or disables the display of notes. In
+ * particular, 'enable_default_display_notes' will display the default notes,
+ * 'enable_ref_display_notes' will display the notes ref 'ref' and
+ * 'disable_display_notes' will disable notes, including those added by previous
+ * invocations of the 'enable_*_display_notes' functions.
+ *
+ * 'show_notes' is a pointer to a boolean which will be set to 1 if notes are
+ * displayed, else 0. It must not be NULL.
+ */
+void enable_default_display_notes(struct display_notes_opt *opt, int *show_notes);
+void enable_ref_display_notes(struct display_notes_opt *opt, int *show_notes,
+		const char *ref);
+void disable_display_notes(struct display_notes_opt *opt, int *show_notes);
+
+/*
  * Load the notes machinery for displaying several notes trees.
  *
  * If 'opt' is not NULL, then it specifies additional settings for the
@@ -269,18 +292,16 @@ struct display_notes_opt {
  * - extra_notes_refs may contain a list of globs (in the same style
  *   as notes.displayRef) where notes should be loaded from.
  */
-void init_display_notes(struct display_notes_opt *opt);
+void load_display_notes(struct display_notes_opt *opt);
 
 /*
  * Append notes for the given 'object_sha1' from all trees set up by
- * init_display_notes() to 'sb'.  The 'flags' are a bitwise
- * combination of
- *
- * - NOTES_SHOW_HEADER: add a 'Notes (refname):' header
+ * load_display_notes() to 'sb'.
  *
- * - NOTES_INDENT: indent the notes by 4 places
+ * If 'raw' is false the note will be indented by 4 places and
+ * a 'Notes (refname):' header added.
  *
- * You *must* call init_display_notes() before using this function.
+ * You *must* call load_display_notes() before using this function.
  */
 void format_display_notes(const struct object_id *object_oid,
 			  struct strbuf *sb, const char *output_encoding, int raw);
diff -pruN 1.2.1+git2.18.0-1/git/notes-merge.c 1.2.3+git2.25.1-1/git/notes-merge.c
--- 1.2.1+git2.18.0-1/git/notes-merge.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/notes-merge.c	2020-02-17 04:47:35.000000000 +0000
@@ -1,6 +1,8 @@
 #include "cache.h"
 #include "commit.h"
 #include "refs.h"
+#include "object-store.h"
+#include "repository.h"
 #include "diff.h"
 #include "diffcore.h"
 #include "xdiff-interface.h"
@@ -10,28 +12,31 @@
 #include "notes-merge.h"
 #include "strbuf.h"
 #include "notes-utils.h"
+#include "commit-reach.h"
 
 struct notes_merge_pair {
 	struct object_id obj, base, local, remote;
 };
 
-void init_notes_merge_options(struct notes_merge_options *o)
+void init_notes_merge_options(struct repository *r,
+			      struct notes_merge_options *o)
 {
 	memset(o, 0, sizeof(struct notes_merge_options));
 	strbuf_init(&(o->commit_msg), 0);
 	o->verbosity = NOTES_MERGE_VERBOSITY_DEFAULT;
+	o->repo = r;
 }
 
 static int path_to_oid(const char *path, struct object_id *oid)
 {
-	char hex_oid[GIT_SHA1_HEXSZ];
+	char hex_oid[GIT_MAX_HEXSZ];
 	int i = 0;
-	while (*path && i < GIT_SHA1_HEXSZ) {
+	while (*path && i < the_hash_algo->hexsz) {
 		if (*path != '/')
 			hex_oid[i++] = *path;
 		path++;
 	}
-	if (*path || i != GIT_SHA1_HEXSZ)
+	if (*path || i != the_hash_algo->hexsz)
 		return -1;
 	return get_oid_hex(hex_oid, oid);
 }
@@ -124,7 +129,7 @@ static struct notes_merge_pair *diff_tre
 	trace_printf("\tdiff_tree_remote(base = %.7s, remote = %.7s)\n",
 	       oid_to_hex(base), oid_to_hex(remote));
 
-	diff_setup(&opt);
+	repo_diff_setup(o->repo, &opt);
 	opt.flags.recursive = 1;
 	opt.output_format = DIFF_FORMAT_NO_OUTPUT;
 	diff_setup_done(&opt);
@@ -149,7 +154,7 @@ static struct notes_merge_pair *diff_tre
 		mp = find_notes_merge_pair_pos(changes, len, &obj, 1, &occupied);
 		if (occupied) {
 			/* We've found an addition/deletion pair */
-			assert(!oidcmp(&mp->obj, &obj));
+			assert(oideq(&mp->obj, &obj));
 			if (is_null_oid(&p->one->oid)) { /* addition */
 				assert(is_null_oid(&mp->remote));
 				oidcpy(&mp->remote, &p->two->oid);
@@ -187,7 +192,7 @@ static void diff_tree_local(struct notes
 	trace_printf("\tdiff_tree_local(len = %i, base = %.7s, local = %.7s)\n",
 	       len, oid_to_hex(base), oid_to_hex(local));
 
-	diff_setup(&opt);
+	repo_diff_setup(o->repo, &opt);
 	opt.flags.recursive = 1;
 	opt.output_format = DIFF_FORMAT_NO_OUTPUT;
 	diff_setup_done(&opt);
@@ -216,7 +221,7 @@ static void diff_tree_local(struct notes
 			continue;
 		}
 
-		assert(!oidcmp(&mp->obj, &obj));
+		assert(oideq(&mp->obj, &obj));
 		if (is_null_oid(&p->two->oid)) { /* deletion */
 			/*
 			 * Either this is a true deletion (1), or it is part
@@ -227,7 +232,7 @@ static void diff_tree_local(struct notes
 			 * (3) mp->local is uninitialized; set it to null_sha1
 			 *     (will be overwritten by following addition)
 			 */
-			if (!oidcmp(&mp->local, &uninitialized))
+			if (oideq(&mp->local, &uninitialized))
 				oidclr(&mp->local);
 		} else if (is_null_oid(&p->one->oid)) { /* addition */
 			/*
@@ -239,7 +244,7 @@ static void diff_tree_local(struct notes
 			 * (3) mp->local is null_sha1;     set to p->two->sha1
 			 */
 			assert(is_null_oid(&mp->local) ||
-			       !oidcmp(&mp->local, &uninitialized));
+			       oideq(&mp->local, &uninitialized));
 			oidcpy(&mp->local, &p->two->oid);
 		} else { /* modification */
 			/*
@@ -247,8 +252,8 @@ static void diff_tree_local(struct notes
 			 * match mp->base, and mp->local shall be uninitialized.
 			 * Set mp->local to p->two->sha1.
 			 */
-			assert(!oidcmp(&p->one->oid, &mp->base));
-			assert(!oidcmp(&mp->local, &uninitialized));
+			assert(oideq(&p->one->oid, &mp->base));
+			assert(oideq(&mp->local, &uninitialized));
 			oidcpy(&mp->local, &p->two->oid);
 		}
 		trace_printf("\t\tStored local change for %s: %.7s -> %.7s\n",
@@ -346,7 +351,8 @@ static int ll_merge_in_worktree(struct n
 	read_mmblob(&remote, &p->remote);
 
 	status = ll_merge(&result_buf, oid_to_hex(&p->obj), &base, NULL,
-			  &local, o->local_ref, &remote, o->remote_ref, NULL);
+			  &local, o->local_ref, &remote, o->remote_ref,
+			  o->repo->index, NULL);
 
 	free(base.ptr);
 	free(local.ptr);
@@ -478,14 +484,14 @@ static int merge_changes(struct notes_me
 		       oid_to_hex(&p->local),
 		       oid_to_hex(&p->remote));
 
-		if (!oidcmp(&p->base, &p->remote)) {
+		if (oideq(&p->base, &p->remote)) {
 			/* no remote change; nothing to do */
 			trace_printf("\t\t\tskipping (no remote change)\n");
-		} else if (!oidcmp(&p->local, &p->remote)) {
+		} else if (oideq(&p->local, &p->remote)) {
 			/* same change in local and remote; nothing to do */
 			trace_printf("\t\t\tskipping (local == remote)\n");
-		} else if (!oidcmp(&p->local, &uninitialized) ||
-			   !oidcmp(&p->local, &p->base)) {
+		} else if (oideq(&p->local, &uninitialized) ||
+			   oideq(&p->local, &p->base)) {
 			/* no local change; adopt remote change */
 			trace_printf("\t\t\tno local change, adopted remote\n");
 			if (add_note(t, &p->obj, &p->remote,
@@ -552,7 +558,7 @@ int notes_merge(struct notes_merge_optio
 	else if (!check_refname_format(o->local_ref, 0) &&
 		is_null_oid(&local_oid))
 		local = NULL; /* local_oid == null_oid indicates unborn ref */
-	else if (!(local = lookup_commit_reference(&local_oid)))
+	else if (!(local = lookup_commit_reference(o->repo, &local_oid)))
 		die("Could not parse local commit %s (%s)",
 		    oid_to_hex(&local_oid), o->local_ref);
 	trace_printf("\tlocal commit: %.7s\n", oid_to_hex(&local_oid));
@@ -570,7 +576,7 @@ int notes_merge(struct notes_merge_optio
 			die("Failed to resolve remote notes ref '%s'",
 			    o->remote_ref);
 		}
-	} else if (!(remote = lookup_commit_reference(&remote_oid))) {
+	} else if (!(remote = lookup_commit_reference(o->repo, &remote_oid))) {
 		die("Could not parse remote commit %s (%s)",
 		    oid_to_hex(&remote_oid), o->remote_ref);
 	}
@@ -619,14 +625,14 @@ int notes_merge(struct notes_merge_optio
 			oid_to_hex(&local->object.oid),
 			oid_to_hex(base_oid));
 
-	if (!oidcmp(&remote->object.oid, base_oid)) {
+	if (oideq(&remote->object.oid, base_oid)) {
 		/* Already merged; result == local commit */
 		if (o->verbosity >= 2)
 			printf("Already up to date!\n");
 		oidcpy(result_oid, &local->object.oid);
 		goto found_result;
 	}
-	if (!oidcmp(&local->object.oid, base_oid)) {
+	if (oideq(&local->object.oid, base_oid)) {
 		/* Fast-forward; result == remote commit */
 		if (o->verbosity >= 2)
 			printf("Fast-forward\n");
@@ -643,7 +649,7 @@ int notes_merge(struct notes_merge_optio
 		struct commit_list *parents = NULL;
 		commit_list_insert(remote, &parents); /* LIFO order */
 		commit_list_insert(local, &parents);
-		create_notes_commit(local_tree, parents, o->commit_msg.buf,
+		create_notes_commit(o->repo, local_tree, parents, o->commit_msg.buf,
 				    o->commit_msg.len, result_oid);
 	}
 
@@ -707,7 +713,7 @@ int notes_merge_commit(struct notes_merg
 		/* write file as blob, and add to partial_tree */
 		if (stat(path.buf, &st))
 			die_errno("Failed to stat '%s'", path.buf);
-		if (index_path(&blob_oid, path.buf, &st, HASH_WRITE_OBJECT))
+		if (index_path(o->repo->index, &blob_oid, path.buf, &st, HASH_WRITE_OBJECT))
 			die("Failed to write blob object from '%s'", path.buf);
 		if (add_note(partial_tree, &obj_oid, &blob_oid, NULL))
 			die("Failed to add resolved note '%s' to notes tree",
@@ -718,7 +724,7 @@ int notes_merge_commit(struct notes_merg
 		strbuf_setlen(&path, baselen);
 	}
 
-	create_notes_commit(partial_tree, partial_commit->parents, msg,
+	create_notes_commit(o->repo, partial_tree, partial_commit->parents, msg,
 			    strlen(msg), result_oid);
 	unuse_commit_buffer(partial_commit, buffer);
 	if (o->verbosity >= 4)
diff -pruN 1.2.1+git2.18.0-1/git/notes-merge.h 1.2.3+git2.25.1-1/git/notes-merge.h
--- 1.2.1+git2.18.0-1/git/notes-merge.h	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/notes-merge.h	2020-02-17 04:47:35.000000000 +0000
@@ -2,6 +2,11 @@
 #define NOTES_MERGE_H
 
 #include "notes-utils.h"
+#include "strbuf.h"
+
+struct commit;
+struct object_id;
+struct repository;
 
 #define NOTES_MERGE_WORKTREE "NOTES_MERGE_WORKTREE"
 
@@ -11,6 +16,7 @@ enum notes_merge_verbosity {
 };
 
 struct notes_merge_options {
+	struct repository *repo;
 	const char *local_ref;
 	const char *remote_ref;
 	struct strbuf commit_msg;
@@ -19,7 +25,8 @@ struct notes_merge_options {
 	unsigned has_worktree:1;
 };
 
-void init_notes_merge_options(struct notes_merge_options *o);
+void init_notes_merge_options(struct repository *r,
+			      struct notes_merge_options *o);
 
 /*
  * Merge notes from o->remote_ref into o->local_ref
diff -pruN 1.2.1+git2.18.0-1/git/notes-utils.c 1.2.3+git2.25.1-1/git/notes-utils.c
--- 1.2.1+git2.18.0-1/git/notes-utils.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/notes-utils.c	2020-02-17 04:47:35.000000000 +0000
@@ -3,8 +3,11 @@
 #include "commit.h"
 #include "refs.h"
 #include "notes-utils.h"
+#include "repository.h"
 
-void create_notes_commit(struct notes_tree *t, struct commit_list *parents,
+void create_notes_commit(struct repository *r,
+			 struct notes_tree *t,
+			 struct commit_list *parents,
 			 const char *msg, size_t msg_len,
 			 struct object_id *result_oid)
 {
@@ -19,7 +22,7 @@ void create_notes_commit(struct notes_tr
 		/* Deduce parent commit from t->ref */
 		struct object_id parent_oid;
 		if (!read_ref(t->ref, &parent_oid)) {
-			struct commit *parent = lookup_commit(&parent_oid);
+			struct commit *parent = lookup_commit(r, &parent_oid);
 			if (parse_commit(parent))
 				die("Failed to find/parse commit %s", t->ref);
 			commit_list_insert(parent, &parents);
@@ -32,7 +35,7 @@ void create_notes_commit(struct notes_tr
 		die("Failed to commit notes tree to database");
 }
 
-void commit_notes(struct notes_tree *t, const char *msg)
+void commit_notes(struct repository *r, struct notes_tree *t, const char *msg)
 {
 	struct strbuf buf = STRBUF_INIT;
 	struct object_id commit_oid;
@@ -48,7 +51,7 @@ void commit_notes(struct notes_tree *t,
 	strbuf_addstr(&buf, msg);
 	strbuf_complete_line(&buf);
 
-	create_notes_commit(t, NULL, buf.buf, buf.len, &commit_oid);
+	create_notes_commit(r, t, NULL, buf.buf, buf.len, &commit_oid);
 	strbuf_insert(&buf, 0, "notes: ", 7); /* commit message starts at index 7 */
 	update_ref(buf.buf, t->update_ref, &commit_oid, NULL, 0,
 		   UPDATE_REFS_DIE_ON_ERR);
@@ -169,11 +172,13 @@ int copy_note_for_rewrite(struct notes_r
 	return ret;
 }
 
-void finish_copy_notes_for_rewrite(struct notes_rewrite_cfg *c, const char *msg)
+void finish_copy_notes_for_rewrite(struct repository *r,
+				   struct notes_rewrite_cfg *c,
+				   const char *msg)
 {
 	int i;
 	for (i = 0; c->trees[i]; i++) {
-		commit_notes(c->trees[i], msg);
+		commit_notes(r, c->trees[i], msg);
 		free_notes(c->trees[i]);
 	}
 	free(c->trees);
diff -pruN 1.2.1+git2.18.0-1/git/notes-utils.h 1.2.3+git2.25.1-1/git/notes-utils.h
--- 1.2.1+git2.18.0-1/git/notes-utils.h	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/notes-utils.h	2020-02-17 04:47:35.000000000 +0000
@@ -3,6 +3,10 @@
 
 #include "notes.h"
 
+struct commit_list;
+struct object_id;
+struct repository;
+
 /*
  * Create new notes commit from the given notes tree
  *
@@ -14,11 +18,13 @@
  *
  * The resulting commit SHA1 is stored in result_sha1.
  */
-void create_notes_commit(struct notes_tree *t, struct commit_list *parents,
+void create_notes_commit(struct repository *r,
+			 struct notes_tree *t,
+			 struct commit_list *parents,
 			 const char *msg, size_t msg_len,
 			 struct object_id *result_oid);
 
-void commit_notes(struct notes_tree *t, const char *msg);
+void commit_notes(struct repository *r, struct notes_tree *t, const char *msg);
 
 enum notes_merge_strategy {
 		NOTES_MERGE_RESOLVE_MANUAL = 0,
@@ -42,6 +48,8 @@ int parse_notes_merge_strategy(const cha
 struct notes_rewrite_cfg *init_copy_notes_for_rewrite(const char *cmd);
 int copy_note_for_rewrite(struct notes_rewrite_cfg *c,
 			  const struct object_id *from_obj, const struct object_id *to_obj);
-void finish_copy_notes_for_rewrite(struct notes_rewrite_cfg *c, const char *msg);
+void finish_copy_notes_for_rewrite(struct repository *r,
+				   struct notes_rewrite_cfg *c,
+				   const char *msg);
 
 #endif
diff -pruN 1.2.1+git2.18.0-1/git/object.c 1.2.3+git2.25.1-1/git/object.c
--- 1.2.1+git2.18.0-1/git/object.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/object.c	2020-02-17 04:47:35.000000000 +0000
@@ -1,24 +1,23 @@
 #include "cache.h"
 #include "object.h"
 #include "replace-object.h"
+#include "object-store.h"
 #include "blob.h"
 #include "tree.h"
 #include "commit.h"
 #include "tag.h"
-#include "object-store.h"
+#include "alloc.h"
 #include "packfile.h"
-
-static struct object **obj_hash;
-static int nr_objs, obj_hash_size;
+#include "commit-graph.h"
 
 unsigned int get_max_object_index(void)
 {
-	return obj_hash_size;
+	return the_repository->parsed_objects->obj_hash_size;
 }
 
 struct object *get_indexed_object(unsigned int idx)
 {
-	return obj_hash[idx];
+	return the_repository->parsed_objects->obj_hash[idx];
 }
 
 static const char *object_type_strings[] = {
@@ -51,7 +50,7 @@ int type_from_string_gently(const char *
 	if (gentle)
 		return -1;
 
-	die("invalid object type \"%s\"", str);
+	die(_("invalid object type \"%s\""), str);
 }
 
 /*
@@ -59,9 +58,9 @@ int type_from_string_gently(const char *
  * the specified sha1.  n must be a power of 2.  Please note that the
  * return value is *not* consistent across computer architectures.
  */
-static unsigned int hash_obj(const unsigned char *sha1, unsigned int n)
+static unsigned int hash_obj(const struct object_id *oid, unsigned int n)
 {
-	return sha1hash(sha1) & (n - 1);
+	return oidhash(oid) & (n - 1);
 }
 
 /*
@@ -71,7 +70,7 @@ static unsigned int hash_obj(const unsig
  */
 static void insert_obj_hash(struct object *obj, struct object **hash, unsigned int size)
 {
-	unsigned int j = hash_obj(obj->oid.hash, size);
+	unsigned int j = hash_obj(&obj->oid, size);
 
 	while (hash[j]) {
 		j++;
@@ -85,20 +84,20 @@ static void insert_obj_hash(struct objec
  * Look up the record for the given sha1 in the hash map stored in
  * obj_hash.  Return NULL if it was not found.
  */
-struct object *lookup_object(const unsigned char *sha1)
+struct object *lookup_object(struct repository *r, const struct object_id *oid)
 {
 	unsigned int i, first;
 	struct object *obj;
 
-	if (!obj_hash)
+	if (!r->parsed_objects->obj_hash)
 		return NULL;
 
-	first = i = hash_obj(sha1, obj_hash_size);
-	while ((obj = obj_hash[i]) != NULL) {
-		if (!hashcmp(sha1, obj->oid.hash))
+	first = i = hash_obj(oid, r->parsed_objects->obj_hash_size);
+	while ((obj = r->parsed_objects->obj_hash[i]) != NULL) {
+		if (oideq(oid, &obj->oid))
 			break;
 		i++;
-		if (i == obj_hash_size)
+		if (i == r->parsed_objects->obj_hash_size)
 			i = 0;
 	}
 	if (obj && i != first) {
@@ -107,7 +106,8 @@ struct object *lookup_object(const unsig
 		 * that we do not need to walk the hash table the next
 		 * time we look for it.
 		 */
-		SWAP(obj_hash[i], obj_hash[first]);
+		SWAP(r->parsed_objects->obj_hash[i],
+		     r->parsed_objects->obj_hash[first]);
 	}
 	return obj;
 }
@@ -117,86 +117,90 @@ struct object *lookup_object(const unsig
  * power of 2 (but at least 32).  Copy the existing values to the new
  * hash map.
  */
-static void grow_object_hash(void)
+static void grow_object_hash(struct repository *r)
 {
 	int i;
 	/*
 	 * Note that this size must always be power-of-2 to match hash_obj
 	 * above.
 	 */
-	int new_hash_size = obj_hash_size < 32 ? 32 : 2 * obj_hash_size;
+	int new_hash_size = r->parsed_objects->obj_hash_size < 32 ? 32 : 2 * r->parsed_objects->obj_hash_size;
 	struct object **new_hash;
 
 	new_hash = xcalloc(new_hash_size, sizeof(struct object *));
-	for (i = 0; i < obj_hash_size; i++) {
-		struct object *obj = obj_hash[i];
+	for (i = 0; i < r->parsed_objects->obj_hash_size; i++) {
+		struct object *obj = r->parsed_objects->obj_hash[i];
+
 		if (!obj)
 			continue;
 		insert_obj_hash(obj, new_hash, new_hash_size);
 	}
-	free(obj_hash);
-	obj_hash = new_hash;
-	obj_hash_size = new_hash_size;
+	free(r->parsed_objects->obj_hash);
+	r->parsed_objects->obj_hash = new_hash;
+	r->parsed_objects->obj_hash_size = new_hash_size;
 }
 
-void *create_object(const unsigned char *sha1, void *o)
+void *create_object(struct repository *r, const struct object_id *oid, void *o)
 {
 	struct object *obj = o;
 
 	obj->parsed = 0;
 	obj->flags = 0;
-	hashcpy(obj->oid.hash, sha1);
+	oidcpy(&obj->oid, oid);
 
-	if (obj_hash_size - 1 <= nr_objs * 2)
-		grow_object_hash();
+	if (r->parsed_objects->obj_hash_size - 1 <= r->parsed_objects->nr_objs * 2)
+		grow_object_hash(r);
 
-	insert_obj_hash(obj, obj_hash, obj_hash_size);
-	nr_objs++;
+	insert_obj_hash(obj, r->parsed_objects->obj_hash,
+			r->parsed_objects->obj_hash_size);
+	r->parsed_objects->nr_objs++;
 	return obj;
 }
 
-void *object_as_type(struct object *obj, enum object_type type, int quiet)
+void *object_as_type(struct repository *r, struct object *obj, enum object_type type, int quiet)
 {
 	if (obj->type == type)
 		return obj;
 	else if (obj->type == OBJ_NONE) {
 		if (type == OBJ_COMMIT)
-			((struct commit *)obj)->index = alloc_commit_index();
-		obj->type = type;
+			init_commit_node(r, (struct commit *) obj);
+		else
+			obj->type = type;
 		return obj;
 	}
 	else {
 		if (!quiet)
-			error("object %s is a %s, not a %s",
+			error(_("object %s is a %s, not a %s"),
 			      oid_to_hex(&obj->oid),
 			      type_name(obj->type), type_name(type));
 		return NULL;
 	}
 }
 
-struct object *lookup_unknown_object(const unsigned char *sha1)
+struct object *lookup_unknown_object(const struct object_id *oid)
 {
-	struct object *obj = lookup_object(sha1);
+	struct object *obj = lookup_object(the_repository, oid);
 	if (!obj)
-		obj = create_object(sha1, alloc_object_node());
+		obj = create_object(the_repository, oid,
+				    alloc_object_node(the_repository));
 	return obj;
 }
 
-struct object *parse_object_buffer(const struct object_id *oid, enum object_type type, unsigned long size, void *buffer, int *eaten_p)
+struct object *parse_object_buffer(struct repository *r, const struct object_id *oid, enum object_type type, unsigned long size, void *buffer, int *eaten_p)
 {
 	struct object *obj;
 	*eaten_p = 0;
 
 	obj = NULL;
 	if (type == OBJ_BLOB) {
-		struct blob *blob = lookup_blob(oid);
+		struct blob *blob = lookup_blob(r, oid);
 		if (blob) {
 			if (parse_blob_buffer(blob, buffer, size))
 				return NULL;
 			obj = &blob->object;
 		}
 	} else if (type == OBJ_TREE) {
-		struct tree *tree = lookup_tree(oid);
+		struct tree *tree = lookup_tree(r, oid);
 		if (tree) {
 			obj = &tree->object;
 			if (!tree->buffer)
@@ -208,25 +212,25 @@ struct object *parse_object_buffer(const
 			}
 		}
 	} else if (type == OBJ_COMMIT) {
-		struct commit *commit = lookup_commit(oid);
+		struct commit *commit = lookup_commit(r, oid);
 		if (commit) {
-			if (parse_commit_buffer(commit, buffer, size))
+			if (parse_commit_buffer(r, commit, buffer, size, 1))
 				return NULL;
-			if (!get_cached_commit_buffer(commit, NULL)) {
-				set_commit_buffer(commit, buffer, size);
+			if (!get_cached_commit_buffer(r, commit, NULL)) {
+				set_commit_buffer(r, commit, buffer, size);
 				*eaten_p = 1;
 			}
 			obj = &commit->object;
 		}
 	} else if (type == OBJ_TAG) {
-		struct tag *tag = lookup_tag(oid);
+		struct tag *tag = lookup_tag(r, oid);
 		if (tag) {
-			if (parse_tag_buffer(tag, buffer, size))
+			if (parse_tag_buffer(r, tag, buffer, size))
 			       return NULL;
 			obj = &tag->object;
 		}
 	} else {
-		warning("object %s has unknown type id %d", oid_to_hex(oid), type);
+		warning(_("object %s has unknown type id %d"), oid_to_hex(oid), type);
 		obj = NULL;
 	}
 	return obj;
@@ -235,46 +239,47 @@ struct object *parse_object_buffer(const
 struct object *parse_object_or_die(const struct object_id *oid,
 				   const char *name)
 {
-	struct object *o = parse_object(oid);
+	struct object *o = parse_object(the_repository, oid);
 	if (o)
 		return o;
 
 	die(_("unable to parse object: %s"), name ? name : oid_to_hex(oid));
 }
 
-struct object *parse_object(const struct object_id *oid)
+struct object *parse_object(struct repository *r, const struct object_id *oid)
 {
 	unsigned long size;
 	enum object_type type;
 	int eaten;
-	const struct object_id *repl = lookup_replace_object(the_repository, oid);
+	const struct object_id *repl = lookup_replace_object(r, oid);
 	void *buffer;
 	struct object *obj;
 
-	obj = lookup_object(oid->hash);
+	obj = lookup_object(r, oid);
 	if (obj && obj->parsed)
 		return obj;
 
-	if ((obj && obj->type == OBJ_BLOB && has_object_file(oid)) ||
-	    (!obj && has_object_file(oid) &&
-	     oid_object_info(the_repository, oid, NULL) == OBJ_BLOB)) {
+	if ((obj && obj->type == OBJ_BLOB && repo_has_object_file(r, oid)) ||
+	    (!obj && repo_has_object_file(r, oid) &&
+	     oid_object_info(r, oid, NULL) == OBJ_BLOB)) {
 		if (check_object_signature(repl, NULL, 0, NULL) < 0) {
-			error("sha1 mismatch %s", oid_to_hex(oid));
+			error(_("hash mismatch %s"), oid_to_hex(oid));
 			return NULL;
 		}
-		parse_blob_buffer(lookup_blob(oid), NULL, 0);
-		return lookup_object(oid->hash);
+		parse_blob_buffer(lookup_blob(r, oid), NULL, 0);
+		return lookup_object(r, oid);
 	}
 
-	buffer = read_object_file(oid, &type, &size);
+	buffer = repo_read_object_file(r, oid, &type, &size);
 	if (buffer) {
 		if (check_object_signature(repl, buffer, size, type_name(type)) < 0) {
 			free(buffer);
-			error("sha1 mismatch %s", oid_to_hex(repl));
+			error(_("hash mismatch %s"), oid_to_hex(repl));
 			return NULL;
 		}
 
-		obj = parse_object_buffer(oid, type, size, buffer, &eaten);
+		obj = parse_object_buffer(r, oid, type, size,
+					  buffer, &eaten);
 		if (!eaten)
 			free(buffer);
 		return obj;
@@ -431,8 +436,8 @@ void clear_object_flags(unsigned flags)
 {
 	int i;
 
-	for (i=0; i < obj_hash_size; i++) {
-		struct object *obj = obj_hash[i];
+	for (i=0; i < the_repository->parsed_objects->obj_hash_size; i++) {
+		struct object *obj = the_repository->parsed_objects->obj_hash[i];
 		if (obj)
 			obj->flags &= ~flags;
 	}
@@ -442,52 +447,123 @@ void clear_commit_marks_all(unsigned int
 {
 	int i;
 
-	for (i = 0; i < obj_hash_size; i++) {
-		struct object *obj = obj_hash[i];
+	for (i = 0; i < the_repository->parsed_objects->obj_hash_size; i++) {
+		struct object *obj = the_repository->parsed_objects->obj_hash[i];
 		if (obj && obj->type == OBJ_COMMIT)
 			obj->flags &= ~flags;
 	}
 }
 
+struct parsed_object_pool *parsed_object_pool_new(void)
+{
+	struct parsed_object_pool *o = xmalloc(sizeof(*o));
+	memset(o, 0, sizeof(*o));
+
+	o->blob_state = allocate_alloc_state();
+	o->tree_state = allocate_alloc_state();
+	o->commit_state = allocate_alloc_state();
+	o->tag_state = allocate_alloc_state();
+	o->object_state = allocate_alloc_state();
+
+	o->is_shallow = -1;
+	o->shallow_stat = xcalloc(1, sizeof(*o->shallow_stat));
+
+	o->buffer_slab = allocate_commit_buffer_slab();
+
+	return o;
+}
+
 struct raw_object_store *raw_object_store_new(void)
 {
 	struct raw_object_store *o = xmalloc(sizeof(*o));
 
 	memset(o, 0, sizeof(*o));
 	INIT_LIST_HEAD(&o->packed_git_mru);
+	hashmap_init(&o->pack_map, pack_map_entry_cmp, NULL, 0);
 	return o;
 }
 
-static void free_alt_odb(struct alternate_object_database *alt)
+static void free_object_directory(struct object_directory *odb)
 {
-	strbuf_release(&alt->scratch);
-	oid_array_clear(&alt->loose_objects_cache);
-	free(alt);
+	free(odb->path);
+	odb_clear_loose_cache(odb);
+	free(odb);
 }
 
-static void free_alt_odbs(struct raw_object_store *o)
+static void free_object_directories(struct raw_object_store *o)
 {
-	while (o->alt_odb_list) {
-		struct alternate_object_database *next;
+	while (o->odb) {
+		struct object_directory *next;
 
-		next = o->alt_odb_list->next;
-		free_alt_odb(o->alt_odb_list);
-		o->alt_odb_list = next;
+		next = o->odb->next;
+		free_object_directory(o->odb);
+		o->odb = next;
 	}
 }
 
 void raw_object_store_clear(struct raw_object_store *o)
 {
-	FREE_AND_NULL(o->objectdir);
 	FREE_AND_NULL(o->alternate_db);
 
 	oidmap_free(o->replace_map, 1);
 	FREE_AND_NULL(o->replace_map);
 
-	free_alt_odbs(o);
-	o->alt_odb_tail = NULL;
+	free_commit_graph(o->commit_graph);
+	o->commit_graph = NULL;
+	o->commit_graph_attempted = 0;
+
+	free_object_directories(o);
+	o->odb_tail = NULL;
+	o->loaded_alternates = 0;
 
 	INIT_LIST_HEAD(&o->packed_git_mru);
-	close_all_packs(o);
+	close_object_store(o);
 	o->packed_git = NULL;
+
+	hashmap_free(&o->pack_map);
+}
+
+void parsed_object_pool_clear(struct parsed_object_pool *o)
+{
+	/*
+	 * As objects are allocated in slabs (see alloc.c), we do
+	 * not need to free each object, but each slab instead.
+	 *
+	 * Before doing so, we need to free any additional memory
+	 * the objects may hold.
+	 */
+	unsigned i;
+
+	for (i = 0; i < o->obj_hash_size; i++) {
+		struct object *obj = o->obj_hash[i];
+
+		if (!obj)
+			continue;
+
+		if (obj->type == OBJ_TREE)
+			free_tree_buffer((struct tree*)obj);
+		else if (obj->type == OBJ_COMMIT)
+			release_commit_memory(o, (struct commit*)obj);
+		else if (obj->type == OBJ_TAG)
+			release_tag_memory((struct tag*)obj);
+	}
+
+	FREE_AND_NULL(o->obj_hash);
+	o->obj_hash_size = 0;
+
+	free_commit_buffer_slab(o->buffer_slab);
+	o->buffer_slab = NULL;
+
+	clear_alloc_state(o->blob_state);
+	clear_alloc_state(o->tree_state);
+	clear_alloc_state(o->commit_state);
+	clear_alloc_state(o->tag_state);
+	clear_alloc_state(o->object_state);
+	stat_validity_clear(o->shallow_stat);
+	FREE_AND_NULL(o->blob_state);
+	FREE_AND_NULL(o->tree_state);
+	FREE_AND_NULL(o->commit_state);
+	FREE_AND_NULL(o->tag_state);
+	FREE_AND_NULL(o->object_state);
+	FREE_AND_NULL(o->shallow_stat);
 }
diff -pruN 1.2.1+git2.18.0-1/git/object.h 1.2.3+git2.25.1-1/git/object.h
--- 1.2.1+git2.18.0-1/git/object.h	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/object.h	2020-02-17 04:47:35.000000000 +0000
@@ -1,6 +1,38 @@
 #ifndef OBJECT_H
 #define OBJECT_H
 
+#include "cache.h"
+
+struct buffer_slab;
+
+struct parsed_object_pool {
+	struct object **obj_hash;
+	int nr_objs, obj_hash_size;
+
+	/* TODO: migrate alloc_states to mem-pool? */
+	struct alloc_state *blob_state;
+	struct alloc_state *tree_state;
+	struct alloc_state *commit_state;
+	struct alloc_state *tag_state;
+	struct alloc_state *object_state;
+	unsigned commit_count;
+
+	/* parent substitutions from .git/info/grafts and .git/shallow */
+	struct commit_graft **grafts;
+	int grafts_alloc, grafts_nr;
+
+	int is_shallow;
+	struct stat_validity *shallow_stat;
+	char *alternate_shallow_file;
+
+	int commit_graft_prepared;
+
+	struct buffer_slab *buffer_slab;
+};
+
+struct parsed_object_pool *parsed_object_pool_new(void);
+void parsed_object_pool_clear(struct parsed_object_pool *o);
+
 struct object_list {
 	struct object *item;
 	struct object_list *next;
@@ -27,24 +59,27 @@ struct object_array {
 
 /*
  * object flag allocation:
- * revision.h:               0---------10                                26
- * fetch-pack.c:             0----5
+ * revision.h:               0---------10                              25----28
+ * fetch-pack.c:             01
+ * negotiator/default.c:       2--5
  * walker.c:                 0-2
- * upload-pack.c:                4       11----------------19
+ * upload-pack.c:                4       11-----14  16-----19
  * builtin/blame.c:                        12-13
  * bisect.c:                                        16
  * bundle.c:                                        16
  * http-push.c:                                     16-----19
- * commit.c:                                        16-----19
+ * commit-graph.c:                                15
+ * commit-reach.c:                                  16-----19
  * sha1-name.c:                                              20
  * list-objects-filter.c:                                      21
  * builtin/fsck.c:           0--3
  * builtin/index-pack.c:                                     2021
  * builtin/pack-objects.c:                                   20
  * builtin/reflog.c:                   10--12
+ * builtin/show-branch.c:    0-------------------------------------------26
  * builtin/unpack-objects.c:                                 2021
  */
-#define FLAG_BITS  27
+#define FLAG_BITS  29
 
 /*
  * The object type is stored in 3 bits.
@@ -56,19 +91,19 @@ struct object {
 	struct object_id oid;
 };
 
-extern const char *type_name(unsigned int type);
-extern int type_from_string_gently(const char *str, ssize_t, int gentle);
+const char *type_name(unsigned int type);
+int type_from_string_gently(const char *str, ssize_t, int gentle);
 #define type_from_string(str) type_from_string_gently(str, -1, 0)
 
 /*
  * Return the current number of buckets in the object hashmap.
  */
-extern unsigned int get_max_object_index(void);
+unsigned int get_max_object_index(void);
 
 /*
  * Return the object from the specified bucket in the object hashmap.
  */
-extern struct object *get_indexed_object(unsigned int);
+struct object *get_indexed_object(unsigned int);
 
 /*
  * This can be used to see if we have heard of the object before, but
@@ -82,18 +117,18 @@ extern struct object *get_indexed_object
  * half-initialised objects, the caller is expected to initialize them
  * by calling parse_object() on them.
  */
-struct object *lookup_object(const unsigned char *sha1);
+struct object *lookup_object(struct repository *r, const struct object_id *oid);
 
-extern void *create_object(const unsigned char *sha1, void *obj);
+void *create_object(struct repository *r, const struct object_id *oid, void *obj);
 
-void *object_as_type(struct object *obj, enum object_type type, int quiet);
+void *object_as_type(struct repository *r, struct object *obj, enum object_type type, int quiet);
 
 /*
  * Returns the object, having parsed it to find out what it is.
  *
  * Returns NULL if the object is missing or corrupt.
  */
-struct object *parse_object(const struct object_id *oid);
+struct object *parse_object(struct repository *r, const struct object_id *oid);
 
 /*
  * Like parse_object, but will die() instead of returning NULL. If the
@@ -106,10 +141,10 @@ struct object *parse_object_or_die(const
  * parsing it.  eaten_p indicates if the object has a borrowed copy
  * of buffer and the caller should not free() it.
  */
-struct object *parse_object_buffer(const struct object_id *oid, enum object_type type, unsigned long size, void *buffer, int *eaten_p);
+struct object *parse_object_buffer(struct repository *r, const struct object_id *oid, enum object_type type, unsigned long size, void *buffer, int *eaten_p);
 
 /** Returns the object, with potentially excess memory allocated. **/
-struct object *lookup_unknown_object(const unsigned  char *sha1);
+struct object *lookup_unknown_object(const struct object_id *oid);
 
 struct object_list *object_list_insert(struct object *item,
 				       struct object_list **list_p);
@@ -155,6 +190,6 @@ void clear_object_flags(unsigned flags);
 /*
  * Clear the specified object flags from all in-core commit objects.
  */
-extern void clear_commit_marks_all(unsigned int flags);
+void clear_commit_marks_all(unsigned int flags);
 
 #endif /* OBJECT_H */
diff -pruN 1.2.1+git2.18.0-1/git/object-store.h 1.2.3+git2.25.1-1/git/object-store.h
--- 1.2.1+git2.18.0-1/git/object-store.h	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/object-store.h	2020-02-17 04:47:35.000000000 +0000
@@ -1,41 +1,40 @@
 #ifndef OBJECT_STORE_H
 #define OBJECT_STORE_H
 
+#include "cache.h"
 #include "oidmap.h"
+#include "list.h"
+#include "sha1-array.h"
+#include "strbuf.h"
 
-struct alternate_object_database {
-	struct alternate_object_database *next;
-
-	/* see alt_scratch_buf() */
-	struct strbuf scratch;
-	size_t base_len;
+struct object_directory {
+	struct object_directory *next;
 
 	/*
-	 * Used to store the results of readdir(3) calls when searching
-	 * for unique abbreviated hashes.  This cache is never
-	 * invalidated, thus it's racy and not necessarily accurate.
-	 * That's fine for its purpose; don't use it for tasks requiring
-	 * greater accuracy!
+	 * Used to store the results of readdir(3) calls when we are OK
+	 * sacrificing accuracy due to races for speed. That includes
+	 * object existence with OBJECT_INFO_QUICK, as well as
+	 * our search for unique abbreviated hashes. Don't use it for tasks
+	 * requiring greater accuracy!
+	 *
+	 * Be sure to call odb_load_loose_cache() before using.
 	 */
 	char loose_objects_subdir_seen[256];
-	struct oid_array loose_objects_cache;
+	struct oid_array loose_objects_cache[256];
 
 	/*
 	 * Path to the alternative object store. If this is a relative path,
 	 * it is relative to the current working directory.
 	 */
-	char path[FLEX_ARRAY];
+	char *path;
 };
+
 void prepare_alt_odb(struct repository *r);
 char *compute_alternate_path(const char *path, struct strbuf *err);
-typedef int alt_odb_fn(struct alternate_object_database *, void *);
+typedef int alt_odb_fn(struct object_directory *, void *);
 int foreach_alt_odb(alt_odb_fn, void*);
-
-/*
- * Allocate a "struct alternate_object_database" but do _not_ actually
- * add it to the list of alternates.
- */
-struct alternate_object_database *alloc_alt_odb(const char *dir);
+typedef void alternate_ref_fn(const struct object_id *oid, void *);
+void for_each_alternate_ref(alternate_ref_fn, void *);
 
 /*
  * Add the directory to the on-disk alternates file; the new entry will also
@@ -51,14 +50,17 @@ void add_to_alternates_file(const char *
 void add_to_alternates_memory(const char *dir);
 
 /*
- * Returns a scratch strbuf pre-filled with the alternate object directory,
- * including a trailing slash, which can be used to access paths in the
- * alternate. Always use this over direct access to alt->scratch, as it
- * cleans up any previous use of the scratch buffer.
+ * Populate and return the loose object cache array corresponding to the
+ * given object ID.
  */
-struct strbuf *alt_scratch_buf(struct alternate_object_database *alt);
+struct oid_array *odb_loose_cache(struct object_directory *odb,
+				  const struct object_id *oid);
+
+/* Empty the loose object cache for the specified object directory. */
+void odb_clear_loose_cache(struct object_directory *odb);
 
 struct packed_git {
+	struct hashmap_entry packmap_ent;
 	struct packed_git *next;
 	struct list_head mru;
 	struct pack_window *windows;
@@ -77,32 +79,63 @@ struct packed_git {
 		 pack_keep_in_core:1,
 		 freshened:1,
 		 do_not_close:1,
-		 pack_promisor:1;
-	unsigned char sha1[20];
+		 pack_promisor:1,
+		 multi_pack_index:1;
+	unsigned char hash[GIT_MAX_RAWSZ];
 	struct revindex_entry *revindex;
 	/* something like ".git/objects/pack/xxxxx.pack" */
 	char pack_name[FLEX_ARRAY]; /* more */
 };
 
+struct multi_pack_index;
+
+static inline int pack_map_entry_cmp(const void *unused_cmp_data,
+				     const struct hashmap_entry *entry,
+				     const struct hashmap_entry *entry2,
+				     const void *keydata)
+{
+	const char *key = keydata;
+	const struct packed_git *pg1, *pg2;
+
+	pg1 = container_of(entry, const struct packed_git, packmap_ent);
+	pg2 = container_of(entry2, const struct packed_git, packmap_ent);
+
+	return strcmp(pg1->pack_name, key ? key : pg2->pack_name);
+}
+
 struct raw_object_store {
 	/*
-	 * Path to the repository's object store.
-	 * Cannot be NULL after initialization.
+	 * Set of all object directories; the main directory is first (and
+	 * cannot be NULL after initialization). Subsequent directories are
+	 * alternates.
 	 */
-	char *objectdir;
+	struct object_directory *odb;
+	struct object_directory **odb_tail;
+	int loaded_alternates;
 
-	/* Path to extra alternate object database if not NULL */
+	/*
+	 * A list of alternate object directories loaded from the environment;
+	 * this should not generally need to be accessed directly, but will
+	 * populate the "odb" list when prepare_alt_odb() is run.
+	 */
 	char *alternate_db;
 
-	struct alternate_object_database *alt_odb_list;
-	struct alternate_object_database **alt_odb_tail;
-
 	/*
 	 * Objects that should be substituted by other objects
 	 * (see git-replace(1)).
 	 */
 	struct oidmap *replace_map;
 
+	struct commit_graph *commit_graph;
+	unsigned commit_graph_attempted : 1; /* if loading has been attempted */
+
+	/*
+	 * private data
+	 *
+	 * should only be accessed directly by packfile.c and midx.c
+	 */
+	struct multi_pack_index *multi_pack_index;
+
 	/*
 	 * private data
 	 *
@@ -114,6 +147,12 @@ struct raw_object_store {
 	struct list_head packed_git_mru;
 
 	/*
+	 * A map of packfiles to packed_git structs for tracking which
+	 * packs have been loaded already.
+	 */
+	struct hashmap pack_map;
+
+	/*
 	 * A fast, rough count of the number of objects in the repository.
 	 * These two fields are not meant for direct access. Use
 	 * approximate_object_count() instead.
@@ -133,10 +172,233 @@ void raw_object_store_clear(struct raw_o
 
 /*
  * Put in `buf` the name of the file in the local object database that
- * would be used to store a loose object with the specified sha1.
+ * would be used to store a loose object with the specified oid.
+ */
+const char *loose_object_path(struct repository *r, struct strbuf *buf,
+			      const struct object_id *oid);
+
+void *map_loose_object(struct repository *r, const struct object_id *oid,
+		       unsigned long *size);
+
+void *read_object_file_extended(struct repository *r,
+				const struct object_id *oid,
+				enum object_type *type,
+				unsigned long *size, int lookup_replace);
+static inline void *repo_read_object_file(struct repository *r,
+					  const struct object_id *oid,
+					  enum object_type *type,
+					  unsigned long *size)
+{
+	return read_object_file_extended(r, oid, type, size, 1);
+}
+#ifndef NO_THE_REPOSITORY_COMPATIBILITY_MACROS
+#define read_object_file(oid, type, size) repo_read_object_file(the_repository, oid, type, size)
+#endif
+
+/* Read and unpack an object file into memory, write memory to an object file */
+int oid_object_info(struct repository *r, const struct object_id *, unsigned long *);
+
+int hash_object_file(const void *buf, unsigned long len,
+		     const char *type, struct object_id *oid);
+
+int write_object_file(const void *buf, unsigned long len,
+		      const char *type, struct object_id *oid);
+
+int hash_object_file_literally(const void *buf, unsigned long len,
+			       const char *type, struct object_id *oid,
+			       unsigned flags);
+
+int pretend_object_file(void *, unsigned long, enum object_type,
+			struct object_id *oid);
+
+int force_object_loose(const struct object_id *oid, time_t mtime);
+
+/*
+ * Open the loose object at path, check its hash, and return the contents,
+ * type, and size. If the object is a blob, then "contents" may return NULL,
+ * to allow streaming of large blobs.
+ *
+ * Returns 0 on success, negative on error (details may be written to stderr).
+ */
+int read_loose_object(const char *path,
+		      const struct object_id *expected_oid,
+		      enum object_type *type,
+		      unsigned long *size,
+		      void **contents);
+
+#ifndef NO_THE_REPOSITORY_COMPATIBILITY_MACROS
+#define has_sha1_file_with_flags(sha1, flags) repo_has_sha1_file_with_flags(the_repository, sha1, flags)
+#define has_sha1_file(sha1) repo_has_sha1_file(the_repository, sha1)
+#endif
+
+/* Same as the above, except for struct object_id. */
+int repo_has_object_file(struct repository *r, const struct object_id *oid);
+int repo_has_object_file_with_flags(struct repository *r,
+				    const struct object_id *oid, int flags);
+#ifndef NO_THE_REPOSITORY_COMPATIBILITY_MACROS
+#define has_object_file(oid) repo_has_object_file(the_repository, oid)
+#define has_object_file_with_flags(oid, flags) repo_has_object_file_with_flags(the_repository, oid, flags)
+#endif
+
+/*
+ * Return true iff an alternate object database has a loose object
+ * with the specified name.  This function does not respect replace
+ * references.
+ */
+int has_loose_object_nonlocal(const struct object_id *);
+
+void assert_oid_type(const struct object_id *oid, enum object_type expect);
+
+struct object_info {
+	/* Request */
+	enum object_type *typep;
+	unsigned long *sizep;
+	off_t *disk_sizep;
+	unsigned char *delta_base_sha1;
+	struct strbuf *type_name;
+	void **contentp;
+
+	/* Response */
+	enum {
+		OI_CACHED,
+		OI_LOOSE,
+		OI_PACKED,
+		OI_DBCACHED
+	} whence;
+	union {
+		/*
+		 * struct {
+		 * 	... Nothing to expose in this case
+		 * } cached;
+		 * struct {
+		 * 	... Nothing to expose in this case
+		 * } loose;
+		 */
+		struct {
+			struct packed_git *pack;
+			off_t offset;
+			unsigned int is_delta;
+		} packed;
+	} u;
+};
+
+/*
+ * Initializer for a "struct object_info" that wants no items. You may
+ * also memset() the memory to all-zeroes.
+ */
+#define OBJECT_INFO_INIT {NULL}
+
+/* Invoke lookup_replace_object() on the given hash */
+#define OBJECT_INFO_LOOKUP_REPLACE 1
+/* Allow reading from a loose object file of unknown/bogus type */
+#define OBJECT_INFO_ALLOW_UNKNOWN_TYPE 2
+/* Do not retry packed storage after checking packed and loose storage */
+#define OBJECT_INFO_QUICK 8
+/* Do not check loose object */
+#define OBJECT_INFO_IGNORE_LOOSE 16
+/*
+ * Do not attempt to fetch the object if missing (even if fetch_is_missing is
+ * nonzero).
+ */
+#define OBJECT_INFO_SKIP_FETCH_OBJECT 32
+/*
+ * This is meant for bulk prefetching of missing blobs in a partial
+ * clone. Implies OBJECT_INFO_SKIP_FETCH_OBJECT and OBJECT_INFO_QUICK
  */
-void sha1_file_name(struct repository *r, struct strbuf *buf, const unsigned char *sha1);
+#define OBJECT_INFO_FOR_PREFETCH (OBJECT_INFO_SKIP_FETCH_OBJECT | OBJECT_INFO_QUICK)
 
-void *map_sha1_file(struct repository *r, const unsigned char *sha1, unsigned long *size);
+int oid_object_info_extended(struct repository *r,
+			     const struct object_id *,
+			     struct object_info *, unsigned flags);
+
+/*
+ * Iterate over the files in the loose-object parts of the object
+ * directory "path", triggering the following callbacks:
+ *
+ *  - loose_object is called for each loose object we find.
+ *
+ *  - loose_cruft is called for any files that do not appear to be
+ *    loose objects. Note that we only look in the loose object
+ *    directories "objects/[0-9a-f]{2}/", so we will not report
+ *    "objects/foobar" as cruft.
+ *
+ *  - loose_subdir is called for each top-level hashed subdirectory
+ *    of the object directory (e.g., "$OBJDIR/f0"). It is called
+ *    after the objects in the directory are processed.
+ *
+ * Any callback that is NULL will be ignored. Callbacks returning non-zero
+ * will end the iteration.
+ *
+ * In the "buf" variant, "path" is a strbuf which will also be used as a
+ * scratch buffer, but restored to its original contents before
+ * the function returns.
+ */
+typedef int each_loose_object_fn(const struct object_id *oid,
+				 const char *path,
+				 void *data);
+typedef int each_loose_cruft_fn(const char *basename,
+				const char *path,
+				void *data);
+typedef int each_loose_subdir_fn(unsigned int nr,
+				 const char *path,
+				 void *data);
+int for_each_file_in_obj_subdir(unsigned int subdir_nr,
+				struct strbuf *path,
+				each_loose_object_fn obj_cb,
+				each_loose_cruft_fn cruft_cb,
+				each_loose_subdir_fn subdir_cb,
+				void *data);
+int for_each_loose_file_in_objdir(const char *path,
+				  each_loose_object_fn obj_cb,
+				  each_loose_cruft_fn cruft_cb,
+				  each_loose_subdir_fn subdir_cb,
+				  void *data);
+int for_each_loose_file_in_objdir_buf(struct strbuf *path,
+				      each_loose_object_fn obj_cb,
+				      each_loose_cruft_fn cruft_cb,
+				      each_loose_subdir_fn subdir_cb,
+				      void *data);
+
+/* Flags for for_each_*_object() below. */
+enum for_each_object_flags {
+	/* Iterate only over local objects, not alternates. */
+	FOR_EACH_OBJECT_LOCAL_ONLY = (1<<0),
+
+	/* Only iterate over packs obtained from the promisor remote. */
+	FOR_EACH_OBJECT_PROMISOR_ONLY = (1<<1),
+
+	/*
+	 * Visit objects within a pack in packfile order rather than .idx order
+	 */
+	FOR_EACH_OBJECT_PACK_ORDER = (1<<2),
+};
+
+/*
+ * Iterate over all accessible loose objects without respect to
+ * reachability. By default, this includes both local and alternate objects.
+ * The order in which objects are visited is unspecified.
+ *
+ * Any flags specific to packs are ignored.
+ */
+int for_each_loose_object(each_loose_object_fn, void *,
+			  enum for_each_object_flags flags);
+
+/*
+ * Iterate over all accessible packed objects without respect to reachability.
+ * By default, this includes both local and alternate packs.
+ *
+ * Note that some objects may appear twice if they are found in multiple packs.
+ * Each pack is visited in an unspecified order. By default, objects within a
+ * pack are visited in pack-idx order (i.e., sorted by oid).
+ */
+typedef int each_packed_object_fn(const struct object_id *oid,
+				  struct packed_git *pack,
+				  uint32_t pos,
+				  void *data);
+int for_each_object_in_pack(struct packed_git *p,
+			    each_packed_object_fn, void *data,
+			    enum for_each_object_flags flags);
+int for_each_packed_object(each_packed_object_fn, void *,
+			   enum for_each_object_flags flags);
 
 #endif /* OBJECT_STORE_H */
diff -pruN 1.2.1+git2.18.0-1/git/oidmap.c 1.2.3+git2.25.1-1/git/oidmap.c
--- 1.2.1+git2.18.0-1/git/oidmap.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/oidmap.c	2020-02-17 04:47:35.000000000 +0000
@@ -1,34 +1,33 @@
 #include "cache.h"
 #include "oidmap.h"
 
-static int cmpfn(const void *hashmap_cmp_fn_data,
-		 const void *entry, const void *entry_or_key,
-		 const void *keydata)
+static int oidmap_neq(const void *hashmap_cmp_fn_data,
+		      const struct hashmap_entry *e1,
+		      const struct hashmap_entry *e2,
+		      const void *keydata)
 {
-	const struct oidmap_entry *entry_ = entry;
-	if (keydata)
-		return oidcmp(&entry_->oid, (const struct object_id *) keydata);
-	return oidcmp(&entry_->oid,
-		      &((const struct oidmap_entry *) entry_or_key)->oid);
-}
+	const struct oidmap_entry *a, *b;
 
-static int hash(const struct object_id *oid)
-{
-	int hash;
-	memcpy(&hash, oid->hash, sizeof(hash));
-	return hash;
+	a = container_of(e1, const struct oidmap_entry, internal_entry);
+	b = container_of(e2, const struct oidmap_entry, internal_entry);
+
+	if (keydata)
+		return !oideq(&a->oid, (const struct object_id *) keydata);
+	return !oideq(&a->oid, &b->oid);
 }
 
 void oidmap_init(struct oidmap *map, size_t initial_size)
 {
-	hashmap_init(&map->map, cmpfn, NULL, initial_size);
+	hashmap_init(&map->map, oidmap_neq, NULL, initial_size);
 }
 
 void oidmap_free(struct oidmap *map, int free_entries)
 {
 	if (!map)
 		return;
-	hashmap_free(&map->map, free_entries);
+
+	/* TODO: make oidmap itself not depend on struct layouts */
+	hashmap_free_(&map->map, free_entries ? 0 : -1);
 }
 
 void *oidmap_get(const struct oidmap *map, const struct object_id *key)
@@ -36,7 +35,7 @@ void *oidmap_get(const struct oidmap *ma
 	if (!map->map.cmpfn)
 		return NULL;
 
-	return hashmap_get_from_hash(&map->map, hash(key), key);
+	return hashmap_get_from_hash(&map->map, oidhash(key), key);
 }
 
 void *oidmap_remove(struct oidmap *map, const struct object_id *key)
@@ -46,7 +45,7 @@ void *oidmap_remove(struct oidmap *map,
 	if (!map->map.cmpfn)
 		oidmap_init(map, 0);
 
-	hashmap_entry_init(&entry, hash(key));
+	hashmap_entry_init(&entry, oidhash(key));
 	return hashmap_remove(&map->map, &entry, key);
 }
 
@@ -57,6 +56,6 @@ void *oidmap_put(struct oidmap *map, voi
 	if (!map->map.cmpfn)
 		oidmap_init(map, 0);
 
-	hashmap_entry_init(&to_put->internal_entry, hash(&to_put->oid));
-	return hashmap_put(&map->map, to_put);
+	hashmap_entry_init(&to_put->internal_entry, oidhash(&to_put->oid));
+	return hashmap_put(&map->map, &to_put->internal_entry);
 }
diff -pruN 1.2.1+git2.18.0-1/git/oidmap.h 1.2.3+git2.25.1-1/git/oidmap.h
--- 1.2.1+git2.18.0-1/git/oidmap.h	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/oidmap.h	2020-02-17 04:47:35.000000000 +0000
@@ -1,6 +1,7 @@
 #ifndef OIDMAP_H
 #define OIDMAP_H
 
+#include "cache.h"
 #include "hashmap.h"
 
 /*
@@ -32,7 +33,7 @@ struct oidmap {
  * parameter may be used to preallocate a sufficiently large table and thus
  * prevent expensive resizing. If 0, the table is dynamically resized.
  */
-extern void oidmap_init(struct oidmap *map, size_t initial_size);
+void oidmap_init(struct oidmap *map, size_t initial_size);
 
 /*
  * Frees an oidmap structure and allocated memory.
@@ -40,13 +41,13 @@ extern void oidmap_init(struct oidmap *m
  * If `free_entries` is true, each oidmap_entry in the map is freed as well
  * using stdlibs free().
  */
-extern void oidmap_free(struct oidmap *map, int free_entries);
+void oidmap_free(struct oidmap *map, int free_entries);
 
 /*
  * Returns the oidmap entry for the specified oid, or NULL if not found.
  */
-extern void *oidmap_get(const struct oidmap *map,
-			const struct object_id *key);
+void *oidmap_get(const struct oidmap *map,
+		 const struct object_id *key);
 
 /*
  * Adds or replaces an oidmap entry.
@@ -56,14 +57,14 @@ extern void *oidmap_get(const struct oid
  *
  * Returns the replaced entry, or NULL if not found (i.e. the entry was added).
  */
-extern void *oidmap_put(struct oidmap *map, void *entry);
+void *oidmap_put(struct oidmap *map, void *entry);
 
 /*
  * Removes an oidmap entry matching the specified oid.
  *
  * Returns the removed entry, or NULL if not found.
  */
-extern void *oidmap_remove(struct oidmap *map, const struct object_id *key);
+void *oidmap_remove(struct oidmap *map, const struct object_id *key);
 
 
 struct oidmap_iter {
@@ -77,14 +78,16 @@ static inline void oidmap_iter_init(stru
 
 static inline void *oidmap_iter_next(struct oidmap_iter *iter)
 {
-	return hashmap_iter_next(&iter->h_iter);
+	/* TODO: this API could be reworked to do compile-time type checks */
+	return (void *)hashmap_iter_next(&iter->h_iter);
 }
 
 static inline void *oidmap_iter_first(struct oidmap *map,
 				      struct oidmap_iter *iter)
 {
 	oidmap_iter_init(map, iter);
-	return oidmap_iter_next(iter);
+	/* TODO: this API could be reworked to do compile-time type checks */
+	return (void *)oidmap_iter_next(iter);
 }
 
 #endif
diff -pruN 1.2.1+git2.18.0-1/git/oidset.c 1.2.3+git2.25.1-1/git/oidset.c
--- 1.2.1+git2.18.0-1/git/oidset.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/oidset.c	2020-02-17 04:47:35.000000000 +0000
@@ -1,40 +1,72 @@
 #include "cache.h"
 #include "oidset.h"
 
+void oidset_init(struct oidset *set, size_t initial_size)
+{
+	memset(&set->set, 0, sizeof(set->set));
+	if (initial_size)
+		kh_resize_oid_set(&set->set, initial_size);
+}
+
 int oidset_contains(const struct oidset *set, const struct object_id *oid)
 {
-	if (!set->map.map.tablesize)
-		return 0;
-	return !!oidmap_get(&set->map, oid);
+	khiter_t pos = kh_get_oid_set(&set->set, *oid);
+	return pos != kh_end(&set->set);
 }
 
 int oidset_insert(struct oidset *set, const struct object_id *oid)
 {
-	struct oidmap_entry *entry;
-
-	if (!set->map.map.tablesize)
-		oidmap_init(&set->map, 0);
-	else if (oidset_contains(set, oid))
-		return 1;
-
-	entry = xmalloc(sizeof(*entry));
-	oidcpy(&entry->oid, oid);
-
-	oidmap_put(&set->map, entry);
-	return 0;
+	int added;
+	kh_put_oid_set(&set->set, *oid, &added);
+	return !added;
 }
 
 int oidset_remove(struct oidset *set, const struct object_id *oid)
 {
-	struct oidmap_entry *entry;
-
-	entry = oidmap_remove(&set->map, oid);
-	free(entry);
-
-	return (entry != NULL);
+	khiter_t pos = kh_get_oid_set(&set->set, *oid);
+	if (pos == kh_end(&set->set))
+		return 0;
+	kh_del_oid_set(&set->set, pos);
+	return 1;
 }
 
 void oidset_clear(struct oidset *set)
 {
-	oidmap_free(&set->map, 1);
+	kh_release_oid_set(&set->set);
+	oidset_init(set, 0);
+}
+
+void oidset_parse_file(struct oidset *set, const char *path)
+{
+	FILE *fp;
+	struct strbuf sb = STRBUF_INIT;
+	struct object_id oid;
+
+	fp = fopen(path, "r");
+	if (!fp)
+		die("could not open object name list: %s", path);
+	while (!strbuf_getline(&sb, fp)) {
+		const char *p;
+		const char *name;
+
+		/*
+		 * Allow trailing comments, leading whitespace
+		 * (including before commits), and empty or whitespace
+		 * only lines.
+		 */
+		name = strchr(sb.buf, '#');
+		if (name)
+			strbuf_setlen(&sb, name - sb.buf);
+		strbuf_trim(&sb);
+		if (!sb.len)
+			continue;
+
+		if (parse_oid_hex(sb.buf, &oid, &p) || *p != '\0')
+			die("invalid object name: %s", sb.buf);
+		oidset_insert(set, &oid);
+	}
+	if (ferror(fp))
+		die_errno("Could not read '%s'", path);
+	fclose(fp);
+	strbuf_release(&sb);
 }
diff -pruN 1.2.1+git2.18.0-1/git/oidset.h 1.2.3+git2.25.1-1/git/oidset.h
--- 1.2.1+git2.18.0-1/git/oidset.h	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/oidset.h	2020-02-17 04:47:35.000000000 +0000
@@ -1,7 +1,8 @@
 #ifndef OIDSET_H
 #define OIDSET_H
 
-#include "oidmap.h"
+#include "hashmap.h"
+#include "khash.h"
 
 /**
  * This API is similar to sha1-array, in that it maintains a set of object ids
@@ -19,16 +20,19 @@
  * A single oidset; should be zero-initialized (or use OIDSET_INIT).
  */
 struct oidset {
-	struct oidmap map;
+	kh_oid_set_t set;
 };
 
-#define OIDSET_INIT { OIDMAP_INIT }
+#define OIDSET_INIT { { 0 } }
 
 
-static inline void oidset_init(struct oidset *set, size_t initial_size)
-{
-	oidmap_init(&set->map, initial_size);
-}
+/**
+ * Initialize the oidset structure `set`.
+ *
+ * If `initial_size` is bigger than 0 then preallocate to allow inserting
+ * the specified number of elements without further allocations.
+ */
+void oidset_init(struct oidset *set, size_t initial_size);
 
 /**
  * Returns true iff `set` contains `oid`.
@@ -57,20 +61,33 @@ int oidset_remove(struct oidset *set, co
  */
 void oidset_clear(struct oidset *set);
 
+/**
+ * Add the contents of the file 'path' to an initialized oidset.  Each line is
+ * an unabbreviated object name.  Comments begin with '#', and trailing comments
+ * are allowed.  Leading whitespace and empty or white-space only lines are
+ * ignored.
+ */
+void oidset_parse_file(struct oidset *set, const char *path);
+
 struct oidset_iter {
-	struct oidmap_iter m_iter;
+	kh_oid_set_t *set;
+	khiter_t iter;
 };
 
 static inline void oidset_iter_init(struct oidset *set,
 				    struct oidset_iter *iter)
 {
-	oidmap_iter_init(&set->map, &iter->m_iter);
+	iter->set = &set->set;
+	iter->iter = kh_begin(iter->set);
 }
 
 static inline struct object_id *oidset_iter_next(struct oidset_iter *iter)
 {
-	struct oidmap_entry *e = oidmap_iter_next(&iter->m_iter);
-	return e ? &e->oid : NULL;
+	for (; iter->iter != kh_end(iter->set); iter->iter++) {
+		if (kh_exist(iter->set, iter->iter))
+			return &kh_key(iter->set, iter->iter++);
+	}
+	return NULL;
 }
 
 static inline struct object_id *oidset_iter_first(struct oidset *set,
diff -pruN 1.2.1+git2.18.0-1/git/pack-bitmap.c 1.2.3+git2.25.1-1/git/pack-bitmap.c
--- 1.2.1+git2.18.0-1/git/pack-bitmap.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/pack-bitmap.c	2020-02-17 04:47:35.000000000 +0000
@@ -18,21 +18,21 @@
  * commit.
  */
 struct stored_bitmap {
-	unsigned char sha1[20];
+	struct object_id oid;
 	struct ewah_bitmap *root;
 	struct stored_bitmap *xor;
 	int flags;
 };
 
 /*
- * The currently active bitmap index. By design, repositories only have
+ * The active bitmap index for a repository. By design, repositories only have
  * a single bitmap index available (the index for the biggest packfile in
  * the repository), since bitmap indexes need full closure.
  *
  * If there is more than one bitmap index available (e.g. because of alternates),
  * the active bitmap index is the largest one.
  */
-static struct bitmap_index {
+struct bitmap_index {
 	/* Packfile to which this bitmap index belongs to */
 	struct packed_git *pack;
 
@@ -60,13 +60,13 @@ static struct bitmap_index {
 	struct ewah_bitmap *blobs;
 	struct ewah_bitmap *tags;
 
-	/* Map from SHA1 -> `stored_bitmap` for all the bitmapped commits */
-	khash_sha1 *bitmaps;
+	/* Map from object ID -> `stored_bitmap` for all the bitmapped commits */
+	kh_oid_map_t *bitmaps;
 
 	/* Number of bitmapped commits */
 	uint32_t entry_count;
 
-	/* Name-hash cache (or NULL if not present). */
+	/* If not NULL, this is a name-hash cache pointing into map. */
 	uint32_t *hashes;
 
 	/*
@@ -80,18 +80,18 @@ static struct bitmap_index {
 		struct object **objects;
 		uint32_t *hashes;
 		uint32_t count, alloc;
-		khash_sha1_pos *positions;
+		kh_oid_pos_t *positions;
 	} ext_index;
 
 	/* Bitmap result of the last performed walk */
 	struct bitmap *result;
 
+	/* "have" bitmap from the last performed walk */
+	struct bitmap *haves;
+
 	/* Version of the bitmap index */
 	unsigned int version;
-
-	unsigned loaded : 1;
-
-} bitmap_git;
+};
 
 static struct ewah_bitmap *lookup_stored_bitmap(struct stored_bitmap *st)
 {
@@ -138,7 +138,7 @@ static int load_bitmap_header(struct bit
 {
 	struct bitmap_disk_header *header = (void *)index->map;
 
-	if (index->map_size < sizeof(*header) + 20)
+	if (index->map_size < sizeof(*header) + the_hash_algo->rawsz)
 		return error("Corrupted bitmap index (missing header data)");
 
 	if (memcmp(header->magic, BITMAP_IDX_SIGNATURE, sizeof(BITMAP_IDX_SIGNATURE)) != 0)
@@ -157,19 +157,19 @@ static int load_bitmap_header(struct bit
 				"(Git requires BITMAP_OPT_FULL_DAG)");
 
 		if (flags & BITMAP_OPT_HASH_CACHE) {
-			unsigned char *end = index->map + index->map_size - 20;
+			unsigned char *end = index->map + index->map_size - the_hash_algo->rawsz;
 			index->hashes = ((uint32_t *)end) - index->pack->num_objects;
 		}
 	}
 
 	index->entry_count = ntohl(header->entry_count);
-	index->map_pos += sizeof(*header);
+	index->map_pos += sizeof(*header) - GIT_MAX_RAWSZ + the_hash_algo->rawsz;
 	return 0;
 }
 
 static struct stored_bitmap *store_bitmap(struct bitmap_index *index,
 					  struct ewah_bitmap *root,
-					  const unsigned char *sha1,
+					  const unsigned char *hash,
 					  struct stored_bitmap *xor_with,
 					  int flags)
 {
@@ -181,15 +181,15 @@ static struct stored_bitmap *store_bitma
 	stored->root = root;
 	stored->xor = xor_with;
 	stored->flags = flags;
-	hashcpy(stored->sha1, sha1);
+	oidread(&stored->oid, hash);
 
-	hash_pos = kh_put_sha1(index->bitmaps, stored->sha1, &ret);
+	hash_pos = kh_put_oid_map(index->bitmaps, stored->oid, &ret);
 
 	/* a 0 return code means the insertion succeeded with no changes,
 	 * because the SHA1 already existed on the map. this is bad, there
 	 * shouldn't be duplicated commits in the index */
 	if (ret == 0) {
-		error("Duplicate entry in bitmap index: %s", sha1_to_hex(sha1));
+		error("Duplicate entry in bitmap index: %s", hash_to_hex(hash));
 		return NULL;
 	}
 
@@ -259,7 +259,7 @@ static char *pack_bitmap_filename(struct
 	return xstrfmt("%.*s.bitmap", (int)len, p->pack_name);
 }
 
-static int open_pack_bitmap_1(struct packed_git *packfile)
+static int open_pack_bitmap_1(struct bitmap_index *bitmap_git, struct packed_git *packfile)
 {
 	int fd;
 	struct stat st;
@@ -280,123 +280,129 @@ static int open_pack_bitmap_1(struct pac
 		return -1;
 	}
 
-	if (bitmap_git.pack) {
+	if (bitmap_git->pack) {
 		warning("ignoring extra bitmap file: %s", packfile->pack_name);
 		close(fd);
 		return -1;
 	}
 
-	bitmap_git.pack = packfile;
-	bitmap_git.map_size = xsize_t(st.st_size);
-	bitmap_git.map = xmmap(NULL, bitmap_git.map_size, PROT_READ, MAP_PRIVATE, fd, 0);
-	bitmap_git.map_pos = 0;
+	bitmap_git->pack = packfile;
+	bitmap_git->map_size = xsize_t(st.st_size);
+	bitmap_git->map = xmmap(NULL, bitmap_git->map_size, PROT_READ, MAP_PRIVATE, fd, 0);
+	bitmap_git->map_pos = 0;
 	close(fd);
 
-	if (load_bitmap_header(&bitmap_git) < 0) {
-		munmap(bitmap_git.map, bitmap_git.map_size);
-		bitmap_git.map = NULL;
-		bitmap_git.map_size = 0;
+	if (load_bitmap_header(bitmap_git) < 0) {
+		munmap(bitmap_git->map, bitmap_git->map_size);
+		bitmap_git->map = NULL;
+		bitmap_git->map_size = 0;
 		return -1;
 	}
 
 	return 0;
 }
 
-static int load_pack_bitmap(void)
+static int load_pack_bitmap(struct bitmap_index *bitmap_git)
 {
-	assert(bitmap_git.map && !bitmap_git.loaded);
+	assert(bitmap_git->map);
 
-	bitmap_git.bitmaps = kh_init_sha1();
-	bitmap_git.ext_index.positions = kh_init_sha1_pos();
-	load_pack_revindex(bitmap_git.pack);
-
-	if (!(bitmap_git.commits = read_bitmap_1(&bitmap_git)) ||
-		!(bitmap_git.trees = read_bitmap_1(&bitmap_git)) ||
-		!(bitmap_git.blobs = read_bitmap_1(&bitmap_git)) ||
-		!(bitmap_git.tags = read_bitmap_1(&bitmap_git)))
+	bitmap_git->bitmaps = kh_init_oid_map();
+	bitmap_git->ext_index.positions = kh_init_oid_pos();
+	if (load_pack_revindex(bitmap_git->pack))
 		goto failed;
 
-	if (load_bitmap_entries_v1(&bitmap_git) < 0)
+	if (!(bitmap_git->commits = read_bitmap_1(bitmap_git)) ||
+		!(bitmap_git->trees = read_bitmap_1(bitmap_git)) ||
+		!(bitmap_git->blobs = read_bitmap_1(bitmap_git)) ||
+		!(bitmap_git->tags = read_bitmap_1(bitmap_git)))
+		goto failed;
+
+	if (load_bitmap_entries_v1(bitmap_git) < 0)
 		goto failed;
 
-	bitmap_git.loaded = 1;
 	return 0;
 
 failed:
-	munmap(bitmap_git.map, bitmap_git.map_size);
-	bitmap_git.map = NULL;
-	bitmap_git.map_size = 0;
+	munmap(bitmap_git->map, bitmap_git->map_size);
+	bitmap_git->map = NULL;
+	bitmap_git->map_size = 0;
 	return -1;
 }
 
-static int open_pack_bitmap(void)
+static int open_pack_bitmap(struct repository *r,
+			    struct bitmap_index *bitmap_git)
 {
 	struct packed_git *p;
 	int ret = -1;
 
-	assert(!bitmap_git.map && !bitmap_git.loaded);
+	assert(!bitmap_git->map);
 
-	for (p = get_packed_git(the_repository); p; p = p->next) {
-		if (open_pack_bitmap_1(p) == 0)
+	for (p = get_all_packs(r); p; p = p->next) {
+		if (open_pack_bitmap_1(bitmap_git, p) == 0)
 			ret = 0;
 	}
 
 	return ret;
 }
 
-int prepare_bitmap_git(void)
+struct bitmap_index *prepare_bitmap_git(struct repository *r)
 {
-	if (bitmap_git.loaded)
-		return 0;
+	struct bitmap_index *bitmap_git = xcalloc(1, sizeof(*bitmap_git));
 
-	if (!open_pack_bitmap())
-		return load_pack_bitmap();
+	if (!open_pack_bitmap(r, bitmap_git) && !load_pack_bitmap(bitmap_git))
+		return bitmap_git;
 
-	return -1;
+	free_bitmap_index(bitmap_git);
+	return NULL;
 }
 
 struct include_data {
+	struct bitmap_index *bitmap_git;
 	struct bitmap *base;
 	struct bitmap *seen;
 };
 
-static inline int bitmap_position_extended(const unsigned char *sha1)
+static inline int bitmap_position_extended(struct bitmap_index *bitmap_git,
+					   const struct object_id *oid)
 {
-	khash_sha1_pos *positions = bitmap_git.ext_index.positions;
-	khiter_t pos = kh_get_sha1_pos(positions, sha1);
+	kh_oid_pos_t *positions = bitmap_git->ext_index.positions;
+	khiter_t pos = kh_get_oid_pos(positions, *oid);
 
 	if (pos < kh_end(positions)) {
 		int bitmap_pos = kh_value(positions, pos);
-		return bitmap_pos + bitmap_git.pack->num_objects;
+		return bitmap_pos + bitmap_git->pack->num_objects;
 	}
 
 	return -1;
 }
 
-static inline int bitmap_position_packfile(const unsigned char *sha1)
+static inline int bitmap_position_packfile(struct bitmap_index *bitmap_git,
+					   const struct object_id *oid)
 {
-	off_t offset = find_pack_entry_one(sha1, bitmap_git.pack);
+	off_t offset = find_pack_entry_one(oid->hash, bitmap_git->pack);
 	if (!offset)
 		return -1;
 
-	return find_revindex_position(bitmap_git.pack, offset);
+	return find_revindex_position(bitmap_git->pack, offset);
 }
 
-static int bitmap_position(const unsigned char *sha1)
+static int bitmap_position(struct bitmap_index *bitmap_git,
+			   const struct object_id *oid)
 {
-	int pos = bitmap_position_packfile(sha1);
-	return (pos >= 0) ? pos : bitmap_position_extended(sha1);
+	int pos = bitmap_position_packfile(bitmap_git, oid);
+	return (pos >= 0) ? pos : bitmap_position_extended(bitmap_git, oid);
 }
 
-static int ext_index_add_object(struct object *object, const char *name)
+static int ext_index_add_object(struct bitmap_index *bitmap_git,
+				struct object *object, const char *name)
 {
-	struct eindex *eindex = &bitmap_git.ext_index;
+	struct eindex *eindex = &bitmap_git->ext_index;
 
 	khiter_t hash_pos;
 	int hash_ret;
 	int bitmap_pos;
 
-	hash_pos = kh_put_sha1_pos(eindex->positions, object->oid.hash, &hash_ret);
+	hash_pos = kh_put_oid_pos(eindex->positions, object->oid, &hash_ret);
 	if (hash_ret > 0) {
 		if (eindex->count >= eindex->alloc) {
 			eindex->alloc = (eindex->alloc + 16) * 3 / 2;
@@ -413,28 +419,35 @@ static int ext_index_add_object(struct o
 		bitmap_pos = kh_value(eindex->positions, hash_pos);
 	}
 
-	return bitmap_pos + bitmap_git.pack->num_objects;
+	return bitmap_pos + bitmap_git->pack->num_objects;
 }
 
-static void show_object(struct object *object, const char *name, void *data)
+struct bitmap_show_data {
+	struct bitmap_index *bitmap_git;
+	struct bitmap *base;
+};
+
+static void show_object(struct object *object, const char *name, void *data_)
 {
-	struct bitmap *base = data;
+	struct bitmap_show_data *data = data_;
 	int bitmap_pos;
 
-	bitmap_pos = bitmap_position(object->oid.hash);
+	bitmap_pos = bitmap_position(data->bitmap_git, &object->oid);
 
 	if (bitmap_pos < 0)
-		bitmap_pos = ext_index_add_object(object, name);
+		bitmap_pos = ext_index_add_object(data->bitmap_git, object,
+						  name);
 
-	bitmap_set(base, bitmap_pos);
+	bitmap_set(data->base, bitmap_pos);
 }
 
 static void show_commit(struct commit *commit, void *data)
 {
 }
 
-static int add_to_include_set(struct include_data *data,
-			      const unsigned char *sha1,
+static int add_to_include_set(struct bitmap_index *bitmap_git,
+			      struct include_data *data,
+			      const struct object_id *oid,
 			      int bitmap_pos)
 {
 	khiter_t hash_pos;
@@ -445,9 +458,9 @@ static int add_to_include_set(struct inc
 	if (bitmap_get(data->base, bitmap_pos))
 		return 0;
 
-	hash_pos = kh_get_sha1(bitmap_git.bitmaps, sha1);
-	if (hash_pos < kh_end(bitmap_git.bitmaps)) {
-		struct stored_bitmap *st = kh_value(bitmap_git.bitmaps, hash_pos);
+	hash_pos = kh_get_oid_map(bitmap_git->bitmaps, *oid);
+	if (hash_pos < kh_end(bitmap_git->bitmaps)) {
+		struct stored_bitmap *st = kh_value(bitmap_git->bitmaps, hash_pos);
 		bitmap_or_ewah(data->base, lookup_stored_bitmap(st));
 		return 0;
 	}
@@ -461,11 +474,14 @@ static int should_include(struct commit
 	struct include_data *data = _data;
 	int bitmap_pos;
 
-	bitmap_pos = bitmap_position(commit->object.oid.hash);
+	bitmap_pos = bitmap_position(data->bitmap_git, &commit->object.oid);
 	if (bitmap_pos < 0)
-		bitmap_pos = ext_index_add_object((struct object *)commit, NULL);
+		bitmap_pos = ext_index_add_object(data->bitmap_git,
+						  (struct object *)commit,
+						  NULL);
 
-	if (!add_to_include_set(data, commit->object.oid.hash, bitmap_pos)) {
+	if (!add_to_include_set(data->bitmap_git, data, &commit->object.oid,
+				bitmap_pos)) {
 		struct commit_list *parent = commit->parents;
 
 		while (parent) {
@@ -479,7 +495,8 @@ static int should_include(struct commit
 	return 1;
 }
 
-static struct bitmap *find_objects(struct rev_info *revs,
+static struct bitmap *find_objects(struct bitmap_index *bitmap_git,
+				   struct rev_info *revs,
 				   struct object_list *roots,
 				   struct bitmap *seen)
 {
@@ -501,10 +518,10 @@ static struct bitmap *find_objects(struc
 		roots = roots->next;
 
 		if (object->type == OBJ_COMMIT) {
-			khiter_t pos = kh_get_sha1(bitmap_git.bitmaps, object->oid.hash);
+			khiter_t pos = kh_get_oid_map(bitmap_git->bitmaps, object->oid);
 
-			if (pos < kh_end(bitmap_git.bitmaps)) {
-				struct stored_bitmap *st = kh_value(bitmap_git.bitmaps, pos);
+			if (pos < kh_end(bitmap_git->bitmaps)) {
+				struct stored_bitmap *st = kh_value(bitmap_git->bitmaps, pos);
 				struct ewah_bitmap *or_with = lookup_stored_bitmap(st);
 
 				if (base == NULL)
@@ -543,7 +560,7 @@ static struct bitmap *find_objects(struc
 		int pos;
 
 		roots = roots->next;
-		pos = bitmap_position(object->oid.hash);
+		pos = bitmap_position(bitmap_git, &object->oid);
 
 		if (pos < 0 || base == NULL || !bitmap_get(base, pos)) {
 			object->flags &= ~UNINTERESTING;
@@ -556,10 +573,12 @@ static struct bitmap *find_objects(struc
 
 	if (needs_walk) {
 		struct include_data incdata;
+		struct bitmap_show_data show_data;
 
 		if (base == NULL)
 			base = bitmap_new();
 
+		incdata.bitmap_git = bitmap_git;
 		incdata.base = base;
 		incdata.seen = seen;
 
@@ -569,22 +588,27 @@ static struct bitmap *find_objects(struc
 		if (prepare_revision_walk(revs))
 			die("revision walk setup failed");
 
-		traverse_commit_list(revs, show_commit, show_object, base);
+		show_data.bitmap_git = bitmap_git;
+		show_data.base = base;
+
+		traverse_commit_list(revs, show_commit, show_object,
+				     &show_data);
 	}
 
 	return base;
 }
 
-static void show_extended_objects(struct bitmap *objects,
+static void show_extended_objects(struct bitmap_index *bitmap_git,
 				  show_reachable_fn show_reach)
 {
-	struct eindex *eindex = &bitmap_git.ext_index;
+	struct bitmap *objects = bitmap_git->result;
+	struct eindex *eindex = &bitmap_git->ext_index;
 	uint32_t i;
 
 	for (i = 0; i < eindex->count; ++i) {
 		struct object *obj;
 
-		if (!bitmap_get(objects, bitmap_git.pack->num_objects + i))
+		if (!bitmap_get(objects, bitmap_git->pack->num_objects + i))
 			continue;
 
 		obj = eindex->objects[i];
@@ -593,7 +617,7 @@ static void show_extended_objects(struct
 }
 
 static void show_objects_for_type(
-	struct bitmap *objects,
+	struct bitmap_index *bitmap_git,
 	struct ewah_bitmap *type_filter,
 	enum object_type object_type,
 	show_reachable_fn show_reach)
@@ -604,7 +628,9 @@ static void show_objects_for_type(
 	struct ewah_iterator it;
 	eword_t filter;
 
-	if (bitmap_git.reuse_objects == bitmap_git.pack->num_objects)
+	struct bitmap *objects = bitmap_git->result;
+
+	if (bitmap_git->reuse_objects == bitmap_git->pack->num_objects)
 		return;
 
 	ewah_iterator_init(&it, type_filter);
@@ -622,16 +648,16 @@ static void show_objects_for_type(
 
 			offset += ewah_bit_ctz64(word >> offset);
 
-			if (pos + offset < bitmap_git.reuse_objects)
+			if (pos + offset < bitmap_git->reuse_objects)
 				continue;
 
-			entry = &bitmap_git.pack->revindex[pos + offset];
-			nth_packed_object_oid(&oid, bitmap_git.pack, entry->nr);
+			entry = &bitmap_git->pack->revindex[pos + offset];
+			nth_packed_object_oid(&oid, bitmap_git->pack, entry->nr);
 
-			if (bitmap_git.hashes)
-				hash = get_be32(bitmap_git.hashes + entry->nr);
+			if (bitmap_git->hashes)
+				hash = get_be32(bitmap_git->hashes + entry->nr);
 
-			show_reach(&oid, object_type, 0, hash, bitmap_git.pack, entry->offset);
+			show_reach(&oid, object_type, 0, hash, bitmap_git->pack, entry->offset);
 		}
 
 		pos += BITS_IN_EWORD;
@@ -639,20 +665,21 @@ static void show_objects_for_type(
 	}
 }
 
-static int in_bitmapped_pack(struct object_list *roots)
+static int in_bitmapped_pack(struct bitmap_index *bitmap_git,
+			     struct object_list *roots)
 {
 	while (roots) {
 		struct object *object = roots->item;
 		roots = roots->next;
 
-		if (find_pack_entry_one(object->oid.hash, bitmap_git.pack) > 0)
+		if (find_pack_entry_one(object->oid.hash, bitmap_git->pack) > 0)
 			return 1;
 	}
 
 	return 0;
 }
 
-int prepare_bitmap_walk(struct rev_info *revs)
+struct bitmap_index *prepare_bitmap_walk(struct rev_info *revs)
 {
 	unsigned int i;
 
@@ -662,12 +689,11 @@ int prepare_bitmap_walk(struct rev_info
 	struct bitmap *wants_bitmap = NULL;
 	struct bitmap *haves_bitmap = NULL;
 
-	if (!bitmap_git.loaded) {
-		/* try to open a bitmapped pack, but don't parse it yet
-		 * because we may not need to use it */
-		if (open_pack_bitmap() < 0)
-			return -1;
-	}
+	struct bitmap_index *bitmap_git = xcalloc(1, sizeof(*bitmap_git));
+	/* try to open a bitmapped pack, but don't parse it yet
+	 * because we may not need to use it */
+	if (open_pack_bitmap(revs->repo, bitmap_git) < 0)
+		goto cleanup;
 
 	for (i = 0; i < revs->pending.nr; ++i) {
 		struct object *object = revs->pending.objects[i].item;
@@ -683,9 +709,7 @@ int prepare_bitmap_walk(struct rev_info
 			else
 				object_list_insert(object, &wants);
 
-			if (!tag->tagged)
-				die("bad tag");
-			object = parse_object_or_die(&tag->tagged->oid, NULL);
+			object = parse_object_or_die(get_tagged_oid(tag), NULL);
 		}
 
 		if (object->flags & UNINTERESTING)
@@ -699,26 +723,26 @@ int prepare_bitmap_walk(struct rev_info
 	 * in the packfile that has a bitmap, we don't have anything to
 	 * optimize here
 	 */
-	if (haves && !in_bitmapped_pack(haves))
-		return -1;
+	if (haves && !in_bitmapped_pack(bitmap_git, haves))
+		goto cleanup;
 
 	/* if we don't want anything, we're done here */
 	if (!wants)
-		return -1;
+		goto cleanup;
 
 	/*
 	 * now we're going to use bitmaps, so load the actual bitmap entries
 	 * from disk. this is the point of no return; after this the rev_list
 	 * becomes invalidated and we must perform the revwalk through bitmaps
 	 */
-	if (!bitmap_git.loaded && load_pack_bitmap() < 0)
-		return -1;
+	if (load_pack_bitmap(bitmap_git) < 0)
+		goto cleanup;
 
 	object_array_clear(&revs->pending);
 
 	if (haves) {
 		revs->ignore_missing_links = 1;
-		haves_bitmap = find_objects(revs, haves, NULL);
+		haves_bitmap = find_objects(bitmap_git, revs, haves, NULL);
 		reset_revision_walk();
 		revs->ignore_missing_links = 0;
 
@@ -726,7 +750,7 @@ int prepare_bitmap_walk(struct rev_info
 			BUG("failed to perform bitmap walk");
 	}
 
-	wants_bitmap = find_objects(revs, wants, haves_bitmap);
+	wants_bitmap = find_objects(bitmap_git, revs, wants, haves_bitmap);
 
 	if (!wants_bitmap)
 		BUG("failed to perform bitmap walk");
@@ -734,13 +758,18 @@ int prepare_bitmap_walk(struct rev_info
 	if (haves_bitmap)
 		bitmap_and_not(wants_bitmap, haves_bitmap);
 
-	bitmap_git.result = wants_bitmap;
+	bitmap_git->result = wants_bitmap;
+	bitmap_git->haves = haves_bitmap;
 
-	bitmap_free(haves_bitmap);
-	return 0;
+	return bitmap_git;
+
+cleanup:
+	free_bitmap_index(bitmap_git);
+	return NULL;
 }
 
-int reuse_partial_packfile_from_bitmap(struct packed_git **packfile,
+int reuse_partial_packfile_from_bitmap(struct bitmap_index *bitmap_git,
+				       struct packed_git **packfile,
 				       uint32_t *entries,
 				       off_t *up_to)
 {
@@ -750,7 +779,7 @@ int reuse_partial_packfile_from_bitmap(s
 	 */
 	static const double REUSE_PERCENT = 0.9;
 
-	struct bitmap *result = bitmap_git.result;
+	struct bitmap *result = bitmap_git->result;
 	uint32_t reuse_threshold;
 	uint32_t i, reuse_objects = 0;
 
@@ -770,60 +799,59 @@ int reuse_partial_packfile_from_bitmap(s
 		const unsigned char *sha1;
 		struct revindex_entry *entry;
 
-		entry = &bitmap_git.reverse_index->revindex[reuse_objects];
-		sha1 = nth_packed_object_sha1(bitmap_git.pack, entry->nr);
+		entry = &bitmap_git->reverse_index->revindex[reuse_objects];
+		sha1 = nth_packed_object_sha1(bitmap_git->pack, entry->nr);
 
 		fprintf(stderr, "Failed to reuse at %d (%016llx)\n",
 			reuse_objects, result->words[i]);
-		fprintf(stderr, " %s\n", sha1_to_hex(sha1));
+		fprintf(stderr, " %s\n", hash_to_hex(sha1));
 	}
 #endif
 
 	if (!reuse_objects)
 		return -1;
 
-	if (reuse_objects >= bitmap_git.pack->num_objects) {
-		bitmap_git.reuse_objects = *entries = bitmap_git.pack->num_objects;
+	if (reuse_objects >= bitmap_git->pack->num_objects) {
+		bitmap_git->reuse_objects = *entries = bitmap_git->pack->num_objects;
 		*up_to = -1; /* reuse the full pack */
-		*packfile = bitmap_git.pack;
+		*packfile = bitmap_git->pack;
 		return 0;
 	}
 
-	reuse_threshold = bitmap_popcount(bitmap_git.result) * REUSE_PERCENT;
+	reuse_threshold = bitmap_popcount(bitmap_git->result) * REUSE_PERCENT;
 
 	if (reuse_objects < reuse_threshold)
 		return -1;
 
-	bitmap_git.reuse_objects = *entries = reuse_objects;
-	*up_to = bitmap_git.pack->revindex[reuse_objects].offset;
-	*packfile = bitmap_git.pack;
+	bitmap_git->reuse_objects = *entries = reuse_objects;
+	*up_to = bitmap_git->pack->revindex[reuse_objects].offset;
+	*packfile = bitmap_git->pack;
 
 	return 0;
 }
 
-void traverse_bitmap_commit_list(show_reachable_fn show_reachable)
+void traverse_bitmap_commit_list(struct bitmap_index *bitmap_git,
+				 show_reachable_fn show_reachable)
 {
-	assert(bitmap_git.result);
+	assert(bitmap_git->result);
 
-	show_objects_for_type(bitmap_git.result, bitmap_git.commits,
+	show_objects_for_type(bitmap_git, bitmap_git->commits,
 		OBJ_COMMIT, show_reachable);
-	show_objects_for_type(bitmap_git.result, bitmap_git.trees,
+	show_objects_for_type(bitmap_git, bitmap_git->trees,
 		OBJ_TREE, show_reachable);
-	show_objects_for_type(bitmap_git.result, bitmap_git.blobs,
+	show_objects_for_type(bitmap_git, bitmap_git->blobs,
 		OBJ_BLOB, show_reachable);
-	show_objects_for_type(bitmap_git.result, bitmap_git.tags,
+	show_objects_for_type(bitmap_git, bitmap_git->tags,
 		OBJ_TAG, show_reachable);
 
-	show_extended_objects(bitmap_git.result, show_reachable);
-
-	bitmap_free(bitmap_git.result);
-	bitmap_git.result = NULL;
+	show_extended_objects(bitmap_git, show_reachable);
 }
 
-static uint32_t count_object_type(struct bitmap *objects,
+static uint32_t count_object_type(struct bitmap_index *bitmap_git,
 				  enum object_type type)
 {
-	struct eindex *eindex = &bitmap_git.ext_index;
+	struct bitmap *objects = bitmap_git->result;
+	struct eindex *eindex = &bitmap_git->ext_index;
 
 	uint32_t i = 0, count = 0;
 	struct ewah_iterator it;
@@ -831,19 +859,19 @@ static uint32_t count_object_type(struct
 
 	switch (type) {
 	case OBJ_COMMIT:
-		ewah_iterator_init(&it, bitmap_git.commits);
+		ewah_iterator_init(&it, bitmap_git->commits);
 		break;
 
 	case OBJ_TREE:
-		ewah_iterator_init(&it, bitmap_git.trees);
+		ewah_iterator_init(&it, bitmap_git->trees);
 		break;
 
 	case OBJ_BLOB:
-		ewah_iterator_init(&it, bitmap_git.blobs);
+		ewah_iterator_init(&it, bitmap_git->blobs);
 		break;
 
 	case OBJ_TAG:
-		ewah_iterator_init(&it, bitmap_git.tags);
+		ewah_iterator_init(&it, bitmap_git->tags);
 		break;
 
 	default:
@@ -857,32 +885,34 @@ static uint32_t count_object_type(struct
 
 	for (i = 0; i < eindex->count; ++i) {
 		if (eindex->objects[i]->type == type &&
-			bitmap_get(objects, bitmap_git.pack->num_objects + i))
+			bitmap_get(objects, bitmap_git->pack->num_objects + i))
 			count++;
 	}
 
 	return count;
 }
 
-void count_bitmap_commit_list(uint32_t *commits, uint32_t *trees,
+void count_bitmap_commit_list(struct bitmap_index *bitmap_git,
+			      uint32_t *commits, uint32_t *trees,
 			      uint32_t *blobs, uint32_t *tags)
 {
-	assert(bitmap_git.result);
+	assert(bitmap_git->result);
 
 	if (commits)
-		*commits = count_object_type(bitmap_git.result, OBJ_COMMIT);
+		*commits = count_object_type(bitmap_git, OBJ_COMMIT);
 
 	if (trees)
-		*trees = count_object_type(bitmap_git.result, OBJ_TREE);
+		*trees = count_object_type(bitmap_git, OBJ_TREE);
 
 	if (blobs)
-		*blobs = count_object_type(bitmap_git.result, OBJ_BLOB);
+		*blobs = count_object_type(bitmap_git, OBJ_BLOB);
 
 	if (tags)
-		*tags = count_object_type(bitmap_git.result, OBJ_TAG);
+		*tags = count_object_type(bitmap_git, OBJ_TAG);
 }
 
 struct bitmap_test_data {
+	struct bitmap_index *bitmap_git;
 	struct bitmap *base;
 	struct progress *prg;
 	size_t seen;
@@ -894,7 +924,7 @@ static void test_show_object(struct obje
 	struct bitmap_test_data *tdata = data;
 	int bitmap_pos;
 
-	bitmap_pos = bitmap_position(object->oid.hash);
+	bitmap_pos = bitmap_position(tdata->bitmap_git, &object->oid);
 	if (bitmap_pos < 0)
 		die("Object not in bitmap: %s\n", oid_to_hex(&object->oid));
 
@@ -907,7 +937,8 @@ static void test_show_commit(struct comm
 	struct bitmap_test_data *tdata = data;
 	int bitmap_pos;
 
-	bitmap_pos = bitmap_position(commit->object.oid.hash);
+	bitmap_pos = bitmap_position(tdata->bitmap_git,
+				     &commit->object.oid);
 	if (bitmap_pos < 0)
 		die("Object not in bitmap: %s\n", oid_to_hex(&commit->object.oid));
 
@@ -922,21 +953,22 @@ void test_bitmap_walk(struct rev_info *r
 	khiter_t pos;
 	size_t result_popcnt;
 	struct bitmap_test_data tdata;
+	struct bitmap_index *bitmap_git;
 
-	if (prepare_bitmap_git())
+	if (!(bitmap_git = prepare_bitmap_git(revs->repo)))
 		die("failed to load bitmap indexes");
 
 	if (revs->pending.nr != 1)
 		die("you must specify exactly one commit to test");
 
 	fprintf(stderr, "Bitmap v%d test (%d entries loaded)\n",
-		bitmap_git.version, bitmap_git.entry_count);
+		bitmap_git->version, bitmap_git->entry_count);
 
 	root = revs->pending.objects[0].item;
-	pos = kh_get_sha1(bitmap_git.bitmaps, root->oid.hash);
+	pos = kh_get_oid_map(bitmap_git->bitmaps, root->oid);
 
-	if (pos < kh_end(bitmap_git.bitmaps)) {
-		struct stored_bitmap *st = kh_value(bitmap_git.bitmaps, pos);
+	if (pos < kh_end(bitmap_git->bitmaps)) {
+		struct stored_bitmap *st = kh_value(bitmap_git->bitmaps, pos);
 		struct ewah_bitmap *bm = lookup_stored_bitmap(st);
 
 		fprintf(stderr, "Found bitmap for %s. %d bits / %08x checksum\n",
@@ -957,6 +989,7 @@ void test_bitmap_walk(struct rev_info *r
 	if (prepare_revision_walk(revs))
 		die("revision walk setup failed");
 
+	tdata.bitmap_git = bitmap_git;
 	tdata.base = bitmap_new();
 	tdata.prg = start_progress("Verifying bitmap entries", result_popcnt);
 	tdata.seen = 0;
@@ -970,7 +1003,7 @@ void test_bitmap_walk(struct rev_info *r
 	else
 		fprintf(stderr, "Mismatch!\n");
 
-	bitmap_free(result);
+	free_bitmap_index(bitmap_git);
 }
 
 static int rebuild_bitmap(uint32_t *reposition,
@@ -1004,8 +1037,9 @@ static int rebuild_bitmap(uint32_t *repo
 	return 0;
 }
 
-int rebuild_existing_bitmaps(struct packing_data *mapping,
-			     khash_sha1 *reused_bitmaps,
+int rebuild_existing_bitmaps(struct bitmap_index *bitmap_git,
+			     struct packing_data *mapping,
+			     kh_oid_map_t *reused_bitmaps,
 			     int show_progress)
 {
 	uint32_t i, num_objects;
@@ -1017,20 +1051,17 @@ int rebuild_existing_bitmaps(struct pack
 	khiter_t hash_pos;
 	int hash_ret;
 
-	if (prepare_bitmap_git() < 0)
-		return -1;
-
-	num_objects = bitmap_git.pack->num_objects;
+	num_objects = bitmap_git->pack->num_objects;
 	reposition = xcalloc(num_objects, sizeof(uint32_t));
 
 	for (i = 0; i < num_objects; ++i) {
-		const unsigned char *sha1;
+		struct object_id oid;
 		struct revindex_entry *entry;
 		struct object_entry *oe;
 
-		entry = &bitmap_git.pack->revindex[i];
-		sha1 = nth_packed_object_sha1(bitmap_git.pack, entry->nr);
-		oe = packlist_find(mapping, sha1, NULL);
+		entry = &bitmap_git->pack->revindex[i];
+		nth_packed_object_oid(&oid, bitmap_git->pack, entry->nr);
+		oe = packlist_find(mapping, &oid);
 
 		if (oe)
 			reposition[i] = oe_in_pack_pos(mapping, oe) + 1;
@@ -1042,14 +1073,14 @@ int rebuild_existing_bitmaps(struct pack
 	if (show_progress)
 		progress = start_progress("Reusing bitmaps", 0);
 
-	kh_foreach_value(bitmap_git.bitmaps, stored, {
+	kh_foreach_value(bitmap_git->bitmaps, stored, {
 		if (stored->flags & BITMAP_FLAG_REUSE) {
 			if (!rebuild_bitmap(reposition,
 					    lookup_stored_bitmap(stored),
 					    rebuild)) {
-				hash_pos = kh_put_sha1(reused_bitmaps,
-						       stored->sha1,
-						       &hash_ret);
+				hash_pos = kh_put_oid_map(reused_bitmaps,
+							  stored->oid,
+							  &hash_ret);
 				kh_value(reused_bitmaps, hash_pos) =
 					bitmap_to_ewah(rebuild);
 			}
@@ -1064,3 +1095,39 @@ int rebuild_existing_bitmaps(struct pack
 	bitmap_free(rebuild);
 	return 0;
 }
+
+void free_bitmap_index(struct bitmap_index *b)
+{
+	if (!b)
+		return;
+
+	if (b->map)
+		munmap(b->map, b->map_size);
+	ewah_pool_free(b->commits);
+	ewah_pool_free(b->trees);
+	ewah_pool_free(b->blobs);
+	ewah_pool_free(b->tags);
+	kh_destroy_oid_map(b->bitmaps);
+	free(b->ext_index.objects);
+	free(b->ext_index.hashes);
+	bitmap_free(b->result);
+	bitmap_free(b->haves);
+	free(b);
+}
+
+int bitmap_has_oid_in_uninteresting(struct bitmap_index *bitmap_git,
+				    const struct object_id *oid)
+{
+	int pos;
+
+	if (!bitmap_git)
+		return 0; /* no bitmap loaded */
+	if (!bitmap_git->haves)
+		return 0; /* walk had no "haves" */
+
+	pos = bitmap_position_packfile(bitmap_git, oid);
+	if (pos < 0)
+		return 0;
+
+	return bitmap_get(bitmap_git->haves, pos);
+}
diff -pruN 1.2.1+git2.18.0-1/git/pack-bitmap.h 1.2.3+git2.25.1-1/git/pack-bitmap.h
--- 1.2.1+git2.18.0-1/git/pack-bitmap.h	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/pack-bitmap.h	2020-02-17 04:47:35.000000000 +0000
@@ -5,16 +5,20 @@
 #include "khash.h"
 #include "pack-objects.h"
 
+struct commit;
+struct repository;
+struct rev_info;
+
+static const char BITMAP_IDX_SIGNATURE[] = {'B', 'I', 'T', 'M'};
+
 struct bitmap_disk_header {
-	char magic[4];
+	char magic[ARRAY_SIZE(BITMAP_IDX_SIGNATURE)];
 	uint16_t version;
 	uint16_t options;
 	uint32_t entry_count;
-	unsigned char checksum[20];
+	unsigned char checksum[GIT_MAX_RAWSZ];
 };
 
-static const char BITMAP_IDX_SIGNATURE[] = {'B', 'I', 'T', 'M'};
-
 #define NEEDS_BITMAP (1u<<22)
 
 enum pack_bitmap_opts {
@@ -34,13 +38,28 @@ typedef int (*show_reachable_fn)(
 	struct packed_git *found_pack,
 	off_t found_offset);
 
-int prepare_bitmap_git(void);
-void count_bitmap_commit_list(uint32_t *commits, uint32_t *trees, uint32_t *blobs, uint32_t *tags);
-void traverse_bitmap_commit_list(show_reachable_fn show_reachable);
+struct bitmap_index;
+
+struct bitmap_index *prepare_bitmap_git(struct repository *r);
+void count_bitmap_commit_list(struct bitmap_index *, uint32_t *commits,
+			      uint32_t *trees, uint32_t *blobs, uint32_t *tags);
+void traverse_bitmap_commit_list(struct bitmap_index *,
+				 show_reachable_fn show_reachable);
 void test_bitmap_walk(struct rev_info *revs);
-int prepare_bitmap_walk(struct rev_info *revs);
-int reuse_partial_packfile_from_bitmap(struct packed_git **packfile, uint32_t *entries, off_t *up_to);
-int rebuild_existing_bitmaps(struct packing_data *mapping, khash_sha1 *reused_bitmaps, int show_progress);
+struct bitmap_index *prepare_bitmap_walk(struct rev_info *revs);
+int reuse_partial_packfile_from_bitmap(struct bitmap_index *,
+				       struct packed_git **packfile,
+				       uint32_t *entries, off_t *up_to);
+int rebuild_existing_bitmaps(struct bitmap_index *, struct packing_data *mapping,
+			     kh_oid_map_t *reused_bitmaps, int show_progress);
+void free_bitmap_index(struct bitmap_index *);
+
+/*
+ * After a traversal has been performed by prepare_bitmap_walk(), this can be
+ * queried to see if a particular object was reachable from any of the
+ * objects flagged as UNINTERESTING.
+ */
+int bitmap_has_oid_in_uninteresting(struct bitmap_index *, const struct object_id *oid);
 
 void bitmap_writer_show_progress(int show);
 void bitmap_writer_set_checksum(unsigned char *sha1);
diff -pruN 1.2.1+git2.18.0-1/git/pack-bitmap-write.c 1.2.3+git2.25.1-1/git/pack-bitmap-write.c
--- 1.2.1+git2.18.0-1/git/pack-bitmap-write.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/pack-bitmap-write.c	2020-02-17 04:47:35.000000000 +0000
@@ -1,4 +1,5 @@
 #include "cache.h"
+#include "object-store.h"
 #include "commit.h"
 #include "tag.h"
 #include "diff.h"
@@ -10,6 +11,7 @@
 #include "pack-bitmap.h"
 #include "sha1-lookup.h"
 #include "pack-objects.h"
+#include "commit-reach.h"
 
 struct bitmapped_commit {
 	struct commit *commit;
@@ -26,8 +28,8 @@ struct bitmap_writer {
 	struct ewah_bitmap *blobs;
 	struct ewah_bitmap *tags;
 
-	khash_sha1 *bitmaps;
-	khash_sha1 *reused;
+	kh_oid_map_t *bitmaps;
+	kh_oid_map_t *reused;
 	struct packing_data *to_pack;
 
 	struct bitmapped_commit *selected;
@@ -35,7 +37,7 @@ struct bitmap_writer {
 
 	struct progress *progress;
 	int show_progress;
-	unsigned char pack_checksum[20];
+	unsigned char pack_checksum[GIT_MAX_RAWSZ];
 };
 
 static struct bitmap_writer writer;
@@ -75,7 +77,7 @@ void bitmap_writer_build_type_index(stru
 			break;
 
 		default:
-			real_type = oid_object_info(the_repository,
+			real_type = oid_object_info(to_pack->repo,
 						    &entry->idx.oid, NULL);
 			break;
 		}
@@ -140,13 +142,13 @@ static inline void reset_all_seen(void)
 	seen_objects_nr = 0;
 }
 
-static uint32_t find_object_pos(const unsigned char *sha1)
+static uint32_t find_object_pos(const struct object_id *oid)
 {
-	struct object_entry *entry = packlist_find(writer.to_pack, sha1, NULL);
+	struct object_entry *entry = packlist_find(writer.to_pack, oid);
 
 	if (!entry) {
 		die("Failed to write bitmap index. Packfile doesn't have full closure "
-			"(object %s is missing)", sha1_to_hex(sha1));
+			"(object %s is missing)", oid_to_hex(oid));
 	}
 
 	return oe_in_pack_pos(writer.to_pack, entry);
@@ -155,7 +157,7 @@ static uint32_t find_object_pos(const un
 static void show_object(struct object *object, const char *name, void *data)
 {
 	struct bitmap *base = data;
-	bitmap_set(base, find_object_pos(object->oid.hash));
+	bitmap_set(base, find_object_pos(&object->oid));
 	mark_as_seen(object);
 }
 
@@ -168,12 +170,12 @@ static int
 add_to_include_set(struct bitmap *base, struct commit *commit)
 {
 	khiter_t hash_pos;
-	uint32_t bitmap_pos = find_object_pos(commit->object.oid.hash);
+	uint32_t bitmap_pos = find_object_pos(&commit->object.oid);
 
 	if (bitmap_get(base, bitmap_pos))
 		return 0;
 
-	hash_pos = kh_get_sha1(writer.bitmaps, commit->object.oid.hash);
+	hash_pos = kh_get_oid_map(writer.bitmaps, commit->object.oid);
 	if (hash_pos < kh_end(writer.bitmaps)) {
 		struct bitmapped_commit *bc = kh_value(writer.bitmaps, hash_pos);
 		bitmap_or_ewah(base, bc->bitmap);
@@ -254,13 +256,13 @@ void bitmap_writer_build(struct packing_
 	struct bitmap *base = bitmap_new();
 	struct rev_info revs;
 
-	writer.bitmaps = kh_init_sha1();
+	writer.bitmaps = kh_init_oid_map();
 	writer.to_pack = to_pack;
 
 	if (writer.show_progress)
 		writer.progress = start_progress("Building bitmaps", writer.selected_nr);
 
-	init_revisions(&revs, NULL);
+	repo_init_revisions(to_pack->repo, &revs, NULL);
 	revs.tag_objects = 1;
 	revs.tree_objects = 1;
 	revs.blob_objects = 1;
@@ -309,7 +311,7 @@ void bitmap_writer_build(struct packing_
 		if (i >= reuse_after)
 			stored->flags |= BITMAP_FLAG_REUSE;
 
-		hash_pos = kh_put_sha1(writer.bitmaps, object->oid.hash, &hash_ret);
+		hash_pos = kh_put_oid_map(writer.bitmaps, object->oid, &hash_ret);
 		if (hash_ret == 0)
 			die("Duplicate entry when writing index: %s",
 			    oid_to_hex(&object->oid));
@@ -360,21 +362,27 @@ static int date_compare(const void *_a,
 
 void bitmap_writer_reuse_bitmaps(struct packing_data *to_pack)
 {
-	if (prepare_bitmap_git() < 0)
+	struct bitmap_index *bitmap_git;
+	if (!(bitmap_git = prepare_bitmap_git(to_pack->repo)))
 		return;
 
-	writer.reused = kh_init_sha1();
-	rebuild_existing_bitmaps(to_pack, writer.reused, writer.show_progress);
+	writer.reused = kh_init_oid_map();
+	rebuild_existing_bitmaps(bitmap_git, to_pack, writer.reused,
+				 writer.show_progress);
+	/*
+	 * NEEDSWORK: rebuild_existing_bitmaps() makes writer.reused reference
+	 * some bitmaps in bitmap_git, so we can't free the latter.
+	 */
 }
 
-static struct ewah_bitmap *find_reused_bitmap(const unsigned char *sha1)
+static struct ewah_bitmap *find_reused_bitmap(const struct object_id *oid)
 {
 	khiter_t hash_pos;
 
 	if (!writer.reused)
 		return NULL;
 
-	hash_pos = kh_get_sha1(writer.reused, sha1);
+	hash_pos = kh_get_oid_map(writer.reused, *oid);
 	if (hash_pos >= kh_end(writer.reused))
 		return NULL;
 
@@ -414,14 +422,14 @@ void bitmap_writer_select_commits(struct
 
 		if (next == 0) {
 			chosen = indexed_commits[i];
-			reused_bitmap = find_reused_bitmap(chosen->object.oid.hash);
+			reused_bitmap = find_reused_bitmap(&chosen->object.oid);
 		} else {
 			chosen = indexed_commits[i + next];
 
 			for (j = 0; j <= next; ++j) {
 				struct commit *cm = indexed_commits[i + j];
 
-				reused_bitmap = find_reused_bitmap(cm->object.oid.hash);
+				reused_bitmap = find_reused_bitmap(&cm->object.oid);
 				if (reused_bitmap || (cm->object.flags & NEEDS_BITMAP) != 0) {
 					chosen = cm;
 					break;
@@ -527,7 +535,7 @@ void bitmap_writer_finish(struct pack_id
 	header.entry_count = htonl(writer.selected_nr);
 	hashcpy(header.checksum, writer.pack_checksum);
 
-	hashwrite(f, &header, sizeof(header));
+	hashwrite(f, &header, sizeof(header) - GIT_MAX_RAWSZ + the_hash_algo->rawsz);
 	dump_bitmap(f, writer.commits);
 	dump_bitmap(f, writer.trees);
 	dump_bitmap(f, writer.blobs);
diff -pruN 1.2.1+git2.18.0-1/git/pack-check.c 1.2.3+git2.25.1-1/git/pack-check.c
--- 1.2.1+git2.18.0-1/git/pack-check.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/pack-check.c	2020-02-17 04:47:35.000000000 +0000
@@ -48,7 +48,8 @@ int check_pack_crc(struct packed_git *p,
 	return data_crc != ntohl(*index_crc);
 }
 
-static int verify_packfile(struct packed_git *p,
+static int verify_packfile(struct repository *r,
+			   struct packed_git *p,
 			   struct pack_window **w_curs,
 			   verify_fn fn,
 			   struct progress *progress, uint32_t base_count)
@@ -79,10 +80,10 @@ static int verify_packfile(struct packed
 	} while (offset < pack_sig_ofs);
 	the_hash_algo->final_fn(hash, &ctx);
 	pack_sig = use_pack(p, w_curs, pack_sig_ofs, NULL);
-	if (hashcmp(hash, pack_sig))
+	if (!hasheq(hash, pack_sig))
 		err = error("%s pack checksum mismatch",
 			    p->pack_name);
-	if (hashcmp(index_base + index_size - the_hash_algo->hexsz, pack_sig))
+	if (!hasheq(index_base + index_size - the_hash_algo->hexsz, pack_sig))
 		err = error("%s pack checksum does not match its index",
 			    p->pack_name);
 	unuse_pack(w_curs);
@@ -135,7 +136,7 @@ static int verify_packfile(struct packed
 			data = NULL;
 			data_valid = 0;
 		} else {
-			data = unpack_entry(the_repository, p, entries[i].offset, &type, &size);
+			data = unpack_entry(r, p, entries[i].offset, &type, &size);
 			data_valid = 1;
 		}
 
@@ -180,13 +181,13 @@ int verify_pack_index(struct packed_git
 	the_hash_algo->init_fn(&ctx);
 	the_hash_algo->update_fn(&ctx, index_base, (unsigned int)(index_size - the_hash_algo->rawsz));
 	the_hash_algo->final_fn(hash, &ctx);
-	if (hashcmp(hash, index_base + index_size - the_hash_algo->rawsz))
+	if (!hasheq(hash, index_base + index_size - the_hash_algo->rawsz))
 		err = error("Packfile index for %s hash mismatch",
 			    p->pack_name);
 	return err;
 }
 
-int verify_pack(struct packed_git *p, verify_fn fn,
+int verify_pack(struct repository *r, struct packed_git *p, verify_fn fn,
 		struct progress *progress, uint32_t base_count)
 {
 	int err = 0;
@@ -196,7 +197,7 @@ int verify_pack(struct packed_git *p, ve
 	if (!p->index_data)
 		return -1;
 
-	err |= verify_packfile(p, &w_curs, fn, progress, base_count);
+	err |= verify_packfile(r, p, &w_curs, fn, progress, base_count);
 	unuse_pack(&w_curs);
 
 	return err;
diff -pruN 1.2.1+git2.18.0-1/git/packfile.c 1.2.3+git2.25.1-1/git/packfile.c
--- 1.2.1+git2.18.0-1/git/packfile.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/packfile.c	2020-02-17 04:47:35.000000000 +0000
@@ -6,7 +6,6 @@
 #include "mergesort.h"
 #include "packfile.h"
 #include "delta.h"
-#include "list.h"
 #include "streaming.h"
 #include "sha1-lookup.h"
 #include "commit.h"
@@ -15,14 +14,17 @@
 #include "tree-walk.h"
 #include "tree.h"
 #include "object-store.h"
+#include "midx.h"
+#include "commit-graph.h"
+#include "promisor-remote.h"
 
 char *odb_pack_name(struct strbuf *buf,
-		    const unsigned char *sha1,
+		    const unsigned char *hash,
 		    const char *ext)
 {
 	strbuf_reset(buf);
 	strbuf_addf(buf, "%s/pack/pack-%s.%s", get_object_directory(),
-		    sha1_to_hex(sha1), ext);
+		    hash_to_hex(hash), ext);
 	return buf->buf;
 }
 
@@ -79,10 +81,8 @@ void pack_report(void)
 static int check_packed_git_idx(const char *path, struct packed_git *p)
 {
 	void *idx_map;
-	struct pack_idx_header *hdr;
 	size_t idx_size;
-	uint32_t version, nr, i, *index;
-	int fd = git_open(path);
+	int fd = git_open(path), ret;
 	struct stat st;
 	const unsigned int hashsz = the_hash_algo->rawsz;
 
@@ -100,16 +100,32 @@ static int check_packed_git_idx(const ch
 	idx_map = xmmap(NULL, idx_size, PROT_READ, MAP_PRIVATE, fd, 0);
 	close(fd);
 
-	hdr = idx_map;
+	ret = load_idx(path, hashsz, idx_map, idx_size, p);
+
+	if (ret)
+		munmap(idx_map, idx_size);
+
+	return ret;
+}
+
+int load_idx(const char *path, const unsigned int hashsz, void *idx_map,
+	     size_t idx_size, struct packed_git *p)
+{
+	struct pack_idx_header *hdr = idx_map;
+	uint32_t version, nr, i, *index;
+
+	if (idx_size < 4 * 256 + hashsz + hashsz)
+		return error("index file %s is too small", path);
+	if (idx_map == NULL)
+		return error("empty data");
+
 	if (hdr->idx_signature == htonl(PACK_IDX_SIGNATURE)) {
 		version = ntohl(hdr->idx_version);
-		if (version < 2 || version > 2) {
-			munmap(idx_map, idx_size);
+		if (version < 2 || version > 2)
 			return error("index file %s is version %"PRIu32
 				     " and is not supported by this binary"
 				     " (try upgrading GIT to a newer version)",
 				     path, version);
-		}
 	} else
 		version = 1;
 
@@ -119,10 +135,8 @@ static int check_packed_git_idx(const ch
 		index += 2;  /* skip index header */
 	for (i = 0; i < 256; i++) {
 		uint32_t n = ntohl(index[i]);
-		if (n < nr) {
-			munmap(idx_map, idx_size);
+		if (n < nr)
 			return error("non-monotonic index %s", path);
-		}
 		nr = n;
 	}
 
@@ -134,10 +148,8 @@ static int check_packed_git_idx(const ch
 		 *  - hash of the packfile
 		 *  - file checksum
 		 */
-		if (idx_size != 4*256 + nr * (hashsz + 4) + hashsz + hashsz) {
-			munmap(idx_map, idx_size);
+		if (idx_size != 4 * 256 + nr * (hashsz + 4) + hashsz + hashsz)
 			return error("wrong index v1 file size in %s", path);
-		}
 	} else if (version == 2) {
 		/*
 		 * Minimum size:
@@ -156,20 +168,16 @@ static int check_packed_git_idx(const ch
 		unsigned long max_size = min_size;
 		if (nr)
 			max_size += (nr - 1)*8;
-		if (idx_size < min_size || idx_size > max_size) {
-			munmap(idx_map, idx_size);
+		if (idx_size < min_size || idx_size > max_size)
 			return error("wrong index v2 file size in %s", path);
-		}
 		if (idx_size != min_size &&
 		    /*
 		     * make sure we can deal with large pack offsets.
 		     * 31-bit signed offset won't be enough, neither
 		     * 32-bit unsigned one will be.
 		     */
-		    (sizeof(off_t) <= 4)) {
-			munmap(idx_map, idx_size);
+		    (sizeof(off_t) <= 4))
 			return error("pack too large for current definition of off_t in %s", path);
-		}
 	}
 
 	p->index_version = version;
@@ -196,6 +204,23 @@ int open_pack_index(struct packed_git *p
 	return ret;
 }
 
+uint32_t get_pack_fanout(struct packed_git *p, uint32_t value)
+{
+	const uint32_t *level1_ofs = p->index_data;
+
+	if (!level1_ofs) {
+		if (open_pack_index(p))
+			return 0;
+		level1_ofs = p->index_data;
+	}
+
+	if (p->index_version > 1) {
+		level1_ofs += 2;
+	}
+
+	return ntohl(level1_ofs[value]);
+}
+
 static struct packed_git *alloc_packed_git(int extra)
 {
 	struct packed_git *p = xmalloc(st_add(sizeof(*p), extra));
@@ -211,7 +236,7 @@ struct packed_git *parse_pack_index(unsi
 	struct packed_git *p = alloc_packed_git(alloc);
 
 	memcpy(p->pack_name, path, alloc); /* includes NUL */
-	hashcpy(p->sha1, sha1);
+	hashcpy(p->hash, sha1);
 	if (check_packed_git_idx(idx_path, p)) {
 		free(p);
 		return NULL;
@@ -262,13 +287,6 @@ static int unuse_one_window(struct packe
 	return 0;
 }
 
-void release_pack_memory(size_t need)
-{
-	size_t cur = pack_mapped;
-	while (need >= (cur - pack_mapped) && unuse_one_window(NULL))
-		; /* nothing */
-}
-
 void close_pack_windows(struct packed_git *p)
 {
 	while (p->windows) {
@@ -285,7 +303,7 @@ void close_pack_windows(struct packed_gi
 	}
 }
 
-static int close_pack_fd(struct packed_git *p)
+int close_pack_fd(struct packed_git *p)
 {
 	if (p->pack_fd < 0)
 		return 0;
@@ -312,7 +330,7 @@ void close_pack(struct packed_git *p)
 	close_pack_index(p);
 }
 
-void close_all_packs(struct raw_object_store *o)
+void close_object_store(struct raw_object_store *o)
 {
 	struct packed_git *p;
 
@@ -321,6 +339,41 @@ void close_all_packs(struct raw_object_s
 			BUG("want to close pack marked 'do-not-close'");
 		else
 			close_pack(p);
+
+	if (o->multi_pack_index) {
+		close_midx(o->multi_pack_index);
+		o->multi_pack_index = NULL;
+	}
+
+	close_commit_graph(o);
+}
+
+void unlink_pack_path(const char *pack_name, int force_delete)
+{
+	static const char *exts[] = {".pack", ".idx", ".keep", ".bitmap", ".promisor"};
+	int i;
+	struct strbuf buf = STRBUF_INIT;
+	size_t plen;
+
+	strbuf_addstr(&buf, pack_name);
+	strip_suffix_mem(buf.buf, &buf.len, ".pack");
+	plen = buf.len;
+
+	if (!force_delete) {
+		strbuf_addstr(&buf, ".keep");
+		if (!access(buf.buf, F_OK)) {
+			strbuf_release(&buf);
+			return;
+		}
+	}
+
+	for (i = 0; i < ARRAY_SIZE(exts); i++) {
+		strbuf_setlen(&buf, plen);
+		strbuf_addstr(&buf, exts[i]);
+		unlink(buf.buf);
+	}
+
+	strbuf_release(&buf);
 }
 
 /*
@@ -437,6 +490,16 @@ static unsigned int get_max_fd_limit(voi
 #endif
 }
 
+const char *pack_basename(struct packed_git *p)
+{
+	const char *ret = strrchr(p->pack_name, '/');
+	if (ret)
+		ret = ret + 1; /* skip past slash */
+	else
+		ret = p->pack_name; /* we only have a base */
+	return ret;
+}
+
 /*
  * Do not call this directly as this leaks p->pack_fd on error return;
  * call open_packed_git() instead.
@@ -447,12 +510,22 @@ static int open_packed_git_1(struct pack
 	struct pack_header hdr;
 	unsigned char hash[GIT_MAX_RAWSZ];
 	unsigned char *idx_hash;
-	long fd_flag;
 	ssize_t read_result;
 	const unsigned hashsz = the_hash_algo->rawsz;
 
-	if (!p->index_data && open_pack_index(p))
-		return error("packfile %s index unavailable", p->pack_name);
+	if (!p->index_data) {
+		struct multi_pack_index *m;
+		const char *pack_name = pack_basename(p);
+
+		for (m = the_repository->objects->multi_pack_index;
+		     m; m = m->next) {
+			if (midx_contains_pack(m, pack_name))
+				break;
+		}
+
+		if (!m && open_pack_index(p))
+			return error("packfile %s index unavailable", p->pack_name);
+	}
 
 	if (!pack_max_fds) {
 		unsigned int max_fds = get_max_fd_limit();
@@ -480,16 +553,6 @@ static int open_packed_git_1(struct pack
 	} else if (p->pack_size != st.st_size)
 		return error("packfile %s size changed", p->pack_name);
 
-	/* We leave these file descriptors open with sliding mmap;
-	 * there is no point keeping them open across exec(), though.
-	 */
-	fd_flag = fcntl(p->pack_fd, F_GETFD, 0);
-	if (fd_flag < 0)
-		return error("cannot determine file descriptor flags");
-	fd_flag |= FD_CLOEXEC;
-	if (fcntl(p->pack_fd, F_SETFD, fd_flag) == -1)
-		return error("cannot set FD_CLOEXEC");
-
 	/* Verify we recognize this pack file format. */
 	read_result = read_in_full(p->pack_fd, &hdr, sizeof(hdr));
 	if (read_result < 0)
@@ -503,21 +566,24 @@ static int open_packed_git_1(struct pack
 			" supported (try upgrading GIT to a newer version)",
 			p->pack_name, ntohl(hdr.hdr_version));
 
+	/* Skip index checking if in multi-pack-index */
+	if (!p->index_data)
+		return 0;
+
 	/* Verify the pack matches its index. */
 	if (p->num_objects != ntohl(hdr.hdr_entries))
 		return error("packfile %s claims to have %"PRIu32" objects"
 			     " while index indicates %"PRIu32" objects",
 			     p->pack_name, ntohl(hdr.hdr_entries),
 			     p->num_objects);
-	if (lseek(p->pack_fd, p->pack_size - hashsz, SEEK_SET) == -1)
-		return error("end of packfile %s is unavailable", p->pack_name);
-	read_result = read_in_full(p->pack_fd, hash, hashsz);
+	read_result = pread_in_full(p->pack_fd, hash, hashsz,
+					p->pack_size - hashsz);
 	if (read_result < 0)
 		return error_errno("error reading from %s", p->pack_name);
 	if (read_result != hashsz)
 		return error("packfile %s signature is unavailable", p->pack_name);
 	idx_hash = ((unsigned char *)p->index_data) + p->index_size - hashsz * 2;
-	if (hashcmp(hash, idx_hash))
+	if (!hasheq(hash, idx_hash))
 		return error("packfile %s does not match index", p->pack_name);
 	return 0;
 }
@@ -586,7 +652,7 @@ unsigned char *use_pack(struct packed_gi
 			while (packed_git_limit < pack_mapped
 				&& unuse_one_window(p))
 				; /* nothing */
-			win->base = xmmap(NULL, win->len,
+			win->base = xmmap_gently(NULL, win->len,
 				PROT_READ, MAP_PRIVATE,
 				p->pack_fd, win->offset);
 			if (win->base == MAP_FAILED)
@@ -625,23 +691,12 @@ void unuse_pack(struct pack_window **w_c
 	}
 }
 
-static void try_to_free_pack_memory(size_t size)
-{
-	release_pack_memory(size);
-}
-
 struct packed_git *add_packed_git(const char *path, size_t path_len, int local)
 {
-	static int have_set_try_to_free_routine;
 	struct stat st;
 	size_t alloc;
 	struct packed_git *p;
 
-	if (!have_set_try_to_free_routine) {
-		have_set_try_to_free_routine = 1;
-		set_try_to_free_routine(try_to_free_pack_memory);
-	}
-
 	/*
 	 * Make sure a corresponding .pack file exists and that
 	 * the index looks sane.
@@ -678,8 +733,8 @@ struct packed_git *add_packed_git(const
 	p->pack_local = local;
 	p->mtime = st.st_mtime;
 	if (path_len < the_hash_algo->hexsz ||
-	    get_sha1_hex(path + path_len - the_hash_algo->hexsz, p->sha1))
-		hashclr(p->sha1);
+	    get_sha1_hex(path + path_len - the_hash_algo->hexsz, p->hash))
+		hashclr(p->hash);
 	return p;
 }
 
@@ -690,6 +745,9 @@ void install_packed_git(struct repositor
 
 	pack->next = r->objects->packed_git;
 	r->objects->packed_git = pack;
+
+	hashmap_entry_init(&pack->packmap_ent, strhash(pack->pack_name));
+	hashmap_add(&r->objects->pack_map, &pack->packmap_ent);
 }
 
 void (*report_garbage)(unsigned seen_bits, const char *path);
@@ -738,13 +796,14 @@ static void report_pack_garbage(struct s
 	report_helper(list, seen_bits, first, list->nr);
 }
 
-static void prepare_packed_git_one(struct repository *r, char *objdir, int local)
+void for_each_file_in_pack_dir(const char *objdir,
+			       each_file_in_pack_dir_fn fn,
+			       void *data)
 {
 	struct strbuf path = STRBUF_INIT;
 	size_t dirnamelen;
 	DIR *dir;
 	struct dirent *de;
-	struct string_list garbage = STRING_LIST_INIT_DUP;
 
 	strbuf_addstr(&path, objdir);
 	strbuf_addstr(&path, "/pack");
@@ -759,53 +818,85 @@ static void prepare_packed_git_one(struc
 	strbuf_addch(&path, '/');
 	dirnamelen = path.len;
 	while ((de = readdir(dir)) != NULL) {
-		struct packed_git *p;
-		size_t base_len;
-
 		if (is_dot_or_dotdot(de->d_name))
 			continue;
 
 		strbuf_setlen(&path, dirnamelen);
 		strbuf_addstr(&path, de->d_name);
 
-		base_len = path.len;
-		if (strip_suffix_mem(path.buf, &base_len, ".idx")) {
-			/* Don't reopen a pack we already have. */
-			for (p = r->objects->packed_git; p;
-			     p = p->next) {
-				size_t len;
-				if (strip_suffix(p->pack_name, ".pack", &len) &&
-				    len == base_len &&
-				    !memcmp(p->pack_name, path.buf, len))
-					break;
-			}
-			if (p == NULL &&
-			    /*
-			     * See if it really is a valid .idx file with
-			     * corresponding .pack file that we can map.
-			     */
-			    (p = add_packed_git(path.buf, path.len, local)) != NULL)
-				install_packed_git(r, p);
-		}
-
-		if (!report_garbage)
-			continue;
-
-		if (ends_with(de->d_name, ".idx") ||
-		    ends_with(de->d_name, ".pack") ||
-		    ends_with(de->d_name, ".bitmap") ||
-		    ends_with(de->d_name, ".keep") ||
-		    ends_with(de->d_name, ".promisor"))
-			string_list_append(&garbage, path.buf);
-		else
-			report_garbage(PACKDIR_FILE_GARBAGE, path.buf);
+		fn(path.buf, path.len, de->d_name, data);
 	}
+
 	closedir(dir);
-	report_pack_garbage(&garbage);
-	string_list_clear(&garbage, 0);
 	strbuf_release(&path);
 }
 
+struct prepare_pack_data {
+	struct repository *r;
+	struct string_list *garbage;
+	int local;
+	struct multi_pack_index *m;
+};
+
+static void prepare_pack(const char *full_name, size_t full_name_len,
+			 const char *file_name, void *_data)
+{
+	struct prepare_pack_data *data = (struct prepare_pack_data *)_data;
+	struct packed_git *p;
+	size_t base_len = full_name_len;
+
+	if (strip_suffix_mem(full_name, &base_len, ".idx") &&
+	    !(data->m && midx_contains_pack(data->m, file_name))) {
+		struct hashmap_entry hent;
+		char *pack_name = xstrfmt("%.*s.pack", (int)base_len, full_name);
+		unsigned int hash = strhash(pack_name);
+		hashmap_entry_init(&hent, hash);
+
+		/* Don't reopen a pack we already have. */
+		if (!hashmap_get(&data->r->objects->pack_map, &hent, pack_name)) {
+			p = add_packed_git(full_name, full_name_len, data->local);
+			if (p)
+				install_packed_git(data->r, p);
+		}
+		free(pack_name);
+	}
+
+	if (!report_garbage)
+		return;
+
+	if (!strcmp(file_name, "multi-pack-index"))
+		return;
+	if (ends_with(file_name, ".idx") ||
+	    ends_with(file_name, ".pack") ||
+	    ends_with(file_name, ".bitmap") ||
+	    ends_with(file_name, ".keep") ||
+	    ends_with(file_name, ".promisor"))
+		string_list_append(data->garbage, full_name);
+	else
+		report_garbage(PACKDIR_FILE_GARBAGE, full_name);
+}
+
+static void prepare_packed_git_one(struct repository *r, char *objdir, int local)
+{
+	struct prepare_pack_data data;
+	struct string_list garbage = STRING_LIST_INIT_DUP;
+
+	data.m = r->objects->multi_pack_index;
+
+	/* look for the multi-pack-index for this object directory */
+	while (data.m && strcmp(data.m->object_dir, objdir))
+		data.m = data.m->next;
+
+	data.r = r;
+	data.garbage = &garbage;
+	data.local = local;
+
+	for_each_file_in_pack_dir(objdir, prepare_pack, &data);
+
+	report_pack_garbage(data.garbage);
+	string_list_clear(data.garbage, 0);
+}
+
 static void prepare_packed_git(struct repository *r);
 /*
  * Give a fast, rough count of the number of objects in the repository. This
@@ -814,22 +905,25 @@ static void prepare_packed_git(struct re
  * all unreachable objects about to be pruned, in which case they're not really
  * interesting as a measure of repo size in the first place.
  */
-unsigned long approximate_object_count(void)
+unsigned long repo_approximate_object_count(struct repository *r)
 {
-	if (!the_repository->objects->approximate_object_count_valid) {
+	if (!r->objects->approximate_object_count_valid) {
 		unsigned long count;
+		struct multi_pack_index *m;
 		struct packed_git *p;
 
-		prepare_packed_git(the_repository);
+		prepare_packed_git(r);
 		count = 0;
-		for (p = the_repository->objects->packed_git; p; p = p->next) {
+		for (m = get_multi_pack_index(r); m; m = m->next)
+			count += m->num_objects;
+		for (p = r->objects->packed_git; p; p = p->next) {
 			if (open_pack_index(p))
 				continue;
 			count += p->num_objects;
 		}
-		the_repository->objects->approximate_object_count = count;
+		r->objects->approximate_object_count = count;
 	}
-	return the_repository->objects->approximate_object_count;
+	return r->objects->approximate_object_count;
 }
 
 static void *get_next_packed_git(const void *p)
@@ -889,21 +983,30 @@ static void prepare_packed_git_mru(struc
 
 static void prepare_packed_git(struct repository *r)
 {
-	struct alternate_object_database *alt;
+	struct object_directory *odb;
 
 	if (r->objects->packed_git_initialized)
 		return;
-	prepare_packed_git_one(r, r->objects->objectdir, 1);
+
 	prepare_alt_odb(r);
-	for (alt = r->objects->alt_odb_list; alt; alt = alt->next)
-		prepare_packed_git_one(r, alt->path, 0);
+	for (odb = r->objects->odb; odb; odb = odb->next) {
+		int local = (odb == r->objects->odb);
+		prepare_multi_pack_index_one(r, odb->path, local);
+		prepare_packed_git_one(r, odb->path, local);
+	}
 	rearrange_packed_git(r);
+
 	prepare_packed_git_mru(r);
 	r->objects->packed_git_initialized = 1;
 }
 
 void reprepare_packed_git(struct repository *r)
 {
+	struct object_directory *odb;
+
+	for (odb = r->objects->odb; odb; odb = odb->next)
+		odb_clear_loose_cache(odb);
+
 	r->objects->approximate_object_count_valid = 0;
 	r->objects->packed_git_initialized = 0;
 	prepare_packed_git(r);
@@ -915,6 +1018,26 @@ struct packed_git *get_packed_git(struct
 	return r->objects->packed_git;
 }
 
+struct multi_pack_index *get_multi_pack_index(struct repository *r)
+{
+	prepare_packed_git(r);
+	return r->objects->multi_pack_index;
+}
+
+struct packed_git *get_all_packs(struct repository *r)
+{
+	struct multi_pack_index *m;
+
+	prepare_packed_git(r);
+	for (m = r->objects->multi_pack_index; m; m = m->next) {
+		uint32_t i;
+		for (i = 0; i < m->num_packs; i++)
+			prepare_midx_pack(r, m, i);
+	}
+
+	return r->objects->packed_git;
+}
+
 struct list_head *get_packed_git_mru(struct repository *r)
 {
 	prepare_packed_git(r);
@@ -1014,25 +1137,27 @@ int unpack_object_header(struct packed_g
 void mark_bad_packed_object(struct packed_git *p, const unsigned char *sha1)
 {
 	unsigned i;
+	const unsigned hashsz = the_hash_algo->rawsz;
 	for (i = 0; i < p->num_bad_objects; i++)
-		if (!hashcmp(sha1, p->bad_object_sha1 + GIT_SHA1_RAWSZ * i))
+		if (hasheq(sha1, p->bad_object_sha1 + hashsz * i))
 			return;
 	p->bad_object_sha1 = xrealloc(p->bad_object_sha1,
 				      st_mult(GIT_MAX_RAWSZ,
 					      st_add(p->num_bad_objects, 1)));
-	hashcpy(p->bad_object_sha1 + GIT_SHA1_RAWSZ * p->num_bad_objects, sha1);
+	hashcpy(p->bad_object_sha1 + hashsz * p->num_bad_objects, sha1);
 	p->num_bad_objects++;
 }
 
-const struct packed_git *has_packed_and_bad(const unsigned char *sha1)
+const struct packed_git *has_packed_and_bad(struct repository *r,
+					    const unsigned char *sha1)
 {
 	struct packed_git *p;
 	unsigned i;
 
-	for (p = the_repository->objects->packed_git; p; p = p->next)
+	for (p = r->objects->packed_git; p; p = p->next)
 		for (i = 0; i < p->num_bad_objects; i++)
-			if (!hashcmp(sha1,
-				     p->bad_object_sha1 + the_hash_algo->rawsz * i))
+			if (hasheq(sha1,
+				   p->bad_object_sha1 + the_hash_algo->rawsz * i))
 				return p;
 	return NULL;
 }
@@ -1146,7 +1271,7 @@ static enum object_type packed_to_object
 		if (poi_stack_nr >= poi_stack_alloc && poi_stack == small_poi_stack) {
 			poi_stack_alloc = alloc_nr(poi_stack_nr);
 			ALLOC_ARRAY(poi_stack, poi_stack_alloc);
-			memcpy(poi_stack, small_poi_stack, sizeof(off_t)*poi_stack_nr);
+			COPY_ARRAY(poi_stack, small_poi_stack, poi_stack_nr);
 		} else {
 			ALLOC_GROW(poi_stack, poi_stack_nr+1, poi_stack_alloc);
 		}
@@ -1207,7 +1332,7 @@ struct delta_base_cache_key {
 };
 
 struct delta_base_cache_entry {
-	struct hashmap hash;
+	struct hashmap_entry ent;
 	struct delta_base_cache_key key;
 	struct list_head lru;
 	void *data;
@@ -1227,7 +1352,7 @@ static unsigned int pack_entry_hash(stru
 static struct delta_base_cache_entry *
 get_delta_base_cache_entry(struct packed_git *p, off_t base_offset)
 {
-	struct hashmap_entry entry;
+	struct hashmap_entry entry, *e;
 	struct delta_base_cache_key key;
 
 	if (!delta_base_cache.cmpfn)
@@ -1236,7 +1361,8 @@ get_delta_base_cache_entry(struct packed
 	hashmap_entry_init(&entry, pack_entry_hash(p, base_offset));
 	key.p = p;
 	key.base_offset = base_offset;
-	return hashmap_get(&delta_base_cache, &entry, &key);
+	e = hashmap_get(&delta_base_cache, &entry, &key);
+	return e ? container_of(e, struct delta_base_cache_entry, ent) : NULL;
 }
 
 static int delta_base_cache_key_eq(const struct delta_base_cache_key *a,
@@ -1246,11 +1372,16 @@ static int delta_base_cache_key_eq(const
 }
 
 static int delta_base_cache_hash_cmp(const void *unused_cmp_data,
-				     const void *va, const void *vb,
+				     const struct hashmap_entry *va,
+				     const struct hashmap_entry *vb,
 				     const void *vkey)
 {
-	const struct delta_base_cache_entry *a = va, *b = vb;
+	const struct delta_base_cache_entry *a, *b;
 	const struct delta_base_cache_key *key = vkey;
+
+	a = container_of(va, const struct delta_base_cache_entry, ent);
+	b = container_of(vb, const struct delta_base_cache_entry, ent);
+
 	if (key)
 		return !delta_base_cache_key_eq(&a->key, key);
 	else
@@ -1269,7 +1400,7 @@ static int in_delta_base_cache(struct pa
  */
 static void detach_delta_base_cache_entry(struct delta_base_cache_entry *ent)
 {
-	hashmap_remove(&delta_base_cache, ent, &ent->key);
+	hashmap_remove(&delta_base_cache, &ent->ent, &ent->key);
 	list_del(&ent->lru);
 	delta_base_cached -= ent->size;
 	free(ent);
@@ -1333,8 +1464,8 @@ static void add_delta_base_cache(struct
 
 	if (!delta_base_cache.cmpfn)
 		hashmap_init(&delta_base_cache, delta_base_cache_hash_cmp, NULL, 0);
-	hashmap_entry_init(ent, pack_entry_hash(p, base_offset));
-	hashmap_add(&delta_base_cache, ent);
+	hashmap_entry_init(&ent->ent, pack_entry_hash(p, base_offset));
+	hashmap_add(&delta_base_cache, &ent->ent);
 }
 
 int packed_object_info(struct repository *r, struct packed_git *p,
@@ -1556,8 +1687,8 @@ void *unpack_entry(struct repository *r,
 		    && delta_stack == small_delta_stack) {
 			delta_stack_alloc = alloc_nr(delta_stack_nr);
 			ALLOC_ARRAY(delta_stack, delta_stack_alloc);
-			memcpy(delta_stack, small_delta_stack,
-			       sizeof(*delta_stack)*delta_stack_nr);
+			COPY_ARRAY(delta_stack, small_delta_stack,
+				   delta_stack_nr);
 		} else {
 			ALLOC_GROW(delta_stack, delta_stack_nr+1, delta_stack_alloc);
 		}
@@ -1830,8 +1961,8 @@ static int fill_pack_entry(const struct
 	if (p->num_bad_objects) {
 		unsigned i;
 		for (i = 0; i < p->num_bad_objects; i++)
-			if (!hashcmp(oid->hash,
-				     p->bad_object_sha1 + the_hash_algo->rawsz * i))
+			if (hasheq(oid->hash,
+				   p->bad_object_sha1 + the_hash_algo->rawsz * i))
 				return 0;
 	}
 
@@ -1856,14 +1987,20 @@ static int fill_pack_entry(const struct
 int find_pack_entry(struct repository *r, const struct object_id *oid, struct pack_entry *e)
 {
 	struct list_head *pos;
+	struct multi_pack_index *m;
 
 	prepare_packed_git(r);
-	if (!r->objects->packed_git)
+	if (!r->objects->packed_git && !r->objects->multi_pack_index)
 		return 0;
 
+	for (m = r->objects->multi_pack_index; m; m = m->next) {
+		if (fill_midx_entry(r, oid, e, m))
+			return 1;
+	}
+
 	list_for_each(pos, &r->objects->packed_git_mru) {
 		struct packed_git *p = list_entry(pos, struct packed_git, mru);
-		if (fill_pack_entry(oid, e, p)) {
+		if (!p->multi_pack_index && fill_pack_entry(oid, e, p)) {
 			list_move(&p->mru, &r->objects->packed_git_mru);
 			return 1;
 		}
@@ -1885,33 +2022,47 @@ int has_pack_index(const unsigned char *
 	return 1;
 }
 
-int for_each_object_in_pack(struct packed_git *p, each_packed_object_fn cb, void *data)
+int for_each_object_in_pack(struct packed_git *p,
+			    each_packed_object_fn cb, void *data,
+			    enum for_each_object_flags flags)
 {
 	uint32_t i;
 	int r = 0;
 
+	if (flags & FOR_EACH_OBJECT_PACK_ORDER) {
+		if (load_pack_revindex(p))
+			return -1;
+	}
+
 	for (i = 0; i < p->num_objects; i++) {
+		uint32_t pos;
 		struct object_id oid;
 
-		if (!nth_packed_object_oid(&oid, p, i))
+		if (flags & FOR_EACH_OBJECT_PACK_ORDER)
+			pos = p->revindex[i].nr;
+		else
+			pos = i;
+
+		if (!nth_packed_object_oid(&oid, p, pos))
 			return error("unable to get sha1 of object %u in %s",
-				     i, p->pack_name);
+				     pos, p->pack_name);
 
-		r = cb(&oid, p, i, data);
+		r = cb(&oid, p, pos, data);
 		if (r)
 			break;
 	}
 	return r;
 }
 
-int for_each_packed_object(each_packed_object_fn cb, void *data, unsigned flags)
+int for_each_packed_object(each_packed_object_fn cb, void *data,
+			   enum for_each_object_flags flags)
 {
 	struct packed_git *p;
 	int r = 0;
 	int pack_errors = 0;
 
 	prepare_packed_git(the_repository);
-	for (p = the_repository->objects->packed_git; p; p = p->next) {
+	for (p = get_all_packs(the_repository); p; p = p->next) {
 		if ((flags & FOR_EACH_OBJECT_LOCAL_ONLY) && !p->pack_local)
 			continue;
 		if ((flags & FOR_EACH_OBJECT_PROMISOR_ONLY) &&
@@ -1921,7 +2072,7 @@ int for_each_packed_object(each_packed_o
 			pack_errors = 1;
 			continue;
 		}
-		r = for_each_object_in_pack(p, cb, data);
+		r = for_each_object_in_pack(p, cb, data, flags);
 		if (r)
 			break;
 	}
@@ -1934,7 +2085,7 @@ static int add_promisor_object(const str
 			       void *set_)
 {
 	struct oidset *set = set_;
-	struct object *obj = parse_object(oid);
+	struct object *obj = parse_object(the_repository, oid);
 	if (!obj)
 		return 1;
 
@@ -1955,7 +2106,7 @@ static int add_promisor_object(const str
 			 */
 			return 0;
 		while (tree_entry_gently(&desc, &entry))
-			oidset_insert(set, entry.oid);
+			oidset_insert(set, &entry.oid);
 	} else if (obj->type == OBJ_COMMIT) {
 		struct commit *commit = (struct commit *) obj;
 		struct commit_list *parents = commit->parents;
@@ -1965,7 +2116,7 @@ static int add_promisor_object(const str
 			oidset_insert(set, &parents->item->object.oid);
 	} else if (obj->type == OBJ_TAG) {
 		struct tag *tag = (struct tag *) obj;
-		oidset_insert(set, &tag->tagged->oid);
+		oidset_insert(set, get_tagged_oid(tag));
 	}
 	return 0;
 }
@@ -1976,7 +2127,7 @@ int is_promisor_object(const struct obje
 	static int promisor_objects_prepared;
 
 	if (!promisor_objects_prepared) {
-		if (repository_format_partial_clone) {
+		if (has_promisor_remote()) {
 			for_each_packed_object(add_promisor_object,
 					       &promisor_objects,
 					       FOR_EACH_OBJECT_PROMISOR_ONLY);
diff -pruN 1.2.1+git2.18.0-1/git/packfile.h 1.2.3+git2.25.1-1/git/packfile.h
--- 1.2.1+git2.18.0-1/git/packfile.h	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/packfile.h	2020-02-17 04:47:35.000000000 +0000
@@ -1,8 +1,13 @@
 #ifndef PACKFILE_H
 #define PACKFILE_H
 
+#include "cache.h"
 #include "oidset.h"
 
+/* in object-store.h */
+struct packed_git;
+struct object_info;
+
 /*
  * Generate the filename to be used for a pack file with checksum "sha1" and
  * extension "ext". The result is written into the strbuf "buf", overwriting
@@ -10,23 +15,35 @@
  *
  * Example: odb_pack_name(out, sha1, "idx") => ".git/objects/pack/pack-1234..idx"
  */
-extern char *odb_pack_name(struct strbuf *buf, const unsigned char *sha1, const char *ext);
+char *odb_pack_name(struct strbuf *buf, const unsigned char *sha1, const char *ext);
 
 /*
  * Return the name of the (local) packfile with the specified sha1 in
  * its name.  The return value is a pointer to memory that is
  * overwritten each time this function is called.
  */
-extern char *sha1_pack_name(const unsigned char *sha1);
+char *sha1_pack_name(const unsigned char *sha1);
 
 /*
  * Return the name of the (local) pack index file with the specified
  * sha1 in its name.  The return value is a pointer to memory that is
  * overwritten each time this function is called.
  */
-extern char *sha1_pack_index_name(const unsigned char *sha1);
+char *sha1_pack_index_name(const unsigned char *sha1);
+
+/*
+ * Return the basename of the packfile, omitting any containing directory
+ * (e.g., "pack-1234abcd[...].pack").
+ */
+const char *pack_basename(struct packed_git *p);
+
+struct packed_git *parse_pack_index(unsigned char *sha1, const char *idx_path);
 
-extern struct packed_git *parse_pack_index(unsigned char *sha1, const char *idx_path);
+typedef void each_file_in_pack_dir_fn(const char *full_path, size_t full_path_len,
+				      const char *file_pach, void *data);
+void for_each_file_in_pack_dir(const char *objdir,
+			       each_file_in_pack_dir_fn fn,
+			       void *data);
 
 /* A hook to report invalid files in pack directory */
 #define PACKDIR_FILE_PACK 1
@@ -34,42 +51,56 @@ extern struct packed_git *parse_pack_ind
 #define PACKDIR_FILE_GARBAGE 4
 extern void (*report_garbage)(unsigned seen_bits, const char *path);
 
-extern void reprepare_packed_git(struct repository *r);
-extern void install_packed_git(struct repository *r, struct packed_git *pack);
+void reprepare_packed_git(struct repository *r);
+void install_packed_git(struct repository *r, struct packed_git *pack);
 
 struct packed_git *get_packed_git(struct repository *r);
 struct list_head *get_packed_git_mru(struct repository *r);
+struct multi_pack_index *get_multi_pack_index(struct repository *r);
+struct packed_git *get_all_packs(struct repository *r);
 
 /*
  * Give a rough count of objects in the repository. This sacrifices accuracy
  * for speed.
  */
-unsigned long approximate_object_count(void);
+unsigned long repo_approximate_object_count(struct repository *r);
+#define approximate_object_count() repo_approximate_object_count(the_repository)
 
-extern struct packed_git *find_sha1_pack(const unsigned char *sha1,
-					 struct packed_git *packs);
+struct packed_git *find_sha1_pack(const unsigned char *sha1,
+				  struct packed_git *packs);
 
-extern void pack_report(void);
+void pack_report(void);
 
 /*
  * mmap the index file for the specified packfile (if it is not
  * already mmapped).  Return 0 on success.
  */
-extern int open_pack_index(struct packed_git *);
+int open_pack_index(struct packed_git *);
 
 /*
  * munmap the index file for the specified packfile (if it is
  * currently mmapped).
  */
-extern void close_pack_index(struct packed_git *);
+void close_pack_index(struct packed_git *);
 
-extern unsigned char *use_pack(struct packed_git *, struct pack_window **, off_t, unsigned long *);
-extern void close_pack_windows(struct packed_git *);
-extern void close_pack(struct packed_git *);
-extern void close_all_packs(struct raw_object_store *o);
-extern void unuse_pack(struct pack_window **);
-extern void clear_delta_base_cache(void);
-extern struct packed_git *add_packed_git(const char *path, size_t path_len, int local);
+int close_pack_fd(struct packed_git *p);
+
+uint32_t get_pack_fanout(struct packed_git *p, uint32_t value);
+
+unsigned char *use_pack(struct packed_git *, struct pack_window **, off_t, unsigned long *);
+void close_pack_windows(struct packed_git *);
+void close_pack(struct packed_git *);
+void close_object_store(struct raw_object_store *o);
+void unuse_pack(struct pack_window **);
+void clear_delta_base_cache(void);
+struct packed_git *add_packed_git(const char *path, size_t path_len, int local);
+
+/*
+ * Unlink the .pack and associated extension files.
+ * Does not unlink if 'force_delete' is false and the pack-file is
+ * marked as ".keep".
+ */
+void unlink_pack_path(const char *pack_name, int force_delete);
 
 /*
  * Make sure that a pointer access into an mmap'd index file is within bounds,
@@ -79,7 +110,7 @@ extern struct packed_git *add_packed_git
  * (like the 64-bit extended offset table), as we compare the size to the
  * fixed-length parts when we open the file.
  */
-extern void check_pack_index_ptr(const struct packed_git *p, const void *ptr);
+void check_pack_index_ptr(const struct packed_git *p, const void *ptr);
 
 /*
  * Perform binary search on a pack-index for a given oid. Packfile is expected to
@@ -95,75 +126,71 @@ int bsearch_pack(const struct object_id
  * at the SHA-1 within the mmapped index.  Return NULL if there is an
  * error.
  */
-extern const unsigned char *nth_packed_object_sha1(struct packed_git *, uint32_t n);
+const unsigned char *nth_packed_object_sha1(struct packed_git *, uint32_t n);
 /*
  * Like nth_packed_object_sha1, but write the data into the object specified by
  * the the first argument.  Returns the first argument on success, and NULL on
  * error.
  */
-extern const struct object_id *nth_packed_object_oid(struct object_id *, struct packed_git *, uint32_t n);
+const struct object_id *nth_packed_object_oid(struct object_id *, struct packed_git *, uint32_t n);
 
 /*
  * Return the offset of the nth object within the specified packfile.
  * The index must already be opened.
  */
-extern off_t nth_packed_object_offset(const struct packed_git *, uint32_t n);
+off_t nth_packed_object_offset(const struct packed_git *, uint32_t n);
 
 /*
  * If the object named sha1 is present in the specified packfile,
  * return its offset within the packfile; otherwise, return 0.
  */
-extern off_t find_pack_entry_one(const unsigned char *sha1, struct packed_git *);
+off_t find_pack_entry_one(const unsigned char *sha1, struct packed_git *);
 
-extern int is_pack_valid(struct packed_git *);
-extern void *unpack_entry(struct repository *r, struct packed_git *, off_t, enum object_type *, unsigned long *);
-extern unsigned long unpack_object_header_buffer(const unsigned char *buf, unsigned long len, enum object_type *type, unsigned long *sizep);
-extern unsigned long get_size_from_delta(struct packed_git *, struct pack_window **, off_t);
-extern int unpack_object_header(struct packed_git *, struct pack_window **, off_t *, unsigned long *);
+int is_pack_valid(struct packed_git *);
+void *unpack_entry(struct repository *r, struct packed_git *, off_t, enum object_type *, unsigned long *);
+unsigned long unpack_object_header_buffer(const unsigned char *buf, unsigned long len, enum object_type *type, unsigned long *sizep);
+unsigned long get_size_from_delta(struct packed_git *, struct pack_window **, off_t);
+int unpack_object_header(struct packed_git *, struct pack_window **, off_t *, unsigned long *);
 
-extern void release_pack_memory(size_t);
+void release_pack_memory(size_t);
 
 /* global flag to enable extra checks when accessing packed objects */
 extern int do_check_packed_object_crc;
 
-extern int packed_object_info(struct repository *r,
-			      struct packed_git *pack,
-			      off_t offset, struct object_info *);
+int packed_object_info(struct repository *r,
+		       struct packed_git *pack,
+		       off_t offset, struct object_info *);
 
-extern void mark_bad_packed_object(struct packed_git *p, const unsigned char *sha1);
-extern const struct packed_git *has_packed_and_bad(const unsigned char *sha1);
+void mark_bad_packed_object(struct packed_git *p, const unsigned char *sha1);
+const struct packed_git *has_packed_and_bad(struct repository *r, const unsigned char *sha1);
 
 /*
  * Iff a pack file in the given repository contains the object named by sha1,
  * return true and store its location to e.
  */
-extern int find_pack_entry(struct repository *r, const struct object_id *oid, struct pack_entry *e);
+int find_pack_entry(struct repository *r, const struct object_id *oid, struct pack_entry *e);
 
-extern int has_object_pack(const struct object_id *oid);
+int has_object_pack(const struct object_id *oid);
 
-extern int has_pack_index(const unsigned char *sha1);
+int has_pack_index(const unsigned char *sha1);
 
 /*
- * Only iterate over packs obtained from the promisor remote.
- */
-#define FOR_EACH_OBJECT_PROMISOR_ONLY 2
-
-/*
- * Iterate over packed objects in both the local
- * repository and any alternates repositories (unless the
- * FOR_EACH_OBJECT_LOCAL_ONLY flag, defined in cache.h, is set).
+ * Return 1 if an object in a promisor packfile is or refers to the given
+ * object, 0 otherwise.
  */
-typedef int each_packed_object_fn(const struct object_id *oid,
-				  struct packed_git *pack,
-				  uint32_t pos,
-				  void *data);
-extern int for_each_object_in_pack(struct packed_git *p, each_packed_object_fn, void *data);
-extern int for_each_packed_object(each_packed_object_fn, void *, unsigned flags);
+int is_promisor_object(const struct object_id *oid);
 
 /*
- * Return 1 if an object in a promisor packfile is or refers to the given
- * object, 0 otherwise.
+ * Expose a function for fuzz testing.
+ *
+ * load_idx() parses a block of memory as a packfile index and puts the results
+ * into a struct packed_git.
+ *
+ * This function should not be used directly. It is exposed here only so that we
+ * have a convenient entry-point for fuzz testing. For real uses, you should
+ * probably use open_pack_index() or parse_pack_index() instead.
  */
-extern int is_promisor_object(const struct object_id *oid);
+int load_idx(const char *path, const unsigned int hashsz, void *idx_map,
+	     size_t idx_size, struct packed_git *p);
 
 #endif
diff -pruN 1.2.1+git2.18.0-1/git/pack.h 1.2.3+git2.25.1-1/git/pack.h
--- 1.2.1+git2.18.0-1/git/pack.h	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/pack.h	2020-02-17 04:47:35.000000000 +0000
@@ -4,6 +4,8 @@
 #include "object.h"
 #include "csum-file.h"
 
+struct repository;
+
 /*
  * Packed object header
  */
@@ -53,7 +55,7 @@ struct pack_idx_option {
 	uint32_t *anomaly;
 };
 
-extern void reset_pack_idx_option(struct pack_idx_option *);
+void reset_pack_idx_option(struct pack_idx_option *);
 
 /*
  * Packed object index header
@@ -77,28 +79,28 @@ struct progress;
 /* Note, the data argument could be NULL if object type is blob */
 typedef int (*verify_fn)(const struct object_id *, enum object_type, unsigned long, void*, int*);
 
-extern const char *write_idx_file(const char *index_name, struct pack_idx_entry **objects, int nr_objects, const struct pack_idx_option *, const unsigned char *sha1);
-extern int check_pack_crc(struct packed_git *p, struct pack_window **w_curs, off_t offset, off_t len, unsigned int nr);
-extern int verify_pack_index(struct packed_git *);
-extern int verify_pack(struct packed_git *, verify_fn fn, struct progress *, uint32_t);
-extern off_t write_pack_header(struct hashfile *f, uint32_t);
-extern void fixup_pack_header_footer(int, unsigned char *, const char *, uint32_t, unsigned char *, off_t);
-extern char *index_pack_lockfile(int fd);
+const char *write_idx_file(const char *index_name, struct pack_idx_entry **objects, int nr_objects, const struct pack_idx_option *, const unsigned char *sha1);
+int check_pack_crc(struct packed_git *p, struct pack_window **w_curs, off_t offset, off_t len, unsigned int nr);
+int verify_pack_index(struct packed_git *);
+int verify_pack(struct repository *, struct packed_git *, verify_fn fn, struct progress *, uint32_t);
+off_t write_pack_header(struct hashfile *f, uint32_t);
+void fixup_pack_header_footer(int, unsigned char *, const char *, uint32_t, unsigned char *, off_t);
+char *index_pack_lockfile(int fd);
 
 /*
  * The "hdr" output buffer should be at least this big, which will handle sizes
  * up to 2^67.
  */
 #define MAX_PACK_OBJECT_HEADER 10
-extern int encode_in_pack_object_header(unsigned char *hdr, int hdr_len,
-					enum object_type, uintmax_t);
+int encode_in_pack_object_header(unsigned char *hdr, int hdr_len,
+				 enum object_type, uintmax_t);
 
 #define PH_ERROR_EOF		(-1)
 #define PH_ERROR_PACK_SIGNATURE	(-2)
 #define PH_ERROR_PROTOCOL	(-3)
-extern int read_pack_header(int fd, struct pack_header *);
+int read_pack_header(int fd, struct pack_header *);
 
-extern struct hashfile *create_tmp_packfile(char **pack_tmp_name);
-extern void finish_tmp_packfile(struct strbuf *name_buffer, const char *pack_tmp_name, struct pack_idx_entry **written_list, uint32_t nr_written, struct pack_idx_option *pack_idx_opts, unsigned char sha1[]);
+struct hashfile *create_tmp_packfile(char **pack_tmp_name);
+void finish_tmp_packfile(struct strbuf *name_buffer, const char *pack_tmp_name, struct pack_idx_entry **written_list, uint32_t nr_written, struct pack_idx_option *pack_idx_opts, unsigned char sha1[]);
 
 #endif
diff -pruN 1.2.1+git2.18.0-1/git/pack-objects.c 1.2.3+git2.25.1-1/git/pack-objects.c
--- 1.2.1+git2.18.0-1/git/pack-objects.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/pack-objects.c	2020-02-17 04:47:35.000000000 +0000
@@ -6,17 +6,17 @@
 #include "config.h"
 
 static uint32_t locate_object_entry_hash(struct packing_data *pdata,
-					 const unsigned char *sha1,
+					 const struct object_id *oid,
 					 int *found)
 {
 	uint32_t i, mask = (pdata->index_size - 1);
 
-	i = sha1hash(sha1) & mask;
+	i = oidhash(oid) & mask;
 
 	while (pdata->index[i] > 0) {
 		uint32_t pos = pdata->index[i] - 1;
 
-		if (!hashcmp(sha1, pdata->objects[pos].idx.oid.hash)) {
+		if (oideq(oid, &pdata->objects[pos].idx.oid)) {
 			*found = 1;
 			return i;
 		}
@@ -56,7 +56,7 @@ static void rehash_objects(struct packin
 	for (i = 0; i < pdata->nr_objects; i++) {
 		int found;
 		uint32_t ix = locate_object_entry_hash(pdata,
-						       entry->idx.oid.hash,
+						       &entry->idx.oid,
 						       &found);
 
 		if (found)
@@ -68,8 +68,7 @@ static void rehash_objects(struct packin
 }
 
 struct object_entry *packlist_find(struct packing_data *pdata,
-				   const unsigned char *sha1,
-				   uint32_t *index_pos)
+				   const struct object_id *oid)
 {
 	uint32_t i;
 	int found;
@@ -77,10 +76,7 @@ struct object_entry *packlist_find(struc
 	if (!pdata->index_size)
 		return NULL;
 
-	i = locate_object_entry_hash(pdata, sha1, &found);
-
-	if (index_pos)
-		*index_pos = i;
+	i = locate_object_entry_hash(pdata, oid, &found);
 
 	if (!found)
 		return NULL;
@@ -99,7 +95,7 @@ static void prepare_in_pack_by_idx(struc
 	 * (i.e. in_pack_idx also zero) should return NULL.
 	 */
 	mapping[cnt++] = NULL;
-	for (p = get_packed_git(the_repository); p; p = p->next, cnt++) {
+	for (p = get_all_packs(pdata->repo); p; p = p->next, cnt++) {
 		if (cnt == nr) {
 			free(mapping);
 			return;
@@ -119,12 +115,14 @@ static void prepare_in_pack_by_idx(struc
  * this fall back code, just stay simple and fall back to using
  * in_pack[] array.
  */
-void oe_map_new_pack(struct packing_data *pack,
-		     struct packed_git *p)
+void oe_map_new_pack(struct packing_data *pack)
 {
 	uint32_t i;
 
-	REALLOC_ARRAY(pack->in_pack, pack->nr_alloc);
+	if (pack->in_pack)
+		BUG("packing_data has already been converted to pack array");
+
+	ALLOC_ARRAY(pack->in_pack, pack->nr_alloc);
 
 	for (i = 0; i < pack->nr_objects; i++)
 		pack->in_pack[i] = oe_in_pack(pack, pack->objects + i);
@@ -133,8 +131,10 @@ void oe_map_new_pack(struct packing_data
 }
 
 /* assume pdata is already zero'd by caller */
-void prepare_packing_data(struct packing_data *pdata)
+void prepare_packing_data(struct repository *r, struct packing_data *pdata)
 {
+	pdata->repo = r;
+
 	if (git_env_bool("GIT_TEST_FULL_IN_PACK_ARRAY", 0)) {
 		/*
 		 * do not initialize in_pack_by_idx[] to force the
@@ -146,11 +146,13 @@ void prepare_packing_data(struct packing
 
 	pdata->oe_size_limit = git_env_ulong("GIT_TEST_OE_SIZE",
 					     1U << OE_SIZE_BITS);
+	pdata->oe_delta_size_limit = git_env_ulong("GIT_TEST_OE_DELTA_SIZE",
+						   1UL << OE_DELTA_SIZE_BITS);
+	init_recursive_mutex(&pdata->odb_lock);
 }
 
 struct object_entry *packlist_alloc(struct packing_data *pdata,
-				    const unsigned char *sha1,
-				    uint32_t index_pos)
+				    const struct object_id *oid)
 {
 	struct object_entry *new_entry;
 
@@ -160,20 +162,60 @@ struct object_entry *packlist_alloc(stru
 
 		if (!pdata->in_pack_by_idx)
 			REALLOC_ARRAY(pdata->in_pack, pdata->nr_alloc);
+		if (pdata->delta_size)
+			REALLOC_ARRAY(pdata->delta_size, pdata->nr_alloc);
+
+		if (pdata->tree_depth)
+			REALLOC_ARRAY(pdata->tree_depth, pdata->nr_alloc);
+
+		if (pdata->layer)
+			REALLOC_ARRAY(pdata->layer, pdata->nr_alloc);
 	}
 
 	new_entry = pdata->objects + pdata->nr_objects++;
 
 	memset(new_entry, 0, sizeof(*new_entry));
-	hashcpy(new_entry->idx.oid.hash, sha1);
+	oidcpy(&new_entry->idx.oid, oid);
 
 	if (pdata->index_size * 3 <= pdata->nr_objects * 4)
 		rehash_objects(pdata);
-	else
-		pdata->index[index_pos] = pdata->nr_objects;
+	else {
+		int found;
+		uint32_t pos = locate_object_entry_hash(pdata,
+							&new_entry->idx.oid,
+							&found);
+		if (found)
+			BUG("duplicate object inserted into hash");
+		pdata->index[pos] = pdata->nr_objects;
+	}
 
 	if (pdata->in_pack)
 		pdata->in_pack[pdata->nr_objects - 1] = NULL;
 
+	if (pdata->tree_depth)
+		pdata->tree_depth[pdata->nr_objects - 1] = 0;
+
+	if (pdata->layer)
+		pdata->layer[pdata->nr_objects - 1] = 0;
+
 	return new_entry;
 }
+
+void oe_set_delta_ext(struct packing_data *pdata,
+		      struct object_entry *delta,
+		      const unsigned char *sha1)
+{
+	struct object_entry *base;
+
+	ALLOC_GROW(pdata->ext_bases, pdata->nr_ext + 1, pdata->alloc_ext);
+	base = &pdata->ext_bases[pdata->nr_ext++];
+	memset(base, 0, sizeof(*base));
+	hashcpy(base->idx.oid.hash, sha1);
+
+	/* These flags mark that we are not part of the actual pack output. */
+	base->preferred_base = 1;
+	base->filled = 1;
+
+	delta->ext_base = 1;
+	delta->delta_idx = base - pdata->ext_bases + 1;
+}
diff -pruN 1.2.1+git2.18.0-1/git/pack-objects.h 1.2.3+git2.25.1-1/git/pack-objects.h
--- 1.2.1+git2.18.0-1/git/pack-objects.h	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/pack-objects.h	2020-02-17 04:47:35.000000000 +0000
@@ -2,6 +2,10 @@
 #define PACK_OBJECTS_H
 
 #include "object-store.h"
+#include "thread-utils.h"
+#include "pack.h"
+
+struct repository;
 
 #define DEFAULT_DELTA_CACHE_SIZE (256 * 1024 * 1024)
 
@@ -14,7 +18,7 @@
  * above this limit. Don't lower it too much.
  */
 #define OE_SIZE_BITS		31
-#define OE_DELTA_SIZE_BITS	20
+#define OE_DELTA_SIZE_BITS	23
 
 /*
  * State flags for depth-first search used for analyzing delta cycles.
@@ -94,12 +98,14 @@ struct object_entry {
 				     */
 	unsigned delta_size_:OE_DELTA_SIZE_BITS; /* delta data size (uncompressed) */
 	unsigned delta_size_valid:1;
+	unsigned char in_pack_header_size;
 	unsigned in_pack_idx:OE_IN_PACK_BITS;	/* already in pack */
 	unsigned z_delta_size:OE_Z_DELTA_BITS;
 	unsigned type_valid:1;
-	unsigned type_:TYPE_BITS;
 	unsigned no_try_delta:1;
+	unsigned type_:TYPE_BITS;
 	unsigned in_pack_type:TYPE_BITS; /* could be delta */
+
 	unsigned preferred_base:1; /*
 				    * we do not pack this, but is available
 				    * to be used as the base object to delta
@@ -108,21 +114,22 @@ struct object_entry {
 	unsigned tagged:1; /* near the very tip of refs */
 	unsigned filled:1; /* assigned write-order */
 	unsigned dfs_state:OE_DFS_STATE_BITS;
-	unsigned char in_pack_header_size;
 	unsigned depth:OE_DEPTH_BITS;
+	unsigned ext_base:1; /* delta_idx points outside packlist */
 
 	/*
 	 * pahole results on 64-bit linux (gcc and clang)
 	 *
-	 *   size: 80, bit_padding: 20 bits, holes: 8 bits
+	 *   size: 80, bit_padding: 9 bits
 	 *
 	 * and on 32-bit (gcc)
 	 *
-	 *   size: 76, bit_padding: 20 bits, holes: 8 bits
+	 *   size: 76, bit_padding: 9 bits
 	 */
 };
 
 struct packing_data {
+	struct repository *repo;
 	struct object_entry *objects;
 	uint32_t nr_objects, nr_alloc;
 
@@ -130,6 +137,7 @@ struct packing_data {
 	uint32_t index_size;
 
 	unsigned int *in_pack_pos;
+	unsigned long *delta_size;
 
 	/*
 	 * Only one of these can be non-NULL and they have different
@@ -140,17 +148,45 @@ struct packing_data {
 	struct packed_git **in_pack_by_idx;
 	struct packed_git **in_pack;
 
+	/*
+	 * During packing with multiple threads, protect the in-core
+	 * object database from concurrent accesses.
+	 */
+	pthread_mutex_t odb_lock;
+
+	/*
+	 * This list contains entries for bases which we know the other side
+	 * has (e.g., via reachability bitmaps), but which aren't in our
+	 * "objects" list.
+	 */
+	struct object_entry *ext_bases;
+	uint32_t nr_ext, alloc_ext;
+
 	uintmax_t oe_size_limit;
+	uintmax_t oe_delta_size_limit;
+
+	/* delta islands */
+	unsigned int *tree_depth;
+	unsigned char *layer;
 };
 
-void prepare_packing_data(struct packing_data *pdata);
+void prepare_packing_data(struct repository *r, struct packing_data *pdata);
+
+/* Protect access to object database */
+static inline void packing_data_lock(struct packing_data *pdata)
+{
+	pthread_mutex_lock(&pdata->odb_lock);
+}
+static inline void packing_data_unlock(struct packing_data *pdata)
+{
+	pthread_mutex_unlock(&pdata->odb_lock);
+}
+
 struct object_entry *packlist_alloc(struct packing_data *pdata,
-				    const unsigned char *sha1,
-				    uint32_t index_pos);
+				    const struct object_id *oid);
 
 struct object_entry *packlist_find(struct packing_data *pdata,
-				   const unsigned char *sha1,
-				   uint32_t *index_pos);
+				   const struct object_id *oid);
 
 static inline uint32_t pack_name_hash(const char *name)
 {
@@ -209,27 +245,39 @@ static inline struct packed_git *oe_in_p
 		return pack->in_pack[e - pack->objects];
 }
 
-void oe_map_new_pack(struct packing_data *pack,
-		     struct packed_git *p);
+void oe_map_new_pack(struct packing_data *pack);
+
 static inline void oe_set_in_pack(struct packing_data *pack,
 				  struct object_entry *e,
 				  struct packed_git *p)
 {
-	if (!p->index)
-		oe_map_new_pack(pack, p);
-	if (pack->in_pack_by_idx)
-		e->in_pack_idx = p->index;
-	else
-		pack->in_pack[e - pack->objects] = p;
+	if (pack->in_pack_by_idx) {
+		if (p->index) {
+			e->in_pack_idx = p->index;
+			return;
+		}
+		/*
+		 * We're accessing packs by index, but this pack doesn't have
+		 * an index (e.g., because it was added since we created the
+		 * in_pack_by_idx array). Bail to oe_map_new_pack(), which
+		 * will convert us to using the full in_pack array, and then
+		 * fall through to our in_pack handling.
+		 */
+		oe_map_new_pack(pack);
+	}
+	pack->in_pack[e - pack->objects] = p;
 }
 
 static inline struct object_entry *oe_delta(
 		const struct packing_data *pack,
 		const struct object_entry *e)
 {
-	if (e->delta_idx)
+	if (!e->delta_idx)
+		return NULL;
+	if (e->ext_base)
+		return &pack->ext_bases[e->delta_idx - 1];
+	else
 		return &pack->objects[e->delta_idx - 1];
-	return NULL;
 }
 
 static inline void oe_set_delta(struct packing_data *pack,
@@ -242,6 +290,10 @@ static inline void oe_set_delta(struct p
 		e->delta_idx = 0;
 }
 
+void oe_set_delta_ext(struct packing_data *pack,
+		      struct object_entry *e,
+		      const unsigned char *sha1);
+
 static inline struct object_entry *oe_delta_child(
 		const struct packing_data *pack,
 		const struct object_entry *e)
@@ -332,18 +384,68 @@ static inline unsigned long oe_delta_siz
 {
 	if (e->delta_size_valid)
 		return e->delta_size_;
-	return oe_size(pack, e);
+
+	/*
+	 * pack->delta_size[] can't be NULL because oe_set_delta_size()
+	 * must have been called when a new delta is saved with
+	 * oe_set_delta().
+	 * If oe_delta() returns NULL (i.e. default state, which means
+	 * delta_size_valid is also false), then the caller must never
+	 * call oe_delta_size().
+	 */
+	return pack->delta_size[e - pack->objects];
 }
 
 static inline void oe_set_delta_size(struct packing_data *pack,
 				     struct object_entry *e,
 				     unsigned long size)
 {
-	e->delta_size_ = size;
-	e->delta_size_valid = e->delta_size_ == size;
-	if (!e->delta_size_valid && size != oe_size(pack, e))
-		BUG("this can only happen in check_object() "
-		    "where delta size is the same as entry size");
+	if (size < pack->oe_delta_size_limit) {
+		e->delta_size_ = size;
+		e->delta_size_valid = 1;
+	} else {
+		packing_data_lock(pack);
+		if (!pack->delta_size)
+			ALLOC_ARRAY(pack->delta_size, pack->nr_alloc);
+		packing_data_unlock(pack);
+
+		pack->delta_size[e - pack->objects] = size;
+		e->delta_size_valid = 0;
+	}
+}
+
+static inline unsigned int oe_tree_depth(struct packing_data *pack,
+					 struct object_entry *e)
+{
+	if (!pack->tree_depth)
+		return 0;
+	return pack->tree_depth[e - pack->objects];
+}
+
+static inline void oe_set_tree_depth(struct packing_data *pack,
+				     struct object_entry *e,
+				     unsigned int tree_depth)
+{
+	if (!pack->tree_depth)
+		CALLOC_ARRAY(pack->tree_depth, pack->nr_alloc);
+	pack->tree_depth[e - pack->objects] = tree_depth;
+}
+
+static inline unsigned char oe_layer(struct packing_data *pack,
+				     struct object_entry *e)
+{
+	if (!pack->layer)
+		return 0;
+	return pack->layer[e - pack->objects];
+}
+
+static inline void oe_set_layer(struct packing_data *pack,
+				struct object_entry *e,
+				unsigned char layer)
+{
+	if (!pack->layer)
+		CALLOC_ARRAY(pack->layer, pack->nr_alloc);
+	pack->layer[e - pack->objects] = layer;
 }
 
 #endif
diff -pruN 1.2.1+git2.18.0-1/git/pack-revindex.c 1.2.3+git2.25.1-1/git/pack-revindex.c
--- 1.2.1+git2.18.0-1/git/pack-revindex.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/pack-revindex.c	2020-02-17 04:47:35.000000000 +0000
@@ -1,6 +1,7 @@
 #include "cache.h"
 #include "pack-revindex.h"
 #include "object-store.h"
+#include "packfile.h"
 
 /*
  * Pack index for existing packs give us easy access to the offsets into
@@ -119,19 +120,20 @@ static void sort_revindex(struct revinde
  */
 static void create_pack_revindex(struct packed_git *p)
 {
-	unsigned num_ent = p->num_objects;
+	const unsigned num_ent = p->num_objects;
 	unsigned i;
 	const char *index = p->index_data;
+	const unsigned hashsz = the_hash_algo->rawsz;
 
 	ALLOC_ARRAY(p->revindex, num_ent + 1);
 	index += 4 * 256;
 
 	if (p->index_version > 1) {
 		const uint32_t *off_32 =
-			(uint32_t *)(index + 8 + p->num_objects * (20 + 4));
+			(uint32_t *)(index + 8 + p->num_objects * (hashsz + 4));
 		const uint32_t *off_64 = off_32 + p->num_objects;
 		for (i = 0; i < num_ent; i++) {
-			uint32_t off = ntohl(*off_32++);
+			const uint32_t off = ntohl(*off_32++);
 			if (!(off & 0x80000000)) {
 				p->revindex[i].offset = off;
 			} else {
@@ -142,34 +144,39 @@ static void create_pack_revindex(struct
 		}
 	} else {
 		for (i = 0; i < num_ent; i++) {
-			uint32_t hl = *((uint32_t *)(index + 24 * i));
+			const uint32_t hl = *((uint32_t *)(index + (hashsz + 4) * i));
 			p->revindex[i].offset = ntohl(hl);
 			p->revindex[i].nr = i;
 		}
 	}
 
-	/* This knows the pack format -- the 20-byte trailer
+	/*
+	 * This knows the pack format -- the hash trailer
 	 * follows immediately after the last object data.
 	 */
-	p->revindex[num_ent].offset = p->pack_size - 20;
+	p->revindex[num_ent].offset = p->pack_size - hashsz;
 	p->revindex[num_ent].nr = -1;
 	sort_revindex(p->revindex, num_ent, p->pack_size);
 }
 
-void load_pack_revindex(struct packed_git *p)
+int load_pack_revindex(struct packed_git *p)
 {
-	if (!p->revindex)
+	if (!p->revindex) {
+		if (open_pack_index(p))
+			return -1;
 		create_pack_revindex(p);
+	}
+	return 0;
 }
 
 int find_revindex_position(struct packed_git *p, off_t ofs)
 {
 	int lo = 0;
 	int hi = p->num_objects + 1;
-	struct revindex_entry *revindex = p->revindex;
+	const struct revindex_entry *revindex = p->revindex;
 
 	do {
-		unsigned mi = lo + (hi - lo) / 2;
+		const unsigned mi = lo + (hi - lo) / 2;
 		if (revindex[mi].offset == ofs) {
 			return mi;
 		} else if (ofs < revindex[mi].offset)
@@ -186,7 +193,9 @@ struct revindex_entry *find_pack_revinde
 {
 	int pos;
 
-	load_pack_revindex(p);
+	if (load_pack_revindex(p))
+		return NULL;
+
 	pos = find_revindex_position(p, ofs);
 
 	if (pos < 0)
diff -pruN 1.2.1+git2.18.0-1/git/pack-revindex.h 1.2.3+git2.25.1-1/git/pack-revindex.h
--- 1.2.1+git2.18.0-1/git/pack-revindex.h	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/pack-revindex.h	2020-02-17 04:47:35.000000000 +0000
@@ -8,7 +8,7 @@ struct revindex_entry {
 	unsigned int nr;
 };
 
-void load_pack_revindex(struct packed_git *p);
+int load_pack_revindex(struct packed_git *p);
 int find_revindex_position(struct packed_git *p, off_t ofs);
 
 struct revindex_entry *find_pack_revindex(struct packed_git *p, off_t ofs);
diff -pruN 1.2.1+git2.18.0-1/git/pack-write.c 1.2.3+git2.25.1-1/git/pack-write.c
--- 1.2.1+git2.18.0-1/git/pack-write.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/pack-write.c	2020-02-17 04:47:35.000000000 +0000
@@ -124,7 +124,7 @@ const char *write_idx_file(const char *i
 		}
 		hashwrite(f, obj->oid.hash, the_hash_algo->rawsz);
 		if ((opts->flags & WRITE_IDX_STRICT) &&
-		    (i && !oidcmp(&list[-2]->oid, &obj->oid)))
+		    (i && oideq(&list[-2]->oid, &obj->oid)))
 			die("The same object %s appears twice in the pack",
 			    oid_to_hex(&obj->oid));
 	}
@@ -260,7 +260,7 @@ void fixup_pack_header_footer(int pack_f
 		if (partial_pack_offset == 0) {
 			unsigned char hash[GIT_MAX_RAWSZ];
 			the_hash_algo->final_fn(hash, &old_hash_ctx);
-			if (hashcmp(hash, partial_pack_hash) != 0)
+			if (!hasheq(hash, partial_pack_hash))
 				die("Unexpected checksum for %s "
 				    "(disk corruption?)", pack_name);
 			/*
@@ -349,7 +349,7 @@ void finish_tmp_packfile(struct strbuf *
 			 struct pack_idx_entry **written_list,
 			 uint32_t nr_written,
 			 struct pack_idx_option *pack_idx_opts,
-			 unsigned char sha1[])
+			 unsigned char hash[])
 {
 	const char *idx_tmp_name;
 	int basename_len = name_buffer->len;
@@ -358,18 +358,18 @@ void finish_tmp_packfile(struct strbuf *
 		die_errno("unable to make temporary pack file readable");
 
 	idx_tmp_name = write_idx_file(NULL, written_list, nr_written,
-				      pack_idx_opts, sha1);
+				      pack_idx_opts, hash);
 	if (adjust_shared_perm(idx_tmp_name))
 		die_errno("unable to make temporary index file readable");
 
-	strbuf_addf(name_buffer, "%s.pack", sha1_to_hex(sha1));
+	strbuf_addf(name_buffer, "%s.pack", hash_to_hex(hash));
 
 	if (rename(pack_tmp_name, name_buffer->buf))
 		die_errno("unable to rename temporary pack file");
 
 	strbuf_setlen(name_buffer, basename_len);
 
-	strbuf_addf(name_buffer, "%s.idx", sha1_to_hex(sha1));
+	strbuf_addf(name_buffer, "%s.idx", hash_to_hex(hash));
 	if (rename(idx_tmp_name, name_buffer->buf))
 		die_errno("unable to rename temporary index file");
 
diff -pruN 1.2.1+git2.18.0-1/git/pager.c 1.2.3+git2.25.1-1/git/pager.c
--- 1.2.1+git2.18.0-1/git/pager.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/pager.c	2020-02-17 04:47:35.000000000 +0000
@@ -100,6 +100,7 @@ void prepare_pager_args(struct child_pro
 	argv_array_push(&pager_process->args, pager);
 	pager_process->use_shell = 1;
 	setup_pager_env(&pager_process->env_array);
+	pager_process->trace2_child_class = "pager";
 }
 
 void setup_pager(void)
@@ -177,6 +178,26 @@ int term_columns(void)
 }
 
 /*
+ * Clear the entire line, leave cursor in first column.
+ */
+void term_clear_line(void)
+{
+	if (is_terminal_dumb())
+		/*
+		 * Fall back to print a terminal width worth of space
+		 * characters (hoping that the terminal is still as wide
+		 * as it was upon the first call to term_columns()).
+		 */
+		fprintf(stderr, "\r%*s\r", term_columns(), "");
+	else
+		/*
+		 * On non-dumb terminals use an escape sequence to clear
+		 * the whole line, no matter how wide the terminal.
+		 */
+		fputs("\r\033[K", stderr);
+}
+
+/*
  * How many columns do we need to show this number in decimal?
  */
 int decimal_width(uintmax_t number)
diff -pruN 1.2.1+git2.18.0-1/git/parse-options.c 1.2.3+git2.25.1-1/git/parse-options.c
--- 1.2.1+git2.18.0-1/git/parse-options.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/parse-options.c	2020-02-17 04:47:35.000000000 +0000
@@ -6,6 +6,8 @@
 #include "color.h"
 #include "utf8.h"
 
+static int disallow_abbreviated_options;
+
 #define OPT_SHORT 1
 #define OPT_UNSET 2
 
@@ -20,8 +22,9 @@ int optbug(const struct option *opt, con
 	return error("BUG: switch '%c' %s", opt->short_name, reason);
 }
 
-static int get_arg(struct parse_opt_ctx_t *p, const struct option *opt,
-		   int flags, const char **arg)
+static enum parse_opt_result get_arg(struct parse_opt_ctx_t *p,
+				     const struct option *opt,
+				     int flags, const char **arg)
 {
 	if (p->opt) {
 		*arg = p->opt;
@@ -32,7 +35,7 @@ static int get_arg(struct parse_opt_ctx_
 		p->argc--;
 		*arg = *++p->argv;
 	} else
-		return opterror(opt, "requires a value", flags);
+		return error(_("%s requires a value"), optname(opt, flags));
 	return 0;
 }
 
@@ -44,12 +47,12 @@ static void fix_filename(const char *pre
 	*file = prefix_filename(prefix, *file);
 }
 
-static int opt_command_mode_error(const struct option *opt,
-				  const struct option *all_opts,
-				  int flags)
+static enum parse_opt_result opt_command_mode_error(
+	const struct option *opt,
+	const struct option *all_opts,
+	int flags)
 {
 	const struct option *that;
-	struct strbuf message = STRBUF_INIT;
 	struct strbuf that_name = STRBUF_INIT;
 
 	/*
@@ -67,34 +70,34 @@ static int opt_command_mode_error(const
 			strbuf_addf(&that_name, "--%s", that->long_name);
 		else
 			strbuf_addf(&that_name, "-%c", that->short_name);
-		strbuf_addf(&message, ": incompatible with %s", that_name.buf);
+		error(_("%s is incompatible with %s"),
+		      optname(opt, flags), that_name.buf);
 		strbuf_release(&that_name);
-		opterror(opt, message.buf, flags);
-		strbuf_release(&message);
-		return -1;
+		return PARSE_OPT_ERROR;
 	}
-	return opterror(opt, ": incompatible with something else", flags);
+	return error(_("%s : incompatible with something else"),
+		     optname(opt, flags));
 }
 
-static int get_value(struct parse_opt_ctx_t *p,
-		     const struct option *opt,
-		     const struct option *all_opts,
-		     int flags)
+static enum parse_opt_result get_value(struct parse_opt_ctx_t *p,
+				       const struct option *opt,
+				       const struct option *all_opts,
+				       int flags)
 {
 	const char *s, *arg;
 	const int unset = flags & OPT_UNSET;
 	int err;
 
 	if (unset && p->opt)
-		return opterror(opt, "takes no value", flags);
+		return error(_("%s takes no value"), optname(opt, flags));
 	if (unset && (opt->flags & PARSE_OPT_NONEG))
-		return opterror(opt, "isn't available", flags);
+		return error(_("%s isn't available"), optname(opt, flags));
 	if (!(flags & OPT_SHORT) && p->opt && (opt->flags & PARSE_OPT_NOARG))
-		return opterror(opt, "takes no value", flags);
+		return error(_("%s takes no value"), optname(opt, flags));
 
 	switch (opt->type) {
 	case OPTION_LOWLEVEL_CALLBACK:
-		return (*(parse_opt_ll_cb *)opt->callback)(p, opt, unset);
+		return opt->ll_callback(p, opt, NULL, unset);
 
 	case OPTION_BIT:
 		if (unset)
@@ -110,6 +113,13 @@ static int get_value(struct parse_opt_ct
 			*(int *)opt->value &= ~opt->defval;
 		return 0;
 
+	case OPTION_BITOP:
+		if (unset)
+			BUG("BITOP can't have unset form");
+		*(int *)opt->value &= ~opt->extra;
+		*(int *)opt->value |= opt->defval;
+		return 0;
+
 	case OPTION_COUNTUP:
 		if (*(int *)opt->value < 0)
 			*(int *)opt->value = 0;
@@ -153,16 +163,27 @@ static int get_value(struct parse_opt_ct
 		return err;
 
 	case OPTION_CALLBACK:
+	{
+		const char *p_arg = NULL;
+		int p_unset;
+
 		if (unset)
-			return (*opt->callback)(opt, NULL, 1) ? (-1) : 0;
-		if (opt->flags & PARSE_OPT_NOARG)
-			return (*opt->callback)(opt, NULL, 0) ? (-1) : 0;
-		if (opt->flags & PARSE_OPT_OPTARG && !p->opt)
-			return (*opt->callback)(opt, NULL, 0) ? (-1) : 0;
-		if (get_arg(p, opt, flags, &arg))
+			p_unset = 1;
+		else if (opt->flags & PARSE_OPT_NOARG)
+			p_unset = 0;
+		else if (opt->flags & PARSE_OPT_OPTARG && !p->opt)
+			p_unset = 0;
+		else if (get_arg(p, opt, flags, &arg))
 			return -1;
-		return (*opt->callback)(opt, arg, 0) ? (-1) : 0;
-
+		else {
+			p_unset = 0;
+			p_arg = arg;
+		}
+		if (opt->callback)
+			return (*opt->callback)(opt, p_arg, p_unset) ? (-1) : 0;
+		else
+			return (*opt->ll_callback)(p, opt, p_arg, p_unset);
+	}
 	case OPTION_INTEGER:
 		if (unset) {
 			*(int *)opt->value = 0;
@@ -174,9 +195,13 @@ static int get_value(struct parse_opt_ct
 		}
 		if (get_arg(p, opt, flags, &arg))
 			return -1;
+		if (!*arg)
+			return error(_("%s expects a numerical value"),
+				     optname(opt, flags));
 		*(int *)opt->value = strtol(arg, (char **)&s, 10);
 		if (*s)
-			return opterror(opt, "expects a numerical value", flags);
+			return error(_("%s expects a numerical value"),
+				     optname(opt, flags));
 		return 0;
 
 	case OPTION_MAGNITUDE:
@@ -191,17 +216,18 @@ static int get_value(struct parse_opt_ct
 		if (get_arg(p, opt, flags, &arg))
 			return -1;
 		if (!git_parse_ulong(arg, opt->value))
-			return opterror(opt,
-				"expects a non-negative integer value with an optional k/m/g suffix",
-				flags);
+			return error(_("%s expects a non-negative integer value"
+				       " with an optional k/m/g suffix"),
+				     optname(opt, flags));
 		return 0;
 
 	default:
-		die("should not happen, someone must be hit on the forehead");
+		BUG("opt->type %d should not happen", opt->type);
 	}
 }
 
-static int parse_short_opt(struct parse_opt_ctx_t *p, const struct option *options)
+static enum parse_opt_result parse_short_opt(struct parse_opt_ctx_t *p,
+					     const struct option *options)
 {
 	const struct option *all_opts = options;
 	const struct option *numopt = NULL;
@@ -228,15 +254,48 @@ static int parse_short_opt(struct parse_
 			len++;
 		arg = xmemdupz(p->opt, len);
 		p->opt = p->opt[len] ? p->opt + len : NULL;
-		rc = (*numopt->callback)(numopt, arg, 0) ? (-1) : 0;
+		if (numopt->callback)
+			rc = (*numopt->callback)(numopt, arg, 0) ? (-1) : 0;
+		else
+			rc = (*numopt->ll_callback)(p, numopt, arg, 0);
 		free(arg);
 		return rc;
 	}
-	return -2;
+	return PARSE_OPT_UNKNOWN;
 }
 
-static int parse_long_opt(struct parse_opt_ctx_t *p, const char *arg,
-                          const struct option *options)
+static int has_string(const char *it, const char **array)
+{
+	while (*array)
+		if (!strcmp(it, *(array++)))
+			return 1;
+	return 0;
+}
+
+static int is_alias(struct parse_opt_ctx_t *ctx,
+		    const struct option *one_opt,
+		    const struct option *another_opt)
+{
+	const char **group;
+
+	if (!ctx->alias_groups)
+		return 0;
+
+	if (!one_opt->long_name || !another_opt->long_name)
+		return 0;
+
+	for (group = ctx->alias_groups; *group; group += 3) {
+		/* it and other are from the same family? */
+		if (has_string(one_opt->long_name, group) &&
+		    has_string(another_opt->long_name, group))
+			return 1;
+	}
+	return 0;
+}
+
+static enum parse_opt_result parse_long_opt(
+	struct parse_opt_ctx_t *p, const char *arg,
+	const struct option *options)
 {
 	const struct option *all_opts = options;
 	const char *arg_end = strchrnul(arg, '=');
@@ -257,17 +316,22 @@ again:
 			if (!rest)
 				continue;
 			if (*rest == '=')
-				return opterror(options, "takes no value", flags);
+				return error(_("%s takes no value"),
+					     optname(options, flags));
 			if (*rest)
 				continue;
+			if (options->value)
+				*(int *)options->value = options->defval;
 			p->out[p->cpidx++] = arg - 2;
-			return 0;
+			return PARSE_OPT_DONE;
 		}
 		if (!rest) {
 			/* abbreviated? */
-			if (!strncmp(long_name, arg, arg_end - arg)) {
+			if (!(p->flags & PARSE_OPT_KEEP_UNKNOWN) &&
+			    !strncmp(long_name, arg, arg_end - arg)) {
 is_abbreviated:
-				if (abbrev_option) {
+				if (abbrev_option &&
+				    !is_alias(p, abbrev_option, options)) {
 					/*
 					 * If this is abbreviated, it is
 					 * ambiguous. So when there is no
@@ -317,19 +381,23 @@ is_abbreviated:
 		return get_value(p, options, all_opts, flags ^ opt_flags);
 	}
 
+	if (disallow_abbreviated_options && (ambiguous_option || abbrev_option))
+		die("disallowed abbreviated or ambiguous option '%.*s'",
+		    (int)(arg_end - arg), arg);
+
 	if (ambiguous_option) {
-		error("Ambiguous option: %s "
-			"(could be --%s%s or --%s%s)",
+		error(_("ambiguous option: %s "
+			"(could be --%s%s or --%s%s)"),
 			arg,
 			(ambiguous_flags & OPT_UNSET) ?  "no-" : "",
 			ambiguous_option->long_name,
 			(abbrev_flags & OPT_UNSET) ?  "no-" : "",
 			abbrev_option->long_name);
-		return -3;
+		return PARSE_OPT_HELP;
 	}
 	if (abbrev_option)
 		return get_value(p, abbrev_option, all_opts, abbrev_flags);
-	return -2;
+	return PARSE_OPT_UNKNOWN;
 }
 
 static int parse_nodash_opt(struct parse_opt_ctx_t *p, const char *arg,
@@ -352,7 +420,7 @@ static void check_typos(const char *arg,
 		return;
 
 	if (starts_with(arg, "no-")) {
-		error ("did you mean `--%s` (with two dashes ?)", arg);
+		error(_("did you mean `--%s` (with two dashes)?"), arg);
 		exit(129);
 	}
 
@@ -360,7 +428,7 @@ static void check_typos(const char *arg,
 		if (!options->long_name)
 			continue;
 		if (starts_with(options->long_name, arg)) {
-			error ("did you mean `--%s` (with two dashes ?)", arg);
+			error(_("did you mean `--%s` (with two dashes)?"), arg);
 			exit(129);
 		}
 	}
@@ -399,6 +467,23 @@ static void parse_options_check(const st
 			if ((opts->flags & PARSE_OPT_OPTARG) ||
 			    !(opts->flags & PARSE_OPT_NOARG))
 				err |= optbug(opts, "should not accept an argument");
+			break;
+		case OPTION_CALLBACK:
+			if (!opts->callback && !opts->ll_callback)
+				BUG("OPTION_CALLBACK needs one callback");
+			if (opts->callback && opts->ll_callback)
+				BUG("OPTION_CALLBACK can't have two callbacks");
+			break;
+		case OPTION_LOWLEVEL_CALLBACK:
+			if (!opts->ll_callback)
+				BUG("OPTION_LOWLEVEL_CALLBACK needs a callback");
+			if (opts->callback)
+				BUG("OPTION_LOWLEVEL_CALLBACK needs no high level callback");
+			break;
+		case OPTION_ALIAS:
+			BUG("OPT_ALIAS() should not remain at this point. "
+			    "Are you using parse_options_step() directly?\n"
+			    "That case is not supported yet.");
 		default:
 			; /* ok. (usually accepts an argument) */
 		}
@@ -410,30 +495,91 @@ static void parse_options_check(const st
 		exit(128);
 }
 
-void parse_options_start(struct parse_opt_ctx_t *ctx,
-			 int argc, const char **argv, const char *prefix,
-			 const struct option *options, int flags)
-{
-	memset(ctx, 0, sizeof(*ctx));
-	ctx->argc = ctx->total = argc - 1;
-	ctx->argv = argv + 1;
-	ctx->out  = argv;
+static void parse_options_start_1(struct parse_opt_ctx_t *ctx,
+				  int argc, const char **argv, const char *prefix,
+				  const struct option *options, int flags)
+{
+	ctx->argc = argc;
+	ctx->argv = argv;
+	if (!(flags & PARSE_OPT_ONE_SHOT)) {
+		ctx->argc--;
+		ctx->argv++;
+	}
+	ctx->total = ctx->argc;
+	ctx->out   = argv;
 	ctx->prefix = prefix;
 	ctx->cpidx = ((flags & PARSE_OPT_KEEP_ARGV0) != 0);
 	ctx->flags = flags;
 	if ((flags & PARSE_OPT_KEEP_UNKNOWN) &&
-	    (flags & PARSE_OPT_STOP_AT_NON_OPTION))
-		die("STOP_AT_NON_OPTION and KEEP_UNKNOWN don't go together");
+	    (flags & PARSE_OPT_STOP_AT_NON_OPTION) &&
+	    !(flags & PARSE_OPT_ONE_SHOT))
+		BUG("STOP_AT_NON_OPTION and KEEP_UNKNOWN don't go together");
+	if ((flags & PARSE_OPT_ONE_SHOT) &&
+	    (flags & PARSE_OPT_KEEP_ARGV0))
+		BUG("Can't keep argv0 if you don't have it");
 	parse_options_check(options);
 }
 
-/*
- * TODO: we are not completing the --no-XXX form yet because there are
- * many options that do not suppress it properly.
- */
-static int show_gitcomp(struct parse_opt_ctx_t *ctx,
-			const struct option *opts)
+void parse_options_start(struct parse_opt_ctx_t *ctx,
+			 int argc, const char **argv, const char *prefix,
+			 const struct option *options, int flags)
+{
+	memset(ctx, 0, sizeof(*ctx));
+	parse_options_start_1(ctx, argc, argv, prefix, options, flags);
+}
+
+static void show_negated_gitcomp(const struct option *opts, int nr_noopts)
+{
+	int printed_dashdash = 0;
+
+	for (; opts->type != OPTION_END; opts++) {
+		int has_unset_form = 0;
+		const char *name;
+
+		if (!opts->long_name)
+			continue;
+		if (opts->flags & (PARSE_OPT_HIDDEN | PARSE_OPT_NOCOMPLETE))
+			continue;
+		if (opts->flags & PARSE_OPT_NONEG)
+			continue;
+
+		switch (opts->type) {
+		case OPTION_STRING:
+		case OPTION_FILENAME:
+		case OPTION_INTEGER:
+		case OPTION_MAGNITUDE:
+		case OPTION_CALLBACK:
+		case OPTION_BIT:
+		case OPTION_NEGBIT:
+		case OPTION_COUNTUP:
+		case OPTION_SET_INT:
+			has_unset_form = 1;
+			break;
+		default:
+			break;
+		}
+		if (!has_unset_form)
+			continue;
+
+		if (skip_prefix(opts->long_name, "no-", &name)) {
+			if (nr_noopts < 0)
+				printf(" --%s", name);
+		} else if (nr_noopts >= 0) {
+			if (nr_noopts && !printed_dashdash) {
+				printf(" --");
+				printed_dashdash = 1;
+			}
+			printf(" --no-%s", opts->long_name);
+			nr_noopts++;
+		}
+	}
+}
+
+static int show_gitcomp(const struct option *opts)
 {
+	const struct option *original_opts = opts;
+	int nr_noopts = 0;
+
 	for (; opts->type != OPTION_END; opts++) {
 		const char *suffix = "";
 
@@ -463,10 +609,91 @@ static int show_gitcomp(struct parse_opt
 		}
 		if (opts->flags & PARSE_OPT_COMP_ARG)
 			suffix = "=";
+		if (starts_with(opts->long_name, "no-"))
+			nr_noopts++;
 		printf(" --%s%s", opts->long_name, suffix);
 	}
+	show_negated_gitcomp(original_opts, -1);
+	show_negated_gitcomp(original_opts, nr_noopts);
 	fputc('\n', stdout);
-	exit(0);
+	return PARSE_OPT_COMPLETE;
+}
+
+/*
+ * Scan and may produce a new option[] array, which should be used
+ * instead of the original 'options'.
+ *
+ * Right now this is only used to preprocess and substitute
+ * OPTION_ALIAS.
+ */
+static struct option *preprocess_options(struct parse_opt_ctx_t *ctx,
+					 const struct option *options)
+{
+	struct option *newopt;
+	int i, nr, alias;
+	int nr_aliases = 0;
+
+	for (nr = 0; options[nr].type != OPTION_END; nr++) {
+		if (options[nr].type == OPTION_ALIAS)
+			nr_aliases++;
+	}
+
+	if (!nr_aliases)
+		return NULL;
+
+	ALLOC_ARRAY(newopt, nr + 1);
+	COPY_ARRAY(newopt, options, nr + 1);
+
+	/* each alias has two string pointers and NULL */
+	CALLOC_ARRAY(ctx->alias_groups, 3 * (nr_aliases + 1));
+
+	for (alias = 0, i = 0; i < nr; i++) {
+		int short_name;
+		const char *long_name;
+		const char *source;
+		int j;
+
+		if (newopt[i].type != OPTION_ALIAS)
+			continue;
+
+		short_name = newopt[i].short_name;
+		long_name = newopt[i].long_name;
+		source = newopt[i].value;
+
+		if (!long_name)
+			BUG("An alias must have long option name");
+
+		for (j = 0; j < nr; j++) {
+			const char *name = options[j].long_name;
+
+			if (!name || strcmp(name, source))
+				continue;
+
+			if (options[j].type == OPTION_ALIAS)
+				BUG("No please. Nested aliases are not supported.");
+
+			/*
+			 * NEEDSWORK: this is a bit inconsistent because
+			 * usage_with_options() on the original options[] will print
+			 * help string as "alias of %s" but "git cmd -h" will
+			 * print the original help string.
+			 */
+			memcpy(newopt + i, options + j, sizeof(*newopt));
+			newopt[i].short_name = short_name;
+			newopt[i].long_name = long_name;
+			break;
+		}
+
+		if (j == nr)
+			BUG("could not find source option '%s' of alias '%s'",
+			    source, newopt[i].long_name);
+		ctx->alias_groups[alias * 3 + 0] = newopt[i].long_name;
+		ctx->alias_groups[alias * 3 + 1] = options[j].long_name;
+		ctx->alias_groups[alias * 3 + 2] = NULL;
+		alias++;
+	}
+
+	return newopt;
 }
 
 static int usage_with_options_internal(struct parse_opt_ctx_t *,
@@ -485,6 +712,10 @@ int parse_options_step(struct parse_opt_
 	for (; ctx->argc; ctx->argc--, ctx->argv++) {
 		const char *arg = ctx->argv[0];
 
+		if (ctx->flags & PARSE_OPT_ONE_SHOT &&
+		    ctx->argc != ctx->total)
+			break;
+
 		if (*arg != '-' || !arg[1]) {
 			if (parse_nodash_opt(ctx, arg, options) == 0)
 				continue;
@@ -500,27 +731,33 @@ int parse_options_step(struct parse_opt_
 
 		/* lone --git-completion-helper is asked by git-completion.bash */
 		if (ctx->total == 1 && !strcmp(arg + 1, "-git-completion-helper"))
-			return show_gitcomp(ctx, options);
+			return show_gitcomp(options);
 
 		if (arg[1] != '-') {
 			ctx->opt = arg + 1;
 			switch (parse_short_opt(ctx, options)) {
-			case -1:
+			case PARSE_OPT_ERROR:
 				return PARSE_OPT_ERROR;
-			case -2:
+			case PARSE_OPT_UNKNOWN:
 				if (ctx->opt)
 					check_typos(arg + 1, options);
 				if (internal_help && *ctx->opt == 'h')
 					goto show_usage;
 				goto unknown;
+			case PARSE_OPT_NON_OPTION:
+			case PARSE_OPT_HELP:
+			case PARSE_OPT_COMPLETE:
+				BUG("parse_short_opt() cannot return these");
+			case PARSE_OPT_DONE:
+				break;
 			}
 			if (ctx->opt)
 				check_typos(arg + 1, options);
 			while (ctx->opt) {
 				switch (parse_short_opt(ctx, options)) {
-				case -1:
+				case PARSE_OPT_ERROR:
 					return PARSE_OPT_ERROR;
-				case -2:
+				case PARSE_OPT_UNKNOWN:
 					if (internal_help && *ctx->opt == 'h')
 						goto show_usage;
 
@@ -532,12 +769,19 @@ int parse_options_step(struct parse_opt_
 					ctx->argv[0] = xstrdup(ctx->opt - 1);
 					*(char *)ctx->argv[0] = '-';
 					goto unknown;
+				case PARSE_OPT_NON_OPTION:
+				case PARSE_OPT_COMPLETE:
+				case PARSE_OPT_HELP:
+					BUG("parse_short_opt() cannot return these");
+				case PARSE_OPT_DONE:
+					break;
 				}
 			}
 			continue;
 		}
 
-		if (!arg[2]) { /* "--" */
+		if (!arg[2] /* "--" */ ||
+		    !strcmp(arg + 2, "end-of-options")) {
 			if (!(ctx->flags & PARSE_OPT_KEEP_DASHDASH)) {
 				ctx->argc--;
 				ctx->argv++;
@@ -550,15 +794,22 @@ int parse_options_step(struct parse_opt_
 		if (internal_help && !strcmp(arg + 2, "help"))
 			goto show_usage;
 		switch (parse_long_opt(ctx, arg + 2, options)) {
-		case -1:
+		case PARSE_OPT_ERROR:
 			return PARSE_OPT_ERROR;
-		case -2:
+		case PARSE_OPT_UNKNOWN:
 			goto unknown;
-		case -3:
+		case PARSE_OPT_HELP:
 			goto show_usage;
+		case PARSE_OPT_NON_OPTION:
+		case PARSE_OPT_COMPLETE:
+			BUG("parse_long_opt() cannot return these");
+		case PARSE_OPT_DONE:
+			break;
 		}
 		continue;
 unknown:
+		if (ctx->flags & PARSE_OPT_ONE_SHOT)
+			break;
 		if (!(ctx->flags & PARSE_OPT_KEEP_UNKNOWN))
 			return PARSE_OPT_UNKNOWN;
 		ctx->out[ctx->cpidx++] = ctx->argv[0];
@@ -572,6 +823,9 @@ unknown:
 
 int parse_options_end(struct parse_opt_ctx_t *ctx)
 {
+	if (ctx->flags & PARSE_OPT_ONE_SHOT)
+		return ctx->total - ctx->argc;
+
 	MOVE_ARRAY(ctx->out + ctx->cpidx, ctx->argv, ctx->argc);
 	ctx->out[ctx->cpidx + ctx->argc] = NULL;
 	return ctx->cpidx + ctx->argc;
@@ -582,35 +836,48 @@ int parse_options(int argc, const char *
 		  int flags)
 {
 	struct parse_opt_ctx_t ctx;
+	struct option *real_options;
+
+	disallow_abbreviated_options =
+		git_env_bool("GIT_TEST_DISALLOW_ABBREVIATED_OPTIONS", 0);
 
-	parse_options_start(&ctx, argc, argv, prefix, options, flags);
+	memset(&ctx, 0, sizeof(ctx));
+	real_options = preprocess_options(&ctx, options);
+	if (real_options)
+		options = real_options;
+	parse_options_start_1(&ctx, argc, argv, prefix, options, flags);
 	switch (parse_options_step(&ctx, options, usagestr)) {
 	case PARSE_OPT_HELP:
 	case PARSE_OPT_ERROR:
 		exit(129);
+	case PARSE_OPT_COMPLETE:
+		exit(0);
 	case PARSE_OPT_NON_OPTION:
 	case PARSE_OPT_DONE:
 		break;
 	default: /* PARSE_OPT_UNKNOWN */
 		if (ctx.argv[0][1] == '-') {
-			error("unknown option `%s'", ctx.argv[0] + 2);
+			error(_("unknown option `%s'"), ctx.argv[0] + 2);
 		} else if (isascii(*ctx.opt)) {
-			error("unknown switch `%c'", *ctx.opt);
+			error(_("unknown switch `%c'"), *ctx.opt);
 		} else {
-			error("unknown non-ascii option in string: `%s'",
+			error(_("unknown non-ascii option in string: `%s'"),
 			      ctx.argv[0]);
 		}
 		usage_with_options(usagestr, options);
 	}
 
 	precompose_argv(argc, argv);
+	free(real_options);
+	free(ctx.alias_groups);
 	return parse_options_end(&ctx);
 }
 
 static int usage_argh(const struct option *opts, FILE *outfile)
 {
 	const char *s;
-	int literal = (opts->flags & PARSE_OPT_LITERAL_ARGHELP) || !opts->argh;
+	int literal = (opts->flags & PARSE_OPT_LITERAL_ARGHELP) ||
+		!opts->argh || !!strpbrk(opts->argh, "()<>[]|");
 	if (opts->flags & PARSE_OPT_OPTARG)
 		if (opts->long_name)
 			s = literal ? "[=%s]" : "[=<%s>]";
@@ -697,6 +964,12 @@ static int usage_with_options_internal(s
 			fputc('\n', outfile);
 			pad = USAGE_OPTS_WIDTH;
 		}
+		if (opts->type == OPTION_ALIAS) {
+			fprintf(outfile, "%*s", pad + USAGE_GAP, "");
+			fprintf_ln(outfile, _("alias of --%s"),
+				   (const char *)opts->value);
+			continue;
+		}
 		fprintf(outfile, "%*s%s\n", pad + USAGE_GAP, "", _(opts->help));
 	}
 	fputc('\n', outfile);
@@ -722,12 +995,17 @@ void NORETURN usage_msg_opt(const char *
 	usage_with_options(usagestr, options);
 }
 
-#undef opterror
-int opterror(const struct option *opt, const char *reason, int flags)
+const char *optname(const struct option *opt, int flags)
 {
+	static struct strbuf sb = STRBUF_INIT;
+
+	strbuf_reset(&sb);
 	if (flags & OPT_SHORT)
-		return error("switch `%c' %s", opt->short_name, reason);
-	if (flags & OPT_UNSET)
-		return error("option `no-%s' %s", opt->long_name, reason);
-	return error("option `%s' %s", opt->long_name, reason);
+		strbuf_addf(&sb, "switch `%c'", opt->short_name);
+	else if (flags & OPT_UNSET)
+		strbuf_addf(&sb, "option `no-%s'", opt->long_name);
+	else
+		strbuf_addf(&sb, "option `%s'", opt->long_name);
+
+	return sb.buf;
 }
diff -pruN 1.2.1+git2.18.0-1/git/parse-options-cb.c 1.2.3+git2.25.1-1/git/parse-options-cb.c
--- 1.2.1+git2.18.0-1/git/parse-options-cb.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/parse-options-cb.c	2020-02-17 04:47:35.000000000 +0000
@@ -16,25 +16,22 @@ int parse_opt_abbrev_cb(const struct opt
 	if (!arg) {
 		v = unset ? 0 : DEFAULT_ABBREV;
 	} else {
+		if (!*arg)
+			return error(_("option `%s' expects a numerical value"),
+				     opt->long_name);
 		v = strtol(arg, (char **)&arg, 10);
 		if (*arg)
-			return opterror(opt, "expects a numerical value", 0);
+			return error(_("option `%s' expects a numerical value"),
+				     opt->long_name);
 		if (v && v < MINIMUM_ABBREV)
 			v = MINIMUM_ABBREV;
-		else if (v > 40)
-			v = 40;
+		else if (v > the_hash_algo->hexsz)
+			v = the_hash_algo->hexsz;
 	}
 	*(int *)(opt->value) = v;
 	return 0;
 }
 
-int parse_opt_approxidate_cb(const struct option *opt, const char *arg,
-			     int unset)
-{
-	*(timestamp_t *)(opt->value) = approxidate(arg);
-	return 0;
-}
-
 int parse_opt_expiry_date_cb(const struct option *opt, const char *arg,
 			     int unset)
 {
@@ -54,8 +51,8 @@ int parse_opt_color_flag_cb(const struct
 		arg = unset ? "never" : (const char *)opt->defval;
 	value = git_config_colorbool(NULL, arg);
 	if (value < 0)
-		return opterror(opt,
-			"expects \"always\", \"auto\", or \"never\"", 0);
+		return error(_("option `%s' expects \"always\", \"auto\", or \"never\""),
+			     opt->long_name);
 	*(int *)opt->value = value;
 	return 0;
 }
@@ -65,6 +62,8 @@ int parse_opt_verbosity_cb(const struct
 {
 	int *target = opt->value;
 
+	BUG_ON_OPT_ARG(arg);
+
 	if (unset)
 		/* --no-quiet, --no-verbose */
 		*target = 0;
@@ -87,17 +86,36 @@ int parse_opt_commits(const struct optio
 	struct object_id oid;
 	struct commit *commit;
 
+	BUG_ON_OPT_NEG(unset);
+
 	if (!arg)
 		return -1;
 	if (get_oid(arg, &oid))
 		return error("malformed object name %s", arg);
-	commit = lookup_commit_reference(&oid);
+	commit = lookup_commit_reference(the_repository, &oid);
 	if (!commit)
 		return error("no such commit %s", arg);
 	commit_list_insert(commit, opt->value);
 	return 0;
 }
 
+int parse_opt_commit(const struct option *opt, const char *arg, int unset)
+{
+	struct object_id oid;
+	struct commit *commit;
+	struct commit **target = opt->value;
+
+	if (!arg)
+		return -1;
+	if (get_oid(arg, &oid))
+		return error("malformed object name %s", arg);
+	commit = lookup_commit_reference(the_repository, &oid);
+	if (!commit)
+		return error("no such commit %s", arg);
+	*target = commit;
+	return 0;
+}
+
 int parse_opt_object_name(const struct option *opt, const char *arg, int unset)
 {
 	struct object_id oid;
@@ -114,13 +132,51 @@ int parse_opt_object_name(const struct o
 	return 0;
 }
 
+int parse_opt_object_id(const struct option *opt, const char *arg, int unset)
+{
+	struct object_id oid;
+	struct object_id *target = opt->value;
+
+	if (unset) {
+		*target = null_oid;
+		return 0;
+	}
+	if (!arg)
+		return -1;
+	if (get_oid(arg, &oid))
+		return error(_("malformed object name '%s'"), arg);
+	*target = oid;
+	return 0;
+}
+
 int parse_opt_tertiary(const struct option *opt, const char *arg, int unset)
 {
 	int *target = opt->value;
+
+	BUG_ON_OPT_ARG(arg);
+
 	*target = unset ? 2 : 1;
 	return 0;
 }
 
+struct option *parse_options_dup(const struct option *o)
+{
+	const struct option *orig = o;
+	struct option *opts;
+	int nr = 0;
+
+	while (o && o->type != OPTION_END) {
+		nr++;
+		o++;
+	}
+
+	ALLOC_ARRAY(opts, nr + 1);
+	COPY_ARRAY(opts, orig, nr);
+	memset(opts + nr, 0, sizeof(*opts));
+	opts[nr].type = OPTION_END;
+	return opts;
+}
+
 struct option *parse_options_concat(struct option *a, struct option *b)
 {
 	struct option *ret;
@@ -169,9 +225,12 @@ int parse_opt_noop_cb(const struct optio
  * "-h" output even if it's not being handled directly by
  * parse_options().
  */
-int parse_opt_unknown_cb(const struct option *opt, const char *arg, int unset)
+enum parse_opt_result parse_opt_unknown_cb(struct parse_opt_ctx_t *ctx,
+					   const struct option *opt,
+					   const char *arg, int unset)
 {
-	return -2;
+	BUG_ON_OPT_ARG(arg);
+	return PARSE_OPT_UNKNOWN;
 }
 
 /**
diff -pruN 1.2.1+git2.18.0-1/git/parse-options.h 1.2.3+git2.25.1-1/git/parse-options.h
--- 1.2.1+git2.18.0-1/git/parse-options.h	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/parse-options.h	2020-02-17 04:47:35.000000000 +0000
@@ -1,15 +1,21 @@
 #ifndef PARSE_OPTIONS_H
 #define PARSE_OPTIONS_H
 
+/**
+ * Refer to Documentation/technical/api-parse-options.txt for the API doc.
+ */
+
 enum parse_opt_type {
 	/* special types */
 	OPTION_END,
 	OPTION_ARGUMENT,
 	OPTION_GROUP,
 	OPTION_NUMBER,
+	OPTION_ALIAS,
 	/* options with no arguments */
 	OPTION_BIT,
 	OPTION_NEGBIT,
+	OPTION_BITOP,
 	OPTION_COUNTUP,
 	OPTION_SET_INT,
 	OPTION_CMDMODE,
@@ -27,7 +33,8 @@ enum parse_opt_flags {
 	PARSE_OPT_STOP_AT_NON_OPTION = 2,
 	PARSE_OPT_KEEP_ARGV0 = 4,
 	PARSE_OPT_KEEP_UNKNOWN = 8,
-	PARSE_OPT_NO_INTERNAL_HELP = 16
+	PARSE_OPT_NO_INTERNAL_HELP = 16,
+	PARSE_OPT_ONE_SHOT = 32
 };
 
 enum parse_opt_option_flags {
@@ -43,12 +50,22 @@ enum parse_opt_option_flags {
 	PARSE_OPT_COMP_ARG = 1024
 };
 
+enum parse_opt_result {
+	PARSE_OPT_COMPLETE = -3,
+	PARSE_OPT_HELP = -2,
+	PARSE_OPT_ERROR = -1,	/* must be the same as error() */
+	PARSE_OPT_DONE = 0,	/* fixed so that "return 0" works */
+	PARSE_OPT_NON_OPTION,
+	PARSE_OPT_UNKNOWN
+};
+
 struct option;
 typedef int parse_opt_cb(const struct option *, const char *arg, int unset);
 
 struct parse_opt_ctx_t;
-typedef int parse_opt_ll_cb(struct parse_opt_ctx_t *ctx,
-				const struct option *opt, int unset);
+typedef enum parse_opt_result parse_opt_ll_cb(struct parse_opt_ctx_t *ctx,
+					      const struct option *opt,
+					      const char *arg, int unset);
 
 /*
  * `type`::
@@ -98,13 +115,16 @@ typedef int parse_opt_ll_cb(struct parse
  *			 the option takes optional argument.
  *
  * `callback`::
- *   pointer to the callback to use for OPTION_CALLBACK or
- *   OPTION_LOWLEVEL_CALLBACK.
+ *   pointer to the callback to use for OPTION_CALLBACK
  *
  * `defval`::
  *   default value to fill (*->value) with for PARSE_OPT_OPTARG.
  *   OPTION_{BIT,SET_INT} store the {mask,integer} to put in the value when met.
  *   CALLBACKS can use it like they want.
+ *
+ * `ll_callback`::
+ *   pointer to the callback to use for OPTION_LOWLEVEL_CALLBACK
+ *
  */
 struct option {
 	enum parse_opt_type type;
@@ -117,6 +137,8 @@ struct option {
 	int flags;
 	parse_opt_cb *callback;
 	intptr_t defval;
+	parse_opt_ll_cb *ll_callback;
+	intptr_t extra;
 };
 
 #define OPT_BIT_F(s, l, v, h, b, f) { OPTION_BIT, (s), (l), (v), NULL, (h), \
@@ -126,12 +148,19 @@ struct option {
 #define OPT_SET_INT_F(s, l, v, h, i, f) { OPTION_SET_INT, (s), (l), (v), NULL, \
 					  (h), PARSE_OPT_NOARG | (f), NULL, (i) }
 #define OPT_BOOL_F(s, l, v, h, f)   OPT_SET_INT_F(s, l, v, h, 1, f)
+#define OPT_CALLBACK_F(s, l, v, a, h, f, cb)			\
+	{ OPTION_CALLBACK, (s), (l), (v), (a), (h), (f), (cb) }
+#define OPT_STRING_F(s, l, v, a, h, f)   { OPTION_STRING,  (s), (l), (v), (a), (h), (f) }
+#define OPT_INTEGER_F(s, l, v, h, f)     { OPTION_INTEGER, (s), (l), (v), N_("n"), (h), (f) }
 
 #define OPT_END()                   { OPTION_END }
-#define OPT_ARGUMENT(l, h)          { OPTION_ARGUMENT, 0, (l), NULL, NULL, \
-				      (h), PARSE_OPT_NOARG}
+#define OPT_ARGUMENT(l, v, h)       { OPTION_ARGUMENT, 0, (l), (v), NULL, \
+				      (h), PARSE_OPT_NOARG, NULL, 1 }
 #define OPT_GROUP(h)                { OPTION_GROUP, 0, NULL, NULL, NULL, (h) }
 #define OPT_BIT(s, l, v, h, b)      OPT_BIT_F(s, l, v, h, b, 0)
+#define OPT_BITOP(s, l, v, h, set, clear) { OPTION_BITOP, (s), (l), (v), NULL, (h), \
+					    PARSE_OPT_NOARG|PARSE_OPT_NONEG, NULL, \
+					    (set), NULL, (clear) }
 #define OPT_NEGBIT(s, l, v, h, b)   { OPTION_NEGBIT, (s), (l), (v), NULL, \
 				      (h), PARSE_OPT_NOARG, NULL, (b) }
 #define OPT_COUNTUP(s, l, v, h)     OPT_COUNTUP_F(s, l, v, h, 0)
@@ -141,23 +170,19 @@ struct option {
 				      (h), PARSE_OPT_NOARG | PARSE_OPT_HIDDEN, NULL, 1}
 #define OPT_CMDMODE(s, l, v, h, i)  { OPTION_CMDMODE, (s), (l), (v), NULL, \
 				      (h), PARSE_OPT_NOARG|PARSE_OPT_NONEG, NULL, (i) }
-#define OPT_INTEGER(s, l, v, h)     { OPTION_INTEGER, (s), (l), (v), N_("n"), (h) }
+#define OPT_INTEGER(s, l, v, h)     OPT_INTEGER_F(s, l, v, h, 0)
 #define OPT_MAGNITUDE(s, l, v, h)   { OPTION_MAGNITUDE, (s), (l), (v), \
 				      N_("n"), (h), PARSE_OPT_NONEG }
-#define OPT_STRING(s, l, v, a, h)   { OPTION_STRING,  (s), (l), (v), (a), (h) }
+#define OPT_STRING(s, l, v, a, h)   OPT_STRING_F(s, l, v, a, h, 0)
 #define OPT_STRING_LIST(s, l, v, a, h) \
 				    { OPTION_CALLBACK, (s), (l), (v), (a), \
 				      (h), 0, &parse_opt_string_list }
 #define OPT_UYN(s, l, v, h)         { OPTION_CALLBACK, (s), (l), (v), NULL, \
 				      (h), PARSE_OPT_NOARG, &parse_opt_tertiary }
-#define OPT_DATE(s, l, v, h) \
-	{ OPTION_CALLBACK, (s), (l), (v), N_("time"),(h), 0,	\
-	  parse_opt_approxidate_cb }
 #define OPT_EXPIRY_DATE(s, l, v, h) \
 	{ OPTION_CALLBACK, (s), (l), (v), N_("expiry-date"),(h), 0,	\
 	  parse_opt_expiry_date_cb }
-#define OPT_CALLBACK(s, l, v, a, h, f) \
-	{ OPTION_CALLBACK, (s), (l), (v), (a), (h), 0, (f) }
+#define OPT_CALLBACK(s, l, v, a, h, f) OPT_CALLBACK_F(s, l, v, a, h, 0, f)
 #define OPT_NUMBER_CALLBACK(v, h, f) \
 	{ OPTION_NUMBER, 0, NULL, (v), NULL, (h), \
 	  PARSE_OPT_NOARG | PARSE_OPT_NONEG, (f) }
@@ -172,37 +197,62 @@ struct option {
 	  N_("no-op (backward compatibility)"),		\
 	  PARSE_OPT_HIDDEN | PARSE_OPT_NOARG, parse_opt_noop_cb }
 
-/* parse_options() will filter out the processed options and leave the
- * non-option arguments in argv[]. usagestr strings should be marked
- * for translation with N_().
+#define OPT_ALIAS(s, l, source_long_name) \
+	{ OPTION_ALIAS, (s), (l), (source_long_name) }
+
+/*
+ * parse_options() will filter out the processed options and leave the
+ * non-option arguments in argv[]. argv0 is assumed program name and
+ * skipped.
+ *
+ * usagestr strings should be marked for translation with N_().
+ *
  * Returns the number of arguments left in argv[].
+ *
+ * In one-shot mode, argv0 is not a program name, argv[] is left
+ * untouched and parse_options() returns the number of options
+ * processed.
  */
-extern int parse_options(int argc, const char **argv, const char *prefix,
-                         const struct option *options,
-                         const char * const usagestr[], int flags);
-
-extern NORETURN void usage_with_options(const char * const *usagestr,
-                                        const struct option *options);
-
-extern NORETURN void usage_msg_opt(const char *msg,
-				   const char * const *usagestr,
-				   const struct option *options);
-
-extern int optbug(const struct option *opt, const char *reason);
-extern int opterror(const struct option *opt, const char *reason, int flags);
-#if defined(__GNUC__)
-#define opterror(o,r,f) (opterror((o),(r),(f)), const_error())
-#endif
+int parse_options(int argc, const char **argv, const char *prefix,
+		  const struct option *options,
+		  const char * const usagestr[], int flags);
+
+NORETURN void usage_with_options(const char * const *usagestr,
+				 const struct option *options);
+
+NORETURN void usage_msg_opt(const char *msg,
+			    const char * const *usagestr,
+			    const struct option *options);
 
-/*----- incremental advanced APIs -----*/
+int optbug(const struct option *opt, const char *reason);
+const char *optname(const struct option *opt, int flags);
 
-enum {
-	PARSE_OPT_HELP = -1,
-	PARSE_OPT_DONE,
-	PARSE_OPT_NON_OPTION,
-	PARSE_OPT_ERROR,
-	PARSE_OPT_UNKNOWN
-};
+/*
+ * Use these assertions for callbacks that expect to be called with NONEG and
+ * NOARG respectively, and do not otherwise handle the "unset" and "arg"
+ * parameters.
+ */
+#define BUG_ON_OPT_NEG(unset) do { \
+	if ((unset)) \
+		BUG("option callback does not expect negation"); \
+} while (0)
+#define BUG_ON_OPT_ARG(arg) do { \
+	if ((arg)) \
+		BUG("option callback does not expect an argument"); \
+} while (0)
+
+/*
+ * Similar to the assertions above, but checks that "arg" is always non-NULL.
+ * This assertion also implies BUG_ON_OPT_NEG(), letting you declare both
+ * assertions in a single line.
+ */
+#define BUG_ON_OPT_NEG_NOARG(unset, arg) do { \
+	BUG_ON_OPT_NEG(unset); \
+	if(!(arg)) \
+		BUG("option callback expects an argument"); \
+} while(0)
+
+/*----- incremental advanced APIs -----*/
 
 /*
  * It's okay for the caller to consume argv/argc in the usual way.
@@ -216,34 +266,42 @@ struct parse_opt_ctx_t {
 	const char *opt;
 	int flags;
 	const char *prefix;
+	const char **alias_groups; /* must be in groups of 3 elements! */
+	struct option *updated_options;
 };
 
-extern void parse_options_start(struct parse_opt_ctx_t *ctx,
-				int argc, const char **argv, const char *prefix,
-				const struct option *options, int flags);
-
-extern int parse_options_step(struct parse_opt_ctx_t *ctx,
-			      const struct option *options,
-			      const char * const usagestr[]);
+void parse_options_start(struct parse_opt_ctx_t *ctx,
+			 int argc, const char **argv, const char *prefix,
+			 const struct option *options, int flags);
+
+int parse_options_step(struct parse_opt_ctx_t *ctx,
+		       const struct option *options,
+		       const char * const usagestr[]);
 
-extern int parse_options_end(struct parse_opt_ctx_t *ctx);
+int parse_options_end(struct parse_opt_ctx_t *ctx);
 
-extern struct option *parse_options_concat(struct option *a, struct option *b);
+struct option *parse_options_dup(const struct option *a);
+struct option *parse_options_concat(struct option *a, struct option *b);
 
 /*----- some often used options -----*/
-extern int parse_opt_abbrev_cb(const struct option *, const char *, int);
-extern int parse_opt_approxidate_cb(const struct option *, const char *, int);
-extern int parse_opt_expiry_date_cb(const struct option *, const char *, int);
-extern int parse_opt_color_flag_cb(const struct option *, const char *, int);
-extern int parse_opt_verbosity_cb(const struct option *, const char *, int);
-extern int parse_opt_object_name(const struct option *, const char *, int);
-extern int parse_opt_commits(const struct option *, const char *, int);
-extern int parse_opt_tertiary(const struct option *, const char *, int);
-extern int parse_opt_string_list(const struct option *, const char *, int);
-extern int parse_opt_noop_cb(const struct option *, const char *, int);
-extern int parse_opt_unknown_cb(const struct option *, const char *, int);
-extern int parse_opt_passthru(const struct option *, const char *, int);
-extern int parse_opt_passthru_argv(const struct option *, const char *, int);
+int parse_opt_abbrev_cb(const struct option *, const char *, int);
+int parse_opt_expiry_date_cb(const struct option *, const char *, int);
+int parse_opt_color_flag_cb(const struct option *, const char *, int);
+int parse_opt_verbosity_cb(const struct option *, const char *, int);
+/* value is struct oid_array* */
+int parse_opt_object_name(const struct option *, const char *, int);
+/* value is struct object_id* */
+int parse_opt_object_id(const struct option *, const char *, int);
+int parse_opt_commits(const struct option *, const char *, int);
+int parse_opt_commit(const struct option *, const char *, int);
+int parse_opt_tertiary(const struct option *, const char *, int);
+int parse_opt_string_list(const struct option *, const char *, int);
+int parse_opt_noop_cb(const struct option *, const char *, int);
+enum parse_opt_result parse_opt_unknown_cb(struct parse_opt_ctx_t *ctx,
+					   const struct option *,
+					   const char *, int);
+int parse_opt_passthru(const struct option *, const char *, int);
+int parse_opt_passthru_argv(const struct option *, const char *, int);
 
 #define OPT__VERBOSE(var, h)  OPT_COUNTUP('v', "verbose", (var), (h))
 #define OPT__QUIET(var, h)    OPT_COUNTUP('q', "quiet",   (var), (h))
@@ -275,5 +333,8 @@ extern int parse_opt_passthru_argv(const
 #define OPT_NO_CONTAINS(v, h) _OPT_CONTAINS_OR_WITH("no-contains", v, h, PARSE_OPT_NONEG)
 #define OPT_WITH(v, h) _OPT_CONTAINS_OR_WITH("with", v, h, PARSE_OPT_HIDDEN | PARSE_OPT_NONEG)
 #define OPT_WITHOUT(v, h) _OPT_CONTAINS_OR_WITH("without", v, h, PARSE_OPT_HIDDEN | PARSE_OPT_NONEG)
+#define OPT_CLEANUP(v) OPT_STRING(0, "cleanup", v, N_("mode"), N_("how to strip spaces and #comments from message"))
+#define OPT_PATHSPEC_FROM_FILE(v) OPT_FILENAME(0, "pathspec-from-file", v, N_("read pathspec from file"))
+#define OPT_PATHSPEC_FILE_NUL(v)  OPT_BOOL(0, "pathspec-file-nul", v, N_("with --pathspec-from-file, pathspec elements are separated with NUL character"))
 
 #endif
diff -pruN 1.2.1+git2.18.0-1/git/patch-delta.c 1.2.3+git2.25.1-1/git/patch-delta.c
--- 1.2.1+git2.18.0-1/git/patch-delta.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/patch-delta.c	2020-02-17 04:47:35.000000000 +0000
@@ -40,24 +40,31 @@ void *patch_delta(const void *src_buf, u
 		cmd = *data++;
 		if (cmd & 0x80) {
 			unsigned long cp_off = 0, cp_size = 0;
-			if (cmd & 0x01) cp_off = *data++;
-			if (cmd & 0x02) cp_off |= (*data++ << 8);
-			if (cmd & 0x04) cp_off |= (*data++ << 16);
-			if (cmd & 0x08) cp_off |= ((unsigned) *data++ << 24);
-			if (cmd & 0x10) cp_size = *data++;
-			if (cmd & 0x20) cp_size |= (*data++ << 8);
-			if (cmd & 0x40) cp_size |= (*data++ << 16);
+#define PARSE_CP_PARAM(bit, var, shift) do { \
+			if (cmd & (bit)) { \
+				if (data >= top) \
+					goto bad_length; \
+				var |= ((unsigned) *data++ << (shift)); \
+			} } while (0)
+			PARSE_CP_PARAM(0x01, cp_off, 0);
+			PARSE_CP_PARAM(0x02, cp_off, 8);
+			PARSE_CP_PARAM(0x04, cp_off, 16);
+			PARSE_CP_PARAM(0x08, cp_off, 24);
+			PARSE_CP_PARAM(0x10, cp_size, 0);
+			PARSE_CP_PARAM(0x20, cp_size, 8);
+			PARSE_CP_PARAM(0x40, cp_size, 16);
+#undef PARSE_CP_PARAM
 			if (cp_size == 0) cp_size = 0x10000;
 			if (unsigned_add_overflows(cp_off, cp_size) ||
 			    cp_off + cp_size > src_size ||
 			    cp_size > size)
-				break;
+				goto bad_length;
 			memcpy(out, (char *) src_buf + cp_off, cp_size);
 			out += cp_size;
 			size -= cp_size;
 		} else if (cmd) {
-			if (cmd > size)
-				break;
+			if (cmd > size || cmd > top - data)
+				goto bad_length;
 			memcpy(out, data, cmd);
 			out += cmd;
 			data += cmd;
@@ -75,6 +82,7 @@ void *patch_delta(const void *src_buf, u
 
 	/* sanity check */
 	if (data != top || size != 0) {
+		bad_length:
 		error("delta replay has gone wild");
 		bad:
 		free(dst_buf);
diff -pruN 1.2.1+git2.18.0-1/git/patch-ids.c 1.2.3+git2.25.1-1/git/patch-ids.c
--- 1.2.1+git2.18.0-1/git/patch-ids.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/patch-ids.c	2020-02-17 04:47:35.000000000 +0000
@@ -11,7 +11,7 @@ static int patch_id_defined(struct commi
 }
 
 int commit_patch_id(struct commit *commit, struct diff_options *options,
-		    struct object_id *oid, int diff_header_only)
+		    struct object_id *oid, int diff_header_only, int stable)
 {
 	if (!patch_id_defined(commit))
 		return -1;
@@ -22,54 +22,56 @@ int commit_patch_id(struct commit *commi
 	else
 		diff_root_tree_oid(&commit->object.oid, "", options);
 	diffcore_std(options);
-	return diff_flush_patch_id(options, oid, diff_header_only);
+	return diff_flush_patch_id(options, oid, diff_header_only, stable);
 }
 
 /*
  * When we cannot load the full patch-id for both commits for whatever
  * reason, the function returns -1 (i.e. return error(...)). Despite
- * the "cmp" in the name of this function, the caller only cares about
+ * the "neq" in the name of this function, the caller only cares about
  * the return value being zero (a and b are equivalent) or non-zero (a
  * and b are different), and returning non-zero would keep both in the
  * result, even if they actually were equivalent, in order to err on
  * the side of safety.  The actual value being negative does not have
  * any significance; only that it is non-zero matters.
  */
-static int patch_id_cmp(const void *cmpfn_data,
-			const void *entry,
-			const void *entry_or_key,
+static int patch_id_neq(const void *cmpfn_data,
+			const struct hashmap_entry *eptr,
+			const struct hashmap_entry *entry_or_key,
 			const void *unused_keydata)
 {
 	/* NEEDSWORK: const correctness? */
 	struct diff_options *opt = (void *)cmpfn_data;
-	struct patch_id *a = (void *)entry;
-	struct patch_id *b = (void *)entry_or_key;
+	struct patch_id *a, *b;
+
+	a = container_of(eptr, struct patch_id, ent);
+	b = container_of(entry_or_key, struct patch_id, ent);
 
 	if (is_null_oid(&a->patch_id) &&
-	    commit_patch_id(a->commit, opt, &a->patch_id, 0))
+	    commit_patch_id(a->commit, opt, &a->patch_id, 0, 0))
 		return error("Could not get patch ID for %s",
 			oid_to_hex(&a->commit->object.oid));
 	if (is_null_oid(&b->patch_id) &&
-	    commit_patch_id(b->commit, opt, &b->patch_id, 0))
+	    commit_patch_id(b->commit, opt, &b->patch_id, 0, 0))
 		return error("Could not get patch ID for %s",
 			oid_to_hex(&b->commit->object.oid));
-	return oidcmp(&a->patch_id, &b->patch_id);
+	return !oideq(&a->patch_id, &b->patch_id);
 }
 
-int init_patch_ids(struct patch_ids *ids)
+int init_patch_ids(struct repository *r, struct patch_ids *ids)
 {
 	memset(ids, 0, sizeof(*ids));
-	diff_setup(&ids->diffopts);
+	repo_diff_setup(r, &ids->diffopts);
 	ids->diffopts.detect_rename = 0;
 	ids->diffopts.flags.recursive = 1;
 	diff_setup_done(&ids->diffopts);
-	hashmap_init(&ids->patches, patch_id_cmp, &ids->diffopts, 256);
+	hashmap_init(&ids->patches, patch_id_neq, &ids->diffopts, 256);
 	return 0;
 }
 
 int free_patch_ids(struct patch_ids *ids)
 {
-	hashmap_free(&ids->patches, 1);
+	hashmap_free_entries(&ids->patches, struct patch_id, ent);
 	return 0;
 }
 
@@ -80,10 +82,10 @@ static int init_patch_id_entry(struct pa
 	struct object_id header_only_patch_id;
 
 	patch->commit = commit;
-	if (commit_patch_id(commit, &ids->diffopts, &header_only_patch_id, 1))
+	if (commit_patch_id(commit, &ids->diffopts, &header_only_patch_id, 1, 0))
 		return -1;
 
-	hashmap_entry_init(patch, sha1hash(header_only_patch_id.hash));
+	hashmap_entry_init(&patch->ent, oidhash(&header_only_patch_id));
 	return 0;
 }
 
@@ -99,7 +101,7 @@ struct patch_id *has_commit_patch_id(str
 	if (init_patch_id_entry(&patch, commit, ids))
 		return NULL;
 
-	return hashmap_get(&ids->patches, &patch, NULL);
+	return hashmap_get_entry(&ids->patches, &patch, ent, NULL);
 }
 
 struct patch_id *add_commit_patch_id(struct commit *commit,
@@ -116,6 +118,6 @@ struct patch_id *add_commit_patch_id(str
 		return NULL;
 	}
 
-	hashmap_add(&ids->patches, key);
+	hashmap_add(&ids->patches, &key->ent);
 	return key;
 }
diff -pruN 1.2.1+git2.18.0-1/git/patch-ids.h 1.2.3+git2.25.1-1/git/patch-ids.h
--- 1.2.1+git2.18.0-1/git/patch-ids.h	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/patch-ids.h	2020-02-17 04:47:35.000000000 +0000
@@ -1,6 +1,13 @@
 #ifndef PATCH_IDS_H
 #define PATCH_IDS_H
 
+#include "diff.h"
+#include "hashmap.h"
+
+struct commit;
+struct object_id;
+struct repository;
+
 struct patch_id {
 	struct hashmap_entry ent;
 	struct object_id patch_id;
@@ -13,8 +20,8 @@ struct patch_ids {
 };
 
 int commit_patch_id(struct commit *commit, struct diff_options *options,
-		    struct object_id *oid, int);
-int init_patch_ids(struct patch_ids *);
+		    struct object_id *oid, int, int);
+int init_patch_ids(struct repository *, struct patch_ids *);
 int free_patch_ids(struct patch_ids *);
 struct patch_id *add_commit_patch_id(struct commit *, struct patch_ids *);
 struct patch_id *has_commit_patch_id(struct commit *, struct patch_ids *);
diff -pruN 1.2.1+git2.18.0-1/git/path.c 1.2.3+git2.25.1-1/git/path.c
--- 1.2.1+git2.18.0-1/git/path.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/path.c	2020-02-17 04:47:35.000000000 +0000
@@ -11,6 +11,7 @@
 #include "path.h"
 #include "packfile.h"
 #include "object-store.h"
+#include "lockfile.h"
 
 static int get_st_mode_bits(const char *path, int *mode)
 {
@@ -101,31 +102,36 @@ struct common_dir {
 	/* Not considered garbage for report_linked_checkout_garbage */
 	unsigned ignore_garbage:1;
 	unsigned is_dir:1;
-	/* Not common even though its parent is */
-	unsigned exclude:1;
-	const char *dirname;
+	/* Belongs to the common dir, though it may contain paths that don't */
+	unsigned is_common:1;
+	const char *path;
 };
 
 static struct common_dir common_list[] = {
-	{ 0, 1, 0, "branches" },
-	{ 0, 1, 0, "hooks" },
-	{ 0, 1, 0, "info" },
-	{ 0, 0, 1, "info/sparse-checkout" },
-	{ 1, 1, 0, "logs" },
-	{ 1, 1, 1, "logs/HEAD" },
-	{ 0, 1, 1, "logs/refs/bisect" },
-	{ 0, 1, 0, "lost-found" },
-	{ 0, 1, 0, "objects" },
-	{ 0, 1, 0, "refs" },
-	{ 0, 1, 1, "refs/bisect" },
-	{ 0, 1, 0, "remotes" },
-	{ 0, 1, 0, "worktrees" },
-	{ 0, 1, 0, "rr-cache" },
-	{ 0, 1, 0, "svn" },
-	{ 0, 0, 0, "config" },
-	{ 1, 0, 0, "gc.pid" },
-	{ 0, 0, 0, "packed-refs" },
-	{ 0, 0, 0, "shallow" },
+	{ 0, 1, 1, "branches" },
+	{ 0, 1, 1, "common" },
+	{ 0, 1, 1, "hooks" },
+	{ 0, 1, 1, "info" },
+	{ 0, 0, 0, "info/sparse-checkout" },
+	{ 1, 1, 1, "logs" },
+	{ 1, 0, 0, "logs/HEAD" },
+	{ 0, 1, 0, "logs/refs/bisect" },
+	{ 0, 1, 0, "logs/refs/rewritten" },
+	{ 0, 1, 0, "logs/refs/worktree" },
+	{ 0, 1, 1, "lost-found" },
+	{ 0, 1, 1, "objects" },
+	{ 0, 1, 1, "refs" },
+	{ 0, 1, 0, "refs/bisect" },
+	{ 0, 1, 0, "refs/rewritten" },
+	{ 0, 1, 0, "refs/worktree" },
+	{ 0, 1, 1, "remotes" },
+	{ 0, 1, 1, "worktrees" },
+	{ 0, 1, 1, "rr-cache" },
+	{ 0, 1, 1, "svn" },
+	{ 0, 0, 1, "config" },
+	{ 1, 0, 1, "gc.pid" },
+	{ 0, 0, 1, "packed-refs" },
+	{ 0, 0, 1, "shallow" },
 	{ 0, 0, 0, NULL }
 };
 
@@ -231,30 +237,41 @@ static void *add_to_trie(struct trie *ro
 	return old;
 }
 
-typedef int (*match_fn)(const char *unmatched, void *data, void *baton);
+typedef int (*match_fn)(const char *unmatched, void *value, void *baton);
 
 /*
  * Search a trie for some key.  Find the longest /-or-\0-terminated
- * prefix of the key for which the trie contains a value.  Call fn
- * with the unmatched portion of the key and the found value, and
- * return its return value.  If there is no such prefix, return -1.
+ * prefix of the key for which the trie contains a value.  If there is
+ * no such prefix, return -1.  Otherwise call fn with the unmatched
+ * portion of the key and the found value.  If fn returns 0 or
+ * positive, then return its return value.  If fn returns negative,
+ * then call fn with the next-longest /-terminated prefix of the key
+ * (i.e. a parent directory) for which the trie contains a value, and
+ * handle its return value the same way.  If there is no shorter
+ * /-terminated prefix with a value left, then return the negative
+ * return value of the most recent fn invocation.
  *
  * The key is partially normalized: consecutive slashes are skipped.
  *
- * For example, consider the trie containing only [refs,
- * refs/worktree] (both with values).
- *
- * | key             | unmatched  | val from node | return value |
- * |-----------------|------------|---------------|--------------|
- * | a               | not called | n/a           | -1           |
- * | refs            | \0         | refs          | as per fn    |
- * | refs/           | /          | refs          | as per fn    |
- * | refs/w          | /w         | refs          | as per fn    |
- * | refs/worktree   | \0         | refs/worktree | as per fn    |
- * | refs/worktree/  | /          | refs/worktree | as per fn    |
- * | refs/worktree/a | /a         | refs/worktree | as per fn    |
- * |-----------------|------------|---------------|--------------|
+ * For example, consider the trie containing only [logs,
+ * logs/refs/bisect], both with values, but not logs/refs.
  *
+ * | key                | unmatched      | prefix to node   | return value |
+ * |--------------------|----------------|------------------|--------------|
+ * | a                  | not called     | n/a              | -1           |
+ * | logstore           | not called     | n/a              | -1           |
+ * | logs               | \0             | logs             | as per fn    |
+ * | logs/              | /              | logs             | as per fn    |
+ * | logs/refs          | /refs          | logs             | as per fn    |
+ * | logs/refs/         | /refs/         | logs             | as per fn    |
+ * | logs/refs/b        | /refs/b        | logs             | as per fn    |
+ * | logs/refs/bisected | /refs/bisected | logs             | as per fn    |
+ * | logs/refs/bisect   | \0             | logs/refs/bisect | as per fn    |
+ * | logs/refs/bisect/  | /              | logs/refs/bisect | as per fn    |
+ * | logs/refs/bisect/a | /a             | logs/refs/bisect | as per fn    |
+ * | (If fn in the previous line returns -1, then fn is called once more:) |
+ * | logs/refs/bisect/a | /refs/bisect/a | logs             | as per fn    |
+ * |--------------------|----------------|------------------|--------------|
  */
 static int trie_find(struct trie *root, const char *key, match_fn fn,
 		     void *baton)
@@ -283,9 +300,13 @@ static int trie_find(struct trie *root,
 
 	/* Matched the entire compressed section */
 	key += i;
-	if (!*key)
+	if (!*key) {
 		/* End of key */
-		return fn(key, root->value, baton);
+		if (root->value)
+			return fn(key, root->value, baton);
+		else
+			return -1;
+	}
 
 	/* Partial path normalization: skip consecutive slashes */
 	while (key[0] == '/' && key[1] == '/')
@@ -315,8 +336,8 @@ static void init_common_trie(void)
 	if (common_trie_done_setup)
 		return;
 
-	for (p = common_list; p->dirname; p++)
-		add_to_trie(&common_trie, p->dirname, p);
+	for (p = common_list; p->path; p++)
+		add_to_trie(&common_trie, p->path, p);
 
 	common_trie_done_setup = 1;
 }
@@ -329,14 +350,11 @@ static int check_common(const char *unma
 {
 	struct common_dir *dir = value;
 
-	if (!dir)
-		return 0;
-
 	if (dir->is_dir && (unmatched[0] == 0 || unmatched[0] == '/'))
-		return !dir->exclude;
+		return dir->is_common;
 
 	if (!dir->is_dir && unmatched[0] == 0)
-		return !dir->exclude;
+		return dir->is_common;
 
 	return 0;
 }
@@ -345,9 +363,14 @@ static void update_common_dir(struct str
 			      const char *common_dir)
 {
 	char *base = buf->buf + git_dir_len;
+	int has_lock_suffix = strbuf_strip_suffix(buf, LOCK_SUFFIX);
+
 	init_common_trie();
 	if (trie_find(&common_trie, base, check_common, NULL) > 0)
 		replace_dir(buf, git_dir_len, common_dir);
+
+	if (has_lock_suffix)
+		strbuf_addstr(buf, LOCK_SUFFIX);
 }
 
 void report_linked_checkout_garbage(void)
@@ -360,8 +383,8 @@ void report_linked_checkout_garbage(void
 		return;
 	strbuf_addf(&sb, "%s/", get_git_dir());
 	len = sb.len;
-	for (p = common_list; p->dirname; p++) {
-		const char *path = p->dirname;
+	for (p = common_list; p->path; p++) {
+		const char *path = p->path;
 		if (p->ignore_garbage)
 			continue;
 		strbuf_setlen(&sb, len);
@@ -383,7 +406,7 @@ static void adjust_git_path(const struct
 		strbuf_splice(buf, 0, buf->len,
 			      repo->index_file, strlen(repo->index_file));
 	else if (dir_prefix(base, "objects"))
-		replace_dir(buf, git_dir_len + 7, repo->objects->objectdir);
+		replace_dir(buf, git_dir_len + 7, repo->objects->odb->path);
 	else if (git_hooks_path && dir_prefix(base, "hooks"))
 		replace_dir(buf, git_dir_len + 5, git_hooks_path);
 	else if (repo->different_commondir)
@@ -1216,31 +1239,52 @@ static inline int chomp_trailing_dir_sep
 }
 
 /*
- * If path ends with suffix (complete path components), returns the
- * part before suffix (sans trailing directory separators).
- * Otherwise returns NULL.
+ * If path ends with suffix (complete path components), returns the offset of
+ * the last character in the path before the suffix (sans trailing directory
+ * separators), and -1 otherwise.
  */
-char *strip_path_suffix(const char *path, const char *suffix)
+static ssize_t stripped_path_suffix_offset(const char *path, const char *suffix)
 {
 	int path_len = strlen(path), suffix_len = strlen(suffix);
 
 	while (suffix_len) {
 		if (!path_len)
-			return NULL;
+			return -1;
 
 		if (is_dir_sep(path[path_len - 1])) {
 			if (!is_dir_sep(suffix[suffix_len - 1]))
-				return NULL;
+				return -1;
 			path_len = chomp_trailing_dir_sep(path, path_len);
 			suffix_len = chomp_trailing_dir_sep(suffix, suffix_len);
 		}
 		else if (path[--path_len] != suffix[--suffix_len])
-			return NULL;
+			return -1;
 	}
 
 	if (path_len && !is_dir_sep(path[path_len - 1]))
-		return NULL;
-	return xstrndup(path, chomp_trailing_dir_sep(path, path_len));
+		return -1;
+	return chomp_trailing_dir_sep(path, path_len);
+}
+
+/*
+ * Returns true if the path ends with components, considering only complete path
+ * components, and false otherwise.
+ */
+int ends_with_path_components(const char *path, const char *components)
+{
+	return stripped_path_suffix_offset(path, components) != -1;
+}
+
+/*
+ * If path ends with suffix (complete path components), returns the
+ * part before suffix (sans trailing directory separators).
+ * Otherwise returns NULL.
+ */
+char *strip_path_suffix(const char *path, const char *suffix)
+{
+	ssize_t offset = stripped_path_suffix_offset(path, suffix);
+
+	return offset == -1 ? NULL : xstrndup(path, offset);
 }
 
 int daemon_avoid_alias(const char *p)
@@ -1290,37 +1334,77 @@ int daemon_avoid_alias(const char *p)
 	}
 }
 
-static int only_spaces_and_periods(const char *path, size_t len, size_t skip)
+/*
+ * On NTFS, we need to be careful to disallow certain synonyms of the `.git/`
+ * directory:
+ *
+ * - For historical reasons, file names that end in spaces or periods are
+ *   automatically trimmed. Therefore, `.git . . ./` is a valid way to refer
+ *   to `.git/`.
+ *
+ * - For other historical reasons, file names that do not conform to the 8.3
+ *   format (up to eight characters for the basename, three for the file
+ *   extension, certain characters not allowed such as `+`, etc) are associated
+ *   with a so-called "short name", at least on the `C:` drive by default.
+ *   Which means that `git~1/` is a valid way to refer to `.git/`.
+ *
+ *   Note: Technically, `.git/` could receive the short name `git~2` if the
+ *   short name `git~1` were already used. In Git, however, we guarantee that
+ *   `.git` is the first item in a directory, therefore it will be associated
+ *   with the short name `git~1` (unless short names are disabled).
+ *
+ * - For yet other historical reasons, NTFS supports so-called "Alternate Data
+ *   Streams", i.e. metadata associated with a given file, referred to via
+ *   `<filename>:<stream-name>:<stream-type>`. There exists a default stream
+ *   type for directories, allowing `.git/` to be accessed via
+ *   `.git::$INDEX_ALLOCATION/`.
+ *
+ * When this function returns 1, it indicates that the specified file/directory
+ * name refers to a `.git` file or directory, or to any of these synonyms, and
+ * Git should therefore not track it.
+ *
+ * For performance reasons, _all_ Alternate Data Streams of `.git/` are
+ * forbidden, not just `::$INDEX_ALLOCATION`.
+ *
+ * This function is intended to be used by `git fsck` even on platforms where
+ * the backslash is a regular filename character, therefore it needs to handle
+ * backlash characters in the provided `name` specially: they are interpreted
+ * as directory separators.
+ */
+int is_ntfs_dotgit(const char *name)
 {
-	if (len < skip)
+	char c;
+
+	/*
+	 * Note that when we don't find `.git` or `git~1` we end up with `name`
+	 * advanced partway through the string. That's okay, though, as we
+	 * return immediately in those cases, without looking at `name` any
+	 * further.
+	 */
+	c = *(name++);
+	if (c == '.') {
+		/* .git */
+		if (((c = *(name++)) != 'g' && c != 'G') ||
+		    ((c = *(name++)) != 'i' && c != 'I') ||
+		    ((c = *(name++)) != 't' && c != 'T'))
+			return 0;
+	} else if (c == 'g' || c == 'G') {
+		/* git ~1 */
+		if (((c = *(name++)) != 'i' && c != 'I') ||
+		    ((c = *(name++)) != 't' && c != 'T') ||
+		    *(name++) != '~' ||
+		    *(name++) != '1')
+			return 0;
+	} else
 		return 0;
-	len -= skip;
-	path += skip;
-	while (len-- > 0) {
-		char c = *(path++);
-		if (c != ' ' && c != '.')
+
+	for (;;) {
+		c = *(name++);
+		if (!c || c == '\\' || c == '/' || c == ':')
+			return 1;
+		if (c != '.' && c != ' ')
 			return 0;
 	}
-	return 1;
-}
-
-int is_ntfs_dotgit(const char *name)
-{
-	size_t len;
-
-	for (len = 0; ; len++)
-		if (!name[len] || name[len] == '\\' || is_dir_sep(name[len])) {
-			if (only_spaces_and_periods(name, len, 4) &&
-					!strncasecmp(name, ".git", 4))
-				return 1;
-			if (only_spaces_and_periods(name, len, 5) &&
-					!strncasecmp(name, "git~1", 5))
-				return 1;
-			if (name[len] != '\\')
-				return 0;
-			name += len + 1;
-			len = -1;
-		}
 }
 
 static int is_ntfs_dot_generic(const char *name,
@@ -1336,7 +1420,7 @@ static int is_ntfs_dot_generic(const cha
 only_spaces_and_periods:
 		for (;;) {
 			char c = name[i++];
-			if (!c)
+			if (!c || c == ':')
 				return 1;
 			if (c != ' ' && c != '.')
 				return 0;
@@ -1369,7 +1453,7 @@ only_spaces_and_periods:
 			saw_tilde = 1;
 		} else if (i >= 6)
 			return 0;
-		else if (name[i] < 0) {
+		else if (name[i] & 0x80) {
 			/*
 			 * We know our needles contain only ASCII, so we clamp
 			 * here to make the results of tolower() sane.
@@ -1442,12 +1526,12 @@ char *xdg_cache_home(const char *filenam
 	return NULL;
 }
 
-GIT_PATH_FUNC(git_path_cherry_pick_head, "CHERRY_PICK_HEAD")
-GIT_PATH_FUNC(git_path_revert_head, "REVERT_HEAD")
-GIT_PATH_FUNC(git_path_squash_msg, "SQUASH_MSG")
-GIT_PATH_FUNC(git_path_merge_msg, "MERGE_MSG")
-GIT_PATH_FUNC(git_path_merge_rr, "MERGE_RR")
-GIT_PATH_FUNC(git_path_merge_mode, "MERGE_MODE")
-GIT_PATH_FUNC(git_path_merge_head, "MERGE_HEAD")
-GIT_PATH_FUNC(git_path_fetch_head, "FETCH_HEAD")
-GIT_PATH_FUNC(git_path_shallow, "shallow")
+REPO_GIT_PATH_FUNC(cherry_pick_head, "CHERRY_PICK_HEAD")
+REPO_GIT_PATH_FUNC(revert_head, "REVERT_HEAD")
+REPO_GIT_PATH_FUNC(squash_msg, "SQUASH_MSG")
+REPO_GIT_PATH_FUNC(merge_msg, "MERGE_MSG")
+REPO_GIT_PATH_FUNC(merge_rr, "MERGE_RR")
+REPO_GIT_PATH_FUNC(merge_mode, "MERGE_MODE")
+REPO_GIT_PATH_FUNC(merge_head, "MERGE_HEAD")
+REPO_GIT_PATH_FUNC(fetch_head, "FETCH_HEAD")
+REPO_GIT_PATH_FUNC(shallow, "shallow")
diff -pruN 1.2.1+git2.18.0-1/git/path.h 1.2.3+git2.25.1-1/git/path.h
--- 1.2.1+git2.18.0-1/git/path.h	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/path.h	2020-02-17 04:47:35.000000000 +0000
@@ -2,6 +2,7 @@
 #define PATH_H
 
 struct repository;
+struct strbuf;
 
 /*
  * The result to all functions which return statically allocated memory may be
@@ -12,19 +13,19 @@ struct repository;
 /*
  * Return a statically allocated path.
  */
-extern const char *mkpath(const char *fmt, ...)
+const char *mkpath(const char *fmt, ...)
 	__attribute__((format (printf, 1, 2)));
 
 /*
  * Return a path.
  */
-extern char *mkpathdup(const char *fmt, ...)
+char *mkpathdup(const char *fmt, ...)
 	__attribute__((format (printf, 1, 2)));
 
 /*
  * Construct a path and place the result in the provided buffer `buf`.
  */
-extern char *mksnpath(char *buf, size_t n, const char *fmt, ...)
+char *mksnpath(char *buf, size_t n, const char *fmt, ...)
 	__attribute__((format (printf, 3, 4)));
 
 /*
@@ -36,16 +37,16 @@ extern char *mksnpath(char *buf, size_t
  * Constructs a path into the common git directory of repository `repo` and
  * append it in the provided buffer `sb`.
  */
-extern void strbuf_git_common_path(struct strbuf *sb,
-				   const struct repository *repo,
-				   const char *fmt, ...)
+void strbuf_git_common_path(struct strbuf *sb,
+			    const struct repository *repo,
+			    const char *fmt, ...)
 	__attribute__((format (printf, 3, 4)));
 
 /*
  * Return a statically allocated path into the main repository's
  * (the_repository) common git directory.
  */
-extern const char *git_common_path(const char *fmt, ...)
+const char *git_common_path(const char *fmt, ...)
 	__attribute__((format (printf, 1, 2)));
 
 
@@ -65,30 +66,30 @@ extern const char *git_common_path(const
 /*
  * Return a path into the git directory of repository `repo`.
  */
-extern char *repo_git_path(const struct repository *repo,
-			   const char *fmt, ...)
+char *repo_git_path(const struct repository *repo,
+		    const char *fmt, ...)
 	__attribute__((format (printf, 2, 3)));
 
 /*
  * Construct a path into the git directory of repository `repo` and append it
  * to the provided buffer `sb`.
  */
-extern void strbuf_repo_git_path(struct strbuf *sb,
-				 const struct repository *repo,
-				 const char *fmt, ...)
+void strbuf_repo_git_path(struct strbuf *sb,
+			  const struct repository *repo,
+			  const char *fmt, ...)
 	__attribute__((format (printf, 3, 4)));
 
 /*
  * Return a statically allocated path into the main repository's
  * (the_repository) git directory.
  */
-extern const char *git_path(const char *fmt, ...)
+const char *git_path(const char *fmt, ...)
 	__attribute__((format (printf, 1, 2)));
 
 /*
  * Return a path into the main repository's (the_repository) git directory.
  */
-extern char *git_pathdup(const char *fmt, ...)
+char *git_pathdup(const char *fmt, ...)
 	__attribute__((format (printf, 1, 2)));
 
 /*
@@ -96,14 +97,14 @@ extern char *git_pathdup(const char *fmt
  * and place it in the provided buffer `buf`, the contents of the buffer will
  * be overridden.
  */
-extern char *git_path_buf(struct strbuf *buf, const char *fmt, ...)
+char *git_path_buf(struct strbuf *buf, const char *fmt, ...)
 	__attribute__((format (printf, 2, 3)));
 
 /*
  * Construct a path into the main repository's (the_repository) git directory
  * and append it to the provided buffer `sb`.
  */
-extern void strbuf_git_path(struct strbuf *sb, const char *fmt, ...)
+void strbuf_git_path(struct strbuf *sb, const char *fmt, ...)
 	__attribute__((format (printf, 2, 3)));
 
 /*
@@ -111,7 +112,7 @@ extern void strbuf_git_path(struct strbu
  *
  * If the repository doesn't have a worktree NULL is returned.
  */
-extern char *repo_worktree_path(const struct repository *repo,
+char *repo_worktree_path(const struct repository *repo,
 				const char *fmt, ...)
 	__attribute__((format (printf, 2, 3)));
 
@@ -121,7 +122,7 @@ extern char *repo_worktree_path(const st
  *
  * If the repository doesn't have a worktree nothing will be appended to `sb`.
  */
-extern void strbuf_repo_worktree_path(struct strbuf *sb,
+void strbuf_repo_worktree_path(struct strbuf *sb,
 				      const struct repository *repo,
 				      const char *fmt, ...)
 	__attribute__((format (printf, 3, 4)));
@@ -130,7 +131,7 @@ extern void strbuf_repo_worktree_path(st
  * Return a path into a submodule's git directory located at `path`.  `path`
  * must only reference a submodule of the main repository (the_repository).
  */
-extern char *git_pathdup_submodule(const char *path, const char *fmt, ...)
+char *git_pathdup_submodule(const char *path, const char *fmt, ...)
 	__attribute__((format (printf, 2, 3)));
 
 /*
@@ -138,16 +139,16 @@ extern char *git_pathdup_submodule(const
  * append it to the provided buffer `sb`.  `path` must only reference a
  * submodule of the main repository (the_repository).
  */
-extern int strbuf_git_path_submodule(struct strbuf *sb, const char *path,
+int strbuf_git_path_submodule(struct strbuf *sb, const char *path,
 				     const char *fmt, ...)
 	__attribute__((format (printf, 3, 4)));
 
-extern void report_linked_checkout_garbage(void);
+void report_linked_checkout_garbage(void);
 
 /*
  * You can define a static memoized git path like:
  *
- *    static GIT_PATH_FUNC(git_path_foo, "FOO");
+ *    static GIT_PATH_FUNC(git_path_foo, "FOO")
  *
  * or use one of the global ones below.
  */
@@ -160,14 +161,39 @@ extern void report_linked_checkout_garba
 		return ret; \
 	}
 
-const char *git_path_cherry_pick_head(void);
-const char *git_path_revert_head(void);
-const char *git_path_squash_msg(void);
-const char *git_path_merge_msg(void);
-const char *git_path_merge_rr(void);
-const char *git_path_merge_mode(void);
-const char *git_path_merge_head(void);
-const char *git_path_fetch_head(void);
-const char *git_path_shallow(void);
+#define REPO_GIT_PATH_FUNC(var, filename) \
+	const char *git_path_##var(struct repository *r) \
+	{ \
+		if (!r->cached_paths.var) \
+			r->cached_paths.var = repo_git_path(r, filename); \
+		return r->cached_paths.var; \
+	}
+
+struct path_cache {
+	const char *cherry_pick_head;
+	const char *revert_head;
+	const char *squash_msg;
+	const char *merge_msg;
+	const char *merge_rr;
+	const char *merge_mode;
+	const char *merge_head;
+	const char *fetch_head;
+	const char *shallow;
+};
+
+#define PATH_CACHE_INIT { NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL }
+
+const char *git_path_cherry_pick_head(struct repository *r);
+const char *git_path_revert_head(struct repository *r);
+const char *git_path_squash_msg(struct repository *r);
+const char *git_path_merge_msg(struct repository *r);
+const char *git_path_merge_rr(struct repository *r);
+const char *git_path_merge_mode(struct repository *r);
+const char *git_path_merge_head(struct repository *r);
+const char *git_path_fetch_head(struct repository *r);
+const char *git_path_shallow(struct repository *r);
+
+
+int ends_with_path_components(const char *path, const char *components);
 
 #endif /* PATH_H */
diff -pruN 1.2.1+git2.18.0-1/git/pathspec.c 1.2.3+git2.25.1-1/git/pathspec.c
--- 1.2.1+git2.18.0-1/git/pathspec.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/pathspec.c	2020-02-17 04:47:35.000000000 +0000
@@ -1,9 +1,10 @@
-#define NO_THE_INDEX_COMPATIBILITY_MACROS
 #include "cache.h"
 #include "config.h"
 #include "dir.h"
 #include "pathspec.h"
 #include "attr.h"
+#include "argv-array.h"
+#include "quote.h"
 
 /*
  * Finds which of the given pathspecs match items in the index.
@@ -37,7 +38,7 @@ void add_pathspec_matches_against_index(
 		return;
 	for (i = 0; i < istate->cache_nr; i++) {
 		const struct cache_entry *ce = istate->cache[i];
-		ce_path_match(ce, pathspec, seen);
+		ce_path_match(istate, ce, pathspec, seen);
 	}
 }
 
@@ -614,6 +615,42 @@ void parse_pathspec(struct pathspec *pat
 	}
 }
 
+void parse_pathspec_file(struct pathspec *pathspec, unsigned magic_mask,
+			 unsigned flags, const char *prefix,
+			 const char *file, int nul_term_line)
+{
+	struct argv_array parsed_file = ARGV_ARRAY_INIT;
+	strbuf_getline_fn getline_fn = nul_term_line ? strbuf_getline_nul :
+						       strbuf_getline;
+	struct strbuf buf = STRBUF_INIT;
+	struct strbuf unquoted = STRBUF_INIT;
+	FILE *in;
+
+	if (!strcmp(file, "-"))
+		in = stdin;
+	else
+		in = xfopen(file, "r");
+
+	while (getline_fn(&buf, in) != EOF) {
+		if (!nul_term_line && buf.buf[0] == '"') {
+			strbuf_reset(&unquoted);
+			if (unquote_c_style(&unquoted, buf.buf, NULL))
+				die(_("line is badly quoted: %s"), buf.buf);
+			strbuf_swap(&buf, &unquoted);
+		}
+		argv_array_push(&parsed_file, buf.buf);
+		strbuf_reset(&buf);
+	}
+
+	strbuf_release(&unquoted);
+	strbuf_release(&buf);
+	if (in != stdin)
+		fclose(in);
+
+	parse_pathspec(pathspec, magic_mask, flags, prefix, parsed_file.argv);
+	argv_array_clear(&parsed_file);
+}
+
 void copy_pathspec(struct pathspec *dst, const struct pathspec *src)
 {
 	int i, j;
@@ -659,3 +696,41 @@ void clear_pathspec(struct pathspec *pat
 	FREE_AND_NULL(pathspec->items);
 	pathspec->nr = 0;
 }
+
+int match_pathspec_attrs(const struct index_state *istate,
+			 const char *name, int namelen,
+			 const struct pathspec_item *item)
+{
+	int i;
+	char *to_free = NULL;
+
+	if (name[namelen])
+		name = to_free = xmemdupz(name, namelen);
+
+	git_check_attr(istate, name, item->attr_check);
+
+	free(to_free);
+
+	for (i = 0; i < item->attr_match_nr; i++) {
+		const char *value;
+		int matched;
+		enum attr_match_mode match_mode;
+
+		value = item->attr_check->items[i].value;
+		match_mode = item->attr_match[i].match_mode;
+
+		if (ATTR_TRUE(value))
+			matched = (match_mode == MATCH_SET);
+		else if (ATTR_FALSE(value))
+			matched = (match_mode == MATCH_UNSET);
+		else if (ATTR_UNSET(value))
+			matched = (match_mode == MATCH_UNSPECIFIED);
+		else
+			matched = (match_mode == MATCH_VALUE &&
+				   !strcmp(item->attr_match[i].value, value));
+		if (!matched)
+			return 0;
+	}
+
+	return 1;
+}
diff -pruN 1.2.1+git2.18.0-1/git/pathspec.h 1.2.3+git2.25.1-1/git/pathspec.h
--- 1.2.1+git2.18.0-1/git/pathspec.h	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/pathspec.h	2020-02-17 04:47:35.000000000 +0000
@@ -1,6 +1,8 @@
 #ifndef PATHSPEC_H
 #define PATHSPEC_H
 
+struct index_state;
+
 /* Pathspec magic */
 #define PATHSPEC_FROMTOP	(1<<0)
 #define PATHSPEC_MAXDEPTH	(1<<1)
@@ -20,6 +22,11 @@
 
 #define PATHSPEC_ONESTAR 1	/* the pathspec pattern satisfies GFNM_ONESTAR */
 
+/**
+ * See glossary-context.txt for the syntax of pathspec.
+ * In memory, a pathspec set is represented by "struct pathspec" and is
+ * prepared by parse_pathspec().
+ */
 struct pathspec {
 	int nr;
 	unsigned int has_wildcard:1;
@@ -71,20 +78,58 @@ struct pathspec {
  */
 #define PATHSPEC_LITERAL_PATH (1<<6)
 
-/*
+/**
  * Given command line arguments and a prefix, convert the input to
  * pathspec. die() if any magic in magic_mask is used.
  *
  * Any arguments used are copied. It is safe for the caller to modify
  * or free 'prefix' and 'args' after calling this function.
+ *
+ * - magic_mask specifies what features that are NOT supported by the following
+ * code. If a user attempts to use such a feature, parse_pathspec() can reject
+ * it early.
+ *
+ * - flags specifies other things that the caller wants parse_pathspec to
+ * perform.
+ *
+ * - prefix and args come from cmd_* functions
+ *
+ * parse_pathspec() helps catch unsupported features and reject them politely.
+ * At a lower level, different pathspec-related functions may not support the
+ * same set of features. Such pathspec-sensitive functions are guarded with
+ * GUARD_PATHSPEC(), which will die in an unfriendly way when an unsupported
+ * feature is requested.
+ *
+ * The command designers are supposed to make sure that GUARD_PATHSPEC() never
+ * dies. They have to make sure all unsupported features are caught by
+ * parse_pathspec(), not by GUARD_PATHSPEC. grepping GUARD_PATHSPEC() should
+ * give the designers all pathspec-sensitive codepaths and what features they
+ * support.
+ *
+ * A similar process is applied when a new pathspec magic is added. The designer
+ * lifts the GUARD_PATHSPEC restriction in the functions that support the new
+ * magic. At the same time (s)he has to make sure this new feature will be
+ * caught at parse_pathspec() in commands that cannot handle the new magic in
+ * some cases. grepping parse_pathspec() should help.
  */
-extern void parse_pathspec(struct pathspec *pathspec,
-			   unsigned magic_mask,
-			   unsigned flags,
-			   const char *prefix,
-			   const char **args);
-extern void copy_pathspec(struct pathspec *dst, const struct pathspec *src);
-extern void clear_pathspec(struct pathspec *);
+void parse_pathspec(struct pathspec *pathspec,
+		    unsigned magic_mask,
+		    unsigned flags,
+		    const char *prefix,
+		    const char **args);
+/*
+ * Same as parse_pathspec() but uses file as input.
+ * When 'file' is exactly "-" it uses 'stdin' instead.
+ */
+void parse_pathspec_file(struct pathspec *pathspec,
+			 unsigned magic_mask,
+			 unsigned flags,
+			 const char *prefix,
+			 const char *file,
+			 int nul_term_line);
+
+void copy_pathspec(struct pathspec *dst, const struct pathspec *src);
+void clear_pathspec(struct pathspec *);
 
 static inline int ps_strncmp(const struct pathspec_item *item,
 			     const char *s1, const char *s2, size_t n)
@@ -104,10 +149,13 @@ static inline int ps_strcmp(const struct
 		return strcmp(s1, s2);
 }
 
-extern void add_pathspec_matches_against_index(const struct pathspec *pathspec,
-					       const struct index_state *istate,
-					       char *seen);
-extern char *find_pathspecs_matching_against_index(const struct pathspec *pathspec,
-						   const struct index_state *istate);
+void add_pathspec_matches_against_index(const struct pathspec *pathspec,
+					const struct index_state *istate,
+					char *seen);
+char *find_pathspecs_matching_against_index(const struct pathspec *pathspec,
+					    const struct index_state *istate);
+int match_pathspec_attrs(const struct index_state *istate,
+			 const char *name, int namelen,
+			 const struct pathspec_item *item);
 
 #endif /* PATHSPEC_H */
diff -pruN 1.2.1+git2.18.0-1/git/perl/Git/SVN.pm 1.2.3+git2.25.1-1/git/perl/Git/SVN.pm
--- 1.2.1+git2.18.0-1/git/perl/Git/SVN.pm	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/perl/Git/SVN.pm	2020-02-17 04:47:35.000000000 +0000
@@ -1491,6 +1491,10 @@ sub call_authors_prog {
 
 sub check_author {
 	my ($author) = @_;
+	if (defined $author) {
+		$author =~ s/^\s+//g;
+		$author =~ s/\s+$//g;
+	}
 	if (!defined $author || length $author == 0) {
 		$author = '(no author)';
 	}
diff -pruN 1.2.1+git2.18.0-1/git/perl/Git.pm 1.2.3+git2.25.1-1/git/perl/Git.pm
--- 1.2.1+git2.18.0-1/git/perl/Git.pm	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/perl/Git.pm	2020-02-17 04:47:35.000000000 +0000
@@ -563,7 +563,7 @@ sub get_record {
 Query user C<PROMPT> and return answer from user.
 
 Honours GIT_ASKPASS and SSH_ASKPASS environment variables for querying
-the user. If no *_ASKPASS variable is set or an error occoured,
+the user. If no *_ASKPASS variable is set or an error occurred,
 the terminal is tried as a fallback.
 If C<ISPASSWORD> is set and true, the terminal disables echo.
 
@@ -980,7 +980,7 @@ sub cat_blob {
 		return -1;
 	}
 
-	if ($description !~ /^[0-9a-fA-F]{40} \S+ (\d+)$/) {
+	if ($description !~ /^[0-9a-fA-F]{40}(?:[0-9a-fA-F]{24})? \S+ (\d+)$/) {
 		carp "Unexpected result returned from git cat-file";
 		return -1;
 	}
diff -pruN 1.2.1+git2.18.0-1/git/pkt-line.c 1.2.3+git2.25.1-1/git/pkt-line.c
--- 1.2.1+git2.18.0-1/git/pkt-line.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/pkt-line.c	2020-02-17 04:47:35.000000000 +0000
@@ -88,20 +88,22 @@ static void packet_trace(const char *buf
 void packet_flush(int fd)
 {
 	packet_trace("0000", 4, 1);
-	write_or_die(fd, "0000", 4);
+	if (write_in_full(fd, "0000", 4) < 0)
+		die_errno(_("unable to write flush packet"));
 }
 
 void packet_delim(int fd)
 {
 	packet_trace("0001", 4, 1);
-	write_or_die(fd, "0001", 4);
+	if (write_in_full(fd, "0001", 4) < 0)
+		die_errno(_("unable to write delim packet"));
 }
 
 int packet_flush_gently(int fd)
 {
 	packet_trace("0000", 4, 1);
 	if (write_in_full(fd, "0000", 4) < 0)
-		return error("flush packet write failed");
+		return error(_("flush packet write failed"));
 	return 0;
 }
 
@@ -117,7 +119,7 @@ void packet_buf_delim(struct strbuf *buf
 	strbuf_add(buf, "0001", 4);
 }
 
-static void set_packet_header(char *buf, const int size)
+void set_packet_header(char *buf, int size)
 {
 	static char hexchar[] = "0123456789abcdef";
 
@@ -129,35 +131,37 @@ static void set_packet_header(char *buf,
 	#undef hex
 }
 
-static void format_packet(struct strbuf *out, const char *fmt, va_list args)
+static void format_packet(struct strbuf *out, const char *prefix,
+			  const char *fmt, va_list args)
 {
 	size_t orig_len, n;
 
 	orig_len = out->len;
 	strbuf_addstr(out, "0000");
+	strbuf_addstr(out, prefix);
 	strbuf_vaddf(out, fmt, args);
 	n = out->len - orig_len;
 
 	if (n > LARGE_PACKET_MAX)
-		die("protocol error: impossibly long line");
+		die(_("protocol error: impossibly long line"));
 
 	set_packet_header(&out->buf[orig_len], n);
 	packet_trace(out->buf + orig_len + 4, n - 4, 1);
 }
 
-static int packet_write_fmt_1(int fd, int gently,
+static int packet_write_fmt_1(int fd, int gently, const char *prefix,
 			      const char *fmt, va_list args)
 {
 	static struct strbuf buf = STRBUF_INIT;
 
 	strbuf_reset(&buf);
-	format_packet(&buf, fmt, args);
+	format_packet(&buf, prefix, fmt, args);
 	if (write_in_full(fd, buf.buf, buf.len) < 0) {
 		if (!gently) {
 			check_pipe(errno);
-			die_errno("packet write with format failed");
+			die_errno(_("packet write with format failed"));
 		}
-		return error("packet write with format failed");
+		return error(_("packet write with format failed"));
 	}
 
 	return 0;
@@ -168,7 +172,7 @@ void packet_write_fmt(int fd, const char
 	va_list args;
 
 	va_start(args, fmt);
-	packet_write_fmt_1(fd, 0, fmt, args);
+	packet_write_fmt_1(fd, 0, "", fmt, args);
 	va_end(args);
 }
 
@@ -178,7 +182,7 @@ int packet_write_fmt_gently(int fd, cons
 	va_list args;
 
 	va_start(args, fmt);
-	status = packet_write_fmt_1(fd, 1, fmt, args);
+	status = packet_write_fmt_1(fd, 1, "", fmt, args);
 	va_end(args);
 	return status;
 }
@@ -189,21 +193,21 @@ static int packet_write_gently(const int
 	size_t packet_size;
 
 	if (size > sizeof(packet_write_buffer) - 4)
-		return error("packet write failed - data exceeds max packet size");
+		return error(_("packet write failed - data exceeds max packet size"));
 
 	packet_trace(buf, size, 1);
 	packet_size = size + 4;
 	set_packet_header(packet_write_buffer, packet_size);
 	memcpy(packet_write_buffer + 4, buf, size);
 	if (write_in_full(fd_out, packet_write_buffer, packet_size) < 0)
-		return error("packet write failed");
+		return error(_("packet write failed"));
 	return 0;
 }
 
 void packet_write(int fd_out, const char *buf, size_t size)
 {
 	if (packet_write_gently(fd_out, buf, size))
-		die_errno("packet write failed");
+		die_errno(_("packet write failed"));
 }
 
 void packet_buf_write(struct strbuf *buf, const char *fmt, ...)
@@ -211,7 +215,7 @@ void packet_buf_write(struct strbuf *buf
 	va_list args;
 
 	va_start(args, fmt);
-	format_packet(buf, fmt, args);
+	format_packet(buf, "", fmt, args);
 	va_end(args);
 }
 
@@ -225,7 +229,7 @@ void packet_buf_write_len(struct strbuf
 	n = buf->len - orig_len;
 
 	if (n > LARGE_PACKET_MAX)
-		die("protocol error: impossibly long line");
+		die(_("protocol error: impossibly long line"));
 
 	set_packet_header(&buf->buf[orig_len], n);
 	packet_trace(data, len, 1);
@@ -288,7 +292,7 @@ static int get_packet_data(int fd, char
 	} else {
 		ret = read_in_full(fd, dst, size);
 		if (ret < 0)
-			die_errno("read error");
+			die_errno(_("read error"));
 	}
 
 	/* And complain if we didn't get enough bytes to satisfy the read. */
@@ -296,7 +300,7 @@ static int get_packet_data(int fd, char
 		if (options & PACKET_READ_GENTLE_ON_EOF)
 			return -1;
 
-		die("The remote end hung up unexpectedly");
+		die(_("the remote end hung up unexpectedly"));
 	}
 
 	return ret;
@@ -324,7 +328,7 @@ enum packet_read_status packet_read_with
 	len = packet_length(linelen);
 
 	if (len < 0) {
-		die("protocol error: bad line length character: %.4s", linelen);
+		die(_("protocol error: bad line length character: %.4s"), linelen);
 	} else if (!len) {
 		packet_trace("0000", 4, 0);
 		*pktlen = 0;
@@ -334,12 +338,12 @@ enum packet_read_status packet_read_with
 		*pktlen = 0;
 		return PACKET_READ_DELIM;
 	} else if (len < 4) {
-		die("protocol error: bad line length %d", len);
+		die(_("protocol error: bad line length %d"), len);
 	}
 
 	len -= 4;
 	if ((unsigned)len >= size)
-		die("protocol error: bad line length %d", len);
+		die(_("protocol error: bad line length %d"), len);
 
 	if (get_packet_data(fd, src_buffer, src_len, buffer, len, options) < 0) {
 		*pktlen = -1;
@@ -352,6 +356,11 @@ enum packet_read_status packet_read_with
 
 	buffer[len] = 0;
 	packet_trace(buffer, len, 0);
+
+	if ((options & PACKET_READ_DIE_ON_ERR_PACKET) &&
+	    starts_with(buffer, "ERR "))
+		die(_("remote error: %s"), buffer + 4);
+
 	*pktlen = len;
 	return PACKET_READ_NORMAL;
 }
@@ -433,6 +442,29 @@ ssize_t read_packetized_to_strbuf(int fd
 	return sb_out->len - orig_len;
 }
 
+int recv_sideband(const char *me, int in_stream, int out)
+{
+	char buf[LARGE_PACKET_MAX + 1];
+	int len;
+	struct strbuf scratch = STRBUF_INIT;
+	enum sideband_type sideband_type;
+
+	while (1) {
+		len = packet_read(in_stream, NULL, NULL, buf, LARGE_PACKET_MAX,
+				  0);
+		if (!demultiplex_sideband(me, buf, len, 0, &scratch,
+					  &sideband_type))
+			continue;
+		switch (sideband_type) {
+		case SIDEBAND_PRIMARY:
+			write_or_die(out, buf + 1, len - 1);
+			break;
+		default: /* errors: message already written */
+			return sideband_type;
+		}
+	}
+}
+
 /* Packet Reader Functions */
 void packet_reader_init(struct packet_reader *reader, int fd,
 			char *src_buffer, size_t src_len,
@@ -446,25 +478,43 @@ void packet_reader_init(struct packet_re
 	reader->buffer = packet_buffer;
 	reader->buffer_size = sizeof(packet_buffer);
 	reader->options = options;
+	reader->me = "git";
 }
 
 enum packet_read_status packet_reader_read(struct packet_reader *reader)
 {
+	struct strbuf scratch = STRBUF_INIT;
+
 	if (reader->line_peeked) {
 		reader->line_peeked = 0;
 		return reader->status;
 	}
 
-	reader->status = packet_read_with_status(reader->fd,
-						 &reader->src_buffer,
-						 &reader->src_len,
-						 reader->buffer,
-						 reader->buffer_size,
-						 &reader->pktlen,
-						 reader->options);
+	/*
+	 * Consume all progress packets until a primary payload packet is
+	 * received
+	 */
+	while (1) {
+		enum sideband_type sideband_type;
+		reader->status = packet_read_with_status(reader->fd,
+							 &reader->src_buffer,
+							 &reader->src_len,
+							 reader->buffer,
+							 reader->buffer_size,
+							 &reader->pktlen,
+							 reader->options);
+		if (!reader->use_sideband)
+			break;
+		if (demultiplex_sideband(reader->me, reader->buffer,
+					 reader->pktlen, 1, &scratch,
+					 &sideband_type))
+			break;
+	}
 
 	if (reader->status == PACKET_READ_NORMAL)
-		reader->line = reader->buffer;
+		/* Skip the sideband designator if sideband is used */
+		reader->line = reader->use_sideband ?
+			reader->buffer + 1 : reader->buffer;
 	else
 		reader->line = NULL;
 
@@ -482,3 +532,39 @@ enum packet_read_status packet_reader_pe
 	reader->line_peeked = 1;
 	return reader->status;
 }
+
+void packet_writer_init(struct packet_writer *writer, int dest_fd)
+{
+	writer->dest_fd = dest_fd;
+	writer->use_sideband = 0;
+}
+
+void packet_writer_write(struct packet_writer *writer, const char *fmt, ...)
+{
+	va_list args;
+
+	va_start(args, fmt);
+	packet_write_fmt_1(writer->dest_fd, 0,
+			   writer->use_sideband ? "\001" : "", fmt, args);
+	va_end(args);
+}
+
+void packet_writer_error(struct packet_writer *writer, const char *fmt, ...)
+{
+	va_list args;
+
+	va_start(args, fmt);
+	packet_write_fmt_1(writer->dest_fd, 0,
+			   writer->use_sideband ? "\003" : "ERR ", fmt, args);
+	va_end(args);
+}
+
+void packet_writer_delim(struct packet_writer *writer)
+{
+	packet_delim(writer->dest_fd);
+}
+
+void packet_writer_flush(struct packet_writer *writer)
+{
+	packet_flush(writer->dest_fd);
+}
diff -pruN 1.2.1+git2.18.0-1/git/pkt-line.h 1.2.3+git2.25.1-1/git/pkt-line.h
--- 1.2.1+git2.18.0-1/git/pkt-line.h	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/pkt-line.h	2020-02-17 04:47:35.000000000 +0000
@@ -3,6 +3,7 @@
 
 #include "git-compat-util.h"
 #include "strbuf.h"
+#include "sideband.h"
 
 /*
  * Write a packetized stream, where each line is preceded by
@@ -24,6 +25,7 @@ void packet_delim(int fd);
 void packet_write_fmt(int fd, const char *fmt, ...) __attribute__((format (printf, 2, 3)));
 void packet_buf_flush(struct strbuf *buf);
 void packet_buf_delim(struct strbuf *buf);
+void set_packet_header(char *buf, int size);
 void packet_write(int fd_out, const char *buf, size_t size);
 void packet_buf_write(struct strbuf *buf, const char *fmt, ...) __attribute__((format (printf, 2, 3)));
 void packet_buf_write_len(struct strbuf *buf, const char *data, size_t len);
@@ -62,16 +64,20 @@ int write_packetized_from_buf(const char
  *
  * If options contains PACKET_READ_CHOMP_NEWLINE, a trailing newline (if
  * present) is removed from the buffer before returning.
+ *
+ * If options contains PACKET_READ_DIE_ON_ERR_PACKET, it dies when it sees an
+ * ERR packet.
  */
-#define PACKET_READ_GENTLE_ON_EOF (1u<<0)
-#define PACKET_READ_CHOMP_NEWLINE (1u<<1)
+#define PACKET_READ_GENTLE_ON_EOF     (1u<<0)
+#define PACKET_READ_CHOMP_NEWLINE     (1u<<1)
+#define PACKET_READ_DIE_ON_ERR_PACKET (1u<<2)
 int packet_read(int fd, char **src_buffer, size_t *src_len, char
 		*buffer, unsigned size, int options);
 
 /*
  * Read a packetized line into a buffer like the 'packet_read()' function but
  * returns an 'enum packet_read_status' which indicates the status of the read.
- * The number of bytes read will be assigined to *pktlen if the status of the
+ * The number of bytes read will be assigned to *pktlen if the status of the
  * read was 'PACKET_READ_NORMAL'.
  */
 enum packet_read_status {
@@ -116,6 +122,21 @@ char *packet_read_line_buf(char **src_bu
  */
 ssize_t read_packetized_to_strbuf(int fd_in, struct strbuf *sb_out);
 
+/*
+ * Receive multiplexed output stream over git native protocol.
+ * in_stream is the input stream from the remote, which carries data
+ * in pkt_line format with band designator.  Demultiplex it into out
+ * and err and return error appropriately.  Band #1 carries the
+ * primary payload.  Things coming over band #2 is not necessarily
+ * error; they are usually informative message on the standard error
+ * stream, aka "verbose").  A message over band #3 is a signal that
+ * the remote died unexpectedly.  A flush() concludes the stream.
+ *
+ * Returns SIDEBAND_FLUSH upon a normal conclusion, and SIDEBAND_PROTOCOL_ERROR
+ * or SIDEBAND_REMOTE_ERROR if an error occurred.
+ */
+int recv_sideband(const char *me, int in_stream, int out);
+
 struct packet_reader {
 	/* source file descriptor */
 	int fd;
@@ -142,15 +163,18 @@ struct packet_reader {
 
 	/* indicates if a line has been peeked */
 	int line_peeked;
+
+	unsigned use_sideband : 1;
+	const char *me;
 };
 
 /*
  * Initialize a 'struct packet_reader' object which is an
  * abstraction around the 'packet_read_with_status()' function.
  */
-extern void packet_reader_init(struct packet_reader *reader, int fd,
-			       char *src_buffer, size_t src_len,
-			       int options);
+void packet_reader_init(struct packet_reader *reader, int fd,
+			char *src_buffer, size_t src_len,
+			int options);
 
 /*
  * Perform a packet read and return the status of the read.
@@ -162,7 +186,7 @@ extern void packet_reader_init(struct pa
  *		       'line' is set to point at the read line
  * PACKET_READ_FLUSH: 'pktlen' is set to '0' and 'line' is set to NULL
  */
-extern enum packet_read_status packet_reader_read(struct packet_reader *reader);
+enum packet_read_status packet_reader_read(struct packet_reader *reader);
 
 /*
  * Peek the next packet line without consuming it and return the status.
@@ -172,11 +196,26 @@ extern enum packet_read_status packet_re
  * Peeking multiple times without calling 'packet_reader_read()' will return
  * the same result.
  */
-extern enum packet_read_status packet_reader_peek(struct packet_reader *reader);
+enum packet_read_status packet_reader_peek(struct packet_reader *reader);
 
 #define DEFAULT_PACKET_MAX 1000
 #define LARGE_PACKET_MAX 65520
 #define LARGE_PACKET_DATA_MAX (LARGE_PACKET_MAX - 4)
 extern char packet_buffer[LARGE_PACKET_MAX];
 
+struct packet_writer {
+	int dest_fd;
+	unsigned use_sideband : 1;
+};
+
+void packet_writer_init(struct packet_writer *writer, int dest_fd);
+
+/* These functions die upon failure. */
+__attribute__((format (printf, 2, 3)))
+void packet_writer_write(struct packet_writer *writer, const char *fmt, ...);
+__attribute__((format (printf, 2, 3)))
+void packet_writer_error(struct packet_writer *writer, const char *fmt, ...);
+void packet_writer_delim(struct packet_writer *writer);
+void packet_writer_flush(struct packet_writer *writer);
+
 #endif
diff -pruN 1.2.1+git2.18.0-1/git/po/bg.po 1.2.3+git2.25.1-1/git/po/bg.po
--- 1.2.1+git2.18.0-1/git/po/bg.po	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/po/bg.po	2020-02-17 04:47:35.000000000 +0000
@@ -1,17 +1,19 @@
 # Bulgarian translation of git po-file.
-# Copyright (C) 2014, 2015, 2016, 2017, 2018 Alexander Shopov <ash@kambanaria.org>.
+# Copyright (C) 2014, 2015, 2016, 2017, 2018, 2019, 2020 Alexander Shopov <ash@kambanaria.org>.
 # This file is distributed under the same license as the git package.
-# Alexander Shopov <ash@kambanaria.org>, 2014, 2015, 2016, 2017, 2018.
+# Alexander Shopov <ash@kambanaria.org>, 2014, 2015, 2016, 2017, 2018, 2019, 2020.
 #
 # ========================
 # DICTIONARY TO MERGE IN GIT GUI
 # ------------------------
 # range диапазон
+# base база
+# tip връх
 # unreachable object недостижим обект
 # dangling objects обект извън клон
 # fast-forward превъртане
 # tree-level merge тривиално сливане (различни файлове са променяни, слива се като дърво)
-# automatic merge автоманично сливаве (еднакви файлове са променяни, но в неприпокриващи се части)
+# automatic merge автоматично сливане (еднакви файлове са променяни, но в неприпокриващи се части)
 # real merge същинско сливане (а не превъртане)
 # three-way merge тройно сливане
 # octopus merge множествено сливане
@@ -20,7 +22,7 @@
 # merge base база за сливане
 # force (push) принудително изтласквам
 # stash/index индекс
-# squash commit вкарвам подаване в преднходното
+# squash commit вкарвам подаване в предходното
 # fixup commit вкарвам подаване в предходното без следа
 # root commit начално подаване
 # remote-tracking branch следящ клон
@@ -29,7 +31,7 @@
 # am прилагам поредица от кръпки
 # working directory/tree — винаги работно дърво, git следи цялото дърво, а не директории, работна директория за cwd
 # switch to branch преминавам към клон
-# sparse entry частично изтеглена директория/път
+# sparse entry/blob частично изтеглена директория/път/обект-BLOB
 # revision range диапазон на версиите
 # cover letter придружаващо писмо
 # reference repository еталонно хранилище
@@ -38,6 +40,7 @@
 # replace refs заместващи указатели
 # embedded repository вградено/вътрешно хранилище (добавянето му е грешка)
 # thin pack съкратен пакет
+# pack file пакетен файл
 # stat (a file) получавам информация чрез „stat“ (за файл)
 # mixed reset смесено зануляване (индекса и указателя „HEAD“, без работното дърво)
 # soft reset меко зануляване (само указателя „HEAD“, без индекса и работното дърво)
@@ -74,9 +77,11 @@
 # term управляваща дума (за git-bisect)
 # mergetag етикет при сливане
 # packfile пакет
-# promisory гаратиращ, гарант promisory packfile гарантиращ пакет, promisory remote хранилище-гарант
+# promisory гарантиращ, гарант promisory packfile гарантиращ пакет, promisory remote хранилище-гарант
 # delta - разлика, делта, обект-разлика
-# peeled tag - проследен етикет - когато етикет сочи към друг етикет, а не подаване и проследяваме подобно на символна връзка
+# ??
+# peeled tag - проследяване на етикет - когато етикет сочи към друг етикет, а не подаване и проследяваме подобно на символна връзка
+# nested tag - непряк етикет
 # strip - премахвам (за компонент при филтриране)
 # unrelated histories - независими истории
 # inexact rename detection търсене на преименувания на обекти съчетани с промени
@@ -84,7 +89,7 @@
 # binary patch двоична кръпка
 # reverse-apply прилагам в обратна посока
 # todo file файл с команди
-# todo command запланувава команда
+# todo command запланувана команда
 # alternate алтернативен източник
 # superproject обхващащ проект
 # split index разделяне на индекса
@@ -103,6 +108,41 @@
 # collection/series of patches поредица от кръпки
 # recieve получавам
 # BOM маркер за поредността на байтовете
+# acknowledgment line ред за потвърждение
+# wanted-ref искан указател
+# chunk откъс
+# clean filter декодиращ филтър
+# smudge filter кодиращ филтър
+# loose object непакетиран обект
+# flush изчистване на буферите
+# flush packet изчистващ пакет
+# fork създаване на процес
+# capabilities възможности
+# remote-helper насрещна помощна програма
+# command alias псевдоним на команда
+# rerere преизползване на запазена корекция на сливане с конфликт
+# preimage предварителен вариант
+# offset отместване
+# multi-pack-index индекс за множество пакети
+# range diff диапазонна разлика
+# inter diff разлика в разликите
+# ssl backend реализация на SSL
+# delta island група разлики
+# island marks граници на групите
+# reflog журнал на указателите
+# hash контролна сума, изчисляване на контролна сума
+# fanout откъс (разперване???)
+# idx - index of pack file, 1 index per 1 packfile
+# midx - multi-pack index, for objects across multiple packfiles
+# overlay mode - припокриващ режим (при изтеглянe)
+# incremental file нарастващ файл
+# split (commit-graphr) раздробен (граф с подавания)
+# clobber (a tag) презаписвам (етикет)
+# blame извеждане на авторство
+# refname име на указател
+# cone pattern matching пътеводно напасване
+# negative pattern отрицателен шаблон
+# colored hunk/diff оцветено парче/разлика
 # ------------------------
 # „$var“ - може да не сработва за shell има gettext и eval_gettext - проверка - намират се лесно по „$
 # ------------------------
@@ -110,12 +150,19 @@
 # HEAD as a reference vs head of a branch
 # git update-index -h извежда само един ред, а не цялата помощ за опциите
 # git fetch --al работи подобно на --all
+# ------------------------
+# export PO_FILE=bg.po
+# msgattrib --only-fuzzy  $PO_FILE > todo1.po
+# msgattrib --untranslated  $PO_FILE > todo2.po
+# msgcat todo1.po todo2.po > todo.po
+# grep '^#: ' todo.po | sed 's/^#: //' | tr ' ' '\n' | sed 's/:[0-9]*$//' > FILES
+# for i in `sort -u FILES`; do cnt=`grep $i FILES | wc -l`; echo $cnt $i ;done | sort -n
 msgid ""
 msgstr ""
-"Project-Id-Version: git master\n"
+"Project-Id-Version: git 2.25\n"
 "Report-Msgid-Bugs-To: Git Mailing List <git@vger.kernel.org>\n"
-"POT-Creation-Date: 2018-06-16 22:06+0800\n"
-"PO-Revision-Date: 2018-06-17 13:16+0200\n"
+"POT-Creation-Date: 2020-01-09 16:22+0100\n"
+"PO-Revision-Date: 2020-01-09 16:31+0100\n"
 "Last-Translator: Alexander Shopov <ash@kambanaria.org>\n"
 "Language-Team: Bulgarian <dict@fsa-bg.org>\n"
 "Language: bg\n"
@@ -124,37 +171,467 @@ msgstr ""
 "Content-Transfer-Encoding: 8bit\n"
 "Plural-Forms: nplurals=2; plural=(n != 1);\n"
 
-#: advice.c:92
+#: add-interactive.c:347
+#, c-format
+msgid "Huh (%s)?"
+msgstr "Неуспешен анализ — „%s“."
+
+#: add-interactive.c:500 add-interactive.c:801 sequencer.c:3216
+#: sequencer.c:3656 builtin/rebase.c:871 builtin/rebase.c:1643
+#: builtin/rebase.c:2019 builtin/rebase.c:2063
+msgid "could not read index"
+msgstr "индексът не може да бъде прочетен"
+
+#: add-interactive.c:555 git-add--interactive.perl:269
+#: git-add--interactive.perl:294
+msgid "binary"
+msgstr "двоично"
+
+#: add-interactive.c:613 git-add--interactive.perl:278
+#: git-add--interactive.perl:332
+msgid "nothing"
+msgstr "нищо"
+
+#: add-interactive.c:614 git-add--interactive.perl:314
+#: git-add--interactive.perl:329
+msgid "unchanged"
+msgstr "няма промени"
+
+#: add-interactive.c:651 git-add--interactive.perl:643
+msgid "Update"
+msgstr "Обновяване"
+
+#: add-interactive.c:668 add-interactive.c:856
+#, c-format
+msgid "could not stage '%s'"
+msgstr "неуспешно добавяне в индекса на „%s“"
+
+#: add-interactive.c:674 add-interactive.c:863 sequencer.c:3409
+#: builtin/rebase.c:895
+msgid "could not write index"
+msgstr "индексът не може да бъде записан"
+
+#: add-interactive.c:677 git-add--interactive.perl:628
+#, c-format, perl-format
+msgid "updated %d path\n"
+msgid_plural "updated %d paths\n"
+msgstr[0] "%d файл обновен\n"
+msgstr[1] "%d файла обновени\n"
+
+#: add-interactive.c:695 git-add--interactive.perl:678
+#, c-format, perl-format
+msgid "note: %s is untracked now.\n"
+msgstr "БЕЛЕЖКА: „%s“ вече не се следи.\n"
+
+#: add-interactive.c:700 apply.c:4108 builtin/checkout.c:281
+#: builtin/reset.c:144
+#, c-format
+msgid "make_cache_entry failed for path '%s'"
+msgstr "неуспешно създаване на запис в кеша чрез „make_cache_entry“ за „%s“"
+
+#: add-interactive.c:730 git-add--interactive.perl:655
+msgid "Revert"
+msgstr "Отмяна"
+
+#: add-interactive.c:746
+msgid "Could not parse HEAD^{tree}"
+msgstr "Указателят „HEAD^{tree}“ не може да бъде анализиран"
+
+#: add-interactive.c:784 git-add--interactive.perl:631
+#, c-format, perl-format
+msgid "reverted %d path\n"
+msgid_plural "reverted %d paths\n"
+msgstr[0] "%d файл с отменени промени\n"
+msgstr[1] "%d файла с отменени промени\n"
+
+#: add-interactive.c:835 git-add--interactive.perl:695
+#, c-format
+msgid "No untracked files.\n"
+msgstr "Няма неследени файлове.\n"
+
+#: add-interactive.c:839 git-add--interactive.perl:689
+msgid "Add untracked"
+msgstr "Добавяне на неследени"
+
+#: add-interactive.c:866 git-add--interactive.perl:625
+#, c-format, perl-format
+msgid "added %d path\n"
+msgid_plural "added %d paths\n"
+msgstr[0] "%d файл добавен\n"
+msgstr[1] "%d файла добавени\n"
+
+#: add-interactive.c:896
+#, c-format
+msgid "ignoring unmerged: %s"
+msgstr "пренебрегване на неслятото: „%s“"
+
+#: add-interactive.c:908 add-patch.c:1331 git-add--interactive.perl:1366
+#, c-format
+msgid "Only binary files changed.\n"
+msgstr "Само двоични файлове са променени.\n"
+
+#: add-interactive.c:910 add-patch.c:1329 git-add--interactive.perl:1368
+#, c-format
+msgid "No changes.\n"
+msgstr "Няма промени.\n"
+
+#: add-interactive.c:914 git-add--interactive.perl:1376
+msgid "Patch update"
+msgstr "Обновяване на кръпка"
+
+#: add-interactive.c:953 git-add--interactive.perl:1754
+msgid "Review diff"
+msgstr "Преглед на разликата"
+
+#: add-interactive.c:981
+msgid "show paths with changes"
+msgstr "извеждане на пътищата с промени"
+
+#: add-interactive.c:983
+msgid "add working tree state to the staged set of changes"
+msgstr "добавяне на състоянието на работното дърво към промените в индекса"
+
+#: add-interactive.c:985
+msgid "revert staged set of changes back to the HEAD version"
+msgstr "връщане на състоянието на индекса към соченото от „HEAD“"
+
+#: add-interactive.c:987
+msgid "pick hunks and update selectively"
+msgstr "интерактивни избор и промяна на парчета код"
+
+#: add-interactive.c:989
+msgid "view diff between HEAD and index"
+msgstr "разлика между соченото от „HEAD“ и индекса"
+
+#: add-interactive.c:991
+msgid "add contents of untracked files to the staged set of changes"
+msgstr "добавяне на съдържанието на неследените файлове към индекса"
+
+#: add-interactive.c:999 add-interactive.c:1048
+msgid "Prompt help:"
+msgstr "Помощ:"
+
+#: add-interactive.c:1001
+msgid "select a single item"
+msgstr "избор на eдин елемент"
+
+#: add-interactive.c:1003
+msgid "select a range of items"
+msgstr "избор на поредица от елементи"
+
+#: add-interactive.c:1005
+msgid "select multiple ranges"
+msgstr "избор на няколко поредици от елементи"
+
+#: add-interactive.c:1007 add-interactive.c:1052
+msgid "select item based on unique prefix"
+msgstr "избор на базата на уникален префикс"
+
+#: add-interactive.c:1009
+msgid "unselect specified items"
+msgstr "изваждане на указаното от избора"
+
+#: add-interactive.c:1011
+msgid "choose all items"
+msgstr "избор на всички елементи"
+
+#: add-interactive.c:1013
+msgid "(empty) finish selecting"
+msgstr "(празно) приключване на избирането"
+
+#: add-interactive.c:1050
+msgid "select a numbered item"
+msgstr "избор на номериран елемент"
+
+#: add-interactive.c:1054
+msgid "(empty) select nothing"
+msgstr "(празно) без избор на нищо"
+
+#: add-interactive.c:1062 builtin/clean.c:822 git-add--interactive.perl:1851
+msgid "*** Commands ***"
+msgstr "●●● Команди ●●●"
+
+#: add-interactive.c:1063 builtin/clean.c:823 git-add--interactive.perl:1848
+msgid "What now"
+msgstr "Избор на следващо действие"
+
+#: add-interactive.c:1115 git-add--interactive.perl:213
+msgid "staged"
+msgstr "в индекса"
+
+#: add-interactive.c:1115 git-add--interactive.perl:213
+msgid "unstaged"
+msgstr "извън индекса"
+
+#: add-interactive.c:1115 apply.c:4965 apply.c:4968 builtin/am.c:2197
+#: builtin/am.c:2200 builtin/clone.c:123 builtin/fetch.c:144
+#: builtin/merge.c:273 builtin/pull.c:209 builtin/submodule--helper.c:409
+#: builtin/submodule--helper.c:1379 builtin/submodule--helper.c:1382
+#: builtin/submodule--helper.c:1875 builtin/submodule--helper.c:1878
+#: builtin/submodule--helper.c:2119 git-add--interactive.perl:213
+msgid "path"
+msgstr "път"
+
+#: add-interactive.c:1122
+msgid "could not refresh index"
+msgstr "индексът не може да бъде обновен"
+
+#
+#: add-interactive.c:1136 builtin/clean.c:787 git-add--interactive.perl:1765
+#, c-format
+msgid "Bye.\n"
+msgstr "Изход.\n"
+
+#: add-patch.c:15
+#, c-format
+msgid "Stage mode change [y,n,a,q,d%s,?]? "
+msgstr "Добавяне на промяната на правата за достъп [y,n,a,q,d%s,?]? "
+
+#: add-patch.c:16
+#, c-format
+msgid "Stage deletion [y,n,a,q,d%s,?]? "
+msgstr "Добавяне на изтриването [y,n,a,q,d%s,?]? "
+
+#: add-patch.c:17
+#, c-format
+msgid "Stage this hunk [y,n,a,q,d%s,?]? "
+msgstr "Добавяне на това парче [y,n,a,q,d%s,?]? "
+
+#: add-patch.c:111
+#, c-format
+msgid "could not parse hunk header '%.*s'"
+msgstr "заглавната част на парчето „%.*s“ не може да се анализира"
+
+#: add-patch.c:130 add-patch.c:134
+#, c-format
+msgid "could not parse colored hunk header '%.*s'"
+msgstr "заглавната част на оцветеното парче „%.*s“ не може да се анализира"
+
+#: add-patch.c:176
+msgid "could not parse diff"
+msgstr "разликата не може да се анализира"
+
+#: add-patch.c:194
+msgid "could not parse colored diff"
+msgstr "оцветената разлика не може да се анализира"
+
+#: add-patch.c:508
+#, c-format
+msgid ""
+"expected context line #%d in\n"
+"%.*s"
+msgstr ""
+"очаква се ред №%d от контекста в\n"
+"%.*s"
+
+#: add-patch.c:523
+#, c-format
+msgid ""
+"hunks do not overlap:\n"
+"%.*s\n"
+"\tdoes not end with:\n"
+"%.*s"
+msgstr ""
+"парчетата код не се припокриват:\n"
+"%.*s\n"
+"    не завършва с:\n"
+"%.*s"
+
+#: add-patch.c:799 git-add--interactive.perl:1112
+msgid "Manual hunk edit mode -- see bottom for a quick guide.\n"
+msgstr "Ръчно редактиране на парчета код — отдолу има подсказка.\n"
+
+#: add-patch.c:803
+#, c-format
+msgid ""
+"---\n"
+"To remove '%c' lines, make them ' ' lines (context).\n"
+"To remove '%c' lines, delete them.\n"
+"Lines starting with %c will be removed.\n"
+msgstr ""
+"———\n"
+"За да пропуснете редовете, започващи с „%c“: заменете знака с „ “ (стават "
+"контекст)\n"
+"За да пропуснете редовете, започващи с „%c“: изтрийте ги.\n"
+"Редовете, които започват с „%c“ ще бъдат пропуснати.\n"
+
+#: add-patch.c:810
+msgid ""
+"If the patch applies cleanly, the edited hunk will immediately be\n"
+"marked for staging.\n"
+msgstr ""
+"Ако кръпката може да се приложи чисто, редактираното парче ще бъде "
+"незабавно\n"
+"добавено към индекса.\n"
+
+#. TRANSLATORS: 'it' refers to the patch mentioned in the previous messages.
+#: add-patch.c:818 git-add--interactive.perl:1126
+msgid ""
+"If it does not apply cleanly, you will be given an opportunity to\n"
+"edit again.  If all lines of the hunk are removed, then the edit is\n"
+"aborted and the hunk is left unchanged.\n"
+msgstr ""
+"Ако е невъзможно чисто прилагане на кода, ще може пак да редактирате.  Ако\n"
+"изтриете всички редове от парчето код, то ще бъде оставено непроменено, а\n"
+"редактирането — отказано.\n"
+
+#: add-patch.c:851
+msgid "could not parse hunk header"
+msgstr "заглавната част парчето не може да се анализира"
+
+#: add-patch.c:895 add-patch.c:1294
+msgid "'git apply --cached' failed"
+msgstr "неуспешно изпълнение на „git apply --cached“"
+
+#. TRANSLATORS: do not translate [y/n]
+#. The program will only accept that input at this point.
+#. Consider translating (saying "no" discards!) as
+#. (saying "n" for "no" discards!) if the translation
+#. of the word "no" does not start with n.
+#.
+#. TRANSLATORS: do not translate [y/n]
+#. The program will only accept that input
+#. at this point.
+#. Consider translating (saying "no" discards!) as
+#. (saying "n" for "no" discards!) if the translation
+#. of the word "no" does not start with n.
+#: add-patch.c:952 git-add--interactive.perl:1239
+msgid ""
+"Your edited hunk does not apply. Edit again (saying \"no\" discards!) [y/n]? "
+msgstr ""
+"Редактираното парче не може да се приложи.  Да се продължи ли с "
+"редактирането? (текущите редакции ще се отменят при отказ!): „y“ (да)/ "
+"„n“ (не)? "
+
+#: add-patch.c:1009
+msgid ""
+"y - stage this hunk\n"
+"n - do not stage this hunk\n"
+"q - quit; do not stage this hunk or any of the remaining ones\n"
+"a - stage this and all the remaining hunks\n"
+"d - do not stage this hunk nor any of the remaining hunks\n"
+msgstr ""
+"y — добавяне на парчето в индекса\n"
+"n — без добавяне на парчето в индекса\n"
+"q — изход, без добавяне на това и всички оставащи парчета\n"
+"a — добавяне на това и всички следващи парчета в индекса\n"
+"d — без добавяне на това и всички оставащи парчета в индекса\n"
+
+#: add-patch.c:1016
+msgid ""
+"j - leave this hunk undecided, see next undecided hunk\n"
+"J - leave this hunk undecided, see next hunk\n"
+"k - leave this hunk undecided, see previous undecided hunk\n"
+"K - leave this hunk undecided, see previous hunk\n"
+"g - select a hunk to go to\n"
+"/ - search for a hunk matching the given regex\n"
+"s - split the current hunk into smaller hunks\n"
+"e - manually edit the current hunk\n"
+"? - print help\n"
+msgstr ""
+"j — без решение за парчето, към следващото парче без решение\n"
+"J — без решение за парчето, към следващото парче\n"
+"k — без решение за парчето, към предишното парче без решение\n"
+"K — без решение за парчето, към предишното парче\n"
+"g — избор към кое парче да се премине\n"
+"/ — търсене на парче, напасващо към даден регулярен израз\n"
+"s — разделяне на текущото парче на по-малки\n"
+"e — ръчно редактиране на текущото парче\n"
+"? — извеждане не помощта\n"
+
+#: add-patch.c:1137 add-patch.c:1147
+msgid "No previous hunk"
+msgstr "Няма друго парче преди това"
+
+#: add-patch.c:1142 add-patch.c:1152
+msgid "No next hunk"
+msgstr "Няма друго парче след това"
+
+#: add-patch.c:1158
+msgid "No other hunks to goto"
+msgstr "Няма други парчета"
+
+#: add-patch.c:1169 git-add--interactive.perl:1577
+msgid "go to which hunk (<ret> to see more)? "
+msgstr "към кое парче да се придвижи (за повече варианти натиснете „enter“)? "
+
+#: add-patch.c:1170 git-add--interactive.perl:1579
+msgid "go to which hunk? "
+msgstr "към кое парче да се придвижи? "
+
+#: add-patch.c:1181
+#, c-format
+msgid "Invalid number: '%s'"
+msgstr "Неправилен номер: „%s“"
+
+#: add-patch.c:1186
+#, c-format
+msgid "Sorry, only %d hunk available."
+msgid_plural "Sorry, only %d hunks available."
+msgstr[0] "Има само %d парче."
+msgstr[1] "Има само %d парчета."
+
+#: add-patch.c:1195
+msgid "No other hunks to search"
+msgstr "Няма други парчета за търсене"
+
+#: add-patch.c:1201 git-add--interactive.perl:1623
+msgid "search for regex? "
+msgstr "да се търси с регулярен израз? "
+
+#: add-patch.c:1216
+#, c-format
+msgid "Malformed search regexp %s: %s"
+msgstr "Сгрешен регулярен израз „%s“: %s"
+
+#: add-patch.c:1233
+msgid "No hunk matches the given pattern"
+msgstr "Никое парче не напасва на регулярния израз"
+
+#: add-patch.c:1240
+msgid "Sorry, cannot split this hunk"
+msgstr "Това парче не може да бъде разделено"
+
+#: add-patch.c:1244
+#, c-format
+msgid "Split into %d hunks."
+msgstr "Разделяне на %d парчета."
+
+#: add-patch.c:1248
+msgid "Sorry, cannot edit this hunk"
+msgstr "Това парче не може да бъде редактирано"
+
+#: advice.c:111
 #, c-format
 msgid "%shint: %.*s%s\n"
 msgstr "%sподсказка: %.*s%s\n"
 
-#: advice.c:137
+#: advice.c:164
 msgid "Cherry-picking is not possible because you have unmerged files."
 msgstr "Отбирането на подавания е блокирано от неслети файлове."
 
-#: advice.c:139
+#: advice.c:166
 msgid "Committing is not possible because you have unmerged files."
 msgstr "Подаването е блокирано от неслети файлове."
 
-#: advice.c:141
+#: advice.c:168
 msgid "Merging is not possible because you have unmerged files."
 msgstr "Сливането е блокирано от неслети файлове."
 
-#: advice.c:143
+#: advice.c:170
 msgid "Pulling is not possible because you have unmerged files."
 msgstr "Издърпването е блокирано от неслети файлове."
 
-#: advice.c:145
+#: advice.c:172
 msgid "Reverting is not possible because you have unmerged files."
 msgstr "Отмяната е блокирана от неслети файлове."
 
-#: advice.c:147
+#: advice.c:174
 #, c-format
 msgid "It is not possible to %s because you have unmerged files."
 msgstr "Действието „%s“ е блокирано от неслети файлове."
 
-#: advice.c:155
+#: advice.c:182
 msgid ""
 "Fix them up in the work tree, and then use 'git add/rm <file>'\n"
 "as appropriate to mark resolution and make a commit."
@@ -162,38 +639,45 @@ msgstr ""
 "Редактирайте ги в работното дърво, и тогава ползвайте „git add/rm ФАЙЛ“,\n"
 "за да отбележите коригирането им.  След това извършете подаването."
 
-#: advice.c:163
+#: advice.c:190
 msgid "Exiting because of an unresolved conflict."
 msgstr "Изход от програмата заради некоригиран конфликт."
 
-#: advice.c:168 builtin/merge.c:1250
+#: advice.c:195 builtin/merge.c:1332
 msgid "You have not concluded your merge (MERGE_HEAD exists)."
 msgstr "Не сте завършили сливане.  (Указателят „MERGE_HEAD“ съществува)."
 
-#: advice.c:170
+#: advice.c:197
 msgid "Please, commit your changes before merging."
 msgstr "Промените трябва да се подадат преди сливане."
 
-#: advice.c:171
+#: advice.c:198
 msgid "Exiting because of unfinished merge."
 msgstr "Изход от програмата заради незавършено сливане."
 
-#: advice.c:177
+#: advice.c:204
 #, c-format
 msgid ""
-"Note: checking out '%s'.\n"
+"Note: switching to '%s'.\n"
 "\n"
 "You are in 'detached HEAD' state. You can look around, make experimental\n"
 "changes and commit them, and you can discard any commits you make in this\n"
-"state without impacting any branches by performing another checkout.\n"
+"state without impacting any branches by switching back to a branch.\n"
 "\n"
 "If you want to create a new branch to retain commits you create, you may\n"
-"do so (now or later) by using -b with the checkout command again. Example:\n"
+"do so (now or later) by using -c with the switch command. Example:\n"
+"\n"
+"  git switch -c <new-branch-name>\n"
+"\n"
+"Or undo this operation with:\n"
+"\n"
+"  git switch -\n"
 "\n"
-"  git checkout -b <new-branch-name>\n"
+"Turn off this advice by setting config variable advice.detachedHead to "
+"false\n"
 "\n"
 msgstr ""
-"Бележка: изтегляне на „%s“.\n"
+"Бележка: преминаване към „%s“.\n"
 "\n"
 "Указателят „HEAD“ не е свързан.  Може да разглеждате, да правите произволни\n"
 "промени и да ги подавате.  Ако изтеглите нещо друго, всички промени ще "
@@ -201,106 +685,111 @@ msgstr ""
 "забравени и никой клон няма да се промени.\n"
 "\n"
 "Ако искате да създадете нов клон, за да запазите подаванията си, можете да\n"
-"направите това като зададете име на клон към опцията „-b“ на командата\n"
-"„commit“.  Например:\n"
+"направите това като зададете име на клон към опцията „-c“ на командата\n"
+"„switch“.  Например:\n"
 "\n"
-"  git checkout -b ИМЕ_НА_НОВ_КЛОН\n"
+"    git switch -c ИМЕ_НА_НОВ_КЛОН\n"
 "\n"
+"Може да отмените това действие с командата:\n"
+"\n"
+"    git switch -\n"
+"\n"
+"Може да спрете това съобщение със задаване на настройката „advice."
+"detachedHead“\n"
+"да е „false“.\n"
+
+#: alias.c:50
+msgid "cmdline ends with \\"
+msgstr "командният ред завършва с „/“"
+
+#: alias.c:51
+msgid "unclosed quote"
+msgstr "кавичка без еш"
 
-#: apply.c:58
+#: apply.c:69
 #, c-format
 msgid "unrecognized whitespace option '%s'"
 msgstr "непозната опция за знаците за интервали „%s“"
 
-#: apply.c:74
+#: apply.c:85
 #, c-format
 msgid "unrecognized whitespace ignore option '%s'"
 msgstr "непозната опция за игнориране на знаците за интервали „%s“"
 
-#: apply.c:122
+#: apply.c:135
 msgid "--reject and --3way cannot be used together."
 msgstr "опциите „--reject“ и „--3way“ са несъвместими"
 
-#: apply.c:124
+#: apply.c:137
 msgid "--cached and --3way cannot be used together."
 msgstr "опциите „--cached“ и „--3way“ са несъвместими"
 
-#: apply.c:127
+#: apply.c:140
 msgid "--3way outside a repository"
 msgstr "като „--3way“, но извън хранилище"
 
-#: apply.c:138
+#: apply.c:151
 msgid "--index outside a repository"
 msgstr "като „--index“, но извън хранилище"
 
-#: apply.c:141
+#: apply.c:154
 msgid "--cached outside a repository"
 msgstr "като „--cached“, но извън хранилище"
 
-#: apply.c:821
+#: apply.c:801
 #, c-format
 msgid "Cannot prepare timestamp regexp %s"
 msgstr "Регулярният израз за времето „%s“ не може за бъде компилиран"
 
-#: apply.c:830
+#: apply.c:810
 #, c-format
 msgid "regexec returned %d for input: %s"
 msgstr "Регулярният израз върна %d при подадена последователност „%s“ на входа"
 
-#: apply.c:904
+#: apply.c:884
 #, c-format
 msgid "unable to find filename in patch at line %d"
 msgstr "Липсва име на файл на ред %d от кръпката"
 
-#: apply.c:942
+#: apply.c:922
 #, c-format
 msgid "git apply: bad git-diff - expected /dev/null, got %s on line %d"
 msgstr ""
 "git apply: лош изход от командата „git-diff“ — на ред %2$d се очакваше „/dev/"
 "null“, а бе получен „%1$s“"
 
-#: apply.c:948
+#: apply.c:928
 #, c-format
 msgid "git apply: bad git-diff - inconsistent new filename on line %d"
 msgstr ""
 "git apply: лош изход от командата „git-diff“ — на ред %d бе получено "
 "неправилно име на нов файл"
 
-#: apply.c:949
+#: apply.c:929
 #, c-format
 msgid "git apply: bad git-diff - inconsistent old filename on line %d"
 msgstr ""
 "git apply: лош изход от командата „git-diff“ — на ред %d бе получено "
 "неправилно име на стар файл"
 
-#: apply.c:954
+#: apply.c:934
 #, c-format
 msgid "git apply: bad git-diff - expected /dev/null on line %d"
 msgstr ""
 "git apply: лош изход от командата „git-diff“ — на ред %d се очакваше „/dev/"
 "null“"
 
-#: apply.c:983
+#: apply.c:963
 #, c-format
 msgid "invalid mode on line %d: %s"
 msgstr "грешен режим на ред №%d: %s"
 
-#: apply.c:1301
+#: apply.c:1282
 #, c-format
 msgid "inconsistent header lines %d and %d"
 msgstr "несъвместими заглавни части на редове №%d и №%d"
 
-#: apply.c:1473
-#, c-format
-msgid "recount: unexpected line: %.*s"
-msgstr "при повторното преброяване бе получен неочакван ред: „%.*s“"
-
-#: apply.c:1542
-#, c-format
-msgid "patch fragment without header at line %d: %.*s"
-msgstr "част от кръпка без заглавна част на ред %d: %.*s"
-
-#: apply.c:1562
+#: apply.c:1372
 #, c-format
 msgid ""
 "git diff header lacks filename information when removing %d leading pathname "
@@ -315,71 +804,81 @@ msgstr[1] ""
 "След съкращаването на първите %d части от компонентите на пътя, в заглавната "
 "част на „git diff“ липсва информация за име на файл (ред: %d)"
 
-#: apply.c:1575
+#: apply.c:1385
 #, c-format
 msgid "git diff header lacks filename information (line %d)"
 msgstr ""
 "в заглавната част на „git diff“ липсва информация за име на файл (ред: %d)"
 
-#: apply.c:1763
+#: apply.c:1481
+#, c-format
+msgid "recount: unexpected line: %.*s"
+msgstr "при повторното преброяване бе получен неочакван ред: „%.*s“"
+
+#: apply.c:1550
+#, c-format
+msgid "patch fragment without header at line %d: %.*s"
+msgstr "част от кръпка без заглавна част на ред %d: %.*s"
+
+#: apply.c:1753
 msgid "new file depends on old contents"
 msgstr "новият файл зависи от старото съдържание на файла"
 
-#: apply.c:1765
+#: apply.c:1755
 msgid "deleted file still has contents"
 msgstr "изтритият файл не е празен"
 
-#: apply.c:1799
+#: apply.c:1789
 #, c-format
 msgid "corrupt patch at line %d"
 msgstr "грешка в кръпката на ред %d"
 
-#: apply.c:1836
+#: apply.c:1826
 #, c-format
 msgid "new file %s depends on old contents"
 msgstr "новият файл „%s“ зависи от старото съдържание на файла"
 
-#: apply.c:1838
+#: apply.c:1828
 #, c-format
 msgid "deleted file %s still has contents"
 msgstr "изтритият файл „%s“ не е празен"
 
-#: apply.c:1841
+#: apply.c:1831
 #, c-format
 msgid "** warning: file %s becomes empty but is not deleted"
 msgstr "● предупреждение: файлът „%s“ вече е празен, но не е изтрит"
 
-#: apply.c:1988
+#: apply.c:1978
 #, c-format
 msgid "corrupt binary patch at line %d: %.*s"
 msgstr "грешка в двоичната кръпка на ред %d: %.*s"
 
-#: apply.c:2025
+#: apply.c:2015
 #, c-format
 msgid "unrecognized binary patch at line %d"
 msgstr "неразпозната двоичната кръпка на ред %d"
 
-#: apply.c:2185
+#: apply.c:2177
 #, c-format
 msgid "patch with only garbage at line %d"
 msgstr "кръпката е с изцяло повредени данни на ред %d"
 
-#: apply.c:2271
+#: apply.c:2263
 #, c-format
 msgid "unable to read symlink %s"
 msgstr "символната връзка „%s“ не може да бъде прочетена"
 
-#: apply.c:2275
+#: apply.c:2267
 #, c-format
 msgid "unable to open or read %s"
 msgstr "файлът „%s“ не може да бъде отворен или прочетен"
 
-#: apply.c:2934
+#: apply.c:2936
 #, c-format
 msgid "invalid start of line: '%c'"
 msgstr "неправилно начало на ред: „%c“"
 
-#: apply.c:3055
+#: apply.c:3057
 #, c-format
 msgid "Hunk #%d succeeded at %d (offset %d line)."
 msgid_plural "Hunk #%d succeeded at %d (offset %d lines)."
@@ -388,13 +887,13 @@ msgstr[0] ""
 msgstr[1] ""
 "%d-то парче код бе успешно приложено на ред %d (отместване от %d реда)."
 
-#: apply.c:3067
+#: apply.c:3069
 #, c-format
 msgid "Context reduced to (%ld/%ld) to apply fragment at %d"
 msgstr ""
 "Контекстът е намален на (%ld/%ld) за прилагането на парчето код на ред %d"
 
-#: apply.c:3073
+#: apply.c:3075
 #, c-format
 msgid ""
 "while searching for:\n"
@@ -403,316 +902,312 @@ msgstr ""
 "при търсене за:\n"
 "%.*s"
 
-#: apply.c:3095
+#: apply.c:3097
 #, c-format
 msgid "missing binary patch data for '%s'"
 msgstr "липсват данните за двоичната кръпка за „%s“"
 
-#: apply.c:3103
+#: apply.c:3105
 #, c-format
 msgid "cannot reverse-apply a binary patch without the reverse hunk to '%s'"
 msgstr ""
 "двоичната кръпка не може да се приложи в обратна посока, когато обратното "
 "парче за „%s“ липсва"
 
-#: apply.c:3149
+#: apply.c:3152
 #, c-format
 msgid "cannot apply binary patch to '%s' without full index line"
 msgstr "към „%s“ не може да се приложи двоична кръпка без пълен индекс"
 
-#: apply.c:3159
+#: apply.c:3162
 #, c-format
 msgid ""
 "the patch applies to '%s' (%s), which does not match the current contents."
 msgstr "кръпката съответства на „%s“ (%s), който не съвпада по съдържание."
 
-#: apply.c:3167
+#: apply.c:3170
 #, c-format
 msgid "the patch applies to an empty '%s' but it is not empty"
 msgstr "кръпката съответства на „%s“, който трябва да е празен, но не е"
 
-#: apply.c:3185
+#: apply.c:3188
 #, c-format
 msgid "the necessary postimage %s for '%s' cannot be read"
 msgstr ""
 "необходимият резултат след операцията  — „%s“ за „%s“ не може да бъде "
 "прочетен"
 
-#: apply.c:3198
+#: apply.c:3201
 #, c-format
 msgid "binary patch does not apply to '%s'"
 msgstr "двоичната кръпка не може да бъде приложена върху „%s“"
 
-#: apply.c:3204
+#: apply.c:3207
 #, c-format
 msgid "binary patch to '%s' creates incorrect result (expecting %s, got %s)"
 msgstr ""
 "двоичната кръпка за „%s“ води до неправилни резултати (очакваше се: „%s“, а "
 "бе получено: „%s“)"
 
-#: apply.c:3225
+#: apply.c:3228
 #, c-format
 msgid "patch failed: %s:%ld"
 msgstr "неуспешно прилагане на кръпка: „%s:%ld“"
 
-#: apply.c:3347
+#: apply.c:3351
 #, c-format
 msgid "cannot checkout %s"
 msgstr "„%s“ не може да се изтегли"
 
-#: apply.c:3396 apply.c:3407 apply.c:3453 setup.c:278
+#: apply.c:3403 apply.c:3414 apply.c:3460 midx.c:61 setup.c:280
 #, c-format
 msgid "failed to read %s"
 msgstr "файлът „%s“ не може да бъде прочетен"
 
-#: apply.c:3404
+#: apply.c:3411
 #, c-format
 msgid "reading from '%s' beyond a symbolic link"
 msgstr "изчитане на „%s“ след проследяване на символна връзка"
 
-#: apply.c:3433 apply.c:3673
+#: apply.c:3440 apply.c:3683
 #, c-format
 msgid "path %s has been renamed/deleted"
 msgstr "обектът с път „%s“ е преименуван или изтрит"
 
-#: apply.c:3516 apply.c:3687
+#: apply.c:3526 apply.c:3698
 #, c-format
 msgid "%s: does not exist in index"
 msgstr "„%s“ не съществува в индекса"
 
-#: apply.c:3525 apply.c:3695
+#: apply.c:3535 apply.c:3706
 #, c-format
 msgid "%s: does not match index"
 msgstr "„%s“ не съответства на индекса"
 
-#: apply.c:3560
+#: apply.c:3570
 msgid "repository lacks the necessary blob to fall back on 3-way merge."
 msgstr ""
 "в хранилището липсват необходимите обекти-BLOB, за да се премине към тройно "
 "сливане."
 
-#: apply.c:3563
+#: apply.c:3573
 #, c-format
 msgid "Falling back to three-way merge...\n"
 msgstr "Преминаване към тройно сливане…\n"
 
-#: apply.c:3579 apply.c:3583
+#: apply.c:3589 apply.c:3593
 #, c-format
 msgid "cannot read the current contents of '%s'"
 msgstr "текущото съдържание на „%s“ не може да бъде прочетено"
 
-#: apply.c:3595
+#: apply.c:3605
 #, c-format
 msgid "Failed to fall back on three-way merge...\n"
 msgstr "Неуспешно преминаване към тройно сливане…\n"
 
-#: apply.c:3609
+#: apply.c:3619
 #, c-format
 msgid "Applied patch to '%s' with conflicts.\n"
 msgstr "Конфликти при прилагането на кръпката към „%s“.\n"
 
-#: apply.c:3614
+#: apply.c:3624
 #, c-format
 msgid "Applied patch to '%s' cleanly.\n"
 msgstr "Кръпката бе приложена чисто към „%s“.\n"
 
-#: apply.c:3640
+#: apply.c:3650
 msgid "removal patch leaves file contents"
 msgstr "изтриващата кръпка оставя файла непразен"
 
-#: apply.c:3712
+#: apply.c:3723
 #, c-format
 msgid "%s: wrong type"
 msgstr "„%s“: неправилен вид"
 
-#: apply.c:3714
+#: apply.c:3725
 #, c-format
 msgid "%s has type %o, expected %o"
 msgstr "„%s“ е от вид „%o“, а се очакваше „%o“"
 
-#: apply.c:3864 apply.c:3866
+#: apply.c:3876 apply.c:3878 read-cache.c:830 read-cache.c:856
+#: read-cache.c:1325
 #, c-format
 msgid "invalid path '%s'"
 msgstr "неправилен път: „%s“"
 
-#: apply.c:3922
+#: apply.c:3934
 #, c-format
 msgid "%s: already exists in index"
 msgstr "„%s“: вече съществува в индекса"
 
-#: apply.c:3925
+#: apply.c:3937
 #, c-format
 msgid "%s: already exists in working directory"
 msgstr "„%s“: вече съществува в работното дърво"
 
-#: apply.c:3945
+#: apply.c:3957
 #, c-format
 msgid "new mode (%o) of %s does not match old mode (%o)"
 msgstr "новите права за достъп (%o) на „%s“ не съвпадат със старите (%o)"
 
-#: apply.c:3950
+#: apply.c:3962
 #, c-format
 msgid "new mode (%o) of %s does not match old mode (%o) of %s"
 msgstr ""
 "новите права за достъп (%o) на „%s“ не съвпадат със старите (%o) на „%s“"
 
-#: apply.c:3970
+#: apply.c:3982
 #, c-format
 msgid "affected file '%s' is beyond a symbolic link"
 msgstr "засегнатият файл „%s“ е след символна връзка"
 
-#: apply.c:3974
+#: apply.c:3986
 #, c-format
 msgid "%s: patch does not apply"
 msgstr "Кръпката „%s“ не може да бъде приложена"
 
-#: apply.c:3989
+#: apply.c:4001
 #, c-format
 msgid "Checking patch %s..."
 msgstr "Проверяване на кръпката „%s“…"
 
-#: apply.c:4080
+#: apply.c:4093
 #, c-format
 msgid "sha1 information is lacking or useless for submodule %s"
 msgstr ""
 "информацията за сумата по SHA1 за подмодула липсва или не е достатъчна (%s)."
 
-#: apply.c:4087
+#: apply.c:4100
 #, c-format
 msgid "mode change for %s, which is not in current HEAD"
 msgstr "смяна на режима на достъпа на „%s“, който не е в текущия връх „HEAD“"
 
-#: apply.c:4090
+#: apply.c:4103
 #, c-format
 msgid "sha1 information is lacking or useless (%s)."
 msgstr "информацията за сумата по SHA1 липсва или не е достатъчна (%s)."
 
-#: apply.c:4095 builtin/checkout.c:235 builtin/reset.c:140
-#, c-format
-msgid "make_cache_entry failed for path '%s'"
-msgstr "неуспешно създаване на запис в кеша чрез „make_cache_entry“ за „%s“"
-
-#: apply.c:4099
+#: apply.c:4112
 #, c-format
 msgid "could not add %s to temporary index"
 msgstr "„%s“ не може да се добави към временния индекс"
 
-#: apply.c:4109
+#: apply.c:4122
 #, c-format
 msgid "could not write temporary index to %s"
 msgstr "временният индекс не може да се запази в „%s“"
 
-#: apply.c:4247
+#: apply.c:4260
 #, c-format
 msgid "unable to remove %s from index"
 msgstr "„%s“ не може да се извади от индекса"
 
-#: apply.c:4282
+#: apply.c:4294
 #, c-format
 msgid "corrupt patch for submodule %s"
 msgstr "повредена кръпка за модула „%s“"
 
-#: apply.c:4288
+#: apply.c:4300
 #, c-format
 msgid "unable to stat newly created file '%s'"
 msgstr ""
 "не може да се получи информация чрез „stat“ за новосъздадения файл „%s“"
 
-#: apply.c:4296
+#: apply.c:4308
 #, c-format
 msgid "unable to create backing store for newly created file %s"
 msgstr ""
 "не може да се за създаде мястото за съхранение на новосъздадения файл „%s“"
 
-#: apply.c:4302 apply.c:4446
+#: apply.c:4314 apply.c:4459
 #, c-format
 msgid "unable to add cache entry for %s"
 msgstr "не може да се добави запис в кеша за „%s“"
 
-#: apply.c:4343
+#: apply.c:4357
 #, c-format
 msgid "failed to write to '%s'"
 msgstr "в „%s“ не може да се пише"
 
-#: apply.c:4347
+#: apply.c:4361
 #, c-format
 msgid "closing file '%s'"
 msgstr "затваряне на файла „%s“"
 
-#: apply.c:4417
+#: apply.c:4431
 #, c-format
 msgid "unable to write file '%s' mode %o"
 msgstr "файлът „%s“ не може да се запише с режим на достъп „%o“"
 
-#: apply.c:4515
+#: apply.c:4529
 #, c-format
 msgid "Applied patch %s cleanly."
 msgstr "Кръпката „%s“ бе приложена чисто."
 
-#: apply.c:4523
+#: apply.c:4537
 msgid "internal error"
 msgstr "вътрешна грешка"
 
-#: apply.c:4526
+#: apply.c:4540
 #, c-format
 msgid "Applying patch %%s with %d reject..."
 msgid_plural "Applying patch %%s with %d rejects..."
 msgstr[0] "Прилагане на кръпката „%%s“ с %d отхвърлено парче…"
 msgstr[1] "Прилагане на кръпката „%%s“ с %d отхвърлени парчета…"
 
-#: apply.c:4537
+#: apply.c:4551
 #, c-format
 msgid "truncating .rej filename to %.*s.rej"
 msgstr "съкращаване на името на файла с отхвърлените парчета на „ %.*s.rej“"
 
-#: apply.c:4545 builtin/fetch.c:786 builtin/fetch.c:1036
+#: apply.c:4559 builtin/fetch.c:901 builtin/fetch.c:1192
 #, c-format
 msgid "cannot open %s"
 msgstr "„%s“ не може да бъде отворен"
 
-#: apply.c:4559
+#: apply.c:4573
 #, c-format
 msgid "Hunk #%d applied cleanly."
 msgstr "%d-то парче бе успешно приложено."
 
-#: apply.c:4563
+#: apply.c:4577
 #, c-format
 msgid "Rejected hunk #%d."
 msgstr "%d-то парче бе отхвърлено."
 
-#: apply.c:4673
+#: apply.c:4696
 #, c-format
 msgid "Skipped patch '%s'."
 msgstr "Пропусната кръпка: „%s“"
 
-#: apply.c:4681
+#: apply.c:4704
 msgid "unrecognized input"
 msgstr "непознат вход"
 
-#: apply.c:4700
+#: apply.c:4724
 msgid "unable to read index file"
 msgstr "индексът не може да бъде записан"
 
-#: apply.c:4837
+#: apply.c:4881
 #, c-format
 msgid "can't open patch '%s': %s"
 msgstr "кръпката „%s“ не може да бъде отворена: %s"
 
-#: apply.c:4864
+#: apply.c:4908
 #, c-format
 msgid "squelched %d whitespace error"
 msgid_plural "squelched %d whitespace errors"
 msgstr[0] "пренебрегната е %d грешка в знаците за интервали"
 msgstr[1] "пренебрегнати са %d грешки в знаците за интервали"
 
-#: apply.c:4870 apply.c:4885
+#: apply.c:4914 apply.c:4929
 #, c-format
 msgid "%d line adds whitespace errors."
 msgid_plural "%d lines add whitespace errors."
 msgstr[0] "%d ред добавя грешки в знаците за интервали."
 msgstr[1] "%d реда добавят грешки в знаците за интервали."
 
-#: apply.c:4878
+#: apply.c:4922
 #, c-format
 msgid "%d line applied after fixing whitespace errors."
 msgid_plural "%d lines applied after fixing whitespace errors."
@@ -721,264 +1216,334 @@ msgstr[0] ""
 msgstr[1] ""
 "Добавени са %d реда след корекцията на грешките в знаците за интервали."
 
-#: apply.c:4894 builtin/add.c:538 builtin/mv.c:300 builtin/rm.c:389
+#: apply.c:4938 builtin/add.c:579 builtin/mv.c:301 builtin/rm.c:390
 msgid "Unable to write new index file"
 msgstr "Новият индекс не може да бъде записан"
 
-#: apply.c:4921 apply.c:4924 builtin/am.c:2254 builtin/am.c:2257
-#: builtin/clone.c:120 builtin/fetch.c:126 builtin/pull.c:198
-#: builtin/submodule--helper.c:405 builtin/submodule--helper.c:1210
-#: builtin/submodule--helper.c:1213 builtin/submodule--helper.c:1584
-#: builtin/submodule--helper.c:1587 builtin/submodule--helper.c:1807
-#: git-add--interactive.perl:197
-msgid "path"
-msgstr "път"
-
-#: apply.c:4922
+#: apply.c:4966
 msgid "don't apply changes matching the given path"
 msgstr "без прилагане на промените напасващи на дадения път"
 
-#: apply.c:4925
+#: apply.c:4969
 msgid "apply changes matching the given path"
 msgstr "прилагане на промените напасващи на дадения път"
 
-#: apply.c:4927 builtin/am.c:2263
+#: apply.c:4971 builtin/am.c:2206
 msgid "num"
 msgstr "БРОЙ"
 
-#: apply.c:4928
+#: apply.c:4972
 msgid "remove <num> leading slashes from traditional diff paths"
 msgstr "премахване на този БРОЙ водещи елементи от пътищата в разликата"
 
-#: apply.c:4931
+#: apply.c:4975
 msgid "ignore additions made by the patch"
 msgstr "игнориране на редовете добавени от тази кръпка"
 
-#: apply.c:4933
+#: apply.c:4977
 msgid "instead of applying the patch, output diffstat for the input"
 msgstr "извеждане на статистика на промените без прилагане на кръпката"
 
-#: apply.c:4937
+#: apply.c:4981
 msgid "show number of added and deleted lines in decimal notation"
 msgstr "извеждане на броя на добавените и изтритите редове"
 
-#: apply.c:4939
+#: apply.c:4983
 msgid "instead of applying the patch, output a summary for the input"
 msgstr "извеждане на статистика на входните данни без прилагане на кръпката"
 
-#: apply.c:4941
+#: apply.c:4985
 msgid "instead of applying the patch, see if the patch is applicable"
 msgstr "проверка дали кръпката може да се приложи, без действително прилагане"
 
-#: apply.c:4943
+#: apply.c:4987
 msgid "make sure the patch is applicable to the current index"
 msgstr "проверка дали кръпката може да бъде приложена към текущия индекс"
 
-#: apply.c:4945
+#: apply.c:4989
+msgid "mark new files with `git add --intent-to-add`"
+msgstr "отбелязване на новите файлове с „git add --intent-to-add“"
+
+#: apply.c:4991
 msgid "apply a patch without touching the working tree"
 msgstr "прилагане на кръпката без промяна на работното дърво"
 
-#: apply.c:4947
+#: apply.c:4993
 msgid "accept a patch that touches outside the working area"
 msgstr "прилагане на кръпка, която променя и файлове извън работното дърво"
 
-#: apply.c:4950
+#: apply.c:4996
 msgid "also apply the patch (use with --stat/--summary/--check)"
 msgstr ""
 "кръпката да бъде приложена.  Опцията се комбинира с „--check“/„--stat“/„--"
 "summary“"
 
-#: apply.c:4952
+#: apply.c:4998
 msgid "attempt three-way merge if a patch does not apply"
 msgstr "пробване с тройно сливане, ако кръпката не може да се приложи директно"
 
-#: apply.c:4954
+#: apply.c:5000
 msgid "build a temporary index based on embedded index information"
 msgstr ""
 "създаване на временен индекс на база на включената информация за индекса"
 
-#: apply.c:4957 builtin/checkout-index.c:168 builtin/ls-files.c:515
+#: apply.c:5003 builtin/checkout-index.c:173 builtin/ls-files.c:524
 msgid "paths are separated with NUL character"
 msgstr "разделяне на пътищата с нулевия знак „NUL“"
 
-#: apply.c:4959
+#: apply.c:5005
 msgid "ensure at least <n> lines of context match"
 msgstr "да се осигури контекст от поне такъв БРОЙ съвпадащи редове"
 
-#: apply.c:4960 builtin/am.c:2242 builtin/interpret-trailers.c:95
-#: builtin/interpret-trailers.c:97 builtin/interpret-trailers.c:99
-#: builtin/pack-objects.c:3177
+#: apply.c:5006 builtin/am.c:2185 builtin/interpret-trailers.c:98
+#: builtin/interpret-trailers.c:100 builtin/interpret-trailers.c:102
+#: builtin/pack-objects.c:3310 builtin/rebase.c:1474
 msgid "action"
 msgstr "действие"
 
-#: apply.c:4961
+#: apply.c:5007
 msgid "detect new or modified lines that have whitespace errors"
 msgstr "засичане на нови или променени редове с грешки в знаците за интервали"
 
-#: apply.c:4964 apply.c:4967
+#: apply.c:5010 apply.c:5013
 msgid "ignore changes in whitespace when finding context"
 msgstr ""
 "игнориране на промените в знаците за интервали при откриване на контекста"
 
-#: apply.c:4970
+#: apply.c:5016
 msgid "apply the patch in reverse"
 msgstr "прилагане на кръпката в обратна посока"
 
-#: apply.c:4972
+#: apply.c:5018
 msgid "don't expect at least one line of context"
 msgstr "без изискване на дори и един ред контекст"
 
-#: apply.c:4974
+#: apply.c:5020
 msgid "leave the rejected hunks in corresponding *.rej files"
 msgstr "оставяне на отхвърлените парчета във файлове с разширение „.rej“"
 
-#: apply.c:4976
+#: apply.c:5022
 msgid "allow overlapping hunks"
 msgstr "позволяване на застъпващи се парчета"
 
-#: apply.c:4977 builtin/add.c:290 builtin/check-ignore.c:21
-#: builtin/commit.c:1301 builtin/count-objects.c:98 builtin/fsck.c:666
-#: builtin/log.c:1901 builtin/mv.c:122 builtin/read-tree.c:124
+#: apply.c:5023 builtin/add.c:309 builtin/check-ignore.c:22
+#: builtin/commit.c:1355 builtin/count-objects.c:98 builtin/fsck.c:774
+#: builtin/log.c:2166 builtin/mv.c:123 builtin/read-tree.c:128
 msgid "be verbose"
 msgstr "повече подробности"
 
-#: apply.c:4979
+#: apply.c:5025
 msgid "tolerate incorrectly detected missing new-line at the end of file"
 msgstr "пренебрегване на неправилно липсващ знак за нов ред в края на файл"
 
-#: apply.c:4982
+#: apply.c:5028
 msgid "do not trust the line counts in the hunk headers"
 msgstr "без доверяване на номерата на редовете в заглавните части на парчетата"
 
-#: apply.c:4984 builtin/am.c:2251
+#: apply.c:5030 builtin/am.c:2194
 msgid "root"
 msgstr "НАЧАЛНА_ДИРЕКТОРИЯ"
 
-#: apply.c:4985
+#: apply.c:5031
 msgid "prepend <root> to all filenames"
 msgstr "добавяне на тази НАЧАЛНА_ДИРЕКТОРИЯ към имената на всички файлове"
 
-#: archive.c:13
+#: archive.c:14
 msgid "git archive [<options>] <tree-ish> [<path>...]"
 msgstr "git archive [ОПЦИЯ…] УКАЗАТЕЛ_КЪМ_ДЪРВО [ПЪТ…]"
 
-#: archive.c:14
+#: archive.c:15
 msgid "git archive --list"
 msgstr "git archive --list"
 
-#: archive.c:15
+#: archive.c:16
 msgid ""
 "git archive --remote <repo> [--exec <cmd>] [<options>] <tree-ish> [<path>...]"
 msgstr ""
 "git archive --remote ХРАНИЛИЩЕ [--exec КОМАНДА] [ОПЦИЯ…] УКАЗАТЕЛ_КЪМ_ДЪРВО "
 "[ПЪТ…]"
 
-#: archive.c:16
+#: archive.c:17
 msgid "git archive --remote <repo> [--exec <cmd>] --list"
 msgstr "git archive --remote ХРАНИЛИЩЕ [--exec КОМАНДА] --list"
 
-#: archive.c:351 builtin/add.c:176 builtin/add.c:514 builtin/rm.c:298
+#: archive.c:372 builtin/add.c:180 builtin/add.c:555 builtin/rm.c:299
 #, c-format
 msgid "pathspec '%s' did not match any files"
 msgstr "пътят „%s“ не съвпада с никой файл"
 
-#: archive.c:434
+#: archive.c:396
+#, c-format
+msgid "no such ref: %.*s"
+msgstr "такъв указател няма: %.*s"
+
+#: archive.c:401
+#, c-format
+msgid "not a valid object name: %s"
+msgstr "неправилно име на обект: „%s“"
+
+#: archive.c:414
+#, c-format
+msgid "not a tree object: %s"
+msgstr "не е обект-дърво: %s"
+
+#: archive.c:426
+msgid "current working directory is untracked"
+msgstr "текущата работна директория не е следена"
+
+#: archive.c:457
 msgid "fmt"
 msgstr "ФОРМАТ"
 
-#: archive.c:434
+#: archive.c:457
 msgid "archive format"
 msgstr "ФОРМАТ на архива"
 
-#: archive.c:435 builtin/log.c:1462
+#: archive.c:458 builtin/log.c:1653
 msgid "prefix"
 msgstr "ПРЕФИКС"
 
-#: archive.c:436
+#: archive.c:459
 msgid "prepend prefix to each pathname in the archive"
 msgstr "добавяне на този ПРЕФИКС към всеки път в архива"
 
-#: archive.c:437 builtin/blame.c:813 builtin/blame.c:814 builtin/config.c:127
-#: builtin/fast-export.c:1007 builtin/fast-export.c:1009 builtin/grep.c:869
-#: builtin/hash-object.c:103 builtin/ls-files.c:551 builtin/ls-files.c:554
-#: builtin/notes.c:405 builtin/notes.c:568 builtin/read-tree.c:119
-#: parse-options.h:165
+#: archive.c:460 builtin/blame.c:861 builtin/blame.c:865 builtin/blame.c:866
+#: builtin/commit-tree.c:117 builtin/config.c:129 builtin/fast-export.c:1162
+#: builtin/fast-export.c:1164 builtin/fast-export.c:1168 builtin/grep.c:899
+#: builtin/hash-object.c:105 builtin/ls-files.c:560 builtin/ls-files.c:563
+#: builtin/notes.c:412 builtin/notes.c:578 builtin/read-tree.c:123
+#: parse-options.h:190
 msgid "file"
 msgstr "ФАЙЛ"
 
-#: archive.c:438 builtin/archive.c:89
+#: archive.c:461 builtin/archive.c:90
 msgid "write the archive to this file"
 msgstr "запазване на архива в този ФАЙЛ"
 
-#: archive.c:440
+#: archive.c:463
 msgid "read .gitattributes in working directory"
 msgstr "изчитане на „.gitattributes“ в работната директория"
 
-#: archive.c:441
+#: archive.c:464
 msgid "report archived files on stderr"
 msgstr "извеждане на архивираните файлове на стандартната грешка"
 
-#: archive.c:442
+#: archive.c:465
 msgid "store only"
-msgstr "само съхранение без компресиране"
+msgstr "съхранение без компресиране"
 
-#: archive.c:443
+#: archive.c:466
 msgid "compress faster"
 msgstr "бързо компресиране"
 
-#: archive.c:451
+#: archive.c:474
 msgid "compress better"
 msgstr "добро компресиране"
 
-#: archive.c:454
+#: archive.c:477
 msgid "list supported archive formats"
 msgstr "извеждане на списъка с поддържаните формати"
 
-#: archive.c:456 builtin/archive.c:90 builtin/clone.c:110 builtin/clone.c:113
-#: builtin/submodule--helper.c:1222 builtin/submodule--helper.c:1593
+#: archive.c:479 builtin/archive.c:91 builtin/clone.c:113 builtin/clone.c:116
+#: builtin/submodule--helper.c:1391 builtin/submodule--helper.c:1884
 msgid "repo"
 msgstr "хранилище"
 
-#: archive.c:457 builtin/archive.c:91
+#: archive.c:480 builtin/archive.c:92
 msgid "retrieve the archive from remote repository <repo>"
 msgstr "изтегляне на архива от отдалеченото ХРАНИЛИЩЕ"
 
-#: archive.c:458 builtin/archive.c:92 builtin/notes.c:489
+#: archive.c:481 builtin/archive.c:93 builtin/difftool.c:715
+#: builtin/notes.c:498
 msgid "command"
 msgstr "команда"
 
-#: archive.c:459 builtin/archive.c:93
+#: archive.c:482 builtin/archive.c:94
 msgid "path to the remote git-upload-archive command"
 msgstr "път към отдалечената команда „git-upload-archive“"
 
-#: archive.c:466
+#: archive.c:489
 msgid "Unexpected option --remote"
 msgstr "Неочаквана опция „--remote“"
 
-#: archive.c:468
+#: archive.c:491
 msgid "Option --exec can only be used together with --remote"
 msgstr "Опцията „--exec“ изисква „--remote“"
 
-#: archive.c:470
+#: archive.c:493
 msgid "Unexpected option --output"
 msgstr "Неочаквана опция „--output“"
 
-#: archive.c:492
+#: archive.c:515
 #, c-format
 msgid "Unknown archive format '%s'"
 msgstr "Непознат формат на архив: „%s“"
 
-#: archive.c:499
+#: archive.c:522
 #, c-format
 msgid "Argument not supported for format '%s': -%d"
 msgstr "Аргументът не се поддържа за форма̀та „%s“: -%d"
 
-#: attr.c:218
+#: archive-tar.c:125 archive-zip.c:350
+#, c-format
+msgid "cannot stream blob %s"
+msgstr "обектът-BLOB „%s“ не може да бъде обработен"
+
+#: archive-tar.c:266 archive-zip.c:368
+#, c-format
+msgid "unsupported file mode: 0%o (SHA1: %s)"
+msgstr "неподдържани права за достъп до файл: 0%o (SHA1: %s)"
+
+#: archive-tar.c:293 archive-zip.c:358
+#, c-format
+msgid "cannot read %s"
+msgstr "обектът „%s“ не може да бъде прочетен"
+
+#: archive-tar.c:465
+#, c-format
+msgid "unable to start '%s' filter"
+msgstr "филтърът „%s“ не може да бъде стартиран"
+
+#: archive-tar.c:468
+msgid "unable to redirect descriptor"
+msgstr "дескрипторът не може да бъде пренасочен"
+
+#: archive-tar.c:475
+#, c-format
+msgid "'%s' filter reported error"
+msgstr "филтърът „%s“ върна грешка"
+
+#: archive-zip.c:319
+#, c-format
+msgid "path is not valid UTF-8: %s"
+msgstr "пътят не е правилно кодиран в UTF-8: %s"
+
+#: archive-zip.c:323
+#, c-format
+msgid "path too long (%d chars, SHA1: %s): %s"
+msgstr "твърде дълъг път (%d знака, SHA1: %s): %s"
+
+#: archive-zip.c:479 builtin/pack-objects.c:230 builtin/pack-objects.c:233
+#, c-format
+msgid "deflate error (%d)"
+msgstr "грешка при декомпресиране с „deflate“ (%d)"
+
+#: archive-zip.c:614
+#, c-format
+msgid "timestamp too large for this system: %<PRIuMAX>"
+msgstr "времевата стойност е твърде голяма за тази система: %<PRIuMAX>"
+
+#: attr.c:212
 #, c-format
 msgid "%.*s is not a valid attribute name"
 msgstr "„%.*s“ е неправилно име за атрибут"
 
-#: attr.c:415
+#: attr.c:369
+#, c-format
+msgid "%s not allowed: %s:%d"
+msgstr "%s: командата не е позволена: „%s:%d“"
+
+#: attr.c:409
 msgid ""
 "Negative patterns are ignored in git attributes\n"
 "Use '\\!' for literal leading exclamation."
@@ -986,22 +1551,22 @@ msgstr ""
 "Отрицателните шаблони се игнорират в атрибутите на git.\n"
 "Ако ви трябва начална удивителна, ползвайте „\\!“."
 
-#: bisect.c:461
+#: bisect.c:468
 #, c-format
 msgid "Badly quoted content in file '%s': %s"
 msgstr "Неправилно цитирано съдържание във файла „%s“: %s"
 
-#: bisect.c:669
+#: bisect.c:678
 #, c-format
 msgid "We cannot bisect more!\n"
 msgstr "Повече не може да се търси двоично!\n"
 
-#: bisect.c:723
+#: bisect.c:733
 #, c-format
 msgid "Not a valid commit name %s"
 msgstr "Неправилно име на подаване „%s“"
 
-#: bisect.c:747
+#: bisect.c:758
 #, c-format
 msgid ""
 "The merge base %s is bad.\n"
@@ -1010,7 +1575,7 @@ msgstr ""
 "Неправилна база за сливане: %s.\n"
 "Следователно грешката е коригирана между „%s“ и [%s].\n"
 
-#: bisect.c:752
+#: bisect.c:763
 #, c-format
 msgid ""
 "The merge base %s is new.\n"
@@ -1019,7 +1584,7 @@ msgstr ""
 "Нова база за сливане: %s.\n"
 "Свойството е променено между „%s“ и [%s].\n"
 
-#: bisect.c:757
+#: bisect.c:768
 #, c-format
 msgid ""
 "The merge base %s is %s.\n"
@@ -1028,7 +1593,7 @@ msgstr ""
 "Базата за сливане „%s“ е %s.\n"
 "Следователно първото %s подаване е между „%s“ и [%s].\n"
 
-#: bisect.c:765
+#: bisect.c:776
 #, c-format
 msgid ""
 "Some %s revs are not ancestors of the %s rev.\n"
@@ -1039,7 +1604,7 @@ msgstr ""
 "Двоичното търсене с git bisect няма да работи правилно.\n"
 "Дали не сте объркали указателите „%s“ и „%s“?\n"
 
-#: bisect.c:778
+#: bisect.c:789
 #, c-format
 msgid ""
 "the merge base between %s and [%s] must be skipped.\n"
@@ -1050,36 +1615,36 @@ msgstr ""
 "Не може да сме сигурни, че първото %s подаване е между „%s“ и „%s“.\n"
 "Двоичното търсене продължава."
 
-#: bisect.c:811
+#: bisect.c:822
 #, c-format
 msgid "Bisecting: a merge base must be tested\n"
 msgstr "Двоично търсене: трябва да се провери база за сливане\n"
 
-#: bisect.c:851
+#: bisect.c:865
 #, c-format
 msgid "a %s revision is needed"
 msgstr "необходима е версия „%s“"
 
-#: bisect.c:870 builtin/notes.c:175 builtin/tag.c:236
+#: bisect.c:884 builtin/notes.c:177 builtin/tag.c:254
 #, c-format
 msgid "could not create file '%s'"
 msgstr "файлът „%s“ не може да бъде създаден"
 
-#: bisect.c:921
+#: bisect.c:928 builtin/merge.c:148
 #, c-format
 msgid "could not read file '%s'"
 msgstr "файлът „%s“ не може да бъде прочетен"
 
-#: bisect.c:951
+#: bisect.c:958
 msgid "reading bisect refs failed"
 msgstr "неуспешно прочитане на указателите за двоично търсене"
 
-#: bisect.c:970
+#: bisect.c:977
 #, c-format
 msgid "%s was both %s and %s\n"
 msgstr "„%s“ e както „%s“, така и „%s“\n"
 
-#: bisect.c:978
+#: bisect.c:985
 #, c-format
 msgid ""
 "No testable commit found.\n"
@@ -1088,7 +1653,7 @@ msgstr ""
 "Липсва подходящо за тестване подаване.\n"
 "Проверете параметрите за пътищата.\n"
 
-#: bisect.c:997
+#: bisect.c:1004
 #, c-format
 msgid "(roughly %d step)"
 msgid_plural "(roughly %d steps)"
@@ -1098,52 +1663,53 @@ msgstr[1] "(приблизително %
 #. TRANSLATORS: the last %s will be replaced with "(roughly %d
 #. steps)" translation.
 #.
-#: bisect.c:1003
+#: bisect.c:1010
 #, c-format
 msgid "Bisecting: %d revision left to test after this %s\n"
 msgid_plural "Bisecting: %d revisions left to test after this %s\n"
 msgstr[0] "Двоично търсене: остава %d версия след тази %s\n"
 msgstr[1] "Двоично търсене: остават %d версии след тази %s\n"
 
-#: blame.c:1756
+#: blame.c:2700
 msgid "--contents and --reverse do not blend well."
 msgstr "Опциите „--contents“ и „--reverse“ са несъвместими"
 
-#: blame.c:1767
+#: blame.c:2714
 msgid "cannot use --contents with final commit object name"
 msgstr "Опцията „--contents“ е несъвместима с име на обект от крайно подаване"
 
-#: blame.c:1787
+#: blame.c:2735
 msgid "--reverse and --first-parent together require specified latest commit"
 msgstr ""
 "Едновременното задаване на опциите „--reverse“ и „--first-parent“ изисква "
 "указването на крайно подаване"
 
-#: blame.c:1796 bundle.c:160 ref-filter.c:2075 sequencer.c:1861
-#: sequencer.c:3632 builtin/commit.c:981 builtin/log.c:366 builtin/log.c:920
-#: builtin/log.c:1371 builtin/log.c:1702 builtin/log.c:1950 builtin/merge.c:372
+#: blame.c:2744 bundle.c:167 ref-filter.c:2203 remote.c:1941 sequencer.c:2093
+#: sequencer.c:4460 builtin/commit.c:1040 builtin/log.c:388 builtin/log.c:991
+#: builtin/log.c:1520 builtin/log.c:1925 builtin/log.c:2215 builtin/merge.c:411
+#: builtin/pack-objects.c:3128 builtin/pack-objects.c:3143
 #: builtin/shortlog.c:192
 msgid "revision walk setup failed"
 msgstr "неуспешно настройване на обхождането на версиите"
 
-#: blame.c:1814
+#: blame.c:2762
 msgid ""
 "--reverse --first-parent together require range along first-parent chain"
 msgstr ""
 "Едновременното задаване на опциите „--reverse“ и „--first-parent“ изисква "
 "указването на диапазон по веригата на първите наследници"
 
-#: blame.c:1825
+#: blame.c:2773
 #, c-format
 msgid "no such path %s in %s"
 msgstr "няма път на име „%s“ в „%s“"
 
-#: blame.c:1836
+#: blame.c:2784
 #, c-format
 msgid "cannot read blob %s for path %s"
 msgstr "обектът-BLOB „%s“ в пътя %s не може да бъде прочетен"
 
-#: branch.c:54
+#: branch.c:53
 #, c-format
 msgid ""
 "\n"
@@ -1156,88 +1722,88 @@ msgstr ""
 "информацията за следения клон чрез:\n"
 "git branch --set-upstream-to=%s%s%s"
 
-#: branch.c:68
+#: branch.c:67
 #, c-format
 msgid "Not setting branch %s as its own upstream."
 msgstr ""
 "Клонът „%s“ не може да служи като източник за собствената си синхронизация."
 
-#: branch.c:94
+#: branch.c:93
 #, c-format
 msgid "Branch '%s' set up to track remote branch '%s' from '%s' by rebasing."
 msgstr ""
 "Клонът „%s“ ще следи отдалечения клон „%s“ от хранилището „%s“ чрез "
 "пребазиране."
 
-#: branch.c:95
+#: branch.c:94
 #, c-format
 msgid "Branch '%s' set up to track remote branch '%s' from '%s'."
 msgstr "Клонът „%s“ ще следи отдалечения клон „%s“ от хранилището „%s“."
 
-#: branch.c:99
+#: branch.c:98
 #, c-format
 msgid "Branch '%s' set up to track local branch '%s' by rebasing."
 msgstr "Клонът „%s“ ще следи локалния клон „%s“ чрез пребазиране."
 
-#: branch.c:100
+#: branch.c:99
 #, c-format
 msgid "Branch '%s' set up to track local branch '%s'."
 msgstr "Клонът „%s“ ще следи локалния клон „%s“."
 
-#: branch.c:105
+#: branch.c:104
 #, c-format
 msgid "Branch '%s' set up to track remote ref '%s' by rebasing."
 msgstr "Клонът „%s“ ще следи отдалечения указател „%s“ чрез пребазиране."
 
-#: branch.c:106
+#: branch.c:105
 #, c-format
 msgid "Branch '%s' set up to track remote ref '%s'."
 msgstr "Клонът „%s“ ще следи отдалечения указател „%s“."
 
-#: branch.c:110
+#: branch.c:109
 #, c-format
 msgid "Branch '%s' set up to track local ref '%s' by rebasing."
 msgstr "Клонът „%s“ ще следи локалния указател „%s“ чрез пребазиране."
 
-#: branch.c:111
+#: branch.c:110
 #, c-format
 msgid "Branch '%s' set up to track local ref '%s'."
 msgstr "Клонът „%s“ ще следи локалния указател „%s“."
 
-#: branch.c:120
+#: branch.c:119
 msgid "Unable to write upstream branch configuration"
 msgstr "Настройките за следения клон не могат да бъдат записани"
 
-#: branch.c:157
+#: branch.c:156
 #, c-format
 msgid "Not tracking: ambiguous information for ref %s"
 msgstr "Няма следене: информацията за указателя „%s“ не е еднозначна"
 
-#: branch.c:190
+#: branch.c:189
 #, c-format
 msgid "'%s' is not a valid branch name."
 msgstr "„%s“ не е позволено име за клон."
 
-#: branch.c:209
+#: branch.c:208
 #, c-format
 msgid "A branch named '%s' already exists."
 msgstr "Вече съществува клон с име „%s“."
 
-#: branch.c:214
+#: branch.c:213
 msgid "Cannot force update the current branch."
 msgstr "Текущият клон не може да бъде принудително обновен."
 
-#: branch.c:234
+#: branch.c:233
 #, c-format
 msgid "Cannot setup tracking information; starting point '%s' is not a branch."
 msgstr "Зададените настройки за следенето са грешни — началото „%s“ не е клон."
 
-#: branch.c:236
+#: branch.c:235
 #, c-format
 msgid "the requested upstream branch '%s' does not exist"
 msgstr "заявеният отдалечен клон „%s“ не съществува"
 
-#: branch.c:238
+#: branch.c:237
 msgid ""
 "\n"
 "If you are planning on basing your work on an upstream\n"
@@ -1271,86 +1837,95 @@ msgstr "Името на обект не
 msgid "Not a valid branch point: '%s'."
 msgstr "Неправилно място за начало на клон: „%s“"
 
-#: branch.c:360
+#: branch.c:364
 #, c-format
 msgid "'%s' is already checked out at '%s'"
 msgstr "„%s“ вече е изтеглен в „%s“"
 
-#: branch.c:383
+#: branch.c:387
 #, c-format
 msgid "HEAD of working tree %s is not updated"
 msgstr "Указателят „HEAD“ на работното дърво „%s“ не е обновен"
 
-#: bundle.c:34
+#: bundle.c:36
 #, c-format
 msgid "'%s' does not look like a v2 bundle file"
 msgstr "Файлът „%s“ не изглежда да е пратка на git версия 2"
 
-#: bundle.c:62
+#: bundle.c:64
 #, c-format
 msgid "unrecognized header: %s%s (%d)"
 msgstr "непозната заглавна част: %s%s (%d)"
 
-#: bundle.c:88 sequencer.c:2081 sequencer.c:2558 builtin/commit.c:755
+#: bundle.c:90 rerere.c:480 rerere.c:690 sequencer.c:2344 sequencer.c:3108
+#: builtin/commit.c:811
 #, c-format
 msgid "could not open '%s'"
 msgstr "„%s“ не може да се отвори"
 
-#: bundle.c:139
+#: bundle.c:143
 msgid "Repository lacks these prerequisite commits:"
 msgstr "В хранилището липсват следните необходими подавания:"
 
-#: bundle.c:190
+#: bundle.c:146
+msgid "need a repository to verify a bundle"
+msgstr "за проверката на пратка е необходимо хранилище"
+
+#: bundle.c:197
 #, c-format
 msgid "The bundle contains this ref:"
 msgid_plural "The bundle contains these %d refs:"
 msgstr[0] "Пратката съдържа следния указател:"
 msgstr[1] "Пратката съдържа следните %d указатели:"
 
-#: bundle.c:197
+#: bundle.c:204
 msgid "The bundle records a complete history."
 msgstr "Пратката съдържа пълна история."
 
-#: bundle.c:199
+#: bundle.c:206
 #, c-format
 msgid "The bundle requires this ref:"
 msgid_plural "The bundle requires these %d refs:"
 msgstr[0] "Пратката изисква следния указател:"
 msgstr[1] "Пратката изисква следните %d указатели:"
 
-#: bundle.c:258
+#: bundle.c:273
+msgid "unable to dup bundle descriptor"
+msgstr "неуспешно дублиране на дескриптора на пратката с „dup“"
+
+#: bundle.c:280
 msgid "Could not spawn pack-objects"
 msgstr "Командата „git pack-objects“ не може да бъде стартирана"
 
-#: bundle.c:269
+#: bundle.c:291
 msgid "pack-objects died"
 msgstr "Командата „git pack-objects“ не завърши успешно"
 
-#: bundle.c:311
+#: bundle.c:333
 msgid "rev-list died"
 msgstr "Командата „git rev-list“ не завърши успешно"
 
-#: bundle.c:360
+#: bundle.c:382
 #, c-format
 msgid "ref '%s' is excluded by the rev-list options"
 msgstr ""
 "указателят „%s“ не е бил включен поради опциите зададени на „git rev-list“"
 
-#: bundle.c:450 builtin/log.c:183 builtin/log.c:1607 builtin/shortlog.c:303
+#: bundle.c:461 builtin/log.c:203 builtin/log.c:1814 builtin/shortlog.c:306
 #, c-format
 msgid "unrecognized argument: %s"
 msgstr "непознат аргумент: %s"
 
-#: bundle.c:458
+#: bundle.c:469
 msgid "Refusing to create empty bundle."
 msgstr "Създаването на празна пратка е невъзможно."
 
-#: bundle.c:470
+#: bundle.c:479
 #, c-format
 msgid "cannot create '%s'"
 msgstr "Файлът „%s“ не може да бъде създаден"
 
-#: bundle.c:498
+#: bundle.c:504
 msgid "index-pack died"
 msgstr "Командата „git index-pack“ не завърши успешно"
 
@@ -1359,19 +1934,18 @@ msgstr "Командата „git index-
 msgid "invalid color value: %.*s"
 msgstr "неправилна стойност за цвят: %.*s"
 
-#: commit.c:43 sequencer.c:2364 builtin/am.c:421 builtin/am.c:465
-#: builtin/am.c:1436 builtin/am.c:2072 builtin/replace.c:376
-#: builtin/replace.c:448
+#: commit.c:51 sequencer.c:2811 builtin/am.c:354 builtin/am.c:398
+#: builtin/am.c:1366 builtin/am.c:2009 builtin/replace.c:456
 #, c-format
 msgid "could not parse %s"
 msgstr "„%s“ не може да се анализира"
 
-#: commit.c:45
+#: commit.c:53
 #, c-format
 msgid "%s %s is not a commit!"
 msgstr "%s %s не е подаване!"
 
-#: commit.c:182
+#: commit.c:193
 msgid ""
 "Support for <GIT_DIR>/info/grafts is deprecated\n"
 "and will be removed in a future Git version.\n"
@@ -1394,7 +1968,29 @@ msgstr ""
 "\n"
 "    git config advice.graftFileDeprecated false"
 
-#: commit.c:1540
+#: commit.c:1152
+#, c-format
+msgid "Commit %s has an untrusted GPG signature, allegedly by %s."
+msgstr ""
+"Подаването „%s“ е с недоверен подпис от GPG, който твърди, че е на „%s“."
+
+#: commit.c:1155
+#, c-format
+msgid "Commit %s has a bad GPG signature allegedly by %s."
+msgstr ""
+"Подаването „%s“ е с неправилен подпис от GPG, който твърди, че е на „%s“."
+
+#: commit.c:1158
+#, c-format
+msgid "Commit %s does not have a GPG signature."
+msgstr "Подаването „%s“ е без подпис от GPG."
+
+#: commit.c:1161
+#, c-format
+msgid "Commit %s has a good GPG signature by %s\n"
+msgstr "Подаването „%s“ е с коректен подпис от GPG на „%s“.\n"
+
+#: commit.c:1415
 msgid ""
 "Warning: commit message did not conform to UTF-8.\n"
 "You may want to amend it after fixing the message, or set the config\n"
@@ -1404,186 +2000,591 @@ msgstr ""
 "Може да поправите подаването заедно със съобщението или може да\n"
 "зададете ползваното кодиране в настройката „i18n.commitencoding“.\n"
 
-#: commit-graph.c:669
+#: commit-graph.c:130
+msgid "commit-graph file is too small"
+msgstr "файлът с гра̀фа на подаванията е твърде малък"
+
+#: commit-graph.c:195
+#, c-format
+msgid "commit-graph signature %X does not match signature %X"
+msgstr "отпечатъкът на гра̀фа с подаванията %X не съвпада с %X"
+
+#: commit-graph.c:202
+#, c-format
+msgid "commit-graph version %X does not match version %X"
+msgstr "версията на гра̀фа с подаванията %X не съвпада с %X"
+
+#: commit-graph.c:209
+#, c-format
+msgid "commit-graph hash version %X does not match version %X"
+msgstr "версията на контролната сума на гра̀фа с подаванията %X не съвпада с %X"
+
+#: commit-graph.c:232
+msgid "commit-graph chunk lookup table entry missing; file may be incomplete"
+msgstr ""
+"записът в таблицата за откъси липсва, файлът за гра̀фа може да е непълен"
+
+#: commit-graph.c:243
+#, c-format
+msgid "commit-graph improper chunk offset %08x%08x"
+msgstr "неправилно отместване на откъс: %08x%08x"
+
+#: commit-graph.c:286
+#, c-format
+msgid "commit-graph chunk id %08x appears multiple times"
+msgstr "откъсът %08x се явява многократно"
+
+#: commit-graph.c:350
+msgid "commit-graph has no base graphs chunk"
+msgstr "базовият откъс липсва в гра̀фа с подаванията"
+
+#: commit-graph.c:360
+msgid "commit-graph chain does not match"
+msgstr "веригата на гра̀фа с подаванията не съвпада"
+
+#: commit-graph.c:407
+#, c-format
+msgid "invalid commit-graph chain: line '%s' not a hash"
+msgstr ""
+"грешка във веригата на гра̀фа с подаванията: ред „%s“ не е контролна сума"
+
+#: commit-graph.c:433
+msgid "unable to find all commit-graph files"
+msgstr "някои файлове на гра̀фа с подаванията не могат да бъдат открити"
+
+#: commit-graph.c:564 commit-graph.c:624
+msgid "invalid commit position. commit-graph is likely corrupt"
+msgstr ""
+"неправилна позиция на подаването.  Вероятно графът с подаванията е повреден"
+
+#: commit-graph.c:585
+#, c-format
+msgid "could not find commit %s"
+msgstr "подаването „%s“ не може да бъде открито"
+
+#: commit-graph.c:858 builtin/am.c:1287
+#, c-format
+msgid "unable to parse commit %s"
+msgstr "подаването не може да бъде анализирано: %s"
+
+#: commit-graph.c:1017 builtin/pack-objects.c:2641
+#, c-format
+msgid "unable to get type of object %s"
+msgstr "видът на обекта „%s“ не може да бъде определен"
+
+#: commit-graph.c:1049
+msgid "Loading known commits in commit graph"
+msgstr "Зареждане на познатите подавания в гра̀фа с подаванията"
+
+#: commit-graph.c:1066
+msgid "Expanding reachable commits in commit graph"
+msgstr "Разширяване на достижимите подавания в гра̀фа"
+
+#: commit-graph.c:1085
+msgid "Clearing commit marks in commit graph"
+msgstr "Изчистване на отбелязванията на подаванията в гра̀фа с подаванията"
+
+#: commit-graph.c:1104
+msgid "Computing commit graph generation numbers"
+msgstr "Изчисляване на номерата на поколенията в гра̀фа с подаванията"
+
+#: commit-graph.c:1179
+#, c-format
+msgid "Finding commits for commit graph in %d pack"
+msgid_plural "Finding commits for commit graph in %d packs"
+msgstr[0] "Откриване на подаванията в гра̀фа в %d пакетен файл"
+msgstr[1] "Откриване на подаванията в гра̀фа в %d пакетни файла"
+
+#: commit-graph.c:1192
+#, c-format
+msgid "error adding pack %s"
+msgstr "грешка при добавяне на пакетен файл „%s“"
+
+#: commit-graph.c:1196
+#, c-format
+msgid "error opening index for %s"
+msgstr "грешка при отваряне на индекса на „%s“"
+
+#: commit-graph.c:1220
+#, c-format
+msgid "Finding commits for commit graph from %d ref"
+msgid_plural "Finding commits for commit graph from %d refs"
+msgstr[0] "Откриване на подаванията в гра̀фа измежду %d указател"
+msgstr[1] "Откриване на подаванията в гра̀фа измежду %d указатели"
+
+#: commit-graph.c:1240
+#, c-format
+msgid "invalid commit object id: %s"
+msgstr "неправилен идентификатор на обект-подаване: „%s“"
+
+#: commit-graph.c:1255
+msgid "Finding commits for commit graph among packed objects"
+msgstr "Откриване на подаванията в гра̀фа измежду пакетираните обекти"
+
+#: commit-graph.c:1270
+msgid "Counting distinct commits in commit graph"
+msgstr "Преброяване на различните подавания в гра̀фа"
+
+#: commit-graph.c:1300
+msgid "Finding extra edges in commit graph"
+msgstr "Откриване на още върхове в гра̀фа с подаванията"
+
+#: commit-graph.c:1346
+msgid "failed to write correct number of base graph ids"
+msgstr "правилният брой на базовите идентификатори не може да се запише"
+
+#: commit-graph.c:1379 midx.c:814
+#, c-format
+msgid "unable to create leading directories of %s"
+msgstr "родителските директории на „%s“ не могат да бъдат създадени"
+
+#: commit-graph.c:1391 builtin/index-pack.c:306 builtin/repack.c:248
+#, c-format
+msgid "unable to create '%s'"
+msgstr "пакетният файл „%s“ не може да бъде създаден"
+
+#: commit-graph.c:1451
+#, c-format
+msgid "Writing out commit graph in %d pass"
+msgid_plural "Writing out commit graph in %d passes"
+msgstr[0] "Запазване на гра̀фа с подаванията в %d пас"
+msgstr[1] "Запазване на гра̀фа с подаванията в %d паса"
+
+#: commit-graph.c:1492
+msgid "unable to open commit-graph chain file"
+msgstr "файлът с веригата на гра̀фа с подаванията не може да се отвори"
+
+#: commit-graph.c:1504
+msgid "failed to rename base commit-graph file"
+msgstr "основният файл на гра̀фа с подаванията не може да бъде преименуван"
+
+#: commit-graph.c:1524
+msgid "failed to rename temporary commit-graph file"
+msgstr "временният файл на гра̀фа с подаванията не може да бъде преименуван"
+
+#: commit-graph.c:1637
+msgid "Scanning merged commits"
+msgstr "Търсене на подаванията със сливания"
+
+#: commit-graph.c:1648
+#, c-format
+msgid "unexpected duplicate commit id %s"
+msgstr "неочакван, повтарящ се идентификатор на подаване: %s"
+
+#: commit-graph.c:1672
+msgid "Merging commit-graph"
+msgstr "Сливане на гра̀фа с подаванията"
+
+#: commit-graph.c:1862
 #, c-format
 msgid "the commit graph format cannot write %d commits"
 msgstr "форматът на гра̀фа с подаванията не може да запише %d подавания"
 
-#: commit-graph.c:696
+#: commit-graph.c:1873
 msgid "too many commits to write graph"
 msgstr "прекалено много подавания за записване на гра̀фа"
 
-#: commit-graph.c:707 builtin/init-db.c:516 builtin/init-db.c:521
+#: commit-graph.c:1963
+msgid "the commit-graph file has incorrect checksum and is likely corrupt"
+msgstr "графът с подаванията е с грешна сума за проверка — вероятно е повреден"
+
+#: commit-graph.c:1973
 #, c-format
-msgid "cannot mkdir %s"
-msgstr "директорията „%s“ не може да бъде създадена"
+msgid "commit-graph has incorrect OID order: %s then %s"
+msgstr ""
+"неправилна подредба на обектите по идентификатор в гра̀фа с подаванията: „%s“ "
+"е преди „%s“, а не трябва"
+
+#: commit-graph.c:1983 commit-graph.c:1998
+#, c-format
+msgid "commit-graph has incorrect fanout value: fanout[%d] = %u != %u"
+msgstr ""
+"неправилна стойност за откъс в гра̀фа с подаванията: fanout[%d] = %u, а "
+"трябва да е %u"
+
+#: commit-graph.c:1990
+#, c-format
+msgid "failed to parse commit %s from commit-graph"
+msgstr "подаване „%s“ в гра̀фа с подаванията не може да се анализира"
+
+#: commit-graph.c:2008
+msgid "Verifying commits in commit graph"
+msgstr "Проверка на подаванията в гра̀фа"
+
+#: commit-graph.c:2022
+#, c-format
+msgid "failed to parse commit %s from object database for commit-graph"
+msgstr ""
+"подаване „%s“ в базата от данни към гра̀фа с подаванията не може да се "
+"анализира"
+
+#: commit-graph.c:2029
+#, c-format
+msgid "root tree OID for commit %s in commit-graph is %s != %s"
+msgstr ""
+"идентификаторът на обект за кореновото дърво за подаване „%s“ в гра̀фа с "
+"подаванията е „%s“, а трябва да е „%s“"
+
+#: commit-graph.c:2039
+#, c-format
+msgid "commit-graph parent list for commit %s is too long"
+msgstr "списъкът с родители на „%s“ в гра̀фа с подаванията е прекалено дълъг"
+
+#: commit-graph.c:2048
+#, c-format
+msgid "commit-graph parent for %s is %s != %s"
+msgstr "родителят на „%s“ в гра̀фа с подаванията е „%s“, а трябва да е „%s“"
+
+#: commit-graph.c:2061
+#, c-format
+msgid "commit-graph parent list for commit %s terminates early"
+msgstr "списъкът с родители на „%s“ в гра̀фа с подаванията е прекалено къс"
+
+#: commit-graph.c:2066
+#, c-format
+msgid ""
+"commit-graph has generation number zero for commit %s, but non-zero elsewhere"
+msgstr ""
+"номерът на поколението на подаване „%s“ в гра̀фа с подаванията е 0, а другаде "
+"не е"
+
+#: commit-graph.c:2070
+#, c-format
+msgid ""
+"commit-graph has non-zero generation number for commit %s, but zero elsewhere"
+msgstr ""
+"номерът на поколението на подаване „%s“ в гра̀фа с подаванията не е 0, а "
+"другаде е"
+
+#: commit-graph.c:2085
+#, c-format
+msgid "commit-graph generation for commit %s is %u != %u"
+msgstr ""
+"номерът на поколението на подаване „%s“ в гра̀фа с подаванията е %u, а "
+"другаде е %u"
+
+#: commit-graph.c:2091
+#, c-format
+msgid "commit date for commit %s in commit-graph is %<PRIuMAX> != %<PRIuMAX>"
+msgstr ""
+"датата на подаване на „%s“ в гра̀фа с подаванията е %<PRIuMAX>, а трябва да е "
+"%<PRIuMAX>"
 
-#: compat/obstack.c:405 compat/obstack.c:407
+#: compat/obstack.c:406 compat/obstack.c:408
 msgid "memory exhausted"
 msgstr "паметта свърши"
 
-#: config.c:187
+#: config.c:124
+#, c-format
+msgid ""
+"exceeded maximum include depth (%d) while including\n"
+"\t%s\n"
+"from\n"
+"\t%s\n"
+"This might be due to circular includes."
+msgstr ""
+"максималната дълбочина на влагане (%d) е надвишена при вмъкването на:\n"
+"    %s\n"
+"от\n"
+"    %s\n"
+"Това може да се дължи на зацикляне при вмъкването."
+
+#: config.c:140
+#, c-format
+msgid "could not expand include path '%s'"
+msgstr "пътят за вмъкване „%s“не може да бъде разширен"
+
+#: config.c:151
+msgid "relative config includes must come from files"
+msgstr "относителните вмъквания на конфигурации трябва да идват от файлове"
+
+#: config.c:197
 msgid "relative config include conditionals must come from files"
 msgstr "относителните условни изрази за вмъкване трябва да идват от файлове"
 
-#: config.c:788
+#: config.c:376
+#, c-format
+msgid "key does not contain a section: %s"
+msgstr "ключът не съдържа раздел: „%s“"
+
+#: config.c:382
+#, c-format
+msgid "key does not contain variable name: %s"
+msgstr "ключът не съдържа име на променлива: „%s“"
+
+#: config.c:406 sequencer.c:2530
+#, c-format
+msgid "invalid key: %s"
+msgstr "неправилен ключ: „%s“"
+
+#: config.c:412
+#, c-format
+msgid "invalid key (newline): %s"
+msgstr "неправилен ключ (нов ред): „%s“"
+
+#: config.c:448 config.c:460
+#, c-format
+msgid "bogus config parameter: %s"
+msgstr "неправилен конфигурационен параметър: „%s“"
+
+#: config.c:495
+#, c-format
+msgid "bogus format in %s"
+msgstr "неправилен формат в „%s“"
+
+#: config.c:821
 #, c-format
 msgid "bad config line %d in blob %s"
 msgstr "неправилен ред за настройки %d в BLOB „%s“"
 
-#: config.c:792
+#: config.c:825
 #, c-format
 msgid "bad config line %d in file %s"
 msgstr "неправилен ред за настройки %d във файла „%s“"
 
-#: config.c:796
+#: config.c:829
 #, c-format
 msgid "bad config line %d in standard input"
 msgstr "неправилен ред за настройки %d на стандартния вход"
 
-#: config.c:800
+#: config.c:833
 #, c-format
 msgid "bad config line %d in submodule-blob %s"
 msgstr "неправилен ред за настройки %d в BLOB за подмодул „%s“"
 
-#: config.c:804
+#: config.c:837
 #, c-format
 msgid "bad config line %d in command line %s"
 msgstr "неправилен ред за настройки %d на командния ред „%s“"
 
-#: config.c:808
+#: config.c:841
 #, c-format
 msgid "bad config line %d in %s"
 msgstr "неправилен ред за настройки %d в „%s“"
 
-#: config.c:936
+#: config.c:978
 msgid "out of range"
 msgstr "извън диапазона"
 
-#: config.c:936
+#: config.c:978
 msgid "invalid unit"
 msgstr "неправилна мерна единица"
 
-#: config.c:942
+#: config.c:979
 #, c-format
 msgid "bad numeric config value '%s' for '%s': %s"
 msgstr "неправилна числова стойност „%s“ за „%s“: %s"
 
-#: config.c:947
+#: config.c:998
 #, c-format
 msgid "bad numeric config value '%s' for '%s' in blob %s: %s"
 msgstr "неправилна числова стойност „%s“ за „%s“ в BLOB „%s“: %s"
 
-#: config.c:950
+#: config.c:1001
 #, c-format
 msgid "bad numeric config value '%s' for '%s' in file %s: %s"
 msgstr "неправилна числова стойност „%s“ за „%s“ във файла „%s“: %s"
 
-#: config.c:953
+#: config.c:1004
 #, c-format
 msgid "bad numeric config value '%s' for '%s' in standard input: %s"
 msgstr "неправилна числова стойност „%s“ за „%s“ на стандартния вход: %s"
 
-#: config.c:956
+#: config.c:1007
 #, c-format
 msgid "bad numeric config value '%s' for '%s' in submodule-blob %s: %s"
 msgstr "неправилна числова стойност „%s“ за „%s“ в BLOB от подмодул „%s“: %s"
 
-#: config.c:959
+#: config.c:1010
 #, c-format
 msgid "bad numeric config value '%s' for '%s' in command line %s: %s"
 msgstr "неправилна числова стойност „%s“ за „%s“ на командния ред „%s“: %s"
 
-#: config.c:962
+#: config.c:1013
 #, c-format
 msgid "bad numeric config value '%s' for '%s' in %s: %s"
 msgstr "неправилна числова стойност „%s“ за „%s“ в %s: %s"
 
-#: config.c:1057
+#: config.c:1108
 #, c-format
 msgid "failed to expand user dir in: '%s'"
 msgstr "домашната папка на потребителя не може да бъде открита: „%s“"
 
-#: config.c:1066
+#: config.c:1117
 #, c-format
 msgid "'%s' for '%s' is not a valid timestamp"
 msgstr "„%s“ не е правилна стойност за време за „%s“"
 
-#: config.c:1171 config.c:1182
+#: config.c:1208
+#, c-format
+msgid "abbrev length out of range: %d"
+msgstr "дължината на съкращаване е извън интервала ([4; 40]): %d"
+
+#: config.c:1222 config.c:1233
 #, c-format
 msgid "bad zlib compression level %d"
 msgstr "неправилно ниво на компресиране: %d"
 
-#: config.c:1307
+#: config.c:1325
+msgid "core.commentChar should only be one character"
+msgstr "настройката „core.commentChar“ трябва да е само един знак"
+
+#: config.c:1358
 #, c-format
 msgid "invalid mode for object creation: %s"
 msgstr "неправилен режим за създаването на обекти: %s"
 
-#: config.c:1473
+#: config.c:1430
+#, c-format
+msgid "malformed value for %s"
+msgstr "неправилна стойност за „%s“"
+
+#: config.c:1456
+#, c-format
+msgid "malformed value for %s: %s"
+msgstr "неправилна стойност за „%s“: „%s“"
+
+#: config.c:1457
+msgid "must be one of nothing, matching, simple, upstream or current"
+msgstr ""
+"трябва да е една от следните стойности: „nothing“ (без изтласкване при липса "
+"на указател), „matching“ (всички клони със съвпадащи имена), "
+"„simple“ (клонът със същото име, от който се издърпва), „upstream“ (клонът, "
+"от който се издърпва) или „current“ (клонът със същото име)"
+
+#: config.c:1518 builtin/pack-objects.c:3394
 #, c-format
 msgid "bad pack compression level %d"
 msgstr "неправилно ниво на компресиране при пакетиране: %d"
 
-#: config.c:1681
+#: config.c:1639
+#, c-format
+msgid "unable to load config blob object '%s'"
+msgstr "обектът-BLOB „%s“ с конфигурации не може да се зареди"
+
+#: config.c:1642
+#, c-format
+msgid "reference '%s' does not point to a blob"
+msgstr "указателят „%s“ не сочи към обект-BLOB"
+
+#: config.c:1659
+#, c-format
+msgid "unable to resolve config blob '%s'"
+msgstr "обектът-BLOB „%s“ с конфигурации не може да бъде открит"
+
+#: config.c:1689
+#, c-format
+msgid "failed to parse %s"
+msgstr "„%s“ не може да бъде анализиран"
+
+#: config.c:1745
 msgid "unable to parse command-line config"
 msgstr "неправилни настройки от командния ред"
 
-#: config.c:2013
+#: config.c:2096
 msgid "unknown error occurred while reading the configuration files"
 msgstr "неочаквана грешка при изчитането на конфигурационните файлове"
 
-#: config.c:2200
+#: config.c:2266
 #, c-format
 msgid "Invalid %s: '%s'"
 msgstr "Неправилен %s: „%s“"
 
-#: config.c:2243
-#, c-format
-msgid "unknown core.untrackedCache value '%s'; using 'keep' default value"
-msgstr ""
-"непозната стойност „%s“ за настройката „core.untrackedCache“.  Ще се ползва "
-"стандартната стойност „keep“ (запазване)"
-
-#: config.c:2269
+#: config.c:2311
 #, c-format
 msgid "splitIndex.maxPercentChange value '%d' should be between 0 and 100"
 msgstr ""
 "стойността на „splitIndex.maxPercentChange“ трябва да е между 1 и 100, а не "
 "%d"
 
-#: config.c:2294
+#: config.c:2357
 #, c-format
 msgid "unable to parse '%s' from command-line config"
 msgstr "неразпозната стойност „%s“ от командния ред"
 
-#: config.c:2296
+#: config.c:2359
 #, c-format
 msgid "bad config variable '%s' in file '%s' at line %d"
 msgstr "неправилна настройка „%s“ във файла „%s“ на ред №%d"
 
-#: config.c:2402
+#: config.c:2440
+#, c-format
+msgid "invalid section name '%s'"
+msgstr "неправилно име на раздел: „%s“"
+
+#: config.c:2472
 #, c-format
 msgid "%s has multiple values"
 msgstr "зададени са няколко стойности за „%s“"
 
-#: config.c:2766 config.c:3019
+#: config.c:2501
+#, c-format
+msgid "failed to write new configuration file %s"
+msgstr "новият конфигурационен файл „%s“ не може да бъде запазен"
+
+#: config.c:2753 config.c:3077
+#, c-format
+msgid "could not lock config file %s"
+msgstr "конфигурационният файл „%s“ не може да бъде заключен"
+
+#: config.c:2764
+#, c-format
+msgid "opening %s"
+msgstr "отваряне на „%s“"
+
+#: config.c:2799 builtin/config.c:328
+#, c-format
+msgid "invalid pattern: %s"
+msgstr "неправилен шаблон: %s"
+
+#: config.c:2824
+#, c-format
+msgid "invalid config file %s"
+msgstr "неправилен конфигурационен файл: „%s“"
+
+#: config.c:2837 config.c:3090
 #, c-format
 msgid "fstat on %s failed"
 msgstr "неуспешно изпълнение на „fstat“ върху „%s“"
 
-#: config.c:2905
+#: config.c:2848
+#, c-format
+msgid "unable to mmap '%s'"
+msgstr "неуспешно изпълнение на „mmap“ върху „%s“"
+
+#: config.c:2857 config.c:3095
+#, c-format
+msgid "chmod on %s failed"
+msgstr "неуспешна смяна на права с „chmod“ върху „%s“"
+
+#: config.c:2942 config.c:3192
+#, c-format
+msgid "could not write config file %s"
+msgstr "конфигурационният файл „%s“ не може да бъде записан"
+
+#: config.c:2976
 #, c-format
 msgid "could not set '%s' to '%s'"
 msgstr "„%s“ не може да се зададе да е „%s“"
 
-#: config.c:2907 builtin/remote.c:779
+#: config.c:2978 builtin/remote.c:781
 #, c-format
 msgid "could not unset '%s'"
 msgstr "„%s“ не може да се премахне"
 
+#: config.c:3068
+#, c-format
+msgid "invalid section name: %s"
+msgstr "неправилно име на раздел: %s"
+
+#: config.c:3235
+#, c-format
+msgid "missing value for '%s'"
+msgstr "липсва стойност за „%s“"
+
 #: connect.c:61
-msgid "The remote end hung up upon initial contact"
-msgstr "Отдалеченото хранилище прекъсна връзката веднага след отварянето ѝ"
+msgid "the remote end hung up upon initial contact"
+msgstr "отдалеченото хранилище прекъсна връзката веднага след отварянето ѝ"
 
 #: connect.c:63
 msgid ""
@@ -1597,69 +2598,222 @@ msgstr ""
 "Проверете дали то съществува и дали имате права\n"
 "за достъп."
 
-#: connected.c:66 builtin/fsck.c:201 builtin/prune.c:145
-msgid "Checking connectivity"
-msgstr "Проверка на връзката"
+#: connect.c:81
+#, c-format
+msgid "server doesn't support '%s'"
+msgstr "сървърът не поддържа „%s“"
 
-#: connected.c:78
-msgid "Could not run 'git rev-list'"
-msgstr "Командата „git rev-list“ не може да бъде изпълнена."
+#: connect.c:103
+#, c-format
+msgid "server doesn't support feature '%s'"
+msgstr "сървърът не поддържа „%s“"
 
-#: connected.c:98
-msgid "failed write to rev-list"
-msgstr "неуспешен запис на списъка с версиите"
+#: connect.c:114
+msgid "expected flush after capabilities"
+msgstr ""
+"след първоначалната обява на възможностите се очаква изчистване на буферите"
 
-#: connected.c:105
-msgid "failed to close rev-list's stdin"
-msgstr "стандартният вход на списъка с версиите не може да бъде затворен"
+#: connect.c:233
+#, c-format
+msgid "ignoring capabilities after first line '%s'"
+msgstr "пропускане на възможностите след първия ред „%s“"
+
+#: connect.c:252
+msgid "protocol error: unexpected capabilities^{}"
+msgstr "протоколна грешка: неочаквани възможности^{}"
 
-#: convert.c:206
+#: connect.c:273
 #, c-format
-msgid "CRLF would be replaced by LF in %s."
-msgstr "Всяка последователност от знаци „CRLF“ ще бъдe заменена с „LF“ в „%s“."
+msgid "protocol error: expected shallow sha-1, got '%s'"
+msgstr "протоколна грешка: очаква се SHA1 на плитък обект, а бе получено: „%s“"
+
+#: connect.c:275
+msgid "repository on the other end cannot be shallow"
+msgstr "отсрещното хранилище не може да е плитко"
 
-#: convert.c:208
+#: connect.c:313
+msgid "invalid packet"
+msgstr "неправилен пакет"
+
+#: connect.c:333
 #, c-format
-msgid ""
+msgid "protocol error: unexpected '%s'"
+msgstr "протоколна грешка: неочаквано „%s“"
+
+#: connect.c:441
+#, c-format
+msgid "invalid ls-refs response: %s"
+msgstr "неправилен отговор на „ls-refs“: „%s“"
+
+#: connect.c:445
+msgid "expected flush after ref listing"
+msgstr "очакваше се изчистване на буферите след изброяването на указателите"
+
+#: connect.c:544
+#, c-format
+msgid "protocol '%s' is not supported"
+msgstr "протокол „%s“ не се поддържа"
+
+#: connect.c:595
+msgid "unable to set SO_KEEPALIVE on socket"
+msgstr "неуспешно задаване на „SO_KEEPALIVE“ на гнездо"
+
+#: connect.c:635 connect.c:698
+#, c-format
+msgid "Looking up %s ... "
+msgstr "Търсене на „%s“… "
+
+#: connect.c:639
+#, c-format
+msgid "unable to look up %s (port %s) (%s)"
+msgstr "„%s“ (порт %s) не може да се открие („%s“)"
+
+#. TRANSLATORS: this is the end of "Looking up %s ... "
+#: connect.c:643 connect.c:714
+#, c-format
+msgid ""
+"done.\n"
+"Connecting to %s (port %s) ... "
+msgstr ""
+"готово.\n"
+"Свързване към „%s“ (порт %s)…"
+
+#: connect.c:665 connect.c:742
+#, c-format
+msgid ""
+"unable to connect to %s:\n"
+"%s"
+msgstr ""
+"неуспешно свързване към „%s“:\n"
+"%s"
+
+#. TRANSLATORS: this is the end of "Connecting to %s (port %s) ... "
+#: connect.c:671 connect.c:748
+msgid "done."
+msgstr "действието завърши."
+
+#: connect.c:702
+#, c-format
+msgid "unable to look up %s (%s)"
+msgstr "„%s“ не може да се открие (%s)"
+
+#: connect.c:708
+#, c-format
+msgid "unknown port %s"
+msgstr "непознат порт „%s“"
+
+#: connect.c:845 connect.c:1175
+#, c-format
+msgid "strange hostname '%s' blocked"
+msgstr "необичайното име на хост „%s“ е блокирано"
+
+#: connect.c:847
+#, c-format
+msgid "strange port '%s' blocked"
+msgstr "необичайният порт „%s“ е блокиран"
+
+#: connect.c:857
+#, c-format
+msgid "cannot start proxy %s"
+msgstr "посредникът „%s“ не може да се стартира"
+
+#: connect.c:928
+msgid "no path specified; see 'git help pull' for valid url syntax"
+msgstr ""
+"не е указан път. Проверете синтаксиса с командата:\n"
+"\n"
+"    git help pull"
+
+#: connect.c:1123
+msgid "ssh variant 'simple' does not support -4"
+msgstr "вариантът за „ssh“ — „simple“ (опростен), не поддържа опцията „-4“"
+
+#: connect.c:1135
+msgid "ssh variant 'simple' does not support -6"
+msgstr "вариантът за „ssh“ — „simple“ (опростен), не поддържа опцията „-6“"
+
+#: connect.c:1152
+msgid "ssh variant 'simple' does not support setting port"
+msgstr ""
+"вариантът за „ssh“ — „simple“ (опростен), не поддържа задаването на порт"
+
+#: connect.c:1264
+#, c-format
+msgid "strange pathname '%s' blocked"
+msgstr "необичайният път „%s“ е блокиран"
+
+#: connect.c:1311
+msgid "unable to fork"
+msgstr "неуспешно създаване на процес"
+
+#: connected.c:89 builtin/fsck.c:208 builtin/prune.c:43
+msgid "Checking connectivity"
+msgstr "Проверка на свързаността"
+
+#: connected.c:101
+msgid "Could not run 'git rev-list'"
+msgstr "Командата „git rev-list“ не може да бъде изпълнена."
+
+#: connected.c:121
+msgid "failed write to rev-list"
+msgstr "неуспешен запис на списъка с версиите"
+
+#: connected.c:128
+msgid "failed to close rev-list's stdin"
+msgstr "стандартният вход на списъка с версиите не може да бъде затворен"
+
+#: convert.c:194
+#, c-format
+msgid "illegal crlf_action %d"
+msgstr "неправилно действие за край на ред: %d"
+
+#: convert.c:207
+#, c-format
+msgid "CRLF would be replaced by LF in %s"
+msgstr "Всяка последователност от знаци „CRLF“ ще бъдe заменена с „LF“ в „%s“."
+
+#: convert.c:209
+#, c-format
+msgid ""
 "CRLF will be replaced by LF in %s.\n"
-"The file will have its original line endings in your working directory."
+"The file will have its original line endings in your working directory"
 msgstr ""
 "Всяка последователност от знаци „CRLF“ ще бъдe заменена с „LF“ в „%s“.\n"
 "Файлът ще остане с първоначалните знаци за край на ред в работната ви "
 "директория."
 
-#: convert.c:216
+#: convert.c:217
 #, c-format
 msgid "LF would be replaced by CRLF in %s"
 msgstr ""
 "Всеки знак „LF“ ще бъдe заменен с последователността от знаци „CRLF“ в „%s“."
 
-#: convert.c:218
+#: convert.c:219
 #, c-format
 msgid ""
 "LF will be replaced by CRLF in %s.\n"
-"The file will have its original line endings in your working directory."
+"The file will have its original line endings in your working directory"
 msgstr ""
 "Всеки знак „LF“ ще бъдe заменен с последователността от знаци „CRLF“ в "
 "„%s“.\n"
 "Файлът ще остане с първоначалните знаци за край на ред в работната ви "
 "директория."
 
-#: convert.c:279
+#: convert.c:284
 #, c-format
 msgid "BOM is prohibited in '%s' if encoded as %s"
 msgstr ""
 "„%s“ не трябва да съдържа маркер за поредността на байтовете (BOM) при "
 "кодиране „%s“"
 
-#: convert.c:286
+#: convert.c:291
 #, c-format
 msgid ""
-"The file '%s' contains a byte order mark (BOM). Please use UTF-%s as working-"
-"tree-encoding."
+"The file '%s' contains a byte order mark (BOM). Please use UTF-%.*s as "
+"working-tree-encoding."
 msgstr ""
 "Файлът „%s“ съдържа маркер за поредността на байтовете (BOM).  Използвайте "
-"„UTF-%s“ като кодиране за работното дърво."
+"„UTF-%.*s“ като кодиране за работното дърво."
 
 #: convert.c:304
 #, c-format
@@ -1678,67 +2832,119 @@ msgstr ""
 "на работното дърво използвайте UTF-%sBE или UTF-%sLE (в зависимост от "
 "поредността на байтовете)."
 
-#: convert.c:424
+#: convert.c:419 convert.c:490
 #, c-format
 msgid "failed to encode '%s' from %s to %s"
 msgstr "неуспешно прекодиране на „%s“ от „%s“ към „%s“"
 
-#: convert.c:467
+#: convert.c:462
 #, c-format
 msgid "encoding '%s' from %s to %s and back is not the same"
 msgstr "Прекодирането на „%s“ от „%s“ към „%s“ и обратно променя файла"
 
-#: convert.c:1225
+#: convert.c:668
+#, c-format
+msgid "cannot fork to run external filter '%s'"
+msgstr "неуспешно създаване на процес за външен филтър „%s“"
+
+#: convert.c:688
+#, c-format
+msgid "cannot feed the input to external filter '%s'"
+msgstr "входът не може да бъде подаден на външния филтър „%s“"
+
+#: convert.c:695
+#, c-format
+msgid "external filter '%s' failed %d"
+msgstr "неуспешно изпълнение на външния филтър „%s“: %d"
+
+#: convert.c:730 convert.c:733
+#, c-format
+msgid "read from external filter '%s' failed"
+msgstr "неуспешно четене от външния филтър „%s“"
+
+#: convert.c:736 convert.c:791
+#, c-format
+msgid "external filter '%s' failed"
+msgstr "неуспешно изпълнение на външния филтър „%s“"
+
+#: convert.c:839
+msgid "unexpected filter type"
+msgstr "неочакван вид филтър"
+
+#: convert.c:850
+msgid "path name too long for external filter"
+msgstr "пътят е прекалено дълъг за външен филтър"
+
+#: convert.c:924
+#, c-format
+msgid ""
+"external filter '%s' is not available anymore although not all paths have "
+"been filtered"
+msgstr ""
+"външният филтър „%s“ вече не е наличен, въпреки че не всички пътища са "
+"филтрирани"
+
+#: convert.c:1223
 msgid "true/false are no valid working-tree-encodings"
 msgstr "„true“/„false“ не може да са кодирания на работното дърво"
 
-#: date.c:116
+#: convert.c:1411 convert.c:1445
+#, c-format
+msgid "%s: clean filter '%s' failed"
+msgstr "%s: неуспешно изпълнение на декодиращ филтър „%s“"
+
+#: convert.c:1489
+#, c-format
+msgid "%s: smudge filter %s failed"
+msgstr "%s: неуспешно изпълнение на кодиращ филтър „%s“"
+
+#: date.c:138
 msgid "in the future"
 msgstr "в бъдещето"
 
-#: date.c:122
+#: date.c:144
 #, c-format
 msgid "%<PRIuMAX> second ago"
 msgid_plural "%<PRIuMAX> seconds ago"
 msgstr[0] "преди %<PRIuMAX> секунда"
 msgstr[1] "преди %<PRIuMAX> секунди"
 
-#: date.c:129
+#: date.c:151
 #, c-format
 msgid "%<PRIuMAX> minute ago"
 msgid_plural "%<PRIuMAX> minutes ago"
 msgstr[0] "преди %<PRIuMAX> минута"
 msgstr[1] "преди %<PRIuMAX> минути"
 
-#: date.c:136
+#: date.c:158
 #, c-format
 msgid "%<PRIuMAX> hour ago"
 msgid_plural "%<PRIuMAX> hours ago"
 msgstr[0] "преди %<PRIuMAX> час"
 msgstr[1] "преди %<PRIuMAX> часа"
 
-#: date.c:143
+#: date.c:165
 #, c-format
 msgid "%<PRIuMAX> day ago"
 msgid_plural "%<PRIuMAX> days ago"
 msgstr[0] "преди %<PRIuMAX> ден"
 msgstr[1] "преди %<PRIuMAX> дена"
 
-#: date.c:149
+#: date.c:171
 #, c-format
 msgid "%<PRIuMAX> week ago"
 msgid_plural "%<PRIuMAX> weeks ago"
 msgstr[0] "преди %<PRIuMAX> седмица"
 msgstr[1] "преди %<PRIuMAX> седмици"
 
-#: date.c:156
+#: date.c:178
 #, c-format
 msgid "%<PRIuMAX> month ago"
 msgid_plural "%<PRIuMAX> months ago"
 msgstr[0] "преди %<PRIuMAX> месец"
 msgstr[1] "преди %<PRIuMAX> месеца"
 
-#: date.c:167
+#: date.c:189
 #, c-format
 msgid "%<PRIuMAX> year"
 msgid_plural "%<PRIuMAX> years"
@@ -1746,61 +2952,115 @@ msgstr[0] "%<PRIuMAX> година"
 msgstr[1] "%<PRIuMAX> години"
 
 #. TRANSLATORS: "%s" is "<n> years"
-#: date.c:170
+#: date.c:192
 #, c-format
 msgid "%s, %<PRIuMAX> month ago"
 msgid_plural "%s, %<PRIuMAX> months ago"
 msgstr[0] "преди %s и %<PRIuMAX> месец"
 msgstr[1] "преди %s и %<PRIuMAX> месеца"
 
-#: date.c:175 date.c:180
+#: date.c:197 date.c:202
 #, c-format
 msgid "%<PRIuMAX> year ago"
 msgid_plural "%<PRIuMAX> years ago"
 msgstr[0] "преди %<PRIuMAX> година"
 msgstr[1] "преди %<PRIuMAX> години"
 
+#: delta-islands.c:272
+msgid "Propagating island marks"
+msgstr "Разпространяване на границите на групите"
+
+#: delta-islands.c:290
+#, c-format
+msgid "bad tree object %s"
+msgstr "неправилен обект-дърво: %s"
+
+#: delta-islands.c:334
+#, c-format
+msgid "failed to load island regex for '%s': %s"
+msgstr "регулярният израз на групата за „%s“, не може да бъде зареден: „%s“"
+
+#: delta-islands.c:390
+#, c-format
+msgid "island regex from config has too many capture groups (max=%d)"
+msgstr ""
+"регулярният израз на групата в конфигурационния файл съдържа повече от "
+"максимално поддържаните (%d) прихващащи групи"
+
+#: delta-islands.c:467
+#, c-format
+msgid "Marked %d islands, done.\n"
+msgstr "Отбелязани са %d групи, работата приключи.\n"
+
 #: diffcore-order.c:24
 #, c-format
 msgid "failed to read orderfile '%s'"
 msgstr "файлът с подредбата на съответствията „%s“ не може да бъде прочетен"
 
-#: diffcore-rename.c:535
+#: diffcore-rename.c:543
 msgid "Performing inexact rename detection"
 msgstr "Търсене на преименувания на обекти съчетани с промени"
 
-#: diff.c:74
-#, c-format
-msgid "option '%s' requires a value"
-msgstr "опцията „%s“ изисква стойност"
+#: diff-no-index.c:238
+msgid "git diff --no-index [<options>] <path> <path>"
+msgstr "git diff --no-index [ОПЦИЯ…] ПЪТ ПЪТ"
 
-#: diff.c:152
+#: diff-no-index.c:263
+msgid ""
+"Not a git repository. Use --no-index to compare two paths outside a working "
+"tree"
+msgstr ""
+"Не е хранилище на git.  Ползвайте опцията „--no-index“, за да сравните "
+"пътища извън работно дърво"
+
+#: diff.c:155
 #, c-format
 msgid "  Failed to parse dirstat cut-off percentage '%s'\n"
 msgstr ""
 "  Неуспешно разпознаване на „%s“ като процент-праг за статистиката по "
 "директории\n"
 
-#: diff.c:157
+#: diff.c:160
 #, c-format
 msgid "  Unknown dirstat parameter '%s'\n"
 msgstr "  Непознат параметър „%s“ за статистиката по директории'\n"
 
-#: diff.c:281
+#: diff.c:296
 msgid ""
-"color moved setting must be one of 'no', 'default', 'zebra', 'dimmed_zebra', "
-"'plain'"
+"color moved setting must be one of 'no', 'default', 'blocks', 'zebra', "
+"'dimmed-zebra', 'plain'"
 msgstr ""
 "настройката за цвят за преместване трябва да е една от: „no“ (без), "
-"„default“ (стандартно), „zebra“ (райе), „dimmed_zebra“ (тъмно райе), "
-"„plain“ (обикновено)"
+"„default“ (стандартно), „blocks“ (парчета), „zebra“ (райе), "
+"„dimmed_zebra“ (тъмно райе), „plain“ (обикновено)"
+
+#: diff.c:324
+#, c-format
+msgid ""
+"unknown color-moved-ws mode '%s', possible values are 'ignore-space-change', "
+"'ignore-space-at-eol', 'ignore-all-space', 'allow-indentation-change'"
+msgstr ""
+"неподдържан режим за настройката „color-moved-ws mode“ — „%s“, възможните "
+"стойности са „ignore-space-change“ (пренебрегване на промените на празните "
+"знаци), „ignore-space-at-eol“ (пренебрегване на промените на празните знаци "
+"в края на реда), „ignore-all-space“ (пренебрегване на всички празни знаци), "
+"„allow-indentation-change“ (позволяване на промените в празните знаци за "
+"форматиране)"
+
+#: diff.c:332
+msgid ""
+"color-moved-ws: allow-indentation-change cannot be combined with other "
+"whitespace modes"
+msgstr ""
+"„color-moved-ws“: „allow-indentation-change“ е несъвместима с другите режими "
+"за празни знаци"
 
-#: diff.c:341
+#: diff.c:405
 #, c-format
 msgid "Unknown value for 'diff.submodule' config variable: '%s'"
 msgstr "Непозната стойност „%s“ за настройката „diff.submodule“"
 
-#: diff.c:401
+#: diff.c:465
 #, c-format
 msgid ""
 "Found errors in 'diff.dirstat' config variable:\n"
@@ -1809,27 +3069,38 @@ msgstr ""
 "Грешки в настройката „diff.dirstat“:\n"
 "%s"
 
-#: diff.c:3823
+#: diff.c:4202
 #, c-format
 msgid "external diff died, stopping at %s"
 msgstr ""
 "външната програма за разлики завърши неуспешно.  Спиране на работата при „%s“"
 
-#: diff.c:4153
+#: diff.c:4547
 msgid "--name-only, --name-status, --check and -s are mutually exclusive"
 msgstr ""
 "Опциите „--name-only“, „--name-status“, „--check“ и „-s“ са несъвместими "
 "една с друга"
 
-#: diff.c:4156
+#: diff.c:4550
 msgid "-G, -S and --find-object are mutually exclusive"
 msgstr "Опциите „-G“, „-S“ и „--find-object“ са несъвместими една с друга"
 
-#: diff.c:4244
+#: diff.c:4628
 msgid "--follow requires exactly one pathspec"
 msgstr "Опцията „--follow“ изисква точно един път"
 
-#: diff.c:4410
+#: diff.c:4676
+#, c-format
+msgid "invalid --stat value: %s"
+msgstr "неправилна стойност за „--stat“: %s"
+
+#: diff.c:4681 diff.c:4686 diff.c:4691 diff.c:4696 diff.c:5209
+#: parse-options.c:199 parse-options.c:203
+#, c-format
+msgid "%s expects a numerical value"
+msgstr "опцията „%s“ очаква число за аргумент"
+
+#: diff.c:4713
 #, c-format
 msgid ""
 "Failed to parse --dirstat/-X option parameter:\n"
@@ -1838,2390 +3109,2541 @@ msgstr ""
 "Неразпознат параметър към опцията „--dirstat/-X“:\n"
 "%s"
 
-#: diff.c:4424
+#: diff.c:4798
 #, c-format
-msgid "Failed to parse --submodule option parameter: '%s'"
-msgstr "Неразпознат параметър към опцията „--submodule“: „%s“"
+msgid "unknown change class '%c' in --diff-filter=%s"
+msgstr "непознат вид промяна: „%c“ в „--diff-filter=%s“"
 
-#: diff.c:5500
-msgid "inexact rename detection was skipped due to too many files."
-msgstr ""
-"търсенето на преименувания на обекти съчетани с промени се прескача поради "
-"многото файлове."
+#: diff.c:4822
+#, c-format
+msgid "unknown value after ws-error-highlight=%.*s"
+msgstr "непозната стойност след „ws-error-highlight=%.*s“"
 
-#: diff.c:5503
-msgid "only found copies from modified paths due to too many files."
+#: diff.c:4836
+#, c-format
+msgid "unable to resolve '%s'"
+msgstr "„%s“ не може да се открие"
+
+#: diff.c:4886 diff.c:4892
+#, c-format
+msgid "%s expects <n>/<m> form"
 msgstr ""
-"установени са точните копия на променените пътища поради многото файлове."
+"опцията „%s“ изисква стойности за МИНИМАЛЕН_%%_ПРОМЯНА_ЗА_ИЗТОЧНИК_/"
+"МАКСИМАЛЕН_%%_ПРОМЯНА_ЗА_ЗАМЯНА от"
 
-#: diff.c:5506
+#: diff.c:4904
 #, c-format
-msgid ""
-"you may want to set your %s variable to at least %d and retry the command."
-msgstr "задайте променливата „%s“ да е поне %d и отново изпълнете командата."
+msgid "%s expects a character, got '%s'"
+msgstr "опцията „%s“ изисква знак, а не: „%s“"
 
-#: dir.c:1867
+#: diff.c:4925
 #, c-format
-msgid "could not open directory '%s'"
-msgstr "директорията „%s“ не може да бъде отворена"
+msgid "bad --color-moved argument: %s"
+msgstr "неправилен аргумент за „--color-moved“: „%s“"
 
-#: dir.c:2109
-msgid "failed to get kernel name and information"
-msgstr "името и версията на ядрото не бяха получени"
+#: diff.c:4944
+#, c-format
+msgid "invalid mode '%s' in --color-moved-ws"
+msgstr "неправилен режим „%s“ за „ --color-moved-ws“"
 
-#: dir.c:2233
-msgid "Untracked cache is disabled on this system or location."
+#: diff.c:4984
+msgid ""
+"option diff-algorithm accepts \"myers\", \"minimal\", \"patience\" and "
+"\"histogram\""
 msgstr ""
-"Кеша за неследените файлове е изключен на тази система или местоположение."
+"опцията приема следните варианти за алгоритъм за разлики: „myers“ (по "
+"Майерс), „minimal“ (минимизиране на разликите), „patience“ (пасианс) и "
+"„histogram“ (хистограмен)"
 
-#: dir.c:3075 dir.c:3080
+#: diff.c:5020 diff.c:5040
 #, c-format
-msgid "could not create directories for %s"
-msgstr "директориите за „%s“ не може да бъдат създадени"
+msgid "invalid argument to %s"
+msgstr "неправилен аргумент към „%s“"
 
-#: dir.c:3109
+#: diff.c:5178
 #, c-format
-msgid "could not migrate git directory from '%s' to '%s'"
-msgstr "директорията на git не може да се мигрира от „%s“ до „%s“"
+msgid "failed to parse --submodule option parameter: '%s'"
+msgstr "неразпознат параметър към опцията „--submodule“: „%s“"
 
-#: editor.c:61
+#: diff.c:5234
 #, c-format
-msgid "hint: Waiting for your editor to close the file...%c"
-msgstr "Подсказка: чака се редакторът ви да затвори файла …%c"
+msgid "bad --word-diff argument: %s"
+msgstr "неправилен аргумент към „--word-diff“: „%s“"
 
-#: entry.c:177
-msgid "Filtering content"
-msgstr "Филтриране на съдържанието"
+#: diff.c:5257
+msgid "Diff output format options"
+msgstr "Формат на изхода за разликите"
 
-#: entry.c:435
-#, c-format
-msgid "could not stat file '%s'"
-msgstr "неуспешно изпълнение на „stat“ върху файла „%s“"
+#: diff.c:5259 diff.c:5265
+msgid "generate patch"
+msgstr "създаване на кръпки"
 
-#: fetch-object.c:17
-msgid "Remote with no URL"
-msgstr "Липсва адрес за отдалеченото хранилище"
+#: diff.c:5262 builtin/log.c:173
+msgid "suppress diff output"
+msgstr "без извеждане на разликите"
 
-#: fetch-pack.c:254
-msgid "git fetch-pack: expected shallow list"
-msgstr "git fetch-pack: очаква се плитък списък"
+#: diff.c:5267 diff.c:5381 diff.c:5388
+msgid "<n>"
+msgstr "БРОЙ"
 
-#: fetch-pack.c:266
-msgid "git fetch-pack: expected ACK/NAK, got a flush packet"
-msgstr ""
-"git fetch-pack: очакваше се „ACK“/„NAK“, а бе получен изчистващ пакет „flush“"
+#: diff.c:5268 diff.c:5271
+msgid "generate diffs with <n> lines context"
+msgstr "файловете с разлики да са с контекст с такъв БРОЙ редове"
 
-#: fetch-pack.c:285 builtin/archive.c:63
-#, c-format
-msgid "remote error: %s"
-msgstr "отдалечена грешка: %s"
+#: diff.c:5273
+msgid "generate the diff in raw format"
+msgstr "файловете с разлики да са в суров формат"
 
-#: fetch-pack.c:286
-#, c-format
-msgid "git fetch-pack: expected ACK/NAK, got '%s'"
-msgstr "git fetch-pack: очакваше се „ACK“/„NAK“, а бе получен „%s“"
+#: diff.c:5276
+msgid "synonym for '-p --raw'"
+msgstr "псевдоним на „-p --stat“"
 
-#: fetch-pack.c:338
-msgid "--stateless-rpc requires multi_ack_detailed"
-msgstr "опцията „--stateless-rpc“ изисква  „multi_ack_detailed“"
+#: diff.c:5280
+msgid "synonym for '-p --stat'"
+msgstr "псевдоним на „-p --stat“"
 
-#: fetch-pack.c:429 fetch-pack.c:1310
-#, c-format
-msgid "invalid shallow line: %s"
-msgstr "неправилен плитък ред: „%s“"
+#: diff.c:5284
+msgid "machine friendly --stat"
+msgstr "„--stat“ във формат за четене от програма"
 
-#: fetch-pack.c:435 fetch-pack.c:1316
-#, c-format
-msgid "invalid unshallow line: %s"
-msgstr "неправилен неплитък ред: „%s“"
+#: diff.c:5287
+msgid "output only the last line of --stat"
+msgstr "извеждане само на последния ред на „--stat“"
 
-#: fetch-pack.c:437 fetch-pack.c:1318
-#, c-format
-msgid "object not found: %s"
-msgstr "обектът „%s“ липсва"
+#: diff.c:5289 diff.c:5297
+msgid "<param1,param2>..."
+msgstr "ПАРАМЕТЪР_1, ПАРАМЕТЪР_2, …"
 
-#: fetch-pack.c:440 fetch-pack.c:1321
-#, c-format
-msgid "error in object: %s"
-msgstr "грешка в обекта: „%s“"
+#: diff.c:5290
+msgid ""
+"output the distribution of relative amount of changes for each sub-directory"
+msgstr "извеждане на разпределението на промените за всяка поддиректория"
 
-#: fetch-pack.c:442 fetch-pack.c:1323
-#, c-format
-msgid "no shallow found: %s"
-msgstr "не е открит плитък обект: %s"
+#: diff.c:5294
+msgid "synonym for --dirstat=cumulative"
+msgstr "псевдоним на „--dirstat=cumulative“"
 
-#: fetch-pack.c:445 fetch-pack.c:1326
-#, c-format
-msgid "expected shallow/unshallow, got %s"
-msgstr "очаква се плитък или не обект, а бе получено: %s"
+#: diff.c:5298
+msgid "synonym for --dirstat=files,param1,param2..."
+msgstr "псевдоним на „--dirstat=ФАЙЛОВЕ,ПАРАМЕТЪР_1,ПАРАМЕТЪР_2,…“"
 
-#: fetch-pack.c:486
-#, c-format
-msgid "got %s %d %s"
-msgstr "получено бе %s %d %s"
+#: diff.c:5302
+msgid "warn if changes introduce conflict markers or whitespace errors"
+msgstr ""
+"предупреждаване, ако промените водят до маркери за конфликт или грешки в "
+"празните знаци"
 
-#: fetch-pack.c:500
-#, c-format
-msgid "invalid commit %s"
-msgstr "неправилно подаване: „%s“"
+#: diff.c:5305
+msgid "condensed summary such as creations, renames and mode changes"
+msgstr ""
+"съкратено резюме на създадените, преименуваните и файловете с промяна на "
+"режима на достъп"
 
-#: fetch-pack.c:533
-msgid "giving up"
-msgstr "преустановяване"
+#: diff.c:5308
+msgid "show only names of changed files"
+msgstr "извеждане само на имената на променените файлове"
 
-#: fetch-pack.c:543 progress.c:229
-msgid "done"
-msgstr "действието завърши"
+#: diff.c:5311
+msgid "show only names and status of changed files"
+msgstr "извеждане само на имената и статистиката за променените файлове"
 
-#: fetch-pack.c:555
-#, c-format
-msgid "got %s (%d) %s"
-msgstr "получено бе %s (%d) %s"
+#: diff.c:5313
+msgid "<width>[,<name-width>[,<count>]]"
+msgstr "ШИРОЧИНА[,ИМЕ-ШИРОЧИНА[,БРОЙ]]"
 
-#: fetch-pack.c:601
-#, c-format
-msgid "Marking %s as complete"
-msgstr "Отбелязване на „%s“ като пълно"
+#: diff.c:5314
+msgid "generate diffstat"
+msgstr "извеждане на статистика за промените"
 
-#: fetch-pack.c:828
-#, c-format
-msgid "already have %s (%s)"
-msgstr "вече има „%s“ (%s)"
+#: diff.c:5316 diff.c:5319 diff.c:5322
+msgid "<width>"
+msgstr "ШИРОЧИНА"
 
-#: fetch-pack.c:869
-msgid "fetch-pack: unable to fork off sideband demultiplexer"
-msgstr "fetch-pack: не може да се създаде процес за демултиплексора"
+#: diff.c:5317
+msgid "generate diffstat with a given width"
+msgstr "статистика с такава ШИРОЧИНА за промените"
 
-#: fetch-pack.c:877
-msgid "protocol error: bad pack header"
-msgstr "протоколна грешка: неправилна заглавна част на пакет"
+#: diff.c:5320
+msgid "generate diffstat with a given name width"
+msgstr "статистика за промените с такава ШИРОЧИНА на имената"
 
-#: fetch-pack.c:944
-#, c-format
-msgid "fetch-pack: unable to fork off %s"
-msgstr "fetch-pack: не може да се създаде процес за „%s“"
+#: diff.c:5323
+msgid "generate diffstat with a given graph width"
+msgstr "статистика за промените с такава ШИРОЧИНА на гра̀фа"
 
-#: fetch-pack.c:960
-#, c-format
-msgid "%s failed"
-msgstr "неуспешно изпълнение на „%s“"
+#: diff.c:5325
+msgid "<count>"
+msgstr "БРОЙ"
 
-#: fetch-pack.c:962
-msgid "error in sideband demultiplexer"
-msgstr "грешка в демултиплексора"
+#: diff.c:5326
+msgid "generate diffstat with limited lines"
+msgstr "ограничаване на БРОя на редовете в статистиката за промените"
+
+#: diff.c:5329
+msgid "generate compact summary in diffstat"
+msgstr "кратко резюме в статистиката за промените"
+
+#: diff.c:5332
+msgid "output a binary diff that can be applied"
+msgstr "извеждане на двоична разлика във вид за прилагане"
+
+#: diff.c:5335
+msgid "show full pre- and post-image object names on the \"index\" lines"
+msgstr ""
+"показване на пълните имена на обекти в редовете за индекса при вариантите "
+"преди и след промяната"
+
+#: diff.c:5337
+msgid "show colored diff"
+msgstr "разлики в цвят"
 
-#: fetch-pack.c:989
-msgid "Server does not support shallow clients"
-msgstr "Сървърът не поддържа плитки клиенти"
+#: diff.c:5338
+msgid "<kind>"
+msgstr "ВИД"
 
-#: fetch-pack.c:993
-msgid "Server supports multi_ack_detailed"
-msgstr "Сървърът поддържа „multi_ack_detailed“"
-
-#: fetch-pack.c:996
-msgid "Server supports no-done"
-msgstr "Сървърът поддържа „no-done“"
-
-#: fetch-pack.c:1002
-msgid "Server supports multi_ack"
-msgstr "Сървърът поддържа „multi_ack“"
-
-#: fetch-pack.c:1006
-msgid "Server supports side-band-64k"
-msgstr "Сървърът поддържа „side-band-64k“"
-
-#: fetch-pack.c:1010
-msgid "Server supports side-band"
-msgstr "Сървърът поддържа „side-band“"
-
-#: fetch-pack.c:1014
-msgid "Server supports allow-tip-sha1-in-want"
-msgstr "Сървърът поддържа „allow-tip-sha1-in-want“"
-
-#: fetch-pack.c:1018
-msgid "Server supports allow-reachable-sha1-in-want"
-msgstr "Сървърът поддържа „allow-reachable-sha1-in-want“"
-
-#: fetch-pack.c:1028
-msgid "Server supports ofs-delta"
-msgstr "Сървърът поддържа „ofs-delta“"
+#: diff.c:5339
+msgid ""
+"highlight whitespace errors in the 'context', 'old' or 'new' lines in the "
+"diff"
+msgstr ""
+"грешките в празните знаци да се указват в редовете за контекста, вариантите "
+"преди и след разликата,"
 
-#: fetch-pack.c:1034 fetch-pack.c:1204
-msgid "Server supports filter"
-msgstr "Сървърът поддържа филтри"
+#: diff.c:5342
+msgid ""
+"do not munge pathnames and use NULs as output field terminators in --raw or "
+"--numstat"
+msgstr ""
+"без преименуване на пътищата.  Да се използват нулеви байтове за разделители "
+"на полета в изхода при ползване на опцията „--raw“ или „--numstat“"
 
-#: fetch-pack.c:1042
-#, c-format
-msgid "Server version is %.*s"
-msgstr "Версията на сървъра е: %.*s"
+#: diff.c:5345 diff.c:5348 diff.c:5351 diff.c:5457
+msgid "<prefix>"
+msgstr "ПРЕФИКС"
 
-#: fetch-pack.c:1048
-msgid "Server does not support --shallow-since"
-msgstr "Сървърът не поддържа опцията „--shallow-since“"
+#: diff.c:5346
+msgid "show the given source prefix instead of \"a/\""
+msgstr "префикс вместо „a/“ за източник"
 
-#: fetch-pack.c:1052
-msgid "Server does not support --shallow-exclude"
-msgstr "Сървърът не поддържа опцията „--shallow-exclude“"
+#: diff.c:5349
+msgid "show the given destination prefix instead of \"b/\""
+msgstr "префикс вместо „b/“ за цел"
 
-#: fetch-pack.c:1054
-msgid "Server does not support --deepen"
-msgstr "Сървърът не поддържа опцията „--deepen“"
+#: diff.c:5352
+msgid "prepend an additional prefix to every line of output"
+msgstr "добавяне на допълнителен префикс за всеки ред на изхода"
 
-#: fetch-pack.c:1065
-msgid "no common commits"
-msgstr "няма общи подавания"
+#: diff.c:5355
+msgid "do not show any source or destination prefix"
+msgstr "без префикс за източника и целта"
 
-#: fetch-pack.c:1077 fetch-pack.c:1414
-msgid "git fetch-pack: fetch failed."
-msgstr "git fetch-pack: неуспешно доставяне."
+#: diff.c:5358
+msgid "show context between diff hunks up to the specified number of lines"
+msgstr ""
+"извеждане на контекст между последователните парчета с разлики от указания "
+"БРОЙ редове"
 
-#: fetch-pack.c:1199
-msgid "Server does not support shallow requests"
-msgstr "Сървърът не поддържа плитки заявки"
+#: diff.c:5362 diff.c:5367 diff.c:5372
+msgid "<char>"
+msgstr "ЗНАК"
 
-#: fetch-pack.c:1584
-msgid "no matching remote head"
-msgstr "не може да бъде открит подходящ връх от отдалеченото хранилище"
+#: diff.c:5363
+msgid "specify the character to indicate a new line instead of '+'"
+msgstr "знак вместо „+“ за нов вариант на ред"
 
-#: fetch-pack.c:1610
-#, c-format
-msgid "no such remote ref %s"
-msgstr "такъв отдалечен указател няма: %s"
+#: diff.c:5368
+msgid "specify the character to indicate an old line instead of '-'"
+msgstr "знак вместо „-“ за стар вариант на ред"
 
-#: fetch-pack.c:1613
-#, c-format
-msgid "Server does not allow request for unadvertised object %s"
-msgstr "Сървърът не позволява заявка за необявен „%s“"
+#: diff.c:5373
+msgid "specify the character to indicate a context instead of ' '"
+msgstr "знак вместо „ “ за контекст"
 
-#: gpg-interface.c:185
-msgid "gpg failed to sign the data"
-msgstr "Програмата „gpg“ не подписа данните."
+#: diff.c:5376
+msgid "Diff rename options"
+msgstr "Настройки за разлики с преименуване"
 
-#: gpg-interface.c:210
-msgid "could not create temporary file"
-msgstr "не може да се създаде временен файл"
+#: diff.c:5377
+msgid "<n>[/<m>]"
+msgstr "МИНИМАЛЕН_%_ПРОМЯНА_ЗА_ИЗТОЧНИК[/МАКСИМАЛEН_%_ПРОМЯНА_ЗА_ЗАМЯНА]"
 
-#: gpg-interface.c:213
-#, c-format
-msgid "failed writing detached signature to '%s'"
-msgstr "Програмата не успя да запише самостоятелния подпис в „%s“"
+#: diff.c:5378
+msgid "break complete rewrite changes into pairs of delete and create"
+msgstr ""
+"заместване на пълните промени с последователност от изтриване и създаване"
 
-#: graph.c:97
-#, c-format
-msgid "ignore invalid color '%.*s' in log.graphColors"
-msgstr "прескачане на неправилния цвят „%.*s“ в „log.graphColors“"
+#: diff.c:5382
+msgid "detect renames"
+msgstr "засичане на преименуванията"
 
-#: grep.c:2020
-#, c-format
-msgid "'%s': unable to read %s"
-msgstr "„%s“: файлът сочен от „%s“ не може да бъде прочетен"
+#: diff.c:5386
+msgid "omit the preimage for deletes"
+msgstr "без предварителен вариант при изтриване"
 
-#: grep.c:2037 setup.c:164 builtin/clone.c:409 builtin/diff.c:81
-#: builtin/rm.c:134
-#, c-format
-msgid "failed to stat '%s'"
-msgstr "не може да бъде получена информация чрез „stat“ за „%s“"
+#: diff.c:5389
+msgid "detect copies"
+msgstr "засичане на копиранията"
 
-#: grep.c:2048
-#, c-format
-msgid "'%s': short read"
-msgstr "„%s“: изчитането върна по-малко байтове от очакваното"
+#: diff.c:5393
+msgid "use unmodified files as source to find copies"
+msgstr "търсене на копирано и от непроменените файлове"
 
-#: help.c:23
-msgid "start a working area (see also: git help tutorial)"
-msgstr "създаване на работно дърво (погледнете: „git help tutorial“)"
+#: diff.c:5395
+msgid "disable rename detection"
+msgstr "без търсене на преименувания"
 
-#: help.c:24
-msgid "work on the current change (see also: git help everyday)"
-msgstr "работа по текущата промяна (погледнете: „git help everyday“)"
+#: diff.c:5398
+msgid "use empty blobs as rename source"
+msgstr "празни обекти като източник при преименувания"
 
-#: help.c:25
-msgid "examine the history and state (see also: git help revisions)"
-msgstr "преглед на историята и състоянието (погледнете: „git help revisions“)"
+#: diff.c:5400
+msgid "continue listing the history of a file beyond renames"
+msgstr ""
+"продължаване на извеждането на историята — без отрязването при преименувания "
+"на файл"
 
-#: help.c:26
-msgid "grow, mark and tweak your common history"
-msgstr "увеличаване, отбелязване и промяна на общата история"
+#: diff.c:5403
+msgid ""
+"prevent rename/copy detection if the number of rename/copy targets exceeds "
+"given limit"
+msgstr ""
+"без засичане на преименувания/копирания, ако броят им надвишава тази стойност"
 
-#: help.c:27
-msgid "collaborate (see also: git help workflows)"
-msgstr "съвместна работа (погледнете: „git help workflows“)"
+#: diff.c:5405
+msgid "Diff algorithm options"
+msgstr "Опции към алгоритъма за разлики"
 
-#: help.c:31
-msgid "Main Porcelain Commands"
-msgstr "Основни команди от потребителско ниво"
+#: diff.c:5407
+msgid "produce the smallest possible diff"
+msgstr "търсене на възможно най-малка разлика"
 
-#: help.c:32
-msgid "Ancillary Commands / Manipulators"
-msgstr "Помощни команди/Променящи"
+#: diff.c:5410
+msgid "ignore whitespace when comparing lines"
+msgstr "без промени в празните знаци при сравняване на редове"
 
-#: help.c:33
-msgid "Ancillary Commands / Interrogators"
-msgstr "Помощни команди/Запитващи"
+#: diff.c:5413
+msgid "ignore changes in amount of whitespace"
+msgstr "без промени в празните знаци"
 
-#: help.c:34
-msgid "Interacting with Others"
-msgstr "Съвместна работа с други хора"
+#: diff.c:5416
+msgid "ignore changes in whitespace at EOL"
+msgstr "без промени в празните знаци в края на редовете"
 
-#: help.c:35
-msgid "Low-level Commands / Manipulators"
-msgstr "Команди от ниско ниво/Променящи"
+#: diff.c:5419
+msgid "ignore carrier-return at the end of line"
+msgstr "без промени в знаците за край на ред"
 
-#: help.c:36
-msgid "Low-level Commands / Interrogators"
-msgstr "Команди от ниско ниво/Запитващи"
+#: diff.c:5422
+msgid "ignore changes whose lines are all blank"
+msgstr "без промени в редовете, които са изцяло от празни знаци"
 
-#: help.c:37
-msgid "Low-level Commands / Synching Repositories"
-msgstr "Команди от ниско ниво/Синхронизация на хранилища"
+#: diff.c:5425
+msgid "heuristic to shift diff hunk boundaries for easy reading"
+msgstr ""
+"евристика за преместване на границите на парчетата за улесняване на четенето"
 
-#: help.c:38
-msgid "Low-level Commands / Internal Helpers"
-msgstr "Команди от ниско ниво/Допълнителни инструменти"
+#: diff.c:5428
+msgid "generate diff using the \"patience diff\" algorithm"
+msgstr "разлика чрез алгоритъм за подредба като пасианс"
 
-#: help.c:293
-#, c-format
-msgid "available git commands in '%s'"
-msgstr "налични команди на git от „%s“"
+#: diff.c:5432
+msgid "generate diff using the \"histogram diff\" algorithm"
+msgstr "разлика по хистограмния алгоритъм"
 
-#: help.c:300
-msgid "git commands available from elsewhere on your $PATH"
-msgstr "команди на git от други директории от „$PATH“"
+#: diff.c:5434
+msgid "<algorithm>"
+msgstr "АЛГОРИТЪМ"
 
-#: help.c:309
-msgid "These are common Git commands used in various situations:"
-msgstr "Това са най-често използваните команди на Git:"
+#: diff.c:5435
+msgid "choose a diff algorithm"
+msgstr "избор на АЛГОРИТЪМа за разлики"
 
-#: help.c:358 git.c:90
-#, c-format
-msgid "unsupported command listing type '%s'"
-msgstr "неподдържан списък от команди „%s“"
+#: diff.c:5437
+msgid "<text>"
+msgstr "ТЕКСТ"
 
-#: help.c:405
-msgid "The common Git guides are:"
-msgstr "Популярните въведения в Git са:"
+#: diff.c:5438
+msgid "generate diff using the \"anchored diff\" algorithm"
+msgstr "разлика чрез алгоритъма със закотвяне"
 
-#: help.c:467
-#, c-format
-msgid ""
-"'%s' appears to be a git command, but we were not\n"
-"able to execute it. Maybe git-%s is broken?"
+#: diff.c:5440 diff.c:5449 diff.c:5452
+msgid "<mode>"
+msgstr "РЕЖИМ"
+
+#: diff.c:5441
+msgid "show word diff, using <mode> to delimit changed words"
 msgstr ""
-"Изглежда, че „%s“ е команда на git, но тя не може да\n"
-"бъде изпълнена.  Вероятно пакетът „git-%s“ е повреден."
+"разлика по думи, като се ползва този РЕЖИМ за отделянето на променените думи"
 
-#: help.c:526
-msgid "Uh oh. Your system reports no Git commands at all."
-msgstr "Странно, изглежда, че на системата ви няма нито една команда на git."
+#: diff.c:5443 diff.c:5446 diff.c:5491
+msgid "<regex>"
+msgstr "РЕГУЛЯРЕН_ИЗРАЗ"
 
-#: help.c:548
-#, c-format
-msgid "WARNING: You called a Git command named '%s', which does not exist."
+#: diff.c:5444
+msgid "use <regex> to decide what a word is"
+msgstr "РЕГУЛЯРЕН_ИЗРАЗ за разделяне по думи"
+
+#: diff.c:5447
+msgid "equivalent to --word-diff=color --word-diff-regex=<regex>"
+msgstr "псевдоним на „--word-diff=color --word-diff-regex=РЕГУЛЯРЕН_ИЗРАЗ“"
+
+#: diff.c:5450
+msgid "moved lines of code are colored differently"
+msgstr "различен цвят за извеждане на преместените редове"
+
+#: diff.c:5453
+msgid "how white spaces are ignored in --color-moved"
 msgstr ""
-"ПРЕДУПРЕЖДЕНИЕ: Пробвахте да изпълните команда на Git на име „%s“, а такава "
-"не съществува."
+"режим за прескачането на празните знаци при задаването на „--color-moved“"
 
-#: help.c:553
-#, c-format
-msgid "Continuing under the assumption that you meant '%s'."
+#: diff.c:5456
+msgid "Other diff options"
+msgstr "Други опции за разлики"
+
+#: diff.c:5458
+msgid "when run from subdir, exclude changes outside and show relative paths"
 msgstr ""
-"Изпълнението автоматично продължава, като се счита, че имате предвид „%s“."
+"при изпълнение от поддиректория да се пренебрегват разликите извън нея и да "
+"се ползват относителни пътища"
 
-#: help.c:558
-#, c-format
-msgid "Continuing in %0.1f seconds, assuming that you meant '%s'."
+#: diff.c:5462
+msgid "treat all files as text"
+msgstr "обработка на всички файлове като текстови"
+
+#: diff.c:5464
+msgid "swap two inputs, reverse the diff"
+msgstr "размяна на двата входа — обръщане на разликата"
+
+#: diff.c:5466
+msgid "exit with 1 if there were differences, 0 otherwise"
 msgstr ""
-"Изпълнението автоматично ще продължи след %0.1f сек., като се счита, че "
-"имате предвид „%s“."
+"завършване с код за състояние 1 при наличието на разлики, а в противен "
+"случай — с 0"
 
-#: help.c:566
-#, c-format
-msgid "git: '%s' is not a git command. See 'git --help'."
-msgstr "git: „%s“ не е команда на git.  Погледнете изхода от „git --help“."
+#: diff.c:5468
+msgid "disable all output of the program"
+msgstr "без всякакъв изход от програмата"
 
-#: help.c:570
-msgid ""
-"\n"
-"The most similar command is"
-msgid_plural ""
-"\n"
-"The most similar commands are"
-msgstr[0] ""
-"\n"
-"Най-близката команда е"
-msgstr[1] ""
-"\n"
-"Най-близките команди са"
+#: diff.c:5470
+msgid "allow an external diff helper to be executed"
+msgstr "позволяване на изпълнение на външна помощна програма за разлики"
 
-#: help.c:585
-msgid "git version [<options>]"
-msgstr "git version [ОПЦИЯ…]"
+#: diff.c:5472
+msgid "run external text conversion filters when comparing binary files"
+msgstr ""
+"изпълнение на външни програми-филтри при сравнението на двоични файлове"
 
-#: help.c:652
-#, c-format
-msgid "%s: %s - %s"
-msgstr "%s: %s — %s"
+#: diff.c:5474
+msgid "<when>"
+msgstr "КОГА"
+
+#: diff.c:5475
+msgid "ignore changes to submodules in the diff generation"
+msgstr "игнориране на промените в подмодулите при извеждането на разликите"
+
+#: diff.c:5478
+msgid "<format>"
+msgstr "ФОРМАТ"
 
-#: help.c:656
+#: diff.c:5479
+msgid "specify how differences in submodules are shown"
+msgstr "начин за извеждане на промените в подмодулите"
+
+#: diff.c:5483
+msgid "hide 'git add -N' entries from the index"
+msgstr "без включване в индекса на записите, добавени с „git add -N“"
+
+#: diff.c:5486
+msgid "treat 'git add -N' entries as real in the index"
+msgstr "включване в индекса на записите, добавени с „git add -N“"
+
+#: diff.c:5488
+msgid "<string>"
+msgstr "НИЗ"
+
+#: diff.c:5489
 msgid ""
-"\n"
-"Did you mean this?"
-msgid_plural ""
-"\n"
-"Did you mean one of these?"
-msgstr[0] ""
-"\n"
-"Команда с подобно име е:"
-msgstr[1] ""
-"\n"
-"Команди с подобно име са:"
+"look for differences that change the number of occurrences of the specified "
+"string"
+msgstr "търсене на разлики, които променят броя на поява на указаните низове"
 
-#: ident.c:342
+#: diff.c:5492
 msgid ""
-"\n"
-"*** Please tell me who you are.\n"
-"\n"
-"Run\n"
-"\n"
-"  git config --global user.email \"you@example.com\"\n"
-"  git config --global user.name \"Your Name\"\n"
-"\n"
-"to set your account's default identity.\n"
-"Omit --global to set the identity only in this repository.\n"
-"\n"
+"look for differences that change the number of occurrences of the specified "
+"regex"
 msgstr ""
-"\n"
-"●●● Въведете самоличност.\n"
-"\n"
-"Изпълнете:\n"
-"\n"
-"  git config --global user.email \"ИМЕ@example.com\"\n"
-"  git config --global user.name \"ВАШЕТО ИМЕ\"\n"
-"\n"
-"и въведете данни за себе си.\n"
-"Ако пропуснете опцията „--global“, самоличността е само за текущото "
-"хранилище.\n"
-"\n"
+"търсене на разлики, които променят броя на поява на низовете, които напасват "
+"на регулярния израз"
 
-#: ident.c:366
-msgid "no email was given and auto-detection is disabled"
-msgstr "липсва адрес за е-поща, а автоматичното отгатване е изключено"
+#: diff.c:5495
+msgid "show all changes in the changeset with -S or -G"
+msgstr "извеждане на всички промени с „-G“/„-S“"
 
-#: ident.c:371
-#, c-format
-msgid "unable to auto-detect email address (got '%s')"
-msgstr ""
-"адресът за е-поща не може да бъде отгатнат (най-доброто предположение бе "
-"„%s“)"
+#: diff.c:5498
+msgid "treat <string> in -S as extended POSIX regular expression"
+msgstr "НИЗът към „-S“ да се тълкува като разширен регулярен израз по POSIX"
 
-#: ident.c:381
-msgid "no name was given and auto-detection is disabled"
-msgstr "липсва име, а автоматичното отгатване е изключено"
+#: diff.c:5501
+msgid "control the order in which files appear in the output"
+msgstr "управление на подредбата на файловете в изхода"
 
-#: ident.c:387
-#, c-format
-msgid "unable to auto-detect name (got '%s')"
-msgstr "името не може да бъде отгатнато (най-доброто предположение бе „%s“)"
+#: diff.c:5502
+msgid "<object-id>"
+msgstr "ИДЕНТИФИКАТОР_НА_ОБЕКТ"
 
-#: ident.c:395
-#, c-format
-msgid "empty ident name (for <%s>) not allowed"
-msgstr "не може да се ползва празно име като идентификатор (за <%s>)"
+#: diff.c:5503
+msgid ""
+"look for differences that change the number of occurrences of the specified "
+"object"
+msgstr "търсене на разлики, които променят броя на поява на указания обект"
+
+#: diff.c:5505
+msgid "[(A|C|D|M|R|T|U|X|B)...[*]]"
+msgstr "[(A|C|D|M|R|T|U|X|B)…[*]]"
 
-#: ident.c:401
-#, c-format
-msgid "name consists only of disallowed characters: %s"
-msgstr "името съдържа само непозволени знаци: „%s“"
+#: diff.c:5506
+msgid "select files by diff type"
+msgstr "избор на файловете по вид разлика"
 
-#: ident.c:416 builtin/commit.c:587
-#, c-format
-msgid "invalid date format: %s"
-msgstr "неправилен формат на дата: %s"
+#: diff.c:5508
+msgid "<file>"
+msgstr "ФАЙЛ"
 
-#: list-objects-filter-options.c:36
-msgid "multiple filter-specs cannot be combined"
-msgstr "не може да комбинирате множество филтри"
+#: diff.c:5509
+msgid "Output to a specific file"
+msgstr "Изход към указания файл"
 
-#: list-objects-filter-options.c:126
-msgid "cannot change partial clone promisor remote"
-msgstr "не може да промените хранилището-гарант на непълно хранилище"
+#: diff.c:6164
+msgid "inexact rename detection was skipped due to too many files."
+msgstr ""
+"търсенето на преименувания на обекти съчетани с промени се прескача поради "
+"многото файлове."
 
-#: lockfile.c:151
-#, c-format
-msgid ""
-"Unable to create '%s.lock': %s.\n"
-"\n"
-"Another git process seems to be running in this repository, e.g.\n"
-"an editor opened by 'git commit'. Please make sure all processes\n"
-"are terminated then try again. If it still fails, a git process\n"
-"may have crashed in this repository earlier:\n"
-"remove the file manually to continue."
+#: diff.c:6167
+msgid "only found copies from modified paths due to too many files."
 msgstr ""
-"Файлът-ключалка „%s.lock“ не може да бъде създаден: %s\n"
-"\n"
-"Изглежда, че и друг процес на git е пуснат в това хранилище, напр.\n"
-"редактор, стартиран с „git commit“.  Уверете се, че всички подобни\n"
-"процеси са спрени и опитайте отново.  Ако това не помогне, вероятната\n"
-"причина е, че някой процес на git в това хранилище е забил.  За да\n"
-"продължите работа, ще трябва ръчно да изтриете файла:"
+"установени са само точните копия на променените пътища поради многото "
+"файлове."
 
-#: lockfile.c:159
+#: diff.c:6170
 #, c-format
-msgid "Unable to create '%s.lock': %s"
-msgstr "Файлът-ключалка „%s.lock“ не може да бъде създаден: %s"
-
-#: merge.c:71
-msgid "failed to read the cache"
-msgstr "кешът не може да бъде прочетен"
+msgid ""
+"you may want to set your %s variable to at least %d and retry the command."
+msgstr "задайте променливата „%s“ да е поне %d и отново изпълнете командата."
 
-#: merge.c:136 builtin/am.c:1946 builtin/am.c:1980 builtin/checkout.c:378
-#: builtin/checkout.c:606 builtin/clone.c:761
-msgid "unable to write new index file"
-msgstr "неуспешно записване на новия индекс"
+#: dir.c:554
+#, c-format
+msgid "pathspec '%s' did not match any file(s) known to git"
+msgstr "пътят „%s“ не съвпада с никой файл в git"
 
-#: merge-recursive.c:298
-msgid "(bad commit)\n"
-msgstr "(лошо подаване)\n"
+#: dir.c:664
+#, c-format
+msgid "unrecognized pattern: '%s'"
+msgstr "непознат шаблон: „%s“"
 
-#: merge-recursive.c:320
+#: dir.c:682 dir.c:696
 #, c-format
-msgid "add_cacheinfo failed for path '%s'; merge aborting."
-msgstr ""
-"неуспешно изпълнение на „add_cacheinfo“ за пътя „%s“.  Сливането е "
-"преустановено."
+msgid "unrecognized negative pattern: '%s'"
+msgstr "непознат отрицателен шаблон: „%s“"
 
-#: merge-recursive.c:328
+#: dir.c:714
 #, c-format
-msgid "add_cacheinfo failed to refresh for path '%s'; merge aborting."
+msgid "your sparse-checkout file may have issues: pattern '%s' is repeated"
 msgstr ""
-"неуспешно изпълнение на „add_cacheinfo“ за обновяването на пътя „%s“.  "
-"Сливането е преустановено."
+"файлът определящ частичността на изтегленото хранилище може да има проблем: "
+"шаблонът „%s“ се повтаря"
 
-#: merge-recursive.c:410
-msgid "error building trees"
-msgstr "грешка при изграждане на дърветата"
+#: dir.c:724
+msgid "disabling cone pattern matching"
+msgstr "изключване на пътеводното напасване"
 
-#: merge-recursive.c:881
+#: dir.c:1101
 #, c-format
-msgid "failed to create path '%s'%s"
-msgstr "грешка при създаването на пътя „%s“%s"
+msgid "cannot use %s as an exclude file"
+msgstr "„%s“ не може да се ползва за игнорираните файлове (като gitignore)"
 
-#: merge-recursive.c:892
+#: dir.c:2078
 #, c-format
-msgid "Removing %s to make room for subdirectory\n"
-msgstr "Изтриване на „%s“, за да се освободи място за поддиректория\n"
+msgid "could not open directory '%s'"
+msgstr "директорията „%s“ не може да бъде отворена"
 
-#: merge-recursive.c:906 merge-recursive.c:925
-msgid ": perhaps a D/F conflict?"
-msgstr ": възможно е да има конфликт директория/файл."
+#: dir.c:2415
+msgid "failed to get kernel name and information"
+msgstr "името и версията на ядрото не бяха получени"
 
-#: merge-recursive.c:915
-#, c-format
-msgid "refusing to lose untracked file at '%s'"
+#: dir.c:2539
+msgid "untracked cache is disabled on this system or location"
 msgstr ""
-"преустановяване на действието, за да не се изтрие неследеният файл „%s“"
+"кешът за неследените файлове е изключен на тази система или местоположение"
 
-#: merge-recursive.c:957 builtin/cat-file.c:37
+#: dir.c:3343
 #, c-format
-msgid "cannot read object %s '%s'"
-msgstr "обектът „%s“ (%s) не може да бъде прочетен"
+msgid "index file corrupt in repo %s"
+msgstr "файлът с индекса е повреден в хранилището „%s“"
 
-#: merge-recursive.c:959
+#: dir.c:3388 dir.c:3393
 #, c-format
-msgid "blob expected for %s '%s'"
-msgstr "обектът „%s“ (%s) се очакваше да е BLOB, а не е"
+msgid "could not create directories for %s"
+msgstr "директориите за „%s“ не може да бъдат създадени"
 
-#: merge-recursive.c:983
+#: dir.c:3422
 #, c-format
-msgid "failed to open '%s': %s"
-msgstr "„%s“ не може да се отвори: %s"
+msgid "could not migrate git directory from '%s' to '%s'"
+msgstr "директорията на git не може да се мигрира от „%s“ до „%s“"
 
-#: merge-recursive.c:994
+#: editor.c:73
 #, c-format
-msgid "failed to symlink '%s': %s"
-msgstr "неуспешно създаване на символната връзка „%s“: %s"
+msgid "hint: Waiting for your editor to close the file...%c"
+msgstr "Подсказка: чака се редакторът ви да затвори файла …%c"
 
-#: merge-recursive.c:999
-#, c-format
-msgid "do not know what to do with %06o %s '%s'"
-msgstr ""
-"не е ясно какво да се прави с обекта „%2$s“ (%3$s) с права за достъп „%1$06o“"
+#: entry.c:178
+msgid "Filtering content"
+msgstr "Филтриране на съдържанието"
 
-#: merge-recursive.c:1186
+#: entry.c:476
 #, c-format
-msgid "Failed to merge submodule %s (not checked out)"
-msgstr "Неуспешно сливане на подмодула „%s“ (не е изтеглен)"
+msgid "could not stat file '%s'"
+msgstr "неуспешно изпълнение на „stat“ върху файла „%s“"
 
-#: merge-recursive.c:1193
+#: environment.c:149
 #, c-format
-msgid "Failed to merge submodule %s (commits not present)"
-msgstr "Неуспешно сливане на подмодула „%s“ (няма подавания)"
+msgid "bad git namespace path \"%s\""
+msgstr "неправилен път към пространства от имена „%s“"
 
-#: merge-recursive.c:1200
+#: environment.c:331
 #, c-format
-msgid "Failed to merge submodule %s (commits don't follow merge-base)"
-msgstr ""
-"Подмодулът „%s“ не може да бъде слят (базата за сливане не предшества "
-"подаванията)"
+msgid "could not set GIT_DIR to '%s'"
+msgstr "GIT_DIR не може да се зададе да е „%s“"
 
-#: merge-recursive.c:1208 merge-recursive.c:1220
+#: exec-cmd.c:363
 #, c-format
-msgid "Fast-forwarding submodule %s to the following commit:"
-msgstr "Превъртане на подмодула „%s“ до следното подаване:"
+msgid "too many args to run %s"
+msgstr "прекалено много аргументи за изпълнение „%s“"
 
-#: merge-recursive.c:1211 merge-recursive.c:1223
-#, c-format
-msgid "Fast-forwarding submodule %s"
-msgstr "Превъртане на подмодула „%s“"
+#: fetch-pack.c:150
+msgid "git fetch-pack: expected shallow list"
+msgstr "git fetch-pack: очаква се плитък списък"
 
-#: merge-recursive.c:1245
-#, c-format
-msgid "Failed to merge submodule %s (merge following commits not found)"
+#: fetch-pack.c:153
+msgid "git fetch-pack: expected a flush packet after shallow list"
+msgstr "git fetch-pack: след плитък списък се очаква изчистващ пакет „flush“"
+
+#: fetch-pack.c:164
+msgid "git fetch-pack: expected ACK/NAK, got a flush packet"
 msgstr ""
-"Неуспешно сливане на подмодула „%s“ (липсва сливането, което се предшества "
-"от подаванията)"
+"git fetch-pack: очаква се „ACK“/„NAK“, а бе получен изчистващ пакет „flush“"
 
-#: merge-recursive.c:1249
+#: fetch-pack.c:184
 #, c-format
-msgid "Failed to merge submodule %s (not fast-forward)"
-msgstr "Неуспешно сливане на подмодула „%s“ (не е превъртане)"
+msgid "git fetch-pack: expected ACK/NAK, got '%s'"
+msgstr "git fetch-pack: очаква се „ACK“/„NAK“, а бе получено „%s“"
 
-#: merge-recursive.c:1250
-msgid "Found a possible merge resolution for the submodule:\n"
-msgstr ""
-"Открито е сливане, което може да решава проблема със сливането на "
-"подмодула:\n"
+#: fetch-pack.c:195
+msgid "unable to write to remote"
+msgstr "невъзможно писане към отдалечено хранилище"
 
-#: merge-recursive.c:1253
-#, c-format
-msgid ""
-"If this is correct simply add it to the index for example\n"
-"by using:\n"
-"\n"
-"  git update-index --cacheinfo 160000 %s \"%s\"\n"
-"\n"
-"which will accept this suggestion.\n"
-msgstr ""
-"Ако това е така, добавете го към индекса с команда като следната:\n"
-"\n"
-"    git update-index --cacheinfo 160000 %s \"%s\"\n"
-"\n"
-"Това приема предложеното.\n"
+#: fetch-pack.c:257
+msgid "--stateless-rpc requires multi_ack_detailed"
+msgstr "опцията „--stateless-rpc“ изисква  „multi_ack_detailed“"
 
-#: merge-recursive.c:1262
+#: fetch-pack.c:356 fetch-pack.c:1340
 #, c-format
-msgid "Failed to merge submodule %s (multiple merges found)"
-msgstr "Неуспешно сливане на подмодула „%s“ (открити са множество сливания)"
-
-#: merge-recursive.c:1321
-msgid "Failed to execute internal merge"
-msgstr "Неуспешно вътрешно сливане"
+msgid "invalid shallow line: %s"
+msgstr "неправилен плитък ред: „%s“"
 
-#: merge-recursive.c:1326
+#: fetch-pack.c:362 fetch-pack.c:1346
 #, c-format
-msgid "Unable to add %s to database"
-msgstr "„%s“ не може да се добави в базата с данни"
+msgid "invalid unshallow line: %s"
+msgstr "неправилен неплитък ред: „%s“"
 
-#: merge-recursive.c:1358
+#: fetch-pack.c:364 fetch-pack.c:1348
 #, c-format
-msgid "Auto-merging %s"
-msgstr "Автоматично сливане на „%s“"
+msgid "object not found: %s"
+msgstr "обектът „%s“ липсва"
 
-#: merge-recursive.c:1423
+#: fetch-pack.c:367 fetch-pack.c:1351
 #, c-format
-msgid "Error: Refusing to lose untracked file at %s; writing to %s instead."
-msgstr "Грешка: за да не се изтрие неследеният файл „%s“, се записва в „%s“."
+msgid "error in object: %s"
+msgstr "грешка в обекта: „%s“"
 
-#: merge-recursive.c:1475
+#: fetch-pack.c:369 fetch-pack.c:1353
 #, c-format
-msgid ""
-"CONFLICT (%s/delete): %s deleted in %s and %s in %s. Version %s of %s left "
-"in tree."
-msgstr ""
-"КОНФЛИКТ (%s/изтриване): „%s“ е изтрит в %s, а „%s“ в %s.  Версия %s на „%s“ "
-"е оставена в дървото."
+msgid "no shallow found: %s"
+msgstr "не е открит плитък обект: %s"
 
-#: merge-recursive.c:1480
+#: fetch-pack.c:372 fetch-pack.c:1357
 #, c-format
-msgid ""
-"CONFLICT (%s/delete): %s deleted in %s and %s to %s in %s. Version %s of %s "
-"left in tree."
-msgstr ""
-"КОНФЛИКТ (%s/изтриване): „%s“ е изтрит в %s, а „%s“ е преименуван на „%s“ в "
-"%s.  Версия %s на „%s“ е оставена в дървото."
+msgid "expected shallow/unshallow, got %s"
+msgstr "очаква се плитък или не обект, а бе получено: „%s“"
 
-#: merge-recursive.c:1487
+#: fetch-pack.c:414
 #, c-format
-msgid ""
-"CONFLICT (%s/delete): %s deleted in %s and %s in %s. Version %s of %s left "
-"in tree at %s."
-msgstr ""
-"КОНФЛИКТ (%s/изтриване): „%s“ е изтрит в %s, а „%s“ в %s.  Версия %s на „%s“ "
-"е оставена в дървото: %s."
+msgid "got %s %d %s"
+msgstr "получено бе %s %d %s"
 
-#: merge-recursive.c:1492
+#: fetch-pack.c:431
 #, c-format
-msgid ""
-"CONFLICT (%s/delete): %s deleted in %s and %s to %s in %s. Version %s of %s "
-"left in tree at %s."
-msgstr ""
-"КОНФЛИКТ (%s/изтриване): „%s“ е изтрит в %s, а „%s“ е преименуван на „%s“ в "
-"%s.  Версия %s на „%s“ е оставена в дървото: %s."
+msgid "invalid commit %s"
+msgstr "неправилно подаване: „%s“"
 
-#: merge-recursive.c:1526
-msgid "rename"
-msgstr "преименуване"
+#: fetch-pack.c:462
+msgid "giving up"
+msgstr "преустановяване"
 
-#: merge-recursive.c:1526
-msgid "renamed"
-msgstr "преименуван"
+#: fetch-pack.c:475 progress.c:323
+msgid "done"
+msgstr "действието завърши"
 
-#: merge-recursive.c:1580 merge-recursive.c:1736 merge-recursive.c:2368
-#: merge-recursive.c:3086
+#: fetch-pack.c:487
 #, c-format
-msgid "Refusing to lose dirty file at %s"
-msgstr "Преустановяване на действието, за да не се изгуби промененият „%s“"
+msgid "got %s (%d) %s"
+msgstr "получено бе %s (%d) %s"
 
-#: merge-recursive.c:1594
+#: fetch-pack.c:533
 #, c-format
-msgid "%s is a directory in %s adding as %s instead"
-msgstr "„%s“ е директория в „%s“, затова се добавя като „%s“"
+msgid "Marking %s as complete"
+msgstr "Отбелязване на „%s“ като пълно"
 
-#: merge-recursive.c:1599
+#: fetch-pack.c:754
 #, c-format
-msgid "Refusing to lose untracked file at %s; adding as %s instead"
-msgstr ""
-"Преустановяване на действието, за да не се изгуби неследеният файл „%s“.  "
-"Вместо него се добавя „%s“"
+msgid "already have %s (%s)"
+msgstr "вече има „%s“ (%s)"
 
-#: merge-recursive.c:1625
-#, c-format
-msgid ""
-"CONFLICT (rename/rename): Rename \"%s\"->\"%s\" in branch \"%s\" rename \"%s"
-"\"->\"%s\" in \"%s\"%s"
-msgstr ""
-"КОНФЛИКТ (преименуване/преименуване): „%s“ е преименуван на „%s“ в клон "
-"„%s“, а „%s“ е преименуван на „%s“ в „%s“/%s."
+#: fetch-pack.c:818
+msgid "fetch-pack: unable to fork off sideband demultiplexer"
+msgstr "fetch-pack: не може да се създаде процес за демултиплексора"
 
-#: merge-recursive.c:1630
-msgid " (left unresolved)"
-msgstr " (некоригиран конфликт)"
+#: fetch-pack.c:826
+msgid "protocol error: bad pack header"
+msgstr "протоколна грешка: неправилна заглавна част на пакет"
 
-#: merge-recursive.c:1694
+#: fetch-pack.c:900
 #, c-format
-msgid "CONFLICT (rename/rename): Rename %s->%s in %s. Rename %s->%s in %s"
-msgstr ""
-"КОНФЛИКТ (преименуване/преименуване): „%s“ е преименуван на „%s“ в клон "
-"„%s“, а „%s“ е преименуван на „%s“ в „%s“"
+msgid "fetch-pack: unable to fork off %s"
+msgstr "fetch-pack: не може да се създаде процес за „%s“"
 
-#: merge-recursive.c:1733
+#: fetch-pack.c:916
 #, c-format
-msgid "Renaming %s to %s and %s to %s instead"
-msgstr "Преименуване на „%s“ на „%s“, а „%s“ на „%s“"
+msgid "%s failed"
+msgstr "неуспешно изпълнение на „%s“"
+
+#: fetch-pack.c:918
+msgid "error in sideband demultiplexer"
+msgstr "грешка в демултиплексора"
 
-#: merge-recursive.c:1745
+#: fetch-pack.c:965
 #, c-format
-msgid "Refusing to lose untracked file at %s, even though it's in the way."
-msgstr ""
-"Отказ да се загуби неследеният файл „%s“, защото е на място, където пречи."
+msgid "Server version is %.*s"
+msgstr "Версията на сървъра е: %.*s"
 
-#: merge-recursive.c:1951
+#: fetch-pack.c:970 fetch-pack.c:976 fetch-pack.c:979 fetch-pack.c:985
+#: fetch-pack.c:989 fetch-pack.c:993 fetch-pack.c:997 fetch-pack.c:1001
+#: fetch-pack.c:1005 fetch-pack.c:1009 fetch-pack.c:1013 fetch-pack.c:1017
+#: fetch-pack.c:1023 fetch-pack.c:1029 fetch-pack.c:1034 fetch-pack.c:1039
 #, c-format
-msgid ""
-"CONFLICT (directory rename split): Unclear where to place %s because "
-"directory %s was renamed to multiple other directories, with no destination "
-"getting a majority of the files."
-msgstr ""
-"КОНФЛИКТ (раздвояване при преименуване на директория): Не е ясно къде да се "
-"постави „%s“, защото няколко нови директории поделят съдържанието на "
-"директория „%s“, като никоя не съдържа мнозинство от файловете ѝ."
+msgid "Server supports %s"
+msgstr "Сървърът поддържа „%s“"
+
+#: fetch-pack.c:972
+msgid "Server does not support shallow clients"
+msgstr "Сървърът не поддържа плитки клиенти"
+
+#: fetch-pack.c:1032
+msgid "Server does not support --shallow-since"
+msgstr "Сървърът не поддържа опцията „--shallow-since“"
+
+#: fetch-pack.c:1037
+msgid "Server does not support --shallow-exclude"
+msgstr "Сървърът не поддържа опцията „--shallow-exclude“"
+
+#: fetch-pack.c:1041
+msgid "Server does not support --deepen"
+msgstr "Сървърът не поддържа опцията „--deepen“"
+
+#: fetch-pack.c:1058
+msgid "no common commits"
+msgstr "няма общи подавания"
+
+#: fetch-pack.c:1070 fetch-pack.c:1536
+msgid "git fetch-pack: fetch failed."
+msgstr "git fetch-pack: неуспешно доставяне."
+
+#: fetch-pack.c:1209
+msgid "Server does not support shallow requests"
+msgstr "Сървърът не поддържа плитки заявки"
+
+#: fetch-pack.c:1216
+msgid "Server supports filter"
+msgstr "Сървърът поддържа филтри"
 
-#: merge-recursive.c:1983
+#: fetch-pack.c:1239
+msgid "unable to write request to remote"
+msgstr "невъзможно писане към отдалечено хранилище"
+
+#: fetch-pack.c:1257
 #, c-format
-msgid ""
-"CONFLICT (implicit dir rename): Existing file/dir at %s in the way of "
-"implicit directory rename(s) putting the following path(s) there: %s."
-msgstr ""
-"КОНФЛИКТ (косвено преименуване на директория): следният файл или директория "
-"„%s“ не позволяват косвеното преименуване на следния път/ища: %s."
+msgid "error reading section header '%s'"
+msgstr "грешка при прочитане на заглавната част на раздел „%s“"
 
-#: merge-recursive.c:1993
+#: fetch-pack.c:1263
 #, c-format
-msgid ""
-"CONFLICT (implicit dir rename): Cannot map more than one path to %s; "
-"implicit directory renames tried to put these paths there: %s"
-msgstr ""
-"КОНФЛИКТ (косвено преименуване на директория): повече от един път "
-"съответства на „%s“.  Косвено преименуване на директория води до поставянето "
-"на тези пътища там: %s."
+msgid "expected '%s', received '%s'"
+msgstr "очаква се „%s“, а бе получено „%s“"
 
-#: merge-recursive.c:2085
+#: fetch-pack.c:1303
 #, c-format
-msgid ""
-"CONFLICT (rename/rename): Rename directory %s->%s in %s. Rename directory %s-"
-">%s in %s"
-msgstr ""
-"КОНФЛИКТ (преименуване/преименуване): „%s“ е преименуван на „%s“ в клон "
-"„%s“, а „%s“ е преименуван на „%s“ в „%s“"
+msgid "unexpected acknowledgment line: '%s'"
+msgstr "неочакван ред за потвърждение: „%s“"
 
-#: merge-recursive.c:2330
+#: fetch-pack.c:1308
 #, c-format
-msgid ""
-"WARNING: Avoiding applying %s -> %s rename to %s, because %s itself was "
-"renamed."
+msgid "error processing acks: %d"
+msgstr "грешка при обработка на потвържденията: %d"
+
+#: fetch-pack.c:1318
+msgid "expected packfile to be sent after 'ready'"
 msgstr ""
-"ПРЕДУПРЕЖДЕНИЕ: прескачане на преименуването на „%s“ на „%s“ в „%s“, защото "
-"„%s“ също е с променено име."
+"очакваше се пакетният файл да бъде изпратен след отговор за готовност (ready)"
 
-#: merge-recursive.c:2736
-#, c-format
-msgid "CONFLICT (rename/add): Rename %s->%s in %s. %s added in %s"
+#: fetch-pack.c:1320
+msgid "expected no other sections to be sent after no 'ready'"
 msgstr ""
-"КОНФЛИКТ (преименуване/добавяне): „%s“ е преименуван на „%s“ в клон „%s“, а "
-"„%s“ е добавен в „%s“"
+"очакваше се след липса на отговор за готовност (ready) да не се се пращат "
+"други раздели"
 
-#: merge-recursive.c:2751
+#: fetch-pack.c:1362
 #, c-format
-msgid "Adding merged %s"
-msgstr "Добавяне на слетия „%s“"
+msgid "error processing shallow info: %d"
+msgstr "грешка при обработка на информация за дълбочината/плиткостта: %d"
 
-#: merge-recursive.c:2758 merge-recursive.c:3089
+#: fetch-pack.c:1409
 #, c-format
-msgid "Adding as %s instead"
-msgstr "Добавяне като „%s“"
+msgid "expected wanted-ref, got '%s'"
+msgstr "очаква се искан указател, а бе получено: „%s“"
 
-#: merge-recursive.c:2914
+#: fetch-pack.c:1414
 #, c-format
-msgid "cannot read object %s"
-msgstr "обектът „%s“ не може да се прочете"
+msgid "unexpected wanted-ref: '%s'"
+msgstr "неочакван искан указател: „%s“"
 
-#: merge-recursive.c:2917
+#: fetch-pack.c:1419
 #, c-format
-msgid "object %s is not a blob"
-msgstr "обектът „%s“ не е BLOB"
-
-#: merge-recursive.c:2986
-msgid "modify"
-msgstr "промяна"
+msgid "error processing wanted refs: %d"
+msgstr "грешка при обработката на исканите указатели: %d"
 
-#: merge-recursive.c:2986
-msgid "modified"
-msgstr "променен"
+#: fetch-pack.c:1762
+msgid "no matching remote head"
+msgstr "не може да бъде открит подходящ връх от отдалеченото хранилище"
 
-#: merge-recursive.c:2997
-msgid "content"
-msgstr "съдържание"
+#: fetch-pack.c:1785 builtin/clone.c:688
+msgid "remote did not send all necessary objects"
+msgstr "отдалеченото хранилище не изпрати всички необходими обекти."
 
-#: merge-recursive.c:3004
-msgid "add/add"
-msgstr "добавяне/добавяне"
+#: fetch-pack.c:1812
+#, c-format
+msgid "no such remote ref %s"
+msgstr "такъв отдалечен указател няма: %s"
 
-#: merge-recursive.c:3046
+#: fetch-pack.c:1815
 #, c-format
-msgid "Skipped %s (merged same as existing)"
-msgstr "Прескачане на „%s“ (слетият резултат е идентичен със сегашния)"
+msgid "Server does not allow request for unadvertised object %s"
+msgstr "Сървърът не позволява заявка за необявен обект „%s“"
 
-#: merge-recursive.c:3055 git-submodule.sh:895
-msgid "submodule"
-msgstr "ПОДМОДУЛ"
+#: gpg-interface.c:223
+msgid "could not create temporary file"
+msgstr "не може да се създаде временен файл"
 
-#: merge-recursive.c:3056
+#: gpg-interface.c:226
 #, c-format
-msgid "CONFLICT (%s): Merge conflict in %s"
-msgstr "КОНФЛИКТ (%s): Конфликт при сливане на „%s“"
+msgid "failed writing detached signature to '%s'"
+msgstr "Програмата не успя да запише самостоятелния подпис в „%s“"
 
-#: merge-recursive.c:3178
-#, c-format
-msgid "Removing %s"
-msgstr "Изтриване на „%s“"
+#: gpg-interface.c:390
+msgid "gpg failed to sign the data"
+msgstr "Програмата „gpg“ не подписа данните."
 
-#: merge-recursive.c:3204
-msgid "file/directory"
-msgstr "файл/директория"
+#: graph.c:98
+#, c-format
+msgid "ignore invalid color '%.*s' in log.graphColors"
+msgstr "прескачане на неправилния цвят „%.*s“ в „log.graphColors“"
 
-#: merge-recursive.c:3210
-msgid "directory/file"
-msgstr "директория/файл"
+#: grep.c:668
+msgid ""
+"given pattern contains NULL byte (via -f <file>). This is only supported "
+"with -P under PCRE v2"
+msgstr ""
+"зададеният шаблон съдържа нулев знак (идва от -f „ФАЙЛ“).  Това се поддържа "
+"в комбинация с „-P“ само при ползването на „PCRE v2“"
 
-#: merge-recursive.c:3217
+#: grep.c:2124
 #, c-format
-msgid "CONFLICT (%s): There is a directory with name %s in %s. Adding %s as %s"
-msgstr ""
-"КОНФЛИКТ (%s): Съществува директория на име „%s“ в „%s“.  Добавяне на „%s“ "
-"като „%s“"
+msgid "'%s': unable to read %s"
+msgstr "„%s“: файлът сочен от „%s“ не може да бъде прочетен"
 
-#: merge-recursive.c:3226
+#: grep.c:2141 setup.c:165 builtin/clone.c:411 builtin/diff.c:82
+#: builtin/rm.c:135
 #, c-format
-msgid "Adding %s"
-msgstr "Добавяне на „%s“"
+msgid "failed to stat '%s'"
+msgstr "не може да бъде получена информация чрез „stat“ за „%s“"
 
-#: merge-recursive.c:3267
+#: grep.c:2152
 #, c-format
-msgid "Dirty index: cannot merge (dirty: %s)"
-msgstr ""
-"Индексът не е чист: кръпките не могат да бъдат приложени (замърсени са: %s)"
+msgid "'%s': short read"
+msgstr "„%s“: изчитането върна по-малко байтове от очакваното"
 
-#: merge-recursive.c:3271
-msgid "Already up to date!"
-msgstr "Вече е обновено!"
+#: help.c:23
+msgid "start a working area (see also: git help tutorial)"
+msgstr "създаване на работно дърво (погледнете: „git help tutorial“)"
 
-#: merge-recursive.c:3280
-#, c-format
-msgid "merging of trees %s and %s failed"
-msgstr "неуспешно сливане на дърветата „%s“ и „%s“"
+#: help.c:24
+msgid "work on the current change (see also: git help everyday)"
+msgstr "работа по текущата промяна (погледнете: „git help everyday“)"
 
-#: merge-recursive.c:3379
-msgid "Merging:"
-msgstr "Сливане:"
+#: help.c:25
+msgid "examine the history and state (see also: git help revisions)"
+msgstr "преглед на историята и състоянието (погледнете: „git help revisions“)"
+
+#: help.c:26
+msgid "grow, mark and tweak your common history"
+msgstr "увеличаване, отбелязване и промяна на общата история"
+
+#: help.c:27
+msgid "collaborate (see also: git help workflows)"
+msgstr "съвместна работа (погледнете: „git help workflows“)"
+
+#: help.c:31
+msgid "Main Porcelain Commands"
+msgstr "Основни команди от потребителско ниво"
 
-#: merge-recursive.c:3392
+#: help.c:32
+msgid "Ancillary Commands / Manipulators"
+msgstr "Помощни команди / Променящи"
+
+#: help.c:33
+msgid "Ancillary Commands / Interrogators"
+msgstr "Помощни команди / Запитващи"
+
+#: help.c:34
+msgid "Interacting with Others"
+msgstr "Съвместна работа с други хора"
+
+#: help.c:35
+msgid "Low-level Commands / Manipulators"
+msgstr "Команди от ниско ниво / Променящи"
+
+#: help.c:36
+msgid "Low-level Commands / Interrogators"
+msgstr "Команди от ниско ниво / Запитващи"
+
+#: help.c:37
+msgid "Low-level Commands / Syncing Repositories"
+msgstr "Команди от ниско ниво / Синхронизация на хранилища"
+
+#: help.c:38
+msgid "Low-level Commands / Internal Helpers"
+msgstr "Команди от ниско ниво / Допълнителни инструменти"
+
+#: help.c:298
 #, c-format
-msgid "found %u common ancestor:"
-msgid_plural "found %u common ancestors:"
-msgstr[0] "открит е %u общ предшественик:"
-msgstr[1] "открити са %u общи предшественици:"
+msgid "available git commands in '%s'"
+msgstr "налични команди на git от „%s“"
 
-#: merge-recursive.c:3431
-msgid "merge returned no commit"
-msgstr "сливането не върна подаване"
+#: help.c:305
+msgid "git commands available from elsewhere on your $PATH"
+msgstr "команди на git от други директории от „$PATH“"
+
+#: help.c:314
+msgid "These are common Git commands used in various situations:"
+msgstr "Това са най-често използваните команди на Git:"
 
-#: merge-recursive.c:3495
+#: help.c:363 git.c:98
 #, c-format
-msgid "Could not parse object '%s'"
-msgstr "Неуспешен анализ на обекта „%s“"
+msgid "unsupported command listing type '%s'"
+msgstr "неподдържан списък от команди „%s“"
 
-#: merge-recursive.c:3511 builtin/merge.c:659 builtin/merge.c:816
-msgid "Unable to write index."
-msgstr "Индексът не може да бъде прочетен"
+#: help.c:403
+msgid "The common Git guides are:"
+msgstr "Популярните въведения в Git са:"
 
-#: notes-merge.c:272
+#: help.c:512
+msgid "See 'git help <command>' to read about a specific subcommand"
+msgstr "За повече информация за КОМАНДА изпълнете „git help КОМАНДА“"
+
+#: help.c:517
+msgid "External commands"
+msgstr "Външни команди"
+
+#: help.c:532
+msgid "Command aliases"
+msgstr "Псевдоними на командите"
+
+#: help.c:596
 #, c-format
 msgid ""
-"You have not concluded your previous notes merge (%s exists).\n"
-"Please, use 'git notes merge --commit' or 'git notes merge --abort' to "
-"commit/abort the previous merge before you start a new notes merge."
+"'%s' appears to be a git command, but we were not\n"
+"able to execute it. Maybe git-%s is broken?"
 msgstr ""
-"Не сте завършили предишното сливане на бележки.  (Указателят „%s“ "
-"съществува).\n"
-"За да завършите предишното сливане, изпълнете:\n"
-"\n"
-"    git notes merge --commit\n"
-"\n"
-"За да отмените предишното сливане, изпълнете:\n"
-"\n"
-"    git notes merge --abort"
+"Изглежда, че „%s“ е команда на git, но тя не може да\n"
+"бъде изпълнена.  Вероятно пакетът „git-%s“ е повреден."
 
-#: notes-merge.c:279
-#, c-format
-msgid "You have not concluded your notes merge (%s exists)."
-msgstr ""
-"Не сте завършили сливането на бележките.  (Указателят „%s“ съществува)."
+#: help.c:655
+msgid "Uh oh. Your system reports no Git commands at all."
+msgstr "Странно, изглежда, че на системата ви няма нито една команда на git."
 
-#: notes-utils.c:43
-msgid "Cannot commit uninitialized/unreferenced notes tree"
+#: help.c:677
+#, c-format
+msgid "WARNING: You called a Git command named '%s', which does not exist."
 msgstr ""
-"Неинициализирано или нереферирано дърво за бележки не може да бъде подадено"
+"ПРЕДУПРЕЖДЕНИЕ: Пробвахте да изпълните команда на Git на име „%s“, а такава "
+"не съществува."
 
-#: notes-utils.c:102
+#: help.c:682
 #, c-format
-msgid "Bad notes.rewriteMode value: '%s'"
-msgstr "Неправилна стойност за „notes.rewriteMode“: „%s“"
+msgid "Continuing under the assumption that you meant '%s'."
+msgstr ""
+"Изпълнението автоматично продължава, като се счита, че имате предвид „%s“."
 
-#: notes-utils.c:112
+#: help.c:687
 #, c-format
-msgid "Refusing to rewrite notes in %s (outside of refs/notes/)"
+msgid "Continuing in %0.1f seconds, assuming that you meant '%s'."
 msgstr ""
-"Бележките в „%s“ няма да бъдат презаписани, защото са извън „refs/notes/“."
+"Изпълнението автоматично ще продължи след %0.1f сек., като се счита, че "
+"имате предвид „%s“."
 
-#. TRANSLATORS: The first %s is the name of
-#. the environment variable, the second %s is
-#. its value.
-#.
-#: notes-utils.c:142
+#: help.c:695
 #, c-format
-msgid "Bad %s value: '%s'"
-msgstr "Зададена е лоша стойност на променливата „%s“: „%s“"
+msgid "git: '%s' is not a git command. See 'git --help'."
+msgstr "git: „%s“ не е команда на git.  Погледнете изхода от „git --help“."
 
-#: object.c:242
-#, c-format
-msgid "unable to parse object: %s"
-msgstr "обектът „%s“ не може да бъде анализиран"
+#: help.c:699
+msgid ""
+"\n"
+"The most similar command is"
+msgid_plural ""
+"\n"
+"The most similar commands are"
+msgstr[0] ""
+"\n"
+"Най-близката команда е"
+msgstr[1] ""
+"\n"
+"Най-близките команди са"
 
-#: packfile.c:563
-msgid "offset before end of packfile (broken .idx?)"
-msgstr ""
-"отместване преди края на пакетния файл (възможно е индексът да е повреден)"
+#: help.c:714
+msgid "git version [<options>]"
+msgstr "git version [ОПЦИЯ…]"
 
-#: packfile.c:1742
+#: help.c:783
 #, c-format
-msgid "offset before start of pack index for %s (corrupt index?)"
+msgid "%s: %s - %s"
+msgstr "%s: %s — %s"
+
+#: help.c:787
+msgid ""
+"\n"
+"Did you mean this?"
+msgid_plural ""
+"\n"
+"Did you mean one of these?"
+msgstr[0] ""
+"\n"
+"Команда с подобно име е:"
+msgstr[1] ""
+"\n"
+"Команди с подобно име са:"
+
+#: ident.c:349
+msgid ""
+"\n"
+"*** Please tell me who you are.\n"
+"\n"
+"Run\n"
+"\n"
+"  git config --global user.email \"you@example.com\"\n"
+"  git config --global user.name \"Your Name\"\n"
+"\n"
+"to set your account's default identity.\n"
+"Omit --global to set the identity only in this repository.\n"
+"\n"
 msgstr ""
-"отместване преди началото на индекса на пакетния файл „%s“ (възможно е "
-"индексът да е повреден)"
+"\n"
+"●●● Въведете самоличност.\n"
+"\n"
+"Изпълнете:\n"
+"\n"
+"    git config --global user.email \"ИМЕ@example.com\"\n"
+"    git config --global user.name \"ВАШЕТО ИМЕ\"\n"
+"\n"
+"и въведете данни за себе си.\n"
+"Ако пропуснете опцията „--global“, самоличността е само за текущото "
+"хранилище.\n"
+"\n"
+
+#: ident.c:379
+msgid "no email was given and auto-detection is disabled"
+msgstr "липсва адрес за е-поща, а автоматичното отгатване е изключено"
 
-#: packfile.c:1746
+#: ident.c:384
 #, c-format
-msgid "offset beyond end of pack index for %s (truncated index?)"
+msgid "unable to auto-detect email address (got '%s')"
 msgstr ""
-"отместване преди края на индекса на пакетния файл „%s“ (възможно е индексът "
-"да е отрязан)"
+"адресът за е-поща не може да бъде отгатнат (най-доброто предположение бе "
+"„%s“)"
 
-#: parse-options.c:621
-msgid "..."
-msgstr "…"
+#: ident.c:401
+msgid "no name was given and auto-detection is disabled"
+msgstr "липсва име, а автоматичното отгатване е изключено"
 
-#: parse-options.c:640
+#: ident.c:407
 #, c-format
-msgid "usage: %s"
-msgstr "употреба: %s"
+msgid "unable to auto-detect name (got '%s')"
+msgstr "името не може да бъде отгатнато (най-доброто предположение бе „%s“)"
 
-#. TRANSLATORS: the colon here should align with the
-#. one in "usage: %s" translation.
-#.
-#: parse-options.c:646
+#: ident.c:415
 #, c-format
-msgid "   or: %s"
-msgstr "     или: %s"
+msgid "empty ident name (for <%s>) not allowed"
+msgstr "не може да се ползва празно име като идентификатор (за <%s>)"
 
-#: parse-options.c:649
+#: ident.c:421
 #, c-format
-msgid "    %s"
-msgstr "    %s"
-
-#: parse-options.c:688
-msgid "-NUM"
-msgstr "-ЧИСЛО"
+msgid "name consists only of disallowed characters: %s"
+msgstr "името съдържа само непозволени знаци: „%s“"
 
-#: parse-options-cb.c:44
+#: ident.c:436 builtin/commit.c:631
 #, c-format
-msgid "malformed expiration date '%s'"
-msgstr "неправилна дата на срок: „%s“"
+msgid "invalid date format: %s"
+msgstr "неправилен формат на дата: %s"
 
-#: parse-options-cb.c:112
+#: list-objects.c:127
 #, c-format
-msgid "malformed object name '%s'"
-msgstr "неправилно име на обект „%s“"
+msgid "entry '%s' in tree %s has tree mode, but is not a tree"
+msgstr "обект „%s“ в дървото „%s“ е отбелязан като дърво, но не е"
 
-#: path.c:892
+#: list-objects.c:140
 #, c-format
-msgid "Could not make %s writable by group"
-msgstr "Не могат да се дадат права за запис в директорията „%s“ на групата"
-
-#: pathspec.c:129
-msgid "Escape character '\\' not allowed as last character in attr value"
-msgstr ""
-"Екраниращият знак „\\“не може да е последен знак в стойността на атрибут"
-
-#: pathspec.c:147
-msgid "Only one 'attr:' specification is allowed."
-msgstr "Позволено е само едно указване на „attr:“."
-
-#: pathspec.c:150
-msgid "attr spec must not be empty"
-msgstr "„attr:“ трябва да указва стойност"
+msgid "entry '%s' in tree %s has blob mode, but is not a blob"
+msgstr "обект „%s“ в дървото „%s“ е отбелязан като BLOB, но не е"
 
-#: pathspec.c:193
+#: list-objects.c:375
 #, c-format
-msgid "invalid attribute name %s"
-msgstr "неправилно име на атрибут: „%s“"
+msgid "unable to load root tree for commit %s"
+msgstr "кореновото дърво за подаване „%s“ не може да се зареди"
 
-#: pathspec.c:258
-msgid "global 'glob' and 'noglob' pathspec settings are incompatible"
-msgstr "глобалните настройки за пътища „glob“ и „noglob“ са несъвместими"
+#: list-objects-filter.c:492
+#, c-format
+msgid "unable to access sparse blob in '%s'"
+msgstr "няма достъп до частично изтегления обект-BLOB в „%s“"
 
-#: pathspec.c:265
-msgid ""
-"global 'literal' pathspec setting is incompatible with all other global "
-"pathspec settings"
+#: list-objects-filter.c:495
+#, c-format
+msgid "unable to parse sparse filter data in %s"
 msgstr ""
-"глобалната настройка за дословни пътища „literal“ е несъвместима с всички "
-"други глобални настройки за пътища"
+"данните от филтъра за частични изтеглания в „%s“ не може да бъдат анализирани"
 
-#: pathspec.c:305
-msgid "invalid parameter for pathspec magic 'prefix'"
-msgstr "неправилен параметър за опцията за магически пътища „prefix“"
+#: list-objects-filter-options.c:58
+msgid "expected 'tree:<depth>'"
+msgstr "очаква се „tree:ДЪЛБОЧИНА“"
 
-#: pathspec.c:326
-#, c-format
-msgid "Invalid pathspec magic '%.*s' in '%s'"
-msgstr "Неправилна стойност за опцията за магически пътища „%.*s“ в „%s“"
+#: list-objects-filter-options.c:73
+msgid "sparse:path filters support has been dropped"
+msgstr "поддръжката на филтри със „sparse:path“ е премахната"
 
-#: pathspec.c:331
+#: list-objects-filter-options.c:86
 #, c-format
-msgid "Missing ')' at the end of pathspec magic in '%s'"
-msgstr "Знакът „)“ липсва в опцията за магически пътища в „%s“"
+msgid "invalid filter-spec '%s'"
+msgstr "неправилен филтър: „%s“"
 
-#: pathspec.c:369
+#: list-objects-filter-options.c:102
 #, c-format
-msgid "Unimplemented pathspec magic '%c' in '%s'"
-msgstr "Магическите пътища „%c“ са без реализация за „%s“"
+msgid "must escape char in sub-filter-spec: '%c'"
+msgstr "знак за екраниране в подфилтър: „%c“"
 
-#: pathspec.c:428
-#, c-format
-msgid "%s: 'literal' and 'glob' are incompatible"
-msgstr "%s: опциите „literal“ и „glob“ са несъвместими"
+#: list-objects-filter-options.c:144
+msgid "expected something after combine:"
+msgstr "добавете нещо след комбинирането:"
 
-#: pathspec.c:441
-#, c-format
-msgid "%s: '%s' is outside repository"
-msgstr "%s: „%s“ е извън хранилището"
+#: list-objects-filter-options.c:226
+msgid "multiple filter-specs cannot be combined"
+msgstr "не може да комбинирате множество филтри"
 
-#: pathspec.c:515
+#: lockfile.c:151
 #, c-format
-msgid "'%s' (mnemonic: '%c')"
-msgstr "„%s“ (клавиш: „%c“)"
+msgid ""
+"Unable to create '%s.lock': %s.\n"
+"\n"
+"Another git process seems to be running in this repository, e.g.\n"
+"an editor opened by 'git commit'. Please make sure all processes\n"
+"are terminated then try again. If it still fails, a git process\n"
+"may have crashed in this repository earlier:\n"
+"remove the file manually to continue."
+msgstr ""
+"Файлът-ключалка „%s.lock“ не може да бъде създаден: %s\n"
+"\n"
+"Изглежда, че и друг процес на git е пуснат в това хранилище, напр.\n"
+"редактор, стартиран с „git commit“.  Уверете се, че всички подобни\n"
+"процеси са спрени и опитайте отново.  Ако това не помогне, вероятната\n"
+"причина е, че някой процес на git в това хранилище е забил.  За да\n"
+"продължите работа, ще трябва ръчно да изтриете файла:"
 
-#: pathspec.c:525
+#: lockfile.c:159
 #, c-format
-msgid "%s: pathspec magic not supported by this command: %s"
-msgstr "%s: магическите пътища не се поддържат от командата „%s“"
+msgid "Unable to create '%s.lock': %s"
+msgstr "Файлът-ключалка „%s.lock“ не може да бъде създаден: %s"
 
-#: pathspec.c:592
-#, c-format
-msgid "pathspec '%s' is beyond a symbolic link"
-msgstr "пътят „%s“ е след символна връзка"
+#: merge.c:41
+msgid "failed to read the cache"
+msgstr "кешът не може да бъде прочетен"
 
-#: pretty.c:962
-msgid "unable to parse --pretty format"
-msgstr "аргументът към опцията „--pretty“ не може да се анализира"
+#: merge.c:107 rerere.c:720 builtin/am.c:1874 builtin/am.c:1908
+#: builtin/checkout.c:539 builtin/checkout.c:798 builtin/clone.c:809
+#: builtin/stash.c:264
+msgid "unable to write new index file"
+msgstr "неуспешно записване на новия индекс"
+
+#: merge-recursive.c:356
+msgid "(bad commit)\n"
+msgstr "(лошо подаване)\n"
 
-#: read-cache.c:1500
+#: merge-recursive.c:379
 #, c-format
-msgid ""
-"index.version set, but the value is invalid.\n"
-"Using version %i"
+msgid "add_cacheinfo failed for path '%s'; merge aborting."
 msgstr ""
-"Зададена е неправилна стойност на настройката „index.version“.\n"
-"Ще се ползва версия %i"
+"неуспешно изпълнение на „add_cacheinfo“ за пътя „%s“.  Сливането е "
+"преустановено."
 
-#: read-cache.c:1510
+#: merge-recursive.c:388
 #, c-format
-msgid ""
-"GIT_INDEX_VERSION set, but the value is invalid.\n"
-"Using version %i"
+msgid "add_cacheinfo failed to refresh for path '%s'; merge aborting."
 msgstr ""
-"Зададена е неправилна стойност на променливата на средата "
-"„GIT_INDEX_VERSION“.\n"
-"Ще се ползва версия %i"
+"неуспешно изпълнение на „add_cacheinfo“ за обновяването на пътя „%s“.  "
+"Сливането е преустановено."
 
-#: read-cache.c:2404 sequencer.c:4338 wrapper.c:658 builtin/merge.c:1048
+#: merge-recursive.c:874
 #, c-format
-msgid "could not close '%s'"
-msgstr "„%s“ не може да се затвори"
+msgid "failed to create path '%s'%s"
+msgstr "грешка при създаването на пътя „%s“%s"
 
-#: read-cache.c:2477 sequencer.c:2102 sequencer.c:3234
+#: merge-recursive.c:885
 #, c-format
-msgid "could not stat '%s'"
-msgstr "неуспешно изпълнение на „stat“ върху „%s“"
+msgid "Removing %s to make room for subdirectory\n"
+msgstr "Изтриване на „%s“, за да се освободи място за поддиректория\n"
 
-#: read-cache.c:2490
-#, c-format
-msgid "unable to open git dir: %s"
-msgstr "не може да се отвори директорията на git: %s"
+#: merge-recursive.c:899 merge-recursive.c:918
+msgid ": perhaps a D/F conflict?"
+msgstr ": възможно е да има конфликт директория/файл."
 
-#: read-cache.c:2502
+#: merge-recursive.c:908
 #, c-format
-msgid "unable to unlink: %s"
-msgstr "неуспешно изтриване на „%s“"
+msgid "refusing to lose untracked file at '%s'"
+msgstr ""
+"преустановяване на действието, за да не се изтрие неследеният файл „%s“"
 
-#: refs.c:732 sequencer.c:4334 sequencer.c:4393 wrapper.c:225 wrapper.c:395
-#: builtin/am.c:779
+#: merge-recursive.c:949 builtin/cat-file.c:41
 #, c-format
-msgid "could not open '%s' for writing"
-msgstr "„%s“ не може да бъде отворен за запис"
-
-#: refs.c:1880
-msgid "ref updates forbidden inside quarantine environment"
-msgstr "обновяванията на указатели са забранени в среди под карантина"
+msgid "cannot read object %s '%s'"
+msgstr "обектът „%s“ (%s) не може да бъде прочетен"
 
-#: refs/files-backend.c:1191
+#: merge-recursive.c:954
 #, c-format
-msgid "could not remove reference %s"
-msgstr "Указателят „%s“ не може да бъде изтрит"
+msgid "blob expected for %s '%s'"
+msgstr "обектът „%s“ (%s) се очакваше да е BLOB, а не е"
 
-#: refs/files-backend.c:1205 refs/packed-backend.c:1531
-#: refs/packed-backend.c:1541
+#: merge-recursive.c:979
 #, c-format
-msgid "could not delete reference %s: %s"
-msgstr "Указателят „%s“ не може да бъде изтрит: %s"
+msgid "failed to open '%s': %s"
+msgstr "„%s“ не може да се отвори: %s"
 
-#: refs/files-backend.c:1208 refs/packed-backend.c:1544
+#: merge-recursive.c:990
 #, c-format
-msgid "could not delete references: %s"
-msgstr "Указателите не може да бъдат изтрити: %s"
-
-#: ref-filter.c:35 wt-status.c:1850
-msgid "gone"
-msgstr "изтрит"
+msgid "failed to symlink '%s': %s"
+msgstr "неуспешно създаване на символната връзка „%s“: %s"
 
-#: ref-filter.c:36
+#: merge-recursive.c:995
 #, c-format
-msgid "ahead %d"
-msgstr "напред с %d"
+msgid "do not know what to do with %06o %s '%s'"
+msgstr ""
+"не е ясно какво да се прави с обекта „%2$s“ (%3$s) с права за достъп „%1$06o“"
 
-#: ref-filter.c:37
+#: merge-recursive.c:1188
 #, c-format
-msgid "behind %d"
-msgstr "назад с %d"
+msgid "Failed to merge submodule %s (not checked out)"
+msgstr "Неуспешно сливане на подмодула „%s“ (не е изтеглен)"
 
-#: ref-filter.c:38
+#: merge-recursive.c:1195
 #, c-format
-msgid "ahead %d, behind %d"
-msgstr "напред с %d, назад с %d"
+msgid "Failed to merge submodule %s (commits not present)"
+msgstr "Неуспешно сливане на подмодула „%s“ (няма подавания)"
 
-#: ref-filter.c:121
+#: merge-recursive.c:1202
 #, c-format
-msgid "expected format: %%(color:<color>)"
-msgstr "очакван формат: %%(color:ЦВЯТ)"
+msgid "Failed to merge submodule %s (commits don't follow merge-base)"
+msgstr ""
+"Подмодулът „%s“ не може да бъде слят (базата за сливане не предшества "
+"подаванията)"
 
-#: ref-filter.c:123
+#: merge-recursive.c:1210 merge-recursive.c:1222
 #, c-format
-msgid "unrecognized color: %%(color:%s)"
-msgstr "непознат цвят: %%(color:%s)"
+msgid "Fast-forwarding submodule %s to the following commit:"
+msgstr "Превъртане на подмодула „%s“ до следното подаване:"
 
-#: ref-filter.c:145
+#: merge-recursive.c:1213 merge-recursive.c:1225
 #, c-format
-msgid "Integer value expected refname:lstrip=%s"
-msgstr "очаква се цяло число за „refname:lstrip=%s“"
+msgid "Fast-forwarding submodule %s"
+msgstr "Превъртане на подмодула „%s“"
 
-#: ref-filter.c:149
+#: merge-recursive.c:1248
 #, c-format
-msgid "Integer value expected refname:rstrip=%s"
-msgstr "очаква се цяло число за „refname:rstrip=%s“"
+msgid "Failed to merge submodule %s (merge following commits not found)"
+msgstr ""
+"Неуспешно сливане на подмодула „%s“ (липсва сливането, което се предшества "
+"от подаванията)"
 
-#: ref-filter.c:151
+#: merge-recursive.c:1252
 #, c-format
-msgid "unrecognized %%(%s) argument: %s"
-msgstr "непознат аргумент за „%%(%s)“: %s"
+msgid "Failed to merge submodule %s (not fast-forward)"
+msgstr "Неуспешно сливане на подмодула „%s“ (не е превъртане)"
 
-#: ref-filter.c:206
-#, c-format
-msgid "%%(body) does not take arguments"
-msgstr "%%(body) не приема аргументи"
+#: merge-recursive.c:1253
+msgid "Found a possible merge resolution for the submodule:\n"
+msgstr ""
+"Открито е сливане, което може да решава проблема със сливането на "
+"подмодула:\n"
 
-#: ref-filter.c:215
+#: merge-recursive.c:1256
 #, c-format
-msgid "%%(subject) does not take arguments"
-msgstr "%%(subject) не приема аргументи"
+msgid ""
+"If this is correct simply add it to the index for example\n"
+"by using:\n"
+"\n"
+"  git update-index --cacheinfo 160000 %s \"%s\"\n"
+"\n"
+"which will accept this suggestion.\n"
+msgstr ""
+"Ако това е така, добавете го към индекса с команда като следната:\n"
+"\n"
+"    git update-index --cacheinfo 160000 %s \"%s\"\n"
+"\n"
+"Това приема предложеното.\n"
 
-#: ref-filter.c:235
+#: merge-recursive.c:1265
 #, c-format
-msgid "unknown %%(trailers) argument: %s"
-msgstr "непознат аргумент „%%(trailers)“: %s"
+msgid "Failed to merge submodule %s (multiple merges found)"
+msgstr "Неуспешно сливане на подмодула „%s“ (открити са множество сливания)"
 
-#: ref-filter.c:264
-#, c-format
-msgid "positive value expected contents:lines=%s"
-msgstr "очаква се положителна стойност за „contents:lines=%s“"
+#: merge-recursive.c:1338
+msgid "Failed to execute internal merge"
+msgstr "Неуспешно вътрешно сливане"
 
-#: ref-filter.c:266
+#: merge-recursive.c:1343
 #, c-format
-msgid "unrecognized %%(contents) argument: %s"
-msgstr "непознат аргумент за %%(contents): %s"
+msgid "Unable to add %s to database"
+msgstr "„%s“ не може да се добави в базата с данни"
 
-#: ref-filter.c:281
+#: merge-recursive.c:1375
 #, c-format
-msgid "positive value expected objectname:short=%s"
-msgstr "очаква се положителна стойност за „objectname:short=%s“"
+msgid "Auto-merging %s"
+msgstr "Автоматично сливане на „%s“"
 
-#: ref-filter.c:285
+#: merge-recursive.c:1399
 #, c-format
-msgid "unrecognized %%(objectname) argument: %s"
-msgstr "непознат аргумент за %%(objectname): %s"
+msgid "Error: Refusing to lose untracked file at %s; writing to %s instead."
+msgstr "Грешка: за да не се изтрие неследеният файл „%s“, се записва в „%s“."
 
-#: ref-filter.c:315
+#: merge-recursive.c:1471
 #, c-format
-msgid "expected format: %%(align:<width>,<position>)"
-msgstr "очакван формат: %%(align:ШИРОЧИНА,ПОЗИЦИЯ)"
+msgid ""
+"CONFLICT (%s/delete): %s deleted in %s and %s in %s. Version %s of %s left "
+"in tree."
+msgstr ""
+"КОНФЛИКТ (%s/изтриване): „%s“ е изтрит в %s, а „%s“ в %s.  Версия %s на „%s“ "
+"е оставена в дървото."
 
-#: ref-filter.c:327
+#: merge-recursive.c:1476
 #, c-format
-msgid "unrecognized position:%s"
-msgstr "непозната позиция: %s"
+msgid ""
+"CONFLICT (%s/delete): %s deleted in %s and %s to %s in %s. Version %s of %s "
+"left in tree."
+msgstr ""
+"КОНФЛИКТ (%s/изтриване): „%s“ е изтрит в %s, а „%s“ е преименуван на „%s“ в "
+"%s.  Версия %s на „%s“ е оставена в дървото."
 
-#: ref-filter.c:334
+#: merge-recursive.c:1483
 #, c-format
-msgid "unrecognized width:%s"
-msgstr "непозната широчина: %s"
+msgid ""
+"CONFLICT (%s/delete): %s deleted in %s and %s in %s. Version %s of %s left "
+"in tree at %s."
+msgstr ""
+"КОНФЛИКТ (%s/изтриване): „%s“ е изтрит в %s, а „%s“ в %s.  Версия %s на „%s“ "
+"е оставена в дървото: %s."
 
-#: ref-filter.c:343
+#: merge-recursive.c:1488
 #, c-format
-msgid "unrecognized %%(align) argument: %s"
-msgstr "непознат аргумент за %%(align): %s"
+msgid ""
+"CONFLICT (%s/delete): %s deleted in %s and %s to %s in %s. Version %s of %s "
+"left in tree at %s."
+msgstr ""
+"КОНФЛИКТ (%s/изтриване): „%s“ е изтрит в %s, а „%s“ е преименуван на „%s“ в "
+"%s.  Версия %s на „%s“ е оставена в дървото: %s."
 
-#: ref-filter.c:351
-#, c-format
-msgid "positive width expected with the %%(align) atom"
-msgstr "очаква се положителна широчина с лексемата „%%(align)“"
+#: merge-recursive.c:1523
+msgid "rename"
+msgstr "преименуване"
 
-#: ref-filter.c:369
-#, c-format
-msgid "unrecognized %%(if) argument: %s"
-msgstr "непознат аргумент за „%%(if)“: %s"
+#: merge-recursive.c:1523
+msgid "renamed"
+msgstr "преименуван"
 
-#: ref-filter.c:464
+#: merge-recursive.c:1603 merge-recursive.c:2519 merge-recursive.c:3164
 #, c-format
-msgid "malformed field name: %.*s"
-msgstr "неправилно име на обект: „%.*s“"
+msgid "Refusing to lose dirty file at %s"
+msgstr "Преустановяване на действието, за да не се изгуби промененият „%s“"
 
-#: ref-filter.c:491
+#: merge-recursive.c:1613
 #, c-format
-msgid "unknown field name: %.*s"
-msgstr "непознато име на обект: „%.*s“"
+msgid "Refusing to lose untracked file at %s, even though it's in the way."
+msgstr ""
+"Отказ да се загуби неследеният файл „%s“, защото е на място, където пречи."
 
-#: ref-filter.c:608
+#: merge-recursive.c:1671
 #, c-format
-msgid "format: %%(if) atom used without a %%(then) atom"
-msgstr "формат: лексемата %%(if) е използвана без съответната ѝ %%(then)"
+msgid "CONFLICT (rename/add): Rename %s->%s in %s.  Added %s in %s"
+msgstr ""
+"КОНФЛИКТ (преименуване/добавяне): „%s“ е преименуван на „%s“ в клон „%s“, а "
+"„%s“ е добавен в „%s“"
 
-#: ref-filter.c:671
+#: merge-recursive.c:1702
 #, c-format
-msgid "format: %%(then) atom used without an %%(if) atom"
-msgstr "формат: лексемата %%(then) е използвана без съответната ѝ %%(if)"
+msgid "%s is a directory in %s adding as %s instead"
+msgstr "„%s“ е директория в „%s“, затова се добавя като „%s“"
 
-#: ref-filter.c:673
+#: merge-recursive.c:1707
 #, c-format
-msgid "format: %%(then) atom used more than once"
-msgstr "формат: лексемата %%(then) е използвана повече от един път"
+msgid "Refusing to lose untracked file at %s; adding as %s instead"
+msgstr ""
+"Преустановяване на действието, за да не се изгуби неследеният файл „%s“.  "
+"Вместо него се добавя „%s“"
 
-#: ref-filter.c:675
+#: merge-recursive.c:1726
 #, c-format
-msgid "format: %%(then) atom used after %%(else)"
-msgstr "формат: лексемата %%(then) е използвана след %%(else)"
+msgid ""
+"CONFLICT (rename/rename): Rename \"%s\"->\"%s\" in branch \"%s\" rename \"%s"
+"\"->\"%s\" in \"%s\"%s"
+msgstr ""
+"КОНФЛИКТ (преименуване/преименуване): „%s“ е преименуван на „%s“ в клон "
+"„%s“, а „%s“ е преименуван на „%s“ в „%s“/%s."
+
+#: merge-recursive.c:1731
+msgid " (left unresolved)"
+msgstr " (некоригиран конфликт)"
 
-#: ref-filter.c:703
+#: merge-recursive.c:1840
 #, c-format
-msgid "format: %%(else) atom used without an %%(if) atom"
-msgstr "формат: лексемата %%(else) е използвана без съответната ѝ %%(if)"
+msgid "CONFLICT (rename/rename): Rename %s->%s in %s. Rename %s->%s in %s"
+msgstr ""
+"КОНФЛИКТ (преименуване/преименуване): „%s“ е преименуван на „%s“ в клон "
+"„%s“, а „%s“ е преименуван на „%s“ в „%s“"
 
-#: ref-filter.c:705
+#: merge-recursive.c:2103
 #, c-format
-msgid "format: %%(else) atom used without a %%(then) atom"
-msgstr "формат: лексемата %%(else) е използвана без съответната ѝ %%(then)"
+msgid ""
+"CONFLICT (directory rename split): Unclear where to place %s because "
+"directory %s was renamed to multiple other directories, with no destination "
+"getting a majority of the files."
+msgstr ""
+"КОНФЛИКТ (раздвояване при преименуване на директория): Не е ясно къде да се "
+"постави „%s“, защото няколко нови директории поделят съдържанието на "
+"директория „%s“, като никоя не съдържа мнозинство от файловете ѝ."
 
-#: ref-filter.c:707
+#: merge-recursive.c:2135
 #, c-format
-msgid "format: %%(else) atom used more than once"
-msgstr "формат: лексемата %%(else) е използвана повече от един път"
+msgid ""
+"CONFLICT (implicit dir rename): Existing file/dir at %s in the way of "
+"implicit directory rename(s) putting the following path(s) there: %s."
+msgstr ""
+"КОНФЛИКТ (косвено преименуване на директория): следният файл или директория "
+"„%s“ не позволяват косвеното преименуване на следния път/ища: %s."
 
-#: ref-filter.c:722
+#: merge-recursive.c:2145
 #, c-format
-msgid "format: %%(end) atom used without corresponding atom"
-msgstr "формат: лексемата %%(end) е използвана без съответната ѝ"
+msgid ""
+"CONFLICT (implicit dir rename): Cannot map more than one path to %s; "
+"implicit directory renames tried to put these paths there: %s"
+msgstr ""
+"КОНФЛИКТ (косвено преименуване на директория): повече от един път "
+"съответства на „%s“.  Косвено преименуване на директория води до поставянето "
+"на тези пътища там: %s."
 
-#: ref-filter.c:779
+#: merge-recursive.c:2237
 #, c-format
-msgid "malformed format string %s"
-msgstr "неправилен форматиращ низ „%s“"
+msgid ""
+"CONFLICT (rename/rename): Rename directory %s->%s in %s. Rename directory %s-"
+">%s in %s"
+msgstr ""
+"КОНФЛИКТ (преименуване/преименуване): „%s“ е преименуван на „%s“ в клон "
+"„%s“, а „%s“ е преименуван на „%s“ в „%s“"
 
-#: ref-filter.c:1387
+#: merge-recursive.c:2482
 #, c-format
-msgid "(no branch, rebasing %s)"
-msgstr "(извън клон, пребазиране на „%s“)"
+msgid ""
+"WARNING: Avoiding applying %s -> %s rename to %s, because %s itself was "
+"renamed."
+msgstr ""
+"ПРЕДУПРЕЖДЕНИЕ: прескачане на преименуването на „%s“ на „%s“ в „%s“, защото "
+"„%s“ също е с променено име."
 
-#: ref-filter.c:1390
+#: merge-recursive.c:3008
 #, c-format
-msgid "(no branch, rebasing detached HEAD %s)"
-msgstr "(извън клон, пребазиране на несвързан указател „HEAD“ при „%s“)"
+msgid "cannot read object %s"
+msgstr "обектът „%s“ не може да се прочете"
 
-#: ref-filter.c:1393
+#: merge-recursive.c:3011
 #, c-format
-msgid "(no branch, bisect started on %s)"
-msgstr "(извън клон, двоично търсене от „%s“)"
+msgid "object %s is not a blob"
+msgstr "обектът „%s“ не е BLOB"
 
-#. TRANSLATORS: make sure this matches "HEAD
-#. detached at " in wt-status.c
-#.
-#: ref-filter.c:1401
-#, c-format
-msgid "(HEAD detached at %s)"
-msgstr "(Указателят „HEAD“ не е свързан и е при „%s“)"
+#: merge-recursive.c:3075
+msgid "modify"
+msgstr "промяна"
 
-#. TRANSLATORS: make sure this matches "HEAD
-#. detached from " in wt-status.c
-#.
-#: ref-filter.c:1408
-#, c-format
-msgid "(HEAD detached from %s)"
-msgstr "Указателят „HEAD“ не е свързан и е отделѐн от „%s“"
+#: merge-recursive.c:3075
+msgid "modified"
+msgstr "променен"
 
-#: ref-filter.c:1412
-msgid "(no branch)"
-msgstr "(извън клон)"
+#: merge-recursive.c:3087
+msgid "content"
+msgstr "съдържание"
 
-#: ref-filter.c:1442
-#, c-format
-msgid "missing object %s for %s"
-msgstr "обектът „%s“ липсва за „%s“"
+#: merge-recursive.c:3091
+msgid "add/add"
+msgstr "добавяне/добавяне"
 
-#: ref-filter.c:1445
+#: merge-recursive.c:3114
 #, c-format
-msgid "parse_object_buffer failed on %s for %s"
-msgstr "неуспешно анализиране чрез „parse_object_buffer“ на „%s“ за „%s“"
+msgid "Skipped %s (merged same as existing)"
+msgstr "Прескачане на „%s“ (слетият резултат е идентичен със сегашния)"
 
-#: ref-filter.c:1902
-#, c-format
-msgid "malformed object at '%s'"
-msgstr "обект със сгрешен формат при „%s“"
+#: merge-recursive.c:3136 git-submodule.sh:993
+msgid "submodule"
+msgstr "ПОДМОДУЛ"
 
-#: ref-filter.c:1984
+#: merge-recursive.c:3137
 #, c-format
-msgid "ignoring ref with broken name %s"
-msgstr "игнориране на указателя с грешно име „%s“"
+msgid "CONFLICT (%s): Merge conflict in %s"
+msgstr "КОНФЛИКТ (%s): Конфликт при сливане на „%s“"
 
-#: ref-filter.c:1989
+#: merge-recursive.c:3167
 #, c-format
-msgid "ignoring broken ref %s"
-msgstr "игнориране на повредения указател „%s“"
+msgid "Adding as %s instead"
+msgstr "Добавяне като „%s“"
 
-#: ref-filter.c:2261
+#: merge-recursive.c:3250
 #, c-format
-msgid "format: %%(end) atom missing"
-msgstr "грешка във форма̀та: липсва лексемата %%(end)"
+msgid ""
+"Path updated: %s added in %s inside a directory that was renamed in %s; "
+"moving it to %s."
+msgstr ""
+"Обновен път: „%s“ е добавен в „%s“ в директория, която е преименувана в "
+"„%s“.  Обектът се мести в „%s“."
 
-#: ref-filter.c:2365
+#: merge-recursive.c:3253
 #, c-format
-msgid "malformed object name %s"
-msgstr "неправилно име на обект „%s“"
+msgid ""
+"CONFLICT (file location): %s added in %s inside a directory that was renamed "
+"in %s, suggesting it should perhaps be moved to %s."
+msgstr ""
+"КОНФЛИКТ (места на файлове): „%s“ е добавен в „%s“ в директория, която е "
+"преименувана в „%s“.  Предложението е да преместите обекта в „%s“."
 
-#: remote.c:605
+#: merge-recursive.c:3257
 #, c-format
-msgid "Cannot fetch both %s and %s to %s"
-msgstr "Невъзможно е да се доставят едновременно и „%s“, и „%s“ към „%s“"
+msgid ""
+"Path updated: %s renamed to %s in %s, inside a directory that was renamed in "
+"%s; moving it to %s."
+msgstr ""
+"Обновен път: „%s“ е преименуван на „%s“ в „%s“ в директория, която е "
+"преименувана в „%s“.  Обектът се мести в „%s“."
 
-#: remote.c:609
+#: merge-recursive.c:3260
 #, c-format
-msgid "%s usually tracks %s, not %s"
-msgstr "„%s“ обикновено следи „%s“, а не „%s“"
+msgid ""
+"CONFLICT (file location): %s renamed to %s in %s, inside a directory that "
+"was renamed in %s, suggesting it should perhaps be moved to %s."
+msgstr ""
+"КОНФЛИКТ (места на файлове): „%s“ е преименуван на „%s“ в „%s“ в директория, "
+"която е преименувана в „%s“.  Предложението е да преместите обекта в „%s“."
 
-#: remote.c:613
+#: merge-recursive.c:3374
 #, c-format
-msgid "%s tracks both %s and %s"
-msgstr "„%s“ следи както „%s“, така и „%s“"
+msgid "Removing %s"
+msgstr "Изтриване на „%s“"
 
-#: remote.c:621
-msgid "Internal error"
-msgstr "Вътрешна грешка"
+#: merge-recursive.c:3397
+msgid "file/directory"
+msgstr "файл/директория"
 
-#: remote.c:1534 remote.c:1635
-msgid "HEAD does not point to a branch"
-msgstr "Указателят „HEAD“ не сочи към клон"
+#: merge-recursive.c:3402
+msgid "directory/file"
+msgstr "директория/файл"
 
-#: remote.c:1543
+#: merge-recursive.c:3409
 #, c-format
-msgid "no such branch: '%s'"
-msgstr "няма клон на име „%s“"
+msgid "CONFLICT (%s): There is a directory with name %s in %s. Adding %s as %s"
+msgstr ""
+"КОНФЛИКТ (%s): Съществува директория на име „%s“ в „%s“.  Добавяне на „%s“ "
+"като „%s“"
 
-#: remote.c:1546
+#: merge-recursive.c:3418
 #, c-format
-msgid "no upstream configured for branch '%s'"
-msgstr "не е зададен клон-източник за клона „%s“"
+msgid "Adding %s"
+msgstr "Добавяне на „%s“"
 
-#: remote.c:1552
+#: merge-recursive.c:3427
 #, c-format
-msgid "upstream branch '%s' not stored as a remote-tracking branch"
-msgstr "клонът-източник „%s“ не е съхранен като следящ клон"
+msgid "CONFLICT (add/add): Merge conflict in %s"
+msgstr "КОНФЛИКТ (добавяне/добавяне): Конфликт при сливане на „%s“"
 
-#: remote.c:1567
-#, c-format
-msgid "push destination '%s' on remote '%s' has no local tracking branch"
-msgstr ""
-"липсва локален следящ клон за местоположението за изтласкване „%s“ в "
-"хранилището „%s“"
+#: merge-recursive.c:3471
+msgid "Already up to date!"
+msgstr "Вече е обновено!"
 
-#: remote.c:1579
+#: merge-recursive.c:3480
 #, c-format
-msgid "branch '%s' has no remote for pushing"
-msgstr "няма информация клонът „%s“ да следи някой друг"
+msgid "merging of trees %s and %s failed"
+msgstr "неуспешно сливане на дърветата „%s“ и „%s“"
+
+#: merge-recursive.c:3584
+msgid "Merging:"
+msgstr "Сливане:"
 
-#: remote.c:1589
+#: merge-recursive.c:3597
 #, c-format
-msgid "push refspecs for '%s' do not include '%s'"
-msgstr "указателят за изтласкване на „%s“ не включва „%s“"
+msgid "found %u common ancestor:"
+msgid_plural "found %u common ancestors:"
+msgstr[0] "открит е %u общ предшественик:"
+msgstr[1] "открити са %u общи предшественици:"
 
-#: remote.c:1602
-msgid "push has no destination (push.default is 'nothing')"
-msgstr "указателят за изтласкване не включва цел („push.default“ е „nothing“)"
+#: merge-recursive.c:3647
+msgid "merge returned no commit"
+msgstr "сливането не върна подаване"
 
-#: remote.c:1624
-msgid "cannot resolve 'simple' push to a single destination"
-msgstr "простото (simple) изтласкване не съответства на една цел"
+#: merge-recursive.c:3706
+#, c-format
+msgid ""
+"Your local changes to the following files would be overwritten by merge:\n"
+"  %s"
+msgstr ""
+"Сливането ще презапише локалните промени на тези файлове:\n"
+"    %s"
 
-#: remote.c:1939
+#: merge-recursive.c:3803
 #, c-format
-msgid "Your branch is based on '%s', but the upstream is gone.\n"
-msgstr "Този клон следи „%s“, но следеният клон е изтрит.\n"
+msgid "Could not parse object '%s'"
+msgstr "Неуспешен анализ на обекта „%s“"
 
-#: remote.c:1943
-msgid "  (use \"git branch --unset-upstream\" to fixup)\n"
-msgstr "  (за да коригирате това, използвайте „git branch --unset-upstream“)\n"
+#: merge-recursive.c:3821 builtin/merge.c:694 builtin/merge.c:874
+msgid "Unable to write index."
+msgstr "Индексът не може да бъде прочетен"
 
-#: remote.c:1946
+#: midx.c:68
 #, c-format
-msgid "Your branch is up to date with '%s'.\n"
-msgstr "Клонът е актуализиран към „%s“.\n"
+msgid "multi-pack-index file %s is too small"
+msgstr "файлът с индекса за множество пакети „%s“ е твърде малък"
 
-#: remote.c:1950
+#: midx.c:84
 #, c-format
-msgid "Your branch and '%s' refer to different commits.\n"
-msgstr "Клонът ви и „%s“ сочат към различни подавания.\n"
+msgid "multi-pack-index signature 0x%08x does not match signature 0x%08x"
+msgstr "отпечатъкът на индекса за множество пакети 0x%08x не съвпада с 0x%08x"
 
-#: remote.c:1953
+#: midx.c:89
 #, c-format
-msgid "  (use \"%s\" for details)\n"
-msgstr "  (за повече информация ползвайте „%s“)\n"
+msgid "multi-pack-index version %d not recognized"
+msgstr "непозната версия на индекс за множество пакети — %d"
 
-#: remote.c:1957
+#: midx.c:94
 #, c-format
-msgid "Your branch is ahead of '%s' by %d commit.\n"
-msgid_plural "Your branch is ahead of '%s' by %d commits.\n"
-msgstr[0] "Клонът ви е с %2$d подаване пред „%1$s“.\n"
-msgstr[1] "Клонът ви е с %2$d подавания пред „%1$s“.\n"
+msgid "hash version %u does not match"
+msgstr "версията на отпечатъка %u не съвпада"
 
-#: remote.c:1963
-msgid "  (use \"git push\" to publish your local commits)\n"
-msgstr "  (публикувайте локалните си промени чрез „git push“)\n"
+#: midx.c:108
+msgid "invalid chunk offset (too large)"
+msgstr "неправилно (прекалено голямо) отместване на откъс"
+
+#: midx.c:132
+msgid "terminating multi-pack-index chunk id appears earlier than expected"
+msgstr ""
+"идентификаторът за краен откъс на индекс за множество пакети се явява по-"
+"рано от очакваното"
+
+#: midx.c:145
+msgid "multi-pack-index missing required pack-name chunk"
+msgstr "липсва откъс (pack-name) от индекс за множество пакети"
 
-#: remote.c:1966
+#: midx.c:147
+msgid "multi-pack-index missing required OID fanout chunk"
+msgstr "липсва откъс (OID fanout) от индекс за множество пакети"
+
+#: midx.c:149
+msgid "multi-pack-index missing required OID lookup chunk"
+msgstr "липсва откъс (OID lookup) от индекс за множество пакети"
+
+#: midx.c:151
+msgid "multi-pack-index missing required object offsets chunk"
+msgstr "липсва откъс за отместванията на обекти от индекс за множество пакети"
+
+#: midx.c:165
 #, c-format
-msgid "Your branch is behind '%s' by %d commit, and can be fast-forwarded.\n"
-msgid_plural ""
-"Your branch is behind '%s' by %d commits, and can be fast-forwarded.\n"
-msgstr[0] "Клонът ви е с %2$d подаване зад „%1$s“ и може да бъде превъртян.\n"
-msgstr[1] "Клонът ви е с %2$d подавания зад „%1$s“ и може да бъде превъртян.\n"
+msgid "multi-pack-index pack names out of order: '%s' before '%s'"
+msgstr ""
+"неправилна подредба на имената в индекс за множество пакети: „%s“ се появи "
+"преди „%s“"
 
-#: remote.c:1974
-msgid "  (use \"git pull\" to update your local branch)\n"
-msgstr "  (обновете локалния си клон чрез „git pull“)\n"
+#: midx.c:210
+#, c-format
+msgid "bad pack-int-id: %u (%u total packs)"
+msgstr ""
+"неправилен идентификатор на пакет (pack-int-id): %u (от общо %u пакети)"
+
+#: midx.c:260
+msgid "multi-pack-index stores a 64-bit offset, but off_t is too small"
+msgstr ""
+"индексът за множество пакети съдържа 64-битови отмествания, но размерът на "
+"„off_t“ е недостатъчен"
+
+#: midx.c:288
+msgid "error preparing packfile from multi-pack-index"
+msgstr ""
+"грешка при създаването на пакетен файл на базата на индекс за множество "
+"пакети"
 
-#: remote.c:1977
+#: midx.c:472
 #, c-format
-msgid ""
-"Your branch and '%s' have diverged,\n"
-"and have %d and %d different commit each, respectively.\n"
-msgid_plural ""
-"Your branch and '%s' have diverged,\n"
-"and have %d and %d different commits each, respectively.\n"
-msgstr[0] ""
-"Текущият клон се е отделил от „%s“,\n"
-"двата имат съответно по %d и %d несъвпадащи подавания.\n"
-msgstr[1] ""
-"Текущият клон се е отделил от „%s“,\n"
-"двата имат съответно по %d и %d несъвпадащи подавания.\n"
+msgid "failed to add packfile '%s'"
+msgstr "пакетният файл „%s“ не може да бъде добавен"
 
-#: remote.c:1987
-msgid "  (use \"git pull\" to merge the remote branch into yours)\n"
-msgstr "  (слейте отдалечения клон в локалния чрез „git pull“)\n"
+#: midx.c:478
+#, c-format
+msgid "failed to open pack-index '%s'"
+msgstr "индексът за пакети „%s“ не може да бъде отворен"
 
-#: revision.c:2289
-msgid "your current branch appears to be broken"
-msgstr "Текущият клон е повреден"
+#: midx.c:538
+#, c-format
+msgid "failed to locate object %d in packfile"
+msgstr "обект %d в пакетния файл липсва"
+
+#: midx.c:842
+msgid "Adding packfiles to multi-pack-index"
+msgstr "Добавяне на пакетни файлове към индекс за множество пакети"
 
-#: revision.c:2292
+#: midx.c:875
 #, c-format
-msgid "your current branch '%s' does not have any commits yet"
-msgstr "Текущият клон „%s“ е без подавания "
+msgid "did not see pack-file %s to drop"
+msgstr "пакетният файл за триене „%s“ не може да се открие"
 
-#: revision.c:2489
-msgid "--first-parent is incompatible with --bisect"
-msgstr "опциите „--first-parent“ и „--bisect“ са несъвместими"
+#: midx.c:973
+msgid "Writing chunks to multi-pack-index"
+msgstr "Запис на откъси към индекс за множество пакети"
 
-#: run-command.c:728
-msgid "open /dev/null failed"
-msgstr "неуспешно отваряне на „/dev/null“"
+#: midx.c:1052
+#, c-format
+msgid "failed to clear multi-pack-index at %s"
+msgstr "индексът за множество пакети не може да бъде изчистен при „%s“"
+
+#: midx.c:1108
+msgid "Looking for referenced packfiles"
+msgstr "Търсене на указаните пакетни файлове"
 
-#: run-command.c:1271
+#: midx.c:1123
 #, c-format
 msgid ""
-"The '%s' hook was ignored because it's not set as executable.\n"
-"You can disable this warning with `git config advice.ignoredHook false`."
+"oid fanout out of order: fanout[%d] = %<PRIx32> > %<PRIx32> = fanout[%d]"
 msgstr ""
-"Куката „%s“ се прескача, защото липсват права за изпълнение.\n"
-"За да изключите това предупреждение, изпълнете:\n"
-"    git config advice.ignoredHook false"
+"неправилна подредба на откъси (OID fanout): fanout[%d] = %<PRIx32> > "
+"%<PRIx32> = fanout[%d]"
 
-#: send-pack.c:141
-msgid "unexpected flush packet while reading remote unpack status"
+#: midx.c:1128
+msgid "Verifying OID order in multi-pack-index"
 msgstr ""
-"неочакван изчистващ пакет „flush“ при изчитане на състоянието от "
-"отдалеченото разпакетиране"
+"Проверка на подредбата на идентификатори на обекти във файл с индекс към "
+"множество пакетни файлове"
 
-#: send-pack.c:143
+#: midx.c:1137
 #, c-format
-msgid "unable to parse remote unpack status: %s"
+msgid "oid lookup out of order: oid[%d] = %s >= %s = oid[%d]"
 msgstr ""
-"състоянието от отдалеченото разпакетиране не може да бъде анализирано: %s"
+"неправилна подредба на откъси (OID lookup): oid[%d] = %s >= %s = oid[%d]"
+
+#: midx.c:1157
+msgid "Sorting objects by packfile"
+msgstr "Подредба на обектите по пакетни файлове"
+
+#: midx.c:1164
+msgid "Verifying object offsets"
+msgstr "Проверка на отместването на обекти"
 
-#: send-pack.c:145
+#: midx.c:1180
 #, c-format
-msgid "remote unpack failed: %s"
-msgstr "неуспешно отдалечено разпакетиране: %s"
+msgid "failed to load pack entry for oid[%d] = %s"
+msgstr "записът в пакета за обекта oid[%d] = %s не може да бъде зареден"
 
-#: send-pack.c:308
-msgid "failed to sign the push certificate"
-msgstr "сертификатът за изтласкване не може да бъде подписан"
+#: midx.c:1186
+#, c-format
+msgid "failed to load pack-index for packfile %s"
+msgstr "индексът на пакета „%s“ не може да бъде зареден"
 
-#: send-pack.c:421
-msgid "the receiving end does not support --signed push"
-msgstr "отсрещната страна не поддържа изтласкване с опцията „--signed“"
+#: midx.c:1195
+#, c-format
+msgid "incorrect object offset for oid[%d] = %s: %<PRIx64> != %<PRIx64>"
+msgstr "неправилно отместване на обект за oid[%d] = %s: %<PRIx64> != %<PRIx64>"
 
-#: send-pack.c:423
-msgid ""
-"not sending a push certificate since the receiving end does not support --"
-"signed push"
-msgstr ""
-"отсрещната страна не поддържа изтласкване с опцията „--signed“, затова не се "
-"използва сертификат"
+#: midx.c:1220
+msgid "Counting referenced objects"
+msgstr "Преброяване на свързаните обекти"
 
-#: send-pack.c:435
-msgid "the receiving end does not support --atomic push"
-msgstr "получаващата страна не поддържа изтласкване с опцията „--atomic“"
+#: midx.c:1230
+msgid "Finding and deleting unreferenced packfiles"
+msgstr "Търсене и изтриване на несвързаните пакетни файлове"
 
-#: send-pack.c:440
-msgid "the receiving end does not support push options"
-msgstr "отсрещната страна не поддържа опции при изтласкване"
+#: midx.c:1388
+msgid "could not start pack-objects"
+msgstr "командата „pack-objects“ не може да бъде стартирана"
+
+#: midx.c:1407
+msgid "could not finish pack-objects"
+msgstr "командата „pack-objects“ не може да бъде завършена"
 
-#: sequencer.c:175
+#: name-hash.c:537
 #, c-format
-msgid "invalid commit message cleanup mode '%s'"
-msgstr "несъществуващ режим на изчистване „%s“ на съобщение при подаване"
+msgid "unable to create lazy_dir thread: %s"
+msgstr "не може да се създаде нишка за директории: %s"
 
-#: sequencer.c:275
+#: name-hash.c:559
 #, c-format
-msgid "could not delete '%s'"
-msgstr "„%s“ не може да бъде изтрит"
+msgid "unable to create lazy_name thread: %s"
+msgstr "не може да се създаде нишка за имена: %s"
 
-#: sequencer.c:301
-msgid "revert"
-msgstr "отмяна"
-
-#: sequencer.c:303
-msgid "cherry-pick"
-msgstr "отбиране"
-
-#: sequencer.c:305
-msgid "rebase -i"
-msgstr "rebase -i"
-
-#: sequencer.c:307
+#: name-hash.c:565
 #, c-format
-msgid "Unknown action: %d"
-msgstr "Неизвестно действие: %d"
+msgid "unable to join lazy_name thread: %s"
+msgstr "не може да се изчака нишка за имена: %s"
 
-#: sequencer.c:364
+#: notes-merge.c:277
+#, c-format
 msgid ""
-"after resolving the conflicts, mark the corrected paths\n"
-"with 'git add <paths>' or 'git rm <paths>'"
+"You have not concluded your previous notes merge (%s exists).\n"
+"Please, use 'git notes merge --commit' or 'git notes merge --abort' to "
+"commit/abort the previous merge before you start a new notes merge."
 msgstr ""
-"след коригирането на конфликтите, отбележете съответните\n"
-"пътища с „git add ПЪТ…“ или „git rm ПЪТ…“."
+"Не сте завършили предишното сливане на бележки.  (Указателят „%s“ "
+"съществува).\n"
+"За да завършите предишното сливане, изпълнете:\n"
+"\n"
+"    git notes merge --commit\n"
+"\n"
+"За да отмените предишното сливане, изпълнете:\n"
+"\n"
+"    git notes merge --abort"
 
-#: sequencer.c:367
-msgid ""
-"after resolving the conflicts, mark the corrected paths\n"
-"with 'git add <paths>' or 'git rm <paths>'\n"
-"and commit the result with 'git commit'"
+#: notes-merge.c:284
+#, c-format
+msgid "You have not concluded your notes merge (%s exists)."
 msgstr ""
-"след коригирането на конфликтите, отбележете съответните\n"
-"пътища с „git add ПЪТ…“ или „git rm ПЪТ…“, след което\n"
-"подайте резултата с командата „git commit'“."
+"Не сте завършили сливането на бележките.  (Указателят „%s“ съществува)."
 
-#: sequencer.c:380 sequencer.c:2468
-#, c-format
-msgid "could not lock '%s'"
-msgstr "„%s“ не може да се заключи"
+#: notes-utils.c:46
+msgid "Cannot commit uninitialized/unreferenced notes tree"
+msgstr ""
+"Неинициализирано или нереферирано дърво за бележки не може да бъде подадено"
 
-#: sequencer.c:382 sequencer.c:2346 sequencer.c:2472 sequencer.c:2486
-#: sequencer.c:2694 sequencer.c:4336 sequencer.c:4399 wrapper.c:656
+#: notes-utils.c:105
 #, c-format
-msgid "could not write to '%s'"
-msgstr "в „%s“ не може да се пише"
+msgid "Bad notes.rewriteMode value: '%s'"
+msgstr "Неправилна стойност за „notes.rewriteMode“: „%s“"
 
-#: sequencer.c:387
+#: notes-utils.c:115
 #, c-format
-msgid "could not write eol to '%s'"
-msgstr "краят на ред не може да се запише в „%s“"
+msgid "Refusing to rewrite notes in %s (outside of refs/notes/)"
+msgstr ""
+"Бележките в „%s“ няма да бъдат презаписани, защото са извън „refs/notes/“."
 
-#: sequencer.c:392 sequencer.c:2351 sequencer.c:2474 sequencer.c:2488
-#: sequencer.c:2702
+#. TRANSLATORS: The first %s is the name of
+#. the environment variable, the second %s is
+#. its value.
+#.
+#: notes-utils.c:145
 #, c-format
-msgid "failed to finalize '%s'"
-msgstr "„%s“ не може да се завърши"
+msgid "Bad %s value: '%s'"
+msgstr "Зададена е лоша стойност на променливата „%s“: „%s“"
 
-#: sequencer.c:415 sequencer.c:804 sequencer.c:1493 sequencer.c:2371
-#: sequencer.c:2684 sequencer.c:2788 builtin/am.c:259 builtin/commit.c:727
-#: builtin/merge.c:1046
+#: object.c:53
 #, c-format
-msgid "could not read '%s'"
-msgstr "файлът „%s“ не може да бъде прочетен"
+msgid "invalid object type \"%s\""
+msgstr "неправилен вид обект: „%s“"
 
-#: sequencer.c:441
+#: object.c:173
 #, c-format
-msgid "your local changes would be overwritten by %s."
-msgstr "локалните ви промени ще бъдат презаписани при %s."
+msgid "object %s is a %s, not a %s"
+msgstr "обектът „%s“ е %s, а не %s"
 
-#: sequencer.c:445
-msgid "commit your changes or stash them to proceed."
-msgstr "подайте или скатайте промените, за да продължите"
-
-#: sequencer.c:474
+#: object.c:233
 #, c-format
-msgid "%s: fast-forward"
-msgstr "%s: превъртане"
+msgid "object %s has unknown type id %d"
+msgstr "обектът „%s“ е непознат вид: %d"
 
-#. TRANSLATORS: %s will be "revert", "cherry-pick" or
-#. "rebase -i".
-#.
-#: sequencer.c:563
+#: object.c:246
 #, c-format
-msgid "%s: Unable to write new index file"
-msgstr "%s: новият индекс не може да бъде запазен"
-
-#: sequencer.c:579
-msgid "unable to update cache tree"
-msgstr "дървото на кеша не може да бъде обновено"
-
-#: sequencer.c:592
-msgid "could not resolve HEAD commit"
-msgstr "подаването, сочено от указателя „HEAD“, не може да бъде открито"
+msgid "unable to parse object: %s"
+msgstr "обектът „%s“ не може да бъде анализиран"
 
-#: sequencer.c:749
+#: object.c:266 object.c:277
 #, c-format
-msgid ""
-"you have staged changes in your working tree\n"
-"If these changes are meant to be squashed into the previous commit, run:\n"
-"\n"
-"  git commit --amend %s\n"
-"\n"
-"If they are meant to go into a new commit, run:\n"
-"\n"
-"  git commit %s\n"
-"\n"
-"In both cases, once you're done, continue with:\n"
-"\n"
-"  git rebase --continue\n"
-msgstr ""
-"в това работно дърво има скатани промени.\n"
-"Ако искате да ги вкарате в предишното подаване, изпълнете:\n"
-"\n"
-"    git commit --amend %s\n"
-"\n"
-"Ако искате да създадете ново подаване, изпълнете:\n"
-"\n"
-"    git commit %s\n"
-"\n"
-"И в двата случая продължавате след това с командата:\n"
-"\n"
-"    git rebase --continue\n"
+msgid "hash mismatch %s"
+msgstr "разлика в контролната сума: „%s“"
 
-#: sequencer.c:818
-msgid "writing root commit"
-msgstr "запазване на начално подаване"
-
-#: sequencer.c:1043
-msgid "'prepare-commit-msg' hook failed"
+#: packfile.c:629
+msgid "offset before end of packfile (broken .idx?)"
 msgstr ""
-"неуспешно изпълнение на куката при промяна на съобщението при подаване "
-"(prepare-commit-msg)"
+"отместване преди края на пакетния файл (възможно е индексът да е повреден)"
 
-#: sequencer.c:1050
-msgid ""
-"Your name and email address were configured automatically based\n"
-"on your username and hostname. Please check that they are accurate.\n"
-"You can suppress this message by setting them explicitly. Run the\n"
-"following command and follow the instructions in your editor to edit\n"
-"your configuration file:\n"
-"\n"
-"    git config --global --edit\n"
-"\n"
-"After doing this, you may fix the identity used for this commit with:\n"
-"\n"
-"    git commit --amend --reset-author\n"
+#: packfile.c:1876
+#, c-format
+msgid "offset before start of pack index for %s (corrupt index?)"
 msgstr ""
-"Името и адресът за е-поща са настроени автоматично на базата на името на\n"
-"потребителя и името на машината.  Проверете дали са верни.  Можете да "
-"спрете\n"
-"това съобщение като изрично зададете стойностите.  Изпълнете следната "
-"команда\n"
-"и следвайте инструкциите в текстовия ви редактор, за да редактирате\n"
-"конфигурационния файл:\n"
-"\n"
-"    git config --global --edit\n"
-"\n"
-"След като направите това, можете да коригирате информацията за автора на\n"
-"текущото подаване чрез:\n"
-"\n"
-"    git commit --amend --reset-author\n"
+"отместване преди началото на индекса на пакетния файл „%s“ (възможно е "
+"индексът да е повреден)"
 
-#: sequencer.c:1063
-msgid ""
-"Your name and email address were configured automatically based\n"
-"on your username and hostname. Please check that they are accurate.\n"
-"You can suppress this message by setting them explicitly:\n"
-"\n"
-"    git config --global user.name \"Your Name\"\n"
-"    git config --global user.email you@example.com\n"
-"\n"
-"After doing this, you may fix the identity used for this commit with:\n"
-"\n"
-"    git commit --amend --reset-author\n"
+#: packfile.c:1880
+#, c-format
+msgid "offset beyond end of pack index for %s (truncated index?)"
 msgstr ""
-"Името и адресът за е-поща са настроени автоматично на базата на името на\n"
-"потребителя и името на машината.  Проверете дали са верни.  Можете да "
-"спрете\n"
-"това съобщение като изрично зададете стойностите:\n"
-"\n"
-"    git config --global user.name \"Вашето Име\"\n"
-"    git config --global user.email пенчо@example.com\n"
-"\n"
-"След като направите това, можете да коригирате информацията за автора на\n"
-"текущото подаване чрез:\n"
-"\n"
-"    git commit --amend --reset-author\n"
+"отместване преди края на индекса на пакетния файл „%s“ (възможно е индексът "
+"да е отрязан)"
 
-#: sequencer.c:1103
-msgid "couldn't look up newly created commit"
-msgstr "току що създаденото подаване не може да бъде открито"
+#: parse-options.c:38
+#, c-format
+msgid "%s requires a value"
+msgstr "опцията „%s“ изисква аргумент"
 
-#: sequencer.c:1105
-msgid "could not parse newly created commit"
-msgstr "току що създаденото подаване не може да бъде анализирано"
+#: parse-options.c:73
+#, c-format
+msgid "%s is incompatible with %s"
+msgstr "опциите „%s“ и „%s“ са несъвместими"
 
-#: sequencer.c:1151
-msgid "unable to resolve HEAD after creating commit"
-msgstr ""
-"състоянието сочено от указателя „HEAD“ не може да бъде открито след "
-"подаването"
+#: parse-options.c:78
+#, c-format
+msgid "%s : incompatible with something else"
+msgstr "опцията „%s“ е несъвместима с нещо"
 
-#: sequencer.c:1153
-msgid "detached HEAD"
-msgstr "несвързан връх „HEAD“"
+#: parse-options.c:92 parse-options.c:96 parse-options.c:319
+#, c-format
+msgid "%s takes no value"
+msgstr "опцията „%s“ не приема аргументи"
 
-#: sequencer.c:1157
-msgid " (root-commit)"
-msgstr " (начално подаване)"
+#: parse-options.c:94
+#, c-format
+msgid "%s isn't available"
+msgstr "опцията „%s“ не е налична"
 
-#: sequencer.c:1178
-msgid "could not parse HEAD"
-msgstr "указателят „HEAD“ не може да бъде анализиран"
+#: parse-options.c:219
+#, c-format
+msgid "%s expects a non-negative integer value with an optional k/m/g suffix"
+msgstr ""
+"„%s“ очаква неотрицателно цяло число, евентуално със суфикс „k“/„m“/„g“"
 
-#: sequencer.c:1180
+#: parse-options.c:389
 #, c-format
-msgid "HEAD %s is not a commit!"
-msgstr "указателят „HEAD“ „%s“ сочи към нещо, което не е подаване!"
+msgid "ambiguous option: %s (could be --%s%s or --%s%s)"
+msgstr "нееднозначна опция: „%s“ (може да е „--%s%s“ или „--%s%s“)"
 
-#: sequencer.c:1184 builtin/commit.c:1528
-msgid "could not parse HEAD commit"
-msgstr "върховото подаване „HEAD“ не може да бъде прочетено"
+#: parse-options.c:423 parse-options.c:431
+#, c-format
+msgid "did you mean `--%s` (with two dashes ?)"
+msgstr "„--%s“ (с 2 тирета) ли имахте предвид?"
 
-#: sequencer.c:1235 sequencer.c:1832
-msgid "unable to parse commit author"
-msgstr "авторът на подаването не може да бъде анализиран"
+#: parse-options.c:860
+#, c-format
+msgid "unknown option `%s'"
+msgstr "непозната опция: „%s“"
 
-#: sequencer.c:1245 builtin/am.c:1630 builtin/merge.c:645
-msgid "git write-tree failed to write a tree"
-msgstr "Командата „git write-tree“ не успя да запише обект-дърво"
+#: parse-options.c:862
+#, c-format
+msgid "unknown switch `%c'"
+msgstr "непознат флаг „%c“"
 
-#: sequencer.c:1262 sequencer.c:1317
+#: parse-options.c:864
 #, c-format
-msgid "unable to read commit message from '%s'"
-msgstr "съобщението за подаване не може да бъде прочетено от „%s“"
+msgid "unknown non-ascii option in string: `%s'"
+msgstr "непозната стойност извън „ascii“ в низа: „%s“"
 
-#: sequencer.c:1284 builtin/am.c:1650 builtin/commit.c:1631 builtin/merge.c:825
-#: builtin/merge.c:850
-msgid "failed to write commit object"
-msgstr "обектът за подаването не може да бъде записан"
+#: parse-options.c:888
+msgid "..."
+msgstr "…"
 
-#: sequencer.c:1344
+#: parse-options.c:907
 #, c-format
-msgid "could not parse commit %s"
-msgstr "подаването „%s“ не може да бъде анализирано"
+msgid "usage: %s"
+msgstr "употреба: %s"
 
-#: sequencer.c:1349
+#. TRANSLATORS: the colon here should align with the
+#. one in "usage: %s" translation.
+#.
+#: parse-options.c:913
 #, c-format
-msgid "could not parse parent commit %s"
-msgstr "родителското подаване „%s“ не може да бъде анализирано"
+msgid "   or: %s"
+msgstr "     или: %s"
 
-#: sequencer.c:1500 sequencer.c:1525
+#: parse-options.c:916
 #, c-format
-msgid "This is a combination of %d commits."
-msgstr "Това е обединение от %d подавания"
-
-#: sequencer.c:1510 sequencer.c:4355
-msgid "need a HEAD to fixup"
-msgstr "За вкарване в предходното подаване ви трябва указател „HEAD“"
-
-#: sequencer.c:1512 sequencer.c:2729
-msgid "could not read HEAD"
-msgstr "указателят „HEAD“ не може да се прочете"
+msgid "    %s"
+msgstr "    %s"
 
-#: sequencer.c:1514
-msgid "could not read HEAD's commit message"
-msgstr ""
-"съобщението за подаване към указателя „HEAD“ не може да бъде прочетено: %s"
+#: parse-options.c:955
+msgid "-NUM"
+msgstr "-ЧИСЛО"
 
-#: sequencer.c:1520
+#: parse-options.c:969
 #, c-format
-msgid "cannot write '%s'"
-msgstr "„%s“ не може да се запази"
+msgid "alias of --%s"
+msgstr "псевдоним на „--%s“"
 
-#: sequencer.c:1527 git-rebase--interactive.sh:457
-msgid "This is the 1st commit message:"
-msgstr "Това е 1-то съобщение при подаване:"
+#: parse-options-cb.c:20 parse-options-cb.c:24
+#, c-format
+msgid "option `%s' expects a numerical value"
+msgstr "опцията „%s“ очаква число за аргумент"
 
-#: sequencer.c:1535
+#: parse-options-cb.c:41
 #, c-format
-msgid "could not read commit message of %s"
-msgstr "съобщението за подаване към „%s“ не може да бъде прочетено"
+msgid "malformed expiration date '%s'"
+msgstr "неправилна дата на срок: „%s“"
 
-#: sequencer.c:1542
+#: parse-options-cb.c:54
 #, c-format
-msgid "This is the commit message #%d:"
-msgstr "Това е съобщение при подаване №%d:"
+msgid "option `%s' expects \"always\", \"auto\", or \"never\""
+msgstr ""
+"опцията „%s“ изисква някоя от стойностите: „always“ (винаги), "
+"„auto“ (автоматично) или „never“ (никога)"
 
-#: sequencer.c:1548
+#: parse-options-cb.c:130 parse-options-cb.c:147
 #, c-format
-msgid "The commit message #%d will be skipped:"
-msgstr "Съобщение при подаване №%d ще бъде прескочено:"
+msgid "malformed object name '%s'"
+msgstr "неправилно име на обект „%s“"
 
-#: sequencer.c:1553
+#: path.c:915
 #, c-format
-msgid "unknown command: %d"
-msgstr "непозната команда: %d"
+msgid "Could not make %s writable by group"
+msgstr "Не могат да се дадат права за запис в директорията „%s“ на групата"
 
-#: sequencer.c:1631
-msgid "your index file is unmerged."
-msgstr "индексът не е слят."
+#: pathspec.c:130
+msgid "Escape character '\\' not allowed as last character in attr value"
+msgstr ""
+"Екраниращият знак „\\“не може да е последен знак в стойността на атрибут"
 
-#: sequencer.c:1638
-msgid "cannot fixup root commit"
-msgstr "началното подаване не може да се вкара в предходното му"
+#: pathspec.c:148
+msgid "Only one 'attr:' specification is allowed."
+msgstr "Позволено е само едно указване на „attr:“."
 
-#: sequencer.c:1657
-#, c-format
-msgid "commit %s is a merge but no -m option was given."
-msgstr "подаването „%s“ е сливане, но не е дадена опцията „-m“"
+#: pathspec.c:151
+msgid "attr spec must not be empty"
+msgstr "„attr:“ трябва да указва стойност"
 
-#: sequencer.c:1665
+#: pathspec.c:194
 #, c-format
-msgid "commit %s does not have parent %d"
-msgstr "подаването „%s“ няма родител %d"
+msgid "invalid attribute name %s"
+msgstr "неправилно име на атрибут: „%s“"
 
-#: sequencer.c:1669
-#, c-format
-msgid "mainline was specified but commit %s is not a merge."
-msgstr "указано е базово подаване, но подаването „%s“ не е сливане."
+#: pathspec.c:259
+msgid "global 'glob' and 'noglob' pathspec settings are incompatible"
+msgstr "глобалните настройки за пътища „glob“ и „noglob“ са несъвместими"
 
-#: sequencer.c:1675
-#, c-format
-msgid "cannot get commit message for %s"
-msgstr "неуспешно извличане на съобщението за подаване на „%s“"
+#: pathspec.c:266
+msgid ""
+"global 'literal' pathspec setting is incompatible with all other global "
+"pathspec settings"
+msgstr ""
+"глобалната настройка за дословни пътища „literal“ е несъвместима с всички "
+"други глобални настройки за пътища"
 
-#. TRANSLATORS: The first %s will be a "todo" command like
-#. "revert" or "pick", the second %s a SHA1.
-#: sequencer.c:1694
+#: pathspec.c:306
+msgid "invalid parameter for pathspec magic 'prefix'"
+msgstr "неправилен параметър за опцията за магически пътища „prefix“"
+
+#: pathspec.c:327
 #, c-format
-msgid "%s: cannot parse parent commit %s"
-msgstr "%s: неразпозната стойност за родителското подаване „%s“"
+msgid "Invalid pathspec magic '%.*s' in '%s'"
+msgstr "Неправилна стойност за опцията за магически пътища „%.*s“ в „%s“"
 
-#: sequencer.c:1759
+#: pathspec.c:332
 #, c-format
-msgid "could not rename '%s' to '%s'"
-msgstr "„%s“ не може да се преименува на „%s“"
+msgid "Missing ')' at the end of pathspec magic in '%s'"
+msgstr "Знакът „)“ липсва в опцията за магически пътища в „%s“"
 
-#: sequencer.c:1813
+#: pathspec.c:370
 #, c-format
-msgid "could not revert %s... %s"
-msgstr "подаването „%s“… не може да бъде отменено: „%s“"
+msgid "Unimplemented pathspec magic '%c' in '%s'"
+msgstr "Магическите пътища „%c“ са без реализация за „%s“"
 
-#: sequencer.c:1814
+#: pathspec.c:429
 #, c-format
-msgid "could not apply %s... %s"
-msgstr "подаването „%s“… не може да бъде приложено: „%s“"
+msgid "%s: 'literal' and 'glob' are incompatible"
+msgstr "%s: опциите „literal“ и „glob“ са несъвместими"
 
-#: sequencer.c:1864
-msgid "empty commit set passed"
-msgstr "зададено е празно множество от подавания"
+#: pathspec.c:442
+#, c-format
+msgid "%s: '%s' is outside repository"
+msgstr "%s: „%s“ е извън хранилището"
 
-#: sequencer.c:1874
+#: pathspec.c:516
 #, c-format
-msgid "git %s: failed to read the index"
-msgstr "git %s: неуспешно изчитане на индекса"
+msgid "'%s' (mnemonic: '%c')"
+msgstr "„%s“ (клавиш: „%c“)"
 
-#: sequencer.c:1881
+#: pathspec.c:526
 #, c-format
-msgid "git %s: failed to refresh the index"
-msgstr "git %s: неуспешно обновяване на индекса"
+msgid "%s: pathspec magic not supported by this command: %s"
+msgstr "%s: магическите пътища не се поддържат от командата „%s“"
 
-#: sequencer.c:1961
+#: pathspec.c:593
 #, c-format
-msgid "%s does not accept arguments: '%s'"
-msgstr "„%s“ не приема аргументи: „%s“"
+msgid "pathspec '%s' is beyond a symbolic link"
+msgstr "пътят „%s“ е след символна връзка"
 
-#: sequencer.c:1970
+#: pathspec.c:638
 #, c-format
-msgid "missing arguments for %s"
-msgstr "„%s“ изисква аргументи"
+msgid "line is badly quoted: %s"
+msgstr "неправилно цитиран ред: %s"
+
+#: pkt-line.c:92
+msgid "unable to write flush packet"
+msgstr "пакетът за изчистване на буферите не може да се запише"
+
+#: pkt-line.c:99
+msgid "unable to write delim packet"
+msgstr "разделящият пакет не може да се запише"
+
+#: pkt-line.c:106
+msgid "flush packet write failed"
+msgstr "неуспешно изчистване на буферите при запис на пакет"
+
+#: pkt-line.c:146 pkt-line.c:232
+msgid "protocol error: impossibly long line"
+msgstr "протоколна грешка: прекалено дълъг ред"
+
+#: pkt-line.c:162 pkt-line.c:164
+msgid "packet write with format failed"
+msgstr "неуспешен запис на пакет с формат"
+
+#: pkt-line.c:196
+msgid "packet write failed - data exceeds max packet size"
+msgstr ""
+"неуспешен запис на пакетен файл — данните надвишават максималният размер на "
+"пакет"
+
+#: pkt-line.c:203 pkt-line.c:210
+msgid "packet write failed"
+msgstr "неуспешен запис на пакет"
+
+#: pkt-line.c:295
+msgid "read error"
+msgstr "грешка при четене"
+
+#: pkt-line.c:303
+msgid "the remote end hung up unexpectedly"
+msgstr "отдалеченото хранилище неочаквано прекъсна връзката"
 
-#: sequencer.c:2029
+#: pkt-line.c:331
 #, c-format
-msgid "invalid line %d: %.*s"
-msgstr "неправилен ред %d: %.*s"
+msgid "protocol error: bad line length character: %.4s"
+msgstr "протоколна грешка: неправилeн знак за дължина на ред: %.4s"
 
-#: sequencer.c:2037
+#: pkt-line.c:341 pkt-line.c:346
 #, c-format
-msgid "cannot '%s' without a previous commit"
-msgstr "Без предишно подаване не може да се изпълни „%s“"
+msgid "protocol error: bad line length %d"
+msgstr "протоколна грешка: неправилна дължина на ред: %d"
 
-#: sequencer.c:2085 sequencer.c:4138 sequencer.c:4173
+#: pkt-line.c:362
 #, c-format
-msgid "could not read '%s'."
-msgstr "от „%s“ не може да се чете."
+msgid "remote error: %s"
+msgstr "отдалечена грешка: %s"
 
-#: sequencer.c:2108
-msgid "please fix this using 'git rebase --edit-todo'."
-msgstr "коригирайте това чрез „git rebase --edit-todo“."
+#: preload-index.c:119
+msgid "Refreshing index"
+msgstr "Обновяване на индекса"
 
-#: sequencer.c:2110
+#: preload-index.c:138
 #, c-format
-msgid "unusable instruction sheet: '%s'"
-msgstr "неизползваем файл с описание на предстоящите действия: „%s“"
+msgid "unable to create threaded lstat: %s"
+msgstr "не може да се създаде нишка за изпълнението на „lstat“: %s"
 
-#: sequencer.c:2115
-msgid "no commits parsed."
-msgstr "никое от подаванията не може да се разпознае."
+#: pretty.c:981
+msgid "unable to parse --pretty format"
+msgstr "аргументът към опцията „--pretty“ не може да се анализира"
 
-#: sequencer.c:2126
-msgid "cannot cherry-pick during a revert."
+#: promisor-remote.c:23
+msgid "Remote with no URL"
+msgstr "Липсва адрес за отдалеченото хранилище"
+
+#: promisor-remote.c:58
+#, c-format
+msgid "promisor remote name cannot begin with '/': %s"
 msgstr ""
-"по време на отмяна на подаване не може да се извърши отбиране на подаване."
+"името отдалеченото хранилище-гарант не може за започва със знака „/“: %s"
 
-#: sequencer.c:2128
-msgid "cannot revert during a cherry-pick."
-msgstr "по време на отбиране не може да се извърши отмяна на подаване."
+#: range-diff.c:75
+msgid "could not start `log`"
+msgstr "командата за журнала с подавания „log“ не може да се стартира"
+
+#: range-diff.c:77
+msgid "could not read `log` output"
+msgstr ""
+"изходът от командата за журнала с подавания „log“ не може да се прочете"
 
-#: sequencer.c:2195
+#: range-diff.c:96 sequencer.c:5163
 #, c-format
-msgid "invalid key: %s"
-msgstr "неправилен ключ: „%s“"
+msgid "could not parse commit '%s'"
+msgstr "подаването „%s“ не може да бъде анализирано"
 
-#: sequencer.c:2198
+#: range-diff.c:122
 #, c-format
-msgid "invalid value for %s: %s"
-msgstr "неправилна стойност за „%s“: „%s“"
+msgid "could not parse git header '%.*s'"
+msgstr "заглавната част на git „%.*s“ не може да се анализира"
 
-#: sequencer.c:2269
-msgid "unusable squash-onto"
-msgstr "подаването, в което другите да се вкарат, не може да се използва"
+#: range-diff.c:285
+msgid "failed to generate diff"
+msgstr "неуспешно търсене на разлика"
 
-#: sequencer.c:2285
+#: range-diff.c:518 range-diff.c:520
 #, c-format
-msgid "malformed options sheet: '%s'"
-msgstr "неправилен файл с опции: „%s“"
+msgid "could not parse log for '%s'"
+msgstr "журналът с подаванията на „%s“ не може да бъде анализиран"
 
-#: sequencer.c:2323
-msgid "a cherry-pick or revert is already in progress"
+#: read-cache.c:680
+#, c-format
+msgid "will not add file alias '%s' ('%s' already exists in index)"
 msgstr ""
-"в момента вече се извършва отбиране на подавания или пребазиране на клона"
+"няма да бъде добавен псевдоним за файл „%s“ („%s“ вече съществува в индекса)"
 
-#: sequencer.c:2324
-msgid "try \"git cherry-pick (--continue | --quit | --abort)\""
-msgstr "използвайте „git cherry-pick (--continue | --quit | --abort)“"
+#: read-cache.c:696
+msgid "cannot create an empty blob in the object database"
+msgstr "в базата от данни за обектите не може да се създаде празен обект-BLOB"
 
-#: sequencer.c:2327
+#: read-cache.c:718
 #, c-format
-msgid "could not create sequencer directory '%s'"
-msgstr "директорията за секвенсора „%s“ не може да бъде създадена"
+msgid "%s: can only add regular files, symbolic links or git-directories"
+msgstr ""
+"%s: може да добавяте само обикновени файлове, символни връзки и директории "
+"на git"
 
-#: sequencer.c:2341
-msgid "could not lock HEAD"
-msgstr "указателят „HEAD“ не може да се заключи"
+#: read-cache.c:723
+#, c-format
+msgid "'%s' does not have a commit checked out"
+msgstr "не е изтеглено подаване в „%s“"
 
-#: sequencer.c:2396 sequencer.c:3403
-msgid "no cherry-pick or revert in progress"
-msgstr ""
-"в момента не се извършва отбиране на подавания или пребазиране на клона"
+#: read-cache.c:775
+#, c-format
+msgid "unable to index file '%s'"
+msgstr "файлът „%s“ не може да бъде индексиран"
 
-#: sequencer.c:2398
-msgid "cannot resolve HEAD"
-msgstr "Подаването сочено от указателя „HEAD“ не може да бъде открито"
+#: read-cache.c:794
+#, c-format
+msgid "unable to add '%s' to index"
+msgstr "„%s“ не може да се добави в индекса"
 
-#: sequencer.c:2400 sequencer.c:2435
-msgid "cannot abort from a branch yet to be born"
-msgstr ""
-"действието не може да бъде преустановено, когато сте на клон, който тепърва "
-"предстои да бъде създаден"
+#: read-cache.c:805
+#, c-format
+msgid "unable to stat '%s'"
+msgstr "„stat“ не може да се изпълни върху „%s“"
 
-#: sequencer.c:2421 builtin/grep.c:720
+#: read-cache.c:1283
 #, c-format
-msgid "cannot open '%s'"
-msgstr "„%s“ не може да бъде отворен"
+msgid "filename in tree entry contains backslash: '%s'"
+msgstr "името на файл в елемент от обект-дърво съдържа „\\“: „%s“"
 
-#: sequencer.c:2423
+#: read-cache.c:1330
 #, c-format
-msgid "cannot read '%s': %s"
-msgstr "„%s“ не може да бъде прочетен: %s"
+msgid "'%s' appears as both a file and as a directory"
+msgstr "„%s“ съществува и като файл, и като директория"
 
-#: sequencer.c:2424
-msgid "unexpected end of file"
-msgstr "неочакван край на файл"
+#: read-cache.c:1536
+msgid "Refresh index"
+msgstr "Обновяване на индекса"
 
-#: sequencer.c:2430
+#: read-cache.c:1651
 #, c-format
-msgid "stored pre-cherry-pick HEAD file '%s' is corrupt"
+msgid ""
+"index.version set, but the value is invalid.\n"
+"Using version %i"
 msgstr ""
-"запазеният преди започването на отбирането файл за указателя „HEAD“ — „%s“ е "
-"повреден"
+"Зададена е неправилна стойност на настройката „index.version“.\n"
+"Ще се ползва версия %i"
 
-#: sequencer.c:2441
-msgid "You seem to have moved HEAD. Not rewinding, check your HEAD!"
+#: read-cache.c:1661
+#, c-format
+msgid ""
+"GIT_INDEX_VERSION set, but the value is invalid.\n"
+"Using version %i"
 msgstr ""
-"Изглежда указателят „HEAD“ е променен.  Проверете към какво сочи.\n"
-"Не се правят промени."
+"Зададена е неправилна стойност на променливата на средата "
+"„GIT_INDEX_VERSION“.\n"
+"Ще се ползва версия %i"
 
-#: sequencer.c:2545 sequencer.c:3321
+#: read-cache.c:1717
 #, c-format
-msgid "could not update %s"
-msgstr "„%s“ не може да се обнови"
-
-#: sequencer.c:2583 sequencer.c:3301
-msgid "cannot read HEAD"
-msgstr "указателят „HEAD“ не може да бъде прочетен"
+msgid "bad signature 0x%08x"
+msgstr "неправилен подпис: „0x%08x“"
 
-#: sequencer.c:2618 sequencer.c:2622 builtin/difftool.c:639
+#: read-cache.c:1720
 #, c-format
-msgid "could not copy '%s' to '%s'"
-msgstr "„%s“ не може да се копира като „%s“"
+msgid "bad index version %d"
+msgstr "неправилна версия на индекса %d"
 
-#: sequencer.c:2641
-msgid "could not read index"
-msgstr "индексът не може да бъде прочетен"
+#: read-cache.c:1729
+msgid "bad index file sha1 signature"
+msgstr "неправилен подпис за контролна сума по SHA1 на файла на индекса"
 
-#: sequencer.c:2646
+#: read-cache.c:1759
 #, c-format
-msgid ""
-"execution failed: %s\n"
-"%sYou can fix the problem, and then run\n"
-"\n"
-"  git rebase --continue\n"
-"\n"
+msgid "index uses %.4s extension, which we do not understand"
 msgstr ""
-"неуспешно изпълнение: %s\n"
-"%sМоже да коригирате проблема, след което изпълнете:\n"
-"\n"
-"    git rebase --continue\n"
-"\n"
+"индексът ползва разширение „%.4s“, което не се поддържа от тази версия на git"
 
-#: sequencer.c:2652
-msgid "and made changes to the index and/or the working tree\n"
-msgstr "и промени индекса и/или работното дърво\n"
+#: read-cache.c:1761
+#, c-format
+msgid "ignoring %.4s extension"
+msgstr "игнориране на разширението „%.4s“"
 
-#: sequencer.c:2658
+#: read-cache.c:1798
 #, c-format
-msgid ""
-"execution succeeded: %s\n"
-"but left changes to the index and/or the working tree\n"
-"Commit or stash your changes, and then run\n"
-"\n"
-"  git rebase --continue\n"
-"\n"
-msgstr ""
-"Успешно изпълнение: %s\n"
-"Остават още промени в индекса или работното дърво.\n"
-"Трябва да ги подадете или скатаете и след това изпълнете:\n"
-"\n"
-"    git rebase --continue\n"
-"\n"
+msgid "unknown index entry format 0x%08x"
+msgstr "непознат формат на запис в индекса: „0x%08x“"
 
-#: sequencer.c:2771
-msgid "writing fake root commit"
-msgstr "запазване на фалшиво начално подаване"
+#: read-cache.c:1814
+#, c-format
+msgid "malformed name field in the index, near path '%s'"
+msgstr "неправилно име на поле в индекса близо до пътя „%s“"
 
-#: sequencer.c:2776
-msgid "writing squash-onto"
-msgstr "запазване на подаването, в което другите да се вкарат"
+#: read-cache.c:1871
+msgid "unordered stage entries in index"
+msgstr "неподредени записи в индекса"
 
-#: sequencer.c:2811
+#: read-cache.c:1874
 #, c-format
-msgid "failed to find tree of %s"
-msgstr "дървото, сочено от „%s“, не може да бъде открито"
+msgid "multiple stage entries for merged file '%s'"
+msgstr "множество записи за слетия файл „%s“"
 
-#: sequencer.c:2829
-msgid "could not write index"
-msgstr "индексът не може да бъде записан"
+#: read-cache.c:1877
+#, c-format
+msgid "unordered stage entries for '%s'"
+msgstr "неподредени записи за „%s“"
 
-#: sequencer.c:2861
-msgid "cannot merge without a current revision"
-msgstr "без текущо подаване не може да се слива"
+#: read-cache.c:1983 read-cache.c:2271 rerere.c:565 rerere.c:599 rerere.c:1111
+#: builtin/add.c:499 builtin/check-ignore.c:178 builtin/checkout.c:470
+#: builtin/checkout.c:654 builtin/clean.c:967 builtin/commit.c:367
+#: builtin/diff-tree.c:120 builtin/grep.c:499 builtin/mv.c:145
+#: builtin/reset.c:246 builtin/rm.c:271 builtin/submodule--helper.c:332
+msgid "index file corrupt"
+msgstr "файлът с индекса е повреден"
 
-#: sequencer.c:2884
+#: read-cache.c:2124
 #, c-format
-msgid "could not resolve '%s'"
-msgstr "„%s“ не може да бъде открит"
+msgid "unable to create load_cache_entries thread: %s"
+msgstr "не може да се създаде нишка за зареждане на обектите от кеша: %s"
 
-#: sequencer.c:2906
+#: read-cache.c:2137
 #, c-format
-msgid "could not get commit message of '%s'"
-msgstr "съобщението за подаване към „%s“ не може да бъде получено"
+msgid "unable to join load_cache_entries thread: %s"
+msgstr "не може да се изчака нишка за зареждане на обектите от кеша: %s"
 
-#: sequencer.c:2916 sequencer.c:2941
+#: read-cache.c:2170
 #, c-format
-msgid "could not write '%s'"
-msgstr "„%s“ не може да се запише"
+msgid "%s: index file open failed"
+msgstr "%s: неуспешно отваряне на файла на индекса"
 
-#: sequencer.c:3005
+#: read-cache.c:2174
 #, c-format
-msgid "could not even attempt to merge '%.*s'"
-msgstr "сливането на „%.*s“ не може даже да започне"
+msgid "%s: cannot stat the open index"
+msgstr "%s: не може да се получи информация за отворения индекс със „stat“"
 
-#: sequencer.c:3021
-msgid "merge: Unable to write new index file"
-msgstr "сливане: новият индекс не може да бъде запазен"
-
-#: sequencer.c:3088
+#: read-cache.c:2178
 #, c-format
-msgid "Applied autostash.\n"
-msgstr "Автоматично скатаното е приложено.\n"
+msgid "%s: index file smaller than expected"
+msgstr "%s: файлът на индекса е по-малък от очакваното"
 
-#: sequencer.c:3100
+#: read-cache.c:2182
 #, c-format
-msgid "cannot store %s"
-msgstr "„%s“ не може да бъде запазен"
+msgid "%s: unable to map index file"
+msgstr "%s: неуспешно заделяне на съответстваща памет чрез „mmap“ на индекса"
 
-#: sequencer.c:3103 git-rebase.sh:188
+#: read-cache.c:2224
 #, c-format
-msgid ""
-"Applying autostash resulted in conflicts.\n"
-"Your changes are safe in the stash.\n"
-"You can run \"git stash pop\" or \"git stash drop\" at any time.\n"
+msgid "unable to create load_index_extensions thread: %s"
 msgstr ""
-"Прилагането на автоматично скатаното доведе до конфликти.  Промените ви са\n"
-"надеждно скатани.  Можете да пробвате да ги приложите чрез „git stash pop“\n"
-"или да ги изхвърлите чрез „git stash drop“, когато поискате.\n"
+"не може да се създаде нишка за зареждане на разширенията на индекса: %s"
 
-#: sequencer.c:3134
+#: read-cache.c:2251
 #, c-format
-msgid ""
-"Could not execute the todo command\n"
-"\n"
-"    %.*s\n"
-"It has been rescheduled; To edit the command before continuing, please\n"
-"edit the todo list first:\n"
-"\n"
-"    git rebase --edit-todo\n"
-"    git rebase --continue\n"
+msgid "unable to join load_index_extensions thread: %s"
 msgstr ""
-"Следната запланувана команда не може да бъде изпълнена:\n"
-"\n"
-"    %.*s\n"
-"\n"
-"Тя е запланувана за по-късно.  За да редактирате командата преди "
-"изпълнение,\n"
-"редактирайте списъка за изпълнение:\n"
-"\n"
-"    git rebase --edit-todo\n"
-"    git rebase --continue\n"
+"не може да се създаде нишка за зареждане на разширенията на индекса: %s"
 
-#: sequencer.c:3202
+#: read-cache.c:2283
 #, c-format
-msgid "Stopped at %s...  %.*s\n"
-msgstr "Спиране при „%s“…  %.*s\n"
+msgid "could not freshen shared index '%s'"
+msgstr "споделеният индекс „%s“ не може да се обнови"
 
-#: sequencer.c:3264
+#: read-cache.c:2330
 #, c-format
-msgid "unknown command %d"
-msgstr "непозната команда %d"
+msgid "broken index, expect %s in %s, got %s"
+msgstr "грешки в индекса — в „%2$s“ се очаква „%1$s“, а бе получено „%3$s“"
 
-#: sequencer.c:3309
-msgid "could not read orig-head"
-msgstr "указателят за „orig-head“ не може да се прочете"
+#: read-cache.c:3026 strbuf.c:1145 wrapper.c:622 builtin/merge.c:1119
+#, c-format
+msgid "could not close '%s'"
+msgstr "„%s“ не може да се затвори"
 
-#: sequencer.c:3314 sequencer.c:4352
-msgid "could not read 'onto'"
-msgstr "указателят за „onto“ не може да се прочете"
+#: read-cache.c:3129 sequencer.c:2429 sequencer.c:4069
+#, c-format
+msgid "could not stat '%s'"
+msgstr "неуспешно изпълнение на „stat“ върху „%s“"
 
-#: sequencer.c:3328
+#: read-cache.c:3142
 #, c-format
-msgid "could not update HEAD to %s"
-msgstr "„HEAD“ не може да бъде обновен до „%s“"
+msgid "unable to open git dir: %s"
+msgstr "не може да се отвори директорията на git: %s"
 
-#: sequencer.c:3414
-msgid "cannot rebase: You have unstaged changes."
-msgstr "не може да пребазирате, защото има промени, които не са в индекса."
+#: read-cache.c:3154
+#, c-format
+msgid "unable to unlink: %s"
+msgstr "неуспешно изтриване на „%s“"
 
-#: sequencer.c:3423
-msgid "cannot amend non-existing commit"
-msgstr "несъществуващо подаване не може да се поправи"
+#: read-cache.c:3179
+#, c-format
+msgid "cannot fix permission bits on '%s'"
+msgstr "правата за достъп до „%s“ не могат да бъдат поправени"
 
-#: sequencer.c:3425
+#: read-cache.c:3328
 #, c-format
-msgid "invalid file: '%s'"
-msgstr "неправилен файл: „%s“"
+msgid "%s: cannot drop to stage #0"
+msgstr "%s: не може да се премине към етап №0"
 
-#: sequencer.c:3427
+#: rebase-interactive.c:26
 #, c-format
-msgid "invalid contents: '%s'"
-msgstr "неправилно съдържание: „%s“"
+msgid ""
+"unrecognized setting %s for option rebase.missingCommitsCheck. Ignoring."
+msgstr ""
+"Непозната стойност „%s“ за настройката „rebase.missingCommitsCheck“.  "
+"Настройката се прескача."
 
-#: sequencer.c:3430
+#: rebase-interactive.c:35
 msgid ""
 "\n"
-"You have uncommitted changes in your working tree. Please, commit them\n"
-"first and then run 'git rebase --continue' again."
+"Commands:\n"
+"p, pick <commit> = use commit\n"
+"r, reword <commit> = use commit, but edit the commit message\n"
+"e, edit <commit> = use commit, but stop for amending\n"
+"s, squash <commit> = use commit, but meld into previous commit\n"
+"f, fixup <commit> = like \"squash\", but discard this commit's log message\n"
+"x, exec <command> = run command (the rest of the line) using shell\n"
+"b, break = stop here (continue rebase later with 'git rebase --continue')\n"
+"d, drop <commit> = remove commit\n"
+"l, label <label> = label current HEAD with a name\n"
+"t, reset <label> = reset HEAD to a label\n"
+"m, merge [-C <commit> | -c <commit>] <label> [# <oneline>]\n"
+".       create a merge commit using the original merge commit's\n"
+".       message (or the oneline, if no original merge commit was\n"
+".       specified). Use -c <commit> to reword the commit message.\n"
+"\n"
+"These lines can be re-ordered; they are executed from top to bottom.\n"
 msgstr ""
 "\n"
-"В работното дърво има неподадени промени.  Първо ги подайте, а след това\n"
-"отново изпълнете „git rebase --continue“."
+"Команди:\n"
+" p, pick ПОДАВАНЕ   — прилагане на подаването\n"
+" r, reword ПОДАВАНЕ — прилагане на подаването, но смяна на съобщението му\n"
+" e, edit ПОДАВАНЕ   — прилагане на подаването и спиране при него за още "
+"промени\n"
+" s, squash ПОДАВАНЕ — вкарване на подаването в предходното му\n"
+" f, fixup ПОДАВАНЕ  — вкарване на подаването в предходното му, без смяна на\n"
+"                      съобщението\n"
+" x, exec ПОДАВАНЕ   — изпълнение на команда към обвивката: останалата част "
+"на\n"
+"                      реда\n"
+" b, break           — спиране (може да продължите пребазирането с командата\n"
+"                      „git rebase --continue“)\n"
+" d, drop ПОДАВАНЕ   — прескачане на подаването\n"
+" l, label ЕТИКЕТ    — задаване на етикет на указаното от HEAD\n"
+" t, reset ЕТИКЕТ    — зануляване на HEAD към ЕТИКЕТа\n"
+" m, merge [-C ПОДАВАНЕ | -c ПОДАВАНЕ] ЕТИКЕТ [# ЕДИН_РЕД]\n"
+"                    — създаване на подаване със сливане със съобщението от\n"
+"                      първоначалното подаване (или съобщението от ЕДИН_РЕД,\n"
+"                      ако не е зададено подаване със сливане.  С опцията\n"
+"                      „-c ПОДАВАНЕ“, може да смените съобщението.\n"
+"\n"
+"Може да променяте последователността на редовете — те се изпълняват\n"
+"последователно отгоре-надолу.\n"
 
-#: sequencer.c:3455 sequencer.c:3493
+#: rebase-interactive.c:56
 #, c-format
-msgid "could not write file: '%s'"
-msgstr "файлът „%s“ не може да бъде записан"
-
-#: sequencer.c:3508
-msgid "could not remove CHERRY_PICK_HEAD"
-msgstr "указателят „CHERRY_PICK_HEAD“ не може да бъде изтрит"
+msgid "Rebase %s onto %s (%d command)"
+msgid_plural "Rebase %s onto %s (%d commands)"
+msgstr[0] "Пребазиране на „%s“ върху „%s“ (%d команди)"
+msgstr[1] "Пребазиране на „%s“ върху „%s“ (%d команда)"
 
-#: sequencer.c:3515
-msgid "could not commit staged changes."
-msgstr "промените в индекса не могат да бъдат подадени."
-
-#: sequencer.c:3612
-#, c-format
-msgid "%s: can't cherry-pick a %s"
-msgstr "%s: не може да се отбере „%s“"
+#: rebase-interactive.c:65 git-rebase--preserve-merges.sh:228
+msgid ""
+"\n"
+"Do not remove any line. Use 'drop' explicitly to remove a commit.\n"
+msgstr ""
+"\n"
+"Не изтривайте редове.  Подаванията могат да се прескачат с командата "
+"„drop“.\n"
 
-#: sequencer.c:3616
-#, c-format
-msgid "%s: bad revision"
-msgstr "%s: неправилна версия"
+#: rebase-interactive.c:68 git-rebase--preserve-merges.sh:232
+msgid ""
+"\n"
+"If you remove a line here THAT COMMIT WILL BE LOST.\n"
+msgstr ""
+"\n"
+"Ако изтриете ред, съответстващото му подаване ще бъде ИЗТРИТО.\n"
 
-#: sequencer.c:3649
-msgid "can't revert as initial commit"
-msgstr "първоначалното подаване не може да бъде отменено"
+#: rebase-interactive.c:74 git-rebase--preserve-merges.sh:871
+msgid ""
+"\n"
+"You are editing the todo file of an ongoing interactive rebase.\n"
+"To continue rebase after editing, run:\n"
+"    git rebase --continue\n"
+"\n"
+msgstr ""
+"\n"
+"В момента редактирате файла с командите на текущото интерактивно "
+"пребазиране.\n"
+"За да продължите пребазирането след това, изпълнете:\n"
+"    git rebase --continue\n"
+"\n"
 
-#: sequencer.c:4098
-msgid "make_script: unhandled options"
-msgstr "make_script: неподдържани опции"
+#: rebase-interactive.c:79 git-rebase--preserve-merges.sh:948
+msgid ""
+"\n"
+"However, if you remove everything, the rebase will be aborted.\n"
+"\n"
+msgstr ""
+"\n"
+"Ако изтриете всичко, пребазирането ще бъде преустановено.\n"
+"\n"
 
-#: sequencer.c:4101
-msgid "make_script: error preparing revisions"
-msgstr "make_script: грешка при подготовката на версии"
+#: rebase-interactive.c:85 git-rebase--preserve-merges.sh:955
+msgid "Note that empty commits are commented out"
+msgstr "Празните подавания са коментирани"
 
-#: sequencer.c:4142 sequencer.c:4177
+#: rebase-interactive.c:105 rerere.c:485 rerere.c:692 sequencer.c:3536
+#: sequencer.c:3562 sequencer.c:5263 builtin/fsck.c:346 builtin/rebase.c:254
 #, c-format
-msgid "unusable todo list: '%s'"
-msgstr "неуспешно изтриване на списъка за изпълнение: „%s“"
+msgid "could not write '%s'"
+msgstr "„%s“ не може да се запише"
 
-#: sequencer.c:4236
+#: rebase-interactive.c:108
 #, c-format
-msgid ""
-"unrecognized setting %s for option rebase.missingCommitsCheck. Ignoring."
-msgstr ""
-"Непозната стойност „%s“ за настройката „rebase.missingCommitsCheck“.  "
-"Настройката се прескача."
+msgid "could not copy '%s' to '%s'."
+msgstr "„%s“ не може да се копира като „%s“."
 
-#: sequencer.c:4302
+#: rebase-interactive.c:173
 #, c-format
 msgid ""
 "Warning: some commits may have been dropped accidentally.\n"
@@ -4230,7 +5652,7 @@ msgstr ""
 "Предупреждение: някои подавания може да са пропуснати.\n"
 "Пропуснати подавания (новите са най-отгоре):\n"
 
-#: sequencer.c:4309
+#: rebase-interactive.c:180
 #, c-format
 msgid ""
 "To avoid this message, use \"drop\" to explicitly remove a commit.\n"
@@ -4247,8887 +5669,13208 @@ msgstr ""
 "предупреждение)\n"
 "или „error“ (считане за грешка).\n"
 
-#: sequencer.c:4321
+#: refs.c:262
 #, c-format
-msgid ""
-"You can fix this with 'git rebase --edit-todo' and then run 'git rebase --"
-"continue'.\n"
-"Or you can abort the rebase with 'git rebase --abort'.\n"
-msgstr ""
-"Може да промените това с командите „git rebase --edit-todo“ и „git rebase --"
-"continue“ след това.\n"
-"Може и да преустановите пребазирането с командата „git rebase --abort“.\n"
+msgid "%s does not point to a valid object!"
+msgstr "„%s“ не сочи към позволен обект!"
 
-#: sequencer.c:4375
+#: refs.c:667
 #, c-format
-msgid "could not parse commit '%s'"
-msgstr "подаването „%s“ не може да бъде анализирано"
+msgid "ignoring dangling symref %s"
+msgstr "игнориране на указател на обект извън клон „%s“"
 
-#: sequencer.c:4490
-msgid "the script was already rearranged."
-msgstr "скриптът вече е преподреден."
-
-#: setup.c:123
+#: refs.c:669 ref-filter.c:2098
 #, c-format
-msgid "'%s' is outside repository"
-msgstr "„%s“ е извън хранилището"
+msgid "ignoring broken ref %s"
+msgstr "игнориране на повредения указател „%s“"
 
-#: setup.c:172
+#: refs.c:804
 #, c-format
-msgid ""
-"%s: no such path in the working tree.\n"
-"Use 'git <command> -- <path>...' to specify paths that do not exist locally."
-msgstr ""
-"%s: в това работно дърво няма такъв път.\n"
-"За да указвате пътища, които локално не съществуват, използвайте:\n"
-"\n"
-"    git КОМАНДА -- ПЪТ…"
+msgid "could not open '%s' for writing: %s"
+msgstr "„%s“ не може да бъде отворен за запис: %s"
 
-#: setup.c:185
+#: refs.c:814 refs.c:865
 #, c-format
-msgid ""
-"ambiguous argument '%s': unknown revision or path not in the working tree.\n"
-"Use '--' to separate paths from revisions, like this:\n"
-"'git <command> [<revision>...] -- [<file>...]'"
-msgstr ""
-"нееднозначен аргумент „%s: непозната версия или пътят не е част от работното "
-"дърво.\n"
-"Разделяйте пътищата от версиите с „--“, ето така:\n"
-"\n"
-"    git КОМАНДА [ВЕРСИЯ…] -- [ФАЙЛ…]"
+msgid "could not read ref '%s'"
+msgstr "указателят „%s“ не може да се прочете"
 
-#: setup.c:234
+#: refs.c:820
 #, c-format
-msgid "option '%s' must come before non-option arguments"
-msgstr "опцията „%s“ трябва да е преди първия аргумент, който не е опция"
+msgid "ref '%s' already exists"
+msgstr "указателят „%s“ вече съществува"
 
-#: setup.c:253
+#: refs.c:825
 #, c-format
-msgid ""
-"ambiguous argument '%s': both revision and filename\n"
-"Use '--' to separate paths from revisions, like this:\n"
-"'git <command> [<revision>...] -- [<file>...]'"
-msgstr ""
-"нееднозначен аргумент „%s“: както версия, така и път.\n"
-"Разделяйте пътищата от версиите с „--“, ето така:\n"
-"\n"
-"    git КОМАНДА [ВЕРСИЯ…] -- [ФАЙЛ…]"
+msgid "unexpected object ID when writing '%s'"
+msgstr "неочакван идентификатор на обект при записването на „%s“"
 
-#: setup.c:389
-msgid "unable to set up work tree using invalid config"
-msgstr ""
-"не може да се зададе текуща работна директория при неправилни настройки"
-
-#: setup.c:393
-msgid "this operation must be run in a work tree"
-msgstr "тази команда трябва да се изпълни в работно дърво"
+#: refs.c:833 sequencer.c:405 sequencer.c:2793 sequencer.c:2997
+#: sequencer.c:3011 sequencer.c:3269 sequencer.c:5179 strbuf.c:1142
+#: wrapper.c:620
+#, c-format
+msgid "could not write to '%s'"
+msgstr "в „%s“ не може да се пише"
 
-#: setup.c:503
+#: refs.c:860 strbuf.c:1140 wrapper.c:188 wrapper.c:358 builtin/am.c:714
+#: builtin/rebase.c:1031
 #, c-format
-msgid "Expected git repo version <= %d, found %d"
-msgstr "Очаква се версия на хранилището на git <= %d, а не %d"
+msgid "could not open '%s' for writing"
+msgstr "„%s“ не може да бъде отворен за запис"
 
-#: setup.c:511
-msgid "unknown repository extensions found:"
-msgstr "открити са непознати разширения в хранилището:"
+#: refs.c:867
+#, c-format
+msgid "unexpected object ID when deleting '%s'"
+msgstr "неочакван идентификатор на обект при изтриването на „%s“"
 
-#: setup.c:530
+#: refs.c:998
 #, c-format
-msgid "error opening '%s'"
-msgstr "„%s“ не може да се отвори"
+msgid "log for ref %s has gap after %s"
+msgstr "има пропуски в журнала с подаванията за указателя „%s“ след „%s“"
 
-#: setup.c:532
+#: refs.c:1004
 #, c-format
-msgid "too large to be a .git file: '%s'"
-msgstr "прекалено голям файл „.git“: „%s“"
+msgid "log for ref %s unexpectedly ended on %s"
+msgstr "журналът с подаванията за указателя „%s“ свършва неочаквано след „%s“"
 
-#: setup.c:534
+#: refs.c:1063
 #, c-format
-msgid "error reading %s"
-msgstr "грешка при прочитане на „%s“"
+msgid "log for %s is empty"
+msgstr "журналът с подаванията за указателя „%s“ е празен"
 
-#: setup.c:536
+#: refs.c:1155
 #, c-format
-msgid "invalid gitfile format: %s"
-msgstr "неправилен формат на gitfile: %s"
+msgid "refusing to update ref with bad name '%s'"
+msgstr "указател не може да се обнови с грешно име „%s“"
 
-#: setup.c:538
+#: refs.c:1231
 #, c-format
-msgid "no path in gitfile: %s"
-msgstr "липсва път в gitfile: „%s“"
+msgid "update_ref failed for ref '%s': %s"
+msgstr "неуспешно обновяване на указателя „%s“: %s"
 
-#: setup.c:540
+#: refs.c:2023
 #, c-format
-msgid "not a git repository: %s"
-msgstr "не е хранилище на Git: %s"
+msgid "multiple updates for ref '%s' not allowed"
+msgstr "не са позволени повече от една промени на указателя „%s“"
 
-#: setup.c:639
+#: refs.c:2055
+msgid "ref updates forbidden inside quarantine environment"
+msgstr "обновяванията на указатели са забранени в среди под карантина"
+
+#: refs.c:2151 refs.c:2181
 #, c-format
-msgid "'$%s' too big"
-msgstr "„%s“ е прекалено голям"
+msgid "'%s' exists; cannot create '%s'"
+msgstr "„%s“ съществува, не може да се създаде „%s“"
 
-#: setup.c:653
+#: refs.c:2157 refs.c:2192
 #, c-format
-msgid "not a git repository: '%s'"
-msgstr "не е хранилище на git: „%s“"
+msgid "cannot process '%s' and '%s' at the same time"
+msgstr "невъзможно е едновременно да се обработват „%s“ и „%s“"
 
-#: setup.c:682 setup.c:684 setup.c:715
+#: refs/files-backend.c:1234
 #, c-format
-msgid "cannot chdir to '%s'"
-msgstr "не може да се влезе в директорията „%s“"
+msgid "could not remove reference %s"
+msgstr "Указателят „%s“ не може да бъде изтрит"
 
-#: setup.c:687 setup.c:743 setup.c:753 setup.c:792 setup.c:800 setup.c:815
-msgid "cannot come back to cwd"
-msgstr "процесът не може да се върне към предишната работна директория"
+#: refs/files-backend.c:1248 refs/packed-backend.c:1541
+#: refs/packed-backend.c:1551
+#, c-format
+msgid "could not delete reference %s: %s"
+msgstr "Указателят „%s“ не може да бъде изтрит: %s"
 
-#: setup.c:813
+#: refs/files-backend.c:1251 refs/packed-backend.c:1554
 #, c-format
-msgid "not a git repository (or any of the parent directories): %s"
-msgstr ""
-"нито тази, нито която и да е от по-горните директории, не е хранилище на "
-"git: %s"
+msgid "could not delete references: %s"
+msgstr "Указателите не може да бъдат изтрити: %s"
 
-#: setup.c:824
+#: refspec.c:137
 #, c-format
-msgid "failed to stat '%*s%s%s'"
-msgstr "не може да бъде получена информация чрез „stat“ за „%*s%s%s“"
+msgid "invalid refspec '%s'"
+msgstr "неправилен указател: „%s“"
 
-#: setup.c:1054
-msgid "Unable to read current working directory"
-msgstr "Текущата работна директория не може да бъде прочетена"
+#: ref-filter.c:42 wt-status.c:1938
+msgid "gone"
+msgstr "изтрит"
 
-#: setup.c:1066 setup.c:1072
+#: ref-filter.c:43
 #, c-format
-msgid "cannot change to '%s'"
-msgstr "не може да се влезе в директорията „%s“"
+msgid "ahead %d"
+msgstr "напред с %d"
 
-#: setup.c:1085
+#: ref-filter.c:44
 #, c-format
-msgid ""
-"not a git repository (or any parent up to mount point %s)\n"
-"Stopping at filesystem boundary (GIT_DISCOVERY_ACROSS_FILESYSTEM not set)."
-msgstr ""
-"нито тази, нито която и да е от по-горните директории (до точката на "
-"монтиране „%s“), не е хранилище на git.\n"
-"Git работи в рамките на една файлова система, защото променливата на средата "
-"„GIT_DISCOVERY_ACROSS_FILESYSTEM“ не е зададена."
+msgid "behind %d"
+msgstr "назад с %d"
 
-#: setup.c:1168
+#: ref-filter.c:45
 #, c-format
-msgid ""
-"problem with core.sharedRepository filemode value (0%.3o).\n"
-"The owner of files must always have read and write permissions."
-msgstr ""
-"зададеният в „core.sharedRepository“ режим за достъп до файлове е неправилен "
-"(0%.3o).\n"
-"Собственикът на файла трябва да има права за писане и четене."
+msgid "ahead %d, behind %d"
+msgstr "напред с %d, назад с %d"
 
-#: setup.c:1211
-msgid "open /dev/null or dup failed"
-msgstr "неуспешно изпълнение на „open“ или „dup“ върху „/dev/null“"
+#: ref-filter.c:165
+#, c-format
+msgid "expected format: %%(color:<color>)"
+msgstr "очакван формат: %%(color:ЦВЯТ)"
 
-#: setup.c:1226
-msgid "fork failed"
-msgstr "неуспешно изпълнение на „fork“"
+#: ref-filter.c:167
+#, c-format
+msgid "unrecognized color: %%(color:%s)"
+msgstr "непознат цвят: %%(color:%s)"
 
-#: setup.c:1231
-msgid "setsid failed"
-msgstr "неуспешно изпълнение на „setsid“"
-
-#: sha1-file.c:625
+#: ref-filter.c:189
 #, c-format
-msgid "path '%s' does not exist"
-msgstr "пътят „%s“ не съществува."
+msgid "Integer value expected refname:lstrip=%s"
+msgstr "очаква се цяло число за „refname:lstrip=%s“"
 
-#: sha1-file.c:651
+#: ref-filter.c:193
 #, c-format
-msgid "reference repository '%s' as a linked checkout is not supported yet."
-msgstr "все още не се поддържа еталонно хранилище „%s“ като свързано."
+msgid "Integer value expected refname:rstrip=%s"
+msgstr "очаква се цяло число за „refname:rstrip=%s“"
 
-#: sha1-file.c:657
+#: ref-filter.c:195
 #, c-format
-msgid "reference repository '%s' is not a local repository."
-msgstr "еталонното хранилище „%s“ не е локално"
+msgid "unrecognized %%(%s) argument: %s"
+msgstr "непознат аргумент за „%%(%s)“: %s"
 
-#: sha1-file.c:663
+#: ref-filter.c:250
 #, c-format
-msgid "reference repository '%s' is shallow"
-msgstr "еталонното хранилище „%s“ е плитко"
+msgid "%%(objecttype) does not take arguments"
+msgstr "%%(objecttype) не приема аргументи"
 
-#: sha1-file.c:671
+#: ref-filter.c:272
 #, c-format
-msgid "reference repository '%s' is grafted"
-msgstr "еталонното хранилище „%s“ е с присаждане"
+msgid "unrecognized %%(objectsize) argument: %s"
+msgstr "непознат аргумент за %%(objectsize): %s"
 
-#: sha1-name.c:442
+#: ref-filter.c:280
 #, c-format
-msgid "short SHA1 %s is ambiguous"
-msgstr "късият SHA1 „%s“ не е еднозначен"
+msgid "%%(deltabase) does not take arguments"
+msgstr "%%(deltabase) не приема аргументи"
 
-#: sha1-name.c:453
-msgid "The candidates are:"
-msgstr "Възможностите са:"
+#: ref-filter.c:292
+#, c-format
+msgid "%%(body) does not take arguments"
+msgstr "%%(body) не приема аргументи"
 
-#: sha1-name.c:695
-msgid ""
-"Git normally never creates a ref that ends with 40 hex characters\n"
-"because it will be ignored when you just specify 40-hex. These refs\n"
-"may be created by mistake. For example,\n"
-"\n"
-"  git checkout -b $br $(git rev-parse ...)\n"
-"\n"
-"where \"$br\" is somehow empty and a 40-hex ref is created. Please\n"
-"examine these refs and maybe delete them. Turn this message off by\n"
-"running \"git config advice.objectNameWarning false\""
-msgstr ""
-"При нормална работа Git никога не създава указатели, които завършват с 40\n"
-"шестнадесетични знака, защото стандартно те ще бъдат прескачани.\n"
-"Възможно е такива указатели да са създадени случайно.  Например:\n"
-"\n"
-"    git checkout -b $BRANCH $(git rev-parse…)\n"
-"\n"
-"където стойността на променливата на средата BRANCH е празна, при което се\n"
-"създава подобен указател.  Прегледайте тези указатели и ги изтрийте.  Можете "
-"да\n"
-"спрете това съобщение като изпълните командата:\n"
-"„git config advice.objectNameWarning false“"
+#: ref-filter.c:301
+#, c-format
+msgid "%%(subject) does not take arguments"
+msgstr "%%(subject) не приема аргументи"
 
-#: submodule.c:97 submodule.c:131
-msgid "Cannot change unmerged .gitmodules, resolve merge conflicts first"
-msgstr ""
-"Неслетите файлове „.gitmodules“ не могат да бъдат променяни.  Първо "
-"коригирайте конфликтите"
+#: ref-filter.c:323
+#, c-format
+msgid "unknown %%(trailers) argument: %s"
+msgstr "непознат аргумент „%%(trailers)“: %s"
 
-#: submodule.c:101 submodule.c:135
+#: ref-filter.c:352
 #, c-format
-msgid "Could not find section in .gitmodules where path=%s"
-msgstr "Във файла „.gitmodules“ липсва раздел за директория „path=%s“"
+msgid "positive value expected contents:lines=%s"
+msgstr "очаква се положителна стойност за „contents:lines=%s“"
 
-#: submodule.c:109
+#: ref-filter.c:354
 #, c-format
-msgid "Could not update .gitmodules entry %s"
-msgstr "Записът „%s“ във файла „.gitmodules“ не може да бъде променен"
+msgid "unrecognized %%(contents) argument: %s"
+msgstr "непознат аргумент за %%(contents): %s"
 
-#: submodule.c:142
+#: ref-filter.c:369
 #, c-format
-msgid "Could not remove .gitmodules entry for %s"
-msgstr "Записът „%s“ във файла „.gitmodules“ не може да бъде изтрит"
+msgid "positive value expected objectname:short=%s"
+msgstr "очаква се положителна стойност за „objectname:short=%s“"
 
-#: submodule.c:153
-msgid "staging updated .gitmodules failed"
-msgstr "неуспешно добавяне на променения файл „.gitmodules“ в индекса"
+#: ref-filter.c:373
+#, c-format
+msgid "unrecognized %%(objectname) argument: %s"
+msgstr "непознат аргумент за %%(objectname): %s"
 
-#: submodule.c:315
+#: ref-filter.c:403
 #, c-format
-msgid "in unpopulated submodule '%s'"
-msgstr "в неподготвения подмодул „%s“"
+msgid "expected format: %%(align:<width>,<position>)"
+msgstr "очакван формат: %%(align:ШИРОЧИНА,ПОЗИЦИЯ)"
 
-#: submodule.c:346
+#: ref-filter.c:415
 #, c-format
-msgid "Pathspec '%s' is in submodule '%.*s'"
-msgstr "Пътят „%s“ е в подмодула „%.*s“"
+msgid "unrecognized position:%s"
+msgstr "непозната позиция: %s"
 
-#: submodule.c:837
+#: ref-filter.c:422
 #, c-format
-msgid "submodule entry '%s' (%s) is a %s, not a commit"
-msgstr "записът за подмодула „%s“ (%s) е %s, а не подаване!"
+msgid "unrecognized width:%s"
+msgstr "непозната широчина: %s"
 
-#: submodule.c:1069 builtin/branch.c:651 builtin/submodule--helper.c:1743
-msgid "Failed to resolve HEAD as a valid ref."
-msgstr "Не може да се открие към какво сочи указателят „HEAD“"
+#: ref-filter.c:431
+#, c-format
+msgid "unrecognized %%(align) argument: %s"
+msgstr "непознат аргумент за %%(align): %s"
 
-#: submodule.c:1375
+#: ref-filter.c:439
 #, c-format
-msgid "'%s' not recognized as a git repository"
-msgstr "„%s“ не е хранилище на git"
+msgid "positive width expected with the %%(align) atom"
+msgstr "очаква се положителна широчина с лексемата „%%(align)“"
 
-#: submodule.c:1513
+#: ref-filter.c:457
 #, c-format
-msgid "could not start 'git status' in submodule '%s'"
-msgstr "командата „git status“ не може да се изпълни в подмодула „%s“"
+msgid "unrecognized %%(if) argument: %s"
+msgstr "непознат аргумент за „%%(if)“: %s"
 
-#: submodule.c:1526
+#: ref-filter.c:559
 #, c-format
-msgid "could not run 'git status' in submodule '%s'"
-msgstr "командата „git status“ не може да се изпълни в подмодула „%s“"
+msgid "malformed field name: %.*s"
+msgstr "неправилно име на обект: „%.*s“"
 
-#: submodule.c:1619
+#: ref-filter.c:586
 #, c-format
-msgid "submodule '%s' has dirty index"
-msgstr "индексът на подмодула „%s“ не е чист"
+msgid "unknown field name: %.*s"
+msgstr "непознато име на обект: „%.*s“"
 
-#: submodule.c:1718
+#: ref-filter.c:590
 #, c-format
 msgid ""
-"relocate_gitdir for submodule '%s' with more than one worktree not supported"
-msgstr ""
-"не се поддържа „relocate_gitdir“ за подмодула „%s“, който има повече от едно "
-"работно дърво"
+"not a git repository, but the field '%.*s' requires access to object data"
+msgstr "не е хранилище на git, а полето „%.*s“ изисква достъп данни на обектни"
 
-#: submodule.c:1730 submodule.c:1786
+#: ref-filter.c:714
 #, c-format
-msgid "could not lookup name for submodule '%s'"
-msgstr "името на подмодула „%s“ не може да бъде намерено"
+msgid "format: %%(if) atom used without a %%(then) atom"
+msgstr "формат: лексемата %%(if) е използвана без съответната ѝ %%(then)"
 
-#: submodule.c:1734 builtin/submodule--helper.c:1261
-#: builtin/submodule--helper.c:1271
+#: ref-filter.c:777
 #, c-format
-msgid "could not create directory '%s'"
-msgstr "Директорията „%s“ не може да бъде създадена"
+msgid "format: %%(then) atom used without an %%(if) atom"
+msgstr "формат: лексемата %%(then) е използвана без съответната ѝ %%(if)"
 
-#: submodule.c:1737
+#: ref-filter.c:779
 #, c-format
-msgid ""
-"Migrating git directory of '%s%s' from\n"
-"'%s' to\n"
-"'%s'\n"
-msgstr ""
-"Мигриране на директорията на git — „%s%s“ от:\n"
-"„%s“ към\n"
-"„%s“\n"
+msgid "format: %%(then) atom used more than once"
+msgstr "формат: лексемата %%(then) е използвана повече от един път"
 
-#: submodule.c:1821
+#: ref-filter.c:781
 #, c-format
-msgid "could not recurse into submodule '%s'"
-msgstr "неуспешна обработка на поддиректориите в подмодула „%s“"
+msgid "format: %%(then) atom used after %%(else)"
+msgstr "формат: лексемата %%(then) е използвана след %%(else)"
 
-#: submodule.c:1865
-msgid "could not start ls-files in .."
-msgstr "„ls-stat“ не може да се стартира в „..“"
+#: ref-filter.c:809
+#, c-format
+msgid "format: %%(else) atom used without an %%(if) atom"
+msgstr "формат: лексемата %%(else) е използвана без съответната ѝ %%(if)"
 
-#: submodule.c:1904
+#: ref-filter.c:811
 #, c-format
-msgid "ls-tree returned unexpected return code %d"
-msgstr "„ls-tree“ завърши с неочакван изходен код: %d"
+msgid "format: %%(else) atom used without a %%(then) atom"
+msgstr "формат: лексемата %%(else) е използвана без съответната ѝ %%(then)"
 
-#: submodule-config.c:230
+#: ref-filter.c:813
 #, c-format
-msgid "ignoring suspicious submodule name: %s"
-msgstr "игнориране на подозрително име на подмодул: „%s“"
+msgid "format: %%(else) atom used more than once"
+msgstr "формат: лексемата %%(else) е използвана повече от един път"
 
-#: submodule-config.c:294
-msgid "negative values not allowed for submodule.fetchjobs"
-msgstr "настройката „submodule.fetchjobs“ не приема отрицателни стойности"
+#: ref-filter.c:828
+#, c-format
+msgid "format: %%(end) atom used without corresponding atom"
+msgstr "формат: лексемата %%(end) е използвана без съответната ѝ"
 
-#: submodule-config.c:467
+#: ref-filter.c:885
 #, c-format
-msgid "invalid value for %s"
-msgstr "Неправилна стойност за „%s“"
+msgid "malformed format string %s"
+msgstr "неправилен форматиращ низ „%s“"
 
-#: trailer.c:238
+#: ref-filter.c:1488
 #, c-format
-msgid "running trailer command '%s' failed"
-msgstr "неуспешно изпълнение на завършващата команда „%s“"
+msgid "no branch, rebasing %s"
+msgstr "извън клон, пребазиране на „%s“"
 
-#: trailer.c:485 trailer.c:490 trailer.c:495 trailer.c:549 trailer.c:553
-#: trailer.c:557
+#: ref-filter.c:1491
 #, c-format
-msgid "unknown value '%s' for key '%s'"
-msgstr "непозната стойност „%s“ за настройката „%s“"
+msgid "no branch, rebasing detached HEAD %s"
+msgstr "извън клон, пребазиране на несвързан указател „HEAD“ при „%s“"
 
-#: trailer.c:539 trailer.c:544 builtin/remote.c:293
+#: ref-filter.c:1494
 #, c-format
-msgid "more than one %s"
-msgstr "стойността „%s“ се повтаря в настройките"
+msgid "no branch, bisect started on %s"
+msgstr "извън клон, двоично търсене от „%s“"
 
-#: trailer.c:730
+#: ref-filter.c:1504
+msgid "no branch"
+msgstr "извън клон"
+
+#: ref-filter.c:1540 ref-filter.c:1749
 #, c-format
-msgid "empty trailer token in trailer '%.*s'"
-msgstr "празна завършваща лексема в епилога „%.*s“"
+msgid "missing object %s for %s"
+msgstr "обектът „%s“ липсва за „%s“"
 
-#: trailer.c:750
+#: ref-filter.c:1550
 #, c-format
-msgid "could not read input file '%s'"
-msgstr "входният файл „%s“ не може да бъде прочетен"
+msgid "parse_object_buffer failed on %s for %s"
+msgstr "неуспешно анализиране чрез „parse_object_buffer“ на „%s“ за „%s“"
 
-#: trailer.c:753
-msgid "could not read from stdin"
-msgstr "от стандартния вход не може да се чете"
+#: ref-filter.c:2004
+#, c-format
+msgid "malformed object at '%s'"
+msgstr "обект със сгрешен формат при „%s“"
 
-#: trailer.c:1008 builtin/am.c:46
+#: ref-filter.c:2093
 #, c-format
-msgid "could not stat %s"
-msgstr "Не може да се получи информация чрез „stat“ за „%s“"
+msgid "ignoring ref with broken name %s"
+msgstr "игнориране на указателя с грешно име „%s“"
 
-#: trailer.c:1010
+#: ref-filter.c:2389
 #, c-format
-msgid "file %s is not a regular file"
-msgstr "„%s“ не е обикновен файл"
+msgid "format: %%(end) atom missing"
+msgstr "грешка във форма̀та: липсва лексемата %%(end)"
 
-#: trailer.c:1012
+#: ref-filter.c:2489
 #, c-format
-msgid "file %s is not writable by user"
-msgstr "„%s“: няма права за записване на файла"
+msgid "option `%s' is incompatible with --merged"
+msgstr "опциите „%s“ и „--merged“ са несъвместими"
 
-#: trailer.c:1024
-msgid "could not open temporary file"
-msgstr "временният файл не може да се отвори"
+#: ref-filter.c:2492
+#, c-format
+msgid "option `%s' is incompatible with --no-merged"
+msgstr "опциите „%s“ и „--no-merged“ са несъвместими"
 
-#: trailer.c:1064
+#: ref-filter.c:2502
 #, c-format
-msgid "could not rename temporary file to %s"
-msgstr "временният файл не може да се преименува на „%s“"
+msgid "malformed object name %s"
+msgstr "неправилно име на обект „%s“"
 
-#: transport.c:116
+#: ref-filter.c:2507
 #, c-format
-msgid "Would set upstream of '%s' to '%s' of '%s'\n"
-msgstr "Клонът „%s“ ще следи „%s“ от „%s“\n"
+msgid "option `%s' must point to a commit"
+msgstr "опцията „%s“ не сочи към подаване"
 
-#: transport.c:208
+#: remote.c:366
 #, c-format
-msgid "transport: invalid depth option '%s'"
-msgstr "transport: неправилна опция за дълбочина: %s"
+msgid "config remote shorthand cannot begin with '/': %s"
+msgstr ""
+"съкращението за отдалечено хранилище не може за започва със знака „/“: %s"
 
-#: transport.c:584
-msgid "could not parse transport.color.* config"
-msgstr "стойността на настройката „transport.color.*“ не може да се разпознае"
+#: remote.c:413
+msgid "more than one receivepack given, using the first"
+msgstr "зададен е повече от един пакет за получаване, ще се ползва първият"
 
-#: transport.c:996
+#: remote.c:421
+msgid "more than one uploadpack given, using the first"
+msgstr "зададен е повече от един пакет за изпращане, ще се ползва първият"
+
+#: remote.c:611
 #, c-format
-msgid ""
-"The following submodule paths contain changes that can\n"
-"not be found on any remote:\n"
-msgstr ""
-"Следните пътища за подмодули съдържат промени,\n"
-"които липсват от всички отдалечени хранилища:\n"
+msgid "Cannot fetch both %s and %s to %s"
+msgstr "Невъзможно е да се доставят едновременно и „%s“, и „%s“ към „%s“"
+
+#: remote.c:615
+#, c-format
+msgid "%s usually tracks %s, not %s"
+msgstr "„%s“ обикновено следи „%s“, а не „%s“"
+
+#: remote.c:619
+#, c-format
+msgid "%s tracks both %s and %s"
+msgstr "„%s“ следи както „%s“, така и „%s“"
+
+#: remote.c:687
+#, c-format
+msgid "key '%s' of pattern had no '*'"
+msgstr "ключ „%s“ на шаблона не съдържа „*“"
+
+#: remote.c:697
+#, c-format
+msgid "value '%s' of pattern has no '*'"
+msgstr "стойност „%s“ на шаблона не съдържа „*“"
+
+#: remote.c:1003
+#, c-format
+msgid "src refspec %s does not match any"
+msgstr "указателят на версия-източник „%s“ не съвпада с никой обект"
+
+#: remote.c:1008
+#, c-format
+msgid "src refspec %s matches more than one"
+msgstr "указателят на версия-източник „%s“ съвпада с повече от един обект"
 
-#: transport.c:1000
+#. TRANSLATORS: "matches '%s'%" is the <dst> part of "git push
+#. <remote> <src>:<dst>" push, and "being pushed ('%s')" is
+#. the <src>.
+#.
+#: remote.c:1023
 #, c-format
 msgid ""
+"The destination you provided is not a full refname (i.e.,\n"
+"starting with \"refs/\"). We tried to guess what you meant by:\n"
 "\n"
-"Please try\n"
-"\n"
-"\tgit push --recurse-submodules=on-demand\n"
-"\n"
-"or cd to the path and use\n"
-"\n"
-"\tgit push\n"
-"\n"
-"to push them to a remote.\n"
+"- Looking for a ref that matches '%s' on the remote side.\n"
+"- Checking if the <src> being pushed ('%s')\n"
+"  is a ref in \"refs/{heads,tags}/\". If so we add a corresponding\n"
+"  refs/{heads,tags}/ prefix on the remote side.\n"
 "\n"
+"Neither worked, so we gave up. You must fully qualify the ref."
 msgstr ""
+"Зададената цел не е пълно име на указател (не започва с „refs/“).\n"
+"Бяха пробвани следните варианти:\n"
 "\n"
-"Пробвайте да ги изтласкате чрез командата:\n"
-"\n"
-"    git push --recurse-submodules=on-demand\n"
-"\n"
-"или отидете в съответната директория и изпълнете:\n"
-"\n"
-"    git push\n"
+"  ⁃ указател от отдалеченото хранилище, който да съответства на „%s“;\n"
+"  ⁃ дали изтласкваният ИЗТОЧНИК („%s“) е указател в „refs/{heads,tags}/“.\n"
+"    При съвпадение се добавя съответен префикс „refs/{heads,tags}/“ за\n"
+"    отдалеченото хранилище.\n"
 "\n"
+"Никой от вариантите не сработи.  Трябва сами да укажете пълното име на\n"
+"указателя."
 
-#: transport.c:1008
-msgid "Aborting."
-msgstr "Преустановяване на действието."
+#: remote.c:1043
+#, c-format
+msgid ""
+"The <src> part of the refspec is a commit object.\n"
+"Did you mean to create a new branch by pushing to\n"
+"'%s:refs/heads/%s'?"
+msgstr ""
+"ИЗТОЧНИКът е обект-подаване.  Не целите ли всъщност да създадете нов клон "
+"като\n"
+"изтласкате към „%s:refs/heads/%s“?"
 
-#: transport-helper.c:1087
+#: remote.c:1048
 #, c-format
-msgid "Could not read ref %s"
-msgstr "Указателят „%s“ не може да се прочете."
+msgid ""
+"The <src> part of the refspec is a tag object.\n"
+"Did you mean to create a new tag by pushing to\n"
+"'%s:refs/tags/%s'?"
+msgstr ""
+"ИЗТОЧНИКът е обект-етикет.  Не целите ли всъщност да създадете нов клон "
+"като\n"
+"изтласкате към „%s:refs/tags/%s“?"
 
-#: tree-walk.c:31
-msgid "too-short tree object"
-msgstr "прекалено кратък обект-дърво"
-
-#: tree-walk.c:37
-msgid "malformed mode in tree entry"
-msgstr "неправилни права за достъп в запис в дърво"
-
-#: tree-walk.c:41
-msgid "empty filename in tree entry"
-msgstr "празно име на файл в запис в дърво"
-
-#: tree-walk.c:113
-msgid "too-short tree file"
-msgstr "прекалено кратък файл-дърво"
-
-#: unpack-trees.c:111
+#: remote.c:1053
 #, c-format
 msgid ""
-"Your local changes to the following files would be overwritten by checkout:\n"
-"%%sPlease commit your changes or stash them before you switch branches."
+"The <src> part of the refspec is a tree object.\n"
+"Did you mean to tag a new tree by pushing to\n"
+"'%s:refs/tags/%s'?"
 msgstr ""
-"Изтеглянето ще презапише локалните промени на тези файлове:\n"
-"%%sПодайте или скатайте промените, за да преминете към нов клон."
+"ИЗТОЧНИКът е обект-дърво.  Не целите ли всъщност да създадете нов клон като\n"
+"изтласкате към „%s:refs/tags/%s“?"
 
-#: unpack-trees.c:113
+#: remote.c:1058
 #, c-format
 msgid ""
-"Your local changes to the following files would be overwritten by checkout:\n"
-"%%s"
+"The <src> part of the refspec is a blob object.\n"
+"Did you mean to tag a new blob by pushing to\n"
+"'%s:refs/tags/%s'?"
 msgstr ""
-"Изтеглянето ще презапише локалните промени на тези файлове:\n"
-"%%s"
+"ИЗТОЧНИКът е обект-BLOB.  Не целите ли всъщност да създадете нов клон като\n"
+"изтласкате към „%s:refs/tags/%s“?"
 
-#: unpack-trees.c:116
+#: remote.c:1094
 #, c-format
-msgid ""
-"Your local changes to the following files would be overwritten by merge:\n"
-"%%sPlease commit your changes or stash them before you merge."
-msgstr ""
-"Сливането ще презапише локалните промени на тези файлове:\n"
-"%%sПодайте или скатайте промените, за да слеете."
+msgid "%s cannot be resolved to branch"
+msgstr "не е открит клон съответстващ на „%s“"
 
-#: unpack-trees.c:118
+#: remote.c:1105
 #, c-format
-msgid ""
-"Your local changes to the following files would be overwritten by merge:\n"
-"%%s"
-msgstr ""
-"Сливането ще презапише локалните промени на тези файлове:\n"
-"%%s"
+msgid "unable to delete '%s': remote ref does not exist"
+msgstr "„%s“ не може да се изтрие: отдалечения указател не съществува"
 
-#: unpack-trees.c:121
+#: remote.c:1117
 #, c-format
-msgid ""
-"Your local changes to the following files would be overwritten by %s:\n"
-"%%sPlease commit your changes or stash them before you %s."
-msgstr ""
-"„%s“ ще презапише локалните промени на тези файлове:\n"
-"%%sПодайте или скатайте промените, за да извършите „%s“."
+msgid "dst refspec %s matches more than one"
+msgstr "указателят на версия-цел „%s“ съвпада с повече от един обект"
 
-#: unpack-trees.c:123
+#: remote.c:1124
 #, c-format
-msgid ""
-"Your local changes to the following files would be overwritten by %s:\n"
-"%%s"
+msgid "dst ref %s receives from more than one src"
 msgstr ""
-"„%s“ ще презапише локалните промени на тези файлове:\n"
-"%%s"
+"указателят на версия-цел „%s“ съответства и ще получава от повече от един "
+"източник"
 
-#: unpack-trees.c:128
-#, c-format
-msgid ""
-"Updating the following directories would lose untracked files in them:\n"
-"%s"
-msgstr ""
-"Обновяването на следните директории ще изтрие неследените файлове в тях:\n"
-"%s"
+#: remote.c:1627 remote.c:1728
+msgid "HEAD does not point to a branch"
+msgstr "Указателят „HEAD“ не сочи към клон"
 
-#: unpack-trees.c:132
+#: remote.c:1636
 #, c-format
-msgid ""
-"The following untracked working tree files would be removed by checkout:\n"
-"%%sPlease move or remove them before you switch branches."
-msgstr ""
-"Изтеглянето ще изтрие тези неследени файлове в работното дърво:\n"
-"%%sПреместете ги или ги изтрийте, за да преминете на друг клон."
+msgid "no such branch: '%s'"
+msgstr "няма клон на име „%s“"
 
-#: unpack-trees.c:134
+#: remote.c:1639
 #, c-format
-msgid ""
-"The following untracked working tree files would be removed by checkout:\n"
-"%%s"
-msgstr ""
-"Изтеглянето ще изтрие тези неследени файлове в работното дърво:\n"
-"%%s"
+msgid "no upstream configured for branch '%s'"
+msgstr "не е зададен клон-източник за клона „%s“"
 
-#: unpack-trees.c:137
+#: remote.c:1645
 #, c-format
-msgid ""
-"The following untracked working tree files would be removed by merge:\n"
-"%%sPlease move or remove them before you merge."
-msgstr ""
-"Сливането ще изтрие тези неследени файлове в работното дърво:\n"
-"%%sПреместете ги или ги изтрийте, за да слеете."
+msgid "upstream branch '%s' not stored as a remote-tracking branch"
+msgstr "клонът-източник „%s“ не е съхранен като следящ клон"
 
-#: unpack-trees.c:139
+#: remote.c:1660
 #, c-format
-msgid ""
-"The following untracked working tree files would be removed by merge:\n"
-"%%s"
+msgid "push destination '%s' on remote '%s' has no local tracking branch"
 msgstr ""
-"Сливането ще изтрие тези неследени файлове в работното дърво:\n"
-"%%s"
+"липсва локален следящ клон за местоположението за изтласкване „%s“ в "
+"хранилището „%s“"
 
-#: unpack-trees.c:142
+#: remote.c:1672
 #, c-format
-msgid ""
-"The following untracked working tree files would be removed by %s:\n"
-"%%sPlease move or remove them before you %s."
-msgstr ""
-"„%s“ ще изтрие тези неследени файлове в работното дърво:\n"
-"%%sПреместете ги или ги изтрийте, за да извършите „%s“."
+msgid "branch '%s' has no remote for pushing"
+msgstr "няма информация клонът „%s“ да следи някой друг"
 
-#: unpack-trees.c:144
+#: remote.c:1682
 #, c-format
-msgid ""
-"The following untracked working tree files would be removed by %s:\n"
-"%%s"
-msgstr ""
-"„%s“ ще изтрие тези неследени файлове в работното дърво:\n"
-"%%s"
+msgid "push refspecs for '%s' do not include '%s'"
+msgstr "указателят за изтласкване на „%s“ не включва „%s“"
 
-#: unpack-trees.c:150
-#, c-format
-msgid ""
-"The following untracked working tree files would be overwritten by "
-"checkout:\n"
-"%%sPlease move or remove them before you switch branches."
-msgstr ""
-"Изтеглянето ще презапише тези неследени файлове в работното дърво:\n"
-"%%sПреместете ги или ги изтрийте, за да смените клон."
+#: remote.c:1695
+msgid "push has no destination (push.default is 'nothing')"
+msgstr "указателят за изтласкване не включва цел („push.default“ е „nothing“)"
 
-#: unpack-trees.c:152
-#, c-format
-msgid ""
-"The following untracked working tree files would be overwritten by "
-"checkout:\n"
-"%%s"
-msgstr ""
-"Изтеглянето ще презапише тези неследени файлове в работното дърво:\n"
-"%%s"
+#: remote.c:1717
+msgid "cannot resolve 'simple' push to a single destination"
+msgstr "простото (simple) изтласкване не съответства на една цел"
 
-#: unpack-trees.c:155
+#: remote.c:1843
 #, c-format
-msgid ""
-"The following untracked working tree files would be overwritten by merge:\n"
-"%%sPlease move or remove them before you merge."
-msgstr ""
-"Сливането ще презапише тези неследени файлове в работното дърво:\n"
-"%%sПреместете ги или ги изтрийте, за да слеете."
+msgid "couldn't find remote ref %s"
+msgstr "отдалеченият указател „%s“ не може да бъде открит"
 
-#: unpack-trees.c:157
+#: remote.c:1856
 #, c-format
-msgid ""
-"The following untracked working tree files would be overwritten by merge:\n"
-"%%s"
-msgstr ""
-"Сливането ще презапише тези неследени файлове в работното дърво:\n"
-"%%s"
+msgid "* Ignoring funny ref '%s' locally"
+msgstr "• прескачане на неочаквания локален указател „%s“"
 
-#: unpack-trees.c:160
+#: remote.c:2019
 #, c-format
-msgid ""
-"The following untracked working tree files would be overwritten by %s:\n"
-"%%sPlease move or remove them before you %s."
-msgstr ""
-"„%s“ ще презапише тези неследени файлове в работното дърво:\n"
-"%%sПреместете ги или ги изтрийте, за да извършите „%s“."
+msgid "Your branch is based on '%s', but the upstream is gone.\n"
+msgstr "Този клон следи „%s“, но следеният клон е изтрит.\n"
+
+#: remote.c:2023
+msgid "  (use \"git branch --unset-upstream\" to fixup)\n"
+msgstr "  (за да коригирате това, използвайте „git branch --unset-upstream“)\n"
 
-#: unpack-trees.c:162
+#: remote.c:2026
 #, c-format
-msgid ""
-"The following untracked working tree files would be overwritten by %s:\n"
-"%%s"
-msgstr ""
-"„%s“ ще презапише тези неследени файлове в работното дърво:\n"
-"%%s"
+msgid "Your branch is up to date with '%s'.\n"
+msgstr "Клонът е актуализиран към „%s“.\n"
 
-#: unpack-trees.c:170
+#: remote.c:2030
 #, c-format
-msgid "Entry '%s' overlaps with '%s'.  Cannot bind."
-msgstr "Записът за „%s“ съвпада с този за „%s“.  Не може да се присвои."
+msgid "Your branch and '%s' refer to different commits.\n"
+msgstr "Клонът ви и „%s“ сочат към различни подавания.\n"
 
-#: unpack-trees.c:173
+#: remote.c:2033
 #, c-format
-msgid ""
-"Cannot update sparse checkout: the following entries are not up to date:\n"
-"%s"
-msgstr ""
-"Частичното изтегляне не може да бъде обновено: следните записи не са "
-"актуални:\n"
-"%s"
+msgid "  (use \"%s\" for details)\n"
+msgstr "  (за повече информация ползвайте „%s“)\n"
 
-#: unpack-trees.c:175
+#: remote.c:2037
 #, c-format
-msgid ""
-"The following working tree files would be overwritten by sparse checkout "
-"update:\n"
-"%s"
-msgstr ""
-"Обновяването на частичното изтегляне ще презапише тези файлове в работното "
-"дърво:\n"
-"%s"
+msgid "Your branch is ahead of '%s' by %d commit.\n"
+msgid_plural "Your branch is ahead of '%s' by %d commits.\n"
+msgstr[0] "Клонът ви е с %2$d подаване пред „%1$s“.\n"
+msgstr[1] "Клонът ви е с %2$d подавания пред „%1$s“.\n"
+
+#: remote.c:2043
+msgid "  (use \"git push\" to publish your local commits)\n"
+msgstr "  (публикувайте локалните си промени чрез „git push“)\n"
 
-#: unpack-trees.c:177
+#: remote.c:2046
 #, c-format
-msgid ""
-"The following working tree files would be removed by sparse checkout "
-"update:\n"
-"%s"
-msgstr ""
-"Обновяването на частичното изтегляне ще изтрие тези файлове в работното "
-"дърво:\n"
-"%s"
+msgid "Your branch is behind '%s' by %d commit, and can be fast-forwarded.\n"
+msgid_plural ""
+"Your branch is behind '%s' by %d commits, and can be fast-forwarded.\n"
+msgstr[0] "Клонът ви е с %2$d подаване зад „%1$s“ и може да бъде превъртян.\n"
+msgstr[1] "Клонът ви е с %2$d подавания зад „%1$s“ и може да бъде превъртян.\n"
+
+#: remote.c:2054
+msgid "  (use \"git pull\" to update your local branch)\n"
+msgstr "  (обновете локалния си клон чрез „git pull“)\n"
 
-#: unpack-trees.c:179
+#: remote.c:2057
 #, c-format
 msgid ""
-"Cannot update submodule:\n"
-"%s"
-msgstr ""
-"Подмодулът не може да бъде обновен:\n"
-"„%s“"
+"Your branch and '%s' have diverged,\n"
+"and have %d and %d different commit each, respectively.\n"
+msgid_plural ""
+"Your branch and '%s' have diverged,\n"
+"and have %d and %d different commits each, respectively.\n"
+msgstr[0] ""
+"Текущият клон се е отделил от „%s“,\n"
+"двата имат съответно по %d и %d несъвпадащи подавания.\n"
+msgstr[1] ""
+"Текущият клон се е отделил от „%s“,\n"
+"двата имат съответно по %d и %d несъвпадащи подавания.\n"
+
+#: remote.c:2067
+msgid "  (use \"git pull\" to merge the remote branch into yours)\n"
+msgstr "  (слейте отдалечения клон в локалния чрез „git pull“)\n"
 
-#: unpack-trees.c:262
+#: remote.c:2250
 #, c-format
-msgid "Aborting\n"
-msgstr "Преустановяване на действието\n"
+msgid "cannot parse expected object name '%s'"
+msgstr "очакваното име на обект „%s“ не може да бъде анализирано"
 
-#: unpack-trees.c:344
-msgid "Checking out files"
-msgstr "Изтегляне на файлове"
+#: replace-object.c:21
+#, c-format
+msgid "bad replace ref name: %s"
+msgstr "неправилно име на указател за замяна: „%s“"
 
-#: urlmatch.c:163
-msgid "invalid URL scheme name or missing '://' suffix"
-msgstr "неправилна схема за адрес или суфиксът „://“ липсва"
+#: replace-object.c:30
+#, c-format
+msgid "duplicate replace ref: %s"
+msgstr "повтарящ се указател за замяна: „%s“"
 
-#: urlmatch.c:187 urlmatch.c:346 urlmatch.c:405
+#: replace-object.c:73
 #, c-format
-msgid "invalid %XX escape sequence"
-msgstr "неправилна екранираща последователност „%XX“"
+msgid "replace depth too high for object %s"
+msgstr "дълбочината на замяна е прекалено голяма за обекта: „%s“"
 
-#: urlmatch.c:215
-msgid "missing host and scheme is not 'file:'"
-msgstr "не е указана машина, а схемата не е „file:“"
+#: rerere.c:217 rerere.c:226 rerere.c:229
+msgid "corrupt MERGE_RR"
+msgstr "повреден „MERGE_RR“ (запис за коригиране на конфликт)"
 
-#: urlmatch.c:232
-msgid "a 'file:' URL may not have a port number"
-msgstr "при схема „file:“ не можете да указвате номер на порт"
+#: rerere.c:264 rerere.c:269
+msgid "unable to write rerere record"
+msgstr "приложеното коригиране на конфликт не може да бъде записано"
 
-#: urlmatch.c:247
-msgid "invalid characters in host name"
-msgstr "неправилни знаци в името на машина"
+#: rerere.c:495
+#, c-format
+msgid "there were errors while writing '%s' (%s)"
+msgstr "грешки при записването на „%s“ (%s)"
 
-#: urlmatch.c:292 urlmatch.c:303
-msgid "invalid port number"
-msgstr "неправилен номер на порт"
+#: rerere.c:498
+#, c-format
+msgid "failed to flush '%s'"
+msgstr "грешка при изчистването на буферите при записването на „%s“"
 
-#: urlmatch.c:371
-msgid "invalid '..' path segment"
-msgstr "неправилна част от пътя „..“"
+#: rerere.c:503 rerere.c:1039
+#, c-format
+msgid "could not parse conflict hunks in '%s'"
+msgstr "парчетата с конфликти в „%s“ не може да се анализират"
 
-#: worktree.c:245 builtin/am.c:2147
+#: rerere.c:684
 #, c-format
-msgid "failed to read '%s'"
-msgstr "„%s“ не може да бъде прочетен"
+msgid "failed utime() on '%s'"
+msgstr "неуспешно задаване на време на достъп/създаване чрез „utime“ на „%s“"
 
-#: worktree.c:291
+#: rerere.c:694
 #, c-format
-msgid "'%s' at main working tree is not the repository directory"
-msgstr "„%s“ в основното работно дърво не е директорията на хранилището"
+msgid "writing '%s' failed"
+msgstr "неуспешен запис на „%s“"
 
-#: worktree.c:302
+#: rerere.c:714
 #, c-format
-msgid "'%s' file does not contain absolute path to the working tree location"
+msgid "Staged '%s' using previous resolution."
 msgstr ""
-"файлът „%s“ не съдържа абсолютния път към местоположението на работното дърво"
+"„%s“ е добавен към индекса с преизползване на запазена корекция при сливане"
 
-#: worktree.c:314
+#: rerere.c:753
 #, c-format
-msgid "'%s' does not exist"
-msgstr "„%s“ не съществува."
+msgid "Recorded resolution for '%s'."
+msgstr "Корекцията на конфликта при сливане на „%s“ е запазена."
 
-#: worktree.c:320
+#: rerere.c:788
 #, c-format
-msgid "'%s' is not a .git file, error code %d"
-msgstr "„%s“ не е файл на .git, код за грешка: %d"
+msgid "Resolved '%s' using previous resolution."
+msgstr ""
+"Конфликтът при сливане на „%s“ е коригиран с преизползване на предишна "
+"корекция."
 
-#: worktree.c:328
+#: rerere.c:803
 #, c-format
-msgid "'%s' does not point back to '%s'"
-msgstr "„%s“ не сочи към обратно към „%s“"
+msgid "cannot unlink stray '%s'"
+msgstr "излишният обект „%s“ не може да се изтрие"
 
-#: wrapper.c:223 wrapper.c:393
+#: rerere.c:807
 #, c-format
-msgid "could not open '%s' for reading and writing"
-msgstr "„%s“ не може да бъде отворен и за четене, и за запис"
+msgid "Recorded preimage for '%s'"
+msgstr "Предварителният вариант на „%s“ е запазен"
 
-#: wrapper.c:227 wrapper.c:397 builtin/am.c:320 builtin/am.c:770
-#: builtin/am.c:862 builtin/merge.c:1043
+#: rerere.c:881 submodule.c:2067 builtin/log.c:1871
+#: builtin/submodule--helper.c:1436 builtin/submodule--helper.c:1448
 #, c-format
-msgid "could not open '%s' for reading"
-msgstr "файлът не може да бъде прочетен: „%s“"
+msgid "could not create directory '%s'"
+msgstr "Директорията „%s“ не може да бъде създадена"
 
-#: wrapper.c:424 wrapper.c:624
+#: rerere.c:1057
 #, c-format
-msgid "unable to access '%s'"
-msgstr "няма достъп до „%s“"
-
-#: wrapper.c:632
-msgid "unable to get current working directory"
-msgstr "текущата работна директория е недостъпна"
+msgid "failed to update conflicted state in '%s'"
+msgstr "конфликтът в „%s“ не може да се обнови"
 
-#: wt-status.c:154
-msgid "Unmerged paths:"
-msgstr "Неслети пътища:"
+#: rerere.c:1068 rerere.c:1075
+#, c-format
+msgid "no remembered resolution for '%s'"
+msgstr "липсва запазена корекция на конфликт при „%s“"
 
-#: wt-status.c:181 wt-status.c:208
+#: rerere.c:1077
 #, c-format
-msgid "  (use \"git reset %s <file>...\" to unstage)"
-msgstr "  (използвайте „git reset %s ФАЙЛ…“, за да извадите ФАЙЛа от индекса)"
+msgid "cannot unlink '%s'"
+msgstr "„%s“ не може да се изтрие"
 
-#: wt-status.c:183 wt-status.c:210
-msgid "  (use \"git rm --cached <file>...\" to unstage)"
-msgstr ""
-"  (използвайте „git rm --cached %s ФАЙЛ…“, за да извадите ФАЙЛа от индекса)"
+#: rerere.c:1087
+#, c-format
+msgid "Updated preimage for '%s'"
+msgstr "Предварителният вариант на „%s“ е обновен"
 
-#: wt-status.c:187
-msgid "  (use \"git add <file>...\" to mark resolution)"
-msgstr ""
-"  (използвайте „git add ФАЙЛ…“, за да укажете разрешаването на конфликта)"
+#: rerere.c:1096
+#, c-format
+msgid "Forgot resolution for '%s'\n"
+msgstr "Запазената корекция на конфликт при „%s“ е премахната\n"
 
-#: wt-status.c:189 wt-status.c:193
-msgid "  (use \"git add/rm <file>...\" as appropriate to mark resolution)"
-msgstr ""
-"  (използвайте „git add/rm ФАЙЛ…“, според решението, което избирате за "
-"конфликта)"
+#: rerere.c:1199
+msgid "unable to open rr-cache directory"
+msgstr "директорията „rr-cache“ не може да се отвори"
 
-#: wt-status.c:191
-msgid "  (use \"git rm <file>...\" to mark resolution)"
-msgstr ""
-"  (използвайте „git rm ФАЙЛ…“, за да укажете разрешаването на конфликта)"
+#: revision.c:2497
+msgid "your current branch appears to be broken"
+msgstr "Текущият клон е повреден"
 
-#: wt-status.c:202 wt-status.c:1015
-msgid "Changes to be committed:"
-msgstr "Промени, които ще бъдат подадени:"
+#: revision.c:2500
+#, c-format
+msgid "your current branch '%s' does not have any commits yet"
+msgstr "Текущият клон „%s“ е без подавания "
 
-#: wt-status.c:220 wt-status.c:1024
-msgid "Changes not staged for commit:"
-msgstr "Промени, които не са в индекса за подаване:"
+#: revision.c:2708
+msgid "--first-parent is incompatible with --bisect"
+msgstr "опциите „--first-parent“ и „--bisect“ са несъвместими"
 
-#: wt-status.c:224
-msgid "  (use \"git add <file>...\" to update what will be committed)"
+#: revision.c:2712
+msgid "-L does not yet support diff formats besides -p and -s"
 msgstr ""
-"  (използвайте „git add ФАЙЛ…“, за да обновите съдържанието за подаване)"
+"опцията „-L“ поддържа единствено форматирането на разликите според опциите „-"
+"p“ и „-s“"
 
-#: wt-status.c:226
-msgid "  (use \"git add/rm <file>...\" to update what will be committed)"
-msgstr ""
-"  (използвайте „git add/rm ФАЙЛ…“, за да обновите съдържанието за подаване)"
+#: run-command.c:762
+msgid "open /dev/null failed"
+msgstr "неуспешно отваряне на „/dev/null“"
+
+#: run-command.c:1268
+#, c-format
+msgid "cannot create async thread: %s"
+msgstr "не може да се създаде асинхронна нишка: %s"
 
-#: wt-status.c:227
+#: run-command.c:1332
+#, c-format
 msgid ""
-"  (use \"git checkout -- <file>...\" to discard changes in working directory)"
+"The '%s' hook was ignored because it's not set as executable.\n"
+"You can disable this warning with `git config advice.ignoredHook false`."
 msgstr ""
-"  (използвайте „git checkout -- ФАЙЛ…“, за да отхвърлите промените в "
-"работното дърво)"
+"Куката „%s“ се прескача, защото липсват права за изпълнение.\n"
+"За да изключите това предупреждение, изпълнете:\n"
+"    git config advice.ignoredHook false"
 
-#: wt-status.c:229
-msgid "  (commit or discard the untracked or modified content in submodules)"
+#: send-pack.c:144
+msgid "unexpected flush packet while reading remote unpack status"
 msgstr ""
-"  (подайте или отхвърлете неследеното или промененото съдържание в "
-"подмодулите)"
+"неочакван изчистващ пакет „flush“ при изчитане на състоянието от "
+"отдалеченото разпакетиране"
 
-#: wt-status.c:241
+#: send-pack.c:146
 #, c-format
-msgid "  (use \"git %s <file>...\" to include in what will be committed)"
+msgid "unable to parse remote unpack status: %s"
 msgstr ""
-"  (използвайте „git %s ФАЙЛ…“, за да определите какво включвате в подаването)"
-
-#: wt-status.c:256
-msgid "both deleted:"
-msgstr "изтрити в двата случая:"
-
-#: wt-status.c:258
-msgid "added by us:"
-msgstr "добавени от вас:"
-
-#: wt-status.c:260
-msgid "deleted by them:"
-msgstr "изтрити от тях:"
-
-#: wt-status.c:262
-msgid "added by them:"
-msgstr "добавени от тях:"
-
-#: wt-status.c:264
-msgid "deleted by us:"
-msgstr "изтрити от вас:"
-
-#: wt-status.c:266
-msgid "both added:"
-msgstr "добавени и в двата случая:"
+"състоянието от отдалеченото разпакетиране не може да бъде анализирано: %s"
 
-#: wt-status.c:268
-msgid "both modified:"
-msgstr "променени и в двата случая:"
+#: send-pack.c:148
+#, c-format
+msgid "remote unpack failed: %s"
+msgstr "неуспешно отдалечено разпакетиране: %s"
 
-#: wt-status.c:278
-msgid "new file:"
-msgstr "нов файл:"
+#: send-pack.c:309
+msgid "failed to sign the push certificate"
+msgstr "сертификатът за изтласкване не може да бъде подписан"
 
-#: wt-status.c:280
-msgid "copied:"
-msgstr "копиран:"
+#: send-pack.c:423
+msgid "the receiving end does not support --signed push"
+msgstr "отсрещната страна не поддържа изтласкване с опцията „--signed“"
 
-#: wt-status.c:282
-msgid "deleted:"
-msgstr "изтрит:"
+#: send-pack.c:425
+msgid ""
+"not sending a push certificate since the receiving end does not support --"
+"signed push"
+msgstr ""
+"отсрещната страна не поддържа изтласкване с опцията „--signed“, затова не се "
+"използва сертификат"
 
-#: wt-status.c:284
-msgid "modified:"
-msgstr "променен:"
+#: send-pack.c:437
+msgid "the receiving end does not support --atomic push"
+msgstr "получаващата страна не поддържа изтласкване с опцията „--atomic“"
 
-#: wt-status.c:286
-msgid "renamed:"
-msgstr "преименуван:"
+#: send-pack.c:442
+msgid "the receiving end does not support push options"
+msgstr "отсрещната страна не поддържа опции при изтласкване"
 
-#: wt-status.c:288
-msgid "typechange:"
-msgstr "смяна на вида:"
+#: sequencer.c:189
+#, c-format
+msgid "invalid commit message cleanup mode '%s'"
+msgstr "несъществуващ режим на изчистване „%s“ на съобщение при подаване"
 
-#: wt-status.c:290
-msgid "unknown:"
-msgstr "непозната промяна:"
+#: sequencer.c:294
+#, c-format
+msgid "could not delete '%s'"
+msgstr "„%s“ не може да бъде изтрит"
 
-#: wt-status.c:292
-msgid "unmerged:"
-msgstr "неслят:"
+#: sequencer.c:313 builtin/rebase.c:781 builtin/rebase.c:1706 builtin/rm.c:369
+#, c-format
+msgid "could not remove '%s'"
+msgstr "„%s“ не може да бъде изтрит"
 
-#: wt-status.c:372
-msgid "new commits, "
-msgstr "нови подавания, "
+#: sequencer.c:323
+msgid "revert"
+msgstr "отмяна"
 
-#: wt-status.c:374
-msgid "modified content, "
-msgstr "променено съдържание, "
+#: sequencer.c:325
+msgid "cherry-pick"
+msgstr "отбиране"
 
-#: wt-status.c:376
-msgid "untracked content, "
-msgstr "неследено съдържание, "
+#: sequencer.c:327
+msgid "rebase -i"
+msgstr "rebase -i"
 
-#: wt-status.c:853
+#: sequencer.c:329
 #, c-format
-msgid "Your stash currently has %d entry"
-msgid_plural "Your stash currently has %d entries"
-msgstr[0] "Има %d скатаване."
-msgstr[1] "Има %d скатавания."
+msgid "unknown action: %d"
+msgstr "неизвестно действие: %d"
 
-#: wt-status.c:885
-msgid "Submodules changed but not updated:"
-msgstr "Подмодулите са променени, но не са обновени:"
-
-#: wt-status.c:887
-msgid "Submodule changes to be committed:"
-msgstr "Промени в подмодулите за подаване:"
+#: sequencer.c:387
+msgid ""
+"after resolving the conflicts, mark the corrected paths\n"
+"with 'git add <paths>' or 'git rm <paths>'"
+msgstr ""
+"след коригирането на конфликтите, отбележете съответните\n"
+"пътища с „git add ПЪТ…“ или „git rm ПЪТ…“."
 
-#: wt-status.c:969
+#: sequencer.c:390
 msgid ""
-"Do not modify or remove the line above.\n"
-"Everything below it will be ignored."
+"after resolving the conflicts, mark the corrected paths\n"
+"with 'git add <paths>' or 'git rm <paths>'\n"
+"and commit the result with 'git commit'"
 msgstr ""
-"Не променяйте и не изтривайте горния ред.\n"
-"Всичко отдолу ще бъде изтрито."
+"след коригирането на конфликтите, отбележете съответните\n"
+"пътища с „git add ПЪТ…“ или „git rm ПЪТ…“, след което\n"
+"подайте резултата с командата „git commit'“."
 
-#: wt-status.c:1084
-msgid "You have unmerged paths."
-msgstr "Някои пътища не са слети."
+#: sequencer.c:403 sequencer.c:2993
+#, c-format
+msgid "could not lock '%s'"
+msgstr "„%s“ не може да се заключи"
 
-#: wt-status.c:1087
-msgid "  (fix conflicts and run \"git commit\")"
-msgstr "  (коригирайте конфликтите и изпълнете „git commit“)"
+#: sequencer.c:410
+#, c-format
+msgid "could not write eol to '%s'"
+msgstr "краят на ред не може да се запише в „%s“"
 
-#: wt-status.c:1089
-msgid "  (use \"git merge --abort\" to abort the merge)"
-msgstr "  (използвайте „git merge --abort“, за да преустановите сливането)"
+#: sequencer.c:415 sequencer.c:2798 sequencer.c:2999 sequencer.c:3013
+#: sequencer.c:3277
+#, c-format
+msgid "failed to finalize '%s'"
+msgstr "„%s“ не може да се завърши"
 
-#: wt-status.c:1094
-msgid "All conflicts fixed but you are still merging."
-msgstr "Всички конфликти са решени, но продължавате сливането."
+#: sequencer.c:438 sequencer.c:1707 sequencer.c:2818 sequencer.c:3259
+#: sequencer.c:3368 builtin/am.c:244 builtin/commit.c:783 builtin/merge.c:1117
+#: builtin/rebase.c:589
+#, c-format
+msgid "could not read '%s'"
+msgstr "файлът „%s“ не може да бъде прочетен"
 
-#: wt-status.c:1097
-msgid "  (use \"git commit\" to conclude merge)"
-msgstr "  (използвайте „git commit“, за да завършите сливането)"
+#: sequencer.c:464
+#, c-format
+msgid "your local changes would be overwritten by %s."
+msgstr "локалните ви промени ще бъдат презаписани при %s."
 
-#: wt-status.c:1107
-msgid "You are in the middle of an am session."
-msgstr "В момента прилагате поредица от кръпки чрез „git am“."
+#: sequencer.c:468
+msgid "commit your changes or stash them to proceed."
+msgstr "подайте или скатайте промените, за да продължите"
 
-#: wt-status.c:1110
-msgid "The current patch is empty."
-msgstr "Текущата кръпка е празна."
+#: sequencer.c:500
+#, c-format
+msgid "%s: fast-forward"
+msgstr "%s: превъртане"
 
-#: wt-status.c:1114
-msgid "  (fix conflicts and then run \"git am --continue\")"
-msgstr "  (коригирайте конфликтите и изпълнете „git am --continue“)"
+#: sequencer.c:539 builtin/tag.c:565
+#, c-format
+msgid "Invalid cleanup mode %s"
+msgstr "Несъществуващ режим на изчистване „%s“"
 
-#: wt-status.c:1116
-msgid "  (use \"git am --skip\" to skip this patch)"
-msgstr "  (използвайте „git am --skip“, за да пропуснете тази кръпка)"
+#. TRANSLATORS: %s will be "revert", "cherry-pick" or
+#. "rebase -i".
+#.
+#: sequencer.c:633
+#, c-format
+msgid "%s: Unable to write new index file"
+msgstr "%s: новият индекс не може да бъде запазен"
 
-#: wt-status.c:1118
-msgid "  (use \"git am --abort\" to restore the original branch)"
-msgstr ""
-"  (използвайте „git am --abort“, за да възстановите първоначалния клон)"
+#: sequencer.c:650
+msgid "unable to update cache tree"
+msgstr "дървото на кеша не може да бъде обновено"
 
-#: wt-status.c:1250
-msgid "git-rebase-todo is missing."
-msgstr "„git-rebase-todo“ липсва."
+#: sequencer.c:664
+msgid "could not resolve HEAD commit"
+msgstr "подаването, сочено от указателя „HEAD“, не може да бъде открито"
 
-#: wt-status.c:1252
-msgid "No commands done."
-msgstr "Не са изпълнени команди."
+#: sequencer.c:744
+#, c-format
+msgid "no key present in '%.*s'"
+msgstr "в „%.*s“ няма ключове"
 
-#: wt-status.c:1255
+#: sequencer.c:755
 #, c-format
-msgid "Last command done (%d command done):"
-msgid_plural "Last commands done (%d commands done):"
-msgstr[0] "Последна изпълнена команда (изпълнена е общо %d команда):"
-msgstr[1] "Последна изпълнена команда (изпълнени са общо %d команди):"
+msgid "unable to dequote value of '%s'"
+msgstr "цитирането на стойността на „%s“ не може да бъде изчистено"
 
-#: wt-status.c:1266
+#: sequencer.c:792 wrapper.c:190 wrapper.c:360 builtin/am.c:705
+#: builtin/am.c:797 builtin/merge.c:1114 builtin/rebase.c:1074
 #, c-format
-msgid "  (see more in file %s)"
-msgstr "  повече информация има във файла „%s“)"
+msgid "could not open '%s' for reading"
+msgstr "файлът не може да бъде прочетен: „%s“"
 
-#: wt-status.c:1271
-msgid "No commands remaining."
-msgstr "Не остават повече команди."
+#: sequencer.c:802
+msgid "'GIT_AUTHOR_NAME' already given"
+msgstr "настройката за автор „GIT_AUTHOR_NAME“ вече е зададена"
 
-#: wt-status.c:1274
-#, c-format
-msgid "Next command to do (%d remaining command):"
-msgid_plural "Next commands to do (%d remaining commands):"
-msgstr[0] "Следваща команда за изпълнение (остава още %d команда):"
-msgstr[1] "Следваща команда за изпълнение (остават още %d команди):"
+#: sequencer.c:807
+msgid "'GIT_AUTHOR_EMAIL' already given"
+msgstr "настройката за е-поща „GIT_AUTHOR_EMAIL“ вече е зададена"
 
-#: wt-status.c:1282
-msgid "  (use \"git rebase --edit-todo\" to view and edit)"
-msgstr ""
-"  (използвайте „git rebase --edit-todo“, за да разгледате и редактирате)"
+#: sequencer.c:812
+msgid "'GIT_AUTHOR_DATE' already given"
+msgstr "настройката за дата „GIT_AUTHOR_DATE“ вече е зададена"
 
-#: wt-status.c:1295
+#: sequencer.c:816
 #, c-format
-msgid "You are currently rebasing branch '%s' on '%s'."
-msgstr "В момента пребазирате клона „%s“ върху „%s“."
+msgid "unknown variable '%s'"
+msgstr "непозната променлива „%s“"
 
-#: wt-status.c:1300
-msgid "You are currently rebasing."
-msgstr "В момента пребазирате."
+#: sequencer.c:821
+msgid "missing 'GIT_AUTHOR_NAME'"
+msgstr "настройката за автор „GIT_AUTHOR_NAME“ липсва"
 
-#: wt-status.c:1314
-msgid "  (fix conflicts and then run \"git rebase --continue\")"
-msgstr "  (коригирайте конфликтите и използвайте „git rebase --continue“)"
+#: sequencer.c:823
+msgid "missing 'GIT_AUTHOR_EMAIL'"
+msgstr "настройката за е-поща „GIT_AUTHOR_EMAIL“ липсва"
 
-#: wt-status.c:1316
-msgid "  (use \"git rebase --skip\" to skip this patch)"
-msgstr "  (използвайте „git rebase --skip“, за да пропуснете тази кръпка)"
+#: sequencer.c:825
+msgid "missing 'GIT_AUTHOR_DATE'"
+msgstr "настройката за дата „GIT_AUTHOR_DATE“ липсва"
 
-#: wt-status.c:1318
-msgid "  (use \"git rebase --abort\" to check out the original branch)"
-msgstr ""
-"  (използвайте „git rebase --abort“, за да възстановите първоначалния клон)"
+#: sequencer.c:902 sequencer.c:1427
+msgid "malformed ident line"
+msgstr "неправилен формат на ред за идентификация"
 
-#: wt-status.c:1324
-msgid "  (all conflicts fixed: run \"git rebase --continue\")"
-msgstr "  (всички конфликти са коригирани: изпълнете „git rebase --continue“)"
-
-#: wt-status.c:1328
+#: sequencer.c:925
 #, c-format
 msgid ""
-"You are currently splitting a commit while rebasing branch '%s' on '%s'."
-msgstr "В момента разделяте подаване докато пребазирате клона „%s“ върху „%s“."
-
-#: wt-status.c:1333
-msgid "You are currently splitting a commit during a rebase."
-msgstr "В момента разделяте подаване докато пребазирате."
-
-#: wt-status.c:1336
-msgid "  (Once your working directory is clean, run \"git rebase --continue\")"
+"you have staged changes in your working tree\n"
+"If these changes are meant to be squashed into the previous commit, run:\n"
+"\n"
+"  git commit --amend %s\n"
+"\n"
+"If they are meant to go into a new commit, run:\n"
+"\n"
+"  git commit %s\n"
+"\n"
+"In both cases, once you're done, continue with:\n"
+"\n"
+"  git rebase --continue\n"
 msgstr ""
-"  (След като работното ви дърво стане чисто, използвайте „git rebase --"
-"continue“)"
+"в това работно дърво има скатани промени.\n"
+"Ако искате да ги вкарате в предишното подаване, изпълнете:\n"
+"\n"
+"    git commit --amend %s\n"
+"\n"
+"Ако искате да създадете ново подаване, изпълнете:\n"
+"\n"
+"    git commit %s\n"
+"\n"
+"И в двата случая продължавате след това с командата:\n"
+"\n"
+"    git rebase --continue\n"
 
-#: wt-status.c:1340
-#, c-format
-msgid "You are currently editing a commit while rebasing branch '%s' on '%s'."
+#: sequencer.c:1218
+msgid "'prepare-commit-msg' hook failed"
 msgstr ""
-"В момента редактирате подаване докато пребазирате клона „%s“ върху „%s“."
-
-#: wt-status.c:1345
-msgid "You are currently editing a commit during a rebase."
-msgstr "В момента редактирате подаване докато пребазирате."
+"неуспешно изпълнение на куката при промяна на съобщението при подаване "
+"(prepare-commit-msg)"
 
-#: wt-status.c:1348
-msgid "  (use \"git commit --amend\" to amend the current commit)"
+#: sequencer.c:1224
+msgid ""
+"Your name and email address were configured automatically based\n"
+"on your username and hostname. Please check that they are accurate.\n"
+"You can suppress this message by setting them explicitly. Run the\n"
+"following command and follow the instructions in your editor to edit\n"
+"your configuration file:\n"
+"\n"
+"    git config --global --edit\n"
+"\n"
+"After doing this, you may fix the identity used for this commit with:\n"
+"\n"
+"    git commit --amend --reset-author\n"
 msgstr ""
-"  (използвайте „git commit --amend“, за да редактирате текущото подаване)"
+"Името и адресът за е-поща са настроени автоматично на базата на името на\n"
+"потребителя и името на машината.  Проверете дали са верни.  Можете да "
+"спрете\n"
+"това съобщение като изрично зададете стойностите.  Изпълнете следната "
+"команда\n"
+"и следвайте инструкциите в текстовия ви редактор, за да редактирате\n"
+"конфигурационния файл:\n"
+"\n"
+"    git config --global --edit\n"
+"\n"
+"След като направите това, можете да коригирате информацията за автора на\n"
+"текущото подаване чрез:\n"
+"\n"
+"    git commit --amend --reset-author\n"
 
-#: wt-status.c:1350
+#: sequencer.c:1237
 msgid ""
-"  (use \"git rebase --continue\" once you are satisfied with your changes)"
+"Your name and email address were configured automatically based\n"
+"on your username and hostname. Please check that they are accurate.\n"
+"You can suppress this message by setting them explicitly:\n"
+"\n"
+"    git config --global user.name \"Your Name\"\n"
+"    git config --global user.email you@example.com\n"
+"\n"
+"After doing this, you may fix the identity used for this commit with:\n"
+"\n"
+"    git commit --amend --reset-author\n"
 msgstr ""
-"  (използвайте „git rebase --continue“, след като завършите промените си)"
-
-#: wt-status.c:1360
-#, c-format
-msgid "You are currently cherry-picking commit %s."
-msgstr "В момента отбирате подаването „%s“."
+"Името и адресът за е-поща са настроени автоматично на базата на името на\n"
+"потребителя и името на машината.  Проверете дали са верни.  Можете да "
+"спрете\n"
+"това съобщение като изрично зададете стойностите:\n"
+"\n"
+"    git config --global user.name \"Вашето Име\"\n"
+"    git config --global user.email пенчо@example.com\n"
+"\n"
+"След като направите това, можете да коригирате информацията за автора на\n"
+"текущото подаване чрез:\n"
+"\n"
+"    git commit --amend --reset-author\n"
 
-#: wt-status.c:1365
-msgid "  (fix conflicts and run \"git cherry-pick --continue\")"
-msgstr "  (коригирайте конфликтите и изпълнете „git cherry-pick --continue“)"
+#: sequencer.c:1279
+msgid "couldn't look up newly created commit"
+msgstr "току що създаденото подаване не може да бъде открито"
 
-#: wt-status.c:1368
-msgid "  (all conflicts fixed: run \"git cherry-pick --continue\")"
-msgstr ""
-"  (всички конфликти са коригирани, изпълнете „git cherry-pick --continue“)"
+#: sequencer.c:1281
+msgid "could not parse newly created commit"
+msgstr "току що създаденото подаване не може да бъде анализирано"
 
-#: wt-status.c:1370
-msgid "  (use \"git cherry-pick --abort\" to cancel the cherry-pick operation)"
+#: sequencer.c:1327
+msgid "unable to resolve HEAD after creating commit"
 msgstr ""
-"  (използвайте „git cherry-pick --abort“, за да отмените всички действия с "
-"отбиране)"
-
-#: wt-status.c:1379
-#, c-format
-msgid "You are currently reverting commit %s."
-msgstr "В момента отменяте подаване „%s“."
+"състоянието сочено от указателя „HEAD“ не може да бъде открито след "
+"подаването"
 
-#: wt-status.c:1384
-msgid "  (fix conflicts and run \"git revert --continue\")"
-msgstr "  (коригирайте конфликтите и изпълнете „git revert --continue“)"
+#: sequencer.c:1329
+msgid "detached HEAD"
+msgstr "несвързан връх „HEAD“"
 
-#: wt-status.c:1387
-msgid "  (all conflicts fixed: run \"git revert --continue\")"
-msgstr "  (всички конфликти са коригирани, изпълнете „git revert --continue“)"
+#: sequencer.c:1333
+msgid " (root-commit)"
+msgstr " (начално подаване)"
 
-#: wt-status.c:1389
-msgid "  (use \"git revert --abort\" to cancel the revert operation)"
-msgstr ""
-"  (използвайте „git revert --abort“, за да преустановите отмяната на "
-"подаване)"
+#: sequencer.c:1354
+msgid "could not parse HEAD"
+msgstr "указателят „HEAD“ не може да бъде анализиран"
 
-#: wt-status.c:1400
+#: sequencer.c:1356
 #, c-format
-msgid "You are currently bisecting, started from branch '%s'."
-msgstr "В момента търсите двоично, като сте стартирали от клон „%s“."
+msgid "HEAD %s is not a commit!"
+msgstr "указателят „HEAD“ „%s“ сочи към нещо, което не е подаване!"
 
-#: wt-status.c:1404
-msgid "You are currently bisecting."
-msgstr "В момента търсите двоично."
+#: sequencer.c:1360 sequencer.c:1458 builtin/commit.c:1569
+msgid "could not parse HEAD commit"
+msgstr "върховото подаване „HEAD“ не може да бъде прочетено"
 
-#: wt-status.c:1407
-msgid "  (use \"git bisect reset\" to get back to the original branch)"
-msgstr ""
-"  (използвайте „git bisect reset“, за да се върнете към първоначалното "
-"състояние и клон)"
+#: sequencer.c:1411 sequencer.c:2055
+msgid "unable to parse commit author"
+msgstr "авторът на подаването не може да бъде анализиран"
 
-#: wt-status.c:1604
-msgid "On branch "
-msgstr "На клон "
+#: sequencer.c:1431
+msgid "corrupted author without date information"
+msgstr "неправилен автор без дата"
 
-#: wt-status.c:1610
-msgid "interactive rebase in progress; onto "
-msgstr "извършвате интерактивно пребазиране върху "
+#: sequencer.c:1447 builtin/am.c:1561 builtin/merge.c:684
+msgid "git write-tree failed to write a tree"
+msgstr "Командата „git write-tree“ не успя да запише обект-дърво"
 
-#: wt-status.c:1612
-msgid "rebase in progress; onto "
-msgstr "извършвате пребазиране върху "
+#: sequencer.c:1480 sequencer.c:1550
+#, c-format
+msgid "unable to read commit message from '%s'"
+msgstr "съобщението за подаване не може да бъде прочетено от „%s“"
 
-#: wt-status.c:1617
-msgid "HEAD detached at "
-msgstr "Указателят „HEAD“ не е свързан и е при "
+#: sequencer.c:1516 builtin/am.c:1583 builtin/commit.c:1668 builtin/merge.c:883
+#: builtin/merge.c:908
+msgid "failed to write commit object"
+msgstr "обектът за подаването не може да бъде записан"
 
-#: wt-status.c:1619
-msgid "HEAD detached from "
-msgstr "Указателят „HEAD“ не е свързан и е отделѐн от "
+#: sequencer.c:1577
+#, c-format
+msgid "could not parse commit %s"
+msgstr "подаването „%s“ не може да бъде анализирано"
 
-#: wt-status.c:1622
-msgid "Not currently on any branch."
-msgstr "Извън всички клони."
+#: sequencer.c:1582
+#, c-format
+msgid "could not parse parent commit %s"
+msgstr "родителското подаване „%s“ не може да бъде анализирано"
 
-#: wt-status.c:1642
-msgid "Initial commit"
-msgstr "Първоначално подаване"
+#: sequencer.c:1656 sequencer.c:1767
+#, c-format
+msgid "unknown command: %d"
+msgstr "непозната команда: %d"
 
-#: wt-status.c:1643
-msgid "No commits yet"
-msgstr "Все още липсват подавания"
+#: sequencer.c:1714 sequencer.c:1739
+#, c-format
+msgid "This is a combination of %d commits."
+msgstr "Това е обединение от %d подавания"
 
-#: wt-status.c:1657
-msgid "Untracked files"
-msgstr "Неследени файлове"
+#: sequencer.c:1724
+msgid "need a HEAD to fixup"
+msgstr "За вкарване в предходното подаване ви трябва указател „HEAD“"
 
-#: wt-status.c:1659
-msgid "Ignored files"
-msgstr "Игнорирани файлове"
+#: sequencer.c:1726 sequencer.c:3304
+msgid "could not read HEAD"
+msgstr "указателят „HEAD“ не може да се прочете"
 
-#: wt-status.c:1663
-#, c-format
-msgid ""
-"It took %.2f seconds to enumerate untracked files. 'status -uno'\n"
-"may speed it up, but you have to be careful not to forget to add\n"
-"new files yourself (see 'git help status')."
+#: sequencer.c:1728
+msgid "could not read HEAD's commit message"
 msgstr ""
-"Бяха необходими %.2f секунди за изброяването на неследените файлове.\n"
-"Добавянето на опцията „-uno“ към командата „git status“, ще ускори\n"
-"изпълнението, но не трябва да забравяте ръчно да добавяте новите файлове.\n"
-"За повече подробности погледнете „git status help“."
+"съобщението за подаване към указателя „HEAD“ не може да бъде прочетено: %s"
 
-#: wt-status.c:1669
+#: sequencer.c:1734
 #, c-format
-msgid "Untracked files not listed%s"
-msgstr "Неследените файлове не са изведени%s"
+msgid "cannot write '%s'"
+msgstr "„%s“ не може да се запази"
 
-#: wt-status.c:1671
-msgid " (use -u option to show untracked files)"
-msgstr " (използвайте опцията „-u“, за да изведете неследените файлове)"
+#: sequencer.c:1741 git-rebase--preserve-merges.sh:496
+msgid "This is the 1st commit message:"
+msgstr "Това е 1-то съобщение при подаване:"
 
-#: wt-status.c:1677
-msgid "No changes"
-msgstr "Няма промени"
+#: sequencer.c:1749
+#, c-format
+msgid "could not read commit message of %s"
+msgstr "съобщението за подаване към „%s“ не може да бъде прочетено"
 
-#: wt-status.c:1682
+#: sequencer.c:1756
 #, c-format
-msgid "no changes added to commit (use \"git add\" and/or \"git commit -a\")\n"
-msgstr ""
-"към индекса за подаване не са добавени промени (използвайте „git add“ и/или "
-"„git commit -a“)\n"
+msgid "This is the commit message #%d:"
+msgstr "Това е съобщение при подаване №%d:"
 
-#: wt-status.c:1685
+#: sequencer.c:1762
 #, c-format
-msgid "no changes added to commit\n"
-msgstr "към индекса за подаване не са добавени промени\n"
+msgid "The commit message #%d will be skipped:"
+msgstr "Съобщение при подаване №%d ще бъде прескочено:"
+
+#: sequencer.c:1850
+msgid "your index file is unmerged."
+msgstr "индексът не е слят."
 
-#: wt-status.c:1688
+#: sequencer.c:1857
+msgid "cannot fixup root commit"
+msgstr "началното подаване не може да се вкара в предходното му"
+
+#: sequencer.c:1876
 #, c-format
-msgid ""
-"nothing added to commit but untracked files present (use \"git add\" to "
-"track)\n"
-msgstr ""
-"към индекса за подаване не са добавени промени, но има нови файлове "
-"(използвайте „git add“, за да започне тяхното следене)\n"
+msgid "commit %s is a merge but no -m option was given."
+msgstr "подаването „%s“ е сливане, но не е дадена опцията „-m“"
 
-#: wt-status.c:1691
+#: sequencer.c:1884 sequencer.c:1892
 #, c-format
-msgid "nothing added to commit but untracked files present\n"
-msgstr "към индекса за подаване не са добавени промени, но има нови файлове\n"
+msgid "commit %s does not have parent %d"
+msgstr "подаването „%s“ няма родител %d"
 
-#: wt-status.c:1694
+#: sequencer.c:1898
 #, c-format
-msgid "nothing to commit (create/copy files and use \"git add\" to track)\n"
-msgstr ""
-"липсват каквито и да е промени (създайте или копирайте файлове и използвайте "
-"„git add“, за да започне тяхното следене)\n"
+msgid "cannot get commit message for %s"
+msgstr "неуспешно извличане на съобщението за подаване на „%s“"
 
-#: wt-status.c:1697 wt-status.c:1702
+#. TRANSLATORS: The first %s will be a "todo" command like
+#. "revert" or "pick", the second %s a SHA1.
+#: sequencer.c:1917
 #, c-format
-msgid "nothing to commit\n"
-msgstr "липсват каквито и да е промени\n"
+msgid "%s: cannot parse parent commit %s"
+msgstr "%s: неразпозната стойност за родителското подаване „%s“"
 
-#: wt-status.c:1700
+#: sequencer.c:1982
 #, c-format
-msgid "nothing to commit (use -u to show untracked files)\n"
-msgstr ""
-"липсват каквито и да е промени (използвайте опцията „-u“, за да се изведат и "
-"неследените файлове)\n"
+msgid "could not rename '%s' to '%s'"
+msgstr "„%s“ не може да се преименува на „%s“"
 
-#: wt-status.c:1704
+#: sequencer.c:2037
 #, c-format
-msgid "nothing to commit, working tree clean\n"
-msgstr "липсват каквито и да е промени, работното дърво е чисто\n"
+msgid "could not revert %s... %s"
+msgstr "подаването „%s“… не може да бъде отменено: „%s“"
 
-#: wt-status.c:1817
-msgid "No commits yet on "
-msgstr "Все още липсват подавания в "
+#: sequencer.c:2038
+#, c-format
+msgid "could not apply %s... %s"
+msgstr "подаването „%s“… не може да бъде приложено: „%s“"
 
-#: wt-status.c:1821
-msgid "HEAD (no branch)"
-msgstr "HEAD (извън клон)"
+#: sequencer.c:2105
+#, c-format
+msgid "git %s: failed to read the index"
+msgstr "git %s: неуспешно изчитане на индекса"
 
-#: wt-status.c:1852
-msgid "different"
-msgstr "различен"
+#: sequencer.c:2112
+#, c-format
+msgid "git %s: failed to refresh the index"
+msgstr "git %s: неуспешно обновяване на индекса"
 
-#: wt-status.c:1854 wt-status.c:1862
-msgid "behind "
-msgstr "назад с "
+#: sequencer.c:2189
+#, c-format
+msgid "%s does not accept arguments: '%s'"
+msgstr "„%s“ не приема аргументи: „%s“"
 
-#: wt-status.c:1857 wt-status.c:1860
-msgid "ahead "
-msgstr "напред с "
+#: sequencer.c:2198
+#, c-format
+msgid "missing arguments for %s"
+msgstr "„%s“ изисква аргументи"
 
-#. TRANSLATORS: the action is e.g. "pull with rebase"
-#: wt-status.c:2366
+#: sequencer.c:2235
 #, c-format
-msgid "cannot %s: You have unstaged changes."
-msgstr "не може да извършите „%s“, защото има промени, които не са в индекса."
+msgid "could not parse '%.*s'"
+msgstr "„%.*s“ не може да се анализира"
 
-#: wt-status.c:2372
-msgid "additionally, your index contains uncommitted changes."
-msgstr "освен това в индекса има неподадени промени."
+#: sequencer.c:2289
+#, c-format
+msgid "invalid line %d: %.*s"
+msgstr "неправилен ред %d: %.*s"
 
-#: wt-status.c:2374
+#: sequencer.c:2300
 #, c-format
-msgid "cannot %s: Your index contains uncommitted changes."
-msgstr "не може да извършите „%s“, защото в индекса има неподадени промени."
+msgid "cannot '%s' without a previous commit"
+msgstr "Без предишно подаване не може да се изпълни „%s“"
 
-#: compat/precompose_utf8.c:58 builtin/clone.c:442
+#: sequencer.c:2348 builtin/rebase.c:172 builtin/rebase.c:197
+#: builtin/rebase.c:223 builtin/rebase.c:248
 #, c-format
-msgid "failed to unlink '%s'"
-msgstr "неуспешно изтриване на „%s“"
+msgid "could not read '%s'."
+msgstr "от „%s“ не може да се чете."
 
-#: builtin/add.c:24
-msgid "git add [<options>] [--] <pathspec>..."
-msgstr "git add [ОПЦИЯ…] [--] ПЪТ…"
+#: sequencer.c:2384
+msgid "cancelling a cherry picking in progress"
+msgstr "преустановяване на извършваното в момента отбиране на подавания"
+
+#: sequencer.c:2391
+msgid "cancelling a revert in progress"
+msgstr "преустановяване на извършваното в момента отмяна на подаване"
+
+#: sequencer.c:2435
+msgid "please fix this using 'git rebase --edit-todo'."
+msgstr "коригирайте това чрез „git rebase --edit-todo“."
 
-#: builtin/add.c:83
+#: sequencer.c:2437
 #, c-format
-msgid "unexpected diff status %c"
-msgstr "неочакван изходен код при генериране на разлика: %c"
+msgid "unusable instruction sheet: '%s'"
+msgstr "неизползваем файл с описание на предстоящите действия: „%s“"
 
-#: builtin/add.c:88 builtin/commit.c:266
-msgid "updating files failed"
-msgstr "неуспешно обновяване на файловете"
+#: sequencer.c:2442
+msgid "no commits parsed."
+msgstr "никое от подаванията не може да се разпознае."
 
-#: builtin/add.c:98
-#, c-format
-msgid "remove '%s'\n"
-msgstr "изтриване на „%s“\n"
+#: sequencer.c:2453
+msgid "cannot cherry-pick during a revert."
+msgstr ""
+"по време на отмяна на подаване не може да се извърши отбиране на подаване."
 
-#: builtin/add.c:173
-msgid "Unstaged changes after refreshing the index:"
-msgstr "Промени, които и след обновяването на индекса не са добавени към него:"
+#: sequencer.c:2455
+msgid "cannot revert during a cherry-pick."
+msgstr "по време на отбиране не може да се извърши отмяна на подаване."
 
-#: builtin/add.c:233 builtin/rev-parse.c:892
-msgid "Could not read the index"
-msgstr "Индексът не може да бъде прочетен"
+#: sequencer.c:2533
+#, c-format
+msgid "invalid value for %s: %s"
+msgstr "неправилна стойност за „%s“: „%s“"
+
+#: sequencer.c:2630
+msgid "unusable squash-onto"
+msgstr "подаването, в което другите да се вкарат, не може да се използва"
 
-#: builtin/add.c:244
+#: sequencer.c:2646
 #, c-format
-msgid "Could not open '%s' for writing."
-msgstr "Файлът „%s“ не може да бъде отворен за запис."
+msgid "malformed options sheet: '%s'"
+msgstr "неправилен файл с опции: „%s“"
 
-#: builtin/add.c:248
-msgid "Could not write patch"
-msgstr "Кръпката не може да бъде записана"
+#: sequencer.c:2736 sequencer.c:4463
+msgid "empty commit set passed"
+msgstr "зададено е празно множество от подавания"
 
-#: builtin/add.c:251
-msgid "editing patch failed"
-msgstr "неуспешно редактиране на кръпка"
+#: sequencer.c:2752
+msgid "revert is already in progress"
+msgstr "в момента вече се извършва отмяна на подавания"
 
-#: builtin/add.c:254
+#: sequencer.c:2754
 #, c-format
-msgid "Could not stat '%s'"
-msgstr "Не може да се получи информация чрез „stat“ за файла „%s“"
+msgid "try \"git revert (--continue | %s--abort | --quit)\""
+msgstr "използвайте „git cherry-pick (--continue | %s--abort | --quit)“"
 
-#: builtin/add.c:256
-msgid "Empty patch. Aborted."
-msgstr "Празна кръпка, преустановяване на действието."
+#: sequencer.c:2757
+msgid "cherry-pick is already in progress"
+msgstr "в момента вече се извършва отбиране на подавания"
 
-#: builtin/add.c:261
+#: sequencer.c:2759
 #, c-format
-msgid "Could not apply '%s'"
-msgstr "Кръпката „%s“ не може да бъде приложена"
+msgid "try \"git cherry-pick (--continue | %s--abort | --quit)\""
+msgstr "използвайте „git cherry-pick (--continue | %s--abort | --quit)“"
 
-#: builtin/add.c:269
-msgid "The following paths are ignored by one of your .gitignore files:\n"
+#: sequencer.c:2773
+#, c-format
+msgid "could not create sequencer directory '%s'"
 msgstr ""
-"Следните пътища ще бъдат игнорирани според някой от файловете „.gitignore“:\n"
-
-#: builtin/add.c:289 builtin/clean.c:911 builtin/fetch.c:145 builtin/mv.c:123
-#: builtin/prune-packed.c:55 builtin/pull.c:212 builtin/push.c:557
-#: builtin/remote.c:1342 builtin/rm.c:240 builtin/send-pack.c:165
-msgid "dry run"
-msgstr "пробно изпълнение"
+"директорията за определянето на последователността „%s“ не може да бъде "
+"създадена"
 
-#: builtin/add.c:292
-msgid "interactive picking"
-msgstr "интерактивно отбиране на промени"
+#: sequencer.c:2788
+msgid "could not lock HEAD"
+msgstr "указателят „HEAD“ не може да се заключи"
 
-#: builtin/add.c:293 builtin/checkout.c:1135 builtin/reset.c:302
-msgid "select hunks interactively"
-msgstr "интерактивен избор на парчета код"
+#: sequencer.c:2848 sequencer.c:4209
+msgid "no cherry-pick or revert in progress"
+msgstr ""
+"в момента не се извършва отбиране на подавания или пребазиране на клона"
 
-#: builtin/add.c:294
-msgid "edit current diff and apply"
-msgstr "редактиране на текущата разлика и прилагане"
+#: sequencer.c:2850 sequencer.c:2861
+msgid "cannot resolve HEAD"
+msgstr "Подаването сочено от указателя „HEAD“ не може да бъде открито"
 
-#: builtin/add.c:295
-msgid "allow adding otherwise ignored files"
-msgstr "добавяне и на иначе игнорираните файлове"
+#: sequencer.c:2852 sequencer.c:2896
+msgid "cannot abort from a branch yet to be born"
+msgstr ""
+"действието не може да бъде преустановено, когато сте на клон, който тепърва "
+"предстои да бъде създаден"
 
-#: builtin/add.c:296
-msgid "update tracked files"
-msgstr "обновяване на следените файлове"
+#: sequencer.c:2882 builtin/grep.c:736
+#, c-format
+msgid "cannot open '%s'"
+msgstr "„%s“ не може да бъде отворен"
 
-#: builtin/add.c:297
-msgid "renormalize EOL of tracked files (implies -u)"
-msgstr "уеднаквяване на знаците за край на файл (включва опцията „-u“)"
+#: sequencer.c:2884
+#, c-format
+msgid "cannot read '%s': %s"
+msgstr "„%s“ не може да бъде прочетен: %s"
 
-#: builtin/add.c:298
-msgid "record only the fact that the path will be added later"
-msgstr "отбелязване само на факта, че пътят ще бъде добавен по-късно"
+#: sequencer.c:2885
+msgid "unexpected end of file"
+msgstr "неочакван край на файл"
 
-#: builtin/add.c:299
-msgid "add changes from all tracked and untracked files"
-msgstr "добавяне на всички промени в следените и неследените файлове"
+#: sequencer.c:2891
+#, c-format
+msgid "stored pre-cherry-pick HEAD file '%s' is corrupt"
+msgstr ""
+"запазеният преди започването на отбирането файл за указателя „HEAD“ — „%s“ е "
+"повреден"
 
-#: builtin/add.c:302
-msgid "ignore paths removed in the working tree (same as --no-all)"
+#: sequencer.c:2902
+msgid "You seem to have moved HEAD. Not rewinding, check your HEAD!"
 msgstr ""
-"игнориране на пътищата, които са изтрити от работното дърво (същото като „--"
-"no-all“)"
+"Изглежда указателят „HEAD“ е променен.  Проверете към какво сочи.\n"
+"Не се правят промени."
 
-#: builtin/add.c:304
-msgid "don't add, only refresh the index"
-msgstr "без добавяне на нови файлове, само обновяване на индекса"
+#: sequencer.c:2943
+msgid "no revert in progress"
+msgstr "в момента не тече пребазиране"
 
-#: builtin/add.c:305
-msgid "just skip files which cannot be added because of errors"
-msgstr ""
-"прескачане на файловете, които не могат да бъдат добавени поради грешки"
+#: sequencer.c:2951
+msgid "no cherry-pick in progress"
+msgstr "в момента не се извършва отбиране на подавания"
 
-#: builtin/add.c:306
-msgid "check if - even missing - files are ignored in dry run"
+#: sequencer.c:2961
+msgid "failed to skip the commit"
+msgstr "неуспешно прескачане на подаването"
+
+#: sequencer.c:2968
+msgid "there is nothing to skip"
+msgstr "няма какво да се прескочи"
+
+#: sequencer.c:2971
+#, c-format
+msgid ""
+"have you committed already?\n"
+"try \"git %s --continue\""
 msgstr ""
-"проверка, че при пробно изпълнение всички файлове, дори и изтритите, се "
-"игнорират"
+"подали ли сте вече?  Пробвайте с:\n"
+"\n"
+"    git %s --continue"
 
-#: builtin/add.c:307 builtin/update-index.c:974
-msgid "(+/-)x"
-msgstr "(+/-)x"
+#: sequencer.c:3095 sequencer.c:4121
+#, c-format
+msgid "could not update %s"
+msgstr "„%s“ не може да се обнови"
 
-#: builtin/add.c:307 builtin/update-index.c:975
-msgid "override the executable bit of the listed files"
-msgstr "изрично задаване на стойността на флага дали файлът е изпълним"
+#: sequencer.c:3134 sequencer.c:4101
+msgid "cannot read HEAD"
+msgstr "указателят „HEAD“ не може да бъде прочетен"
 
-#: builtin/add.c:309
-msgid "warn when adding an embedded repository"
-msgstr "предупреждаване при добавяне на вградено хранилище"
+#: sequencer.c:3151
+#, c-format
+msgid "unable to copy '%s' to '%s'"
+msgstr "„%s“ не може да се копира като „%s“"
 
-#: builtin/add.c:324
+#: sequencer.c:3159
 #, c-format
 msgid ""
-"You've added another git repository inside your current repository.\n"
-"Clones of the outer repository will not contain the contents of\n"
-"the embedded repository and will not know how to obtain it.\n"
-"If you meant to add a submodule, use:\n"
-"\n"
-"\tgit submodule add <url> %s\n"
+"You can amend the commit now, with\n"
 "\n"
-"If you added this path by mistake, you can remove it from the\n"
-"index with:\n"
+"  git commit --amend %s\n"
 "\n"
-"\tgit rm --cached %s\n"
+"Once you are satisfied with your changes, run\n"
 "\n"
-"See \"git help submodule\" for more information."
+"  git rebase --continue\n"
 msgstr ""
-"Изтеглили сте допълнително хранилище в текущото.  Когато клонирате "
-"обхващащото\n"
-"хранилище няма да получите вграденото, защото външното хранилище няма "
-"представа\n"
-"за вътрешното.  За да добавите подмодул, изпълнете:\n"
-"\n"
-"    git submodule add АДРЕС %s\n"
+"Може да промените подаването с командата:\n"
 "\n"
-"Ако добавянето е грешка, може да го извадите от индекса с командата:\n"
+"    git commit --amend %s\n"
 "\n"
-"    git rm --cached %s\n"
+"След като привършите, продължете с командата:\n"
 "\n"
-"За повече информация погледнете „git help submodule“."
+"    git rebase --continue\n"
 
-#: builtin/add.c:352
+#: sequencer.c:3169
 #, c-format
-msgid "adding embedded git repository: %s"
-msgstr "добавяне на вградено хранилище: %s"
+msgid "Could not apply %s... %.*s"
+msgstr "Подаването „%s“… не може да бъде приложено: „%.*s“"
 
-#: builtin/add.c:370
+#: sequencer.c:3176
 #, c-format
-msgid "Use -f if you really want to add them.\n"
-msgstr "Използвайте опцията „-f“, за да ги добавите наистина.\n"
-
-#: builtin/add.c:378
-msgid "adding files failed"
-msgstr "неуспешно добавяне на файлове"
-
-#: builtin/add.c:416
-msgid "-A and -u are mutually incompatible"
-msgstr "опциите „-A“ и „-u“ са несъвместими"
+msgid "Could not merge %.*s"
+msgstr "Невъзможно сливане на „%.*s“"
 
-#: builtin/add.c:423
-msgid "Option --ignore-missing can only be used together with --dry-run"
-msgstr "Опцията „--ignore-missing“ е съвместима само с „--dry-run“"
+#: sequencer.c:3190 sequencer.c:3194 builtin/difftool.c:641
+#, c-format
+msgid "could not copy '%s' to '%s'"
+msgstr "„%s“ не може да се копира като „%s“"
 
-#: builtin/add.c:427
+#: sequencer.c:3221
 #, c-format
-msgid "--chmod param '%s' must be either -x or +x"
-msgstr "параметърът към „--chmod“ — „%s“ може да е или „-x“, или „+x“"
+msgid ""
+"execution failed: %s\n"
+"%sYou can fix the problem, and then run\n"
+"\n"
+"  git rebase --continue\n"
+"\n"
+msgstr ""
+"неуспешно изпълнение: %s\n"
+"%sМоже да коригирате проблема, след което изпълнете:\n"
+"\n"
+"    git rebase --continue\n"
+"\n"
 
-#: builtin/add.c:442
+#: sequencer.c:3227
+msgid "and made changes to the index and/or the working tree\n"
+msgstr "и променѝ индекса и/или работното дърво\n"
+
+#: sequencer.c:3233
 #, c-format
-msgid "Nothing specified, nothing added.\n"
-msgstr "Нищо не е зададено и нищо не е добавено.\n"
+msgid ""
+"execution succeeded: %s\n"
+"but left changes to the index and/or the working tree\n"
+"Commit or stash your changes, and then run\n"
+"\n"
+"  git rebase --continue\n"
+"\n"
+msgstr ""
+"Успешно изпълнение: %s\n"
+"Остават още промени в индекса или работното дърво.\n"
+"Трябва да ги подадете или скатаете и след това изпълнете:\n"
+"\n"
+"    git rebase --continue\n"
+"\n"
 
-#: builtin/add.c:443
+#: sequencer.c:3294
 #, c-format
-msgid "Maybe you wanted to say 'git add .'?\n"
-msgstr "Вероятно искахте да използвате „git add .“?\n"
+msgid "illegal label name: '%.*s'"
+msgstr "неправилно име на етикет: „%.*s“"
 
-#: builtin/add.c:448 builtin/check-ignore.c:177 builtin/checkout.c:280
-#: builtin/checkout.c:483 builtin/clean.c:958 builtin/commit.c:325
-#: builtin/diff-tree.c:114 builtin/mv.c:144 builtin/reset.c:241
-#: builtin/rm.c:270 builtin/submodule--helper.c:328
-msgid "index file corrupt"
-msgstr "файлът с индекса е повреден"
+#: sequencer.c:3348
+msgid "writing fake root commit"
+msgstr "запазване на фалшиво начално подаване"
 
-#: builtin/am.c:414
-msgid "could not parse author script"
-msgstr "скриптът за автор не може да се анализира"
+#: sequencer.c:3353
+msgid "writing squash-onto"
+msgstr "запазване на подаването, в което другите да се вкарат"
 
-#: builtin/am.c:498
+#: sequencer.c:3391 builtin/rebase.c:876 builtin/rebase.c:882
 #, c-format
-msgid "'%s' was deleted by the applypatch-msg hook"
-msgstr "„%s“ бе изтрит от куката „applypatch-msg“"
+msgid "failed to find tree of %s"
+msgstr "дървото, сочено от „%s“, не може да бъде открито"
 
-#: builtin/am.c:539
+#: sequencer.c:3436
 #, c-format
-msgid "Malformed input line: '%s'."
-msgstr "Даденият входен ред е с неправилен формат: „%s“."
+msgid "could not resolve '%s'"
+msgstr "„%s“ не може да бъде открит"
 
-#: builtin/am.c:576
-#, c-format
-msgid "Failed to copy notes from '%s' to '%s'"
-msgstr "Бележката не може да се копира от „%s“ към „%s“"
+#: sequencer.c:3467
+msgid "cannot merge without a current revision"
+msgstr "без текущо подаване не може да се слива"
 
-#: builtin/am.c:602
-msgid "fseek failed"
-msgstr "неуспешно изпълнение на „fseek“"
+#: sequencer.c:3489
+#, c-format
+msgid "unable to parse '%.*s'"
+msgstr "„%.*s“ не може да се анализира"
 
-#: builtin/am.c:790
+#: sequencer.c:3498
 #, c-format
-msgid "could not parse patch '%s'"
-msgstr "кръпката „%s“ не може да се анализира"
+msgid "nothing to merge: '%.*s'"
+msgstr "няма нищо за сливане: „%.*s“"
 
-#: builtin/am.c:855
-msgid "Only one StGIT patch series can be applied at once"
-msgstr ""
-"Само една поредица от кръпки от „StGIT“ може да бъде прилагана в даден момент"
+#: sequencer.c:3510
+msgid "octopus merge cannot be executed on top of a [new root]"
+msgstr "върху начално подаване не може да се извърши множествено сливане"
 
-#: builtin/am.c:903
-msgid "invalid timestamp"
-msgstr "неправилна стойност за време"
+#: sequencer.c:3526
+#, c-format
+msgid "could not get commit message of '%s'"
+msgstr "съобщението за подаване към „%s“ не може да бъде получено"
 
-#: builtin/am.c:908 builtin/am.c:920
-msgid "invalid Date line"
-msgstr "неправилен ред за дата „Date“"
+#: sequencer.c:3688
+#, c-format
+msgid "could not even attempt to merge '%.*s'"
+msgstr "сливането на „%.*s“ не може даже да започне"
 
-#: builtin/am.c:915
-msgid "invalid timezone offset"
-msgstr "неправилно отместване на часовия пояс"
+#: sequencer.c:3704
+msgid "merge: Unable to write new index file"
+msgstr "сливане: новият индекс не може да бъде запазен"
 
-#: builtin/am.c:1008
-msgid "Patch format detection failed."
-msgstr "Форматът на кръпката не може да бъде определен."
+#: sequencer.c:3773 builtin/rebase.c:733
+#, c-format
+msgid "Applied autostash.\n"
+msgstr "Автоматично скатаното е приложено.\n"
 
-#: builtin/am.c:1013 builtin/clone.c:407
+#: sequencer.c:3785
 #, c-format
-msgid "failed to create directory '%s'"
-msgstr "директорията „%s“ не може да бъде създадена"
+msgid "cannot store %s"
+msgstr "„%s“ не може да бъде запазен"
 
-#: builtin/am.c:1018
-msgid "Failed to split patches."
-msgstr "Кръпките не могат да бъдат разделени."
+#: sequencer.c:3788 builtin/rebase.c:749 git-rebase--preserve-merges.sh:113
+#, c-format
+msgid ""
+"Applying autostash resulted in conflicts.\n"
+"Your changes are safe in the stash.\n"
+"You can run \"git stash pop\" or \"git stash drop\" at any time.\n"
+msgstr ""
+"Прилагането на автоматично скатаното доведе до конфликти.  Промените ви са\n"
+"надеждно скатани.  Можете да пробвате да ги приложите чрез „git stash pop“\n"
+"или да ги изхвърлите чрез „git stash drop“, когато поискате.\n"
 
-#: builtin/am.c:1148 builtin/commit.c:351
-msgid "unable to write index file"
-msgstr "индексът не може да бъде записан"
+#: sequencer.c:3849
+#, c-format
+msgid "could not checkout %s"
+msgstr "„%s“ не може да се изтегли"
 
-#: builtin/am.c:1162
+#: sequencer.c:3863
 #, c-format
-msgid "When you have resolved this problem, run \"%s --continue\"."
-msgstr "След коригирането на този проблем изпълнете „%s --continue“."
+msgid "%s: not a valid OID"
+msgstr "„%s“ е неправилен идентификатор на обект"
+
+#: sequencer.c:3868 git-rebase--preserve-merges.sh:779
+msgid "could not detach HEAD"
+msgstr "указателят „HEAD“ не може да се отдели"
 
-#: builtin/am.c:1163
+#: sequencer.c:3883
 #, c-format
-msgid "If you prefer to skip this patch, run \"%s --skip\" instead."
-msgstr "Ако предпочитате да прескочите тази кръпка, изпълнете „%s --skip“."
+msgid "Stopped at HEAD\n"
+msgstr "Бе спряно при „HEAD“\n"
 
-#: builtin/am.c:1164
+#: sequencer.c:3885
 #, c-format
-msgid "To restore the original branch and stop patching, run \"%s --abort\"."
-msgstr "За да се върнете към първоначалното състояние, изпълнете „%s --abort“."
+msgid "Stopped at %s\n"
+msgstr "Бе спряно при „%s“\n"
 
-#: builtin/am.c:1271
-msgid "Patch is empty."
-msgstr "Кръпката е празна."
+#: sequencer.c:3893
+#, c-format
+msgid ""
+"Could not execute the todo command\n"
+"\n"
+"    %.*s\n"
+"It has been rescheduled; To edit the command before continuing, please\n"
+"edit the todo list first:\n"
+"\n"
+"    git rebase --edit-todo\n"
+"    git rebase --continue\n"
+msgstr ""
+"Следната запланувана команда не може да бъде изпълнена:\n"
+"\n"
+"    %.*s\n"
+"\n"
+"Тя е запланувана за по-късно.  За да редактирате командата преди "
+"изпълнение,\n"
+"редактирайте списъка за изпълнение:\n"
+"\n"
+"    git rebase --edit-todo\n"
+"    git rebase --continue\n"
 
-#: builtin/am.c:1337
+#: sequencer.c:3979
 #, c-format
-msgid "invalid ident line: %.*s"
-msgstr "грешен ред с идентичност: %.*s"
+msgid "Stopped at %s...  %.*s\n"
+msgstr "Спиране при „%s“…  %.*s\n"
 
-#: builtin/am.c:1359
+#: sequencer.c:4050
 #, c-format
-msgid "unable to parse commit %s"
-msgstr "подаването не може да бъде анализирано: %s"
+msgid "unknown command %d"
+msgstr "непозната команда %d"
 
-#: builtin/am.c:1554
-msgid "Repository lacks necessary blobs to fall back on 3-way merge."
-msgstr ""
-"В хранилището липсват необходимите обекти-BLOB, за да се премине към тройно "
-"сливане."
+#: sequencer.c:4109
+msgid "could not read orig-head"
+msgstr "указателят за „orig-head“ не може да се прочете"
 
-#: builtin/am.c:1556
-msgid "Using index info to reconstruct a base tree..."
-msgstr "Базовото дърво се реконструира от информацията в индекса…"
+#: sequencer.c:4114
+msgid "could not read 'onto'"
+msgstr "указателят за „onto“ не може да се прочете"
 
-#: builtin/am.c:1575
-msgid ""
-"Did you hand edit your patch?\n"
-"It does not apply to blobs recorded in its index."
-msgstr ""
-"Кръпката не може да се приложи към обектите-BLOB в индекса.\n"
-"Да не би да сте я редактирали на ръка?"
+#: sequencer.c:4128
+#, c-format
+msgid "could not update HEAD to %s"
+msgstr "„HEAD“ не може да бъде обновен до „%s“"
 
-#: builtin/am.c:1581
-msgid "Falling back to patching base and 3-way merge..."
-msgstr "Преминаване към прилагане на кръпка към базата и тройно сливане…"
+#: sequencer.c:4221
+msgid "cannot rebase: You have unstaged changes."
+msgstr "не може да пребазирате, защото има промени, които не са в индекса."
 
-#: builtin/am.c:1606
-msgid "Failed to merge in the changes."
-msgstr "Неуспешно сливане на промените."
+#: sequencer.c:4230
+msgid "cannot amend non-existing commit"
+msgstr "несъществуващо подаване не може да се поправи"
 
-#: builtin/am.c:1637
-msgid "applying to an empty history"
-msgstr "прилагане върху празна история"
+#: sequencer.c:4232
+#, c-format
+msgid "invalid file: '%s'"
+msgstr "неправилен файл: „%s“"
 
-#: builtin/am.c:1683 builtin/am.c:1687
+#: sequencer.c:4234
 #, c-format
-msgid "cannot resume: %s does not exist."
-msgstr "не може да се продължи — „%s“ не съществува."
+msgid "invalid contents: '%s'"
+msgstr "неправилно съдържание: „%s“"
 
-#: builtin/am.c:1703
-msgid "cannot be interactive without stdin connected to a terminal."
+#: sequencer.c:4237
+msgid ""
+"\n"
+"You have uncommitted changes in your working tree. Please, commit them\n"
+"first and then run 'git rebase --continue' again."
 msgstr ""
-"За интерактивно изпълнение е необходимо стандартният\n"
-"вход да е свързан с терминал, а в момента не е."
+"\n"
+"В работното дърво има неподадени промени.  Първо ги подайте, а след това\n"
+"отново изпълнете „git rebase --continue“."
 
-#: builtin/am.c:1708
-msgid "Commit Body is:"
-msgstr "Тялото на кръпката за прилагане е:"
+#: sequencer.c:4273 sequencer.c:4312
+#, c-format
+msgid "could not write file: '%s'"
+msgstr "файлът „%s“ не може да бъде записан"
 
-#. TRANSLATORS: Make sure to include [y], [n], [e], [v] and [a]
-#. in your translation. The program will only accept English
-#. input at this point.
-#.
-#: builtin/am.c:1718
-msgid "Apply? [y]es/[n]o/[e]dit/[v]iew patch/[a]ccept all: "
-msgstr ""
-"Прилагане? „y“ — да/„n“ — не/„e“ — редактиране/„v“ — преглед/„a“ — приемане "
-"на всичко:"
+#: sequencer.c:4327
+msgid "could not remove CHERRY_PICK_HEAD"
+msgstr "указателят „CHERRY_PICK_HEAD“ не може да бъде изтрит"
+
+#: sequencer.c:4334
+msgid "could not commit staged changes."
+msgstr "промените в индекса не могат да бъдат подадени."
 
-#: builtin/am.c:1768
+#: sequencer.c:4440
 #, c-format
-msgid "Dirty index: cannot apply patches (dirty: %s)"
-msgstr ""
-"Индексът не е чист: кръпките не могат да бъдат приложени (замърсени са: %s)"
+msgid "%s: can't cherry-pick a %s"
+msgstr "%s: не може да се отбере „%s“"
 
-#: builtin/am.c:1808 builtin/am.c:1879
+#: sequencer.c:4444
 #, c-format
-msgid "Applying: %.*s"
-msgstr "Прилагане: %.*s"
+msgid "%s: bad revision"
+msgstr "%s: неправилна версия"
 
-#: builtin/am.c:1824
-msgid "No changes -- Patch already applied."
-msgstr "Без промени — кръпката вече е приложена."
+#: sequencer.c:4479
+msgid "can't revert as initial commit"
+msgstr "първоначалното подаване не може да бъде отменено"
 
-#: builtin/am.c:1832
-#, c-format
-msgid "Patch failed at %s %.*s"
-msgstr "Неуспешно прилагане на кръпка при %s %.*s“"
+#: sequencer.c:4952
+msgid "make_script: unhandled options"
+msgstr "make_script: неподдържани опции"
 
-#: builtin/am.c:1838
-msgid "Use 'git am --show-current-patch' to see the failed patch"
-msgstr ""
-"За да видите неуспешно приложени кръпки, използвайте опцията „git am --show-"
-"current-patch“ to see the failed patch"
+#: sequencer.c:4955
+msgid "make_script: error preparing revisions"
+msgstr "make_script: грешка при подготовката на версии"
 
-#: builtin/am.c:1882
+#: sequencer.c:5113
 msgid ""
-"No changes - did you forget to use 'git add'?\n"
-"If there is nothing left to stage, chances are that something else\n"
-"already introduced the same changes; you might want to skip this patch."
+"You can fix this with 'git rebase --edit-todo' and then run 'git rebase --"
+"continue'.\n"
+"Or you can abort the rebase with 'git rebase --abort'.\n"
 msgstr ""
-"Без промени — възможно е да не сте изпълнили „git add“.\n"
-"Ако няма друга промяна за включване в индекса, най-вероятно някоя друга\n"
-"кръпка е довела до същите промени и в такъв случай просто пропуснете тази."
+"Може да промените това с командите „git rebase --edit-todo“ и „git rebase --"
+"continue“ след това.\n"
+"Може и да преустановите пребазирането с командата „git rebase --abort“.\n"
 
-#: builtin/am.c:1889
-msgid ""
-"You still have unmerged paths in your index.\n"
-"You should 'git add' each file with resolved conflicts to mark them as "
-"such.\n"
-"You might run `git rm` on a file to accept \"deleted by them\" for it."
-msgstr ""
-"Индексът все още съдържа неслети промени.\n"
-"След корекция на конфликтите изпълнете „git add“ върху поправените файлове.\n"
-"За да приемете „изтрити от тях“, изпълнете „git rm“ върху изтритите файлове."
+#: sequencer.c:5226 sequencer.c:5243
+msgid "nothing to do"
+msgstr "няма какво да се прави"
+
+#: sequencer.c:5257
+msgid "could not skip unnecessary pick commands"
+msgstr "излишните команди за отбиране не бяха прескочени"
+
+#: sequencer.c:5351
+msgid "the script was already rearranged."
+msgstr "скриптът вече е преподреден."
 
-#: builtin/am.c:1996 builtin/am.c:2000 builtin/am.c:2012 builtin/reset.c:324
-#: builtin/reset.c:332
+#: setup.c:124
 #, c-format
-msgid "Could not parse object '%s'."
-msgstr "„%s“ не е разпознат като обект."
+msgid "'%s' is outside repository"
+msgstr "„%s“ е извън хранилището"
 
-#: builtin/am.c:2048
-msgid "failed to clean index"
-msgstr "индексът не може да бъде изчистен"
+#: setup.c:174
+#, c-format
+msgid ""
+"%s: no such path in the working tree.\n"
+"Use 'git <command> -- <path>...' to specify paths that do not exist locally."
+msgstr ""
+"%s: в това работно дърво няма такъв път.\n"
+"За да указвате пътища, които локално не съществуват, използвайте:\n"
+"\n"
+"    git КОМАНДА -- ПЪТ…"
 
-#: builtin/am.c:2083
+#: setup.c:187
+#, c-format
 msgid ""
-"You seem to have moved HEAD since the last 'am' failure.\n"
-"Not rewinding to ORIG_HEAD"
+"ambiguous argument '%s': unknown revision or path not in the working tree.\n"
+"Use '--' to separate paths from revisions, like this:\n"
+"'git <command> [<revision>...] -- [<file>...]'"
 msgstr ""
-"Изглежда указателят „HEAD“ е променен и не сочи към същия обект както по "
-"времето\n"
-"на последното неуспешно изпълнение на „git am“.  Указателят се задава да "
-"сочи към\n"
-"„ORIG_HEAD“"
+"нееднозначен аргумент „%s: непозната версия или пътят не е част от работното "
+"дърво.\n"
+"Разделяйте пътищата от версиите с „--“, ето така:\n"
+"\n"
+"    git КОМАНДА [ВЕРСИЯ…] -- [ФАЙЛ…]"
 
-#: builtin/am.c:2174
+#: setup.c:236
 #, c-format
-msgid "Invalid value for --patch-format: %s"
-msgstr "Неправилна стойност за „--patch-format“: „%s“"
+msgid "option '%s' must come before non-option arguments"
+msgstr "опцията „%s“ трябва да е преди първия аргумент, който не е опция"
 
-#: builtin/am.c:2210
-msgid "git am [<options>] [(<mbox> | <Maildir>)...]"
-msgstr "git am [ОПЦИЯ…] [(ФАЙЛ_С_ПОЩА|ДИРЕКТОРИЯ_С_ПОЩА)…]"
+#: setup.c:255
+#, c-format
+msgid ""
+"ambiguous argument '%s': both revision and filename\n"
+"Use '--' to separate paths from revisions, like this:\n"
+"'git <command> [<revision>...] -- [<file>...]'"
+msgstr ""
+"нееднозначен аргумент „%s“: както версия, така и път.\n"
+"Разделяйте пътищата от версиите с „--“, ето така:\n"
+"\n"
+"    git КОМАНДА [ВЕРСИЯ…] -- [ФАЙЛ…]"
 
-#: builtin/am.c:2211
-msgid "git am [<options>] (--continue | --skip | --abort)"
-msgstr "git am [ОПЦИЯ…] (--continue | --quit | --abort)"
+#: setup.c:391
+msgid "unable to set up work tree using invalid config"
+msgstr ""
+"не може да се зададе текуща работна директория при неправилни настройки"
 
-#: builtin/am.c:2217
-msgid "run interactively"
-msgstr "интерактивна работа"
+#: setup.c:395
+msgid "this operation must be run in a work tree"
+msgstr "тази команда трябва да се изпълни в работно дърво"
 
-#: builtin/am.c:2219
-msgid "historical option -- no-op"
-msgstr "изоставена опция, съществува по исторически причини, нищо не прави"
+#: setup.c:541
+#, c-format
+msgid "Expected git repo version <= %d, found %d"
+msgstr "Очаква се версия на хранилището на git <= %d, а не %d"
 
-#: builtin/am.c:2221
-msgid "allow fall back on 3way merging if needed"
-msgstr "да се преминава към тройно сливане при нужда."
+#: setup.c:549
+msgid "unknown repository extensions found:"
+msgstr "открити са непознати разширения в хранилището:"
 
-#: builtin/am.c:2222 builtin/init-db.c:484 builtin/prune-packed.c:57
-#: builtin/repack.c:192
-msgid "be quiet"
-msgstr "без извеждане на информация"
+#: setup.c:568
+#, c-format
+msgid "error opening '%s'"
+msgstr "„%s“ не може да се отвори"
 
-#: builtin/am.c:2224
-msgid "add a Signed-off-by line to the commit message"
-msgstr "добавяне на ред за подпис „Signed-off-by“ в съобщението за подаване"
+#: setup.c:570
+#, c-format
+msgid "too large to be a .git file: '%s'"
+msgstr "прекалено голям файл „.git“: „%s“"
 
-#: builtin/am.c:2227
-msgid "recode into utf8 (default)"
-msgstr "прекодиране в UTF-8 (стандартно)"
+#: setup.c:572
+#, c-format
+msgid "error reading %s"
+msgstr "грешка при прочитане на „%s“"
 
-#: builtin/am.c:2229
-msgid "pass -k flag to git-mailinfo"
-msgstr "подаване на опцията „-k“ на командата „git-mailinfo“"
+#: setup.c:574
+#, c-format
+msgid "invalid gitfile format: %s"
+msgstr "неправилен формат на gitfile: %s"
 
-#: builtin/am.c:2231
-msgid "pass -b flag to git-mailinfo"
-msgstr "подаване на опцията „-b“ на командата „git-mailinfo“"
+#: setup.c:576
+#, c-format
+msgid "no path in gitfile: %s"
+msgstr "липсва път в gitfile: „%s“"
 
-#: builtin/am.c:2233
-msgid "pass -m flag to git-mailinfo"
-msgstr "подаване на опцията „-m“ на командата „git-mailinfo“"
+#: setup.c:578
+#, c-format
+msgid "not a git repository: %s"
+msgstr "не е хранилище на Git: %s"
 
-#: builtin/am.c:2235
-msgid "pass --keep-cr flag to git-mailsplit for mbox format"
-msgstr ""
-"подаване на опцията „--keep-cr“ на командата „git-mailsplit“ за формат „mbox“"
+#: setup.c:677
+#, c-format
+msgid "'$%s' too big"
+msgstr "„%s“ е прекалено голям"
 
-#: builtin/am.c:2238
-msgid "do not pass --keep-cr flag to git-mailsplit independent of am.keepcr"
-msgstr ""
-"без подаване на опцията „--keep-cr“ на командата „git-mailsplit“ независимо "
-"от „am.keepcr“"
+#: setup.c:691
+#, c-format
+msgid "not a git repository: '%s'"
+msgstr "не е хранилище на git: „%s“"
 
-#: builtin/am.c:2241
-msgid "strip everything before a scissors line"
-msgstr "пропускане на всичко преди реда за отрязване"
+#: setup.c:720 setup.c:722 setup.c:753
+#, c-format
+msgid "cannot chdir to '%s'"
+msgstr "не може да се влезе в директорията „%s“"
 
-#: builtin/am.c:2243 builtin/am.c:2246 builtin/am.c:2249 builtin/am.c:2252
-#: builtin/am.c:2255 builtin/am.c:2258 builtin/am.c:2261 builtin/am.c:2264
-#: builtin/am.c:2270
-msgid "pass it through git-apply"
-msgstr "прекарване през „git-apply“"
+#: setup.c:725 setup.c:781 setup.c:791 setup.c:830 setup.c:838
+msgid "cannot come back to cwd"
+msgstr "процесът не може да се върне към предишната работна директория"
 
-#: builtin/am.c:2260 builtin/commit.c:1332 builtin/fmt-merge-msg.c:665
-#: builtin/fmt-merge-msg.c:668 builtin/grep.c:853 builtin/merge.c:208
-#: builtin/pull.c:150 builtin/pull.c:208 builtin/repack.c:201
-#: builtin/repack.c:205 builtin/repack.c:207 builtin/show-branch.c:631
-#: builtin/show-ref.c:169 builtin/tag.c:383 parse-options.h:144
-#: parse-options.h:146 parse-options.h:258
-msgid "n"
-msgstr "БРОЙ"
+#: setup.c:852
+#, c-format
+msgid "failed to stat '%*s%s%s'"
+msgstr "не може да бъде получена информация чрез „stat“ за „%*s%s%s“"
 
-#: builtin/am.c:2266 builtin/branch.c:632 builtin/for-each-ref.c:38
-#: builtin/replace.c:543 builtin/tag.c:419 builtin/verify-tag.c:39
-msgid "format"
-msgstr "ФОРМАТ"
+#: setup.c:1090
+msgid "Unable to read current working directory"
+msgstr "Текущата работна директория не може да бъде прочетена"
 
-#: builtin/am.c:2267
-msgid "format the patch(es) are in"
-msgstr "формат на кръпките"
+#: setup.c:1099 setup.c:1105
+#, c-format
+msgid "cannot change to '%s'"
+msgstr "не може да се влезе в директорията „%s“"
 
-#: builtin/am.c:2273
-msgid "override error message when patch failure occurs"
-msgstr "избрано от вас съобщение за грешка при прилагане на кръпки"
+#: setup.c:1110
+#, c-format
+msgid "not a git repository (or any of the parent directories): %s"
+msgstr ""
+"нито тази, нито която и да е от по-горните директории, не е хранилище на "
+"git: %s"
 
-#: builtin/am.c:2275
-msgid "continue applying patches after resolving a conflict"
-msgstr "продължаване на прилагането на кръпки след коригирането на конфликт"
+#: setup.c:1116
+#, c-format
+msgid ""
+"not a git repository (or any parent up to mount point %s)\n"
+"Stopping at filesystem boundary (GIT_DISCOVERY_ACROSS_FILESYSTEM not set)."
+msgstr ""
+"нито тази, нито която и да е от по-горните директории (до точката на "
+"монтиране „%s“), не е хранилище на git.\n"
+"Git работи в рамките на една файлова система, защото променливата на средата "
+"„GIT_DISCOVERY_ACROSS_FILESYSTEM“ не е зададена."
 
-#: builtin/am.c:2278
-msgid "synonyms for --continue"
-msgstr "синоними на „--continue“"
+#: setup.c:1227
+#, c-format
+msgid ""
+"problem with core.sharedRepository filemode value (0%.3o).\n"
+"The owner of files must always have read and write permissions."
+msgstr ""
+"зададеният в „core.sharedRepository“ режим за достъп до файлове е неправилен "
+"(0%.3o).\n"
+"Собственикът на файла трябва да има права за писане и четене."
 
-#: builtin/am.c:2281
-msgid "skip the current patch"
-msgstr "прескачане на текущата кръпка"
+#: setup.c:1271
+msgid "open /dev/null or dup failed"
+msgstr "неуспешно изпълнение на „open“ или „dup“ върху „/dev/null“"
 
-#: builtin/am.c:2284
-msgid "restore the original branch and abort the patching operation."
+#: setup.c:1286
+msgid "fork failed"
+msgstr "неуспешно създаване на процес чрез „fork“"
+
+#: setup.c:1291
+msgid "setsid failed"
+msgstr "неуспешно изпълнение на „setsid“"
+
+#: sha1-file.c:452
+#, c-format
+msgid "object directory %s does not exist; check .git/objects/info/alternates"
 msgstr ""
-"възстановяване на първоначалното състояние на клона и преустановяване на "
-"прилагането на кръпката."
+"директорията за обекти „%s“ не съществува, проверете „.git/objects/info/"
+"alternates“"
 
-#: builtin/am.c:2287
-msgid "abort the patching operation but keep HEAD where it is."
+#: sha1-file.c:503
+#, c-format
+msgid "unable to normalize alternate object path: %s"
+msgstr "алтернативният път към обекти не може да бъде нормализиран: „%s“"
+
+#: sha1-file.c:575
+#, c-format
+msgid "%s: ignoring alternate object stores, nesting too deep"
 msgstr ""
-"преустановяване на прилагането на кръпката без промяна към кое сочи „HEAD“."
+"%s: алтернативните хранилища за обекти се пренебрегват поради прекалено "
+"дълбоко влагане"
 
-#: builtin/am.c:2290
-msgid "show the patch being applied."
-msgstr "показване на прилаганата кръпка."
+#: sha1-file.c:582
+#, c-format
+msgid "unable to normalize object directory: %s"
+msgstr "директорията за обекти „%s“ не може да бъде нормализирана"
 
-#: builtin/am.c:2294
-msgid "lie about committer date"
-msgstr "дата за подаване различна от първоначалната"
+#: sha1-file.c:625
+msgid "unable to fdopen alternates lockfile"
+msgstr "заключващият файл за алтернативите не може да се отвори с „fdopen“"
 
-#: builtin/am.c:2296
-msgid "use current timestamp for author date"
-msgstr "използване на текущото време като това за автор"
+#: sha1-file.c:643
+msgid "unable to read alternates file"
+msgstr "файлът с алтернативите не може да бъде прочетен"
+
+#: sha1-file.c:650
+msgid "unable to move new alternates file into place"
+msgstr "новият файл с алтернативите не може да бъде преместен на мястото му"
 
-#: builtin/am.c:2298 builtin/commit.c:1468 builtin/merge.c:239
-#: builtin/pull.c:183 builtin/revert.c:112 builtin/tag.c:399
-msgid "key-id"
-msgstr "ИДЕНТИФИКАТОР_НА_КЛЮЧ"
+#: sha1-file.c:685
+#, c-format
+msgid "path '%s' does not exist"
+msgstr "пътят „%s“ не съществува."
 
-#: builtin/am.c:2299
-msgid "GPG-sign commits"
-msgstr "подписване на подаванията с GPG"
+#: sha1-file.c:711
+#, c-format
+msgid "reference repository '%s' as a linked checkout is not supported yet."
+msgstr "все още не се поддържа еталонно хранилище „%s“ като свързано."
 
-#: builtin/am.c:2302
-msgid "(internal use for git-rebase)"
-msgstr "(ползва се вътрешно за „git-rebase“)"
+#: sha1-file.c:717
+#, c-format
+msgid "reference repository '%s' is not a local repository."
+msgstr "еталонното хранилище „%s“ не е локално"
 
-#: builtin/am.c:2320
-msgid ""
-"The -b/--binary option has been a no-op for long time, and\n"
-"it will be removed. Please do not use it anymore."
-msgstr ""
-"Опциите „-b“/„--binary“ отдавна не правят нищо и\n"
-"ще бъдат премахнати в бъдеще.  Не ги ползвайте."
+#: sha1-file.c:723
+#, c-format
+msgid "reference repository '%s' is shallow"
+msgstr "еталонното хранилище „%s“ е плитко"
 
-#: builtin/am.c:2327
-msgid "failed to read the index"
-msgstr "неуспешно изчитане на индекса"
+#: sha1-file.c:731
+#, c-format
+msgid "reference repository '%s' is grafted"
+msgstr "еталонното хранилище „%s“ е с присаждане"
 
-#: builtin/am.c:2342
+#: sha1-file.c:791
 #, c-format
-msgid "previous rebase directory %s still exists but mbox given."
-msgstr ""
-"предишната директория за пребазиране „%s“ все още съществува, а е зададен "
-"файл „mbox“."
+msgid "invalid line while parsing alternate refs: %s"
+msgstr "неправилен ред при анализа на алтернативните указатели: „%s“"
 
-#: builtin/am.c:2366
+#: sha1-file.c:943
 #, c-format
-msgid ""
-"Stray %s directory found.\n"
-"Use \"git am --abort\" to remove it."
+msgid "attempting to mmap %<PRIuMAX> over limit %<PRIuMAX>"
 msgstr ""
-"Открита е излишна директория „%s“.\n"
-"Можете да я изтриете с командата „git am --abort“."
+"неуспешен опит за „mmap“ %<PRIuMAX>, което е над позволеното %<PRIuMAX>"
 
-#: builtin/am.c:2372
-msgid "Resolve operation not in progress, we are not resuming."
-msgstr "В момента не тече операция по коригиране и няма как да се продължи."
+#: sha1-file.c:964
+msgid "mmap failed"
+msgstr "неуспешно изпълнение на „mmap“"
 
-#: builtin/apply.c:8
-msgid "git apply [<options>] [<patch>...]"
-msgstr "git apply [ОПЦИЯ…] [КРЪПКА…]"
+#: sha1-file.c:1128
+#, c-format
+msgid "object file %s is empty"
+msgstr "файлът с обектите „%s“ е празен"
 
-#: builtin/archive.c:17
+#: sha1-file.c:1252 sha1-file.c:2392
 #, c-format
-msgid "could not create archive file '%s'"
-msgstr "архивният файл „%s“ не може да бъде създаден"
+msgid "corrupt loose object '%s'"
+msgstr "непакетираният обект „%s“ е повреден"
 
-#: builtin/archive.c:20
-msgid "could not redirect output"
-msgstr "изходът не може да бъде пренасочен"
+#: sha1-file.c:1254 sha1-file.c:2396
+#, c-format
+msgid "garbage at end of loose object '%s'"
+msgstr "грешни данни в края на непакетирания обект „%s“"
 
-#: builtin/archive.c:37
-msgid "git archive: Remote with no URL"
-msgstr "git archive: Липсва адрес за отдалеченото хранилище"
+#: sha1-file.c:1296
+msgid "invalid object type"
+msgstr "неправилен вид обект"
 
-#: builtin/archive.c:58
-msgid "git archive: expected ACK/NAK, got a flush packet"
+#: sha1-file.c:1380
+#, c-format
+msgid "unable to unpack %s header with --allow-unknown-type"
 msgstr ""
-"git archive: очакваше се „ACK“/„NAK“, а бе получен изчистващ пакет „flush“"
+"заглавната част „%s“ не може да се разпакетира с опцията „--allow-unknown-"
+"type“"
 
-#: builtin/archive.c:61
+#: sha1-file.c:1383
 #, c-format
-msgid "git archive: NACK %s"
-msgstr "git archive: получен е „NACK“ — %s"
+msgid "unable to unpack %s header"
+msgstr "заглавната част на „%s“ не може да бъде разпакетирана"
 
-#: builtin/archive.c:64
-msgid "git archive: protocol error"
-msgstr "git archive: протоколна грешка"
+#: sha1-file.c:1389
+#, c-format
+msgid "unable to parse %s header with --allow-unknown-type"
+msgstr ""
+"заглавната част „%s“ не може да се анализира с опцията „--allow-unknown-type“"
 
-#: builtin/archive.c:68
-msgid "git archive: expected a flush"
-msgstr "git archive: очакваше се изчистване на буферите чрез „flush“"
+#: sha1-file.c:1392
+#, c-format
+msgid "unable to parse %s header"
+msgstr "заглавната част на „%s“ не може да бъде анализирана"
 
-#: builtin/bisect--helper.c:12
-msgid "git bisect--helper --next-all [--no-checkout]"
-msgstr "git bisect--helper --next-all [--no-checkout]"
+#: sha1-file.c:1584
+#, c-format
+msgid "failed to read object %s"
+msgstr "обектът „%s“ не може да бъде прочетен"
 
-#: builtin/bisect--helper.c:13
-msgid "git bisect--helper --write-terms <bad_term> <good_term>"
-msgstr "git bisect--helper --write-terms ЛОШО ДОБРО"
+#: sha1-file.c:1588
+#, c-format
+msgid "replacement %s not found for %s"
+msgstr "заместителят „%s“ на „%s“ не може да бъде открит"
 
-#: builtin/bisect--helper.c:14
-msgid "git bisect--helper --bisect-clean-state"
-msgstr "git bisect--helper --bisect-clean-state"
+#: sha1-file.c:1592
+#, c-format
+msgid "loose object %s (stored in %s) is corrupt"
+msgstr "непакетираният обект „%s“ (в „%s“) е повреден"
 
-#: builtin/bisect--helper.c:46
+#: sha1-file.c:1596
 #, c-format
-msgid "'%s' is not a valid term"
-msgstr "„%s“ е неправилна управляваща дума"
+msgid "packed object %s (stored in %s) is corrupt"
+msgstr "пакетираният обект „%s“ (в „%s“) е повреден"
 
-#: builtin/bisect--helper.c:50
+#: sha1-file.c:1699
 #, c-format
-msgid "can't use the builtin command '%s' as a term"
-msgstr "„%s“ е вградена команда и не може да се използва като управляваща дума"
+msgid "unable to write file %s"
+msgstr "файлът „%s“ не може да бъде записан"
 
-#: builtin/bisect--helper.c:60
+#: sha1-file.c:1706
 #, c-format
-msgid "can't change the meaning of the term '%s'"
-msgstr "не може да смените значението на управляващата дума „%s“"
+msgid "unable to set permission to '%s'"
+msgstr "правата за достъп до „%s“ не могат да бъдат зададени"
 
-#: builtin/bisect--helper.c:71
-msgid "please use two different terms"
-msgstr "използвайте две различни управляващи думи"
+#: sha1-file.c:1713
+msgid "file write error"
+msgstr "грешка при запис на файл"
 
-#: builtin/bisect--helper.c:78
-msgid "could not open the file BISECT_TERMS"
-msgstr "файлът „BISECT_TERMS“ не може да се отвори"
+#: sha1-file.c:1732
+msgid "error when closing loose object file"
+msgstr "грешка при затварянето на файла с непакетиран обект"
 
-#: builtin/bisect--helper.c:120
-msgid "perform 'git bisect next'"
-msgstr "извършване на „git bisect next“"
+#: sha1-file.c:1797
+#, c-format
+msgid "insufficient permission for adding an object to repository database %s"
+msgstr ""
+"няма права за добавяне на обект към базата от данни на хранилището „%s“"
 
-#: builtin/bisect--helper.c:122
-msgid "write the terms to .git/BISECT_TERMS"
-msgstr "запазване на управляващите думи в „“.git/BISECT_TERMS„“"
+#: sha1-file.c:1799
+msgid "unable to create temporary file"
+msgstr "не може да бъде създаден временен файл"
 
-#: builtin/bisect--helper.c:124
-msgid "cleanup the bisection state"
-msgstr "изчистване на състоянието на двоичното търсене"
+#: sha1-file.c:1823
+msgid "unable to write loose object file"
+msgstr "грешка при записа на файла с непакетиран обект"
 
-#: builtin/bisect--helper.c:126
-msgid "check for expected revs"
-msgstr "проверка за очакваните версии"
+#: sha1-file.c:1829
+#, c-format
+msgid "unable to deflate new object %s (%d)"
+msgstr "новият обект „%s“ не може да се компресира с „deflate“: %d"
 
-#: builtin/bisect--helper.c:128
-msgid "update BISECT_HEAD instead of checking out the current commit"
-msgstr ""
-"обновяване на указателя „BISECT_HEAD“ вместо да се използва текущото подаване"
+#: sha1-file.c:1833
+#, c-format
+msgid "deflateEnd on object %s failed (%d)"
+msgstr "неуспешно приключване на „deflate“ върху „%s“: %d"
 
-#: builtin/bisect--helper.c:143
-msgid "--write-terms requires two arguments"
-msgstr "опцията „--write-terms“ изисква точно два аргумента"
+#: sha1-file.c:1837
+#, c-format
+msgid "confused by unstable object source data for %s"
+msgstr "грешка поради нестабилния източник данни за обектите „%s“"
 
-#: builtin/bisect--helper.c:147
-msgid "--bisect-clean-state requires no arguments"
-msgstr "опцията „--bisect-clean-state“ не приема аргументи"
+#: sha1-file.c:1847 builtin/pack-objects.c:925
+#, c-format
+msgid "failed utime() on %s"
+msgstr "неуспешно задаване на време на достъп/създаване чрез „utime“ на „%s“"
 
-#: builtin/blame.c:29
-msgid "git blame [<options>] [<rev-opts>] [<rev>] [--] <file>"
-msgstr "git blame [ОПЦИЯ…] [ОПЦИЯ_ЗА_ВЕРСИЯТА…] [ВЕРСИЯ] [--] ФАЙЛ"
+#: sha1-file.c:1922
+#, c-format
+msgid "cannot read object for %s"
+msgstr "обектът за „%s“ не може да се прочете"
 
-#: builtin/blame.c:34
-msgid "<rev-opts> are documented in git-rev-list(1)"
-msgstr "ОПЦИИте_ЗА_ВЕРСИЯТА са документирани в ръководството git-rev-list(1)"
+#: sha1-file.c:1962
+msgid "corrupt commit"
+msgstr "повредено подаване"
+
+#: sha1-file.c:1970
+msgid "corrupt tag"
+msgstr "повреден етикет"
 
-#: builtin/blame.c:404
+#: sha1-file.c:2069
 #, c-format
-msgid "expecting a color: %s"
-msgstr "трябва да е цвят: %s"
+msgid "read error while indexing %s"
+msgstr "грешка при четене по време на индексиране на „%s“"
 
-#: builtin/blame.c:411
-msgid "must end with a color"
-msgstr "трябва да завършва с цвят"
+#: sha1-file.c:2072
+#, c-format
+msgid "short read while indexing %s"
+msgstr "непълно прочитане по време на индексиране на „%s“"
 
-#: builtin/blame.c:697
+#: sha1-file.c:2145 sha1-file.c:2154
 #, c-format
-msgid "invalid color '%s' in color.blame.repeatedLines"
-msgstr "неправилен цвят „%s“ в „color.blame.repeatedLines“"
+msgid "%s: failed to insert into database"
+msgstr "„%s“ не може да се вмъкне в базата от данни"
 
-#: builtin/blame.c:715
-msgid "invalid value for blame.coloring"
-msgstr "неправилна стойност за „blame.coloring“"
+#: sha1-file.c:2160
+#, c-format
+msgid "%s: unsupported file type"
+msgstr "неподдържан вид файл: „%s“"
 
-#: builtin/blame.c:786
-msgid "Show blame entries as we find them, incrementally"
-msgstr "Извеждане на анотациите с намирането им, последователно"
+#: sha1-file.c:2184
+#, c-format
+msgid "%s is not a valid object"
+msgstr "„%s“ е неправилен обект"
 
-#: builtin/blame.c:787
-msgid "Show blank SHA-1 for boundary commits (Default: off)"
-msgstr ""
-"Извеждане на празни суми по SHA1 за граничните подавания (стандартно опцията "
-"е изключена)"
+#: sha1-file.c:2186
+#, c-format
+msgid "%s is not a valid '%s' object"
+msgstr "„%s“ е неправилен обект от вид „%s“"
 
-#: builtin/blame.c:788
-msgid "Do not treat root commits as boundaries (Default: off)"
-msgstr ""
-"Началните подавания да не се считат за гранични (стандартно опцията е "
-"изключена)"
+#: sha1-file.c:2213 builtin/index-pack.c:155
+#, c-format
+msgid "unable to open %s"
+msgstr "обектът „%s“ не може да бъде отворен"
 
-#: builtin/blame.c:789
-msgid "Show work cost statistics"
-msgstr "Извеждане на статистика за извършените действия"
+#: sha1-file.c:2403 sha1-file.c:2455
+#, c-format
+msgid "hash mismatch for %s (expected %s)"
+msgstr "неправилна контролна сума за „%s“ (трябва да е %s)"
 
-#: builtin/blame.c:790
-msgid "Force progress reporting"
-msgstr "Принудително извеждане на напредъка"
+#: sha1-file.c:2427
+#, c-format
+msgid "unable to mmap %s"
+msgstr "неуспешно изпълнение на „mmap“ върху „%s“"
 
-#: builtin/blame.c:791
-msgid "Show output score for blame entries"
-msgstr "Извеждане на допълнителна информация за определянето на анотациите"
+#: sha1-file.c:2432
+#, c-format
+msgid "unable to unpack header of %s"
+msgstr "заглавната част на „%s“ не може да бъде разпакетирана"
 
-#: builtin/blame.c:792
-msgid "Show original filename (Default: auto)"
-msgstr ""
-"Извеждане на първоначалното име на файл (стандартно това е автоматично)"
+#: sha1-file.c:2438
+#, c-format
+msgid "unable to parse header of %s"
+msgstr "заглавната част на „%s“ не може да бъде анализирана"
 
-#: builtin/blame.c:793
-msgid "Show original linenumber (Default: off)"
-msgstr ""
-"Извеждане на първоначалният номер на ред (стандартно опцията е изключена)"
+#: sha1-file.c:2449
+#, c-format
+msgid "unable to unpack contents of %s"
+msgstr "съдържанието на „%s“ не може да бъде разпакетирано"
 
-#: builtin/blame.c:794
-msgid "Show in a format designed for machine consumption"
-msgstr "Извеждане във формат за по-нататъшна обработка"
+#: sha1-name.c:487
+#, c-format
+msgid "short SHA1 %s is ambiguous"
+msgstr "късият SHA1 „%s“ не е еднозначен"
 
-#: builtin/blame.c:795
-msgid "Show porcelain format with per-line commit information"
-msgstr ""
-"Извеждане във формат за команди от потребителско ниво с информация на всеки "
-"ред"
+#: sha1-name.c:498
+msgid "The candidates are:"
+msgstr "Възможностите са:"
 
-#: builtin/blame.c:796
-msgid "Use the same output mode as git-annotate (Default: off)"
+#: sha1-name.c:797
+msgid ""
+"Git normally never creates a ref that ends with 40 hex characters\n"
+"because it will be ignored when you just specify 40-hex. These refs\n"
+"may be created by mistake. For example,\n"
+"\n"
+"  git switch -c $br $(git rev-parse ...)\n"
+"\n"
+"where \"$br\" is somehow empty and a 40-hex ref is created. Please\n"
+"examine these refs and maybe delete them. Turn this message off by\n"
+"running \"git config advice.objectNameWarning false\""
 msgstr ""
-"Използване на същия формат като „git-annotate“ (стандартно опцията е "
-"изключена)"
-
-#: builtin/blame.c:797
-msgid "Show raw timestamp (Default: off)"
-msgstr "Извеждане на неформатирани времена (стандартно опцията е изключена)"
-
-#: builtin/blame.c:798
-msgid "Show long commit SHA1 (Default: off)"
-msgstr "Извеждане на пълните суми по SHA1 (стандартно опцията е изключена)"
-
-#: builtin/blame.c:799
-msgid "Suppress author name and timestamp (Default: off)"
-msgstr "Без име на автор и време на промяна (стандартно опцията е изключена)"
+"При нормална работа Git никога не създава указатели, които завършват с 40\n"
+"шестнадесетични знака, защото стандартно те ще бъдат прескачани.\n"
+"Възможно е такива указатели да са създадени случайно.  Например:\n"
+"\n"
+"    git switch -c $BRANCH $(git rev-parse …)\n"
+"\n"
+"където стойността на променливата на средата BRANCH е празна, при което се\n"
+"създава подобен указател.  Прегледайте тези указатели и ги изтрийте.  Може "
+"да\n"
+"спрете това съобщение като изпълните командата:\n"
+"\n"
+"    git config advice.objectNameWarning false"
 
-#: builtin/blame.c:800
-msgid "Show author email instead of name (Default: off)"
-msgstr ""
-"Извеждане на е-пощата на автора, а не името му (стандартно опцията е "
-"изключена)"
+#. TRANSLATORS: IEC 80000-13:2008 gibibyte
+#: strbuf.c:822
+#, c-format
+msgid "%u.%2.2u GiB"
+msgstr "%u.%2.2u GiB"
 
-#: builtin/blame.c:801
-msgid "Ignore whitespace differences"
-msgstr "Без разлики в знаците за интервали"
+#. TRANSLATORS: IEC 80000-13:2008 gibibyte/second
+#: strbuf.c:824
+#, c-format
+msgid "%u.%2.2u GiB/s"
+msgstr "%u.%2.2u GiB/s"
 
-#: builtin/blame.c:802
-msgid "color redundant metadata from previous line differently"
-msgstr ""
-"оцветяване на повтарящите се метаданни от предишния ред в различен цвят"
+#. TRANSLATORS: IEC 80000-13:2008 mebibyte
+#: strbuf.c:832
+#, c-format
+msgid "%u.%2.2u MiB"
+msgstr "%u.%2.2u MiB"
 
-#: builtin/blame.c:803
-msgid "color lines by age"
-msgstr "оцветяване на редовете по възраст"
+#. TRANSLATORS: IEC 80000-13:2008 mebibyte/second
+#: strbuf.c:834
+#, c-format
+msgid "%u.%2.2u MiB/s"
+msgstr "%u.%2.2u MiB/s"
 
-#: builtin/blame.c:810
-msgid "Use an experimental heuristic to improve diffs"
-msgstr "Подобряване на разликите чрез експериментална евристика"
+#. TRANSLATORS: IEC 80000-13:2008 kibibyte
+#: strbuf.c:841
+#, c-format
+msgid "%u.%2.2u KiB"
+msgstr "%u.%2.2u KiB"
 
-#: builtin/blame.c:812
-msgid "Spend extra cycles to find better match"
-msgstr "Допълнителни изчисления за по-добри резултати"
+#. TRANSLATORS: IEC 80000-13:2008 kibibyte/second
+#: strbuf.c:843
+#, c-format
+msgid "%u.%2.2u KiB/s"
+msgstr "%u.%2.2u KiB/s"
 
-#: builtin/blame.c:813
-msgid "Use revisions from <file> instead of calling git-rev-list"
-msgstr "Изчитане на версиите от ФАЙЛ, а не чрез изпълнение на „git-rev-list“"
+#. TRANSLATORS: IEC 80000-13:2008 byte
+#: strbuf.c:849
+#, c-format
+msgid "%u byte"
+msgid_plural "%u bytes"
+msgstr[0] "%u байт"
+msgstr[1] "%u байта"
 
-#: builtin/blame.c:814
-msgid "Use <file>'s contents as the final image"
-msgstr "Използване на съдържанието на ФАЙЛа като крайно положение"
+#. TRANSLATORS: IEC 80000-13:2008 byte/second
+#: strbuf.c:851
+#, c-format
+msgid "%u byte/s"
+msgid_plural "%u bytes/s"
+msgstr[0] "%u байт/сек."
+msgstr[1] "%u байта/сек."
 
-#: builtin/blame.c:815 builtin/blame.c:816
-msgid "score"
-msgstr "напасване на редовете"
+#: strbuf.c:1149
+#, c-format
+msgid "could not edit '%s'"
+msgstr "„%s“ не може да се редактира"
 
-#: builtin/blame.c:815
-msgid "Find line copies within and across files"
+#: submodule.c:114 submodule.c:143
+msgid "Cannot change unmerged .gitmodules, resolve merge conflicts first"
 msgstr ""
-"Търсене на копирани редове както в рамките на един файл, така и от един файл "
-"към друг"
+"Неслетите файлове „.gitmodules“ не могат да бъдат променяни.  Първо "
+"коригирайте конфликтите"
 
-#: builtin/blame.c:816
-msgid "Find line movements within and across files"
-msgstr ""
-"Търсене на преместени редове както в рамките на един файл, така и от един "
-"файл към друг"
+#: submodule.c:118 submodule.c:147
+#, c-format
+msgid "Could not find section in .gitmodules where path=%s"
+msgstr "Във файла „.gitmodules“ липсва раздел за директория „path=%s“"
 
-#: builtin/blame.c:817
-msgid "n,m"
-msgstr "n,m"
+#: submodule.c:154
+#, c-format
+msgid "Could not remove .gitmodules entry for %s"
+msgstr "Записът „%s“ във файла „.gitmodules“ не може да бъде изтрит"
 
-#: builtin/blame.c:817
-msgid "Process only line range n,m, counting from 1"
-msgstr ""
-"Информация само за редовете в диапазона от n до m включително.  Броенето "
-"започва от 1"
+#: submodule.c:165
+msgid "staging updated .gitmodules failed"
+msgstr "неуспешно добавяне на променения файл „.gitmodules“ в индекса"
 
-#: builtin/blame.c:866
-msgid "--progress can't be used with --incremental or porcelain formats"
-msgstr ""
-"опцията „--progress“ е несъвместима с „--incremental“ и форма̀та на командите "
-"от потребителско ниво"
+#: submodule.c:327
+#, c-format
+msgid "in unpopulated submodule '%s'"
+msgstr "в неподготвения подмодул „%s“"
 
-#. TRANSLATORS: This string is used to tell us the
-#. maximum display width for a relative timestamp in
-#. "git blame" output.  For C locale, "4 years, 11
-#. months ago", which takes 22 places, is the longest
-#. among various forms of relative timestamps, but
-#. your language may need more or fewer display
-#. columns.
-#.
-#: builtin/blame.c:917
-msgid "4 years, 11 months ago"
-msgstr "преди 4 години и 11 месеца"
+#: submodule.c:358
+#, c-format
+msgid "Pathspec '%s' is in submodule '%.*s'"
+msgstr "Пътят „%s“ е в подмодула „%.*s“"
 
-#: builtin/blame.c:1003
+#: submodule.c:910
 #, c-format
-msgid "file %s has only %lu line"
-msgid_plural "file %s has only %lu lines"
-msgstr[0] "има само %2$lu ред във файла „%1$s“"
-msgstr[1] "има само %2$lu реда във файла „%1$s“"
+msgid "submodule entry '%s' (%s) is a %s, not a commit"
+msgstr "записът за подмодула „%s“ (%s) е %s, а не подаване!"
 
-#: builtin/blame.c:1049
-msgid "Blaming lines"
-msgstr "Анотирани редове"
+#: submodule.c:1147 builtin/branch.c:680 builtin/submodule--helper.c:2016
+msgid "Failed to resolve HEAD as a valid ref."
+msgstr "Не може да се открие към какво сочи указателят „HEAD“"
 
-#: builtin/branch.c:27
-msgid "git branch [<options>] [-r | -a] [--merged | --no-merged]"
-msgstr "git branch [ОПЦИЯ…] [-r | -a] [--merged | --no-merged]"
+#: submodule.c:1481
+#, c-format
+msgid "Could not access submodule '%s'"
+msgstr "Подмодулът „%s“ не може да бъде достъпен"
 
-#: builtin/branch.c:28
-msgid "git branch [<options>] [-l] [-f] <branch-name> [<start-point>]"
-msgstr "git branch [ОПЦИЯ…] [-l] [-f] ИМЕ_НА_КЛОН [НАЧАЛО]"
+#: submodule.c:1651
+#, c-format
+msgid "'%s' not recognized as a git repository"
+msgstr "„%s“ не е хранилище на git"
 
-#: builtin/branch.c:29
-msgid "git branch [<options>] [-r] (-d | -D) <branch-name>..."
-msgstr "git branch [ОПЦИЯ…] [-r] (-d | -D) ИМЕ_НА_КЛОН…"
+#: submodule.c:1789
+#, c-format
+msgid "could not start 'git status' in submodule '%s'"
+msgstr "командата „git status“ не може да се изпълни в подмодула „%s“"
 
-#: builtin/branch.c:30
-msgid "git branch [<options>] (-m | -M) [<old-branch>] <new-branch>"
-msgstr "git branch [ОПЦИЯ…] (-m | -M) [СТАР_КЛОН] НОВ_КЛОН"
+#: submodule.c:1802
+#, c-format
+msgid "could not run 'git status' in submodule '%s'"
+msgstr "командата „git status“ не може да се изпълни в подмодула „%s“"
 
-#: builtin/branch.c:31
-msgid "git branch [<options>] (-c | -C) [<old-branch>] <new-branch>"
-msgstr "git branch [ОПЦИЯ…] (-c | -C) [СТАР_КЛОН] НОВ_КЛОН"
+#: submodule.c:1817
+#, c-format
+msgid "Could not unset core.worktree setting in submodule '%s'"
+msgstr "Настройката „core.worktree“ не може да се изтрие в подмодула „%s“"
 
-#: builtin/branch.c:32
-msgid "git branch [<options>] [-r | -a] [--points-at]"
-msgstr "git branch [ОПЦИЯ…] [-r | -a] [--points-at]"
+#: submodule.c:1907
+#, c-format
+msgid "submodule '%s' has dirty index"
+msgstr "индексът на подмодула „%s“ не е чист"
 
-#: builtin/branch.c:33
-msgid "git branch [<options>] [-r | -a] [--format]"
-msgstr "git branch [ОПЦИЯ…] [-r | -a] [--format]"
+#: submodule.c:1959
+#, c-format
+msgid "Submodule '%s' could not be updated."
+msgstr "Подмодулът „%s“ не може да се обнови."
 
-#: builtin/branch.c:146
+#: submodule.c:2027
 #, c-format
-msgid ""
-"deleting branch '%s' that has been merged to\n"
-"         '%s', but not yet merged to HEAD."
-msgstr ""
-"изтриване на клона „%s“, който е слят към „%s“,\n"
-"    но още не е слят към върха „HEAD“."
+msgid "submodule git dir '%s' is inside git dir '%.*s'"
+msgstr "„%s“ (директория на подмодул) е в директорията на git: „%.*s“"
 
-#: builtin/branch.c:150
+#: submodule.c:2048
 #, c-format
 msgid ""
-"not deleting branch '%s' that is not yet merged to\n"
-"         '%s', even though it is merged to HEAD."
+"relocate_gitdir for submodule '%s' with more than one worktree not supported"
 msgstr ""
-"отказване на изтриване на клона „%s“, който не е слят към\n"
-"    „%s“, но е слят към върха „HEAD“."
+"не се поддържа „relocate_gitdir“ за подмодула „%s“, който има повече от едно "
+"работно дърво"
 
-#: builtin/branch.c:164
+#: submodule.c:2060 submodule.c:2119
 #, c-format
-msgid "Couldn't look up commit object for '%s'"
-msgstr "Обектът-подаване за „%s“ не може да бъде открит"
+msgid "could not lookup name for submodule '%s'"
+msgstr "името на подмодула „%s“ не може да бъде намерено"
+
+#: submodule.c:2064
+#, c-format
+msgid "refusing to move '%s' into an existing git dir"
+msgstr "„%s“ не може да се премести в съществуваща директория на git"
 
-#: builtin/branch.c:168
+#: submodule.c:2071
 #, c-format
 msgid ""
-"The branch '%s' is not fully merged.\n"
-"If you are sure you want to delete it, run 'git branch -D %s'."
+"Migrating git directory of '%s%s' from\n"
+"'%s' to\n"
+"'%s'\n"
 msgstr ""
-"Клонът „%s“ не е слят напълно.  Ако сте сигурни, че искате\n"
-"да го изтриете, изпълнете „git branch -D %s“."
-
-#: builtin/branch.c:181
-msgid "Update of config-file failed"
-msgstr "Неуспешно обновяване на конфигурационния файл"
+"Мигриране на директорията на git — „%s%s“ от:\n"
+"„%s“ към\n"
+"„%s“\n"
 
-#: builtin/branch.c:212
-msgid "cannot use -a with -d"
-msgstr "Опцията „-a“ е несъвместима с опцията „-d“"
+#: submodule.c:2154
+#, c-format
+msgid "could not recurse into submodule '%s'"
+msgstr "неуспешна обработка на поддиректориите в подмодула „%s“"
 
-#: builtin/branch.c:218
-msgid "Couldn't look up commit object for HEAD"
-msgstr "Обектът-подаване, сочен от указателя „HEAD“, не може да бъде открит"
+#: submodule.c:2198
+msgid "could not start ls-files in .."
+msgstr "„ls-stat“ не може да се стартира в „..“"
 
-#: builtin/branch.c:232
+#: submodule.c:2237
 #, c-format
-msgid "Cannot delete branch '%s' checked out at '%s'"
-msgstr "Не можете да изтриете клона „%s“, който е изтеглен в пътя „%s“"
+msgid "ls-tree returned unexpected return code %d"
+msgstr "„ls-tree“ завърши с неочакван изходен код: %d"
 
-#: builtin/branch.c:247
+#: submodule-config.c:236
 #, c-format
-msgid "remote-tracking branch '%s' not found."
-msgstr "следящият клон „%s“ не може да бъде открит."
+msgid "ignoring suspicious submodule name: %s"
+msgstr "игнориране на подозрително име на подмодул: „%s“"
+
+#: submodule-config.c:303
+msgid "negative values not allowed for submodule.fetchjobs"
+msgstr "настройката „submodule.fetchjobs“ не приема отрицателни стойности"
 
-#: builtin/branch.c:248
+#: submodule-config.c:401
 #, c-format
-msgid "branch '%s' not found."
-msgstr "клонът „%s“ не може да бъде открит."
+msgid "ignoring '%s' which may be interpreted as a command-line option: %s"
+msgstr ""
+"„%s“ се прескача, защото е възможно да се тълкува като опция за командния "
+"ред: %s"
 
-#: builtin/branch.c:263
+#: submodule-config.c:498
 #, c-format
-msgid "Error deleting remote-tracking branch '%s'"
-msgstr "Грешка при изтриването на следящия клон „%s“"
+msgid "invalid value for %s"
+msgstr "Неправилна стойност за „%s“"
 
-#: builtin/branch.c:264
+#: submodule-config.c:769
 #, c-format
-msgid "Error deleting branch '%s'"
-msgstr "Грешка при изтриването на клона „%s“"
+msgid "Could not update .gitmodules entry %s"
+msgstr "Записът „%s“ във файла „.gitmodules“ не може да бъде променен"
 
-#: builtin/branch.c:271
+#: trailer.c:238
 #, c-format
-msgid "Deleted remote-tracking branch %s (was %s).\n"
-msgstr "Изтрит следящ клон „%s“ (той сочеше към „%s“).\n"
+msgid "running trailer command '%s' failed"
+msgstr "неуспешно изпълнение на завършващата команда „%s“"
 
-#: builtin/branch.c:272
+#: trailer.c:485 trailer.c:490 trailer.c:495 trailer.c:549 trailer.c:553
+#: trailer.c:557
 #, c-format
-msgid "Deleted branch %s (was %s).\n"
-msgstr "Изтрит клон „%s“ (той сочеше към „%s“).\n"
+msgid "unknown value '%s' for key '%s'"
+msgstr "непозната стойност „%s“ за настройката „%s“"
 
-#: builtin/branch.c:416 builtin/tag.c:58
-msgid "unable to parse format string"
-msgstr "форматиращият низ не може да бъде анализиран: %s"
+#: trailer.c:539 trailer.c:544 builtin/remote.c:295
+#, c-format
+msgid "more than one %s"
+msgstr "стойността „%s“ се повтаря в настройките"
 
-#: builtin/branch.c:453
+#: trailer.c:730
 #, c-format
-msgid "Branch %s is being rebased at %s"
-msgstr "Клонът „%s“ се пребазира върху „%s“"
+msgid "empty trailer token in trailer '%.*s'"
+msgstr "празна завършваща лексема в епилога „%.*s“"
 
-#: builtin/branch.c:457
+#: trailer.c:750
 #, c-format
-msgid "Branch %s is being bisected at %s"
-msgstr "Търси се двоично в клона „%s“ при „%s“"
+msgid "could not read input file '%s'"
+msgstr "входният файл „%s“ не може да бъде прочетен"
 
-#: builtin/branch.c:474
-msgid "cannot copy the current branch while not on any."
-msgstr "не можете да копирате текущия клон, защото сте извън който и да е клон"
+#: trailer.c:753
+msgid "could not read from stdin"
+msgstr "от стандартния вход не може да се чете"
 
-#: builtin/branch.c:476
-msgid "cannot rename the current branch while not on any."
-msgstr ""
-"не можете да преименувате текущия клон, защото сте извън който и да е клон"
+#: trailer.c:1011 wrapper.c:665
+#, c-format
+msgid "could not stat %s"
+msgstr "Не може да се получи информация чрез „stat“ за „%s“"
 
-#: builtin/branch.c:487
+#: trailer.c:1013
 #, c-format
-msgid "Invalid branch name: '%s'"
-msgstr "Неправилно име на клон: „%s“"
+msgid "file %s is not a regular file"
+msgstr "„%s“ не е обикновен файл"
 
-#: builtin/branch.c:514
-msgid "Branch rename failed"
-msgstr "Неуспешно преименуване на клон"
+#: trailer.c:1015
+#, c-format
+msgid "file %s is not writable by user"
+msgstr "„%s“: няма права за записване на файла"
 
-#: builtin/branch.c:516
-msgid "Branch copy failed"
-msgstr "Неуспешно копиране на клон"
+#: trailer.c:1027
+msgid "could not open temporary file"
+msgstr "временният файл не може да се отвори"
 
-#: builtin/branch.c:520
+#: trailer.c:1067
 #, c-format
-msgid "Created a copy of a misnamed branch '%s'"
-msgstr "Клонът с неправилно име „%s“ е копиран"
+msgid "could not rename temporary file to %s"
+msgstr "временният файл не може да се преименува на „%s“"
 
-#: builtin/branch.c:523
+#: transport.c:116
 #, c-format
-msgid "Renamed a misnamed branch '%s' away"
-msgstr "Клонът с неправилно име „%s“ е преименуван"
+msgid "Would set upstream of '%s' to '%s' of '%s'\n"
+msgstr "Клонът „%s“ ще следи „%s“ от „%s“\n"
 
-#: builtin/branch.c:529
+#: transport.c:145
 #, c-format
-msgid "Branch renamed to %s, but HEAD is not updated!"
-msgstr "Клонът е преименуван на „%s“, но указателят „HEAD“ не е обновен"
+msgid "could not read bundle '%s'"
+msgstr "пратката на git „%s“ не може да бъде прочетена"
 
-#: builtin/branch.c:538
-msgid "Branch is renamed, but update of config-file failed"
-msgstr "Клонът е преименуван, но конфигурационният файл не е обновен"
-
-#: builtin/branch.c:540
-msgid "Branch is copied, but update of config-file failed"
-msgstr "Клонът е копиран, но конфигурационният файл не е обновен"
-
-#: builtin/branch.c:556
+#: transport.c:214
 #, c-format
-msgid ""
-"Please edit the description for the branch\n"
-"  %s\n"
-"Lines starting with '%c' will be stripped.\n"
-msgstr ""
-"Въведете описание на клона.\n"
-"    %s\n"
-"Редовете, които започват с „%c“, ще бъдат пропуснати.\n"
-
-#: builtin/branch.c:589
-msgid "Generic options"
-msgstr "Общи настройки"
+msgid "transport: invalid depth option '%s'"
+msgstr "transport: неправилна опция за дълбочина: %s"
 
-#: builtin/branch.c:591
-msgid "show hash and subject, give twice for upstream branch"
+#: transport.c:266
+msgid "see protocol.version in 'git help config' for more details"
 msgstr ""
-"извеждане на хеша и темата.  Повтарянето на опцията прибавя отдалечените "
-"клони"
+"За повече информация вижте раздела „protocol.version“ в „git help config“"
 
-#: builtin/branch.c:592
-msgid "suppress informational messages"
-msgstr "без информационни съобщения"
+#: transport.c:267
+msgid "server options require protocol version 2 or later"
+msgstr "опциите на сървъра изискват поне версия 2 на протокола"
 
-#: builtin/branch.c:593
-msgid "set up tracking mode (see git-pull(1))"
-msgstr "задаване на режима на следене (виж git-pull(1))"
+#: transport.c:632
+msgid "could not parse transport.color.* config"
+msgstr "стойността на настройката „transport.color.*“ не може да се разпознае"
 
-#: builtin/branch.c:595
-msgid "do not use"
-msgstr "да не се ползва"
+#: transport.c:705
+msgid "support for protocol v2 not implemented yet"
+msgstr "протокол версия 2 все още не се поддържа"
 
-#: builtin/branch.c:597
-msgid "upstream"
-msgstr "клон-източник"
+#: transport.c:831
+#, c-format
+msgid "unknown value for config '%s': %s"
+msgstr "непозната стойност за настройката „%s“: „%s“"
 
-#: builtin/branch.c:597
-msgid "change the upstream info"
-msgstr "смяна на клона-източник"
+#: transport.c:897
+#, c-format
+msgid "transport '%s' not allowed"
+msgstr "преносът по „%s“ не е позволен"
 
-#: builtin/branch.c:598
-msgid "Unset the upstream info"
-msgstr "без клон-източник"
+#: transport.c:949
+msgid "git-over-rsync is no longer supported"
+msgstr "командата „git-over-rsync“ вече не се поддържа"
 
-#: builtin/branch.c:599
-msgid "use colored output"
-msgstr "цветен изход"
+#: transport.c:1044
+#, c-format
+msgid ""
+"The following submodule paths contain changes that can\n"
+"not be found on any remote:\n"
+msgstr ""
+"Следните пътища за подмодули съдържат промени,\n"
+"които липсват от всички отдалечени хранилища:\n"
 
-#: builtin/branch.c:600
-msgid "act on remote-tracking branches"
-msgstr "действие върху следящите клони"
+#: transport.c:1048
+#, c-format
+msgid ""
+"\n"
+"Please try\n"
+"\n"
+"\tgit push --recurse-submodules=on-demand\n"
+"\n"
+"or cd to the path and use\n"
+"\n"
+"\tgit push\n"
+"\n"
+"to push them to a remote.\n"
+"\n"
+msgstr ""
+"\n"
+"Пробвайте да ги изтласкате чрез командата:\n"
+"\n"
+"    git push --recurse-submodules=on-demand\n"
+"\n"
+"или отидете в съответната директория и изпълнете:\n"
+"\n"
+"    git push\n"
+"\n"
 
-#: builtin/branch.c:602 builtin/branch.c:604
-msgid "print only branches that contain the commit"
-msgstr "извеждане само на клоните, които съдържат това ПОДАВАНЕ"
+#: transport.c:1056
+msgid "Aborting."
+msgstr "Преустановяване на действието."
 
-#: builtin/branch.c:603 builtin/branch.c:605
-msgid "print only branches that don't contain the commit"
-msgstr "извеждане само на клоните, които не съдържат това ПОДАВАНЕ"
+#: transport.c:1201
+msgid "failed to push all needed submodules"
+msgstr "неуспешно изтласкване на всички необходими подмодули"
 
-#: builtin/branch.c:608
-msgid "Specific git-branch actions:"
-msgstr "Специални действия на „git-branch“:"
+#: transport.c:1345 transport-helper.c:656
+msgid "operation not supported by protocol"
+msgstr "опцията не се поддържа от протокола"
 
-#: builtin/branch.c:609
-msgid "list both remote-tracking and local branches"
-msgstr "извеждане както на следящите, така и на локалните клони"
+#: transport-helper.c:61 transport-helper.c:90
+msgid "full write to remote helper failed"
+msgstr "неуспешен пълен запис към насрещната помощна програма"
 
-#: builtin/branch.c:611
-msgid "delete fully merged branch"
-msgstr "изтриване на клони, които са напълно слети"
+#: transport-helper.c:144
+#, c-format
+msgid "unable to find remote helper for '%s'"
+msgstr "насрещната помощна програма за „%s“ не може да бъде открита"
 
-#: builtin/branch.c:612
-msgid "delete branch (even if not merged)"
-msgstr "изтриване и на клони, които не са напълно слети"
+#: transport-helper.c:160 transport-helper.c:570
+msgid "can't dup helper output fd"
+msgstr ""
+"файловият дескриптор от насрещната помощна програма не може да се дублира с "
+"„dup“"
 
-#: builtin/branch.c:613
-msgid "move/rename a branch and its reflog"
+#: transport-helper.c:211
+#, c-format
+msgid ""
+"unknown mandatory capability %s; this remote helper probably needs newer "
+"version of Git"
 msgstr ""
-"преместване/преименуване на клон и принадлежащият му журнал на указателите"
+"непозната задължителна способност „%s“.  Насрещната помощна програма "
+"вероятно изисква нова версия на Git"
 
-#: builtin/branch.c:614
-msgid "move/rename a branch, even if target exists"
-msgstr "преместване/преименуване на клон, дори ако има вече клон с такова име"
+#: transport-helper.c:217
+msgid "this remote helper should implement refspec capability"
+msgstr ""
+"насрещната помощна програма трябва да поддържа способност за изброяване на "
+"указатели"
 
-#: builtin/branch.c:615
-msgid "copy a branch and its reflog"
-msgstr "копиране на клон и принадлежащия му журнал на указателите"
+#: transport-helper.c:284 transport-helper.c:424
+#, c-format
+msgid "%s unexpectedly said: '%s'"
+msgstr "„%s“ неочаквано върна: „%s“"
 
-#: builtin/branch.c:616
-msgid "copy a branch, even if target exists"
-msgstr "копиране на клон, дори ако има вече клон с такова име"
+#: transport-helper.c:413
+#, c-format
+msgid "%s also locked %s"
+msgstr "„%s“ заключи и „%s“"
 
-#: builtin/branch.c:617
-msgid "list branch names"
-msgstr "извеждане на имената на клоните"
+#: transport-helper.c:492
+msgid "couldn't run fast-import"
+msgstr "неуспешно изпълнение на бързо внасяне"
 
-#: builtin/branch.c:618
-msgid "create the branch's reflog"
-msgstr "създаване на журнала на указателите на клона"
+#: transport-helper.c:515
+msgid "error while running fast-import"
+msgstr "грешка при изпълнението на бързо внасяне"
 
-#: builtin/branch.c:620
-msgid "edit the description for the branch"
-msgstr "редактиране на описанието на клона"
+#: transport-helper.c:544 transport-helper.c:1133
+#, c-format
+msgid "could not read ref %s"
+msgstr "указателят „%s“ не може да се прочете"
 
-#: builtin/branch.c:621
-msgid "force creation, move/rename, deletion"
-msgstr "принудително създаване, преместване, преименуване, изтриване"
+#: transport-helper.c:589
+#, c-format
+msgid "unknown response to connect: %s"
+msgstr "неочакван отговор при свързване: „%s“"
 
-#: builtin/branch.c:622
-msgid "print only branches that are merged"
-msgstr "извеждане само на слетите клони"
+#: transport-helper.c:611
+msgid "setting remote service path not supported by protocol"
+msgstr "протоколът не поддържа задаването на път на отдалечената услуга"
 
-#: builtin/branch.c:623
-msgid "print only branches that are not merged"
-msgstr "извеждане само на неслетите клони"
+#: transport-helper.c:613
+msgid "invalid remote service path"
+msgstr "неправилен път на отдалечената услуга"
 
-#: builtin/branch.c:624
-msgid "list branches in columns"
-msgstr "извеждане по колони"
+#: transport-helper.c:659
+#, c-format
+msgid "can't connect to subservice %s"
+msgstr "неуспешно свързване към подуслугата „%s“"
 
-#: builtin/branch.c:625 builtin/for-each-ref.c:40 builtin/ls-remote.c:70
-#: builtin/tag.c:412
-msgid "key"
-msgstr "КЛЮЧ"
+#: transport-helper.c:735
+#, c-format
+msgid "expected ok/error, helper said '%s'"
+msgstr ""
+"очаква се или успех, или грешка, но насрещната помощна програма върна „%s“"
 
-#: builtin/branch.c:626 builtin/for-each-ref.c:41 builtin/ls-remote.c:71
-#: builtin/tag.c:413
-msgid "field name to sort on"
-msgstr "име на полето, по което да е подредбата"
+#: transport-helper.c:788
+#, c-format
+msgid "helper reported unexpected status of %s"
+msgstr "насрещната помощна програма завърши с неочакван изходен код: „%s“"
 
-#: builtin/branch.c:628 builtin/for-each-ref.c:43 builtin/notes.c:408
-#: builtin/notes.c:411 builtin/notes.c:571 builtin/notes.c:574
-#: builtin/tag.c:415
-msgid "object"
-msgstr "ОБЕКТ"
+#: transport-helper.c:849
+#, c-format
+msgid "helper %s does not support dry-run"
+msgstr "насрещната помощна програма „%s“ не поддържа проби „dry-run“"
 
-#: builtin/branch.c:629
-msgid "print only branches of the object"
-msgstr "извеждане само на клоните на ОБЕКТА"
+#: transport-helper.c:852
+#, c-format
+msgid "helper %s does not support --signed"
+msgstr "насрещната помощна програма „%s“ не поддържа опцията „--signed“"
 
-#: builtin/branch.c:631 builtin/for-each-ref.c:49 builtin/tag.c:422
-msgid "sorting and filtering are case insensitive"
-msgstr "подредбата и филтрирането третират еднакво малките и главните букви"
+#: transport-helper.c:855
+#, c-format
+msgid "helper %s does not support --signed=if-asked"
+msgstr ""
+"насрещната помощна програма „%s“ не поддържа опцията „--signed=if-asked“"
 
-#: builtin/branch.c:632 builtin/for-each-ref.c:38 builtin/tag.c:420
-#: builtin/verify-tag.c:39
-msgid "format to use for the output"
-msgstr "ФОРМАТ за изхода"
+#: transport-helper.c:860
+#, c-format
+msgid "helper %s does not support --atomic"
+msgstr "насрещната помощна програма „%s“ не поддържа опцията „--atomic“"
 
-#: builtin/branch.c:655 builtin/clone.c:737
-msgid "HEAD not found below refs/heads!"
-msgstr "В директорията „refs/heads“ липсва файл „HEAD“"
+#: transport-helper.c:866
+#, c-format
+msgid "helper %s does not support 'push-option'"
+msgstr "насрещната помощна програма „%s“ не поддържа опции за изтласкване"
 
-#: builtin/branch.c:678
-msgid "--column and --verbose are incompatible"
-msgstr "Опциите „--column“ и „--verbose“ са несъвместими"
+#: transport-helper.c:964
+msgid "remote-helper doesn't support push; refspec needed"
+msgstr ""
+"насрещната помощна програма не поддържа изтласкване.  Необходимо е "
+"изброяване на указателите"
 
-#: builtin/branch.c:693 builtin/branch.c:745 builtin/branch.c:754
-msgid "branch name required"
-msgstr "Необходимо е име на клон"
+#: transport-helper.c:969
+#, c-format
+msgid "helper %s does not support 'force'"
+msgstr ""
+"насрещната помощна програма не поддържа „%s“ поддържа опцията „--force“"
 
-#: builtin/branch.c:721
-msgid "Cannot give description to detached HEAD"
-msgstr "Не може да зададете описание на несвързан „HEAD“"
+#: transport-helper.c:1016
+msgid "couldn't run fast-export"
+msgstr "не може да се извърши бързо изнасяне"
 
-#: builtin/branch.c:726
-msgid "cannot edit description of more than one branch"
-msgstr "Не може да редактирате описанието на повече от един клон едновременно"
+#: transport-helper.c:1021
+msgid "error while running fast-export"
+msgstr "грешка при изпълнението на командата за бързо изнасяне"
 
-#: builtin/branch.c:733
+#: transport-helper.c:1046
 #, c-format
-msgid "No commit on branch '%s' yet."
-msgstr "В клона „%s“ все още няма подавания."
+msgid ""
+"No refs in common and none specified; doing nothing.\n"
+"Perhaps you should specify a branch such as 'master'.\n"
+msgstr ""
+"Няма общи указатели, не са указани никакви указатели — нищо няма да бъде\n"
+"направено.  Пробвайте да укажете клон, напр. “master“.\n"
 
-#: builtin/branch.c:736
+#: transport-helper.c:1119
 #, c-format
-msgid "No branch named '%s'."
-msgstr "Липсва клон на име „%s“."
+msgid "malformed response in ref list: %s"
+msgstr "неправилен отговор в списъка с указатели: „%s“"
 
-#: builtin/branch.c:751
-msgid "too many branches for a copy operation"
-msgstr "прекалено много клони за копиране"
+#: transport-helper.c:1271
+#, c-format
+msgid "read(%s) failed"
+msgstr "неуспешно четене на „%s“"
 
-#: builtin/branch.c:760
-msgid "too many arguments for a rename operation"
-msgstr "прекалено много аргументи към командата за преименуване"
+#: transport-helper.c:1298
+#, c-format
+msgid "write(%s) failed"
+msgstr "неуспешен запис в „%s“"
 
-#: builtin/branch.c:765
-msgid "too many arguments to set new upstream"
-msgstr "прекалено много аргументи към командата за следене"
+#: transport-helper.c:1347
+#, c-format
+msgid "%s thread failed"
+msgstr "неуспешно изпълнение на нишката „%s“"
 
-#: builtin/branch.c:769
+#: transport-helper.c:1351
 #, c-format
-msgid ""
-"could not set upstream of HEAD to %s when it does not point to any branch."
-msgstr ""
-"Следеното от „HEAD“ не може да се зададе да е „%s“, защото то не сочи към "
-"никой клон."
+msgid "%s thread failed to join: %s"
+msgstr "завършването на нишката „%s“ не може да се изчака: „%s“"
 
-#: builtin/branch.c:772 builtin/branch.c:794 builtin/branch.c:810
+#: transport-helper.c:1370 transport-helper.c:1374
 #, c-format
-msgid "no such branch '%s'"
-msgstr "Няма клон на име „%s“."
+msgid "can't start thread for copying data: %s"
+msgstr "неуспешно стартиране на нишка за копиране на данните: „%s“"
 
-#: builtin/branch.c:776
+#: transport-helper.c:1411
 #, c-format
-msgid "branch '%s' does not exist"
-msgstr "Не съществува клон на име „%s“."
+msgid "%s process failed to wait"
+msgstr "процесът на „%s“ не успя да изчака чрез „waitpid“"
 
-#: builtin/branch.c:788
-msgid "too many arguments to unset upstream"
-msgstr "прекалено много аргументи към командата за спиране на следене"
+#: transport-helper.c:1415
+#, c-format
+msgid "%s process failed"
+msgstr "неуспешно изпълнение на „%s“"
 
-#: builtin/branch.c:792
-msgid "could not unset upstream of HEAD when it does not point to any branch."
-msgstr ""
-"Следеното от „HEAD“ не може да махне, защото то не сочи към никой клон."
+#: transport-helper.c:1433 transport-helper.c:1442
+msgid "can't start thread for copying data"
+msgstr "неуспешно стартиране на нишка за копиране на данните"
 
-#: builtin/branch.c:798
-#, c-format
-msgid "Branch '%s' has no upstream information"
-msgstr "Няма информация клонът „%s“ да следи някой друг"
+#: tree-walk.c:33
+msgid "too-short tree object"
+msgstr "прекалено кратък обект-дърво"
+
+#: tree-walk.c:39
+msgid "malformed mode in tree entry"
+msgstr "неправилни права за достъп в запис в дърво"
+
+#: tree-walk.c:43
+msgid "empty filename in tree entry"
+msgstr "празно име на файл в запис в дърво"
 
-#: builtin/branch.c:813
-msgid "-a and -r options to 'git branch' do not make sense with a branch name"
-msgstr "Опциите „-a“ и „-r“ на „git branch“ са несъвместими с име на клон"
+#: tree-walk.c:118
+msgid "too-short tree file"
+msgstr "прекалено кратък файл-дърво"
 
-#: builtin/branch.c:816
+#: unpack-trees.c:110
+#, c-format
 msgid ""
-"the '--set-upstream' option is no longer supported. Please use '--track' or "
-"'--set-upstream-to' instead."
+"Your local changes to the following files would be overwritten by checkout:\n"
+"%%sPlease commit your changes or stash them before you switch branches."
 msgstr ""
-"Опцията „--set-upstream“ вече не се поддържа.  Използвайте „--track“ или „--"
-"set-upstream-to“"
+"Изтеглянето ще презапише локалните промени на тези файлове:\n"
+"%%sПодайте или скатайте промените, за да преминете към нов клон."
 
-#: builtin/bundle.c:45
+#: unpack-trees.c:112
 #, c-format
-msgid "%s is okay\n"
-msgstr "Пратката „%s“ е наред\n"
-
-#: builtin/bundle.c:58
-msgid "Need a repository to create a bundle."
-msgstr "За създаването на пратка е необходимо хранилище."
+msgid ""
+"Your local changes to the following files would be overwritten by checkout:\n"
+"%%s"
+msgstr ""
+"Изтеглянето ще презапише локалните промени на тези файлове:\n"
+"%%s"
 
-#: builtin/bundle.c:62
-msgid "Need a repository to unbundle."
-msgstr "За приемането на пратка е необходимо хранилище."
+#: unpack-trees.c:115
+#, c-format
+msgid ""
+"Your local changes to the following files would be overwritten by merge:\n"
+"%%sPlease commit your changes or stash them before you merge."
+msgstr ""
+"Сливането ще презапише локалните промени на тези файлове:\n"
+"%%sПодайте или скатайте промените, за да слеете."
 
-#: builtin/cat-file.c:525
+#: unpack-trees.c:117
+#, c-format
 msgid ""
-"git cat-file (-t [--allow-unknown-type] | -s [--allow-unknown-type] | -e | -"
-"p | <type> | --textconv | --filters) [--path=<path>] <object>"
+"Your local changes to the following files would be overwritten by merge:\n"
+"%%s"
 msgstr ""
-"git cat-file (-t [--allow-unknown-type] | -s [--allow-unknown-type] | -e | -"
-"p | ВИД | --textconv --filters) [--path=ПЪТ] ОБЕКТ"
+"Сливането ще презапише локалните промени на тези файлове:\n"
+"%%s"
 
-#: builtin/cat-file.c:526
+#: unpack-trees.c:120
+#, c-format
 msgid ""
-"git cat-file (--batch | --batch-check) [--follow-symlinks] [--textconv | --"
-"filters]"
+"Your local changes to the following files would be overwritten by %s:\n"
+"%%sPlease commit your changes or stash them before you %s."
 msgstr ""
-"git cat-file (--batch | --batch-check) [--follow-symlinks] [--textconv | --"
-"filters]"
+"„%s“ ще презапише локалните промени на тези файлове:\n"
+"%%sПодайте или скатайте промените, за да извършите „%s“."
 
-#: builtin/cat-file.c:563
-msgid "<type> can be one of: blob, tree, commit, tag"
+#: unpack-trees.c:122
+#, c-format
+msgid ""
+"Your local changes to the following files would be overwritten by %s:\n"
+"%%s"
 msgstr ""
-"ВИДът може да е: „blob“ (BLOB), „tree“ (дърво), „commit“ (подаване), "
-"„tag“ (етикет)"
+"„%s“ ще презапише локалните промени на тези файлове:\n"
+"%%s"
 
-#: builtin/cat-file.c:564
-msgid "show object type"
-msgstr "извеждане на вида на обект"
+#: unpack-trees.c:127
+#, c-format
+msgid ""
+"Updating the following directories would lose untracked files in them:\n"
+"%s"
+msgstr ""
+"Обновяването на следните директории ще изтрие неследените файлове в тях:\n"
+"%s"
 
-#: builtin/cat-file.c:565
-msgid "show object size"
-msgstr "извеждане на размера на обект"
+#: unpack-trees.c:131
+#, c-format
+msgid ""
+"The following untracked working tree files would be removed by checkout:\n"
+"%%sPlease move or remove them before you switch branches."
+msgstr ""
+"Изтеглянето ще изтрие тези неследени файлове в работното дърво:\n"
+"%%sПреместете ги или ги изтрийте, за да преминете на друг клон."
 
-#: builtin/cat-file.c:567
-msgid "exit with zero when there's no error"
-msgstr "изход с 0, когато няма грешка"
+#: unpack-trees.c:133
+#, c-format
+msgid ""
+"The following untracked working tree files would be removed by checkout:\n"
+"%%s"
+msgstr ""
+"Изтеглянето ще изтрие тези неследени файлове в работното дърво:\n"
+"%%s"
 
-#: builtin/cat-file.c:568
-msgid "pretty-print object's content"
-msgstr "форматирано извеждане на съдържанието на обекта"
+#: unpack-trees.c:136
+#, c-format
+msgid ""
+"The following untracked working tree files would be removed by merge:\n"
+"%%sPlease move or remove them before you merge."
+msgstr ""
+"Сливането ще изтрие тези неследени файлове в работното дърво:\n"
+"%%sПреместете ги или ги изтрийте, за да слеете."
 
-#: builtin/cat-file.c:570
-msgid "for blob objects, run textconv on object's content"
+#: unpack-trees.c:138
+#, c-format
+msgid ""
+"The following untracked working tree files would be removed by merge:\n"
+"%%s"
 msgstr ""
-"да се стартира програмата зададена в настройката „textconv“ за преобразуване "
-"на съдържанието на обекта-BLOB"
+"Сливането ще изтрие тези неследени файлове в работното дърво:\n"
+"%%s"
 
-#: builtin/cat-file.c:572
-msgid "for blob objects, run filters on object's content"
+#: unpack-trees.c:141
+#, c-format
+msgid ""
+"The following untracked working tree files would be removed by %s:\n"
+"%%sPlease move or remove them before you %s."
 msgstr ""
-"да се стартират програмите за преобразуване на съдържанието на обектите-BLOB"
+"„%s“ ще изтрие тези неследени файлове в работното дърво:\n"
+"%%sПреместете ги или ги изтрийте, за да извършите „%s“."
 
-#: builtin/cat-file.c:573 git-submodule.sh:894
-msgid "blob"
-msgstr "обект-BLOB"
+#: unpack-trees.c:143
+#, c-format
+msgid ""
+"The following untracked working tree files would be removed by %s:\n"
+"%%s"
+msgstr ""
+"„%s“ ще изтрие тези неследени файлове в работното дърво:\n"
+"%%s"
 
-#: builtin/cat-file.c:574
-msgid "use a specific path for --textconv/--filters"
-msgstr "опциите „--textconv“/„--filters“ изискват път"
+#: unpack-trees.c:149
+#, c-format
+msgid ""
+"The following untracked working tree files would be overwritten by "
+"checkout:\n"
+"%%sPlease move or remove them before you switch branches."
+msgstr ""
+"Изтеглянето ще презапише тези неследени файлове в работното дърво:\n"
+"%%sПреместете ги или ги изтрийте, за да смените клон."
 
-#: builtin/cat-file.c:576
-msgid "allow -s and -t to work with broken/corrupt objects"
-msgstr "позволяване на опциите „-s“ и „-t“ да работят с повредени обекти"
+#: unpack-trees.c:151
+#, c-format
+msgid ""
+"The following untracked working tree files would be overwritten by "
+"checkout:\n"
+"%%s"
+msgstr ""
+"Изтеглянето ще презапише тези неследени файлове в работното дърво:\n"
+"%%s"
 
-#: builtin/cat-file.c:577
-msgid "buffer --batch output"
-msgstr "буфериране на изхода от „--batch“"
+#: unpack-trees.c:154
+#, c-format
+msgid ""
+"The following untracked working tree files would be overwritten by merge:\n"
+"%%sPlease move or remove them before you merge."
+msgstr ""
+"Сливането ще презапише тези неследени файлове в работното дърво:\n"
+"%%sПреместете ги или ги изтрийте, за да слеете."
 
-#: builtin/cat-file.c:579
-msgid "show info and content of objects fed from the standard input"
+#: unpack-trees.c:156
+#, c-format
+msgid ""
+"The following untracked working tree files would be overwritten by merge:\n"
+"%%s"
 msgstr ""
-"извеждане на информация и съдържание на обектите подадени на стандартния вход"
+"Сливането ще презапише тези неследени файлове в работното дърво:\n"
+"%%s"
 
-#: builtin/cat-file.c:582
-msgid "show info about objects fed from the standard input"
-msgstr "извеждане на информация за обектите подадени на стандартния вход"
+#: unpack-trees.c:159
+#, c-format
+msgid ""
+"The following untracked working tree files would be overwritten by %s:\n"
+"%%sPlease move or remove them before you %s."
+msgstr ""
+"„%s“ ще презапише тези неследени файлове в работното дърво:\n"
+"%%sПреместете ги или ги изтрийте, за да извършите „%s“."
 
-#: builtin/cat-file.c:585
-msgid "follow in-tree symlinks (used with --batch or --batch-check)"
+#: unpack-trees.c:161
+#, c-format
+msgid ""
+"The following untracked working tree files would be overwritten by %s:\n"
+"%%s"
 msgstr ""
-"следване на символните връзки сочещи в дървото (ползва се с „--batch“ или „--"
-"batch-check“)"
+"„%s“ ще презапише тези неследени файлове в работното дърво:\n"
+"%%s"
 
-#: builtin/cat-file.c:587
-msgid "show all objects with --batch or --batch-check"
-msgstr "извеждане на всички обекти с „--batch“ или „--batch-check“"
+#: unpack-trees.c:169
+#, c-format
+msgid "Entry '%s' overlaps with '%s'.  Cannot bind."
+msgstr "Записът за „%s“ съвпада с този за „%s“.  Не може да се присвои."
 
-#: builtin/check-attr.c:12
-msgid "git check-attr [-a | --all | <attr>...] [--] <pathname>..."
-msgstr "git check-attr [-a | --all | АТРИБУТ…] [--] ПЪТ…"
+#: unpack-trees.c:172
+#, c-format
+msgid ""
+"Cannot update sparse checkout: the following entries are not up to date:\n"
+"%s"
+msgstr ""
+"Частичното изтегляне не може да бъде обновено: следните записи не са "
+"актуални:\n"
+"%s"
 
-#: builtin/check-attr.c:13
-msgid "git check-attr --stdin [-z] [-a | --all | <attr>...]"
-msgstr "git check-attr --stdin [-z] [-a | --all | АТРИБУТ…]"
+#: unpack-trees.c:174
+#, c-format
+msgid ""
+"The following working tree files would be overwritten by sparse checkout "
+"update:\n"
+"%s"
+msgstr ""
+"Обновяването на частичното изтегляне ще презапише тези файлове в работното "
+"дърво:\n"
+"%s"
 
-#: builtin/check-attr.c:20
-msgid "report all attributes set on file"
-msgstr "извеждане на всички атрибути, зададени върху файл"
+#: unpack-trees.c:176
+#, c-format
+msgid ""
+"The following working tree files would be removed by sparse checkout "
+"update:\n"
+"%s"
+msgstr ""
+"Обновяването на частичното изтегляне ще изтрие тези файлове в работното "
+"дърво:\n"
+"%s"
 
-#: builtin/check-attr.c:21
-msgid "use .gitattributes only from the index"
-msgstr "използване на файла „.gitattributes“ само от индекса"
+#: unpack-trees.c:178
+#, c-format
+msgid ""
+"Cannot update submodule:\n"
+"%s"
+msgstr ""
+"Подмодулът не може да бъде обновен:\n"
+"„%s“"
 
-#: builtin/check-attr.c:22 builtin/check-ignore.c:24 builtin/hash-object.c:100
-msgid "read file names from stdin"
-msgstr "изчитане на имената на файловете от стандартния вход"
+#: unpack-trees.c:255
+#, c-format
+msgid "Aborting\n"
+msgstr "Преустановяване на действието\n"
 
-#: builtin/check-attr.c:24 builtin/check-ignore.c:26
-msgid "terminate input and output records by a NUL character"
-msgstr "разделяне на входните и изходните записи с нулевия знак „NUL“"
+#: unpack-trees.c:317
+msgid "Updating files"
+msgstr "Обновяване на файлове"
+
+#: unpack-trees.c:349
+msgid ""
+"the following paths have collided (e.g. case-sensitive paths\n"
+"on a case-insensitive filesystem) and only one from the same\n"
+"colliding group is in the working tree:\n"
+msgstr ""
+"следните пътища са в конфликт (напр. при разлика в регистъра\n"
+"във файлови системи, които не различават главни от малки букви)\n"
+"и само един от участниците в конфликта е в работното дърво:\n"
+
+#: unpack-trees.c:1441
+msgid "Updating index flags"
+msgstr "Обновяване на флаговете на индекса"
 
-#: builtin/check-ignore.c:20 builtin/checkout.c:1113 builtin/gc.c:500
-msgid "suppress progress reporting"
-msgstr "без показване на напредъка"
+#: urlmatch.c:163
+msgid "invalid URL scheme name or missing '://' suffix"
+msgstr "неправилна схема за адрес или суфиксът „://“ липсва"
 
-#: builtin/check-ignore.c:28
-msgid "show non-matching input paths"
-msgstr "извеждане на несъвпадащите пътища"
+#: urlmatch.c:187 urlmatch.c:346 urlmatch.c:405
+#, c-format
+msgid "invalid %XX escape sequence"
+msgstr "неправилна екранираща последователност „%XX“"
 
-#: builtin/check-ignore.c:30
-msgid "ignore index when checking"
-msgstr "прескачане на индекса при проверката"
+#: urlmatch.c:215
+msgid "missing host and scheme is not 'file:'"
+msgstr "не е указана машина, а схемата не е „file:“"
 
-#: builtin/check-ignore.c:159
-msgid "cannot specify pathnames with --stdin"
-msgstr "опцията „--stdin“ е несъвместима с имена на пътища"
+#: urlmatch.c:232
+msgid "a 'file:' URL may not have a port number"
+msgstr "при схема „file:“ не можете да указвате номер на порт"
 
-#: builtin/check-ignore.c:162
-msgid "-z only makes sense with --stdin"
-msgstr "опцията „-z“ изисква „--stdin“"
+#: urlmatch.c:247
+msgid "invalid characters in host name"
+msgstr "неправилни знаци в името на машина"
 
-#: builtin/check-ignore.c:164
-msgid "no path specified"
-msgstr "не е зададен път"
+#: urlmatch.c:292 urlmatch.c:303
+msgid "invalid port number"
+msgstr "неправилен номер на порт"
 
-#: builtin/check-ignore.c:168
-msgid "--quiet is only valid with a single pathname"
-msgstr "опцията „--quiet“ изисква да е подаден точно един път"
+#: urlmatch.c:371
+msgid "invalid '..' path segment"
+msgstr "неправилна част от пътя „..“"
 
-#: builtin/check-ignore.c:170
-msgid "cannot have both --quiet and --verbose"
-msgstr "опциите „--quiet“ и „--verbose“ са несъвместими"
+#: worktree.c:258 builtin/am.c:2084
+#, c-format
+msgid "failed to read '%s'"
+msgstr "„%s“ не може да бъде прочетен"
 
-#: builtin/check-ignore.c:173
-msgid "--non-matching is only valid with --verbose"
-msgstr "опцията „--non-matching“ изисква „--verbose“"
+#: worktree.c:304
+#, c-format
+msgid "'%s' at main working tree is not the repository directory"
+msgstr "„%s“ в основното работно дърво не е директорията на хранилището"
 
-#: builtin/check-mailmap.c:9
-msgid "git check-mailmap [<options>] <contact>..."
-msgstr "git check-mailmap [ОПЦИЯ…] КОНТАКТ…"
+#: worktree.c:315
+#, c-format
+msgid "'%s' file does not contain absolute path to the working tree location"
+msgstr ""
+"файлът „%s“ не съдържа абсолютния път към местоположението на работното дърво"
 
-#: builtin/check-mailmap.c:14
-msgid "also read contacts from stdin"
-msgstr "четене на контакти и от стандартния вход"
+#: worktree.c:327
+#, c-format
+msgid "'%s' does not exist"
+msgstr "„%s“ не съществува."
 
-#: builtin/check-mailmap.c:25
+#: worktree.c:333
 #, c-format
-msgid "unable to parse contact: %s"
-msgstr "контактът не може да бъде анализиран: %s"
+msgid "'%s' is not a .git file, error code %d"
+msgstr "„%s“ не е файл на .git, код за грешка: %d"
 
-#: builtin/check-mailmap.c:48
-msgid "no contacts specified"
-msgstr "не са указани контакти"
+#: worktree.c:341
+#, c-format
+msgid "'%s' does not point back to '%s'"
+msgstr "„%s“ не сочи към обратно към „%s“"
 
-#: builtin/checkout-index.c:128
-msgid "git checkout-index [<options>] [--] [<file>...]"
-msgstr "git checkout-index [ОПЦИЯ…] [--] [ФАЙЛ…]"
+#: wrapper.c:186 wrapper.c:356
+#, c-format
+msgid "could not open '%s' for reading and writing"
+msgstr "„%s“ не може да бъде отворен и за четене, и за запис"
 
-#: builtin/checkout-index.c:143
-msgid "stage should be between 1 and 3 or all"
-msgstr "етапът трябва да е „1“, „2“, „3“ или „all“ (всички)"
+#: wrapper.c:387 wrapper.c:588
+#, c-format
+msgid "unable to access '%s'"
+msgstr "няма достъп до „%s“"
 
-#: builtin/checkout-index.c:159
-msgid "check out all files in the index"
-msgstr "изтегляне на всички файлове в индекса"
+#: wrapper.c:596
+msgid "unable to get current working directory"
+msgstr "текущата работна директория е недостъпна"
 
-#: builtin/checkout-index.c:160
-msgid "force overwrite of existing files"
-msgstr "презаписване на файловете, дори и да съществуват"
+#: wt-status.c:158
+msgid "Unmerged paths:"
+msgstr "Неслети пътища:"
 
-#: builtin/checkout-index.c:162
-msgid "no warning for existing files and files not in index"
-msgstr "без предупреждения при липсващи файлове и файлове не в индекса"
+#: wt-status.c:187 wt-status.c:219
+msgid "  (use \"git restore --staged <file>...\" to unstage)"
+msgstr ""
+"  (използвайте „git restore --staged ФАЙЛ…“, за да извадите ФАЙЛа от индекса)"
 
-#: builtin/checkout-index.c:164
-msgid "don't checkout new files"
-msgstr "без изтегляне на нови файлове"
+#: wt-status.c:190 wt-status.c:222
+#, c-format
+msgid "  (use \"git restore --source=%s --staged <file>...\" to unstage)"
+msgstr ""
+"  (използвайте „git restore --source=%s --staged ФАЙЛ…“, за да извадите "
+"ФАЙЛа от индекса)"
 
-#: builtin/checkout-index.c:166
-msgid "update stat information in the index file"
-msgstr "обновяване на информацията получена чрез „stat“ за файловете в индекса"
+#: wt-status.c:193 wt-status.c:225
+msgid "  (use \"git rm --cached <file>...\" to unstage)"
+msgstr ""
+"  (използвайте „git rm --cached %s ФАЙЛ…“, за да извадите ФАЙЛа от индекса)"
 
-#: builtin/checkout-index.c:170
-msgid "read list of paths from the standard input"
-msgstr "изчитане на пътищата от стандартния вход"
+#: wt-status.c:197
+msgid "  (use \"git add <file>...\" to mark resolution)"
+msgstr ""
+"  (използвайте „git add ФАЙЛ…“, за да укажете разрешаването на конфликта)"
 
-#: builtin/checkout-index.c:172
-msgid "write the content to temporary files"
-msgstr "записване на съдържанието във временни файлове"
+#: wt-status.c:199 wt-status.c:203
+msgid "  (use \"git add/rm <file>...\" as appropriate to mark resolution)"
+msgstr ""
+"  (използвайте „git add/rm ФАЙЛ…“, според решението, което избирате за "
+"конфликта)"
 
-#: builtin/checkout-index.c:173 builtin/column.c:31
-#: builtin/submodule--helper.c:1216 builtin/submodule--helper.c:1219
-#: builtin/submodule--helper.c:1227 builtin/submodule--helper.c:1591
-#: builtin/worktree.c:610
-msgid "string"
-msgstr "НИЗ"
+#: wt-status.c:201
+msgid "  (use \"git rm <file>...\" to mark resolution)"
+msgstr ""
+"  (използвайте „git rm ФАЙЛ…“, за да укажете разрешаването на конфликта)"
 
-#: builtin/checkout-index.c:174
-msgid "when creating files, prepend <string>"
-msgstr "при създаването на нови файлове да се добавя префикса НИЗ"
+#: wt-status.c:211 wt-status.c:1074
+msgid "Changes to be committed:"
+msgstr "Промени, които ще бъдат подадени:"
 
-#: builtin/checkout-index.c:176
-msgid "copy out the files from named stage"
-msgstr "копиране на файловете от това състояние на сливане"
+#: wt-status.c:234 wt-status.c:1083
+msgid "Changes not staged for commit:"
+msgstr "Промени, които не са в индекса за подаване:"
 
-#: builtin/checkout.c:27
-msgid "git checkout [<options>] <branch>"
-msgstr "git checkout [ОПЦИЯ…] КЛОН"
+#: wt-status.c:238
+msgid "  (use \"git add <file>...\" to update what will be committed)"
+msgstr ""
+"  (използвайте „git add ФАЙЛ…“, за да обновите съдържанието за подаване)"
 
-#: builtin/checkout.c:28
-msgid "git checkout [<options>] [<branch>] -- <file>..."
-msgstr "git checkout [ОПЦИЯ…] [КЛОН] -- ФАЙЛ…"
+#: wt-status.c:240
+msgid "  (use \"git add/rm <file>...\" to update what will be committed)"
+msgstr ""
+"  (използвайте „git add/rm ФАЙЛ…“, за да обновите съдържанието за подаване)"
 
-#: builtin/checkout.c:136 builtin/checkout.c:169
-#, c-format
-msgid "path '%s' does not have our version"
-msgstr "вашата версия липсва в пътя „%s“"
+#: wt-status.c:241
+msgid ""
+"  (use \"git restore <file>...\" to discard changes in working directory)"
+msgstr ""
+"  (използвайте „git restore ФАЙЛ…“, за да отхвърлите промените в работната "
+"директория)"
 
-#: builtin/checkout.c:138 builtin/checkout.c:171
-#, c-format
-msgid "path '%s' does not have their version"
-msgstr "чуждата версия липсва в пътя „%s“"
+#: wt-status.c:243
+msgid "  (commit or discard the untracked or modified content in submodules)"
+msgstr ""
+"  (подайте или отхвърлете неследеното или промененото съдържание в "
+"подмодулите)"
 
-#: builtin/checkout.c:154
+#: wt-status.c:254
 #, c-format
-msgid "path '%s' does not have all necessary versions"
-msgstr "някоя от необходимите версии липсва в пътя „%s“"
+msgid "  (use \"git %s <file>...\" to include in what will be committed)"
+msgstr ""
+"  (използвайте „git %s ФАЙЛ…“, за да определите какво включвате в подаването)"
 
-#: builtin/checkout.c:198
-#, c-format
-msgid "path '%s' does not have necessary versions"
-msgstr "някоя от необходимите версии липсва в пътя „%s“"
+#: wt-status.c:268
+msgid "both deleted:"
+msgstr "изтрити в двата случая:"
 
-#: builtin/checkout.c:215
-#, c-format
-msgid "path '%s': cannot merge"
-msgstr "пътят „%s“ не може да бъде слян"
+#: wt-status.c:270
+msgid "added by us:"
+msgstr "добавени от вас:"
 
-#: builtin/checkout.c:231
-#, c-format
-msgid "Unable to add merge result for '%s'"
-msgstr "Резултатът за „%s“ не може да бъде слян"
+#: wt-status.c:272
+msgid "deleted by them:"
+msgstr "изтрити от тях:"
 
-#: builtin/checkout.c:253 builtin/checkout.c:256 builtin/checkout.c:259
-#: builtin/checkout.c:262
-#, c-format
-msgid "'%s' cannot be used with updating paths"
-msgstr "Опцията „%s“ е несъвместима с обновяването на пътища"
+#: wt-status.c:274
+msgid "added by them:"
+msgstr "добавени от тях:"
 
-#: builtin/checkout.c:265 builtin/checkout.c:268
-#, c-format
-msgid "'%s' cannot be used with %s"
-msgstr "Опцията „%s“ е несъвместима с „%s“"
+#: wt-status.c:276
+msgid "deleted by us:"
+msgstr "изтрити от вас:"
 
-#: builtin/checkout.c:271
-#, c-format
-msgid "Cannot update paths and switch to branch '%s' at the same time."
-msgstr ""
-"Невъзможно е едновременно да обновявате пътища и да преминете към клона „%s“."
+#: wt-status.c:278
+msgid "both added:"
+msgstr "добавени и в двата случая:"
 
-#: builtin/checkout.c:340 builtin/checkout.c:347
-#, c-format
-msgid "path '%s' is unmerged"
-msgstr "пътят „%s“ не е слят"
+#: wt-status.c:280
+msgid "both modified:"
+msgstr "променени и в двата случая:"
 
-#: builtin/checkout.c:506
-msgid "you need to resolve your current index first"
-msgstr "първо трябва да коригирате индекса си"
+#: wt-status.c:290
+msgid "new file:"
+msgstr "нов файл:"
 
-#: builtin/checkout.c:643
-#, c-format
-msgid "Can not do reflog for '%s': %s\n"
-msgstr "Журналът на указателите за „%s“ не може да се проследи: %s\n"
+#: wt-status.c:292
+msgid "copied:"
+msgstr "копиран:"
 
-#: builtin/checkout.c:684
-msgid "HEAD is now at"
-msgstr "Указателят „HEAD“ в момента сочи към"
+#: wt-status.c:294
+msgid "deleted:"
+msgstr "изтрит:"
 
-#: builtin/checkout.c:688 builtin/clone.c:691
-msgid "unable to update HEAD"
-msgstr "Указателят „HEAD“ не може да бъде обновен"
+#: wt-status.c:296
+msgid "modified:"
+msgstr "променен:"
 
-#: builtin/checkout.c:692
-#, c-format
-msgid "Reset branch '%s'\n"
-msgstr "Зануляване на клона „%s“\n"
+#: wt-status.c:298
+msgid "renamed:"
+msgstr "преименуван:"
 
-#: builtin/checkout.c:695
-#, c-format
-msgid "Already on '%s'\n"
-msgstr "Вече сте на „%s“\n"
+#: wt-status.c:300
+msgid "typechange:"
+msgstr "смяна на вида:"
 
-#: builtin/checkout.c:699
-#, c-format
-msgid "Switched to and reset branch '%s'\n"
-msgstr "Преминаване към клона „%s“ и зануляване на промените\n"
+#: wt-status.c:302
+msgid "unknown:"
+msgstr "непозната промяна:"
 
-#: builtin/checkout.c:701 builtin/checkout.c:1046
-#, c-format
-msgid "Switched to a new branch '%s'\n"
-msgstr "Преминахте към новия клон „%s“\n"
+#: wt-status.c:304
+msgid "unmerged:"
+msgstr "неслят:"
 
-#: builtin/checkout.c:703
-#, c-format
-msgid "Switched to branch '%s'\n"
-msgstr "Преминахте към клона „%s“\n"
+#: wt-status.c:384
+msgid "new commits, "
+msgstr "нови подавания, "
 
-#: builtin/checkout.c:754
-#, c-format
-msgid " ... and %d more.\n"
-msgstr "… и още %d.\n"
+#: wt-status.c:386
+msgid "modified content, "
+msgstr "променено съдържание, "
+
+#: wt-status.c:388
+msgid "untracked content, "
+msgstr "неследено съдържание, "
 
-#: builtin/checkout.c:760
+#: wt-status.c:906
 #, c-format
+msgid "Your stash currently has %d entry"
+msgid_plural "Your stash currently has %d entries"
+msgstr[0] "Има %d скатаване."
+msgstr[1] "Има %d скатавания."
+
+#: wt-status.c:938
+msgid "Submodules changed but not updated:"
+msgstr "Подмодулите са променени, но не са обновени:"
+
+#: wt-status.c:940
+msgid "Submodule changes to be committed:"
+msgstr "Промени в подмодулите за подаване:"
+
+#: wt-status.c:1022
 msgid ""
-"Warning: you are leaving %d commit behind, not connected to\n"
-"any of your branches:\n"
-"\n"
-"%s\n"
-msgid_plural ""
-"Warning: you are leaving %d commits behind, not connected to\n"
-"any of your branches:\n"
-"\n"
-"%s\n"
-msgstr[0] ""
-"ПРЕДУПРЕЖДЕНИЕ: изоставяте %d подаване, което не е свързано към никой клон:\n"
-"\n"
-"%s\n"
-msgstr[1] ""
-"ПРЕДУПРЕЖДЕНИЕ: изоставяте %d подавания, които не са свързани към никой "
-"клон:\n"
-"\n"
-"%s\n"
+"Do not modify or remove the line above.\n"
+"Everything below it will be ignored."
+msgstr ""
+"Не променяйте и не изтривайте горния ред.\n"
+"Всичко отдолу ще бъде изтрито."
 
-#: builtin/checkout.c:779
+#: wt-status.c:1114
 #, c-format
 msgid ""
-"If you want to keep it by creating a new branch, this may be a good time\n"
-"to do so with:\n"
-"\n"
-" git branch <new-branch-name> %s\n"
-"\n"
-msgid_plural ""
-"If you want to keep them by creating a new branch, this may be a good time\n"
-"to do so with:\n"
-"\n"
-" git branch <new-branch-name> %s\n"
-"\n"
-msgstr[0] ""
-"Ако все пак искате да запазите тази промяна чрез създаване на клон,\n"
-"сега е най-подходящият за това чрез командата:\n"
-"\n"
-" git branch ИМЕ_НА_НОВИЯ_КЛОН %s\n"
-"\n"
-msgstr[1] ""
-"Ако все пак искате да запазите тези промени чрез създаване на клон,\n"
-"сега е най-подходящият за това чрез командата:\n"
 "\n"
-" git branch ИМЕ_НА_НОВИЯ_КЛОН %s\n"
+"It took %.2f seconds to compute the branch ahead/behind values.\n"
+"You can use '--no-ahead-behind' to avoid this.\n"
+msgstr ""
 "\n"
+"Изчисляването на броя различаващи се подавания отне %.2f сек.\n"
+"За да избегнете това, ползвайте „--no-ahead-behind“.\n"
 
-#: builtin/checkout.c:811
-msgid "internal error in revision walk"
-msgstr "вътрешна грешка при обхождането на версиите"
+#: wt-status.c:1144
+msgid "You have unmerged paths."
+msgstr "Някои пътища не са слети."
 
-#: builtin/checkout.c:815
-msgid "Previous HEAD position was"
-msgstr "Преди това „HEAD“ сочеше към"
+#: wt-status.c:1147
+msgid "  (fix conflicts and run \"git commit\")"
+msgstr "  (коригирайте конфликтите и изпълнете „git commit“)"
 
-#: builtin/checkout.c:843 builtin/checkout.c:1041
-msgid "You are on a branch yet to be born"
-msgstr "В момента сте на клон, който предстои да бъде създаден"
+#: wt-status.c:1149
+msgid "  (use \"git merge --abort\" to abort the merge)"
+msgstr "  (използвайте „git merge --abort“, за да преустановите сливането)"
 
-#: builtin/checkout.c:947
-#, c-format
-msgid "only one reference expected, %d given."
-msgstr "очакваше се един указател, а сте подали %d."
+#: wt-status.c:1153
+msgid "All conflicts fixed but you are still merging."
+msgstr "Всички конфликти са решени, но продължавате сливането."
 
-#: builtin/checkout.c:987 builtin/worktree.c:240 builtin/worktree.c:389
-#, c-format
-msgid "invalid reference: %s"
-msgstr "неправилен указател: %s"
+#: wt-status.c:1156
+msgid "  (use \"git commit\" to conclude merge)"
+msgstr "  (използвайте „git commit“, за да завършите сливането)"
 
-#: builtin/checkout.c:1016
-#, c-format
-msgid "reference is not a tree: %s"
-msgstr "указателят не сочи към обект-дърво: %s"
+#: wt-status.c:1165
+msgid "You are in the middle of an am session."
+msgstr "В момента прилагате поредица от кръпки чрез „git am“."
 
-#: builtin/checkout.c:1055
-msgid "paths cannot be used with switching branches"
-msgstr "задаването на път е несъвместимо с преминаването от един клон към друг"
+#: wt-status.c:1168
+msgid "The current patch is empty."
+msgstr "Текущата кръпка е празна."
 
-#: builtin/checkout.c:1058 builtin/checkout.c:1062
-#, c-format
-msgid "'%s' cannot be used with switching branches"
-msgstr "опцията „%s“ е несъвместима с преминаването от един клон към друг"
+#: wt-status.c:1172
+msgid "  (fix conflicts and then run \"git am --continue\")"
+msgstr "  (коригирайте конфликтите и изпълнете „git am --continue“)"
 
-#: builtin/checkout.c:1066 builtin/checkout.c:1069 builtin/checkout.c:1074
-#: builtin/checkout.c:1077
-#, c-format
-msgid "'%s' cannot be used with '%s'"
-msgstr "опцията „%s“ е несъвместима с „%s“"
+#: wt-status.c:1174
+msgid "  (use \"git am --skip\" to skip this patch)"
+msgstr "  (използвайте „git am --skip“, за да пропуснете тази кръпка)"
 
-#: builtin/checkout.c:1082
-#, c-format
-msgid "Cannot switch branch to a non-commit '%s'"
+#: wt-status.c:1176
+msgid "  (use \"git am --abort\" to restore the original branch)"
 msgstr ""
-"За да преминете към клон, подайте указател, който сочи към подаване.  „%s“ "
-"не е такъв"
+"  (използвайте „git am --abort“, за да възстановите първоначалния клон)"
 
-#: builtin/checkout.c:1114 builtin/checkout.c:1116 builtin/clone.c:118
-#: builtin/remote.c:167 builtin/remote.c:169 builtin/worktree.c:433
-#: builtin/worktree.c:435
-msgid "branch"
-msgstr "клон"
+#: wt-status.c:1309
+msgid "git-rebase-todo is missing."
+msgstr "„git-rebase-todo“ липсва."
 
-#: builtin/checkout.c:1115
-msgid "create and checkout a new branch"
-msgstr "създаване и преминаване към нов клон"
+#: wt-status.c:1311
+msgid "No commands done."
+msgstr "Не са изпълнени команди."
 
-#: builtin/checkout.c:1117
-msgid "create/reset and checkout a branch"
-msgstr "създаване/зануляване на клон и преминаване към него"
+#: wt-status.c:1314
+#, c-format
+msgid "Last command done (%d command done):"
+msgid_plural "Last commands done (%d commands done):"
+msgstr[0] "Последно изпълнена команда (изпълнена е общо %d команда):"
+msgstr[1] "Последно изпълнени команди (изпълнени са общо %d команди):"
 
-#: builtin/checkout.c:1118
-msgid "create reflog for new branch"
-msgstr "създаване на журнал на указателите за нов клон"
+#: wt-status.c:1325
+#, c-format
+msgid "  (see more in file %s)"
+msgstr "  (повече информация има във файла „%s“)"
 
-#: builtin/checkout.c:1119 builtin/worktree.c:437
-msgid "detach HEAD at named commit"
-msgstr "отделяне на указателя „HEAD“ към указаното подаване"
+#: wt-status.c:1330
+msgid "No commands remaining."
+msgstr "Не остават повече команди."
 
-#: builtin/checkout.c:1120
-msgid "set upstream info for new branch"
-msgstr "задаване на кой клон бива следен при създаването на новия клон"
+#: wt-status.c:1333
+#, c-format
+msgid "Next command to do (%d remaining command):"
+msgid_plural "Next commands to do (%d remaining commands):"
+msgstr[0] "Следваща команда за изпълнение (остава още %d команда):"
+msgstr[1] "Следващи команди за изпълнение (остават още %d команди):"
 
-#: builtin/checkout.c:1122
-msgid "new-branch"
-msgstr "НОВ_КЛОН"
+#: wt-status.c:1341
+msgid "  (use \"git rebase --edit-todo\" to view and edit)"
+msgstr ""
+"  (използвайте „git rebase --edit-todo“, за да разгледате и редактирате)"
 
-#: builtin/checkout.c:1122
-msgid "new unparented branch"
-msgstr "нов клон без родител"
+#: wt-status.c:1353
+#, c-format
+msgid "You are currently rebasing branch '%s' on '%s'."
+msgstr "В момента пребазирате клона „%s“ върху „%s“."
 
-#: builtin/checkout.c:1123
-msgid "checkout our version for unmerged files"
-msgstr "изтегляне на вашата версия на неслетите файлове"
+#: wt-status.c:1358
+msgid "You are currently rebasing."
+msgstr "В момента пребазирате."
 
-#: builtin/checkout.c:1125
-msgid "checkout their version for unmerged files"
-msgstr "изтегляне на чуждата версия на неслетите файлове"
+#: wt-status.c:1371
+msgid "  (fix conflicts and then run \"git rebase --continue\")"
+msgstr "  (коригирайте конфликтите и използвайте „git rebase --continue“)"
 
-#: builtin/checkout.c:1127
-msgid "force checkout (throw away local modifications)"
-msgstr "принудително изтегляне (вашите промени ще бъдат занулени)"
+#: wt-status.c:1373
+msgid "  (use \"git rebase --skip\" to skip this patch)"
+msgstr "  (използвайте „git rebase --skip“, за да пропуснете тази кръпка)"
 
-#: builtin/checkout.c:1129
-msgid "perform a 3-way merge with the new branch"
-msgstr "извършване на тройно сливане с новия клон"
+#: wt-status.c:1375
+msgid "  (use \"git rebase --abort\" to check out the original branch)"
+msgstr ""
+"  (използвайте „git rebase --abort“, за да възстановите първоначалния клон)"
 
-#: builtin/checkout.c:1131 builtin/merge.c:241
-msgid "update ignored files (default)"
-msgstr "обновяване на игнорираните файлове (стандартно)"
+#: wt-status.c:1382
+msgid "  (all conflicts fixed: run \"git rebase --continue\")"
+msgstr "  (всички конфликти са коригирани: изпълнете „git rebase --continue“)"
 
-#: builtin/checkout.c:1133 builtin/log.c:1499 parse-options.h:264
-msgid "style"
-msgstr "СТИЛ"
+#: wt-status.c:1386
+#, c-format
+msgid ""
+"You are currently splitting a commit while rebasing branch '%s' on '%s'."
+msgstr "В момента разделяте подаване докато пребазирате клона „%s“ върху „%s“."
 
-#: builtin/checkout.c:1134
-msgid "conflict style (merge or diff3)"
-msgstr "действие при конфликт (сливане или тройна разлика)"
+#: wt-status.c:1391
+msgid "You are currently splitting a commit during a rebase."
+msgstr "В момента разделяте подаване докато пребазирате."
 
-#: builtin/checkout.c:1137
-msgid "do not limit pathspecs to sparse entries only"
-msgstr "без ограничаване на изброените пътища само до частично изтеглените"
+#: wt-status.c:1394
+msgid "  (Once your working directory is clean, run \"git rebase --continue\")"
+msgstr ""
+"  (След като работното ви дърво стане чисто, използвайте „git rebase --"
+"continue“)"
 
-#: builtin/checkout.c:1139
-msgid "second guess 'git checkout <no-such-branch>'"
+#: wt-status.c:1398
+#, c-format
+msgid "You are currently editing a commit while rebasing branch '%s' on '%s'."
 msgstr ""
-"опит за отгатване на име на клон след неуспешен опит с „git checkout "
-"НЕСЪЩЕСТВУВАЩ_КЛОН“"
+"В момента редактирате подаване докато пребазирате клона „%s“ върху „%s“."
 
-#: builtin/checkout.c:1141
-msgid "do not check if another worktree is holding the given ref"
-msgstr "без проверка дали друго работно дърво държи указателя"
+#: wt-status.c:1403
+msgid "You are currently editing a commit during a rebase."
+msgstr "В момента редактирате подаване докато пребазирате."
 
-#: builtin/checkout.c:1145 builtin/clone.c:85 builtin/fetch.c:149
-#: builtin/merge.c:238 builtin/pull.c:128 builtin/push.c:572
-#: builtin/send-pack.c:174
-msgid "force progress reporting"
-msgstr "извеждане на напредъка"
+#: wt-status.c:1406
+msgid "  (use \"git commit --amend\" to amend the current commit)"
+msgstr ""
+"  (използвайте „git commit --amend“, за да редактирате текущото подаване)"
 
-#: builtin/checkout.c:1175
-msgid "-b, -B and --orphan are mutually exclusive"
-msgstr "Опциите „-b“, „-B“ и „--orphan“ са несъвместими една с друга"
+#: wt-status.c:1408
+msgid ""
+"  (use \"git rebase --continue\" once you are satisfied with your changes)"
+msgstr ""
+"  (използвайте „git rebase --continue“, след като завършите промените си)"
 
-#: builtin/checkout.c:1192
-msgid "--track needs a branch name"
-msgstr "опцията „--track“ изисква име на клон"
+#: wt-status.c:1419
+msgid "Cherry-pick currently in progress."
+msgstr "В момента се извършва отбиране на подавания."
 
-#: builtin/checkout.c:1197
-msgid "Missing branch name; try -b"
-msgstr "Липсва име на клон, използвайте опцията „-b“"
+#: wt-status.c:1422
+#, c-format
+msgid "You are currently cherry-picking commit %s."
+msgstr "В момента отбирате подаването „%s“."
 
-#: builtin/checkout.c:1233
-msgid "invalid path specification"
-msgstr "указан е неправилен път"
+#: wt-status.c:1429
+msgid "  (fix conflicts and run \"git cherry-pick --continue\")"
+msgstr "  (коригирайте конфликтите и изпълнете „git cherry-pick --continue“)"
 
-#: builtin/checkout.c:1240
-#, c-format
-msgid "'%s' is not a commit and a branch '%s' cannot be created from it"
-msgstr "„%s“ не е подаване, затова от него не може да се създаде клон „%s“"
+#: wt-status.c:1432
+msgid "  (run \"git cherry-pick --continue\" to continue)"
+msgstr "  (за да продължите, изпълнете „git cherry-pick --continue“)"
 
-#: builtin/checkout.c:1244
-#, c-format
-msgid "git checkout: --detach does not take a path argument '%s'"
-msgstr "git checkout: опцията „--detach“ не приема аргумент-път „%s“"
+#: wt-status.c:1435
+msgid "  (all conflicts fixed: run \"git cherry-pick --continue\")"
+msgstr ""
+"  (всички конфликти са коригирани, изпълнете „git cherry-pick --continue“)"
 
-#: builtin/checkout.c:1248
-msgid ""
-"git checkout: --ours/--theirs, --force and --merge are incompatible when\n"
-"checking out of the index."
+#: wt-status.c:1437
+msgid "  (use \"git cherry-pick --skip\" to skip this patch)"
+msgstr "  (използвайте „git cherry-pick --skip“, за да пропуснете тази кръпка)"
+
+#: wt-status.c:1439
+msgid "  (use \"git cherry-pick --abort\" to cancel the cherry-pick operation)"
 msgstr ""
-"git checkout: опциите „--ours“/„--theirs“, „--force“ и „--merge“\n"
-"са несъвместими с изтегляне от индекса."
+"  (използвайте „git cherry-pick --abort“, за да отмените всички действия с "
+"отбиране)"
 
-#: builtin/clean.c:26
-msgid ""
-"git clean [-d] [-f] [-i] [-n] [-q] [-e <pattern>] [-x | -X] [--] <paths>..."
-msgstr "git clean [-d] [-f] [-i] [-n] [-q] [-e ШАБЛОН] [-x | -X] [--] ПЪТ…"
+#: wt-status.c:1449
+msgid "Revert currently in progress."
+msgstr "В момента тече отмяна на подаване."
 
-#: builtin/clean.c:30
+#: wt-status.c:1452
 #, c-format
-msgid "Removing %s\n"
-msgstr "Изтриване на „%s“\n"
+msgid "You are currently reverting commit %s."
+msgstr "В момента отменяте подаване „%s“."
 
-#: builtin/clean.c:31
-#, c-format
-msgid "Would remove %s\n"
-msgstr "Файлът „%s“ ще бъде изтрит\n"
+#: wt-status.c:1458
+msgid "  (fix conflicts and run \"git revert --continue\")"
+msgstr "  (коригирайте конфликтите и изпълнете „git revert --continue“)"
 
-#: builtin/clean.c:32
-#, c-format
-msgid "Skipping repository %s\n"
-msgstr "Прескачане на хранилището „%s“\n"
+#: wt-status.c:1461
+msgid "  (run \"git revert --continue\" to continue)"
+msgstr "  (за да продължите, изпълнете „git revert --continue“)"
 
-#: builtin/clean.c:33
-#, c-format
-msgid "Would skip repository %s\n"
-msgstr "Хранилището „%s“ ще бъде прескочено\n"
+#: wt-status.c:1464
+msgid "  (all conflicts fixed: run \"git revert --continue\")"
+msgstr "  (всички конфликти са коригирани, изпълнете „git revert --continue“)"
 
-#: builtin/clean.c:34
-#, c-format
-msgid "failed to remove %s"
-msgstr "файлът „%s“ не може да бъде изтрит"
+#: wt-status.c:1466
+msgid "  (use \"git revert --skip\" to skip this patch)"
+msgstr "  (използвайте „git revert --skip“, за да пропуснете тази кръпка)"
 
-#: builtin/clean.c:302 git-add--interactive.perl:579
-#, c-format
-msgid ""
-"Prompt help:\n"
-"1          - select a numbered item\n"
-"foo        - select item based on unique prefix\n"
-"           - (empty) select nothing\n"
+#: wt-status.c:1468
+msgid "  (use \"git revert --abort\" to cancel the revert operation)"
 msgstr ""
-"Подсказка:\n"
-"1          — избор на обект според реда\n"
-"ПРЕФИКС    — избор на единствен обект по този уникален префикс\n"
-"           — (празно) нищо да не се избира\n"
+"  (използвайте „git revert --abort“, за да преустановите отмяната на "
+"подаване)"
 
-#: builtin/clean.c:306 git-add--interactive.perl:588
+#: wt-status.c:1478
 #, c-format
-msgid ""
-"Prompt help:\n"
-"1          - select a single item\n"
-"3-5        - select a range of items\n"
-"2-3,6-9    - select multiple ranges\n"
-"foo        - select item based on unique prefix\n"
+msgid "You are currently bisecting, started from branch '%s'."
+msgstr "В момента търсите двоично, като сте стартирали от клон „%s“."
+
+#: wt-status.c:1482
+msgid "You are currently bisecting."
+msgstr "В момента търсите двоично."
+
+#: wt-status.c:1485
+msgid "  (use \"git bisect reset\" to get back to the original branch)"
+msgstr ""
+"  (използвайте „git bisect reset“, за да се върнете към първоначалното "
+"състояние и клон)"
+
+#: wt-status.c:1694
+msgid "On branch "
+msgstr "На клон "
+
+#: wt-status.c:1701
+msgid "interactive rebase in progress; onto "
+msgstr "извършвате интерактивно пребазиране върху "
+
+#: wt-status.c:1703
+msgid "rebase in progress; onto "
+msgstr "извършвате пребазиране върху "
+
+#: wt-status.c:1713
+msgid "Not currently on any branch."
+msgstr "Извън всички клони."
+
+#: wt-status.c:1730
+msgid "Initial commit"
+msgstr "Първоначално подаване"
+
+#: wt-status.c:1731
+msgid "No commits yet"
+msgstr "Все още липсват подавания"
+
+#: wt-status.c:1745
+msgid "Untracked files"
+msgstr "Неследени файлове"
+
+#: wt-status.c:1747
+msgid "Ignored files"
+msgstr "Игнорирани файлове"
+
+#: wt-status.c:1751
+#, c-format
+msgid ""
+"It took %.2f seconds to enumerate untracked files. 'status -uno'\n"
+"may speed it up, but you have to be careful not to forget to add\n"
+"new files yourself (see 'git help status')."
+msgstr ""
+"Бяха необходими %.2f секунди за изброяването на неследените файлове.\n"
+"Добавянето на опцията „-uno“ към командата „git status“, ще ускори\n"
+"изпълнението, но ще трябва да добавяте новите файлове ръчно.\n"
+"За повече подробности погледнете „git status help“."
+
+#: wt-status.c:1757
+#, c-format
+msgid "Untracked files not listed%s"
+msgstr "Неследените файлове не са изведени%s"
+
+#: wt-status.c:1759
+msgid " (use -u option to show untracked files)"
+msgstr " (използвайте опцията „-u“, за да изведете неследените файлове)"
+
+#: wt-status.c:1765
+msgid "No changes"
+msgstr "Няма промени"
+
+#: wt-status.c:1770
+#, c-format
+msgid "no changes added to commit (use \"git add\" and/or \"git commit -a\")\n"
+msgstr ""
+"към индекса за подаване не са добавени промени (използвайте „git add“ и/или "
+"„git commit -a“)\n"
+
+#: wt-status.c:1773
+#, c-format
+msgid "no changes added to commit\n"
+msgstr "към индекса за подаване не са добавени промени\n"
+
+#: wt-status.c:1776
+#, c-format
+msgid ""
+"nothing added to commit but untracked files present (use \"git add\" to "
+"track)\n"
+msgstr ""
+"към индекса за подаване не са добавени промени, но има нови файлове "
+"(използвайте „git add“, за да започне тяхното следене)\n"
+
+#: wt-status.c:1779
+#, c-format
+msgid "nothing added to commit but untracked files present\n"
+msgstr "към индекса за подаване не са добавени промени, но има нови файлове\n"
+
+#: wt-status.c:1782
+#, c-format
+msgid "nothing to commit (create/copy files and use \"git add\" to track)\n"
+msgstr ""
+"липсват каквито и да е промени (създайте или копирайте файлове и използвайте "
+"„git add“, за да започне тяхното следене)\n"
+
+#: wt-status.c:1785 wt-status.c:1790
+#, c-format
+msgid "nothing to commit\n"
+msgstr "липсват каквито и да е промени\n"
+
+#: wt-status.c:1788
+#, c-format
+msgid "nothing to commit (use -u to show untracked files)\n"
+msgstr ""
+"липсват каквито и да е промени (използвайте опцията „-u“, за да се изведат и "
+"неследените файлове)\n"
+
+#: wt-status.c:1792
+#, c-format
+msgid "nothing to commit, working tree clean\n"
+msgstr "липсват каквито и да е промени, работното дърво е чисто\n"
+
+#: wt-status.c:1905
+msgid "No commits yet on "
+msgstr "Все още липсват подавания в "
+
+#: wt-status.c:1909
+msgid "HEAD (no branch)"
+msgstr "HEAD (извън клон)"
+
+#: wt-status.c:1940
+msgid "different"
+msgstr "различен"
+
+#: wt-status.c:1942 wt-status.c:1950
+msgid "behind "
+msgstr "назад с "
+
+#: wt-status.c:1945 wt-status.c:1948
+msgid "ahead "
+msgstr "напред с "
+
+#. TRANSLATORS: the action is e.g. "pull with rebase"
+#: wt-status.c:2470
+#, c-format
+msgid "cannot %s: You have unstaged changes."
+msgstr "не може да извършите „%s“, защото има промени, които не са в индекса."
+
+#: wt-status.c:2476
+msgid "additionally, your index contains uncommitted changes."
+msgstr "освен това в индекса има неподадени промени."
+
+#: wt-status.c:2478
+#, c-format
+msgid "cannot %s: Your index contains uncommitted changes."
+msgstr "не може да извършите „%s“, защото в индекса има неподадени промени."
+
+#: compat/precompose_utf8.c:58 builtin/clone.c:455
+#, c-format
+msgid "failed to unlink '%s'"
+msgstr "неуспешно изтриване на „%s“"
+
+#: builtin/add.c:26
+msgid "git add [<options>] [--] <pathspec>..."
+msgstr "git add [ОПЦИЯ…] [--] ПЪТ…"
+
+#: builtin/add.c:87
+#, c-format
+msgid "unexpected diff status %c"
+msgstr "неочакван изходен код при генериране на разлика: %c"
+
+#: builtin/add.c:92 builtin/commit.c:288
+msgid "updating files failed"
+msgstr "неуспешно обновяване на файловете"
+
+#: builtin/add.c:102
+#, c-format
+msgid "remove '%s'\n"
+msgstr "изтриване на „%s“\n"
+
+#: builtin/add.c:177
+msgid "Unstaged changes after refreshing the index:"
+msgstr "Промени, които и след обновяването на индекса не са добавени към него:"
+
+#: builtin/add.c:252 builtin/rev-parse.c:899
+msgid "Could not read the index"
+msgstr "Индексът не може да бъде прочетен"
+
+#: builtin/add.c:263
+#, c-format
+msgid "Could not open '%s' for writing."
+msgstr "Файлът „%s“ не може да бъде отворен за запис."
+
+#: builtin/add.c:267
+msgid "Could not write patch"
+msgstr "Кръпката не може да бъде записана"
+
+#: builtin/add.c:270
+msgid "editing patch failed"
+msgstr "неуспешно редактиране на кръпка"
+
+#: builtin/add.c:273
+#, c-format
+msgid "Could not stat '%s'"
+msgstr "Не може да се получи информация чрез „stat“ за файла „%s“"
+
+#: builtin/add.c:275
+msgid "Empty patch. Aborted."
+msgstr "Празна кръпка, преустановяване на действието."
+
+#: builtin/add.c:280
+#, c-format
+msgid "Could not apply '%s'"
+msgstr "Кръпката „%s“ не може да бъде приложена"
+
+#: builtin/add.c:288
+msgid "The following paths are ignored by one of your .gitignore files:\n"
+msgstr ""
+"Следните пътища ще бъдат игнорирани според някой от файловете „.gitignore“:\n"
+
+#: builtin/add.c:308 builtin/clean.c:910 builtin/fetch.c:163 builtin/mv.c:124
+#: builtin/prune-packed.c:56 builtin/pull.c:223 builtin/push.c:548
+#: builtin/remote.c:1344 builtin/rm.c:241 builtin/send-pack.c:165
+msgid "dry run"
+msgstr "пробно изпълнение"
+
+#: builtin/add.c:311
+msgid "interactive picking"
+msgstr "интерактивно отбиране на промени"
+
+#: builtin/add.c:312 builtin/checkout.c:1482 builtin/reset.c:307
+msgid "select hunks interactively"
+msgstr "интерактивен избор на парчета код"
+
+#: builtin/add.c:313
+msgid "edit current diff and apply"
+msgstr "редактиране на текущата разлика и прилагане"
+
+#: builtin/add.c:314
+msgid "allow adding otherwise ignored files"
+msgstr "добавяне и на иначе игнорираните файлове"
+
+#: builtin/add.c:315
+msgid "update tracked files"
+msgstr "обновяване на следените файлове"
+
+#: builtin/add.c:316
+msgid "renormalize EOL of tracked files (implies -u)"
+msgstr "уеднаквяване на знаците за край на файл (включва опцията „-u“)"
+
+#: builtin/add.c:317
+msgid "record only the fact that the path will be added later"
+msgstr "отбелязване само на факта, че пътят ще бъде добавен по-късно"
+
+#: builtin/add.c:318
+msgid "add changes from all tracked and untracked files"
+msgstr "добавяне на всички промени в следените и неследените файлове"
+
+#: builtin/add.c:321
+msgid "ignore paths removed in the working tree (same as --no-all)"
+msgstr ""
+"игнориране на пътищата, които са изтрити от работното дърво (същото като „--"
+"no-all“)"
+
+#: builtin/add.c:323
+msgid "don't add, only refresh the index"
+msgstr "без добавяне на нови файлове, само обновяване на индекса"
+
+#: builtin/add.c:324
+msgid "just skip files which cannot be added because of errors"
+msgstr ""
+"прескачане на файловете, които не могат да бъдат добавени поради грешки"
+
+#: builtin/add.c:325
+msgid "check if - even missing - files are ignored in dry run"
+msgstr ""
+"проверка, че при пробно изпълнение всички файлове, дори и изтритите, се "
+"игнорират"
+
+#: builtin/add.c:327 builtin/update-index.c:1004
+msgid "override the executable bit of the listed files"
+msgstr "изрично задаване на стойността на флага дали файлът е изпълним"
+
+#: builtin/add.c:329
+msgid "warn when adding an embedded repository"
+msgstr "предупреждаване при добавяне на вградено хранилище"
+
+#: builtin/add.c:347
+#, c-format
+msgid ""
+"You've added another git repository inside your current repository.\n"
+"Clones of the outer repository will not contain the contents of\n"
+"the embedded repository and will not know how to obtain it.\n"
+"If you meant to add a submodule, use:\n"
+"\n"
+"\tgit submodule add <url> %s\n"
+"\n"
+"If you added this path by mistake, you can remove it from the\n"
+"index with:\n"
+"\n"
+"\tgit rm --cached %s\n"
+"\n"
+"See \"git help submodule\" for more information."
+msgstr ""
+"Изтеглили сте допълнително хранилище в текущото.  Когато клонирате "
+"обхващащото\n"
+"хранилище няма да получите вграденото, защото външното хранилище няма "
+"представа\n"
+"за вътрешното.  За да добавите подмодул, изпълнете:\n"
+"\n"
+"    git submodule add АДРЕС %s\n"
+"\n"
+"Ако добавянето е грешка, може да го извадите от индекса с командата:\n"
+"\n"
+"    git rm --cached %s\n"
+"\n"
+"За повече информация погледнете „git help submodule“."
+
+#: builtin/add.c:375
+#, c-format
+msgid "adding embedded git repository: %s"
+msgstr "добавяне на вградено хранилище: %s"
+
+#: builtin/add.c:393
+#, c-format
+msgid "Use -f if you really want to add them.\n"
+msgstr "Използвайте опцията „-f“, за да ги добавите наистина.\n"
+
+#: builtin/add.c:400
+msgid "adding files failed"
+msgstr "неуспешно добавяне на файлове"
+
+#: builtin/add.c:428 builtin/commit.c:348
+msgid "--pathspec-from-file is incompatible with --interactive/--patch"
+msgstr ""
+"опцията „--pathspec-from-file“ е несъвместима с всяка от опциите „--"
+"interactive“/„--patch“"
+
+#: builtin/add.c:434
+msgid "--pathspec-from-file is incompatible with --edit"
+msgstr "опциите „--pathspec-from-file“ и „--edit“ са несъвместими"
+
+#: builtin/add.c:446
+msgid "-A and -u are mutually incompatible"
+msgstr "опциите „-A“ и „-u“ са несъвместими"
+
+#: builtin/add.c:449
+msgid "Option --ignore-missing can only be used together with --dry-run"
+msgstr "Опцията „--ignore-missing“ изисква „--dry-run“"
+
+#: builtin/add.c:453
+#, c-format
+msgid "--chmod param '%s' must be either -x or +x"
+msgstr "параметърът към „--chmod“ — „%s“ може да е или „-x“, или „+x“"
+
+#: builtin/add.c:471 builtin/checkout.c:1648 builtin/commit.c:354
+#: builtin/reset.c:327
+msgid "--pathspec-from-file is incompatible with pathspec arguments"
+msgstr ""
+"опцията „--pathspec-from-file“ е несъвместима с аргументи, указващи пътища"
+
+#: builtin/add.c:478 builtin/checkout.c:1660 builtin/commit.c:360
+#: builtin/reset.c:333
+msgid "--pathspec-file-nul requires --pathspec-from-file"
+msgstr "опцията „--pathspec-file-nul“ изисква опция „--pathspec-from-file“"
+
+#: builtin/add.c:482
+#, c-format
+msgid "Nothing specified, nothing added.\n"
+msgstr "Нищо не е зададено и нищо не е добавено.\n"
+
+#: builtin/add.c:483
+#, c-format
+msgid "Maybe you wanted to say 'git add .'?\n"
+msgstr "Вероятно искахте да използвате „git add .“?\n"
+
+#: builtin/am.c:347
+msgid "could not parse author script"
+msgstr "скриптът за автор не може да се анализира"
+
+#: builtin/am.c:431
+#, c-format
+msgid "'%s' was deleted by the applypatch-msg hook"
+msgstr "„%s“ бе изтрит от куката „applypatch-msg“"
+
+#: builtin/am.c:473
+#, c-format
+msgid "Malformed input line: '%s'."
+msgstr "Даденият входен ред е с неправилен формат: „%s“."
+
+#: builtin/am.c:511
+#, c-format
+msgid "Failed to copy notes from '%s' to '%s'"
+msgstr "Бележката не може да се копира от „%s“ към „%s“"
+
+#: builtin/am.c:537
+msgid "fseek failed"
+msgstr "неуспешно изпълнение на „fseek“"
+
+#: builtin/am.c:725
+#, c-format
+msgid "could not parse patch '%s'"
+msgstr "кръпката „%s“ не може да се анализира"
+
+#: builtin/am.c:790
+msgid "Only one StGIT patch series can be applied at once"
+msgstr ""
+"Само една поредица от кръпки от „StGIT“ може да бъде прилагана в даден момент"
+
+#: builtin/am.c:838
+msgid "invalid timestamp"
+msgstr "неправилна стойност за време"
+
+#: builtin/am.c:843 builtin/am.c:855
+msgid "invalid Date line"
+msgstr "неправилен ред за дата „Date“"
+
+#: builtin/am.c:850
+msgid "invalid timezone offset"
+msgstr "неправилно отместване на часовия пояс"
+
+#: builtin/am.c:943
+msgid "Patch format detection failed."
+msgstr "Форматът на кръпката не може да бъде определен."
+
+#: builtin/am.c:948 builtin/clone.c:409
+#, c-format
+msgid "failed to create directory '%s'"
+msgstr "директорията „%s“ не може да бъде създадена"
+
+#: builtin/am.c:953
+msgid "Failed to split patches."
+msgstr "Кръпките не могат да бъдат разделени."
+
+#: builtin/am.c:1084
+#, c-format
+msgid "When you have resolved this problem, run \"%s --continue\"."
+msgstr "След коригирането на този проблем изпълнете „%s --continue“."
+
+#: builtin/am.c:1085
+#, c-format
+msgid "If you prefer to skip this patch, run \"%s --skip\" instead."
+msgstr "Ако предпочитате да прескочите тази кръпка, изпълнете „%s --skip“."
+
+#: builtin/am.c:1086
+#, c-format
+msgid "To restore the original branch and stop patching, run \"%s --abort\"."
+msgstr "За да се върнете към първоначалното състояние, изпълнете „%s --abort“."
+
+#: builtin/am.c:1169
+msgid "Patch sent with format=flowed; space at the end of lines might be lost."
+msgstr ""
+"Кръпката е пратена с форматиране „format=flowed“.  Празните знаци в края на "
+"редовете може да се загубят."
+
+#: builtin/am.c:1197
+msgid "Patch is empty."
+msgstr "Кръпката е празна."
+
+#: builtin/am.c:1262
+#, c-format
+msgid "missing author line in commit %s"
+msgstr "липсва ред за авторство в подаването „%s“"
+
+#: builtin/am.c:1265
+#, c-format
+msgid "invalid ident line: %.*s"
+msgstr "грешен ред с идентичност: %.*s"
+
+#: builtin/am.c:1484
+msgid "Repository lacks necessary blobs to fall back on 3-way merge."
+msgstr ""
+"В хранилището липсват необходимите обекти-BLOB, за да се премине към тройно "
+"сливане."
+
+#: builtin/am.c:1486
+msgid "Using index info to reconstruct a base tree..."
+msgstr "Базовото дърво се реконструира от информацията в индекса…"
+
+#: builtin/am.c:1505
+msgid ""
+"Did you hand edit your patch?\n"
+"It does not apply to blobs recorded in its index."
+msgstr ""
+"Кръпката не може да се приложи към обектите-BLOB в индекса.\n"
+"Да не би да сте я редактирали на ръка?"
+
+#: builtin/am.c:1511
+msgid "Falling back to patching base and 3-way merge..."
+msgstr "Преминаване към прилагане на кръпка към базата и тройно сливане…"
+
+#: builtin/am.c:1537
+msgid "Failed to merge in the changes."
+msgstr "Неуспешно сливане на промените."
+
+#: builtin/am.c:1569
+msgid "applying to an empty history"
+msgstr "прилагане върху празна история"
+
+#: builtin/am.c:1616 builtin/am.c:1620
+#, c-format
+msgid "cannot resume: %s does not exist."
+msgstr "не може да се продължи — „%s“ не съществува."
+
+#: builtin/am.c:1638
+msgid "Commit Body is:"
+msgstr "Тялото на кръпката за прилагане е:"
+
+#. TRANSLATORS: Make sure to include [y], [n], [e], [v] and [a]
+#. in your translation. The program will only accept English
+#. input at this point.
+#.
+#: builtin/am.c:1648
+#, c-format
+msgid "Apply? [y]es/[n]o/[e]dit/[v]iew patch/[a]ccept all: "
+msgstr ""
+"Прилагане? „y“ — да/„n“ — не/„e“ — редактиране/„v“ — преглед/„a“ — приемане "
+"на всичко:"
+
+#: builtin/am.c:1695 builtin/commit.c:394
+msgid "unable to write index file"
+msgstr "индексът не може да бъде записан"
+
+#: builtin/am.c:1699
+#, c-format
+msgid "Dirty index: cannot apply patches (dirty: %s)"
+msgstr ""
+"Индексът не е чист: кръпките не могат да бъдат приложени (замърсени са: %s)"
+
+#: builtin/am.c:1739 builtin/am.c:1807
+#, c-format
+msgid "Applying: %.*s"
+msgstr "Прилагане: %.*s"
+
+#: builtin/am.c:1756
+msgid "No changes -- Patch already applied."
+msgstr "Без промени — кръпката вече е приложена."
+
+#: builtin/am.c:1762
+#, c-format
+msgid "Patch failed at %s %.*s"
+msgstr "Неуспешно прилагане на кръпка при %s %.*s“"
+
+#: builtin/am.c:1766
+msgid "Use 'git am --show-current-patch' to see the failed patch"
+msgstr ""
+"За да видите неуспешно приложени кръпки, използвайте опцията „git am --show-"
+"current-patch“ to see the failed patch"
+
+#: builtin/am.c:1810
+msgid ""
+"No changes - did you forget to use 'git add'?\n"
+"If there is nothing left to stage, chances are that something else\n"
+"already introduced the same changes; you might want to skip this patch."
+msgstr ""
+"Без промени — възможно е да не сте изпълнили „git add“.\n"
+"Ако няма друга промяна за включване в индекса, най-вероятно някоя друга\n"
+"кръпка е довела до същите промени и в такъв случай просто пропуснете тази."
+
+#: builtin/am.c:1817
+msgid ""
+"You still have unmerged paths in your index.\n"
+"You should 'git add' each file with resolved conflicts to mark them as "
+"such.\n"
+"You might run `git rm` on a file to accept \"deleted by them\" for it."
+msgstr ""
+"Индексът все още съдържа неслети промени.\n"
+"След корекция на конфликтите изпълнете „git add“ върху поправените файлове.\n"
+"За да приемете „изтрити от тях“, изпълнете „git rm“ върху изтритите файлове."
+
+#: builtin/am.c:1924 builtin/am.c:1928 builtin/am.c:1940 builtin/reset.c:346
+#: builtin/reset.c:354
+#, c-format
+msgid "Could not parse object '%s'."
+msgstr "„%s“ не е разпознат като обект."
+
+#: builtin/am.c:1976
+msgid "failed to clean index"
+msgstr "индексът не може да бъде изчистен"
+
+#: builtin/am.c:2020
+msgid ""
+"You seem to have moved HEAD since the last 'am' failure.\n"
+"Not rewinding to ORIG_HEAD"
+msgstr ""
+"Изглежда указателят „HEAD“ е променен и не сочи към същия обект както по "
+"времето\n"
+"на последното неуспешно изпълнение на „git am“.  Указателят се задава да "
+"сочи към\n"
+"„ORIG_HEAD“"
+
+#: builtin/am.c:2117
+#, c-format
+msgid "Invalid value for --patch-format: %s"
+msgstr "Неправилна стойност за „--patch-format“: „%s“"
+
+#: builtin/am.c:2153
+msgid "git am [<options>] [(<mbox> | <Maildir>)...]"
+msgstr "git am [ОПЦИЯ…] [(ФАЙЛ_С_ПОЩА|ДИРЕКТОРИЯ_С_ПОЩА)…]"
+
+#: builtin/am.c:2154
+msgid "git am [<options>] (--continue | --skip | --abort)"
+msgstr "git am [ОПЦИЯ…] (--continue | --quit | --abort)"
+
+#: builtin/am.c:2160
+msgid "run interactively"
+msgstr "интерактивна работа"
+
+#: builtin/am.c:2162
+msgid "historical option -- no-op"
+msgstr "изоставена опция, съществува по исторически причини, нищо не прави"
+
+#: builtin/am.c:2164
+msgid "allow fall back on 3way merging if needed"
+msgstr "да се преминава към тройно сливане при нужда."
+
+#: builtin/am.c:2165 builtin/init-db.c:494 builtin/prune-packed.c:58
+#: builtin/repack.c:304 builtin/stash.c:811
+msgid "be quiet"
+msgstr "без извеждане на информация"
+
+#: builtin/am.c:2167
+msgid "add a Signed-off-by line to the commit message"
+msgstr "добавяне на ред за подпис „Signed-off-by“ в съобщението за подаване"
+
+#: builtin/am.c:2170
+msgid "recode into utf8 (default)"
+msgstr "прекодиране в UTF-8 (стандартно)"
+
+#: builtin/am.c:2172
+msgid "pass -k flag to git-mailinfo"
+msgstr "подаване на опцията „-k“ на командата „git-mailinfo“"
+
+#: builtin/am.c:2174
+msgid "pass -b flag to git-mailinfo"
+msgstr "подаване на опцията „-b“ на командата „git-mailinfo“"
+
+#: builtin/am.c:2176
+msgid "pass -m flag to git-mailinfo"
+msgstr "подаване на опцията „-m“ на командата „git-mailinfo“"
+
+#: builtin/am.c:2178
+msgid "pass --keep-cr flag to git-mailsplit for mbox format"
+msgstr ""
+"подаване на опцията „--keep-cr“ на командата „git-mailsplit“ за формат „mbox“"
+
+#: builtin/am.c:2181
+msgid "do not pass --keep-cr flag to git-mailsplit independent of am.keepcr"
+msgstr ""
+"без подаване на опцията „--keep-cr“ на командата „git-mailsplit“ независимо "
+"от „am.keepcr“"
+
+#: builtin/am.c:2184
+msgid "strip everything before a scissors line"
+msgstr "пропускане на всичко преди реда за отрязване"
+
+#: builtin/am.c:2186 builtin/am.c:2189 builtin/am.c:2192 builtin/am.c:2195
+#: builtin/am.c:2198 builtin/am.c:2201 builtin/am.c:2204 builtin/am.c:2207
+#: builtin/am.c:2213
+msgid "pass it through git-apply"
+msgstr "прекарване през „git-apply“"
+
+#: builtin/am.c:2203 builtin/commit.c:1386 builtin/fmt-merge-msg.c:673
+#: builtin/fmt-merge-msg.c:676 builtin/grep.c:883 builtin/merge.c:249
+#: builtin/pull.c:160 builtin/pull.c:219 builtin/rebase.c:1469
+#: builtin/repack.c:315 builtin/repack.c:319 builtin/repack.c:321
+#: builtin/show-branch.c:650 builtin/show-ref.c:172 builtin/tag.c:403
+#: parse-options.h:154 parse-options.h:175 parse-options.h:316
+msgid "n"
+msgstr "БРОЙ"
+
+#: builtin/am.c:2209 builtin/branch.c:661 builtin/for-each-ref.c:38
+#: builtin/replace.c:555 builtin/tag.c:437 builtin/verify-tag.c:38
+msgid "format"
+msgstr "ФОРМАТ"
+
+#: builtin/am.c:2210
+msgid "format the patch(es) are in"
+msgstr "формат на кръпките"
+
+#: builtin/am.c:2216
+msgid "override error message when patch failure occurs"
+msgstr "избрано от вас съобщение за грешка при прилагане на кръпки"
+
+#: builtin/am.c:2218
+msgid "continue applying patches after resolving a conflict"
+msgstr "продължаване на прилагането на кръпки след коригирането на конфликт"
+
+#: builtin/am.c:2221
+msgid "synonyms for --continue"
+msgstr "псевдоними на „--continue“"
+
+#: builtin/am.c:2224
+msgid "skip the current patch"
+msgstr "прескачане на текущата кръпка"
+
+#: builtin/am.c:2227
+msgid "restore the original branch and abort the patching operation."
+msgstr ""
+"възстановяване на първоначалното състояние на клона и преустановяване на "
+"прилагането на кръпката."
+
+#: builtin/am.c:2230
+msgid "abort the patching operation but keep HEAD where it is."
+msgstr ""
+"преустановяване на прилагането на кръпката без промяна към кое сочи „HEAD“."
+
+#: builtin/am.c:2233
+msgid "show the patch being applied."
+msgstr "показване на прилаганата кръпка."
+
+#: builtin/am.c:2237
+msgid "lie about committer date"
+msgstr "дата за подаване различна от първоначалната"
+
+#: builtin/am.c:2239
+msgid "use current timestamp for author date"
+msgstr "използване на текущото време като това за автор"
+
+#: builtin/am.c:2241 builtin/commit-tree.c:120 builtin/commit.c:1507
+#: builtin/merge.c:286 builtin/pull.c:194 builtin/rebase.c:509
+#: builtin/rebase.c:1513 builtin/revert.c:117 builtin/tag.c:418
+msgid "key-id"
+msgstr "ИДЕНТИФИКАТОР_НА_КЛЮЧ"
+
+#: builtin/am.c:2242 builtin/rebase.c:510 builtin/rebase.c:1514
+msgid "GPG-sign commits"
+msgstr "подписване на подаванията с GPG"
+
+#: builtin/am.c:2245
+msgid "(internal use for git-rebase)"
+msgstr "(ползва се вътрешно за „git-rebase“)"
+
+#: builtin/am.c:2263
+msgid ""
+"The -b/--binary option has been a no-op for long time, and\n"
+"it will be removed. Please do not use it anymore."
+msgstr ""
+"Опциите „-b“/„--binary“ отдавна не правят нищо и\n"
+"ще бъдат премахнати в бъдеще.  Не ги ползвайте."
+
+#: builtin/am.c:2270
+msgid "failed to read the index"
+msgstr "неуспешно изчитане на индекса"
+
+#: builtin/am.c:2285
+#, c-format
+msgid "previous rebase directory %s still exists but mbox given."
+msgstr ""
+"предишната директория за пребазиране „%s“ все още съществува, а е зададен "
+"файл „mbox“."
+
+#: builtin/am.c:2309
+#, c-format
+msgid ""
+"Stray %s directory found.\n"
+"Use \"git am --abort\" to remove it."
+msgstr ""
+"Открита е излишна директория „%s“.\n"
+"Можете да я изтриете с командата „git am --abort“."
+
+#: builtin/am.c:2315
+msgid "Resolve operation not in progress, we are not resuming."
+msgstr "В момента не тече операция по коригиране и няма как да се продължи."
+
+#: builtin/am.c:2325
+msgid "interactive mode requires patches on the command line"
+msgstr "интерактивният режим изисква кръпки на командния ред"
+
+#: builtin/apply.c:8
+msgid "git apply [<options>] [<patch>...]"
+msgstr "git apply [ОПЦИЯ…] [КРЪПКА…]"
+
+#: builtin/archive.c:17
+#, c-format
+msgid "could not create archive file '%s'"
+msgstr "архивният файл „%s“ не може да бъде създаден"
+
+#: builtin/archive.c:20
+msgid "could not redirect output"
+msgstr "изходът не може да бъде пренасочен"
+
+#: builtin/archive.c:37
+msgid "git archive: Remote with no URL"
+msgstr "git archive: Липсва адрес за отдалеченото хранилище"
+
+#: builtin/archive.c:61
+msgid "git archive: expected ACK/NAK, got a flush packet"
+msgstr ""
+"git archive: очакваше се „ACK“/„NAK“, а бе получен изчистващ пакет „flush“"
+
+#: builtin/archive.c:64
+#, c-format
+msgid "git archive: NACK %s"
+msgstr "git archive: получен е „NACK“ — %s"
+
+#: builtin/archive.c:65
+msgid "git archive: protocol error"
+msgstr "git archive: протоколна грешка"
+
+#: builtin/archive.c:69
+msgid "git archive: expected a flush"
+msgstr "git archive: очакваше се изчистване на буферите чрез „flush“"
+
+#: builtin/bisect--helper.c:22
+msgid "git bisect--helper --next-all [--no-checkout]"
+msgstr "git bisect--helper --next-all [--no-checkout]"
+
+#: builtin/bisect--helper.c:23
+msgid "git bisect--helper --write-terms <bad_term> <good_term>"
+msgstr "git bisect--helper --write-terms ЛОШО ДОБРО"
+
+#: builtin/bisect--helper.c:24
+msgid "git bisect--helper --bisect-clean-state"
+msgstr "git bisect--helper --bisect-clean-state"
+
+#: builtin/bisect--helper.c:25
+msgid "git bisect--helper --bisect-reset [<commit>]"
+msgstr "git bisect--helper --bisect-reset [ПОДАВАНЕ]"
+
+#: builtin/bisect--helper.c:26
+msgid ""
+"git bisect--helper --bisect-write [--no-log] <state> <revision> <good_term> "
+"<bad_term>"
+msgstr ""
+"git bisect--helper --bisect-write [--no-log] СЪСТОЯНИЕ ВЕРСИЯ ДОБРО ЛОШО"
+
+#: builtin/bisect--helper.c:27
+msgid ""
+"git bisect--helper --bisect-check-and-set-terms <command> <good_term> "
+"<bad_term>"
+msgstr "git bisect--helper --bisect-check-and-set-terms КОМАНДА ДОБРО"
+
+#: builtin/bisect--helper.c:28
+msgid "git bisect--helper --bisect-next-check <good_term> <bad_term> [<term>]"
+msgstr "git bisect--helper --bisect-next-check ЛОШО ДОБРО УПРАВЛЯВАЩА_ДУМА"
+
+#: builtin/bisect--helper.c:29
+msgid ""
+"git bisect--helper --bisect-terms [--term-good | --term-old | --term-bad | --"
+"term-new]"
+msgstr ""
+"git bisect--helper --bisect-terms [--term-good | --term-old | --term-bad | --"
+"term-new]"
+
+#: builtin/bisect--helper.c:30
+msgid ""
+"git bisect--helper --bisect-start [--term-{old,good}=<term> --term-{new,bad}"
+"=<term>][--no-checkout] [<bad> [<good>...]] [--] [<paths>...]"
+msgstr ""
+"git bisect--helper --bisect-start [--term-{old,good}=<term> --term-{new,bad}"
+"=<term>][--no-checkout] [ЛОШО [ДОБРО…]] [--] [ПЪТ…]"
+
+#: builtin/bisect--helper.c:86
+#, c-format
+msgid "'%s' is not a valid term"
+msgstr "„%s“ е неправилна управляваща дума"
+
+#: builtin/bisect--helper.c:90
+#, c-format
+msgid "can't use the builtin command '%s' as a term"
+msgstr "„%s“ е вградена команда и не може да се използва като управляваща дума"
+
+#: builtin/bisect--helper.c:100
+#, c-format
+msgid "can't change the meaning of the term '%s'"
+msgstr "не може да смените значението на управляващата дума „%s“"
+
+#: builtin/bisect--helper.c:111
+msgid "please use two different terms"
+msgstr "използвайте две различни управляващи думи"
+
+#: builtin/bisect--helper.c:118
+msgid "could not open the file BISECT_TERMS"
+msgstr "файлът „BISECT_TERMS“ не може да се отвори"
+
+#: builtin/bisect--helper.c:155
+#, c-format
+msgid "We are not bisecting.\n"
+msgstr "В момента не се извършва двоично търсене.\n"
+
+#: builtin/bisect--helper.c:163
+#, c-format
+msgid "'%s' is not a valid commit"
+msgstr "„%s“ не е подаване"
+
+#: builtin/bisect--helper.c:172
+#, c-format
+msgid ""
+"could not check out original HEAD '%s'. Try 'git bisect reset <commit>'."
+msgstr ""
+"първоначално указаното „%s“ в указателя „HEAD“ не може да бъде\n"
+"изтеглено.  Пробвайте да изпълните командата „git bisect reset ПОДАВАНЕ“."
+
+#: builtin/bisect--helper.c:216
+#, c-format
+msgid "Bad bisect_write argument: %s"
+msgstr "Неправилен аргумент на функцията „bisect_write“: „%s“"
+
+#: builtin/bisect--helper.c:221
+#, c-format
+msgid "couldn't get the oid of the rev '%s'"
+msgstr "идентификаторът на обект на версия „%s“ не може да бъде получен"
+
+#: builtin/bisect--helper.c:233
+#, c-format
+msgid "couldn't open the file '%s'"
+msgstr "файлът „%s“ не може да бъде отворен"
+
+#: builtin/bisect--helper.c:259
+#, c-format
+msgid "Invalid command: you're currently in a %s/%s bisect"
+msgstr "Неправилна команда: в момента се изпълнява двоично търсене по %s/%s."
+
+#: builtin/bisect--helper.c:286
+#, c-format
+msgid ""
+"You need to give me at least one %s and %s revision.\n"
+"You can use \"git bisect %s\" and \"git bisect %s\" for that."
+msgstr ""
+"Трябва да зададете поне една „%s“ и една „%s“ версия.  (Това може да се\n"
+"направи съответно и чрез командите „git bisect %s“ и „git bisect %s“.)"
+
+#: builtin/bisect--helper.c:290
+#, c-format
+msgid ""
+"You need to start by \"git bisect start\".\n"
+"You then need to give me at least one %s and %s revision.\n"
+"You can use \"git bisect %s\" and \"git bisect %s\" for that."
+msgstr ""
+"Трябва да започнете двоичното търсене чрез командата „git bisect start“.\n"
+"Трябва да зададете поне една „%s“ и една „%s“ версия.  (Това може да се\n"
+"направи съответно и чрез командите „git bisect %s“ и „git bisect %s“.)"
+
+#: builtin/bisect--helper.c:322
+#, c-format
+msgid "bisecting only with a %s commit"
+msgstr "двоично търсене само по „%s“ подаване."
+
+#. TRANSLATORS: Make sure to include [Y] and [n] in your
+#. translation. The program will only accept English input
+#. at this point.
+#.
+#: builtin/bisect--helper.c:330
+msgid "Are you sure [Y/n]? "
+msgstr "Да се продължи ли? „Y“ —  ДА, „n“ — не"
+
+#: builtin/bisect--helper.c:377
+msgid "no terms defined"
+msgstr "не са указани управляващи думи"
+
+#: builtin/bisect--helper.c:380
+#, c-format
+msgid ""
+"Your current terms are %s for the old state\n"
+"and %s for the new state.\n"
+msgstr ""
+"Текущите управляващи думи са: %s за старото състояние\n"
+"и %s за новото състояние.\n"
+
+#: builtin/bisect--helper.c:390
+#, c-format
+msgid ""
+"invalid argument %s for 'git bisect terms'.\n"
+"Supported options are: --term-good|--term-old and --term-bad|--term-new."
+msgstr ""
+"на „git bisect terms“ е подаден неправилен аргумент „%s“\n"
+"Поддържат се опциите „--term-good“/„--term-old“ и „--term-bad„/„--term-new“."
+
+#: builtin/bisect--helper.c:476
+#, c-format
+msgid "unrecognized option: '%s'"
+msgstr "непозната опция: %s"
+
+#: builtin/bisect--helper.c:480
+#, c-format
+msgid "'%s' does not appear to be a valid revision"
+msgstr "„%s“ не изглежда като указател към версия"
+
+#: builtin/bisect--helper.c:512
+msgid "bad HEAD - I need a HEAD"
+msgstr "Неправилен указател „HEAD“"
+
+#: builtin/bisect--helper.c:527
+#, c-format
+msgid "checking out '%s' failed. Try 'git bisect start <valid-branch>'."
+msgstr ""
+"Неуспешно преминаване към „%s“.  Изпълнете командата „git bisect start "
+"СЪЩЕСТВУВАЩ_КЛОН“."
+
+#: builtin/bisect--helper.c:548
+msgid "won't bisect on cg-seek'ed tree"
+msgstr ""
+"не може да се търси двоично, когато е изпълнена командата „cg-seek“ от "
+"„cogito“"
+
+#: builtin/bisect--helper.c:551
+msgid "bad HEAD - strange symbolic ref"
+msgstr "Неправилен указател „HEAD“ — необичаен символен указател"
+
+#: builtin/bisect--helper.c:575
+#, c-format
+msgid "invalid ref: '%s'"
+msgstr "неправилен указател: „%s“"
+
+#: builtin/bisect--helper.c:631
+msgid "perform 'git bisect next'"
+msgstr "извършване на „git bisect next“"
+
+#: builtin/bisect--helper.c:633
+msgid "write the terms to .git/BISECT_TERMS"
+msgstr "запазване на управляващите думи в „“.git/BISECT_TERMS„“"
+
+#: builtin/bisect--helper.c:635
+msgid "cleanup the bisection state"
+msgstr "изчистване на състоянието на двоичното търсене"
+
+#: builtin/bisect--helper.c:637
+msgid "check for expected revs"
+msgstr "проверка за очакваните версии"
+
+#: builtin/bisect--helper.c:639
+msgid "reset the bisection state"
+msgstr "изчистване на състоянието на двоичното търсене"
+
+#: builtin/bisect--helper.c:641
+msgid "write out the bisection state in BISECT_LOG"
+msgstr "запис на състоянието на двоичното търсене в „BISECT_LOG“"
+
+#: builtin/bisect--helper.c:643
+msgid "check and set terms in a bisection state"
+msgstr ""
+"проверка и задаване на управляващи думи към състоянието на двоичното търсене"
+
+#: builtin/bisect--helper.c:645
+msgid "check whether bad or good terms exist"
+msgstr "проверка дали съществуват одобряващи/отхвърлящи управляващи думи"
+
+#: builtin/bisect--helper.c:647
+msgid "print out the bisect terms"
+msgstr "извеждане на управляващите думи"
+
+#: builtin/bisect--helper.c:649
+msgid "start the bisect session"
+msgstr "начало на двоично търсене"
+
+#: builtin/bisect--helper.c:651
+msgid "update BISECT_HEAD instead of checking out the current commit"
+msgstr ""
+"обновяване на указателя „BISECT_HEAD“ вместо да се използва текущото подаване"
+
+#: builtin/bisect--helper.c:653
+msgid "no log for BISECT_WRITE"
+msgstr "липсва запис за „BISECT_WRITE“"
+
+#: builtin/bisect--helper.c:670
+msgid "--write-terms requires two arguments"
+msgstr "опцията „--write-terms“ изисква точно 2 аргумента"
+
+#: builtin/bisect--helper.c:674
+msgid "--bisect-clean-state requires no arguments"
+msgstr "опцията „--bisect-clean-state“ не приема аргументи"
+
+#: builtin/bisect--helper.c:681
+msgid "--bisect-reset requires either no argument or a commit"
+msgstr "опцията „--bisect-reset“ изисква или 0 аргументи, или 1 — подаване"
+
+#: builtin/bisect--helper.c:685
+msgid "--bisect-write requires either 4 or 5 arguments"
+msgstr "опцията „--bisect-write“ изисква 4 или 5 аргумента"
+
+#: builtin/bisect--helper.c:691
+msgid "--check-and-set-terms requires 3 arguments"
+msgstr "опцията „--check-and-set-terms“ изисква 3 аргумента"
+
+#: builtin/bisect--helper.c:697
+msgid "--bisect-next-check requires 2 or 3 arguments"
+msgstr "опцията „--bisect-next-check“ изисква 2 или 3 аргумента"
+
+#: builtin/bisect--helper.c:703
+msgid "--bisect-terms requires 0 or 1 argument"
+msgstr "опцията „--bisect-terms“ изисква 0 или 1 аргумента"
+
+#: builtin/blame.c:31
+msgid "git blame [<options>] [<rev-opts>] [<rev>] [--] <file>"
+msgstr "git blame [ОПЦИЯ…] [ОПЦИЯ_ЗА_ВЕРСИЯТА…] [ВЕРСИЯ] [--] ФАЙЛ"
+
+#: builtin/blame.c:36
+msgid "<rev-opts> are documented in git-rev-list(1)"
+msgstr "ОПЦИИте_ЗА_ВЕРСИЯТА са документирани в ръководството git-rev-list(1)"
+
+#: builtin/blame.c:409
+#, c-format
+msgid "expecting a color: %s"
+msgstr "трябва да е цвят: %s"
+
+#: builtin/blame.c:416
+msgid "must end with a color"
+msgstr "трябва да завършва с цвят"
+
+#: builtin/blame.c:729
+#, c-format
+msgid "invalid color '%s' in color.blame.repeatedLines"
+msgstr "неправилен цвят „%s“ в „color.blame.repeatedLines“"
+
+#: builtin/blame.c:747
+msgid "invalid value for blame.coloring"
+msgstr "неправилна стойност за „blame.coloring“"
+
+#: builtin/blame.c:822
+#, c-format
+msgid "cannot find revision %s to ignore"
+msgstr "версията за прескачане „%s“ не може да бъде открита"
+
+#: builtin/blame.c:844
+msgid "Show blame entries as we find them, incrementally"
+msgstr "Извеждане на авторството с намирането му, последователно"
+
+#: builtin/blame.c:845
+msgid "Show blank SHA-1 for boundary commits (Default: off)"
+msgstr ""
+"Извеждане на празни суми по SHA1 за граничните подавания (стандартно опцията "
+"е изключена)"
+
+#: builtin/blame.c:846
+msgid "Do not treat root commits as boundaries (Default: off)"
+msgstr ""
+"Началните подавания да не се считат за гранични (стандартно опцията е "
+"изключена)"
+
+#: builtin/blame.c:847
+msgid "Show work cost statistics"
+msgstr "Извеждане на статистика за извършените действия"
+
+#: builtin/blame.c:848
+msgid "Force progress reporting"
+msgstr "Принудително извеждане на напредъка"
+
+#: builtin/blame.c:849
+msgid "Show output score for blame entries"
+msgstr "Извеждане на допълнителна информация за определянето на авторството"
+
+#: builtin/blame.c:850
+msgid "Show original filename (Default: auto)"
+msgstr ""
+"Извеждане на първоначалното име на файл (стандартно това е автоматично)"
+
+#: builtin/blame.c:851
+msgid "Show original linenumber (Default: off)"
+msgstr ""
+"Извеждане на първоначалният номер на ред (стандартно опцията е изключена)"
+
+#: builtin/blame.c:852
+msgid "Show in a format designed for machine consumption"
+msgstr "Извеждане във формат за по-нататъшна обработка"
+
+#: builtin/blame.c:853
+msgid "Show porcelain format with per-line commit information"
+msgstr ""
+"Извеждане във формат за команди от потребителско ниво с информация на всеки "
+"ред"
+
+#: builtin/blame.c:854
+msgid "Use the same output mode as git-annotate (Default: off)"
+msgstr ""
+"Използване на същия формат като „git-annotate“ (стандартно опцията е "
+"изключена)"
+
+#: builtin/blame.c:855
+msgid "Show raw timestamp (Default: off)"
+msgstr "Извеждане на неформатирани времена (стандартно опцията е изключена)"
+
+#: builtin/blame.c:856
+msgid "Show long commit SHA1 (Default: off)"
+msgstr "Извеждане на пълните суми по SHA1 (стандартно опцията е изключена)"
+
+#: builtin/blame.c:857
+msgid "Suppress author name and timestamp (Default: off)"
+msgstr "Без име на автор и време на промяна (стандартно опцията е изключена)"
+
+#: builtin/blame.c:858
+msgid "Show author email instead of name (Default: off)"
+msgstr ""
+"Извеждане на е-пощата на автора, а не името му (стандартно опцията е "
+"изключена)"
+
+#: builtin/blame.c:859
+msgid "Ignore whitespace differences"
+msgstr "Без разлики в знаците за интервали"
+
+#: builtin/blame.c:860 builtin/log.c:1702
+msgid "rev"
+msgstr "ВЕРС"
+
+#: builtin/blame.c:860
+msgid "Ignore <rev> when blaming"
+msgstr "Прескачане на ВЕРСията при извеждане на авторството"
+
+#: builtin/blame.c:861
+msgid "Ignore revisions from <file>"
+msgstr "Прескачане на версиите указани във ФАЙЛа при извеждане на авторството"
+
+#: builtin/blame.c:862
+msgid "color redundant metadata from previous line differently"
+msgstr ""
+"оцветяване на повтарящите се метаданни от предишния ред в различен цвят"
+
+#: builtin/blame.c:863
+msgid "color lines by age"
+msgstr "оцветяване на редовете по възраст"
+
+#: builtin/blame.c:864
+msgid "Spend extra cycles to find better match"
+msgstr "Допълнителни изчисления за по-добри резултати"
+
+#: builtin/blame.c:865
+msgid "Use revisions from <file> instead of calling git-rev-list"
+msgstr "Изчитане на версиите от ФАЙЛ, а не чрез изпълнение на „git-rev-list“"
+
+#: builtin/blame.c:866
+msgid "Use <file>'s contents as the final image"
+msgstr "Използване на съдържанието на ФАЙЛа като крайно положение"
+
+#: builtin/blame.c:867 builtin/blame.c:868
+msgid "score"
+msgstr "напасване на редовете"
+
+#: builtin/blame.c:867
+msgid "Find line copies within and across files"
+msgstr ""
+"Търсене на копирани редове както в рамките на един файл, така и от един файл "
+"към друг"
+
+#: builtin/blame.c:868
+msgid "Find line movements within and across files"
+msgstr ""
+"Търсене на преместени редове както в рамките на един файл, така и от един "
+"файл към друг"
+
+#: builtin/blame.c:869
+msgid "n,m"
+msgstr "n,m"
+
+#: builtin/blame.c:869
+msgid "Process only line range n,m, counting from 1"
+msgstr ""
+"Информация само за редовете в диапазона от n до m включително.  Броенето "
+"започва от 1"
+
+#: builtin/blame.c:921
+msgid "--progress can't be used with --incremental or porcelain formats"
+msgstr ""
+"опцията „--progress“ е несъвместима с „--incremental“ и форма̀та на командите "
+"от потребителско ниво"
+
+#. TRANSLATORS: This string is used to tell us the
+#. maximum display width for a relative timestamp in
+#. "git blame" output.  For C locale, "4 years, 11
+#. months ago", which takes 22 places, is the longest
+#. among various forms of relative timestamps, but
+#. your language may need more or fewer display
+#. columns.
+#.
+#: builtin/blame.c:972
+msgid "4 years, 11 months ago"
+msgstr "преди 4 години и 11 месеца"
+
+#: builtin/blame.c:1079
+#, c-format
+msgid "file %s has only %lu line"
+msgid_plural "file %s has only %lu lines"
+msgstr[0] "има само %2$lu ред във файла „%1$s“"
+msgstr[1] "има само %2$lu реда във файла „%1$s“"
+
+#: builtin/blame.c:1125
+msgid "Blaming lines"
+msgstr "Редове с авторство"
+
+#: builtin/branch.c:29
+msgid "git branch [<options>] [-r | -a] [--merged | --no-merged]"
+msgstr "git branch [ОПЦИЯ…] [-r | -a] [--merged | --no-merged]"
+
+#: builtin/branch.c:30
+msgid "git branch [<options>] [-l] [-f] <branch-name> [<start-point>]"
+msgstr "git branch [ОПЦИЯ…] [-l] [-f] ИМЕ_НА_КЛОН [НАЧАЛО]"
+
+#: builtin/branch.c:31
+msgid "git branch [<options>] [-r] (-d | -D) <branch-name>..."
+msgstr "git branch [ОПЦИЯ…] [-r] (-d | -D) ИМЕ_НА_КЛОН…"
+
+#: builtin/branch.c:32
+msgid "git branch [<options>] (-m | -M) [<old-branch>] <new-branch>"
+msgstr "git branch [ОПЦИЯ…] (-m | -M) [СТАР_КЛОН] НОВ_КЛОН"
+
+#: builtin/branch.c:33
+msgid "git branch [<options>] (-c | -C) [<old-branch>] <new-branch>"
+msgstr "git branch [ОПЦИЯ…] (-c | -C) [СТАР_КЛОН] НОВ_КЛОН"
+
+#: builtin/branch.c:34
+msgid "git branch [<options>] [-r | -a] [--points-at]"
+msgstr "git branch [ОПЦИЯ…] [-r | -a] [--points-at]"
+
+#: builtin/branch.c:35
+msgid "git branch [<options>] [-r | -a] [--format]"
+msgstr "git branch [ОПЦИЯ…] [-r | -a] [--format]"
+
+#: builtin/branch.c:154
+#, c-format
+msgid ""
+"deleting branch '%s' that has been merged to\n"
+"         '%s', but not yet merged to HEAD."
+msgstr ""
+"изтриване на клона „%s“, който е слят към „%s“,\n"
+"    но още не е слят към върха „HEAD“."
+
+#: builtin/branch.c:158
+#, c-format
+msgid ""
+"not deleting branch '%s' that is not yet merged to\n"
+"         '%s', even though it is merged to HEAD."
+msgstr ""
+"отказване на изтриване на клона „%s“, който не е слят към\n"
+"    „%s“, но е слят към върха „HEAD“."
+
+#: builtin/branch.c:172
+#, c-format
+msgid "Couldn't look up commit object for '%s'"
+msgstr "Обектът-подаване за „%s“ не може да бъде открит"
+
+#: builtin/branch.c:176
+#, c-format
+msgid ""
+"The branch '%s' is not fully merged.\n"
+"If you are sure you want to delete it, run 'git branch -D %s'."
+msgstr ""
+"Клонът „%s“ не е слят напълно.  Ако сте сигурни, че искате\n"
+"да го изтриете, изпълнете „git branch -D %s“."
+
+#: builtin/branch.c:189
+msgid "Update of config-file failed"
+msgstr "Неуспешно обновяване на конфигурационния файл"
+
+#: builtin/branch.c:220
+msgid "cannot use -a with -d"
+msgstr "Опцията „-a“ е несъвместима с опцията „-d“"
+
+#: builtin/branch.c:226
+msgid "Couldn't look up commit object for HEAD"
+msgstr "Обектът-подаване, сочен от указателя „HEAD“, не може да бъде открит"
+
+#: builtin/branch.c:240
+#, c-format
+msgid "Cannot delete branch '%s' checked out at '%s'"
+msgstr "Не можете да изтриете клона „%s“, който е изтеглен в пътя „%s“"
+
+#: builtin/branch.c:255
+#, c-format
+msgid "remote-tracking branch '%s' not found."
+msgstr "следящият клон „%s“ не може да бъде открит."
+
+#: builtin/branch.c:256
+#, c-format
+msgid "branch '%s' not found."
+msgstr "клонът „%s“ не може да бъде открит."
+
+#: builtin/branch.c:271
+#, c-format
+msgid "Error deleting remote-tracking branch '%s'"
+msgstr "Грешка при изтриването на следящия клон „%s“"
+
+#: builtin/branch.c:272
+#, c-format
+msgid "Error deleting branch '%s'"
+msgstr "Грешка при изтриването на клона „%s“"
+
+#: builtin/branch.c:279
+#, c-format
+msgid "Deleted remote-tracking branch %s (was %s).\n"
+msgstr "Изтрит следящ клон „%s“ (той сочеше към „%s“).\n"
+
+#: builtin/branch.c:280
+#, c-format
+msgid "Deleted branch %s (was %s).\n"
+msgstr "Изтрит клон „%s“ (той сочеше към „%s“).\n"
+
+#: builtin/branch.c:429 builtin/tag.c:61
+msgid "unable to parse format string"
+msgstr "форматиращият низ не може да бъде анализиран: %s"
+
+#: builtin/branch.c:460
+msgid "could not resolve HEAD"
+msgstr "подаването, сочено от указателя „HEAD“, не може да се установи"
+
+#: builtin/branch.c:466
+#, c-format
+msgid "HEAD (%s) points outside of refs/heads/"
+msgstr "„HEAD“ (%s) сочи извън директорията „refs/heads“"
+
+#: builtin/branch.c:481
+#, c-format
+msgid "Branch %s is being rebased at %s"
+msgstr "Клонът „%s“ се пребазира върху „%s“"
+
+#: builtin/branch.c:485
+#, c-format
+msgid "Branch %s is being bisected at %s"
+msgstr "Търси се двоично в клона „%s“ при „%s“"
+
+#: builtin/branch.c:502
+msgid "cannot copy the current branch while not on any."
+msgstr "не можете да копирате текущия клон, защото сте извън който и да е клон"
+
+#: builtin/branch.c:504
+msgid "cannot rename the current branch while not on any."
+msgstr ""
+"не можете да преименувате текущия клон, защото сте извън който и да е клон"
+
+#: builtin/branch.c:515
+#, c-format
+msgid "Invalid branch name: '%s'"
+msgstr "Неправилно име на клон: „%s“"
+
+#: builtin/branch.c:542
+msgid "Branch rename failed"
+msgstr "Неуспешно преименуване на клон"
+
+#: builtin/branch.c:544
+msgid "Branch copy failed"
+msgstr "Неуспешно копиране на клон"
+
+#: builtin/branch.c:548
+#, c-format
+msgid "Created a copy of a misnamed branch '%s'"
+msgstr "Клонът с неправилно име „%s“ е копиран"
+
+#: builtin/branch.c:551
+#, c-format
+msgid "Renamed a misnamed branch '%s' away"
+msgstr "Клонът с неправилно име „%s“ е преименуван"
+
+#: builtin/branch.c:557
+#, c-format
+msgid "Branch renamed to %s, but HEAD is not updated!"
+msgstr "Клонът е преименуван на „%s“, но указателят „HEAD“ не е обновен"
+
+#: builtin/branch.c:566
+msgid "Branch is renamed, but update of config-file failed"
+msgstr "Клонът е преименуван, но конфигурационният файл не е обновен"
+
+#: builtin/branch.c:568
+msgid "Branch is copied, but update of config-file failed"
+msgstr "Клонът е копиран, но конфигурационният файл не е обновен"
+
+#: builtin/branch.c:584
+#, c-format
+msgid ""
+"Please edit the description for the branch\n"
+"  %s\n"
+"Lines starting with '%c' will be stripped.\n"
+msgstr ""
+"Въведете описание на клона.\n"
+"    %s\n"
+"Редовете, които започват с „%c“, ще бъдат пропуснати.\n"
+
+#: builtin/branch.c:618
+msgid "Generic options"
+msgstr "Общи настройки"
+
+#: builtin/branch.c:620
+msgid "show hash and subject, give twice for upstream branch"
+msgstr ""
+"извеждане на контролната сума и темата.  Повтарянето на опцията прибавя "
+"отдалечените клони"
+
+#: builtin/branch.c:621
+msgid "suppress informational messages"
+msgstr "без информационни съобщения"
+
+#: builtin/branch.c:622
+msgid "set up tracking mode (see git-pull(1))"
+msgstr "задаване на режима на следене (виж git-pull(1))"
+
+#: builtin/branch.c:624
+msgid "do not use"
+msgstr "да не се ползва"
+
+#: builtin/branch.c:626 builtin/rebase.c:505
+msgid "upstream"
+msgstr "клон-източник"
+
+#: builtin/branch.c:626
+msgid "change the upstream info"
+msgstr "смяна на клона-източник"
+
+#: builtin/branch.c:627
+msgid "unset the upstream info"
+msgstr "изчистване на информацията за клон-източник"
+
+#: builtin/branch.c:628
+msgid "use colored output"
+msgstr "цветен изход"
+
+#: builtin/branch.c:629
+msgid "act on remote-tracking branches"
+msgstr "действие върху следящите клони"
+
+#: builtin/branch.c:631 builtin/branch.c:633
+msgid "print only branches that contain the commit"
+msgstr "извеждане само на клоните, които съдържат това ПОДАВАНЕ"
+
+#: builtin/branch.c:632 builtin/branch.c:634
+msgid "print only branches that don't contain the commit"
+msgstr "извеждане само на клоните, които не съдържат това ПОДАВАНЕ"
+
+#: builtin/branch.c:637
+msgid "Specific git-branch actions:"
+msgstr "Специални действия на „git-branch“:"
+
+#: builtin/branch.c:638
+msgid "list both remote-tracking and local branches"
+msgstr "извеждане както на следящите, така и на локалните клони"
+
+#: builtin/branch.c:640
+msgid "delete fully merged branch"
+msgstr "изтриване на клони, които са напълно слети"
+
+#: builtin/branch.c:641
+msgid "delete branch (even if not merged)"
+msgstr "изтриване и на клони, които не са напълно слети"
+
+#: builtin/branch.c:642
+msgid "move/rename a branch and its reflog"
+msgstr ""
+"преместване/преименуване на клон и принадлежащият му журнал на указателите"
+
+#: builtin/branch.c:643
+msgid "move/rename a branch, even if target exists"
+msgstr "преместване/преименуване на клон, дори ако има вече клон с такова име"
+
+#: builtin/branch.c:644
+msgid "copy a branch and its reflog"
+msgstr "копиране на клон и принадлежащия му журнал на указателите"
+
+#: builtin/branch.c:645
+msgid "copy a branch, even if target exists"
+msgstr "копиране на клон, дори ако има вече клон с такова име"
+
+#: builtin/branch.c:646
+msgid "list branch names"
+msgstr "извеждане на имената на клоните"
+
+#: builtin/branch.c:647
+msgid "show current branch name"
+msgstr "извеждане на името на текущия клон"
+
+#: builtin/branch.c:648
+msgid "create the branch's reflog"
+msgstr "създаване на журнала на указателите на клона"
+
+#: builtin/branch.c:650
+msgid "edit the description for the branch"
+msgstr "редактиране на описанието на клона"
+
+#: builtin/branch.c:651
+msgid "force creation, move/rename, deletion"
+msgstr "принудително създаване, преместване, преименуване, изтриване"
+
+#: builtin/branch.c:652
+msgid "print only branches that are merged"
+msgstr "извеждане само на слетите клони"
+
+#: builtin/branch.c:653
+msgid "print only branches that are not merged"
+msgstr "извеждане само на неслетите клони"
+
+#: builtin/branch.c:654
+msgid "list branches in columns"
+msgstr "извеждане по колони"
+
+#: builtin/branch.c:657 builtin/for-each-ref.c:42 builtin/notes.c:415
+#: builtin/notes.c:418 builtin/notes.c:581 builtin/notes.c:584
+#: builtin/tag.c:433
+msgid "object"
+msgstr "ОБЕКТ"
+
+#: builtin/branch.c:658
+msgid "print only branches of the object"
+msgstr "извеждане само на клоните на ОБЕКТА"
+
+#: builtin/branch.c:660 builtin/for-each-ref.c:48 builtin/tag.c:440
+msgid "sorting and filtering are case insensitive"
+msgstr "подредбата и филтрирането третират еднакво малките и главните букви"
+
+#: builtin/branch.c:661 builtin/for-each-ref.c:38 builtin/tag.c:438
+#: builtin/verify-tag.c:38
+msgid "format to use for the output"
+msgstr "ФОРМАТ за изхода"
+
+#: builtin/branch.c:684 builtin/clone.c:784
+msgid "HEAD not found below refs/heads!"
+msgstr "В директорията „refs/heads“ липсва файл „HEAD“"
+
+#: builtin/branch.c:708
+msgid "--column and --verbose are incompatible"
+msgstr "Опциите „--column“ и „--verbose“ са несъвместими"
+
+#: builtin/branch.c:723 builtin/branch.c:777 builtin/branch.c:786
+msgid "branch name required"
+msgstr "Необходимо е име на клон"
+
+#: builtin/branch.c:753
+msgid "Cannot give description to detached HEAD"
+msgstr "Не може да зададете описание на несвързан „HEAD“"
+
+#: builtin/branch.c:758
+msgid "cannot edit description of more than one branch"
+msgstr "Не може да редактирате описанието на повече от един клон едновременно"
+
+#: builtin/branch.c:765
+#, c-format
+msgid "No commit on branch '%s' yet."
+msgstr "В клона „%s“ все още няма подавания."
+
+#: builtin/branch.c:768
+#, c-format
+msgid "No branch named '%s'."
+msgstr "Липсва клон на име „%s“."
+
+#: builtin/branch.c:783
+msgid "too many branches for a copy operation"
+msgstr "прекалено много клони за копиране"
+
+#: builtin/branch.c:792
+msgid "too many arguments for a rename operation"
+msgstr "прекалено много аргументи към командата за преименуване"
+
+#: builtin/branch.c:797
+msgid "too many arguments to set new upstream"
+msgstr "прекалено много аргументи към командата за следене"
+
+#: builtin/branch.c:801
+#, c-format
+msgid ""
+"could not set upstream of HEAD to %s when it does not point to any branch."
+msgstr ""
+"Следеното от „HEAD“ не може да се зададе да е „%s“, защото то не сочи към "
+"никой клон."
+
+#: builtin/branch.c:804 builtin/branch.c:827
+#, c-format
+msgid "no such branch '%s'"
+msgstr "Няма клон на име „%s“."
+
+#: builtin/branch.c:808
+#, c-format
+msgid "branch '%s' does not exist"
+msgstr "Не съществува клон на име „%s“."
+
+#: builtin/branch.c:821
+msgid "too many arguments to unset upstream"
+msgstr "прекалено много аргументи към командата за спиране на следене"
+
+#: builtin/branch.c:825
+msgid "could not unset upstream of HEAD when it does not point to any branch."
+msgstr ""
+"Следеното от „HEAD“ не може да махне, защото то не сочи към никой клон."
+
+#: builtin/branch.c:831
+#, c-format
+msgid "Branch '%s' has no upstream information"
+msgstr "Няма информация клонът „%s“ да следи някой друг"
+
+#: builtin/branch.c:841
+msgid ""
+"The -a, and -r, options to 'git branch' do not take a branch name.\n"
+"Did you mean to use: -a|-r --list <pattern>?"
+msgstr ""
+"Опциите „-a“ и „-r“ на „git branch“ са несъвместими с име на клон.\n"
+"Пробвайте с: „-a|-r --list ШАБЛОН“"
+
+#: builtin/branch.c:845
+msgid ""
+"the '--set-upstream' option is no longer supported. Please use '--track' or "
+"'--set-upstream-to' instead."
+msgstr ""
+"Опцията „--set-upstream“ вече не се поддържа.  Използвайте „--track“ или „--"
+"set-upstream-to“"
+
+#: builtin/bundle.c:15 builtin/bundle.c:23
+msgid "git bundle create [<options>] <file> <git-rev-list args>"
+msgstr "git bundle create [ОПЦИЯ…] ФАЙЛ АРГУМЕНТ_ЗА_git_rev-list…"
+
+#: builtin/bundle.c:16 builtin/bundle.c:28
+msgid "git bundle verify [<options>] <file>"
+msgstr "git bundle verify [ОПЦИЯ…] ФАЙЛ…"
+
+#: builtin/bundle.c:17 builtin/bundle.c:33
+msgid "git bundle list-heads <file> [<refname>...]"
+msgstr "git bundle list-heads ФАЙЛ [ИМЕ_НА_УКАЗАТЕЛ…]"
+
+#: builtin/bundle.c:18 builtin/bundle.c:38
+msgid "git bundle unbundle <file> [<refname>...]"
+msgstr "git bundle unbundle ФАЙЛ [ИМЕ_НА_УКАЗАТЕЛ…]"
+
+#: builtin/bundle.c:66 builtin/pack-objects.c:3228
+msgid "do not show progress meter"
+msgstr "без извеждане на напредъка"
+
+#: builtin/bundle.c:68 builtin/pack-objects.c:3230
+msgid "show progress meter"
+msgstr "извеждане на напредъка"
+
+#: builtin/bundle.c:70 builtin/pack-objects.c:3232
+msgid "show progress meter during object writing phase"
+msgstr "извеждане на напредъка във фазата на запазване на обектите"
+
+#: builtin/bundle.c:73 builtin/pack-objects.c:3235
+msgid "similar to --all-progress when progress meter is shown"
+msgstr ""
+"същото действие като опцията „--all-progress“ при извеждането на напредъка"
+
+#: builtin/bundle.c:93
+msgid "Need a repository to create a bundle."
+msgstr "За създаването на пратка е необходимо хранилище."
+
+#: builtin/bundle.c:104
+msgid "do not show bundle details"
+msgstr "без подробна информация за пратките"
+
+#: builtin/bundle.c:119
+#, c-format
+msgid "%s is okay\n"
+msgstr "Пратката „%s“ е наред\n"
+
+#: builtin/bundle.c:160
+msgid "Need a repository to unbundle."
+msgstr "За приемането на пратка е необходимо хранилище."
+
+#: builtin/bundle.c:168 builtin/remote.c:1609
+msgid "be verbose; must be placed before a subcommand"
+msgstr "повече подробности.  Поставя се пред подкоманда"
+
+#: builtin/bundle.c:190 builtin/remote.c:1640
+#, c-format
+msgid "Unknown subcommand: %s"
+msgstr "Непозната подкоманда: %s"
+
+#: builtin/cat-file.c:595
+msgid ""
+"git cat-file (-t [--allow-unknown-type] | -s [--allow-unknown-type] | -e | -"
+"p | <type> | --textconv | --filters) [--path=<path>] <object>"
+msgstr ""
+"git cat-file (-t [--allow-unknown-type] | -s [--allow-unknown-type] | -e | -"
+"p | ВИД | --textconv --filters) [--path=ПЪТ] ОБЕКТ"
+
+#: builtin/cat-file.c:596
+msgid ""
+"git cat-file (--batch | --batch-check) [--follow-symlinks] [--textconv | --"
+"filters]"
+msgstr ""
+"git cat-file (--batch | --batch-check) [--follow-symlinks] [--textconv | --"
+"filters]"
+
+#: builtin/cat-file.c:617
+msgid "only one batch option may be specified"
+msgstr "може да укажете само една пакетна опция"
+
+#: builtin/cat-file.c:635
+msgid "<type> can be one of: blob, tree, commit, tag"
+msgstr ""
+"ВИДът може да е: „blob“ (BLOB), „tree“ (дърво), „commit“ (подаване), "
+"„tag“ (етикет)"
+
+#: builtin/cat-file.c:636
+msgid "show object type"
+msgstr "извеждане на вида на обект"
+
+#: builtin/cat-file.c:637
+msgid "show object size"
+msgstr "извеждане на размера на обект"
+
+#: builtin/cat-file.c:639
+msgid "exit with zero when there's no error"
+msgstr "изход с 0, когато няма грешка"
+
+#: builtin/cat-file.c:640
+msgid "pretty-print object's content"
+msgstr "форматирано извеждане на съдържанието на обекта"
+
+#: builtin/cat-file.c:642
+msgid "for blob objects, run textconv on object's content"
+msgstr ""
+"да се стартира програмата зададена в настройката „textconv“ за преобразуване "
+"на съдържанието на обекта-BLOB"
+
+#: builtin/cat-file.c:644
+msgid "for blob objects, run filters on object's content"
+msgstr ""
+"да се стартират програмите за преобразуване на съдържанието на обектите-BLOB"
+
+#: builtin/cat-file.c:645 git-submodule.sh:992
+msgid "blob"
+msgstr "обект-BLOB"
+
+#: builtin/cat-file.c:646
+msgid "use a specific path for --textconv/--filters"
+msgstr "опциите „--textconv“/„--filters“ изискват път"
+
+#: builtin/cat-file.c:648
+msgid "allow -s and -t to work with broken/corrupt objects"
+msgstr "позволяване на опциите „-s“ и „-t“ да работят с повредени обекти"
+
+#: builtin/cat-file.c:649
+msgid "buffer --batch output"
+msgstr "буфериране на изхода от „--batch“"
+
+#: builtin/cat-file.c:651
+msgid "show info and content of objects fed from the standard input"
+msgstr ""
+"извеждане на информация и съдържание на обектите подадени на стандартния вход"
+
+#: builtin/cat-file.c:655
+msgid "show info about objects fed from the standard input"
+msgstr "извеждане на информация за обектите подадени на стандартния вход"
+
+#: builtin/cat-file.c:659
+msgid "follow in-tree symlinks (used with --batch or --batch-check)"
+msgstr ""
+"следване на символните връзки сочещи в дървото (ползва се с „--batch“ или „--"
+"batch-check“)"
+
+#: builtin/cat-file.c:661
+msgid "show all objects with --batch or --batch-check"
+msgstr "извеждане на всички обекти с „--batch“ или „--batch-check“"
+
+#: builtin/cat-file.c:663
+msgid "do not order --batch-all-objects output"
+msgstr "без подреждане на изхода от „--batch-all-objects“"
+
+#: builtin/check-attr.c:13
+msgid "git check-attr [-a | --all | <attr>...] [--] <pathname>..."
+msgstr "git check-attr [-a | --all | АТРИБУТ…] [--] ПЪТ…"
+
+#: builtin/check-attr.c:14
+msgid "git check-attr --stdin [-z] [-a | --all | <attr>...]"
+msgstr "git check-attr --stdin [-z] [-a | --all | АТРИБУТ…]"
+
+#: builtin/check-attr.c:21
+msgid "report all attributes set on file"
+msgstr "извеждане на всички атрибути, зададени върху файл"
+
+#: builtin/check-attr.c:22
+msgid "use .gitattributes only from the index"
+msgstr "използване на файла „.gitattributes“ само от индекса"
+
+#: builtin/check-attr.c:23 builtin/check-ignore.c:25 builtin/hash-object.c:102
+msgid "read file names from stdin"
+msgstr "изчитане на имената на файловете от стандартния вход"
+
+#: builtin/check-attr.c:25 builtin/check-ignore.c:27
+msgid "terminate input and output records by a NUL character"
+msgstr "разделяне на входните и изходните записи с нулевия знак „NUL“"
+
+#: builtin/check-ignore.c:21 builtin/checkout.c:1435 builtin/gc.c:537
+#: builtin/worktree.c:506
+msgid "suppress progress reporting"
+msgstr "без показване на напредъка"
+
+#: builtin/check-ignore.c:29
+msgid "show non-matching input paths"
+msgstr "извеждане на несъвпадащите пътища"
+
+#: builtin/check-ignore.c:31
+msgid "ignore index when checking"
+msgstr "прескачане на индекса при проверката"
+
+#: builtin/check-ignore.c:160
+msgid "cannot specify pathnames with --stdin"
+msgstr "опцията „--stdin“ е несъвместима с имена на пътища"
+
+#: builtin/check-ignore.c:163
+msgid "-z only makes sense with --stdin"
+msgstr "опцията „-z“ изисква „--stdin“"
+
+#: builtin/check-ignore.c:165
+msgid "no path specified"
+msgstr "не е зададен път"
+
+#: builtin/check-ignore.c:169
+msgid "--quiet is only valid with a single pathname"
+msgstr "опцията „--quiet“ изисква да е подаден точно един път"
+
+#: builtin/check-ignore.c:171
+msgid "cannot have both --quiet and --verbose"
+msgstr "опциите „--quiet“ и „--verbose“ са несъвместими"
+
+#: builtin/check-ignore.c:174
+msgid "--non-matching is only valid with --verbose"
+msgstr "опцията „--non-matching“ изисква „--verbose“"
+
+#: builtin/check-mailmap.c:9
+msgid "git check-mailmap [<options>] <contact>..."
+msgstr "git check-mailmap [ОПЦИЯ…] КОНТАКТ…"
+
+#: builtin/check-mailmap.c:14
+msgid "also read contacts from stdin"
+msgstr "четене на контакти и от стандартния вход"
+
+#: builtin/check-mailmap.c:25
+#, c-format
+msgid "unable to parse contact: %s"
+msgstr "контактът не може да бъде анализиран: %s"
+
+#: builtin/check-mailmap.c:48
+msgid "no contacts specified"
+msgstr "не са указани контакти"
+
+#: builtin/checkout-index.c:131
+msgid "git checkout-index [<options>] [--] [<file>...]"
+msgstr "git checkout-index [ОПЦИЯ…] [--] [ФАЙЛ…]"
+
+#: builtin/checkout-index.c:148
+msgid "stage should be between 1 and 3 or all"
+msgstr "етапът трябва да е „1“, „2“, „3“ или „all“ (всички)"
+
+#: builtin/checkout-index.c:164
+msgid "check out all files in the index"
+msgstr "изтегляне на всички файлове в индекса"
+
+#: builtin/checkout-index.c:165
+msgid "force overwrite of existing files"
+msgstr "презаписване на файловете, дори и да съществуват"
+
+#: builtin/checkout-index.c:167
+msgid "no warning for existing files and files not in index"
+msgstr "без предупреждения при липсващи файлове и файлове не в индекса"
+
+#: builtin/checkout-index.c:169
+msgid "don't checkout new files"
+msgstr "без изтегляне на нови файлове"
+
+#: builtin/checkout-index.c:171
+msgid "update stat information in the index file"
+msgstr "обновяване на информацията получена чрез „stat“ за файловете в индекса"
+
+#: builtin/checkout-index.c:175
+msgid "read list of paths from the standard input"
+msgstr "изчитане на пътищата от стандартния вход"
+
+#: builtin/checkout-index.c:177
+msgid "write the content to temporary files"
+msgstr "записване на съдържанието във временни файлове"
+
+#: builtin/checkout-index.c:178 builtin/column.c:31
+#: builtin/submodule--helper.c:1385 builtin/submodule--helper.c:1388
+#: builtin/submodule--helper.c:1396 builtin/submodule--helper.c:1882
+#: builtin/worktree.c:679
+msgid "string"
+msgstr "НИЗ"
+
+#: builtin/checkout-index.c:179
+msgid "when creating files, prepend <string>"
+msgstr "при създаването на нови файлове да се добавя префикса НИЗ"
+
+#: builtin/checkout-index.c:181
+msgid "copy out the files from named stage"
+msgstr "копиране на файловете от това състояние на сливане"
+
+#: builtin/checkout.c:31
+msgid "git checkout [<options>] <branch>"
+msgstr "git checkout [ОПЦИЯ…] КЛОН"
+
+#: builtin/checkout.c:32
+msgid "git checkout [<options>] [<branch>] -- <file>..."
+msgstr "git checkout [ОПЦИЯ…] [КЛОН] -- ФАЙЛ…"
+
+#: builtin/checkout.c:37
+msgid "git switch [<options>] [<branch>]"
+msgstr "git switch [ОПЦИЯ…] КЛОН"
+
+#: builtin/checkout.c:42
+msgid "git restore [<options>] [--source=<branch>] <file>..."
+msgstr "git restore [ОПЦИЯ…] [--source=КЛОН] ФАЙЛ…"
+
+#: builtin/checkout.c:175 builtin/checkout.c:214
+#, c-format
+msgid "path '%s' does not have our version"
+msgstr "вашата версия липсва в пътя „%s“"
+
+#: builtin/checkout.c:177 builtin/checkout.c:216
+#, c-format
+msgid "path '%s' does not have their version"
+msgstr "чуждата версия липсва в пътя „%s“"
+
+#: builtin/checkout.c:193
+#, c-format
+msgid "path '%s' does not have all necessary versions"
+msgstr "някоя от необходимите версии липсва в пътя „%s“"
+
+#: builtin/checkout.c:243
+#, c-format
+msgid "path '%s' does not have necessary versions"
+msgstr "някоя от необходимите версии липсва в пътя „%s“"
+
+#: builtin/checkout.c:261
+#, c-format
+msgid "path '%s': cannot merge"
+msgstr "пътят „%s“ не може да бъде слян"
+
+#: builtin/checkout.c:277
+#, c-format
+msgid "Unable to add merge result for '%s'"
+msgstr "Резултатът за „%s“ не може да бъде слян"
+
+#: builtin/checkout.c:377
+#, c-format
+msgid "Recreated %d merge conflict"
+msgid_plural "Recreated %d merge conflicts"
+msgstr[0] "Пресъздаден е %d конфликт при сливане"
+msgstr[1] "Пресъздадени са %d конфликта при сливане"
+
+#: builtin/checkout.c:382
+#, c-format
+msgid "Updated %d path from %s"
+msgid_plural "Updated %d paths from %s"
+msgstr[0] "Обновен е %d път от „%s“"
+msgstr[1] "Обновени са %d пътя от „%s“"
+
+#: builtin/checkout.c:389
+#, c-format
+msgid "Updated %d path from the index"
+msgid_plural "Updated %d paths from the index"
+msgstr[0] "Обновен е %d път от индекса"
+msgstr[1] "Обновени са %d пътя от индекса"
+
+#: builtin/checkout.c:412 builtin/checkout.c:415 builtin/checkout.c:418
+#: builtin/checkout.c:422
+#, c-format
+msgid "'%s' cannot be used with updating paths"
+msgstr "опцията „%s“ е несъвместима с обновяването на пътища"
+
+#: builtin/checkout.c:425 builtin/checkout.c:428
+#, c-format
+msgid "'%s' cannot be used with %s"
+msgstr "опцията „%s“ е несъвместима с „%s“"
+
+#: builtin/checkout.c:432
+#, c-format
+msgid "Cannot update paths and switch to branch '%s' at the same time."
+msgstr ""
+"Невъзможно е едновременно да обновявате пътища и да преминете към клона „%s“."
+
+#: builtin/checkout.c:436
+#, c-format
+msgid "neither '%s' or '%s' is specified"
+msgstr "не е указано нито „%s“, нито „%s“"
+
+#: builtin/checkout.c:440
+#, c-format
+msgid "'%s' must be used when '%s' is not specified"
+msgstr "опцията „%s“ е задължителна, когато „%s“ не е зададена"
+
+#: builtin/checkout.c:445 builtin/checkout.c:450
+#, c-format
+msgid "'%s' or '%s' cannot be used with %s"
+msgstr "опцията „%3$s“ е несъвместима както с „%1$s“, така и с „%2$s“"
+
+#: builtin/checkout.c:509 builtin/checkout.c:516
+#, c-format
+msgid "path '%s' is unmerged"
+msgstr "пътят „%s“ не е слят"
+
+#: builtin/checkout.c:682 builtin/sparse-checkout.c:103
+msgid "you need to resolve your current index first"
+msgstr "първо трябва да коригирате индекса си"
+
+#: builtin/checkout.c:732
+#, c-format
+msgid ""
+"cannot continue with staged changes in the following files:\n"
+"%s"
+msgstr ""
+"не може да се продължи с промени в следните файлове, които са добавени в "
+"индекса:\n"
+"%s"
+
+#: builtin/checkout.c:835
+#, c-format
+msgid "Can not do reflog for '%s': %s\n"
+msgstr "Журналът на указателите за „%s“ не може да се проследи: %s\n"
+
+#: builtin/checkout.c:877
+msgid "HEAD is now at"
+msgstr "Указателят „HEAD“ в момента сочи към"
+
+#: builtin/checkout.c:881 builtin/clone.c:716
+msgid "unable to update HEAD"
+msgstr "Указателят „HEAD“ не може да бъде обновен"
+
+#: builtin/checkout.c:885
+#, c-format
+msgid "Reset branch '%s'\n"
+msgstr "Зануляване на клона „%s“\n"
+
+#: builtin/checkout.c:888
+#, c-format
+msgid "Already on '%s'\n"
+msgstr "Вече сте на „%s“\n"
+
+#: builtin/checkout.c:892
+#, c-format
+msgid "Switched to and reset branch '%s'\n"
+msgstr "Преминаване към клона „%s“ и зануляване на промените\n"
+
+#: builtin/checkout.c:894 builtin/checkout.c:1291
+#, c-format
+msgid "Switched to a new branch '%s'\n"
+msgstr "Преминахте към новия клон „%s“\n"
+
+#: builtin/checkout.c:896
+#, c-format
+msgid "Switched to branch '%s'\n"
+msgstr "Преминахте към клона „%s“\n"
+
+#: builtin/checkout.c:947
+#, c-format
+msgid " ... and %d more.\n"
+msgstr "… и още %d.\n"
+
+#: builtin/checkout.c:953
+#, c-format
+msgid ""
+"Warning: you are leaving %d commit behind, not connected to\n"
+"any of your branches:\n"
+"\n"
+"%s\n"
+msgid_plural ""
+"Warning: you are leaving %d commits behind, not connected to\n"
+"any of your branches:\n"
+"\n"
+"%s\n"
+msgstr[0] ""
+"ПРЕДУПРЕЖДЕНИЕ: изоставяте %d подаване, което не е свързано към никой клон:\n"
+"\n"
+"%s\n"
+msgstr[1] ""
+"ПРЕДУПРЕЖДЕНИЕ: изоставяте %d подавания, които не са свързани към никой "
+"клон:\n"
+"\n"
+"%s\n"
+
+#: builtin/checkout.c:972
+#, c-format
+msgid ""
+"If you want to keep it by creating a new branch, this may be a good time\n"
+"to do so with:\n"
+"\n"
+" git branch <new-branch-name> %s\n"
+"\n"
+msgid_plural ""
+"If you want to keep them by creating a new branch, this may be a good time\n"
+"to do so with:\n"
+"\n"
+" git branch <new-branch-name> %s\n"
+"\n"
+msgstr[0] ""
+"Ако все пак искате да запазите тази промяна чрез създаване на клон,\n"
+"сега е най-подходящият за това чрез командата:\n"
+"\n"
+"    git branch ИМЕ_НА_НОВИЯ_КЛОН %s\n"
+"\n"
+msgstr[1] ""
+"Ако все пак искате да запазите тези промени чрез създаване на клон,\n"
+"сега е най-подходящият за това чрез командата:\n"
+"\n"
+"    git branch ИМЕ_НА_НОВИЯ_КЛОН %s\n"
+"\n"
+
+#: builtin/checkout.c:1007
+msgid "internal error in revision walk"
+msgstr "вътрешна грешка при обхождането на версиите"
+
+#: builtin/checkout.c:1011
+msgid "Previous HEAD position was"
+msgstr "Преди това „HEAD“ сочеше към"
+
+#: builtin/checkout.c:1051 builtin/checkout.c:1286
+msgid "You are on a branch yet to be born"
+msgstr "В момента сте на клон, който все още не е създаден"
+
+#: builtin/checkout.c:1178
+msgid "only one reference expected"
+msgstr "очаква се само един указател"
+
+#: builtin/checkout.c:1195
+#, c-format
+msgid "only one reference expected, %d given."
+msgstr "очаква се един указател, а сте подали %d."
+
+#: builtin/checkout.c:1232
+#, c-format
+msgid ""
+"'%s' could be both a local file and a tracking branch.\n"
+"Please use -- (and optionally --no-guess) to disambiguate"
+msgstr ""
+"„%s“ може да е както локален файл, така и следящ клон.  За уточняване\n"
+"ползвайте разделителя „--“ (и евентуално опцията „--no-guess“)"
+
+#: builtin/checkout.c:1245 builtin/worktree.c:290 builtin/worktree.c:455
+#, c-format
+msgid "invalid reference: %s"
+msgstr "неправилен указател: %s"
+
+#: builtin/checkout.c:1258 builtin/checkout.c:1622
+#, c-format
+msgid "reference is not a tree: %s"
+msgstr "указателят не сочи към обект-дърво: %s"
+
+#: builtin/checkout.c:1305
+#, c-format
+msgid "a branch is expected, got tag '%s'"
+msgstr "очаква се клон, а не етикет — „%s“"
+
+#: builtin/checkout.c:1307
+#, c-format
+msgid "a branch is expected, got remote branch '%s'"
+msgstr "очаква се локален, а не отдалечен клон — „%s“"
+
+#: builtin/checkout.c:1308 builtin/checkout.c:1316
+#, c-format
+msgid "a branch is expected, got '%s'"
+msgstr "очаква се клон, а не „%s“"
+
+#: builtin/checkout.c:1311
+#, c-format
+msgid "a branch is expected, got commit '%s'"
+msgstr "очаква се клон, а не подаване — „%s“"
+
+#: builtin/checkout.c:1327
+msgid ""
+"cannot switch branch while merging\n"
+"Consider \"git merge --quit\" or \"git worktree add\"."
+msgstr ""
+"по време на сливане не може да преминете към друг клон.\n"
+"Пробвайте с „git merge --quit“ или „git worktree add“."
+
+#: builtin/checkout.c:1331
+msgid ""
+"cannot switch branch in the middle of an am session\n"
+"Consider \"git am --quit\" or \"git worktree add\"."
+msgstr ""
+"по време на прилагане на поредица от кръпки не може да преминете към друг "
+"клон.\n"
+"Пробвайте с „git am --quit“ или „git worktree add“."
+
+#: builtin/checkout.c:1335
+msgid ""
+"cannot switch branch while rebasing\n"
+"Consider \"git rebase --quit\" or \"git worktree add\"."
+msgstr ""
+"по време на пребазиране не може да преминете към друг клон.\n"
+"Пробвайте с „git rebase --quit“ или „git worktree add“."
+
+#: builtin/checkout.c:1339
+msgid ""
+"cannot switch branch while cherry-picking\n"
+"Consider \"git cherry-pick --quit\" or \"git worktree add\"."
+msgstr ""
+"по време на отбиране на подавания не може да преминете към друг клон.\n"
+"Пробвайте с „git cherry-pick --quit“ или „git worktree add“."
+
+#: builtin/checkout.c:1343
+msgid ""
+"cannot switch branch while reverting\n"
+"Consider \"git revert --quit\" or \"git worktree add\"."
+msgstr ""
+"по време на отмяна на подавания не може да преминете към друг клон.\n"
+"Пробвайте с „git revert --quit“ или „git worktree add“."
+
+#: builtin/checkout.c:1347
+msgid "you are switching branch while bisecting"
+msgstr "преминаване към друг клон по време на двоично търсене"
+
+#: builtin/checkout.c:1354
+msgid "paths cannot be used with switching branches"
+msgstr "задаването на път е несъвместимо с преминаването от един клон към друг"
+
+#: builtin/checkout.c:1357 builtin/checkout.c:1361 builtin/checkout.c:1365
+#, c-format
+msgid "'%s' cannot be used with switching branches"
+msgstr "опцията „%s“ е несъвместима с преминаването от един клон към друг"
+
+#: builtin/checkout.c:1369 builtin/checkout.c:1372 builtin/checkout.c:1375
+#: builtin/checkout.c:1380 builtin/checkout.c:1385
+#, c-format
+msgid "'%s' cannot be used with '%s'"
+msgstr "опцията „%s“ е несъвместима с „%s“"
+
+#: builtin/checkout.c:1382
+#, c-format
+msgid "'%s' cannot take <start-point>"
+msgstr "опцията „%s“ е несъвместима със задаването на НАЧАЛО"
+
+#: builtin/checkout.c:1390
+#, c-format
+msgid "Cannot switch branch to a non-commit '%s'"
+msgstr ""
+"За да преминете към клон, подайте указател, който сочи към подаване.  „%s“ "
+"не е такъв"
+
+#: builtin/checkout.c:1397
+msgid "missing branch or commit argument"
+msgstr "липсва аргумент — клон или подаване"
+
+#: builtin/checkout.c:1439 builtin/clone.c:91 builtin/commit-graph.c:52
+#: builtin/commit-graph.c:113 builtin/fetch.c:167 builtin/merge.c:285
+#: builtin/multi-pack-index.c:27 builtin/pull.c:138 builtin/push.c:563
+#: builtin/send-pack.c:174
+msgid "force progress reporting"
+msgstr "извеждане на напредъка"
+
+#: builtin/checkout.c:1440
+msgid "perform a 3-way merge with the new branch"
+msgstr "извършване на тройно сливане с новия клон"
+
+#: builtin/checkout.c:1441 builtin/log.c:1690 parse-options.h:322
+msgid "style"
+msgstr "СТИЛ"
+
+#: builtin/checkout.c:1442
+msgid "conflict style (merge or diff3)"
+msgstr "действие при конфликт (сливане или тройна разлика)"
+
+#: builtin/checkout.c:1454 builtin/worktree.c:503
+msgid "detach HEAD at named commit"
+msgstr "отделяне на указателя „HEAD“ към указаното подаване"
+
+#: builtin/checkout.c:1455
+msgid "set upstream info for new branch"
+msgstr "задаване на кой клон бива следен при създаването на новия клон"
+
+#: builtin/checkout.c:1457
+msgid "force checkout (throw away local modifications)"
+msgstr "принудително изтегляне (вашите промени ще бъдат занулени)"
+
+#: builtin/checkout.c:1459
+msgid "new-branch"
+msgstr "НОВ_КЛОН"
+
+#: builtin/checkout.c:1459
+msgid "new unparented branch"
+msgstr "нов клон без родител"
+
+#: builtin/checkout.c:1461 builtin/merge.c:288
+msgid "update ignored files (default)"
+msgstr "обновяване на игнорираните файлове (стандартно)"
+
+#: builtin/checkout.c:1464
+msgid "do not check if another worktree is holding the given ref"
+msgstr "без проверка дали друго работно дърво държи указателя"
+
+#: builtin/checkout.c:1477
+msgid "checkout our version for unmerged files"
+msgstr "изтегляне на вашата версия на неслетите файлове"
+
+#: builtin/checkout.c:1480
+msgid "checkout their version for unmerged files"
+msgstr "изтегляне на чуждата версия на неслетите файлове"
+
+#: builtin/checkout.c:1484
+msgid "do not limit pathspecs to sparse entries only"
+msgstr "без ограничаване на изброените пътища само до частично изтеглените"
+
+#: builtin/checkout.c:1537
+msgid "-b, -B and --orphan are mutually exclusive"
+msgstr "Опциите „-b“, „-B“ и „--orphan“ са несъвместими една с друга"
+
+#: builtin/checkout.c:1540
+msgid "-p and --overlay are mutually exclusive"
+msgstr "опциите „-p“ и „--overlay“ са несъвместими"
+
+#: builtin/checkout.c:1577
+msgid "--track needs a branch name"
+msgstr "опцията „--track“ изисква име на клон"
+
+#: builtin/checkout.c:1582
+msgid "missing branch name; try -b"
+msgstr "липсва име на клон, използвайте опцията „-b“"
+
+#: builtin/checkout.c:1615
+#, c-format
+msgid "could not resolve %s"
+msgstr "„%s“ не може да бъде открит"
+
+#: builtin/checkout.c:1631
+msgid "invalid path specification"
+msgstr "указан е неправилен път"
+
+#: builtin/checkout.c:1638
+#, c-format
+msgid "'%s' is not a commit and a branch '%s' cannot be created from it"
+msgstr "„%s“ не е подаване, затова от него не може да се създаде клон „%s“"
+
+#: builtin/checkout.c:1642
+#, c-format
+msgid "git checkout: --detach does not take a path argument '%s'"
+msgstr "git checkout: опцията „--detach“ не приема аргумент-път „%s“"
+
+#: builtin/checkout.c:1651
+msgid "--pathspec-from-file is incompatible with --detach"
+msgstr "опциите „--pathspec-from-file“ и „--detach“ са несъвместими"
+
+#: builtin/checkout.c:1654 builtin/reset.c:324
+msgid "--pathspec-from-file is incompatible with --patch"
+msgstr "опциите „--pathspec-from-file“ и „--patch“ са несъвместими"
+
+#: builtin/checkout.c:1665
+msgid ""
+"git checkout: --ours/--theirs, --force and --merge are incompatible when\n"
+"checking out of the index."
+msgstr ""
+"git checkout: опциите „--ours“/„--theirs“, „--force“ и „--merge“\n"
+"са несъвместими с изтегляне от индекса."
+
+#: builtin/checkout.c:1670
+msgid "you must specify path(s) to restore"
+msgstr "трябва да укажете поне един път за възстановяване"
+
+#: builtin/checkout.c:1689
+#, c-format
+msgid ""
+"'%s' matched more than one remote tracking branch.\n"
+"We found %d remotes with a reference that matched. So we fell back\n"
+"on trying to resolve the argument as a path, but failed there too!\n"
+"\n"
+"If you meant to check out a remote tracking branch on, e.g. 'origin',\n"
+"you can do so by fully qualifying the name with the --track option:\n"
+"\n"
+"    git checkout --track origin/<name>\n"
+"\n"
+"If you'd like to always have checkouts of an ambiguous <name> prefer\n"
+"one remote, e.g. the 'origin' remote, consider setting\n"
+"checkout.defaultRemote=origin in your config."
+msgstr ""
+"„%s“ съвпада с повече от един отдалечен клон — открити са %d възможности.\n"
+"Пробата аргументът да се тълкува като път също бе неуспешна.\n"
+"\n"
+"Ако искате да изтеглите клона от конкретно хранилище, напр. „origin“,\n"
+"изрично го укажете към опцията „--track“:\n"
+"\n"
+"    git checkout --track origin/ИМЕ_НА_КЛОН\n"
+"\n"
+"Ако искате винаги да се предпочита конкретно хранилище при нееднозначно\n"
+"ИМЕ_НА_КЛОН, напр. „origin“, задайте следната настройка в конфигурационния\n"
+"файл:\n"
+"\n"
+"    checkout.defaultRemote=origin"
+
+#: builtin/checkout.c:1714 builtin/checkout.c:1716 builtin/checkout.c:1765
+#: builtin/checkout.c:1767 builtin/clone.c:121 builtin/remote.c:169
+#: builtin/remote.c:171 builtin/worktree.c:499 builtin/worktree.c:501
+msgid "branch"
+msgstr "клон"
+
+#: builtin/checkout.c:1715
+msgid "create and checkout a new branch"
+msgstr "създаване и преминаване към нов клон"
+
+#: builtin/checkout.c:1717
+msgid "create/reset and checkout a branch"
+msgstr "създаване/зануляване на клон и преминаване към него"
+
+#: builtin/checkout.c:1718
+msgid "create reflog for new branch"
+msgstr "създаване на журнал на указателите за нов клон"
+
+#: builtin/checkout.c:1720
+msgid "second guess 'git checkout <no-such-branch>' (default)"
+msgstr ""
+"опит за отгатване на име на клон след неуспешен опит с „git checkout "
+"НЕСЪЩЕСТВУВАЩ_КЛОН“ (стандартно)"
+
+#: builtin/checkout.c:1721
+msgid "use overlay mode (default)"
+msgstr "използване на припокриващ режим (стандартно)"
+
+#: builtin/checkout.c:1766
+msgid "create and switch to a new branch"
+msgstr "създаване и преминаване към нов клон"
+
+#: builtin/checkout.c:1768
+msgid "create/reset and switch to a branch"
+msgstr "създаване/зануляване на клон и преминаване към него"
+
+#: builtin/checkout.c:1770
+msgid "second guess 'git switch <no-such-branch>'"
+msgstr ""
+"опит за отгатване на име на клон след неуспешен опит с „git switch "
+"НЕСЪЩЕСТВУВАЩ_КЛОН“"
+
+#: builtin/checkout.c:1772
+msgid "throw away local modifications"
+msgstr "зануляване на локалните промени"
+
+#: builtin/checkout.c:1804
+msgid "which tree-ish to checkout from"
+msgstr "към кой указател към дърво да се премине"
+
+#: builtin/checkout.c:1806
+msgid "restore the index"
+msgstr "възстановяване на индекса"
+
+#: builtin/checkout.c:1808
+msgid "restore the working tree (default)"
+msgstr "възстановяване на работното дърво (стандартно)"
+
+#: builtin/checkout.c:1810
+msgid "ignore unmerged entries"
+msgstr "пренебрегване на неслетите елементи"
+
+#: builtin/checkout.c:1811
+msgid "use overlay mode"
+msgstr "използване на припокриващ режим"
+
+#: builtin/clean.c:28
+msgid ""
+"git clean [-d] [-f] [-i] [-n] [-q] [-e <pattern>] [-x | -X] [--] <paths>..."
+msgstr "git clean [-d] [-f] [-i] [-n] [-q] [-e ШАБЛОН] [-x | -X] [--] ПЪТ…"
+
+#: builtin/clean.c:32
+#, c-format
+msgid "Removing %s\n"
+msgstr "Изтриване на „%s“\n"
+
+#: builtin/clean.c:33
+#, c-format
+msgid "Would remove %s\n"
+msgstr "Файлът „%s“ ще бъде изтрит\n"
+
+#: builtin/clean.c:34
+#, c-format
+msgid "Skipping repository %s\n"
+msgstr "Прескачане на хранилището „%s“\n"
+
+#: builtin/clean.c:35
+#, c-format
+msgid "Would skip repository %s\n"
+msgstr "Хранилището „%s“ ще бъде прескочено\n"
+
+#: builtin/clean.c:36
+#, c-format
+msgid "failed to remove %s"
+msgstr "файлът „%s“ не може да бъде изтрит"
+
+#: builtin/clean.c:37
+#, c-format
+msgid "could not lstat %s\n"
+msgstr "не може да се получи информация чрез „lstat“ за „%s“\n"
+
+#: builtin/clean.c:301 git-add--interactive.perl:595
+#, c-format
+msgid ""
+"Prompt help:\n"
+"1          - select a numbered item\n"
+"foo        - select item based on unique prefix\n"
+"           - (empty) select nothing\n"
+msgstr ""
+"Подсказка:\n"
+"1          — избор на обект според реда\n"
+"ПРЕФИКС    — избор на единствен обект по този уникален префикс\n"
+"           — (празно) нищо да не се избира\n"
+
+#: builtin/clean.c:305 git-add--interactive.perl:604
+#, c-format
+msgid ""
+"Prompt help:\n"
+"1          - select a single item\n"
+"3-5        - select a range of items\n"
+"2-3,6-9    - select multiple ranges\n"
+"foo        - select item based on unique prefix\n"
 "-...       - unselect specified items\n"
 "*          - choose all items\n"
 "           - (empty) finish selecting\n"
 msgstr ""
-"Подсказка:\n"
-"1          — избор на един обект\n"
-"3-5        — диапазон за избор на обекти\n"
-"2-3,6-9    — множество диапазони за избор на обекти\n"
-"ПРЕФИКС    — избор на единствен обект по този уникален префикс\n"
-"-…         — отмяна на избора на обекти\n"
-"*          — избиране на всички обекти\n"
-"           — (празно) завършване на избирането\n"
+"Подсказка:\n"
+"1          — избор на един обект\n"
+"3-5        — диапазон за избор на обекти\n"
+"2-3,6-9    — множество диапазони за избор на обекти\n"
+"ПРЕФИКС    — избор на единствен обект по този уникален префикс\n"
+"-…         — отмяна на избора на обекти\n"
+"*          — избиране на всички обекти\n"
+"           — (празно) завършване на избирането\n"
+
+#: builtin/clean.c:521 git-add--interactive.perl:570
+#: git-add--interactive.perl:575
+#, c-format, perl-format
+msgid "Huh (%s)?\n"
+msgstr "Неправилен избор (%s).\n"
+
+#: builtin/clean.c:663
+#, c-format
+msgid "Input ignore patterns>> "
+msgstr "Шаблони за игнорирани елементи≫ "
+
+#: builtin/clean.c:700
+#, c-format
+msgid "WARNING: Cannot find items matched by: %s"
+msgstr "ПРЕДУПРЕЖДЕНИЕ: Никой обект не напасва на „%s“"
+
+#: builtin/clean.c:721
+msgid "Select items to delete"
+msgstr "Избиране на обекти за изтриване"
+
+#. TRANSLATORS: Make sure to keep [y/N] as is
+#: builtin/clean.c:762
+#, c-format
+msgid "Remove %s [y/N]? "
+msgstr "Да се изтрие ли „%s“? „y“ —  да, „N“ — НЕ"
+
+#: builtin/clean.c:795
+msgid ""
+"clean               - start cleaning\n"
+"filter by pattern   - exclude items from deletion\n"
+"select by numbers   - select items to be deleted by numbers\n"
+"ask each            - confirm each deletion (like \"rm -i\")\n"
+"quit                - stop cleaning\n"
+"help                - this screen\n"
+"?                   - help for prompt selection"
+msgstr ""
+"clean               — начало на изчистването\n"
+"filter by pattern   — шаблон за обекти, които да не се трият\n"
+"select by numbers   — номера на обекти, които да се трият\n"
+"ask each            — потвърждаване на всяко изтриване (подобно на „rm -i“)\n"
+"quit                — край на изчистването\n"
+"help                — този край\n"
+"?                   — подсказка за шаблоните"
+
+#: builtin/clean.c:831
+msgid "Would remove the following item:"
+msgid_plural "Would remove the following items:"
+msgstr[0] "Следният обект ще бъде изтрит:"
+msgstr[1] "Следните обекти ще бъдат изтрити:"
+
+#: builtin/clean.c:847
+msgid "No more files to clean, exiting."
+msgstr "Файловете за изчистване свършиха.  Изход от програмата."
+
+#: builtin/clean.c:909
+msgid "do not print names of files removed"
+msgstr "без извеждане на имената на файловете, които ще бъдат изтрити"
+
+#: builtin/clean.c:911
+msgid "force"
+msgstr "принудително изтриване"
+
+#: builtin/clean.c:912
+msgid "interactive cleaning"
+msgstr "интерактивно изтриване"
+
+#: builtin/clean.c:914
+msgid "remove whole directories"
+msgstr "изтриване на цели директории"
+
+#: builtin/clean.c:915 builtin/describe.c:548 builtin/describe.c:550
+#: builtin/grep.c:901 builtin/log.c:177 builtin/log.c:179
+#: builtin/ls-files.c:557 builtin/name-rev.c:464 builtin/name-rev.c:466
+#: builtin/show-ref.c:179
+msgid "pattern"
+msgstr "ШАБЛОН"
+
+#: builtin/clean.c:916
+msgid "add <pattern> to ignore rules"
+msgstr "добавяне на ШАБЛОН от файлове, които да не се трият"
+
+#: builtin/clean.c:917
+msgid "remove ignored files, too"
+msgstr "изтриване и на игнорираните файлове"
+
+#: builtin/clean.c:919
+msgid "remove only ignored files"
+msgstr "изтриване само на игнорирани файлове"
+
+#: builtin/clean.c:937
+msgid "-x and -X cannot be used together"
+msgstr "опциите „-x“ и „-X“ са несъвместими"
+
+#: builtin/clean.c:941
+msgid ""
+"clean.requireForce set to true and neither -i, -n, nor -f given; refusing to "
+"clean"
+msgstr ""
+"Настройката „clean.requireForce“ е зададена като истина, което изисква някоя "
+"от опциите „-i“, „-n“ или „-f“.  Няма да се извърши изчистване"
+
+#: builtin/clean.c:944
+msgid ""
+"clean.requireForce defaults to true and neither -i, -n, nor -f given; "
+"refusing to clean"
+msgstr ""
+"Настройката „clean.requireForce“ не е зададена, но стандартно е истина, "
+"което изисква някоя от опциите „-i“, „-n“ или „-f“.  Няма да се извърши "
+"изчистване"
+
+#: builtin/clone.c:45
+msgid "git clone [<options>] [--] <repo> [<dir>]"
+msgstr "git clone [ОПЦИЯ…] [--] ХРАНИЛИЩЕ [ДИРЕКТОРИЯ]"
+
+#: builtin/clone.c:93
+msgid "don't create a checkout"
+msgstr "без създаване на работно дърво"
+
+#: builtin/clone.c:94 builtin/clone.c:96 builtin/init-db.c:489
+msgid "create a bare repository"
+msgstr "създаване на голо хранилище"
+
+#: builtin/clone.c:98
+msgid "create a mirror repository (implies bare)"
+msgstr ""
+"създаване на хранилище-огледало (включва опцията „--bare“ за голо хранилище)"
+
+#: builtin/clone.c:100
+msgid "to clone from a local repository"
+msgstr "клониране от локално хранилище"
+
+#: builtin/clone.c:102
+msgid "don't use local hardlinks, always copy"
+msgstr "без твърди връзки, файловете винаги да се копират"
+
+#: builtin/clone.c:104
+msgid "setup as shared repository"
+msgstr "настройване за споделено хранилище"
+
+#: builtin/clone.c:107
+msgid "pathspec"
+msgstr "път"
+
+#: builtin/clone.c:107
+msgid "initialize submodules in the clone"
+msgstr "инициализиране на подмодулите при това клониране"
+
+#: builtin/clone.c:110
+msgid "number of submodules cloned in parallel"
+msgstr "брой подмодули, клонирани паралелно"
+
+#: builtin/clone.c:111 builtin/init-db.c:486
+msgid "template-directory"
+msgstr "директория с шаблони"
+
+#: builtin/clone.c:112 builtin/init-db.c:487
+msgid "directory from which templates will be used"
+msgstr "директория, която съдържа шаблоните, които да се ползват"
+
+#: builtin/clone.c:114 builtin/clone.c:116 builtin/submodule--helper.c:1392
+#: builtin/submodule--helper.c:1885
+msgid "reference repository"
+msgstr "еталонно хранилище"
+
+#: builtin/clone.c:118 builtin/submodule--helper.c:1394
+#: builtin/submodule--helper.c:1887
+msgid "use --reference only while cloning"
+msgstr "опцията „--reference“ може да се използва само при клониране"
+
+#: builtin/clone.c:119 builtin/column.c:27 builtin/merge-file.c:46
+#: builtin/pack-objects.c:3294 builtin/repack.c:327
+msgid "name"
+msgstr "ИМЕ"
+
+#: builtin/clone.c:120
+msgid "use <name> instead of 'origin' to track upstream"
+msgstr "използване на това ИМЕ вместо „origin“ при проследяване на клони"
+
+#: builtin/clone.c:122
+msgid "checkout <branch> instead of the remote's HEAD"
+msgstr "изтегляне на този КЛОН, а не соченият от отдалечения указател „HEAD“"
+
+#: builtin/clone.c:124
+msgid "path to git-upload-pack on the remote"
+msgstr "път към командата „git-upload-pack“ на отдалеченото хранилище"
+
+#: builtin/clone.c:125 builtin/fetch.c:168 builtin/grep.c:840
+#: builtin/pull.c:227
+msgid "depth"
+msgstr "ДЪЛБОЧИНА"
+
+#: builtin/clone.c:126
+msgid "create a shallow clone of that depth"
+msgstr "плитко клониране до тази ДЪЛБОЧИНА"
+
+#: builtin/clone.c:127 builtin/fetch.c:170 builtin/pack-objects.c:3283
+msgid "time"
+msgstr "ВРЕМЕ"
+
+#: builtin/clone.c:128
+msgid "create a shallow clone since a specific time"
+msgstr "плитко клониране до момент във времето"
+
+#: builtin/clone.c:129 builtin/fetch.c:172 builtin/fetch.c:195
+#: builtin/rebase.c:1445
+msgid "revision"
+msgstr "ВЕРСИЯ"
+
+#: builtin/clone.c:130 builtin/fetch.c:173
+msgid "deepen history of shallow clone, excluding rev"
+msgstr "задълбочаване на историята на плитко хранилище до изключващ указател"
+
+#: builtin/clone.c:132
+msgid "clone only one branch, HEAD or --branch"
+msgstr ""
+"клониране само на един клон — или сочения от отдалечения „HEAD“, или изрично "
+"зададения с „--branch“"
+
+#: builtin/clone.c:134
+msgid "don't clone any tags, and make later fetches not to follow them"
+msgstr ""
+"без клониране на етикети, като последващите доставяния няма да ги следят"
+
+#: builtin/clone.c:136
+msgid "any cloned submodules will be shallow"
+msgstr "всички клонирани подмодули ще са плитки"
+
+#: builtin/clone.c:137 builtin/init-db.c:495
+msgid "gitdir"
+msgstr "СЛУЖЕБНА_ДИРЕКТОРИЯ"
+
+#: builtin/clone.c:138 builtin/init-db.c:496
+msgid "separate git dir from working tree"
+msgstr "отделна СЛУЖЕБНА_ДИРЕКТОРИЯ за git извън работното дърво"
+
+#: builtin/clone.c:139
+msgid "key=value"
+msgstr "КЛЮЧ=СТОЙНОСТ"
+
+#: builtin/clone.c:140
+msgid "set config inside the new repository"
+msgstr "задаване на настройките на новото хранилище"
+
+#: builtin/clone.c:142 builtin/fetch.c:190 builtin/ls-remote.c:76
+#: builtin/push.c:573 builtin/send-pack.c:172
+msgid "server-specific"
+msgstr "специфични за сървъра"
+
+#: builtin/clone.c:142 builtin/fetch.c:190 builtin/ls-remote.c:76
+#: builtin/push.c:573 builtin/send-pack.c:173
+msgid "option to transmit"
+msgstr "опция за пренос"
+
+#: builtin/clone.c:143 builtin/fetch.c:191 builtin/pull.c:240
+#: builtin/push.c:574
+msgid "use IPv4 addresses only"
+msgstr "само адреси IPv4"
+
+#: builtin/clone.c:145 builtin/fetch.c:193 builtin/pull.c:243
+#: builtin/push.c:576
+msgid "use IPv6 addresses only"
+msgstr "само адреси IPv6"
+
+#: builtin/clone.c:149
+msgid "any cloned submodules will use their remote-tracking branch"
+msgstr "всички клонирани подмодули ще ползват следящите си клони"
+
+#: builtin/clone.c:151
+msgid "initialize sparse-checkout file to include only files at root"
+msgstr ""
+"инициализиране на файла за частично изтегляне („.git/info/sparse-checkout“) "
+"да съдържа само файловете в основната директория"
+
+#: builtin/clone.c:287
+msgid ""
+"No directory name could be guessed.\n"
+"Please specify a directory on the command line"
+msgstr ""
+"Името на директорията не може да бъде отгатнато.\n"
+"Задайте директорията изрично на командния ред"
+
+#: builtin/clone.c:340
+#, c-format
+msgid "info: Could not add alternate for '%s': %s\n"
+msgstr ""
+"ПРЕДУПРЕЖДЕНИЕ: не може да се добави алтернативен източник на „%s“: %s\n"
+
+#: builtin/clone.c:413
+#, c-format
+msgid "%s exists and is not a directory"
+msgstr "„%s“ съществува и не е директория"
+
+#: builtin/clone.c:430
+#, c-format
+msgid "failed to start iterator over '%s'"
+msgstr "неуспешно итериране по „%s“"
+
+#: builtin/clone.c:460
+#, c-format
+msgid "failed to create link '%s'"
+msgstr "връзката „%s“ не може да бъде създадена"
+
+#: builtin/clone.c:464
+#, c-format
+msgid "failed to copy file to '%s'"
+msgstr "файлът не може да бъде копиран като „%s“"
+
+#: builtin/clone.c:469
+#, c-format
+msgid "failed to iterate over '%s'"
+msgstr "неуспешно итериране по „%s“"
+
+#: builtin/clone.c:494
+#, c-format
+msgid "done.\n"
+msgstr "действието завърши.\n"
+
+#: builtin/clone.c:508
+msgid ""
+"Clone succeeded, but checkout failed.\n"
+"You can inspect what was checked out with 'git status'\n"
+"and retry with 'git restore --source=HEAD :/'\n"
+msgstr ""
+"Клонирането бе успешно за разлика от подготовката на работното дърво\n"
+"за определен клон.  Все пак можете да проверите кои файлове и от кой\n"
+"клон в момента са изтеглени с командата „git status“.  Можете да\n"
+"завършите изтеглянето на клона с командата:\n"
+"\n"
+"    git restore --source=HEAD :/\n"
+
+#: builtin/clone.c:585
+#, c-format
+msgid "Could not find remote branch %s to clone."
+msgstr ""
+"Клонът „%s“ от отдалеченото хранилище, което клонирате,\n"
+"и който следва да бъде изтеглен, не съществува."
+
+#: builtin/clone.c:704
+#, c-format
+msgid "unable to update %s"
+msgstr "обектът „%s“ не може да бъде обновен"
+
+#: builtin/clone.c:752
+msgid "failed to initialize sparse-checkout"
+msgstr "частичното изтегляне не може да се инициализира"
+
+#: builtin/clone.c:775
+msgid "remote HEAD refers to nonexistent ref, unable to checkout.\n"
+msgstr ""
+"указателят „HEAD“ от отдалеченото хранилище сочи към нещо,\n"
+"което не съществува.  Не може да се изтегли определен клон.\n"
+
+#: builtin/clone.c:806
+msgid "unable to checkout working tree"
+msgstr "работното дърво не може да бъде подготвено"
+
+#: builtin/clone.c:856
+msgid "unable to write parameters to config file"
+msgstr "настройките не могат да бъдат записани в конфигурационния файл"
+
+#: builtin/clone.c:919
+msgid "cannot repack to clean up"
+msgstr "не може да се извърши пакетиране за изчистване на файловете"
+
+#: builtin/clone.c:921
+msgid "cannot unlink temporary alternates file"
+msgstr "временният файл за алтернативни обекти не може да бъде изтрит"
+
+#: builtin/clone.c:959 builtin/receive-pack.c:1948
+msgid "Too many arguments."
+msgstr "Прекалено много аргументи."
+
+#: builtin/clone.c:963
+msgid "You must specify a repository to clone."
+msgstr "Трябва да укажете кое хранилище искате да клонирате."
+
+#: builtin/clone.c:976
+#, c-format
+msgid "--bare and --origin %s options are incompatible."
+msgstr "опциите „--bare“ и „--origin %s“ са несъвместими."
+
+#: builtin/clone.c:979
+msgid "--bare and --separate-git-dir are incompatible."
+msgstr "опциите „--bare“ и „--separate-git-dir“ са несъвместими."
+
+#: builtin/clone.c:992
+#, c-format
+msgid "repository '%s' does not exist"
+msgstr "не съществува хранилище „%s“"
+
+#: builtin/clone.c:998 builtin/fetch.c:1787
+#, c-format
+msgid "depth %s is not a positive number"
+msgstr "дълбочината трябва да е положително цяло число, а не „%s“"
+
+#: builtin/clone.c:1008
+#, c-format
+msgid "destination path '%s' already exists and is not an empty directory."
+msgstr "целевият път „%s“ съществува и не е празна директория."
+
+#: builtin/clone.c:1018
+#, c-format
+msgid "working tree '%s' already exists."
+msgstr "в „%s“ вече съществува работно дърво."
+
+#: builtin/clone.c:1033 builtin/clone.c:1054 builtin/difftool.c:271
+#: builtin/log.c:1866 builtin/worktree.c:302 builtin/worktree.c:334
+#, c-format
+msgid "could not create leading directories of '%s'"
+msgstr "родителските директории на „%s“ не могат да бъдат създадени"
+
+#: builtin/clone.c:1038
+#, c-format
+msgid "could not create work tree dir '%s'"
+msgstr "работното дърво в „%s“ не може да бъде създадено."
+
+#: builtin/clone.c:1058
+#, c-format
+msgid "Cloning into bare repository '%s'...\n"
+msgstr "Клониране и създаване на голо хранилище в „%s“…\n"
+
+#: builtin/clone.c:1060
+#, c-format
+msgid "Cloning into '%s'...\n"
+msgstr "Клониране и създаване на хранилище в „%s“…\n"
+
+#: builtin/clone.c:1084
+msgid ""
+"clone --recursive is not compatible with both --reference and --reference-if-"
+"able"
+msgstr ""
+"Опцията „--recursive“ е несъвместима с опциите „--reference“ и „--reference-"
+"if-able“"
+
+#: builtin/clone.c:1148
+msgid "--depth is ignored in local clones; use file:// instead."
+msgstr ""
+"При локално клониране опцията „--depth“ се прескача.  Ползвайте схемата "
+"„file://“."
+
+#: builtin/clone.c:1150
+msgid "--shallow-since is ignored in local clones; use file:// instead."
+msgstr ""
+"При локално клониране опцията „--shallow-since“ се прескача.  Ползвайте "
+"схемата „file://“."
+
+#: builtin/clone.c:1152
+msgid "--shallow-exclude is ignored in local clones; use file:// instead."
+msgstr ""
+"При локално клониране опцията „--shallow-exclude“ се прескача.  Ползвайте "
+"схемата „file://“."
+
+#: builtin/clone.c:1154
+msgid "--filter is ignored in local clones; use file:// instead."
+msgstr ""
+"При локално клониране опцията „--filter“ се прескача.  Ползвайте схемата "
+"„file://“."
+
+#: builtin/clone.c:1157
+msgid "source repository is shallow, ignoring --local"
+msgstr "клонираното хранилище е плитко, затова опцията „--local“ се прескача"
+
+#: builtin/clone.c:1162
+msgid "--local is ignored"
+msgstr "опцията „--local“ се прескача"
+
+#: builtin/clone.c:1237 builtin/clone.c:1245
+#, c-format
+msgid "Remote branch %s not found in upstream %s"
+msgstr "Отдалеченият клон „%s“ липсва в клонираното хранилище „%s“"
+
+#: builtin/clone.c:1248
+msgid "You appear to have cloned an empty repository."
+msgstr "Изглежда клонирахте празно хранилище."
+
+#: builtin/column.c:10
+msgid "git column [<options>]"
+msgstr "git column [ОПЦИЯ…]"
+
+#: builtin/column.c:27
+msgid "lookup config vars"
+msgstr "извеждане на настройките"
+
+#: builtin/column.c:28 builtin/column.c:29
+msgid "layout to use"
+msgstr "как да се подреди резултата"
+
+#: builtin/column.c:30
+msgid "Maximum width"
+msgstr "Максимална широчина"
+
+#: builtin/column.c:31
+msgid "Padding space on left border"
+msgstr "Поле в знаци отляво"
+
+#: builtin/column.c:32
+msgid "Padding space on right border"
+msgstr "Поле в знаци отдясно"
+
+#: builtin/column.c:33
+msgid "Padding space between columns"
+msgstr "Поле в знаци между колоните"
+
+#: builtin/column.c:51
+msgid "--command must be the first argument"
+msgstr "опцията „--command“ трябва да е първият аргумент"
+
+#: builtin/commit-tree.c:18
+msgid ""
+"git commit-tree [(-p <parent>)...] [-S[<keyid>]] [(-m <message>)...] [(-F "
+"<file>)...] <tree>"
+msgstr ""
+"git commit-tree [(-p РОДИТЕЛ)…] [-S[ИДЕНТИФИКАТОР]] [(-m СЪОБЩЕНИЕ)…] [(-F "
+"ФАЙЛ)…] ДЪРВО"
+
+#: builtin/commit-tree.c:31
+#, c-format
+msgid "duplicate parent %s ignored"
+msgstr "прескачане на повтарящ се родител: „%s“"
+
+#: builtin/commit-tree.c:56 builtin/commit-tree.c:136 builtin/log.c:526
+#, c-format
+msgid "not a valid object name %s"
+msgstr "неправилно име на обект: „%s“"
+
+#: builtin/commit-tree.c:93
+#, c-format
+msgid "git commit-tree: failed to open '%s'"
+msgstr "git commit-tree: „%s“ не може да се отвори"
+
+#: builtin/commit-tree.c:96
+#, c-format
+msgid "git commit-tree: failed to read '%s'"
+msgstr "git commit-tree: „%s“ не може да се прочете"
+
+#: builtin/commit-tree.c:98
+#, c-format
+msgid "git commit-tree: failed to close '%s'"
+msgstr "git commit-tree: „%s“ не може да се затвори"
+
+#: builtin/commit-tree.c:111
+msgid "parent"
+msgstr "родител"
+
+#: builtin/commit-tree.c:112
+msgid "id of a parent commit object"
+msgstr "ИДЕНТИФИКАТОР на обекта за подаването-родител"
+
+#: builtin/commit-tree.c:114 builtin/commit.c:1496 builtin/merge.c:270
+#: builtin/notes.c:409 builtin/notes.c:575 builtin/stash.c:1469
+#: builtin/tag.c:412
+msgid "message"
+msgstr "СЪОБЩЕНИЕ"
+
+#: builtin/commit-tree.c:115 builtin/commit.c:1496
+msgid "commit message"
+msgstr "СЪОБЩЕНИЕ при подаване"
+
+#: builtin/commit-tree.c:118
+msgid "read commit log message from file"
+msgstr "изчитане на съобщението за подаване от ФАЙЛ"
+
+#: builtin/commit-tree.c:121 builtin/commit.c:1508 builtin/merge.c:287
+#: builtin/pull.c:195 builtin/revert.c:118
+msgid "GPG sign commit"
+msgstr "подписване на подаването с GPG"
+
+#: builtin/commit-tree.c:133
+msgid "must give exactly one tree"
+msgstr "трябва да е точно едно дърво"
+
+#: builtin/commit-tree.c:140
+msgid "git commit-tree: failed to read"
+msgstr "git commit-tree: не може да се прочете"
+
+#: builtin/commit.c:41
+msgid "git commit [<options>] [--] <pathspec>..."
+msgstr "git commit [ОПЦИЯ…] [--] ПЪТ…"
+
+#: builtin/commit.c:46
+msgid "git status [<options>] [--] <pathspec>..."
+msgstr "git status [ОПЦИЯ…] [--] ПЪТ…"
+
+#: builtin/commit.c:51
+msgid ""
+"You asked to amend the most recent commit, but doing so would make\n"
+"it empty. You can repeat your command with --allow-empty, or you can\n"
+"remove the commit entirely with \"git reset HEAD^\".\n"
+msgstr ""
+"Поискахте да поправите последното си подаване.  Това действие ще превърне\n"
+"подаването в празно.  Можете или да го повторите като разрешите такива "
+"подавания\n"
+"с опцията „--allow-empty“, или да го изтриете от историята с командата:\n"
+"„git reset HEAD^“.\n"
+
+#: builtin/commit.c:56
+msgid ""
+"The previous cherry-pick is now empty, possibly due to conflict resolution.\n"
+"If you wish to commit it anyway, use:\n"
+"\n"
+"    git commit --allow-empty\n"
+"\n"
+msgstr ""
+"Предишното отбрано подаване вече е празно, като най-вероятната причина е\n"
+"корекция на конфликт.  Ако все пак искате да го ползвате, използвайте "
+"командата:\n"
+"\n"
+"    git commit --allow-empty\n"
+"\n"
+
+#: builtin/commit.c:63
+msgid "Otherwise, please use 'git cherry-pick --skip'\n"
+msgstr ""
+"В противен случай използвайте командата:\n"
+"\n"
+"    git cherry-pick --skip\n"
+
+#: builtin/commit.c:66
+msgid ""
+"and then use:\n"
+"\n"
+"    git cherry-pick --continue\n"
+"\n"
+"to resume cherry-picking the remaining commits.\n"
+"If you wish to skip this commit, use:\n"
+"\n"
+"    git cherry-pick --skip\n"
+"\n"
+msgstr ""
+"след това изпълнете:\n"
+"\n"
+"    git cherry-pick --continue\n"
+"\n"
+"и ще продължите да отбирате останалите подавания.\n"
+"За да прескочите това подаване, изпълнете:\n"
+"\n"
+"    git cherry-pick --skip\n"
+"\n"
+
+#: builtin/commit.c:315
+msgid "failed to unpack HEAD tree object"
+msgstr "върховото дърво (HEAD tree object) не може да бъде извадено от пакет"
+
+#: builtin/commit.c:351
+msgid "--pathspec-from-file with -a does not make sense"
+msgstr "опциите „-a“ и „--pathspec-from-file“ са несъвместими"
+
+#: builtin/commit.c:364
+msgid "No paths with --include/--only does not make sense."
+msgstr "Опциите „--include“ и „--only“ изискват аргументи."
+
+#: builtin/commit.c:376
+msgid "unable to create temporary index"
+msgstr "временният индекс не може да бъде създаден"
+
+#: builtin/commit.c:382
+msgid "interactive add failed"
+msgstr "неуспешно интерактивно добавяне"
+
+#: builtin/commit.c:396
+msgid "unable to update temporary index"
+msgstr "временният индекс не може да бъде обновен"
+
+#: builtin/commit.c:398
+msgid "Failed to update main cache tree"
+msgstr "Дървото на основния кеш не може да бъде обновено"
+
+#: builtin/commit.c:423 builtin/commit.c:446 builtin/commit.c:492
+msgid "unable to write new_index file"
+msgstr "новият индекс не може да бъде записан"
+
+#: builtin/commit.c:475
+msgid "cannot do a partial commit during a merge."
+msgstr "по време на сливане не може да се извърши частично подаване."
+
+#: builtin/commit.c:477
+msgid "cannot do a partial commit during a cherry-pick."
+msgstr "по време на отбиране не може да се извърши частично подаване."
+
+#: builtin/commit.c:485
+msgid "cannot read the index"
+msgstr "индексът не може да бъде прочетен"
+
+#: builtin/commit.c:504
+msgid "unable to write temporary index file"
+msgstr "временният индекс не може да бъде записан"
+
+#: builtin/commit.c:602
+#, c-format
+msgid "commit '%s' lacks author header"
+msgstr "заглавната част за автор в подаването „%s“ липсва"
+
+#: builtin/commit.c:604
+#, c-format
+msgid "commit '%s' has malformed author line"
+msgstr "заглавната част за автор в подаването „%s“ е неправилна"
+
+#: builtin/commit.c:623
+msgid "malformed --author parameter"
+msgstr "неправилен параметър към опцията „--author“"
+
+#: builtin/commit.c:676
+msgid ""
+"unable to select a comment character that is not used\n"
+"in the current commit message"
+msgstr ""
+"не може да се избере знак за коментар — в текущото съобщение за подаване са "
+"използвани всички подобни знаци"
+
+#: builtin/commit.c:714 builtin/commit.c:747 builtin/commit.c:1092
+#, c-format
+msgid "could not lookup commit %s"
+msgstr "следното подаване не може да бъде открито: %s"
+
+#: builtin/commit.c:726 builtin/shortlog.c:319
+#, c-format
+msgid "(reading log message from standard input)\n"
+msgstr "(изчитане на съобщението за подаване от стандартния вход)\n"
+
+#: builtin/commit.c:728
+msgid "could not read log from standard input"
+msgstr "съобщението за подаване не бе прочетено стандартния вход"
+
+#: builtin/commit.c:732
+#, c-format
+msgid "could not read log file '%s'"
+msgstr "файлът със съобщението за подаване „%s“ не може да бъде прочетен"
+
+#: builtin/commit.c:763 builtin/commit.c:779
+msgid "could not read SQUASH_MSG"
+msgstr "съобщението за вкарване SQUASH_MSG не може да бъде прочетено"
+
+#: builtin/commit.c:770
+msgid "could not read MERGE_MSG"
+msgstr "съобщението за сливане MERGE_MSG не може да бъде прочетено"
+
+#: builtin/commit.c:830
+msgid "could not write commit template"
+msgstr "шаблонът за подаване не може да бъде запазен"
+
+#: builtin/commit.c:849
+#, c-format
+msgid ""
+"\n"
+"It looks like you may be committing a merge.\n"
+"If this is not correct, please remove the file\n"
+"\t%s\n"
+"and try again.\n"
+msgstr ""
+"\n"
+"Изглежда, че подавате сливане.  Ако това не е така, изтрийте файла:\n"
+"\n"
+"    %s\n"
+"и опитайте отново.\n"
+
+#: builtin/commit.c:854
+#, c-format
+msgid ""
+"\n"
+"It looks like you may be committing a cherry-pick.\n"
+"If this is not correct, please remove the file\n"
+"\t%s\n"
+"and try again.\n"
+msgstr ""
+"\n"
+"Изглежда, че извършвате отбрано подаване.  Ако това не е така, изтрийте "
+"файла:\n"
+"\n"
+"    %s\n"
+"и опитайте отново.\n"
+
+#: builtin/commit.c:867
+#, c-format
+msgid ""
+"Please enter the commit message for your changes. Lines starting\n"
+"with '%c' will be ignored, and an empty message aborts the commit.\n"
+msgstr ""
+"Въведете съобщението за подаване на промените.  Редовете, които започват\n"
+"с „%c“, ще бъдат пропуснати, а празно съобщение преустановява подаването.\n"
+
+#: builtin/commit.c:875
+#, c-format
+msgid ""
+"Please enter the commit message for your changes. Lines starting\n"
+"with '%c' will be kept; you may remove them yourself if you want to.\n"
+"An empty message aborts the commit.\n"
+msgstr ""
+"Въведете съобщението за подаване на промените.  Редовете, които започват\n"
+"с „%c“, също ще бъдат включени — може да ги изтриете вие.  Празно \n"
+"съобщение преустановява подаването.\n"
+
+#: builtin/commit.c:892
+#, c-format
+msgid "%sAuthor:    %.*s <%.*s>"
+msgstr "%sАвтор:   %.*s <%.*s>"
+
+#: builtin/commit.c:900
+#, c-format
+msgid "%sDate:      %s"
+msgstr "%sДата:    %s"
+
+#: builtin/commit.c:907
+#, c-format
+msgid "%sCommitter: %.*s <%.*s>"
+msgstr "%sПодаващ: %.*s <%.*s>"
+
+#: builtin/commit.c:925
+msgid "Cannot read index"
+msgstr "Индексът не може да бъде прочетен"
+
+#: builtin/commit.c:992
+msgid "Error building trees"
+msgstr "Грешка при изграждане на дърветата"
+
+#: builtin/commit.c:1006 builtin/tag.c:275
+#, c-format
+msgid "Please supply the message using either -m or -F option.\n"
+msgstr "Подайте съобщението с някоя от опциите „-m“ или „-F“.\n"
+
+#: builtin/commit.c:1050
+#, c-format
+msgid "--author '%s' is not 'Name <email>' and matches no existing author"
+msgstr ""
+"Опцията „--author '%s'“ не отговаря на форма̀та „Име <е-поща>“ и не съвпада с "
+"никой автор"
+
+#: builtin/commit.c:1064
+#, c-format
+msgid "Invalid ignored mode '%s'"
+msgstr "Неправилен режим за игнорираните файлове: „%s“"
+
+#: builtin/commit.c:1082 builtin/commit.c:1322
+#, c-format
+msgid "Invalid untracked files mode '%s'"
+msgstr "Неправилен режим за неследените файлове: „%s“"
+
+#: builtin/commit.c:1122
+msgid "--long and -z are incompatible"
+msgstr "Опциите „--long“ и „-z“ са несъвместими."
+
+#: builtin/commit.c:1166
+msgid "Using both --reset-author and --author does not make sense"
+msgstr "Опциите „--reset-author“ и „--author“ са несъвместими."
+
+#: builtin/commit.c:1175
+msgid "You have nothing to amend."
+msgstr "Няма какво да бъде поправено."
+
+#: builtin/commit.c:1178
+msgid "You are in the middle of a merge -- cannot amend."
+msgstr "В момента се извършва сливане, не можете да поправяте."
+
+#: builtin/commit.c:1180
+msgid "You are in the middle of a cherry-pick -- cannot amend."
+msgstr "В момента се извършва отбиране на подаване, не можете да поправяте."
+
+#: builtin/commit.c:1183
+msgid "Options --squash and --fixup cannot be used together"
+msgstr "Опциите „--squash“ и „--fixup“ са несъвместими."
+
+#: builtin/commit.c:1193
+msgid "Only one of -c/-C/-F/--fixup can be used."
+msgstr "Опциите „-c“, „-C“, „-F“ и „--fixup““ са несъвместими."
+
+#: builtin/commit.c:1195
+msgid "Option -m cannot be combined with -c/-C/-F."
+msgstr "Опцията „-m“ е несъвместима с „-c“, „-C“ и „-F“."
+
+#: builtin/commit.c:1203
+msgid "--reset-author can be used only with -C, -c or --amend."
+msgstr ""
+"Опцията „--reset-author“ може да се използва само заедно с „-C“, „-c“ или\n"
+"„--amend“."
+
+#: builtin/commit.c:1220
+msgid "Only one of --include/--only/--all/--interactive/--patch can be used."
+msgstr ""
+"Опциите „--include“, „--only“, „--all“, „--interactive“ и „--patch“ са\n"
+"несъвместими."
+
+#: builtin/commit.c:1226
+#, c-format
+msgid "paths '%s ...' with -a does not make sense"
+msgstr "опцията „-a“ е несъвместима със задаването на пътища: „%s…“"
+
+#: builtin/commit.c:1357 builtin/commit.c:1519
+msgid "show status concisely"
+msgstr "кратка информация за състоянието"
+
+#: builtin/commit.c:1359 builtin/commit.c:1521
+msgid "show branch information"
+msgstr "информация за клоните"
+
+#: builtin/commit.c:1361
+msgid "show stash information"
+msgstr "информация за скатаното"
+
+#: builtin/commit.c:1363 builtin/commit.c:1523
+msgid "compute full ahead/behind values"
+msgstr "изчисляване на точните стойности напред/назад"
+
+#: builtin/commit.c:1365
+msgid "version"
+msgstr "версия"
+
+#: builtin/commit.c:1365 builtin/commit.c:1525 builtin/push.c:549
+#: builtin/worktree.c:650
+msgid "machine-readable output"
+msgstr "формат на изхода за четене от програма"
+
+#: builtin/commit.c:1368 builtin/commit.c:1527
+msgid "show status in long format (default)"
+msgstr "подробна информация за състоянието (стандартно)"
+
+#: builtin/commit.c:1371 builtin/commit.c:1530
+msgid "terminate entries with NUL"
+msgstr "разделяне на елементите с нулевия знак „NUL“"
+
+#: builtin/commit.c:1373 builtin/commit.c:1377 builtin/commit.c:1533
+#: builtin/fast-export.c:1153 builtin/fast-export.c:1156
+#: builtin/fast-export.c:1159 builtin/rebase.c:1525 parse-options.h:336
+msgid "mode"
+msgstr "РЕЖИМ"
+
+#: builtin/commit.c:1374 builtin/commit.c:1533
+msgid "show untracked files, optional modes: all, normal, no. (Default: all)"
+msgstr ""
+"извеждане на неследените файлове.  Възможните РЕЖИМи са „all“ (подробна "
+"информация), „normal“ (кратка информация), „no“ (без неследените файлове).  "
+"Стандартният РЕЖИМ е: „all“."
+
+#: builtin/commit.c:1378
+msgid ""
+"show ignored files, optional modes: traditional, matching, no. (Default: "
+"traditional)"
+msgstr ""
+"извеждане на игнорираните файлове.  Възможните РЕЖИМи са "
+"„traditional“ (традиционен), „matching“ (напасващи), „no“ (без игнорираните "
+"файлове).  Стандартният РЕЖИМ е: „traditional“."
+
+#: builtin/commit.c:1380 parse-options.h:192
+msgid "when"
+msgstr "КОГА"
+
+#: builtin/commit.c:1381
+msgid ""
+"ignore changes to submodules, optional when: all, dirty, untracked. "
+"(Default: all)"
+msgstr ""
+"игнориране на промените в подмодулите.  Опция с незадължителна стойност — "
+"една от „all“ (всички), „dirty“ (тези с неподадени промени), "
+"„untracked“ (неследени)"
+
+#: builtin/commit.c:1383
+msgid "list untracked files in columns"
+msgstr "извеждане на неследените файлове в колони"
+
+#: builtin/commit.c:1384
+msgid "do not detect renames"
+msgstr "без засичане на преименуванията"
+
+#: builtin/commit.c:1386
+msgid "detect renames, optionally set similarity index"
+msgstr "засичане на преименуванията, може да се зададе коефициент на прилика"
+
+#: builtin/commit.c:1406
+msgid "Unsupported combination of ignored and untracked-files arguments"
+msgstr "Неподдържана комбинация от аргументи за игнорирани и неследени файлове"
+
+#: builtin/commit.c:1489
+msgid "suppress summary after successful commit"
+msgstr "без информация след успешно подаване"
+
+#: builtin/commit.c:1490
+msgid "show diff in commit message template"
+msgstr "добавяне на разликата към шаблона за съобщението при подаване"
+
+#: builtin/commit.c:1492
+msgid "Commit message options"
+msgstr "Опции за съобщението при подаване"
+
+#: builtin/commit.c:1493 builtin/merge.c:274 builtin/tag.c:414
+msgid "read message from file"
+msgstr "взимане на съобщението от ФАЙЛ"
+
+#: builtin/commit.c:1494
+msgid "author"
+msgstr "АВТОР"
+
+#: builtin/commit.c:1494
+msgid "override author for commit"
+msgstr "задаване на АВТОР за подаването"
+
+#: builtin/commit.c:1495 builtin/gc.c:538
+msgid "date"
+msgstr "ДАТА"
+
+#: builtin/commit.c:1495
+msgid "override date for commit"
+msgstr "задаване на ДАТА за подаването"
+
+#: builtin/commit.c:1497 builtin/commit.c:1498 builtin/commit.c:1499
+#: builtin/commit.c:1500 parse-options.h:328 ref-filter.h:92
+msgid "commit"
+msgstr "ПОДАВАНЕ"
+
+#: builtin/commit.c:1497
+msgid "reuse and edit message from specified commit"
+msgstr "преизползване и редактиране на съобщението от указаното ПОДАВАНЕ"
+
+#: builtin/commit.c:1498
+msgid "reuse message from specified commit"
+msgstr "преизползване на съобщението от указаното ПОДАВАНЕ"
+
+#: builtin/commit.c:1499
+msgid "use autosquash formatted message to fixup specified commit"
+msgstr ""
+"използване на автоматичното съобщение за вкарване на указаното ПОДАВАНЕ в "
+"предходното без следа"
+
+#: builtin/commit.c:1500
+msgid "use autosquash formatted message to squash specified commit"
+msgstr ""
+"използване на автоматичното съобщение за вкарване на указаното ПОДАВАНЕ в "
+"предното"
+
+#: builtin/commit.c:1501
+msgid "the commit is authored by me now (used with -C/-c/--amend)"
+msgstr ""
+"смяна на автора да съвпада с подаващия (използва се с „-C“/„-c“/„--amend“)"
+
+#: builtin/commit.c:1502 builtin/log.c:1634 builtin/merge.c:289
+#: builtin/pull.c:164 builtin/revert.c:110
+msgid "add Signed-off-by:"
+msgstr "добавяне на поле за подпис — „Signed-off-by:“"
+
+#: builtin/commit.c:1503
+msgid "use specified template file"
+msgstr "използване на указания шаблонен ФАЙЛ"
+
+#: builtin/commit.c:1504
+msgid "force edit of commit"
+msgstr "редактиране на подаване"
+
+#: builtin/commit.c:1506
+msgid "include status in commit message template"
+msgstr "вмъкване на състоянието в шаблона за съобщението при подаване"
+
+#: builtin/commit.c:1511
+msgid "Commit contents options"
+msgstr "Опции за избор на файлове при подаване"
+
+#: builtin/commit.c:1512
+msgid "commit all changed files"
+msgstr "подаване на всички променени файлове"
+
+#: builtin/commit.c:1513
+msgid "add specified files to index for commit"
+msgstr "добавяне на указаните файлове към индекса за подаване"
+
+#: builtin/commit.c:1514
+msgid "interactively add files"
+msgstr "интерактивно добавяне на файлове"
+
+#: builtin/commit.c:1515
+msgid "interactively add changes"
+msgstr "интерактивно добавяне на промени"
+
+#: builtin/commit.c:1516
+msgid "commit only specified files"
+msgstr "подаване само на указаните файлове"
+
+#: builtin/commit.c:1517
+msgid "bypass pre-commit and commit-msg hooks"
+msgstr ""
+"без изпълнение на куките преди подаване и при промяна на съобщението за "
+"подаване (pre-commit и commit-msg)"
+
+#: builtin/commit.c:1518
+msgid "show what would be committed"
+msgstr "отпечатване на това, което би било подадено"
+
+#: builtin/commit.c:1531
+msgid "amend previous commit"
+msgstr "поправяне на предишното подаване"
+
+#: builtin/commit.c:1532
+msgid "bypass post-rewrite hook"
+msgstr "без изпълнение на куката след презаписване (post-rewrite)"
+
+#: builtin/commit.c:1539
+msgid "ok to record an empty change"
+msgstr "позволяване на празни подавания"
+
+#: builtin/commit.c:1541
+msgid "ok to record a change with an empty message"
+msgstr "позволяване на подавания с празни съобщения"
+
+#: builtin/commit.c:1614
+#, c-format
+msgid "Corrupt MERGE_HEAD file (%s)"
+msgstr "Повреден файл за върха за сливането „MERGE_HEAD“ (%s)"
+
+#: builtin/commit.c:1621
+msgid "could not read MERGE_MODE"
+msgstr "режимът на сливане „MERGE_MODE“ не може да бъде прочетен"
+
+#: builtin/commit.c:1640
+#, c-format
+msgid "could not read commit message: %s"
+msgstr "съобщението за подаване не може да бъде прочетено: %s"
+
+#: builtin/commit.c:1647
+#, c-format
+msgid "Aborting commit due to empty commit message.\n"
+msgstr "Неизвършване на подаване поради празно съобщение.\n"
+
+#: builtin/commit.c:1652
+#, c-format
+msgid "Aborting commit; you did not edit the message.\n"
+msgstr "Неизвършване на подаване поради нередактирано съобщение.\n"
+
+#: builtin/commit.c:1686
+msgid ""
+"repository has been updated, but unable to write\n"
+"new_index file. Check that disk is not full and quota is\n"
+"not exceeded, and then \"git restore --staged :/\" to recover."
+msgstr ""
+"хранилището е обновено, но новият файл за индекс „new_index“\n"
+"не е записан.  Проверете дали дискът не е препълнен или не сте\n"
+"превишили дисковата си квота.  За възстановяване изпълнете:\n"
+"\n"
+"    git restore --staged :/"
+
+#: builtin/commit-graph.c:11 builtin/commit-graph.c:17
+msgid ""
+"git commit-graph verify [--object-dir <objdir>] [--shallow] [--[no-]progress]"
+msgstr ""
+"git commit-graph verify [--object-dir ДИР_ОБЕКТИ] [--shallow] [--"
+"[no-]progress]"
+
+#: builtin/commit-graph.c:12 builtin/commit-graph.c:22
+msgid ""
+"git commit-graph write [--object-dir <objdir>] [--append|--split] [--"
+"reachable|--stdin-packs|--stdin-commits] [--[no-]progress] <split options>"
+msgstr ""
+"git commit-graph write [--object-dir ДИР_ОБЕКТИ] [--append|--split] [--"
+"reachable|--stdin-packs|--stdin-commits] [--[no-]progress] ОПЦИИ_ЗА_РАЗДЕЛЯНЕ"
+
+#: builtin/commit-graph.c:48 builtin/commit-graph.c:103
+#: builtin/commit-graph.c:187 builtin/fetch.c:179 builtin/log.c:1657
+msgid "dir"
+msgstr "директория"
+
+#: builtin/commit-graph.c:49 builtin/commit-graph.c:104
+#: builtin/commit-graph.c:188
+msgid "The object directory to store the graph"
+msgstr "ДИРекторията_с_ОБЕКТИ за запазване на гра̀фа"
+
+#: builtin/commit-graph.c:51
+msgid "if the commit-graph is split, only verify the tip file"
+msgstr ""
+"ако гра̀фа с подаванията е раздробен, да се проверява само файлът на върха"
+
+#: builtin/commit-graph.c:73 t/helper/test-read-graph.c:23
+#, c-format
+msgid "Could not open commit-graph '%s'"
+msgstr "Графът с подаванията не може да се отвори: „%s“"
+
+#: builtin/commit-graph.c:106
+msgid "start walk at all refs"
+msgstr "обхождането да започне от всички указатели"
+
+#: builtin/commit-graph.c:108
+msgid "scan pack-indexes listed by stdin for commits"
+msgstr ""
+"проверка на подаванията за индексите на пакетите изброени на командния ред"
 
-#: builtin/clean.c:522 git-add--interactive.perl:554
-#: git-add--interactive.perl:559
-#, c-format, perl-format
-msgid "Huh (%s)?\n"
-msgstr "Неправилен избор (%s).\n"
+#: builtin/commit-graph.c:110
+msgid "start walk at commits listed by stdin"
+msgstr "започване на обхождането при подаванията подадени на стандартния вход"
 
-#: builtin/clean.c:664
+#: builtin/commit-graph.c:112
+msgid "include all commits already in the commit-graph file"
+msgstr ""
+"включване на всички подавания, които вече са във файла с гра̀фа на подаванията"
+
+#: builtin/commit-graph.c:115
+msgid "allow writing an incremental commit-graph file"
+msgstr "позволяване на запис на нарастващ файл с гра̀фа на подаванията"
+
+#: builtin/commit-graph.c:117 builtin/commit-graph.c:121
+msgid "maximum number of commits in a non-base split commit-graph"
+msgstr "максимален брой подавания в небазово ниво на раздробен граф"
+
+#: builtin/commit-graph.c:119
+msgid "maximum ratio between two levels of a split commit-graph"
+msgstr ""
+"максимално отношение на броя подавания в две последователни нива в раздробен "
+"граф"
+
+#: builtin/commit-graph.c:137
+msgid "use at most one of --reachable, --stdin-commits, or --stdin-packs"
+msgstr ""
+"опциите „--reachable“, „--stdin-commits“ и „--stdin-packs“ са несъвместими"
+
+#: builtin/config.c:11
+msgid "git config [<options>]"
+msgstr "git config [ОПЦИЯ…]"
+
+#: builtin/config.c:103 builtin/env--helper.c:23
 #, c-format
-msgid "Input ignore patterns>> "
-msgstr "Шаблони за игнорирани елементи≫ "
+msgid "unrecognized --type argument, %s"
+msgstr "непознат аргумент „--type“: %s"
+
+#: builtin/config.c:115
+msgid "only one type at a time"
+msgstr "само по един вид"
+
+#: builtin/config.c:124
+msgid "Config file location"
+msgstr "Местоположение на конфигурационния файл"
+
+#: builtin/config.c:125
+msgid "use global config file"
+msgstr "използване на глобалния конфигурационен файл"
+
+#: builtin/config.c:126
+msgid "use system config file"
+msgstr "използване на системния конфигурационен файл"
+
+#: builtin/config.c:127
+msgid "use repository config file"
+msgstr "използване на конфигурационния файл на хранилището"
+
+#: builtin/config.c:128
+msgid "use per-worktree config file"
+msgstr "използване на конфигурационния файл на работното копие"
+
+#: builtin/config.c:129
+msgid "use given config file"
+msgstr "използване на зададения конфигурационен ФАЙЛ"
+
+#: builtin/config.c:130
+msgid "blob-id"
+msgstr "ИДЕНТИФИКАТОР"
+
+#: builtin/config.c:130
+msgid "read config from given blob object"
+msgstr ""
+"изчитане на конфигурацията от BLOB с този ИДЕНТИФИКАТОР на съдържанието"
+
+#: builtin/config.c:131
+msgid "Action"
+msgstr "Действие"
+
+#: builtin/config.c:132
+msgid "get value: name [value-regex]"
+msgstr "извеждане на стойност: ИМЕ [РЕГУЛЯРЕН_ИЗРАЗ_ЗА_СТОЙНОСТТА]"
+
+#: builtin/config.c:133
+msgid "get all values: key [value-regex]"
+msgstr "извеждане на всички стойности: ключ [РЕГУЛЯРЕН_ИЗРАЗ_ЗА_СТОЙНОСТТА]"
+
+#: builtin/config.c:134
+msgid "get values for regexp: name-regex [value-regex]"
+msgstr ""
+"извеждане на стойностите за РЕГУЛЯРНия_ИЗРАЗ: РЕГУЛЯРЕН_ИЗРАЗ_ЗА_ИМЕТО "
+"[РЕГУЛЯРЕН_ИЗРАЗ_ЗА_СТОЙНОСТТА]"
+
+#: builtin/config.c:135
+msgid "get value specific for the URL: section[.var] URL"
+msgstr "извеждане на стойността за указания адрес: РАЗДЕЛ[.ПРОМЕНЛИВА] АДРЕС"
+
+#: builtin/config.c:136
+msgid "replace all matching variables: name value [value_regex]"
+msgstr ""
+"замяна на всички съвпадащи променливи: ИМЕ СТОЙНОСТ "
+"[РЕГУЛЯРЕН_ИЗРАЗ_ЗА_СТОЙНОСТТА]"
+
+#: builtin/config.c:137
+msgid "add a new variable: name value"
+msgstr "добавяне на нова променлива: ИМЕ СТОЙНОСТ"
+
+#: builtin/config.c:138
+msgid "remove a variable: name [value-regex]"
+msgstr "изтриване на променлива: ИМЕ [РЕГУЛЯРЕН_ИЗРАЗ_ЗА_СТОЙНОСТТА]"
+
+#: builtin/config.c:139
+msgid "remove all matches: name [value-regex]"
+msgstr "изтриване на всички съвпадащи: ИМЕ [РЕГУЛЯРЕН_ИЗРАЗ_ЗА_СТОЙНОСТТА]"
+
+#: builtin/config.c:140
+msgid "rename section: old-name new-name"
+msgstr "преименуване на раздел: СТАРО_ИМЕ НОВО_ИМЕ"
+
+#: builtin/config.c:141
+msgid "remove a section: name"
+msgstr "изтриване на раздел: ИМЕ"
+
+#: builtin/config.c:142
+msgid "list all"
+msgstr "изброяване на всички"
+
+#: builtin/config.c:143
+msgid "open an editor"
+msgstr "отваряне на редактор"
+
+#: builtin/config.c:144
+msgid "find the color configured: slot [default]"
+msgstr "извеждане на зададения цвят: номер [стандартно]"
+
+#: builtin/config.c:145
+msgid "find the color setting: slot [stdout-is-tty]"
+msgstr "извеждане на зададения цвят: номер (стандартният изход е терминал)"
+
+#: builtin/config.c:146
+msgid "Type"
+msgstr "Вид"
+
+#: builtin/config.c:147 builtin/env--helper.c:38
+msgid "value is given this type"
+msgstr "стойността е от този вид"
+
+#: builtin/config.c:148
+msgid "value is \"true\" or \"false\""
+msgstr "СТОЙНОСТТА е „true“ (истина) или „false“ (лъжа)"
+
+#: builtin/config.c:149
+msgid "value is decimal number"
+msgstr "СТОЙНОСТТА е цяло, десетично число"
+
+#: builtin/config.c:150
+msgid "value is --bool or --int"
+msgstr "СТОЙНОСТТА е „--bool“ (булева) или „--int“ (десетично цяло число)"
+
+#: builtin/config.c:151
+msgid "value is a path (file or directory name)"
+msgstr "СТОЙНОСТТА е път (до файл или директория)"
+
+#: builtin/config.c:152
+msgid "value is an expiry date"
+msgstr "стойността е период на валидност/запазване"
+
+#: builtin/config.c:153
+msgid "Other"
+msgstr "Други"
 
-#: builtin/clean.c:701
+#: builtin/config.c:154
+msgid "terminate values with NUL byte"
+msgstr "разделяне на стойностите с нулевия знак „NUL“"
+
+#: builtin/config.c:155
+msgid "show variable names only"
+msgstr "извеждане на имената на променливите"
+
+#: builtin/config.c:156
+msgid "respect include directives on lookup"
+msgstr "при търсене да се уважат и директивите за включване"
+
+#: builtin/config.c:157
+msgid "show origin of config (file, standard input, blob, command line)"
+msgstr ""
+"извеждане на мястото на задаване на настройката (файл, стандартен вход, "
+"обект-BLOB, команден ред)"
+
+#: builtin/config.c:158 builtin/env--helper.c:40
+msgid "value"
+msgstr "СТОЙНОСТ"
+
+#: builtin/config.c:158
+msgid "with --get, use default value when missing entry"
+msgstr "с „--get“ се използва стандартна СТОЙНОСТ при липсваща"
+
+#: builtin/config.c:172
 #, c-format
-msgid "WARNING: Cannot find items matched by: %s"
-msgstr "ПРЕДУПРЕЖДЕНИЕ: Никой обект не напасва на „%s“"
+msgid "wrong number of arguments, should be %d"
+msgstr "неправилен брой аргументи, трябва да е точно %d"
 
-#: builtin/clean.c:722
-msgid "Select items to delete"
-msgstr "Избиране на обекти за изтриване"
+#: builtin/config.c:174
+#, c-format
+msgid "wrong number of arguments, should be from %d to %d"
+msgstr "неправилен брой аргументи, трябва да е от %d до %d включително"
 
-#. TRANSLATORS: Make sure to keep [y/N] as is
-#: builtin/clean.c:763
+#: builtin/config.c:308
 #, c-format
-msgid "Remove %s [y/N]? "
-msgstr "Да се изтрие ли „%s“? „y“ —  да, „N“ — НЕ"
+msgid "invalid key pattern: %s"
+msgstr "неправилен шаблон за ключ: „%s“"
 
-#
-#: builtin/clean.c:788 git-add--interactive.perl:1717
+#: builtin/config.c:344
 #, c-format
-msgid "Bye.\n"
-msgstr "Изход.\n"
+msgid "failed to format default config value: %s"
+msgstr "неуспешно форматиране на стандартната стойност на настройка: %s"
+
+#: builtin/config.c:401
+#, c-format
+msgid "cannot parse color '%s'"
+msgstr "„%s“ не може да се анализира като цвят"
+
+#: builtin/config.c:443
+msgid "unable to parse default color value"
+msgstr "неразпозната стойност на стандартния цвят"
+
+#: builtin/config.c:496 builtin/config.c:742
+msgid "not in a git directory"
+msgstr "не е в директория под Git"
+
+#: builtin/config.c:499
+msgid "writing to stdin is not supported"
+msgstr "не се поддържа записване в стандартния вход"
+
+#: builtin/config.c:502
+msgid "writing config blobs is not supported"
+msgstr "обекти-BLOB в настройките не се поддържат"
 
-#: builtin/clean.c:796
+#: builtin/config.c:587
+#, c-format
 msgid ""
-"clean               - start cleaning\n"
-"filter by pattern   - exclude items from deletion\n"
-"select by numbers   - select items to be deleted by numbers\n"
-"ask each            - confirm each deletion (like \"rm -i\")\n"
-"quit                - stop cleaning\n"
-"help                - this screen\n"
-"?                   - help for prompt selection"
+"# This is Git's per-user configuration file.\n"
+"[user]\n"
+"# Please adapt and uncomment the following lines:\n"
+"#\tname = %s\n"
+"#\temail = %s\n"
 msgstr ""
-"clean               — начало на изчистването\n"
-"filter by pattern   — шаблон за обекти, които да не се трият\n"
-"select by numbers   — номера на обекти, които да се трият\n"
-"ask each            — потвърждаване на всяко изтриване (подобно на „rm -i“)\n"
-"quit                — край на изчистването\n"
-"help                — този край\n"
-"?                   — подсказка за шаблоните"
+"# Това е потребителският ви конфигурационен файл за Git.\n"
+"[user]\n"
+"# Проверете и разкоментирайте следните два реда:\n"
+"#\tname = %s\n"
+"#\temail = %s\n"
+
+#: builtin/config.c:611
+msgid "only one config file at a time"
+msgstr "само по един конфигурационен файл"
+
+#: builtin/config.c:616
+msgid "--local can only be used inside a git repository"
+msgstr "„--local“ може да се използва само в хранилище"
+
+#: builtin/config.c:619
+msgid "--blob can only be used inside a git repository"
+msgstr "„--blob“ може да се използва само в хранилище"
+
+#: builtin/config.c:638
+msgid "$HOME not set"
+msgstr "променливата „HOME“ не е зададена"
+
+#: builtin/config.c:658
+msgid ""
+"--worktree cannot be used with multiple working trees unless the config\n"
+"extension worktreeConfig is enabled. Please read \"CONFIGURATION FILE\"\n"
+"section in \"git help worktree\" for details"
+msgstr ""
+"опцията „--worktre“ не приема множество работни дървета, преди\n"
+"включването на разширението в настройките „worktreeConfig“.  За\n"
+"повече информация вижте раздела „CONFIGURATION FILE“ в\n"
+"„git help worktree“"
+
+#: builtin/config.c:688
+msgid "--get-color and variable type are incoherent"
+msgstr "опцията „--get-color“ не съответства на вида на променливата"
+
+#: builtin/config.c:693
+msgid "only one action at a time"
+msgstr "само по едно действие"
+
+#: builtin/config.c:706
+msgid "--name-only is only applicable to --list or --get-regexp"
+msgstr ""
+"опцията „--name-only“ е приложима само към опциите „--list“ и „--get-regexp“"
+
+#: builtin/config.c:712
+msgid ""
+"--show-origin is only applicable to --get, --get-all, --get-regexp, and --"
+"list"
+msgstr ""
+"опцията „--show-origin“ е приложима само към опциите „--get“, „--get-all“, "
+"„--get-regexp“ и „--list“"
+
+#: builtin/config.c:718
+msgid "--default is only applicable to --get"
+msgstr "опцията „--default“ е приложима само към опцията „--get“"
+
+#: builtin/config.c:731
+#, c-format
+msgid "unable to read config file '%s'"
+msgstr "конфигурационният файл „%s“ не може да бъде прочетен"
+
+#: builtin/config.c:734
+msgid "error processing config file(s)"
+msgstr "грешка при обработката на конфигурационен файл"
+
+#: builtin/config.c:744
+msgid "editing stdin is not supported"
+msgstr "не се поддържа редактиране на стандартния вход"
+
+#: builtin/config.c:746
+msgid "editing blobs is not supported"
+msgstr "не се поддържа редактиране на обекти-BLOB"
+
+#: builtin/config.c:760
+#, c-format
+msgid "cannot create configuration file %s"
+msgstr "конфигурационният файл „%s“ не може да бъде създаден"
+
+#: builtin/config.c:773
+#, c-format
+msgid ""
+"cannot overwrite multiple values with a single value\n"
+"       Use a regexp, --add or --replace-all to change %s."
+msgstr ""
+"множество стойности не могат да се заменят с една.\n"
+"За да промените „%s“, ползвайте регулярен израз или опциите „--add“ и „--"
+"replace-all“."
 
-#: builtin/clean.c:823 git-add--interactive.perl:1793
-msgid "*** Commands ***"
-msgstr "●●● Команди ●●●"
+#: builtin/config.c:847 builtin/config.c:858
+#, c-format
+msgid "no such section: %s"
+msgstr "такъв раззел няма: %s"
 
-#: builtin/clean.c:824 git-add--interactive.perl:1790
-msgid "What now"
-msgstr "Избор на следващо действие"
+#: builtin/count-objects.c:90
+msgid "git count-objects [-v] [-H | --human-readable]"
+msgstr "git count-objects [-v] [-H | --human-readable]"
 
-#: builtin/clean.c:832
-msgid "Would remove the following item:"
-msgid_plural "Would remove the following items:"
-msgstr[0] "Следният обект ще бъде изтрит:"
-msgstr[1] "Следните обекти ще бъдат изтрити:"
+#: builtin/count-objects.c:100
+msgid "print sizes in human readable format"
+msgstr "извеждане на размерите на обектите във формат лесно четим от хора"
 
-#: builtin/clean.c:848
-msgid "No more files to clean, exiting."
-msgstr "Файловете за изчистване свършиха.  Изход от програмата."
+#: builtin/describe.c:26
+msgid "git describe [<options>] [<commit-ish>...]"
+msgstr "git describe [ОПЦИЯ…] [УКАЗАТЕЛ_КЪМ_ПОДАВАНЕ…]"
 
-#: builtin/clean.c:910
-msgid "do not print names of files removed"
-msgstr "без извеждане на имената на файловете, които ще бъдат изтрити"
+#: builtin/describe.c:27
+msgid "git describe [<options>] --dirty"
+msgstr "git describe [ОПЦИЯ…] --dirty"
 
-#: builtin/clean.c:912
-msgid "force"
-msgstr "принудително изтриване"
+#: builtin/describe.c:62
+msgid "head"
+msgstr "основно"
 
-#: builtin/clean.c:913
-msgid "interactive cleaning"
-msgstr "интерактивно изтриване"
+#: builtin/describe.c:62
+msgid "lightweight"
+msgstr "кратко"
 
-#: builtin/clean.c:915
-msgid "remove whole directories"
-msgstr "изтриване на цели директории"
+#: builtin/describe.c:62
+msgid "annotated"
+msgstr "анотирано"
 
-#: builtin/clean.c:916 builtin/describe.c:533 builtin/describe.c:535
-#: builtin/grep.c:871 builtin/log.c:157 builtin/log.c:159
-#: builtin/ls-files.c:548 builtin/name-rev.c:397 builtin/name-rev.c:399
-#: builtin/show-ref.c:176
-msgid "pattern"
-msgstr "ШАБЛОН"
+#: builtin/describe.c:275
+#, c-format
+msgid "annotated tag %s not available"
+msgstr "не съществува анотиран етикет „%s“"
 
-#: builtin/clean.c:917
-msgid "add <pattern> to ignore rules"
-msgstr "добавяне на ШАБЛОН от файлове, които да не се трият"
+#: builtin/describe.c:279
+#, c-format
+msgid "annotated tag %s has no embedded name"
+msgstr "в анотирания етикет „%s“ липсва вградено име"
 
-#: builtin/clean.c:918
-msgid "remove ignored files, too"
-msgstr "изтриване и на игнорираните файлове"
+#: builtin/describe.c:281
+#, c-format
+msgid "tag '%s' is really '%s' here"
+msgstr "етикетът „%s“ тук е всъщност „%s“"
 
-#: builtin/clean.c:920
-msgid "remove only ignored files"
-msgstr "изтриване само на игнорирани файлове"
+#: builtin/describe.c:325
+#, c-format
+msgid "no tag exactly matches '%s'"
+msgstr "никой етикет не напасва точно „%s“"
 
-#: builtin/clean.c:938
-msgid "-x and -X cannot be used together"
-msgstr "опциите „-x“ и „-X“ са несъвместими"
+#: builtin/describe.c:327
+#, c-format
+msgid "No exact match on refs or tags, searching to describe\n"
+msgstr "Никоя версия и етикет не напасват точно.  Търси се по описание\n"
+
+#: builtin/describe.c:381
+#, c-format
+msgid "finished search at %s\n"
+msgstr "търсенето приключи при „%s“\n"
 
-#: builtin/clean.c:942
+#: builtin/describe.c:407
+#, c-format
 msgid ""
-"clean.requireForce set to true and neither -i, -n, nor -f given; refusing to "
-"clean"
+"No annotated tags can describe '%s'.\n"
+"However, there were unannotated tags: try --tags."
 msgstr ""
-"Настройката „clean.requireForce“ е зададена като истина, което изисква някоя "
-"от опциите „-i“, „-n“ или „-f“.  Няма да се извърши изчистване"
+"Никой анотиран етикет не описва „%s“.\n"
+"Съществуват и неанотирани етикети.  Пробвайте с опцията „--tags“."
 
-#: builtin/clean.c:945
+#: builtin/describe.c:411
+#, c-format
 msgid ""
-"clean.requireForce defaults to true and neither -i, -n, nor -f given; "
-"refusing to clean"
+"No tags can describe '%s'.\n"
+"Try --always, or create some tags."
 msgstr ""
-"Настройката „clean.requireForce“ не е зададена, но стандартно е истина, "
-"което изисква някоя от опциите „-i“, „-n“ или „-f“.  Няма да се извърши "
-"изчистване"
-
-#: builtin/clone.c:42
-msgid "git clone [<options>] [--] <repo> [<dir>]"
-msgstr "git clone [ОПЦИЯ…] [--] ХРАНИЛИЩЕ [ДИРЕКТОРИЯ]"
-
-#: builtin/clone.c:87
-msgid "don't create a checkout"
-msgstr "без създаване на работно дърво"
+"Никой етикет не описва „%s“.\n"
+"Пробвайте с опцията „--always“ или създайте етикети."
 
-#: builtin/clone.c:88 builtin/clone.c:90 builtin/init-db.c:479
-msgid "create a bare repository"
-msgstr "създаване на голо хранилище"
+#: builtin/describe.c:441
+#, c-format
+msgid "traversed %lu commits\n"
+msgstr "претърсени са %lu подавания\n"
 
-#: builtin/clone.c:92
-msgid "create a mirror repository (implies bare)"
+#: builtin/describe.c:444
+#, c-format
+msgid ""
+"more than %i tags found; listed %i most recent\n"
+"gave up search at %s\n"
 msgstr ""
-"създаване на хранилище-огледало (включва опцията „--bare“ за голо хранилище)"
-
-#: builtin/clone.c:94
-msgid "to clone from a local repository"
-msgstr "клониране от локално хранилище"
-
-#: builtin/clone.c:96
-msgid "don't use local hardlinks, always copy"
-msgstr "без твърди връзки, файловете винаги да се копират"
-
-#: builtin/clone.c:98
-msgid "setup as shared repository"
-msgstr "настройване за споделено хранилище"
-
-#: builtin/clone.c:100 builtin/clone.c:104
-msgid "pathspec"
-msgstr "път"
-
-#: builtin/clone.c:100 builtin/clone.c:104
-msgid "initialize submodules in the clone"
-msgstr "инициализиране на подмодулите при това клониране"
+"открити са над %i етикета, изведени са последните %i,\n"
+"търсенето бе прекратено при „%s“.\n"
 
-#: builtin/clone.c:107
-msgid "number of submodules cloned in parallel"
-msgstr "брой подмодули, клонирани паралелно"
+#: builtin/describe.c:512
+#, c-format
+msgid "describe %s\n"
+msgstr "описание на „%s“\n"
 
-#: builtin/clone.c:108 builtin/init-db.c:476
-msgid "template-directory"
-msgstr "директория с шаблони"
+#: builtin/describe.c:515
+#, c-format
+msgid "Not a valid object name %s"
+msgstr "Неправилно име на обект „%s“"
 
-#: builtin/clone.c:109 builtin/init-db.c:477
-msgid "directory from which templates will be used"
-msgstr "директория, която съдържа шаблоните, които да се ползват"
+#: builtin/describe.c:523
+#, c-format
+msgid "%s is neither a commit nor blob"
+msgstr "„%s“ не е нито подаване, нито обект-BLOB"
 
-#: builtin/clone.c:111 builtin/clone.c:113 builtin/submodule--helper.c:1223
-#: builtin/submodule--helper.c:1594
-msgid "reference repository"
-msgstr "еталонно хранилище"
+#: builtin/describe.c:537
+msgid "find the tag that comes after the commit"
+msgstr "откриване на етикета, който следва подаване"
 
-#: builtin/clone.c:115 builtin/submodule--helper.c:1225
-#: builtin/submodule--helper.c:1596
-msgid "use --reference only while cloning"
-msgstr "опцията „--reference“ може да се използва само при клониране"
+#: builtin/describe.c:538
+msgid "debug search strategy on stderr"
+msgstr ""
+"извеждане на информация за трасиране на стратегията за търсене на "
+"стандартната грешка"
 
-#: builtin/clone.c:116 builtin/column.c:27 builtin/merge-file.c:44
-#: builtin/pack-objects.c:3166 builtin/repack.c:213
-msgid "name"
-msgstr "ИМЕ"
+#: builtin/describe.c:539
+msgid "use any ref"
+msgstr "използване на произволен указател"
 
-#: builtin/clone.c:117
-msgid "use <name> instead of 'origin' to track upstream"
-msgstr "използване на това ИМЕ вместо „origin“ при проследяване на клони"
+#: builtin/describe.c:540
+msgid "use any tag, even unannotated"
+msgstr "използване на всеки етикет — включително и неанотираните"
 
-#: builtin/clone.c:119
-msgid "checkout <branch> instead of the remote's HEAD"
-msgstr "изтегляне на този КЛОН, а не соченият от отдалечения указател „HEAD“"
+#: builtin/describe.c:541
+msgid "always use long format"
+msgstr "винаги да се ползва дългият формат"
 
-#: builtin/clone.c:121
-msgid "path to git-upload-pack on the remote"
-msgstr "път към командата „git-upload-pack“ на отдалеченото хранилище"
+#: builtin/describe.c:542
+msgid "only follow first parent"
+msgstr "проследяване само на първия родител"
 
-#: builtin/clone.c:122 builtin/fetch.c:150 builtin/grep.c:813
-#: builtin/pull.c:216
-msgid "depth"
-msgstr "ДЪЛБОЧИНА"
+#: builtin/describe.c:545
+msgid "only output exact matches"
+msgstr "извеждане само на точните съвпадения"
 
-#: builtin/clone.c:123
-msgid "create a shallow clone of that depth"
-msgstr "плитко клониране до тази ДЪЛБОЧИНА"
+#: builtin/describe.c:547
+msgid "consider <n> most recent tags (default: 10)"
+msgstr "да се търси само в този БРОЙ последни етикети (стандартно: 10)"
 
-#: builtin/clone.c:124 builtin/fetch.c:152 builtin/pack-objects.c:3157
-#: parse-options.h:154
-msgid "time"
-msgstr "ВРЕМЕ"
+#: builtin/describe.c:549
+msgid "only consider tags matching <pattern>"
+msgstr "да се търси само измежду етикетите напасващи този ШАБЛОН"
 
-#: builtin/clone.c:125
-msgid "create a shallow clone since a specific time"
-msgstr "плитко клониране до момент във времето"
+#: builtin/describe.c:551
+msgid "do not consider tags matching <pattern>"
+msgstr "да не се търси измежду етикетите напасващи този ШАБЛОН"
 
-#: builtin/clone.c:126 builtin/fetch.c:154
-msgid "revision"
-msgstr "версия"
+#: builtin/describe.c:553 builtin/name-rev.c:473
+msgid "show abbreviated commit object as fallback"
+msgstr "извеждане на съкратено име на обект като резервен вариант"
 
-#: builtin/clone.c:127 builtin/fetch.c:155
-msgid "deepen history of shallow clone, excluding rev"
-msgstr "задълбочаване на историята на плитко хранилище до изключващ указател"
+#: builtin/describe.c:554 builtin/describe.c:557
+msgid "mark"
+msgstr "МАРКЕР"
 
-#: builtin/clone.c:129
-msgid "clone only one branch, HEAD or --branch"
-msgstr ""
-"клониране само на един клон — или сочения от отдалечения „HEAD“, или изрично "
-"зададения с „--branch“"
+#: builtin/describe.c:555
+msgid "append <mark> on dirty working tree (default: \"-dirty\")"
+msgstr "добавяне на такъв МАРКЕР на работното дърво (стандартно е „-dirty“)"
 
-#: builtin/clone.c:131
-msgid "don't clone any tags, and make later fetches not to follow them"
+#: builtin/describe.c:558
+msgid "append <mark> on broken working tree (default: \"-broken\")"
 msgstr ""
-"без клониране на етикети, като последващите доставяния няма да ги следят"
+"добавяне на такъв МАРКЕР на счупеното работно дърво (стандартно е „-broken“)"
 
-#: builtin/clone.c:133
-msgid "any cloned submodules will be shallow"
-msgstr "всички клонирани подмодули ще са плитки"
+#: builtin/describe.c:576
+msgid "--long is incompatible with --abbrev=0"
+msgstr "Опциите „--long“ и „--abbrev=0“ са несъвместими"
 
-#: builtin/clone.c:134 builtin/init-db.c:485
-msgid "gitdir"
-msgstr "СЛУЖЕБНА_ДИРЕКТОРИЯ"
+#: builtin/describe.c:605
+msgid "No names found, cannot describe anything."
+msgstr "Не са открити имена — нищо не може да бъде описано."
 
-#: builtin/clone.c:135 builtin/init-db.c:486
-msgid "separate git dir from working tree"
-msgstr "отделна СЛУЖЕБНА_ДИРЕКТОРИЯ за git извън работното дърво"
+#: builtin/describe.c:656
+msgid "--dirty is incompatible with commit-ishes"
+msgstr "опцията „--dirty“ е несъвместима с указател към подаване"
 
-#: builtin/clone.c:136
-msgid "key=value"
-msgstr "КЛЮЧ=СТОЙНОСТ"
+#: builtin/describe.c:658
+msgid "--broken is incompatible with commit-ishes"
+msgstr "опцията „--broken“ е несъвместима с указател към подаване"
 
-#: builtin/clone.c:137
-msgid "set config inside the new repository"
-msgstr "задаване на настройките на новото хранилище"
+#: builtin/diff.c:84
+#, c-format
+msgid "'%s': not a regular file or symlink"
+msgstr "„%s“: не е нито обикновен файл, нито символна връзка"
 
-#: builtin/clone.c:138 builtin/fetch.c:173 builtin/pull.c:229
-#: builtin/push.c:583
-msgid "use IPv4 addresses only"
-msgstr "само адреси IPv4"
+#: builtin/diff.c:235
+#, c-format
+msgid "invalid option: %s"
+msgstr "неправилна опция: %s"
 
-#: builtin/clone.c:140 builtin/fetch.c:175 builtin/pull.c:232
-#: builtin/push.c:585
-msgid "use IPv6 addresses only"
-msgstr "само адреси IPv6"
+#: builtin/diff.c:350
+msgid "Not a git repository"
+msgstr "Не е хранилище на Git"
 
-#: builtin/clone.c:278
-msgid ""
-"No directory name could be guessed.\n"
-"Please specify a directory on the command line"
-msgstr ""
-"Името на директорията не може да бъде отгатнато.\n"
-"Задайте директорията изрично на командния ред"
+#: builtin/diff.c:394
+#, c-format
+msgid "invalid object '%s' given."
+msgstr "зададен е неправилен обект „%s“."
 
-#: builtin/clone.c:331
+#: builtin/diff.c:403
 #, c-format
-msgid "info: Could not add alternate for '%s': %s\n"
-msgstr ""
-"ПРЕДУПРЕЖДЕНИЕ: не може да се добави алтернативен източник на „%s“: %s\n"
+msgid "more than two blobs given: '%s'"
+msgstr "зададени са повече от 2 обекта-BLOB: „%s“"
 
-#: builtin/clone.c:403
+#: builtin/diff.c:408
 #, c-format
-msgid "failed to open '%s'"
-msgstr "директорията „%s“ не може да бъде отворена"
+msgid "unhandled object '%s' given."
+msgstr "зададен е неподдържан обект „%s“."
 
-#: builtin/clone.c:411
-#, c-format
-msgid "%s exists and is not a directory"
-msgstr "„%s“ съществува и не е директория"
+#: builtin/difftool.c:30
+msgid "git difftool [<options>] [<commit> [<commit>]] [--] [<path>...]"
+msgstr "git difftool [ОПЦИЯ…] [ПОДАВАНЕ [ПОДАВАНЕ]] [[--] ПЪТ…]"
 
-#: builtin/clone.c:425
+#: builtin/difftool.c:260
 #, c-format
-msgid "failed to stat %s\n"
-msgstr "не може да бъде получена информация чрез „stat“ за „%s“\n"
+msgid "failed: %d"
+msgstr "неуспешно действие с изходен код: %d"
 
-#: builtin/clone.c:447
+#: builtin/difftool.c:302
 #, c-format
-msgid "failed to create link '%s'"
-msgstr "връзката „%s“ не може да бъде създадена"
+msgid "could not read symlink %s"
+msgstr "символната връзка „%s“ не може да бъде прочетена"
 
-#: builtin/clone.c:451
+#: builtin/difftool.c:304
 #, c-format
-msgid "failed to copy file to '%s'"
-msgstr "файлът не може да бъде копиран като „%s“"
+msgid "could not read symlink file %s"
+msgstr "файлът, сочен от символната връзка „%s“, не може да бъде прочетен"
 
-#: builtin/clone.c:477
+#: builtin/difftool.c:312
 #, c-format
-msgid "done.\n"
-msgstr "действието завърши.\n"
+msgid "could not read object %s for symlink %s"
+msgstr "обектът „%s“ за символната връзка „%s“ не може да бъде прочетен"
 
-#: builtin/clone.c:491
+#: builtin/difftool.c:413
 msgid ""
-"Clone succeeded, but checkout failed.\n"
-"You can inspect what was checked out with 'git status'\n"
-"and retry the checkout with 'git checkout -f HEAD'\n"
+"combined diff formats('-c' and '--cc') are not supported in\n"
+"directory diff mode('-d' and '--dir-diff')."
 msgstr ""
-"Клонирането бе успешно за разлика от подготовката на работното дърво\n"
-"за определен клон.  Все пак можете да проверите кои файлове и от кой\n"
-"клон в момента са изтеглени с командата „git status“.  Можете да\n"
-"завършите изтеглянето на клона с командата „git checkout -f HEAD“.\n"
+"комбинираните формати на разликите („-c“ и „--cc“) не се поддържат\n"
+"в режима за разлики върху директории („-d“ и „--dir-diff“)."
 
-#: builtin/clone.c:568
+#: builtin/difftool.c:634
 #, c-format
-msgid "Could not find remote branch %s to clone."
-msgstr ""
-"Клонът „%s“ от отдалеченото хранилище, което клонирате,\n"
-"и който следва да бъде изтеглен, не съществува."
+msgid "both files modified: '%s' and '%s'."
+msgstr "и двата файла са променени: „%s“ и „%s“."
 
-#: builtin/clone.c:663
-msgid "remote did not send all necessary objects"
-msgstr "отдалеченото хранилище не изпрати всички необходими обекти."
+#: builtin/difftool.c:636
+msgid "working tree file has been left."
+msgstr "работното дърво е изоставено."
 
-#: builtin/clone.c:679
+#: builtin/difftool.c:647
 #, c-format
-msgid "unable to update %s"
-msgstr "обектът „%s“ не може да бъде обновен"
-
-#: builtin/clone.c:728
-msgid "remote HEAD refers to nonexistent ref, unable to checkout.\n"
-msgstr ""
-"указателят „HEAD“ от отдалеченото хранилище сочи към нещо,\n"
-"което не съществува.  Не може да се изтегли определен клон.\n"
+msgid "temporary files exist in '%s'."
+msgstr "в „%s“ има временни файлове."
 
-#: builtin/clone.c:758
-msgid "unable to checkout working tree"
-msgstr "работното дърво не може да бъде подготвено"
+#: builtin/difftool.c:648
+msgid "you may want to cleanup or recover these."
+msgstr "възможно е да ги изчистите или възстановите"
 
-#: builtin/clone.c:803
-msgid "unable to write parameters to config file"
-msgstr "настройките не могат да бъдат записани в конфигурационния файл"
+#: builtin/difftool.c:697
+msgid "use `diff.guitool` instead of `diff.tool`"
+msgstr "използвайте „diff.guitool“ вместо „diff.tool“"
 
-#: builtin/clone.c:866
-msgid "cannot repack to clean up"
-msgstr "не може да се извърши пакетиране за изчистване на файловете"
+#: builtin/difftool.c:699
+msgid "perform a full-directory diff"
+msgstr "разлика по директории"
 
-#: builtin/clone.c:868
-msgid "cannot unlink temporary alternates file"
-msgstr "временният файл за алтернативни обекти не може да бъде изтрит"
+#: builtin/difftool.c:701
+msgid "do not prompt before launching a diff tool"
+msgstr "стартиране на ПРОГРАМАта за разлики без предупреждение"
 
-#: builtin/clone.c:907 builtin/receive-pack.c:1947
-msgid "Too many arguments."
-msgstr "Прекалено много аргументи."
+#: builtin/difftool.c:706
+msgid "use symlinks in dir-diff mode"
+msgstr "следване на символните връзки при разлика по директории"
 
-#: builtin/clone.c:911
-msgid "You must specify a repository to clone."
-msgstr "Трябва да укажете кое хранилище искате да клонирате."
+#: builtin/difftool.c:707
+msgid "tool"
+msgstr "ПРОГРАМА"
 
-#: builtin/clone.c:924
-#, c-format
-msgid "--bare and --origin %s options are incompatible."
-msgstr "опциите „--bare“ и „--origin %s“ са несъвместими."
+#: builtin/difftool.c:708
+msgid "use the specified diff tool"
+msgstr "използване на указаната ПРОГРАМА"
 
-#: builtin/clone.c:927
-msgid "--bare and --separate-git-dir are incompatible."
-msgstr "опциите „--bare“ и „--separate-git-dir“ са несъвместими."
+#: builtin/difftool.c:710
+msgid "print a list of diff tools that may be used with `--tool`"
+msgstr ""
+"извеждане на списък с всички ПРОГРАМи, които може да се ползват с опцията „--"
+"tool“"
 
-#: builtin/clone.c:940
-#, c-format
-msgid "repository '%s' does not exist"
-msgstr "не съществува хранилище „%s“"
+#: builtin/difftool.c:713
+msgid ""
+"make 'git-difftool' exit when an invoked diff tool returns a non - zero exit "
+"code"
+msgstr ""
+"„git-difftool“ да спре работа, когато стартираната ПРОГРАМА завърши с "
+"ненулев код"
 
-#: builtin/clone.c:946 builtin/fetch.c:1460
-#, c-format
-msgid "depth %s is not a positive number"
-msgstr "дълбочината трябва да е положително цяло число, а не „%s“"
+#: builtin/difftool.c:716
+msgid "specify a custom command for viewing diffs"
+msgstr "команда за разглеждане на разлики"
 
-#: builtin/clone.c:956
-#, c-format
-msgid "destination path '%s' already exists and is not an empty directory."
-msgstr "целевият път „%s“ съществува и не е празна директория."
+#: builtin/difftool.c:717
+msgid "passed to `diff`"
+msgstr "подава се към „diff“"
+
+#: builtin/difftool.c:732
+msgid "difftool requires worktree or --no-index"
+msgstr "„git-difftool“ изисква работно дърво или опцията „--no-index“"
+
+#: builtin/difftool.c:739
+msgid "--dir-diff is incompatible with --no-index"
+msgstr "опциите „--dir-diff“ и „--no-index“ са несъвместими"
+
+#: builtin/difftool.c:742
+msgid "--gui, --tool and --extcmd are mutually exclusive"
+msgstr "опциите „--gui“, „--tool“ и „--extcmd“ са несъвместими една с друга"
 
-#: builtin/clone.c:966
-#, c-format
-msgid "working tree '%s' already exists."
-msgstr "в „%s“ вече съществува работно дърво."
+#: builtin/difftool.c:750
+msgid "no <tool> given for --tool=<tool>"
+msgstr "не е зададена програма за „--tool=ПРОГРАМА“"
 
-#: builtin/clone.c:981 builtin/clone.c:1002 builtin/difftool.c:270
-#: builtin/worktree.c:246 builtin/worktree.c:276
-#, c-format
-msgid "could not create leading directories of '%s'"
-msgstr "родителските директории на „%s“ не могат да бъдат създадени"
+#: builtin/difftool.c:757
+msgid "no <cmd> given for --extcmd=<cmd>"
+msgstr "не е зададена команда за „--extcmd=КОМАНДА“"
 
-#: builtin/clone.c:986
-#, c-format
-msgid "could not create work tree dir '%s'"
-msgstr "работното дърво в „%s“ не може да бъде създадено."
+#: builtin/env--helper.c:6
+msgid "git env--helper --type=[bool|ulong] <options> <env-var>"
+msgstr "git env--helper --type=[bool|ulong] ОПЦИИ ПРОМЕНЛИВИ"
 
-#: builtin/clone.c:1006
-#, c-format
-msgid "Cloning into bare repository '%s'...\n"
-msgstr "Клониране и създаване на голо хранилище в „%s“…\n"
+#: builtin/env--helper.c:37 builtin/hash-object.c:98
+msgid "type"
+msgstr "ВИД"
 
-#: builtin/clone.c:1008
-#, c-format
-msgid "Cloning into '%s'...\n"
-msgstr "Клониране и създаване на хранилище в „%s“…\n"
+#: builtin/env--helper.c:41
+msgid "default for git_env_*(...) to fall back on"
+msgstr "стандартна, резервна стойност за „git_env_*(…)“"
 
-#: builtin/clone.c:1032
-msgid ""
-"clone --recursive is not compatible with both --reference and --reference-if-"
-"able"
+#: builtin/env--helper.c:43
+msgid "be quiet only use git_env_*() value as exit code"
 msgstr ""
-"Опцията „--recursive“ е несъвместима с опциите „--reference“ и „--reference-"
-"if-able“"
+"без извеждане на информация — стойността на „git_env_*()“ да е изходен код"
 
-#: builtin/clone.c:1093
-msgid "--depth is ignored in local clones; use file:// instead."
+#: builtin/env--helper.c:62
+#, c-format
+msgid "option `--default' expects a boolean value with `--type=bool`, not `%s`"
 msgstr ""
-"При локално клониране опцията „--depth“ се прескача.  Ползвайте схемата "
-"„file://“."
+"опцията „--default“ изисква булева стойност при „--type=bool“, а не „%s“"
 
-#: builtin/clone.c:1095
-msgid "--shallow-since is ignored in local clones; use file:// instead."
+#: builtin/env--helper.c:77
+#, c-format
+msgid ""
+"option `--default' expects an unsigned long value with `--type=ulong`, not `"
+"%s`"
 msgstr ""
-"При локално клониране опцията „--shallow-since“ се прескача.  Ползвайте "
-"схемата „file://“."
+"опцията „--default“ изисква целочислена стойност без знак при „--"
+"type=ulong“, а не „%s“"
 
-#: builtin/clone.c:1097
-msgid "--shallow-exclude is ignored in local clones; use file:// instead."
-msgstr ""
-"При локално клониране опцията „--shallow-exclude“ се прескача.  Ползвайте "
-"схемата „file://“."
+#: builtin/fast-export.c:29
+msgid "git fast-export [rev-list-opts]"
+msgstr "git fast-export [ОПЦИИ_ЗА_СПИСЪКА_С_ВЕРСИИ]"
 
-#: builtin/clone.c:1099
-msgid "--filter is ignored in local clones; use file:// instead."
+#: builtin/fast-export.c:852
+msgid "Error: Cannot export nested tags unless --mark-tags is specified."
 msgstr ""
-"При локално клониране опцията „--filter“ се прескача.  Ползвайте схемата "
-"„file://“."
+"Грешка: непреките етикети не се изнасят, освен ако не зададете „--mark-tags“."
 
-#: builtin/clone.c:1102
-msgid "source repository is shallow, ignoring --local"
-msgstr "клонираното хранилище е плитко, затова опцията „--local“ се прескача"
+#: builtin/fast-export.c:1152
+msgid "show progress after <n> objects"
+msgstr "Съобщение за напредъка на всеки такъв БРОЙ обекта"
 
-#: builtin/clone.c:1107
-msgid "--local is ignored"
-msgstr "опцията „--local“ се прескача"
+#: builtin/fast-export.c:1154
+msgid "select handling of signed tags"
+msgstr "Как да се обработват подписаните етикети"
 
-#: builtin/clone.c:1169 builtin/clone.c:1177
-#, c-format
-msgid "Remote branch %s not found in upstream %s"
-msgstr "Отдалеченият клон „%s“ липсва в клонираното хранилище „%s“"
+#: builtin/fast-export.c:1157
+msgid "select handling of tags that tag filtered objects"
+msgstr "Как да се обработват етикетите на филтрираните обекти"
 
-#: builtin/clone.c:1180
-msgid "You appear to have cloned an empty repository."
-msgstr "Изглежда клонирахте празно хранилище."
+#: builtin/fast-export.c:1160
+msgid "select handling of commit messages in an alternate encoding"
+msgstr ""
+"как да се обработват съобщенията за подаване, които са в друго кодиране"
 
-#: builtin/column.c:10
-msgid "git column [<options>]"
-msgstr "git column [ОПЦИЯ…]"
+#: builtin/fast-export.c:1163
+msgid "Dump marks to this file"
+msgstr "Запазване на маркерите в този ФАЙЛ"
 
-#: builtin/column.c:27
-msgid "lookup config vars"
-msgstr "извеждане на настройките"
+#: builtin/fast-export.c:1165
+msgid "Import marks from this file"
+msgstr "Внасяне на маркерите от този ФАЙЛ"
 
-#: builtin/column.c:28 builtin/column.c:29
-msgid "layout to use"
-msgstr "как да се подреди резултата"
+#: builtin/fast-export.c:1169
+msgid "Import marks from this file if it exists"
+msgstr "Внасяне на маркерите от този ФАЙЛ, ако съществува"
 
-#: builtin/column.c:30
-msgid "Maximum width"
-msgstr "Максимална широчина"
+#: builtin/fast-export.c:1171
+msgid "Fake a tagger when tags lack one"
+msgstr "Да се използва изкуствено име на човек при липса на задаващ етикета"
 
-#: builtin/column.c:31
-msgid "Padding space on left border"
-msgstr "Поле в знаци отляво"
+#: builtin/fast-export.c:1173
+msgid "Output full tree for each commit"
+msgstr "Извеждане на цялото дърво за всяко подаване"
 
-#: builtin/column.c:32
-msgid "Padding space on right border"
-msgstr "Поле в знаци отдясно"
+#: builtin/fast-export.c:1175
+msgid "Use the done feature to terminate the stream"
+msgstr "Използване на маркер за завършване на потока"
 
-#: builtin/column.c:33
-msgid "Padding space between columns"
-msgstr "Поле в знаци между колоните"
+#: builtin/fast-export.c:1176
+msgid "Skip output of blob data"
+msgstr "Без извеждане на съдържанието на обектите-BLOB"
 
-#: builtin/column.c:51
-msgid "--command must be the first argument"
-msgstr "опцията „--command“ трябва да е първият аргумент"
+#: builtin/fast-export.c:1177 builtin/log.c:1705
+msgid "refspec"
+msgstr "УКАЗАТЕЛ_НА_ВЕРСИЯ"
 
-#: builtin/commit.c:37
-msgid "git commit [<options>] [--] <pathspec>..."
-msgstr "git commit [ОПЦИЯ…] [--] ПЪТ…"
+#: builtin/fast-export.c:1178
+msgid "Apply refspec to exported refs"
+msgstr "Прилагане на УКАЗАТЕЛя_НА_ВЕРСИЯ към изнесените указатели"
 
-#: builtin/commit.c:42
-msgid "git status [<options>] [--] <pathspec>..."
-msgstr "git status [ОПЦИЯ…] [--] ПЪТ…"
+#: builtin/fast-export.c:1179
+msgid "anonymize output"
+msgstr "анонимизиране на извежданата информация"
 
-#: builtin/commit.c:47
-msgid ""
-"You asked to amend the most recent commit, but doing so would make\n"
-"it empty. You can repeat your command with --allow-empty, or you can\n"
-"remove the commit entirely with \"git reset HEAD^\".\n"
+#: builtin/fast-export.c:1181
+msgid "Reference parents which are not in fast-export stream by object id"
 msgstr ""
-"Поискахте да поправите последното си подаване.  Това действие ще превърне\n"
-"подаването в празно.  Можете или да го повторите като разрешите такива "
-"подавания\n"
-"с опцията „--allow-empty“, или да го изтриете от историята с командата:\n"
-"„git reset HEAD^“.\n"
+"Указване на родителите, които не са в потока на бързо изнасяне, с "
+"идентификатор на обект"
 
-#: builtin/commit.c:52
-msgid ""
-"The previous cherry-pick is now empty, possibly due to conflict resolution.\n"
-"If you wish to commit it anyway, use:\n"
-"\n"
-"    git commit --allow-empty\n"
-"\n"
-msgstr ""
-"Предишното отбрано подаване вече е празно, като най-вероятната причина е\n"
-"корекция на конфликт.  Ако все пак искате да го ползвате, използвайте "
-"командата:\n"
-"\n"
-"    git commit --allow-empty\n"
-"\n"
+#: builtin/fast-export.c:1183
+msgid "Show original object ids of blobs/commits"
+msgstr "Извеждане на първоначалните идентификатори на обектите BLOB/подавяния"
 
-#: builtin/commit.c:59
-msgid "Otherwise, please use 'git reset'\n"
-msgstr "В противен случай използвайте командата „git reset“\n"
+#: builtin/fast-export.c:1185
+msgid "Label tags with mark ids"
+msgstr "Задаване на идентификатори на маркери на етикетите"
 
-#: builtin/commit.c:62
-msgid ""
-"If you wish to skip this commit, use:\n"
-"\n"
-"    git reset\n"
-"\n"
-"Then \"git cherry-pick --continue\" will resume cherry-picking\n"
-"the remaining commits.\n"
-msgstr ""
-"Ако искате да прескочите това подаване, използвайте командата:\n"
-"\n"
-"    git reset\n"
-"\n"
-"Чрез командата „git cherry-pick --continue“ ще продължите отбирането на\n"
-"останалите подавания.\n"
+#: builtin/fast-export.c:1220
+msgid "Cannot pass both --import-marks and --import-marks-if-exists"
+msgstr "опциите „--import-marks“ и „--import-marks-if-exists“ са несъвместими"
 
-#: builtin/commit.c:293
-msgid "failed to unpack HEAD tree object"
-msgstr "върховото дърво (HEAD tree object) не може да бъде извадено от пакет"
+#: builtin/fetch.c:34
+msgid "git fetch [<options>] [<repository> [<refspec>...]]"
+msgstr "git fetch [ОПЦИЯ…] [ХРАНИЛИЩЕ [УКАЗАТЕЛ…]]"
 
-#: builtin/commit.c:334
-msgid "unable to create temporary index"
-msgstr "временният индекс не може да бъде създаден"
+#: builtin/fetch.c:35
+msgid "git fetch [<options>] <group>"
+msgstr "git fetch [ОПЦИЯ…] ГРУПА"
 
-#: builtin/commit.c:340
-msgid "interactive add failed"
-msgstr "неуспешно интерактивно добавяне"
+#: builtin/fetch.c:36
+msgid "git fetch --multiple [<options>] [(<repository> | <group>)...]"
+msgstr "git fetch --multiple [ОПЦИЯ…] [(ХРАНИЛИЩЕ | ГРУПА)…]"
 
-#: builtin/commit.c:353
-msgid "unable to update temporary index"
-msgstr "временният индекс не може да бъде обновен"
+#: builtin/fetch.c:37
+msgid "git fetch --all [<options>]"
+msgstr "git fetch --all [ОПЦИЯ…]"
 
-#: builtin/commit.c:355
-msgid "Failed to update main cache tree"
-msgstr "Дървото на основния кеш не може да бъде обновено"
+#: builtin/fetch.c:116
+msgid "fetch.parallel cannot be negative"
+msgstr "опцията „fetch.parallel“ трябва да е неотрицателна"
 
-#: builtin/commit.c:380 builtin/commit.c:403 builtin/commit.c:449
-msgid "unable to write new_index file"
-msgstr "новият индекс не може да бъде записан"
+#: builtin/fetch.c:139 builtin/pull.c:204
+msgid "fetch from all remotes"
+msgstr "доставяне от всички отдалечени хранилища"
 
-#: builtin/commit.c:432
-msgid "cannot do a partial commit during a merge."
-msgstr "по време на сливане не може да се извърши частично подаване."
+#: builtin/fetch.c:141 builtin/pull.c:248
+msgid "set upstream for git pull/fetch"
+msgstr "задаване на клон за следене за издърпване/доставяне"
 
-#: builtin/commit.c:434
-msgid "cannot do a partial commit during a cherry-pick."
-msgstr "по време на отбиране не може да се извърши частично подаване."
+#: builtin/fetch.c:143 builtin/pull.c:207
+msgid "append to .git/FETCH_HEAD instead of overwriting"
+msgstr "добавяне към „.git/FETCH_HEAD“ вместо замяна"
 
-#: builtin/commit.c:442
-msgid "cannot read the index"
-msgstr "индексът не може да бъде прочетен"
+#: builtin/fetch.c:145 builtin/pull.c:210
+msgid "path to upload pack on remote end"
+msgstr "отдалечен път, където да се качи пакетът"
 
-#: builtin/commit.c:461
-msgid "unable to write temporary index file"
-msgstr "временният индекс не може да бъде записан"
+#: builtin/fetch.c:146
+msgid "force overwrite of local reference"
+msgstr "принудително презаписване на локален указател"
 
-#: builtin/commit.c:558
-#, c-format
-msgid "commit '%s' lacks author header"
-msgstr "заглавната част за автор в подаването „%s“ липсва"
+#: builtin/fetch.c:148
+msgid "fetch from multiple remotes"
+msgstr "доставяне от множество отдалечени хранилища"
 
-#: builtin/commit.c:560
-#, c-format
-msgid "commit '%s' has malformed author line"
-msgstr "заглавната част за автор в подаването „%s“ е неправилна"
+#: builtin/fetch.c:150 builtin/pull.c:214
+msgid "fetch all tags and associated objects"
+msgstr "доставяне на всички етикети и принадлежащи обекти"
 
-#: builtin/commit.c:579
-msgid "malformed --author parameter"
-msgstr "неправилен параметър към опцията „--author“"
+#: builtin/fetch.c:152
+msgid "do not fetch all tags (--no-tags)"
+msgstr "без доставянето на всички етикети „--no-tags“"
 
-#: builtin/commit.c:631
-msgid ""
-"unable to select a comment character that is not used\n"
-"in the current commit message"
-msgstr ""
-"не може да се избере знак за коментар — в текущото съобщение за подаване са "
-"използвани всички подобни знаци"
+#: builtin/fetch.c:154
+msgid "number of submodules fetched in parallel"
+msgstr "брой подмодули доставени паралелно"
 
-#: builtin/commit.c:668 builtin/commit.c:701 builtin/commit.c:1029
-#, c-format
-msgid "could not lookup commit %s"
-msgstr "следното подаване не може да бъде открито: %s"
+#: builtin/fetch.c:156 builtin/pull.c:217
+msgid "prune remote-tracking branches no longer on remote"
+msgstr "окастряне на клоните следящи вече несъществуващи отдалечени клони"
 
-#: builtin/commit.c:680 builtin/shortlog.c:316
-#, c-format
-msgid "(reading log message from standard input)\n"
-msgstr "(изчитане на съобщението за подаване от стандартния вход)\n"
+#: builtin/fetch.c:158
+msgid "prune local tags no longer on remote and clobber changed tags"
+msgstr ""
+"окастряне на локалните етикети, които вече не съществуват в отдалеченото "
+"хранилище и презаписване на променените"
 
-#: builtin/commit.c:682
-msgid "could not read log from standard input"
-msgstr "съобщението за подаване не бе прочетено стандартния вход"
+#: builtin/fetch.c:159 builtin/fetch.c:182 builtin/pull.c:141
+msgid "on-demand"
+msgstr "ПРИ НУЖДА"
 
-#: builtin/commit.c:686
-#, c-format
-msgid "could not read log file '%s'"
-msgstr "файлът със съобщението за подаване „%s“ не може да бъде прочетен"
+#: builtin/fetch.c:160
+msgid "control recursive fetching of submodules"
+msgstr "управление на рекурсивното доставяне на подмодулите"
 
-#: builtin/commit.c:715 builtin/commit.c:723
-msgid "could not read SQUASH_MSG"
-msgstr "съобщението за вкарване SQUASH_MSG не може да бъде прочетено"
+#: builtin/fetch.c:164 builtin/pull.c:225
+msgid "keep downloaded pack"
+msgstr "запазване на изтеглените пакети с обекти"
 
-#: builtin/commit.c:720
-msgid "could not read MERGE_MSG"
-msgstr "съобщението за сливане MERGE_MSG не може да бъде прочетено"
+#: builtin/fetch.c:166
+msgid "allow updating of HEAD ref"
+msgstr "позволяване на обновяването на указателя „HEAD“"
 
-#: builtin/commit.c:774
-msgid "could not write commit template"
-msgstr "шаблонът за подаване не може да бъде запазен"
+#: builtin/fetch.c:169 builtin/fetch.c:175 builtin/pull.c:228
+msgid "deepen history of shallow clone"
+msgstr "задълбочаване на историята на плитко хранилище"
 
-#: builtin/commit.c:792
-#, c-format
-msgid ""
-"\n"
-"It looks like you may be committing a merge.\n"
-"If this is not correct, please remove the file\n"
-"\t%s\n"
-"and try again.\n"
-msgstr ""
-"\n"
-"Изглежда, че подавате сливане.  Ако това не е така, изтрийте файла:\n"
-"\n"
-"  %s\n"
-"и опитайте отново.\n"
+#: builtin/fetch.c:171
+msgid "deepen history of shallow repository based on time"
+msgstr "задълбочаване на историята на плитко хранилище до определено време"
 
-#: builtin/commit.c:797
-#, c-format
-msgid ""
-"\n"
-"It looks like you may be committing a cherry-pick.\n"
-"If this is not correct, please remove the file\n"
-"\t%s\n"
-"and try again.\n"
-msgstr ""
-"\n"
-"Изглежда, че извършвате отбрано подаване.  Ако това не е така, изтрийте "
-"файла:\n"
-"\n"
-"  %s\n"
-"и опитайте отново.\n"
+#: builtin/fetch.c:177 builtin/pull.c:231
+msgid "convert to a complete repository"
+msgstr "превръщане в пълно хранилище"
 
-#: builtin/commit.c:810
-#, c-format
-msgid ""
-"Please enter the commit message for your changes. Lines starting\n"
-"with '%c' will be ignored, and an empty message aborts the commit.\n"
-msgstr ""
-"Въведете съобщението за подаване на промените.  Редовете, които започват\n"
-"с „%c“, ще бъдат пропуснати, а празно съобщение преустановява подаването.\n"
+#: builtin/fetch.c:180
+msgid "prepend this to submodule path output"
+msgstr "добавяне на това пред пътя на подмодула"
 
-#: builtin/commit.c:818
-#, c-format
+#: builtin/fetch.c:183
 msgid ""
-"Please enter the commit message for your changes. Lines starting\n"
-"with '%c' will be kept; you may remove them yourself if you want to.\n"
-"An empty message aborts the commit.\n"
+"default for recursive fetching of submodules (lower priority than config "
+"files)"
 msgstr ""
-"Въведете съобщението за подаване на промените.  Редовете, които започват\n"
-"с „%c“, също ще бъдат включени — може да ги изтриете вие.  Празно \n"
-"съобщение преустановява подаването.\n"
+"стандартно рекурсивно изтегляне на подмодулите (файловете с настройки са с "
+"приоритет)"
 
-#: builtin/commit.c:835
-#, c-format
-msgid "%sAuthor:    %.*s <%.*s>"
-msgstr "%sАвтор:   %.*s <%.*s>"
+#: builtin/fetch.c:187 builtin/pull.c:234
+msgid "accept refs that update .git/shallow"
+msgstr "приемане на указатели, които обновяват „.git/shallow“"
 
-#: builtin/commit.c:843
-#, c-format
-msgid "%sDate:      %s"
-msgstr "%sДата:    %s"
+#: builtin/fetch.c:188 builtin/pull.c:236
+msgid "refmap"
+msgstr "КАРТА_С_УКАЗАТЕЛИ"
 
-#: builtin/commit.c:850
-#, c-format
-msgid "%sCommitter: %.*s <%.*s>"
-msgstr "%sПодаващ: %.*s <%.*s>"
+#: builtin/fetch.c:189 builtin/pull.c:237
+msgid "specify fetch refmap"
+msgstr "указване на КАРТАта_С_УКАЗАТЕЛИ за доставяне"
 
-#: builtin/commit.c:867
-msgid "Cannot read index"
-msgstr "Индексът не може да бъде прочетен"
+#: builtin/fetch.c:196
+msgid "report that we have only objects reachable from this object"
+msgstr "докладване, че всички обекти могат са достижими при започване от този"
+
+#: builtin/fetch.c:199
+msgid "run 'gc --auto' after fetching"
+msgstr "изпълняване на „gc --auto“ след доставяне"
+
+#: builtin/fetch.c:201 builtin/pull.c:246
+msgid "check for forced-updates on all updated branches"
+msgstr "проверка за принудителни обновявания на всички клони"
+
+#: builtin/fetch.c:203
+msgid "write the commit-graph after fetching"
+msgstr "запазване на гра̀фа с подаванията след доставяне"
 
-#: builtin/commit.c:933
-msgid "Error building trees"
-msgstr "Грешка при изграждане на дърветата"
+#: builtin/fetch.c:513
+msgid "Couldn't find remote ref HEAD"
+msgstr "Указателят „HEAD“ в отдалеченото хранилище не може да бъде открит"
 
-#: builtin/commit.c:947 builtin/tag.c:257
+#: builtin/fetch.c:653
 #, c-format
-msgid "Please supply the message using either -m or -F option.\n"
-msgstr "Подайте съобщението с някоя от опциите „-m“ или „-F“.\n"
+msgid "configuration fetch.output contains invalid value %s"
+msgstr "настройката „fetch.output“ е с неправилна стойност „%s“"
 
-#: builtin/commit.c:991
+#: builtin/fetch.c:751
 #, c-format
-msgid "--author '%s' is not 'Name <email>' and matches no existing author"
-msgstr ""
-"Опцията „--author '%s'“ не отговаря на форма̀та „Име <е-поща>“ и не съвпада с "
-"никой автор"
+msgid "object %s not found"
+msgstr "обектът „%s“ липсва"
 
-#: builtin/commit.c:1005
-#, c-format
-msgid "Invalid ignored mode '%s'"
-msgstr "Неправилен режим за игнорираните файлове: „%s“"
+#: builtin/fetch.c:755
+msgid "[up to date]"
+msgstr "[актуализиран]"
 
-#: builtin/commit.c:1019 builtin/commit.c:1269
-#, c-format
-msgid "Invalid untracked files mode '%s'"
-msgstr "Неправилен режим за неследените файлове: „%s“"
+#: builtin/fetch.c:768 builtin/fetch.c:784 builtin/fetch.c:856
+msgid "[rejected]"
+msgstr "[отхвърлен]"
 
-#: builtin/commit.c:1057
-msgid "--long and -z are incompatible"
-msgstr "Опциите „--long“ и „-z“ са несъвместими."
+#: builtin/fetch.c:769
+msgid "can't fetch in current branch"
+msgstr "в текущия клон не може да се доставя"
 
-#: builtin/commit.c:1090
-msgid "Using both --reset-author and --author does not make sense"
-msgstr "Опциите „--reset-author“ и „--author“ са несъвместими."
+#: builtin/fetch.c:779
+msgid "[tag update]"
+msgstr "[обновяване на етикетите]"
 
-#: builtin/commit.c:1099
-msgid "You have nothing to amend."
-msgstr "Няма какво да бъде поправено."
+#: builtin/fetch.c:780 builtin/fetch.c:817 builtin/fetch.c:839
+#: builtin/fetch.c:851
+msgid "unable to update local ref"
+msgstr "локален указател не може да бъде обновен"
 
-#: builtin/commit.c:1102
-msgid "You are in the middle of a merge -- cannot amend."
-msgstr "В момента се извършва сливане, не можете да поправяте."
+#: builtin/fetch.c:784
+msgid "would clobber existing tag"
+msgstr "съществуващ етикет ще бъде презаписан"
 
-#: builtin/commit.c:1104
-msgid "You are in the middle of a cherry-pick -- cannot amend."
-msgstr "В момента се извършва отбиране на подаване, не можете да поправяте."
+#: builtin/fetch.c:806
+msgid "[new tag]"
+msgstr "[нов етикет]"
 
-#: builtin/commit.c:1107
-msgid "Options --squash and --fixup cannot be used together"
-msgstr "Опциите „--squash“ и „--fixup“ са несъвместими."
+#: builtin/fetch.c:809
+msgid "[new branch]"
+msgstr "[нов клон]"
 
-#: builtin/commit.c:1117
-msgid "Only one of -c/-C/-F/--fixup can be used."
-msgstr "Опциите „-c“, „-C“, „-F“ и „--fixup““ са несъвместими."
+#: builtin/fetch.c:812
+msgid "[new ref]"
+msgstr "[нов указател]"
 
-#: builtin/commit.c:1119
-msgid "Option -m cannot be combined with -c/-C/-F."
-msgstr "Опцията „-m“ е несъвместима с „-c“, „-C“ и „-F“."
+#: builtin/fetch.c:851
+msgid "forced update"
+msgstr "принудително обновяване"
 
-#: builtin/commit.c:1127
-msgid "--reset-author can be used only with -C, -c or --amend."
-msgstr ""
-"Опцията „--reset-author“ може да се използва само заедно с „-C“, „-c“ или\n"
-"„--amend“."
+#: builtin/fetch.c:856
+msgid "non-fast-forward"
+msgstr "същинско сливане"
 
-#: builtin/commit.c:1144
-msgid "Only one of --include/--only/--all/--interactive/--patch can be used."
+#: builtin/fetch.c:877
+msgid ""
+"Fetch normally indicates which branches had a forced update,\n"
+"but that check has been disabled. To re-enable, use '--show-forced-updates'\n"
+"flag or run 'git config fetch.showForcedUpdates true'."
 msgstr ""
-"Опциите „--include“, „--only“, „--all“, „--interactive“ и „--patch“ са\n"
-"несъвместими."
-
-#: builtin/commit.c:1146
-msgid "No paths with --include/--only does not make sense."
-msgstr "Опциите „--include“ и „--only“ изискват аргументи."
+"За да я включите еднократно ползвайте опцията „--show-forced-updates“, а за "
+"да я включите за постоянно, изпълнете:\n"
+"\n"
+"    git config fetch.showForcedUpdates true"
 
-#: builtin/commit.c:1160 builtin/tag.c:543
+#: builtin/fetch.c:881
 #, c-format
-msgid "Invalid cleanup mode %s"
-msgstr "Несъществуващ режим на изчистване „%s“"
-
-#: builtin/commit.c:1165
-msgid "Paths with -a does not make sense."
-msgstr "Опцията „-a“ е несъвместима със задаването на пътища."
-
-#: builtin/commit.c:1303 builtin/commit.c:1480
-msgid "show status concisely"
-msgstr "кратка информация за състоянието"
+msgid ""
+"It took %.2f seconds to check forced updates. You can use\n"
+"'--no-show-forced-updates' or run 'git config fetch.showForcedUpdates "
+"false'\n"
+" to avoid this check.\n"
+msgstr ""
+"Проверката за принудителни изтласквания отне %.2f сек.  Може да я прескочите "
+"еднократно с опцията „--no-show-forced-updates“, а за да я изключите за "
+"постоянно, изпълнете:\n"
+"\n"
+"    git config fetch.showForcedUpdates false\n"
 
-#: builtin/commit.c:1305 builtin/commit.c:1482
-msgid "show branch information"
-msgstr "информация за клоните"
+#: builtin/fetch.c:911
+#, c-format
+msgid "%s did not send all necessary objects\n"
+msgstr "хранилището „%s“ не изпрати всички необходими обекти\n"
 
-#: builtin/commit.c:1307
-msgid "show stash information"
-msgstr "информация за скатаното"
+#: builtin/fetch.c:932
+#, c-format
+msgid "reject %s because shallow roots are not allowed to be updated"
+msgstr ""
+"отхвърляне на върха „%s“, защото плитките хранилища не могат да бъдат "
+"обновявани"
 
-#: builtin/commit.c:1309 builtin/commit.c:1484
-msgid "compute full ahead/behind values"
-msgstr "изчисляване на точните стойности напред/назад"
+#: builtin/fetch.c:1017 builtin/fetch.c:1155
+#, c-format
+msgid "From %.*s\n"
+msgstr "От %.*s\n"
 
-#: builtin/commit.c:1311
-msgid "version"
-msgstr "версия"
+#: builtin/fetch.c:1028
+#, c-format
+msgid ""
+"some local refs could not be updated; try running\n"
+" 'git remote prune %s' to remove any old, conflicting branches"
+msgstr ""
+"някои локални указатели не могат да бъдат обновени.  Изпълнете командата\n"
+"„git remote prune %s“, за да премахнете остарелите клони, които\n"
+"предизвикват конфликта"
 
-#: builtin/commit.c:1311 builtin/commit.c:1486 builtin/push.c:558
-#: builtin/worktree.c:581
-msgid "machine-readable output"
-msgstr "формат на изхода за четене от програма"
+#: builtin/fetch.c:1125
+#, c-format
+msgid "   (%s will become dangling)"
+msgstr "   (обектът „%s“ ще се окаже извън клон)"
 
-#: builtin/commit.c:1314 builtin/commit.c:1488
-msgid "show status in long format (default)"
-msgstr "подробна информация за състоянието (стандартно)"
+#: builtin/fetch.c:1126
+#, c-format
+msgid "   (%s has become dangling)"
+msgstr "   (обектът „%s“ вече е извън клон)"
 
-#: builtin/commit.c:1317 builtin/commit.c:1491
-msgid "terminate entries with NUL"
-msgstr "разделяне на елементите с нулевия знак „NUL“"
+#: builtin/fetch.c:1158
+msgid "[deleted]"
+msgstr "[изтрит]"
 
-#: builtin/commit.c:1319 builtin/commit.c:1323 builtin/commit.c:1494
-#: builtin/fast-export.c:1001 builtin/fast-export.c:1004 builtin/tag.c:397
-msgid "mode"
-msgstr "РЕЖИМ"
+#: builtin/fetch.c:1159 builtin/remote.c:1035
+msgid "(none)"
+msgstr "(нищо)"
 
-#: builtin/commit.c:1320 builtin/commit.c:1494
-msgid "show untracked files, optional modes: all, normal, no. (Default: all)"
-msgstr ""
-"извеждане на неследените файлове.  Възможните РЕЖИМи са „all“ (подробна "
-"информация), „normal“ (кратка информация), „no“ (без неследените файлове).  "
-"Стандартният РЕЖИМ е: „all“."
+#: builtin/fetch.c:1182
+#, c-format
+msgid "Refusing to fetch into current branch %s of non-bare repository"
+msgstr "Не може да доставите в текущия клон „%s“ на хранилище, което не е голо"
 
-#: builtin/commit.c:1324
-msgid ""
-"show ignored files, optional modes: traditional, matching, no. (Default: "
-"traditional)"
-msgstr ""
-"извеждане на игнорираните файлове.  Възможните РЕЖИМи са "
-"„traditional“ (традиционен), „matching“ (напасващи), „no“ (без игнорираните "
-"файлове).  Стандартният РЕЖИМ е: „traditional“."
+#: builtin/fetch.c:1201
+#, c-format
+msgid "Option \"%s\" value \"%s\" is not valid for %s"
+msgstr "Стойността „%2$s“ за опцията „%1$s“ не е съвместима с „%3$s“"
 
-#: builtin/commit.c:1326 parse-options.h:167
-msgid "when"
-msgstr "КОГА"
+#: builtin/fetch.c:1204
+#, c-format
+msgid "Option \"%s\" is ignored for %s\n"
+msgstr "Опцията „%s“ се прескача при „%s“\n"
 
-#: builtin/commit.c:1327
-msgid ""
-"ignore changes to submodules, optional when: all, dirty, untracked. "
-"(Default: all)"
+#: builtin/fetch.c:1412
+msgid "multiple branches detected, incompatible with --set-upstream"
 msgstr ""
-"игнориране на промените в подмодулите.  Опция с незадължителна стойност — "
-"една от „all“ (всички), „dirty“ (тези с неподадени промени), "
-"„untracked“ (неследени)"
+"засечени са множество клони, това е несъвместимо с опцията „--set-upstream“"
 
-#: builtin/commit.c:1329
-msgid "list untracked files in columns"
-msgstr "извеждане на неследените файлове в колони"
+#: builtin/fetch.c:1427
+msgid "not setting upstream for a remote remote-tracking branch"
+msgstr "не може да указвате клон за следене на отдалечен етикет"
 
-#: builtin/commit.c:1330
-msgid "do not detect renames"
-msgstr "без засичане на преименуванията"
+#: builtin/fetch.c:1429
+msgid "not setting upstream for a remote tag"
+msgstr "не може да указвате клон за следене на отдалечен етикет"
 
-#: builtin/commit.c:1332
-msgid "detect renames, optionally set similarity index"
-msgstr "засичане на преименуванията, може да се зададе коефициент на прилика"
+#: builtin/fetch.c:1431
+msgid "unknown branch type"
+msgstr "непознат вид клон"
 
-#: builtin/commit.c:1352
-msgid "Unsupported combination of ignored and untracked-files arguments"
-msgstr "Неподдържана комбинация от аргументи за игнорирани и неследени файлове"
+#: builtin/fetch.c:1433
+msgid ""
+"no source branch found.\n"
+"you need to specify exactly one branch with the --set-upstream option."
+msgstr ""
+"не е открит клон за следене.\n"
+"Трябва изрично да зададете един клон с опцията „--set-upstream option“."
 
-#: builtin/commit.c:1450
-msgid "suppress summary after successful commit"
-msgstr "без информация след успешно подаване"
+#: builtin/fetch.c:1559 builtin/fetch.c:1622
+#, c-format
+msgid "Fetching %s\n"
+msgstr "Доставяне на „%s“\n"
 
-#: builtin/commit.c:1451
-msgid "show diff in commit message template"
-msgstr "добавяне на разликата към шаблона за съобщението при подаване"
+#: builtin/fetch.c:1569 builtin/fetch.c:1624 builtin/remote.c:100
+#, c-format
+msgid "Could not fetch %s"
+msgstr "„%s“ не може да се достави"
 
-#: builtin/commit.c:1453
-msgid "Commit message options"
-msgstr "Опции за съобщението при подаване"
+#: builtin/fetch.c:1581
+#, c-format
+msgid "could not fetch '%s' (exit code: %d)\n"
+msgstr "„%s“ не може да се достави (изходният код е: %d)\n"
 
-#: builtin/commit.c:1454 builtin/tag.c:394
-msgid "read message from file"
-msgstr "взимане на съобщението от ФАЙЛ"
+#: builtin/fetch.c:1684
+msgid ""
+"No remote repository specified.  Please, specify either a URL or a\n"
+"remote name from which new revisions should be fetched."
+msgstr ""
+"Не сте указали отдалечено хранилище.  Задайте или адрес, или име\n"
+"на отдалечено хранилище, откъдето да се доставят новите версии."
 
-#: builtin/commit.c:1455
-msgid "author"
-msgstr "АВТОР"
+#: builtin/fetch.c:1721
+msgid "You need to specify a tag name."
+msgstr "Трябва да укажете име на етикет."
 
-#: builtin/commit.c:1455
-msgid "override author for commit"
-msgstr "задаване на АВТОР за подаването"
+#: builtin/fetch.c:1771
+msgid "Negative depth in --deepen is not supported"
+msgstr "Отрицателна дълбочина като аргумент на „--deepen“ не се поддържа"
 
-#: builtin/commit.c:1456 builtin/gc.c:501
-msgid "date"
-msgstr "ДАТА"
+#: builtin/fetch.c:1773
+msgid "--deepen and --depth are mutually exclusive"
+msgstr "опциите „--deepen“ и „--depth“ са несъвместими"
 
-#: builtin/commit.c:1456
-msgid "override date for commit"
-msgstr "задаване на ДАТА за подаването"
+#: builtin/fetch.c:1778
+msgid "--depth and --unshallow cannot be used together"
+msgstr "опциите „--depth“ и „--unshallow“ са несъвместими"
 
-#: builtin/commit.c:1457 builtin/merge.c:228 builtin/notes.c:402
-#: builtin/notes.c:565 builtin/tag.c:392
-msgid "message"
-msgstr "СЪОБЩЕНИЕ"
+#: builtin/fetch.c:1780
+msgid "--unshallow on a complete repository does not make sense"
+msgstr "не можете да използвате опцията „--unshallow“ върху пълно хранилище"
 
-#: builtin/commit.c:1457
-msgid "commit message"
-msgstr "СЪОБЩЕНИЕ при подаване"
+#: builtin/fetch.c:1796
+msgid "fetch --all does not take a repository argument"
+msgstr "към „git fetch --all“ не можете да добавите аргумент — хранилище"
 
-#: builtin/commit.c:1458 builtin/commit.c:1459 builtin/commit.c:1460
-#: builtin/commit.c:1461 parse-options.h:270 ref-filter.h:92
-msgid "commit"
-msgstr "ПОДАВАНЕ"
+#: builtin/fetch.c:1798
+msgid "fetch --all does not make sense with refspecs"
+msgstr ""
+"към „git fetch --all“ не можете да добавите аргумент — указател на версия"
 
-#: builtin/commit.c:1458
-msgid "reuse and edit message from specified commit"
-msgstr "преизползване и редактиране на съобщението от указаното ПОДАВАНЕ"
+#: builtin/fetch.c:1807
+#, c-format
+msgid "No such remote or remote group: %s"
+msgstr "Няма нито отдалечено хранилище, нито група от хранилища на име „%s“"
 
-#: builtin/commit.c:1459
-msgid "reuse message from specified commit"
-msgstr "преизползване на съобщението от указаното ПОДАВАНЕ"
+#: builtin/fetch.c:1814
+msgid "Fetching a group and specifying refspecs does not make sense"
+msgstr "Указването на група и указването на версия са несъвместими"
 
-#: builtin/commit.c:1460
-msgid "use autosquash formatted message to fixup specified commit"
+#: builtin/fetch.c:1832
+msgid ""
+"--filter can only be used with the remote configured in extensions."
+"partialclone"
 msgstr ""
-"използване на автоматичното съобщение за вкарване на указаното ПОДАВАНЕ в "
-"предходното без следа"
+"опцията „--filter“ може да се ползва само с отдалеченото хранилище указано в "
+"настройката „extensions.partialClone“"
 
-#: builtin/commit.c:1461
-msgid "use autosquash formatted message to squash specified commit"
+#: builtin/fmt-merge-msg.c:18
+msgid ""
+"git fmt-merge-msg [-m <message>] [--log[=<n>] | --no-log] [--file <file>]"
 msgstr ""
-"използване на автоматичното съобщение за вкарване на указаното ПОДАВАНЕ в "
-"предното"
+"git fmt-merge-msg [-m СЪОБЩЕНИЕ] [--log[=БРОЙ] | --no-log] [--file ФАЙЛ]"
 
-#: builtin/commit.c:1462
-msgid "the commit is authored by me now (used with -C/-c/--amend)"
+#: builtin/fmt-merge-msg.c:674
+msgid "populate log with at most <n> entries from shortlog"
 msgstr ""
-"смяна на автора да съвпада с подаващия (използва се с „-C“/„-c“/„--amend“)"
-
-#: builtin/commit.c:1463 builtin/log.c:1446 builtin/merge.c:242
-#: builtin/pull.c:154 builtin/revert.c:105
-msgid "add Signed-off-by:"
-msgstr "добавяне на поле за подпис — „Signed-off-by:“"
+"вмъкване на журнал състоящ се от не повече от БРОЙ записа от съкратения "
+"журнал"
 
-#: builtin/commit.c:1464
-msgid "use specified template file"
-msgstr "използване на указания шаблонен ФАЙЛ"
+#: builtin/fmt-merge-msg.c:677
+msgid "alias for --log (deprecated)"
+msgstr "псевдоним на „--log“ (остаряло)"
 
-#: builtin/commit.c:1465
-msgid "force edit of commit"
-msgstr "редактиране на подаване"
+#: builtin/fmt-merge-msg.c:680
+msgid "text"
+msgstr "ТЕКСТ"
 
-#: builtin/commit.c:1466
-msgid "default"
-msgstr "стандартно"
+#: builtin/fmt-merge-msg.c:681
+msgid "use <text> as start of message"
+msgstr "за начало на съобщението да се ползва ТЕКСТ"
 
-#: builtin/commit.c:1466 builtin/tag.c:398
-msgid "how to strip spaces and #comments from message"
-msgstr "кои празни знаци и #коментари да се махат от съобщенията"
+#: builtin/fmt-merge-msg.c:682
+msgid "file to read from"
+msgstr "файл, от който да се чете"
 
-#: builtin/commit.c:1467
-msgid "include status in commit message template"
-msgstr "вмъкване на състоянието в шаблона за съобщението при подаване"
+#: builtin/for-each-ref.c:10
+msgid "git for-each-ref [<options>] [<pattern>]"
+msgstr "git for-each-ref [ОПЦИЯ…] [ШАБЛОН]"
 
-#: builtin/commit.c:1469 builtin/merge.c:240 builtin/pull.c:184
-#: builtin/revert.c:113
-msgid "GPG sign commit"
-msgstr "подписване на подаването с GPG"
+#: builtin/for-each-ref.c:11
+msgid "git for-each-ref [--points-at <object>]"
+msgstr "git for-each-ref [--points ОБЕКТ]"
 
-#: builtin/commit.c:1472
-msgid "Commit contents options"
-msgstr "Опции за избор на файлове при подаване"
+#: builtin/for-each-ref.c:12
+msgid "git for-each-ref [(--merged | --no-merged) [<commit>]]"
+msgstr "git for-each-ref[(--merged | --no-merged) [ПОДАВАНЕ]]"
 
-#: builtin/commit.c:1473
-msgid "commit all changed files"
-msgstr "подаване на всички променени файлове"
+#: builtin/for-each-ref.c:13
+msgid "git for-each-ref [--contains [<commit>]] [--no-contains [<commit>]]"
+msgstr "git for-each-ref [--contains [ПОДАВАНЕ]] [--no-contains [ПОДАВАНЕ]]"
 
-#: builtin/commit.c:1474
-msgid "add specified files to index for commit"
-msgstr "добавяне на указаните файлове към индекса за подаване"
+#: builtin/for-each-ref.c:28
+msgid "quote placeholders suitably for shells"
+msgstr "цитиране подходящо за командни интерпретатори на обвивката"
 
-#: builtin/commit.c:1475
-msgid "interactively add files"
-msgstr "интерактивно добавяне на файлове"
+#: builtin/for-each-ref.c:30
+msgid "quote placeholders suitably for perl"
+msgstr "цитиране подходящо за perl"
 
-#: builtin/commit.c:1476
-msgid "interactively add changes"
-msgstr "интерактивно добавяне на промени"
+#: builtin/for-each-ref.c:32
+msgid "quote placeholders suitably for python"
+msgstr "цитиране подходящо за python"
 
-#: builtin/commit.c:1477
-msgid "commit only specified files"
-msgstr "подаване само на указаните файлове"
+#: builtin/for-each-ref.c:34
+msgid "quote placeholders suitably for Tcl"
+msgstr "цитиране подходящо за tcl"
 
-#: builtin/commit.c:1478
-msgid "bypass pre-commit and commit-msg hooks"
-msgstr ""
-"без изпълнение на куките преди подаване и при промяна на съобщението за "
-"подаване (pre-commit и commit-msg)"
+#: builtin/for-each-ref.c:37
+msgid "show only <n> matched refs"
+msgstr "извеждане само на този БРОЙ напаснати указатели"
 
-#: builtin/commit.c:1479
-msgid "show what would be committed"
-msgstr "отпечатване на това, което би било подадено"
+#: builtin/for-each-ref.c:39 builtin/tag.c:439
+msgid "respect format colors"
+msgstr "спазване на цветовете на форма̀та"
 
-#: builtin/commit.c:1492
-msgid "amend previous commit"
-msgstr "поправяне на предишното подаване"
+#: builtin/for-each-ref.c:42
+msgid "print only refs which points at the given object"
+msgstr "извеждане само на указателите, сочещи към ОБЕКТА"
 
-#: builtin/commit.c:1493
-msgid "bypass post-rewrite hook"
-msgstr "без изпълнение на куката след презаписване (post-rewrite)"
+#: builtin/for-each-ref.c:44
+msgid "print only refs that are merged"
+msgstr "извеждане само на слетите указатели"
 
-#: builtin/commit.c:1498
-msgid "ok to record an empty change"
-msgstr "позволяване на празни подавания"
+#: builtin/for-each-ref.c:45
+msgid "print only refs that are not merged"
+msgstr "извеждане само на неслетите указатели"
 
-#: builtin/commit.c:1500
-msgid "ok to record a change with an empty message"
-msgstr "позволяване на подавания с празни съобщения"
+#: builtin/for-each-ref.c:46
+msgid "print only refs which contain the commit"
+msgstr "извеждане само на указателите, които съдържат това ПОДАВАНЕ"
 
-#: builtin/commit.c:1573
-#, c-format
-msgid "Corrupt MERGE_HEAD file (%s)"
-msgstr "Повреден файл за върха за сливането „MERGE_HEAD“ (%s)"
+#: builtin/for-each-ref.c:47
+msgid "print only refs which don't contain the commit"
+msgstr "извеждане само на указателите, които не съдържат това ПОДАВАНЕ"
 
-#: builtin/commit.c:1580
-msgid "could not read MERGE_MODE"
-msgstr "режимът на сливане „MERGE_MODE“ не може да бъде прочетен"
+#: builtin/fsck.c:68 builtin/fsck.c:147 builtin/fsck.c:148
+msgid "unknown"
+msgstr "непознат"
 
-#: builtin/commit.c:1599
+#. TRANSLATORS: e.g. error in tree 01bfda: <more explanation>
+#: builtin/fsck.c:100 builtin/fsck.c:120
 #, c-format
-msgid "could not read commit message: %s"
-msgstr "съобщението за подаване не може да бъде прочетено: %s"
+msgid "error in %s %s: %s"
+msgstr "грешка в %s „%s“: %s"
 
-#: builtin/commit.c:1610
+#. TRANSLATORS: e.g. warning in tree 01bfda: <more explanation>
+#: builtin/fsck.c:114
 #, c-format
-msgid "Aborting commit due to empty commit message.\n"
-msgstr "Неизвършване на подаване поради празно съобщение.\n"
+msgid "warning in %s %s: %s"
+msgstr "предупреждение за %s „%s“: %s"
 
-#: builtin/commit.c:1615
+#: builtin/fsck.c:143 builtin/fsck.c:146
 #, c-format
-msgid "Aborting commit; you did not edit the message.\n"
-msgstr "Неизвършване на подаване поради нередактирано съобщение.\n"
+msgid "broken link from %7s %s"
+msgstr "скъсана връзка от %7s %s"
 
-#: builtin/commit.c:1650
+#: builtin/fsck.c:155
+msgid "wrong object type in link"
+msgstr "неправилен вид обект във връзката"
+
+#: builtin/fsck.c:171
+#, c-format
 msgid ""
-"Repository has been updated, but unable to write\n"
-"new_index file. Check that disk is not full and quota is\n"
-"not exceeded, and then \"git reset HEAD\" to recover."
+"broken link from %7s %s\n"
+"              to %7s %s"
 msgstr ""
-"Хранилището е обновено, но новият файл за индекс „new_index“\n"
-"не е записан.  Проверете дали дискът не е препълнен или не сте\n"
-"превишили дисковата си квота.  След това изпълнете „git reset HEAD“."
+"скъсана връзка от %7s %s\n"
+"              към %7s %s"
 
-#: builtin/commit-graph.c:9
-msgid "git commit-graph [--object-dir <objdir>]"
-msgstr "git commit-graph [--object-dir ДИР_ОБЕКТИ]"
-
-#: builtin/commit-graph.c:10 builtin/commit-graph.c:16
-msgid "git commit-graph read [--object-dir <objdir>]"
-msgstr "git commit-graph read [--object-dir ДИР_ОБЕКТИ]"
+#: builtin/fsck.c:282
+#, c-format
+msgid "missing %s %s"
+msgstr "липсващ обект: %s „%s“"
 
-#: builtin/commit-graph.c:11 builtin/commit-graph.c:21
-msgid ""
-"git commit-graph write [--object-dir <objdir>] [--append] [--stdin-packs|--"
-"stdin-commits]"
-msgstr ""
-"git commit-graph write [--object-dir ДИР_ОБЕКТИ] [--append] [--stdin-packs|--"
-"stdin-commits]"
+#: builtin/fsck.c:309
+#, c-format
+msgid "unreachable %s %s"
+msgstr "недостижим обект: %s „%s“"
 
-#: builtin/commit-graph.c:39 builtin/commit-graph.c:92
-#: builtin/commit-graph.c:147 builtin/fetch.c:161 builtin/log.c:1466
-msgid "dir"
-msgstr "директория"
+#: builtin/fsck.c:329
+#, c-format
+msgid "dangling %s %s"
+msgstr "извън клон: %s „%s“"
 
-#: builtin/commit-graph.c:40 builtin/commit-graph.c:93
-#: builtin/commit-graph.c:148
-msgid "The object directory to store the graph"
-msgstr "ДИРекторията_с_ОБЕКТИ за запазване на гра̀фа"
+#: builtin/fsck.c:339
+msgid "could not create lost-found"
+msgstr "„lost-found“ не може да се създаде"
 
-#: builtin/commit-graph.c:95
-msgid "scan pack-indexes listed by stdin for commits"
-msgstr ""
-"проверка на подаванията за индексите на пакетите изброени на командния ред"
+#: builtin/fsck.c:350
+#, c-format
+msgid "could not finish '%s'"
+msgstr "„%s“ не може да се завърши"
 
-#: builtin/commit-graph.c:97
-msgid "start walk at commits listed by stdin"
-msgstr "започване на обхождането при подаванията подадени на стандартния вход"
+#: builtin/fsck.c:367
+#, c-format
+msgid "Checking %s"
+msgstr "Проверка на „%s“"
 
-#: builtin/commit-graph.c:99
-msgid "include all commits already in the commit-graph file"
-msgstr ""
-"включване на всички подавания, които вече са във файла с гра̀фа на подаванията"
+#: builtin/fsck.c:405
+#, c-format
+msgid "Checking connectivity (%d objects)"
+msgstr "Проверка на свързаността (%d обекта)"
 
-#: builtin/commit-graph.c:108
-msgid "cannot use both --stdin-commits and --stdin-packs"
-msgstr "опциите „--stdin-commits“ и „--stdin-packs“ са несъвместими"
+#: builtin/fsck.c:424
+#, c-format
+msgid "Checking %s %s"
+msgstr "Проверяване на %s „%s“"
 
-#: builtin/config.c:10
-msgid "git config [<options>]"
-msgstr "git config [ОПЦИЯ…]"
+#: builtin/fsck.c:429
+msgid "broken links"
+msgstr "скъсани връзки"
 
-#: builtin/config.c:101
+#: builtin/fsck.c:438
 #, c-format
-msgid "unrecognized --type argument, %s"
-msgstr "непознат аргумент „--type“: %s"
-
-#: builtin/config.c:123
-msgid "Config file location"
-msgstr "Местоположение на конфигурационния файл"
+msgid "root %s"
+msgstr "начална директория „%s“"
 
-#: builtin/config.c:124
-msgid "use global config file"
-msgstr "използване на глобалния конфигурационен файл"
+#: builtin/fsck.c:446
+#, c-format
+msgid "tagged %s %s (%s) in %s"
+msgstr "приложен етикет „%s“ върху „%s“ (%s) в „%s“"
 
-#: builtin/config.c:125
-msgid "use system config file"
-msgstr "използване на системния конфигурационен файл"
+#: builtin/fsck.c:475
+#, c-format
+msgid "%s: object corrupt or missing"
+msgstr "%s: липсващ или повреден обект"
 
-#: builtin/config.c:126
-msgid "use repository config file"
-msgstr "използване на конфигурационния файл на хранилището"
+#: builtin/fsck.c:500
+#, c-format
+msgid "%s: invalid reflog entry %s"
+msgstr "%s: неправилен запис в журнала за указатели „%s“"
 
-#: builtin/config.c:127
-msgid "use given config file"
-msgstr "използване на зададения конфигурационен ФАЙЛ"
+#: builtin/fsck.c:514
+#, c-format
+msgid "Checking reflog %s->%s"
+msgstr "Проверка на журнала на указателите: „%s“ до „%s“"
 
-#: builtin/config.c:128
-msgid "blob-id"
-msgstr "ИДЕНТИФИКАТОР"
+#: builtin/fsck.c:548
+#, c-format
+msgid "%s: invalid sha1 pointer %s"
+msgstr "„%s“: неправилен указател за SHA1: „%s“"
 
-#: builtin/config.c:128
-msgid "read config from given blob object"
-msgstr ""
-"изчитане на конфигурацията от BLOB с този ИДЕНТИФИКАТОР на съдържанието"
+#: builtin/fsck.c:555
+#, c-format
+msgid "%s: not a commit"
+msgstr "%s: не е подаване!"
 
-#: builtin/config.c:129
-msgid "Action"
-msgstr "Действие"
+#: builtin/fsck.c:609
+msgid "notice: No default references"
+msgstr "внимание: няма указатели по подразбиране"
 
-#: builtin/config.c:130
-msgid "get value: name [value-regex]"
-msgstr "извеждане на стойност: ИМЕ [РЕГУЛЯРЕН_ИЗРАЗ_ЗА_СТОЙНОСТТА]"
+#: builtin/fsck.c:624
+#, c-format
+msgid "%s: object corrupt or missing: %s"
+msgstr "„%s“: липсващ обект: „%s“"
 
-#: builtin/config.c:131
-msgid "get all values: key [value-regex]"
-msgstr "извеждане на всички стойности: ключ [РЕГУЛЯРЕН_ИЗРАЗ_ЗА_СТОЙНОСТТА]"
+#: builtin/fsck.c:637
+#, c-format
+msgid "%s: object could not be parsed: %s"
+msgstr "„%s“: не може да се анализира: „%s“"
 
-#: builtin/config.c:132
-msgid "get values for regexp: name-regex [value-regex]"
-msgstr ""
-"извеждане на стойностите за РЕГУЛЯРНия_ИЗРАЗ: РЕГУЛЯРЕН_ИЗРАЗ_ЗА_ИМЕТО "
-"[РЕГУЛЯРЕН_ИЗРАЗ_ЗА_СТОЙНОСТТА]"
+#: builtin/fsck.c:657
+#, c-format
+msgid "bad sha1 file: %s"
+msgstr "неправилен ред с контролна сума по SHA1: „%s“"
 
-#: builtin/config.c:133
-msgid "get value specific for the URL: section[.var] URL"
-msgstr "извеждане на стойността за указания адрес: РАЗДЕЛ[.ПРОМЕНЛИВА] АДРЕС"
+#: builtin/fsck.c:672
+msgid "Checking object directory"
+msgstr "Проверка на директория с обекти"
 
-#: builtin/config.c:134
-msgid "replace all matching variables: name value [value_regex]"
-msgstr ""
-"замяна на всички съвпадащи променливи: ИМЕ СТОЙНОСТ "
-"[РЕГУЛЯРЕН_ИЗРАЗ_ЗА_СТОЙНОСТТА]"
+#: builtin/fsck.c:675
+msgid "Checking object directories"
+msgstr "Проверка на директориите с обекти"
 
-#: builtin/config.c:135
-msgid "add a new variable: name value"
-msgstr "добавяне на нова променлива: ИМЕ СТОЙНОСТ"
+#: builtin/fsck.c:690
+#, c-format
+msgid "Checking %s link"
+msgstr "Проверка на връзките на „%s“"
 
-#: builtin/config.c:136
-msgid "remove a variable: name [value-regex]"
-msgstr "изтриване на променлива: ИМЕ [РЕГУЛЯРЕН_ИЗРАЗ_ЗА_СТОЙНОСТТА]"
+#
+#: builtin/fsck.c:695 builtin/index-pack.c:842
+#, c-format
+msgid "invalid %s"
+msgstr "неправилен указател „%s“"
 
-#: builtin/config.c:137
-msgid "remove all matches: name [value-regex]"
-msgstr "изтриване на всички съвпадащи: ИМЕ [РЕГУЛЯРЕН_ИЗРАЗ_ЗА_СТОЙНОСТТА]"
+#: builtin/fsck.c:702
+#, c-format
+msgid "%s points to something strange (%s)"
+msgstr "„%s“ сочи към нещо необичайно (%s)"
 
-#: builtin/config.c:138
-msgid "rename section: old-name new-name"
-msgstr "преименуване на раздел: СТАРО_ИМЕ НОВО_ИМЕ"
+#: builtin/fsck.c:708
+#, c-format
+msgid "%s: detached HEAD points at nothing"
+msgstr "%s: несвързаният връх „HEAD“ не сочи към нищо"
 
-#: builtin/config.c:139
-msgid "remove a section: name"
-msgstr "изтриване на раздел: ИМЕ"
+#: builtin/fsck.c:712
+#, c-format
+msgid "notice: %s points to an unborn branch (%s)"
+msgstr "предупреждение: „%s“ сочи към все още несъществуващ клон (%s)"
 
-#: builtin/config.c:140
-msgid "list all"
-msgstr "изброяване на всички"
+#: builtin/fsck.c:724
+msgid "Checking cache tree"
+msgstr "Проверка на дървото на кеша"
 
-#: builtin/config.c:141
-msgid "open an editor"
-msgstr "отваряне на редактор"
+#: builtin/fsck.c:729
+#, c-format
+msgid "%s: invalid sha1 pointer in cache-tree"
+msgstr "„%s“: неправилен указател за SHA1 в дървото на кеша"
 
-#: builtin/config.c:142
-msgid "find the color configured: slot [default]"
-msgstr "извеждане на зададения цвят: номер [стандартно]"
+#: builtin/fsck.c:738
+msgid "non-tree in cache-tree"
+msgstr "в дървото на кеша има нещо, което не е дърво"
 
-#: builtin/config.c:143
-msgid "find the color setting: slot [stdout-is-tty]"
-msgstr "извеждане на зададения цвят: номер (стандартният изход е терминал)"
+#: builtin/fsck.c:769
+msgid "git fsck [<options>] [<object>...]"
+msgstr "git fsck [ОПЦИЯ…] [ОБЕКТ…]"
 
-#: builtin/config.c:144
-msgid "Type"
-msgstr "Вид"
+#: builtin/fsck.c:775
+msgid "show unreachable objects"
+msgstr "показване на недостижимите обекти"
 
-#: builtin/config.c:145
-msgid "value is given this type"
-msgstr "стойността е от този вид"
+#: builtin/fsck.c:776
+msgid "show dangling objects"
+msgstr "показване на обектите извън клоните"
 
-#: builtin/config.c:146
-msgid "value is \"true\" or \"false\""
-msgstr "СТОЙНОСТТА е „true“ (истина) или „false“ (лъжа)"
+#: builtin/fsck.c:777
+msgid "report tags"
+msgstr "показване на етикетите"
 
-#: builtin/config.c:147
-msgid "value is decimal number"
-msgstr "СТОЙНОСТТА е цяло, десетично число"
+#: builtin/fsck.c:778
+msgid "report root nodes"
+msgstr "показване на кореновите възли"
 
-#: builtin/config.c:148
-msgid "value is --bool or --int"
-msgstr "СТОЙНОСТТА е „--bool“ (булева) или „--int“ (десетично цяло число)"
+#: builtin/fsck.c:779
+msgid "make index objects head nodes"
+msgstr "задаване на обекти от индекса да са коренови"
 
-#: builtin/config.c:149
-msgid "value is a path (file or directory name)"
-msgstr "СТОЙНОСТТА е път (до файл или директория)"
+#: builtin/fsck.c:780
+msgid "make reflogs head nodes (default)"
+msgstr "проследяване и на указателите от журнала с указателите (стандартно)"
 
-#: builtin/config.c:150
-msgid "value is an expiry date"
-msgstr "стойността е период на валидност/запазване"
+#: builtin/fsck.c:781
+msgid "also consider packs and alternate objects"
+msgstr "допълнително да се проверяват пакетите и алтернативните обекти"
 
-#: builtin/config.c:151
-msgid "Other"
-msgstr "Други"
+#: builtin/fsck.c:782
+msgid "check only connectivity"
+msgstr "проверка само на връзката"
 
-#: builtin/config.c:152
-msgid "terminate values with NUL byte"
-msgstr "разделяне на стойностите с нулевия знак „NUL“"
+#: builtin/fsck.c:783
+msgid "enable more strict checking"
+msgstr "по-строги проверки"
 
-#: builtin/config.c:153
-msgid "show variable names only"
-msgstr "извеждане на имената на променливите"
+#: builtin/fsck.c:785
+msgid "write dangling objects in .git/lost-found"
+msgstr "запазване на обектите извън клоните в директорията „.git/lost-found“"
 
-#: builtin/config.c:154
-msgid "respect include directives on lookup"
-msgstr "при търсене да се уважат и директивите за включване"
+#: builtin/fsck.c:786 builtin/prune.c:132
+msgid "show progress"
+msgstr "показване на напредъка"
 
-#: builtin/config.c:155
-msgid "show origin of config (file, standard input, blob, command line)"
-msgstr ""
-"извеждане на мястото на задаване на настройката (файл, стандартен вход, "
-"обект-BLOB, команден ред)"
+#: builtin/fsck.c:787
+msgid "show verbose names for reachable objects"
+msgstr "показване на подробни имена на достижимите обекти"
 
-#: builtin/config.c:156
-msgid "value"
-msgstr "СТОЙНОСТ"
+#: builtin/fsck.c:846 builtin/index-pack.c:225
+msgid "Checking objects"
+msgstr "Проверка на обектите"
 
-#: builtin/config.c:156
-msgid "with --get, use default value when missing entry"
-msgstr "с „--get“ се използва стандартна СТОЙНОСТ при липсваща"
+#: builtin/fsck.c:874
+#, c-format
+msgid "%s: object missing"
+msgstr "„%s“: липсващ обект"
 
-#: builtin/config.c:332
+#: builtin/fsck.c:885
 #, c-format
-msgid "failed to format default config value: %s"
-msgstr "неуспешно форматиране на стандартната стойност на настройка: %s"
+msgid "invalid parameter: expected sha1, got '%s'"
+msgstr "неправилен параметър: очаква се SHA1, а бе получено: „%s“"
 
-#: builtin/config.c:431
-msgid "unable to parse default color value"
-msgstr "неразпозната стойност на стандартния цвят"
+#: builtin/gc.c:35
+msgid "git gc [<options>]"
+msgstr "git gc [ОПЦИЯ…]"
 
-#: builtin/config.c:575
+#: builtin/gc.c:90
 #, c-format
-msgid ""
-"# This is Git's per-user configuration file.\n"
-"[user]\n"
-"# Please adapt and uncomment the following lines:\n"
-"#\tname = %s\n"
-"#\temail = %s\n"
-msgstr ""
-"# Това е потребителският ви конфигурационен файл за Git.\n"
-"[user]\n"
-"# Проверете и разкоментирайте следните два реда:\n"
-"#\tname = %s\n"
-"#\temail = %s\n"
+msgid "Failed to fstat %s: %s"
+msgstr "Неуспешно изпълнение на „fstat“ върху „%s“: %s"
 
-#: builtin/config.c:603
-msgid "--local can only be used inside a git repository"
-msgstr "„--local“ може да се използва само в хранилище"
+#: builtin/gc.c:126
+#, c-format
+msgid "failed to parse '%s' value '%s'"
+msgstr "стойността на „%s“ — „%s“ не може да се анализира"
 
-#: builtin/config.c:606
-msgid "--blob can only be used inside a git repository"
-msgstr "„--blob“ може да се използва само в хранилище"
+#: builtin/gc.c:475 builtin/init-db.c:55
+#, c-format
+msgid "cannot stat '%s'"
+msgstr "не може да се получи информация чрез „stat“ за директорията „%s“"
 
-#: builtin/config.c:735
+#: builtin/gc.c:484 builtin/notes.c:240 builtin/tag.c:529
 #, c-format
-msgid "cannot create configuration file %s"
-msgstr "конфигурационният файл „%s“ не може да бъде създаден"
+msgid "cannot read '%s'"
+msgstr "файлът „%s“ не може да бъде прочетен"
 
-#: builtin/config.c:748
+#: builtin/gc.c:491
 #, c-format
 msgid ""
-"cannot overwrite multiple values with a single value\n"
-"       Use a regexp, --add or --replace-all to change %s."
+"The last gc run reported the following. Please correct the root cause\n"
+"and remove %s.\n"
+"Automatic cleanup will not be performed until the file is removed.\n"
+"\n"
+"%s"
 msgstr ""
-"множество стойности не могат да се заменят с една.\n"
-"За да промените „%s“, ползвайте регулярен израз или опциите „--add“ и „--"
-"replace-all“."
-
-#: builtin/count-objects.c:90
-msgid "git count-objects [-v] [-H | --human-readable]"
-msgstr "git count-objects [-v] [-H | --human-readable]"
-
-#: builtin/count-objects.c:100
-msgid "print sizes in human readable format"
-msgstr "извеждане на размерите на обектите във формат лесно четим от хора"
-
-#: builtin/describe.c:22
-msgid "git describe [<options>] [<commit-ish>...]"
-msgstr "git describe [ОПЦИЯ…] [УКАЗАТЕЛ_КЪМ_ПОДАВАНЕ…]"
+"При последното изпълнение на „git gc“ бе докладвана грешка.  Коригирайте "
+"причината за\n"
+"нея и изтрийте „%s“.\n"
+"Автоматичното изчистване на боклука няма да работи, преди да изтриете "
+"файла.\n"
+"\n"
+"%s"
 
-#: builtin/describe.c:23
-msgid "git describe [<options>] --dirty"
-msgstr "git describe [ОПЦИЯ…] --dirty"
+#: builtin/gc.c:539
+msgid "prune unreferenced objects"
+msgstr "окастряне на обектите, към които нищо не сочи"
 
-#: builtin/describe.c:57
-msgid "head"
-msgstr "основно"
+#: builtin/gc.c:541
+msgid "be more thorough (increased runtime)"
+msgstr "изчерпателно търсене на боклука (за сметка на повече време работа)"
 
-#: builtin/describe.c:57
-msgid "lightweight"
-msgstr "кратко"
+#: builtin/gc.c:542
+msgid "enable auto-gc mode"
+msgstr "включване на автоматичното събиране на боклука (auto-gc)"
 
-#: builtin/describe.c:57
-msgid "annotated"
-msgstr "анотирано"
+#: builtin/gc.c:545
+msgid "force running gc even if there may be another gc running"
+msgstr ""
+"изрично стартиране на събирането на боклука, дори и ако вече работи друго "
+"събиране"
 
-#: builtin/describe.c:267
-#, c-format
-msgid "annotated tag %s not available"
-msgstr "не съществува анотиран етикет „%s“"
+#: builtin/gc.c:548
+msgid "repack all other packs except the largest pack"
+msgstr "препакетиране на всичко без най-големия пакет"
 
-#: builtin/describe.c:271
+#: builtin/gc.c:565
 #, c-format
-msgid "annotated tag %s has no embedded name"
-msgstr "в анотирания етикет „%s“ липсва вградено име"
+msgid "failed to parse gc.logexpiry value %s"
+msgstr "неразпозната стойност на „gc.logexpiry“ %s"
 
-#: builtin/describe.c:273
+#: builtin/gc.c:576
 #, c-format
-msgid "tag '%s' is really '%s' here"
-msgstr "етикетът „%s“ тук е всъщност „%s“"
+msgid "failed to parse prune expiry value %s"
+msgstr "неразпозната стойност на периода за окастряне: %s"
 
-#: builtin/describe.c:317
+#: builtin/gc.c:596
 #, c-format
-msgid "no tag exactly matches '%s'"
-msgstr "никой етикет не напасва точно „%s“"
+msgid "Auto packing the repository in background for optimum performance.\n"
+msgstr ""
+"Автоматично пакетиране на заден фон на хранилището за по-добра "
+"производителност.\n"
 
-#: builtin/describe.c:319
+#: builtin/gc.c:598
 #, c-format
-msgid "No exact match on refs or tags, searching to describe\n"
-msgstr "Никоя версия и етикет не напасват точно.  Търси се по описание\n"
+msgid "Auto packing the repository for optimum performance.\n"
+msgstr "Автоматично пакетиране на хранилището за по-добра производителност.\n"
 
-#: builtin/describe.c:366
+#: builtin/gc.c:599
 #, c-format
-msgid "finished search at %s\n"
-msgstr "търсенето приключи при „%s“\n"
+msgid "See \"git help gc\" for manual housekeeping.\n"
+msgstr ""
+"Погледнете ръководството за повече информация как да изпълните „git help "
+"gc“.\n"
 
-#: builtin/describe.c:392
+#: builtin/gc.c:639
 #, c-format
 msgid ""
-"No annotated tags can describe '%s'.\n"
-"However, there were unannotated tags: try --tags."
+"gc is already running on machine '%s' pid %<PRIuMAX> (use --force if not)"
 msgstr ""
-"Никой анотиран етикет не описва „%s“.\n"
-"Съществуват и неанотирани етикети.  Пробвайте с опцията „--tags“."
+"събирането на боклука вече е стартирано на машината „%s“ с идентификатор на\n"
+"процеса: %<PRIuMAX> (ако сте сигурни, че това не е вярно, това използвайте\n"
+"опцията „--force“)"
 
-#: builtin/describe.c:396
-#, c-format
+#: builtin/gc.c:694
 msgid ""
-"No tags can describe '%s'.\n"
-"Try --always, or create some tags."
+"There are too many unreachable loose objects; run 'git prune' to remove them."
 msgstr ""
-"Никой етикет не описва „%s“.\n"
-"Пробвайте с опцията „--always“ или създайте етикети."
+"Има прекалено много недостижими, непакетирани обекти.\n"
+"Използвайте „git prune“, за да ги окастрите."
 
-#: builtin/describe.c:426
-#, c-format
-msgid "traversed %lu commits\n"
-msgstr "претърсени са %lu подавания\n"
+#: builtin/grep.c:29
+msgid "git grep [<options>] [-e] <pattern> [<rev>...] [[--] <path>...]"
+msgstr "git grep [ОПЦИЯ…] [-e] ШАБЛОН [ВЕРСИЯ…] [[--] ПЪТ…]"
 
-#: builtin/describe.c:429
+#: builtin/grep.c:225
 #, c-format
-msgid ""
-"more than %i tags found; listed %i most recent\n"
-"gave up search at %s\n"
-msgstr ""
-"открити са над %i етикета, изведени са последните %i,\n"
-"търсенето бе прекратено при „%s“.\n"
+msgid "grep: failed to create thread: %s"
+msgstr "grep: неуспешно създаване на нишка: %s"
 
-#: builtin/describe.c:497
+#: builtin/grep.c:279
 #, c-format
-msgid "describe %s\n"
-msgstr "описание на „%s“\n"
+msgid "invalid number of threads specified (%d) for %s"
+msgstr "зададен е неправилен брой нишки (%d) за %s"
 
-#: builtin/describe.c:500 builtin/log.c:502
+#. TRANSLATORS: %s is the configuration
+#. variable for tweaking threads, currently
+#. grep.threads
+#.
+#: builtin/grep.c:287 builtin/index-pack.c:1534 builtin/index-pack.c:1727
+#: builtin/pack-objects.c:2708
 #, c-format
-msgid "Not a valid object name %s"
-msgstr "Неправилно име на обект „%s“"
+msgid "no threads support, ignoring %s"
+msgstr "липсва поддръжка за нишки.  „%s“ ще се пренебрегне"
 
-#: builtin/describe.c:508
+#: builtin/grep.c:467 builtin/grep.c:592 builtin/grep.c:635
 #, c-format
-msgid "%s is neither a commit nor blob"
-msgstr "„%s“ не е нито подаване, нито обект-BLOB"
-
-#: builtin/describe.c:522
-msgid "find the tag that comes after the commit"
-msgstr "откриване на етикета, който следва подаване"
+msgid "unable to read tree (%s)"
+msgstr "дървото не може да бъде прочетено (%s)"
 
-#: builtin/describe.c:523
-msgid "debug search strategy on stderr"
-msgstr ""
-"извеждане на информация за трасиране на стратегията за търсене на "
-"стандартната грешка"
+#: builtin/grep.c:650
+#, c-format
+msgid "unable to grep from object of type %s"
+msgstr "не може да се изпълни „grep“ от обект от вида %s"
 
-#: builtin/describe.c:524
-msgid "use any ref"
-msgstr "използване на произволен указател"
+#: builtin/grep.c:716
+#, c-format
+msgid "switch `%c' expects a numerical value"
+msgstr "опцията „%c“ очаква число за аргумент"
 
-#: builtin/describe.c:525
-msgid "use any tag, even unannotated"
-msgstr "използване на всеки етикет — включително и неанотираните"
+#: builtin/grep.c:815
+msgid "search in index instead of in the work tree"
+msgstr "търсене в индекса, а не в работното дърво"
 
-#: builtin/describe.c:526
-msgid "always use long format"
-msgstr "винаги да се ползва дългият формат"
+#: builtin/grep.c:817
+msgid "find in contents not managed by git"
+msgstr "търсене и във файловете, които не са под управлението на git"
 
-#: builtin/describe.c:527
-msgid "only follow first parent"
-msgstr "проследяване само на първия родител"
+#: builtin/grep.c:819
+msgid "search in both tracked and untracked files"
+msgstr "търсене и в следените, и в неследените файлове"
 
-#: builtin/describe.c:530
-msgid "only output exact matches"
-msgstr "извеждане само на точните съвпадения"
+#: builtin/grep.c:821
+msgid "ignore files specified via '.gitignore'"
+msgstr "игнориране на файловете указани в „.gitignore“"
 
-#: builtin/describe.c:532
-msgid "consider <n> most recent tags (default: 10)"
-msgstr "да се търси само в този БРОЙ последни етикети (стандартно: 10)"
+#: builtin/grep.c:823
+msgid "recursively search in each submodule"
+msgstr "рекурсивно търсене във всички подмодули"
 
-#: builtin/describe.c:534
-msgid "only consider tags matching <pattern>"
-msgstr "да се търси само измежду етикетите напасващи този ШАБЛОН"
+#: builtin/grep.c:826
+msgid "show non-matching lines"
+msgstr "извеждане на редовете, които не съвпадат"
 
-#: builtin/describe.c:536
-msgid "do not consider tags matching <pattern>"
-msgstr "да не се търси измежду етикетите напасващи този ШАБЛОН"
+#: builtin/grep.c:828
+msgid "case insensitive matching"
+msgstr "без значение на регистъра на буквите (главни/малки)"
 
-#: builtin/describe.c:538 builtin/name-rev.c:406
-msgid "show abbreviated commit object as fallback"
-msgstr "извеждане на съкратено име на обект като резервен вариант"
+#: builtin/grep.c:830
+msgid "match patterns only at word boundaries"
+msgstr "напасване на шаблоните само по границите на думите"
 
-#: builtin/describe.c:539 builtin/describe.c:542
-msgid "mark"
-msgstr "МАРКЕР"
+#: builtin/grep.c:832
+msgid "process binary files as text"
+msgstr "обработване на двоичните файлове като текстови"
 
-#: builtin/describe.c:540
-msgid "append <mark> on dirty working tree (default: \"-dirty\")"
-msgstr "добавяне на такъв МАРКЕР на работното дърво (стандартно е „-dirty“)"
+#: builtin/grep.c:834
+msgid "don't match patterns in binary files"
+msgstr "прескачане на двоичните файлове"
 
-#: builtin/describe.c:543
-msgid "append <mark> on broken working tree (default: \"-broken\")"
+#: builtin/grep.c:837
+msgid "process binary files with textconv filters"
 msgstr ""
-"добавяне на такъв МАРКЕР на счупеното работно дърво (стандартно е „-broken“)"
-
-#: builtin/describe.c:561
-msgid "--long is incompatible with --abbrev=0"
-msgstr "Опциите „--long“ и „--abbrev=0“ са несъвместими"
-
-#: builtin/describe.c:590
-msgid "No names found, cannot describe anything."
-msgstr "Не са открити имена — нищо не може да бъде описано."
-
-#: builtin/describe.c:640
-msgid "--dirty is incompatible with commit-ishes"
-msgstr "опцията „--dirty“ е несъвместима с указател към подаване"
-
-#: builtin/describe.c:642
-msgid "--broken is incompatible with commit-ishes"
-msgstr "опцията „--broken“ е несъвместима с указател към подаване"
-
-#: builtin/diff.c:83
-#, c-format
-msgid "'%s': not a regular file or symlink"
-msgstr "„%s“: не е нито обикновен файл, нито символна връзка"
+"обработване на двоичните файлове чрез филтри за преобразуване към текст"
 
-#: builtin/diff.c:234
-#, c-format
-msgid "invalid option: %s"
-msgstr "неправилна опция: %s"
+#: builtin/grep.c:839
+msgid "search in subdirectories (default)"
+msgstr "търсене в поддиректориите (стандартно)"
 
-#: builtin/diff.c:356
-msgid "Not a git repository"
-msgstr "Не е хранилище на Git"
+#: builtin/grep.c:841
+msgid "descend at most <depth> levels"
+msgstr "навлизане максимално на тази ДЪЛБОЧИНА в дървото"
 
-#: builtin/diff.c:399
-#, c-format
-msgid "invalid object '%s' given."
-msgstr "зададен е неправилен обект „%s“."
+#: builtin/grep.c:845
+msgid "use extended POSIX regular expressions"
+msgstr "разширени регулярни изрази по POSIX"
 
-#: builtin/diff.c:408
-#, c-format
-msgid "more than two blobs given: '%s'"
-msgstr "зададени са повече от 2 обекта-BLOB: „%s“"
+#: builtin/grep.c:848
+msgid "use basic POSIX regular expressions (default)"
+msgstr "основни регулярни изрази по POSIX (стандартно)"
 
-#: builtin/diff.c:413
-#, c-format
-msgid "unhandled object '%s' given."
-msgstr "зададен е неподдържан обект „%s“."
+#: builtin/grep.c:851
+msgid "interpret patterns as fixed strings"
+msgstr "шаблоните са дословни низове"
 
-#: builtin/difftool.c:29
-msgid "git difftool [<options>] [<commit> [<commit>]] [--] [<path>...]"
-msgstr "git difftool [ОПЦИЯ…] [ПОДАВАНЕ [ПОДАВАНЕ]] [[--] ПЪТ…]"
+#: builtin/grep.c:854
+msgid "use Perl-compatible regular expressions"
+msgstr "регулярни изрази на Perl"
 
-#: builtin/difftool.c:259
-#, c-format
-msgid "failed: %d"
-msgstr "неуспешно действие с изходен код: %d"
+#: builtin/grep.c:857
+msgid "show line numbers"
+msgstr "извеждане на номерата на редовете"
 
-#: builtin/difftool.c:301
-#, c-format
-msgid "could not read symlink %s"
-msgstr "символната връзка „%s“ не може да бъде прочетена"
+#: builtin/grep.c:858
+msgid "show column number of first match"
+msgstr "извеждане на номера на колоната на първото напасване"
 
-#: builtin/difftool.c:303
-#, c-format
-msgid "could not read symlink file %s"
-msgstr "файлът, сочен от символната връзка „%s“, не може да бъде прочетен"
+#: builtin/grep.c:859
+msgid "don't show filenames"
+msgstr "без извеждане на имената на файловете"
 
-#: builtin/difftool.c:311
-#, c-format
-msgid "could not read object %s for symlink %s"
-msgstr "обектът „%s“ за символната връзка „%s“ не може да бъде прочетен"
+#: builtin/grep.c:860
+msgid "show filenames"
+msgstr "извеждане на имената на файловете"
 
-#: builtin/difftool.c:412
-msgid ""
-"combined diff formats('-c' and '--cc') are not supported in\n"
-"directory diff mode('-d' and '--dir-diff')."
+#: builtin/grep.c:862
+msgid "show filenames relative to top directory"
 msgstr ""
-"комбинираните формати на разликите („-c“ и „--cc“) не се поддържат\n"
-"в режима за разлики върху директории („-d“ и „--dir-diff“)."
-
-#: builtin/difftool.c:632
-#, c-format
-msgid "both files modified: '%s' and '%s'."
-msgstr "и двата файла са променени: „%s“ и „%s“."
-
-#: builtin/difftool.c:634
-msgid "working tree file has been left."
-msgstr "работното дърво е изоставено."
-
-#: builtin/difftool.c:645
-#, c-format
-msgid "temporary files exist in '%s'."
-msgstr "в „%s“ има временни файлове."
-
-#: builtin/difftool.c:646
-msgid "you may want to cleanup or recover these."
-msgstr "възможно е да ги изчистите или възстановите"
-
-#: builtin/difftool.c:695
-msgid "use `diff.guitool` instead of `diff.tool`"
-msgstr "използвайте „diff.guitool“ вместо „diff.tool“"
-
-#: builtin/difftool.c:697
-msgid "perform a full-directory diff"
-msgstr "разлика по директории"
-
-#: builtin/difftool.c:699
-msgid "do not prompt before launching a diff tool"
-msgstr "стартиране на ПРОГРАМАта за разлики без предупреждение"
-
-#: builtin/difftool.c:704
-msgid "use symlinks in dir-diff mode"
-msgstr "следване на символните връзки при разлика по директории"
-
-#: builtin/difftool.c:705
-msgid "<tool>"
-msgstr "ПРОГРАМА"
+"извеждане на относителните имена на файловете спрямо основната директория на "
+"хранилището"
 
-#: builtin/difftool.c:706
-msgid "use the specified diff tool"
-msgstr "използване на указаната ПРОГРАМА"
+#: builtin/grep.c:864
+msgid "show only filenames instead of matching lines"
+msgstr "извеждане само на имената на файловете без напасващите редове"
 
-#: builtin/difftool.c:708
-msgid "print a list of diff tools that may be used with `--tool`"
-msgstr ""
-"извеждане на списък с всички ПРОГРАМи, които може да се ползват с опцията „--"
-"tool“"
+#: builtin/grep.c:866
+msgid "synonym for --files-with-matches"
+msgstr "псевдоним на „--files-with-matches“"
 
-#: builtin/difftool.c:711
-msgid ""
-"make 'git-difftool' exit when an invoked diff tool returns a non - zero exit "
-"code"
+#: builtin/grep.c:869
+msgid "show only the names of files without match"
 msgstr ""
-"„git-difftool“ да спре работа, когато стартираната ПРОГРАМА завърши с "
-"ненулев код"
-
-#: builtin/difftool.c:713
-msgid "<command>"
-msgstr "КОМАНДА"
+"извеждане само на имената на файловете, които не съдържат ред, напасващ на "
+"шаблона"
 
-#: builtin/difftool.c:714
-msgid "specify a custom command for viewing diffs"
-msgstr "команда за разглеждане на разлики"
+#: builtin/grep.c:871
+msgid "print NUL after filenames"
+msgstr "извеждане на нулевия знак „NUL“ след всяко име на файл"
 
-#: builtin/difftool.c:738
-msgid "no <tool> given for --tool=<tool>"
-msgstr "не е зададена програма за „--tool=ПРОГРАМА“"
+#: builtin/grep.c:874
+msgid "show only matching parts of a line"
+msgstr "извеждане само на частите на редовете, които съвпадат"
 
-#: builtin/difftool.c:745
-msgid "no <cmd> given for --extcmd=<cmd>"
-msgstr "не е зададена команда за „--extcmd=КОМАНДА“"
+#: builtin/grep.c:876
+msgid "show the number of matches instead of matching lines"
+msgstr "извеждане на броя на съвпаденията вместо напасващите редове"
 
-#: builtin/fast-export.c:27
-msgid "git fast-export [rev-list-opts]"
-msgstr "git fast-export [ОПЦИИ_ЗА_СПИСЪКА_С_ВЕРСИИ]"
+#: builtin/grep.c:877
+msgid "highlight matches"
+msgstr "оцветяване на напасванията"
 
-#: builtin/fast-export.c:1000
-msgid "show progress after <n> objects"
-msgstr "Съобщение за напредъка на всеки такъв БРОЙ обекта"
+#: builtin/grep.c:879
+msgid "print empty line between matches from different files"
+msgstr "извеждане на празен ред между напасванията от различни файлове"
 
-#: builtin/fast-export.c:1002
-msgid "select handling of signed tags"
-msgstr "Как да се обработват подписаните етикети"
+#: builtin/grep.c:881
+msgid "show filename only once above matches from same file"
+msgstr ""
+"извеждане на името на файла само веднъж за всички напасвания от този файл"
 
-#: builtin/fast-export.c:1005
-msgid "select handling of tags that tag filtered objects"
-msgstr "Как да се обработват етикетите на филтрираните обекти"
+#: builtin/grep.c:884
+msgid "show <n> context lines before and after matches"
+msgstr "извеждане на такъв БРОЙ редове преди и след напасванията"
 
-#: builtin/fast-export.c:1008
-msgid "Dump marks to this file"
-msgstr "Запазване на маркерите в този ФАЙЛ"
+#: builtin/grep.c:887
+msgid "show <n> context lines before matches"
+msgstr "извеждане на такъв БРОЙ редове преди напасванията"
 
-#: builtin/fast-export.c:1010
-msgid "Import marks from this file"
-msgstr "Внасяне на маркерите от този ФАЙЛ"
+#: builtin/grep.c:889
+msgid "show <n> context lines after matches"
+msgstr "извеждане на такъв БРОЙ редове след напасванията"
 
-#: builtin/fast-export.c:1012
-msgid "Fake a tagger when tags lack one"
-msgstr "Да се използва изкуствено име на човек при липса на задаващ етикета"
+#: builtin/grep.c:891
+msgid "use <n> worker threads"
+msgstr "използване на такъв БРОЙ работещи нишки"
 
-#: builtin/fast-export.c:1014
-msgid "Output full tree for each commit"
-msgstr "Извеждане на цялото дърво за всяко подаване"
+#: builtin/grep.c:892
+msgid "shortcut for -C NUM"
+msgstr "псевдоним на „-C БРОЙ“"
 
-#: builtin/fast-export.c:1016
-msgid "Use the done feature to terminate the stream"
-msgstr "Използване на маркер за завършване на потока"
+#: builtin/grep.c:895
+msgid "show a line with the function name before matches"
+msgstr "извеждане на ред с името на функцията, в която е напаснат шаблона"
 
-#: builtin/fast-export.c:1017
-msgid "Skip output of blob data"
-msgstr "Без извеждане на съдържанието на обектите-BLOB"
+#: builtin/grep.c:897
+msgid "show the surrounding function"
+msgstr "извеждане на обхващащата функция"
 
-#: builtin/fast-export.c:1018
-msgid "refspec"
-msgstr "УКАЗАТЕЛ_НА_ВЕРСИЯ"
+#: builtin/grep.c:900
+msgid "read patterns from file"
+msgstr "изчитане на шаблоните от ФАЙЛ"
 
-#: builtin/fast-export.c:1019
-msgid "Apply refspec to exported refs"
-msgstr "Прилагане на УКАЗАТЕЛя_НА_ВЕРСИЯ към изнесените указатели"
+#: builtin/grep.c:902
+msgid "match <pattern>"
+msgstr "напасване на ШАБЛОН"
 
-#: builtin/fast-export.c:1020
-msgid "anonymize output"
-msgstr "анонимизиране на извежданата информация"
+#: builtin/grep.c:904
+msgid "combine patterns specified with -e"
+msgstr "комбиниране на шаблоните указани с опцията „-e“"
 
-#: builtin/fetch.c:26
-msgid "git fetch [<options>] [<repository> [<refspec>...]]"
-msgstr "git fetch [ОПЦИЯ…] [ХРАНИЛИЩЕ [УКАЗАТЕЛ…]]"
+#: builtin/grep.c:916
+msgid "indicate hit with exit status without output"
+msgstr ""
+"без извеждане на стандартния изход.  Изходният код указва наличието на "
+"напасване"
 
-#: builtin/fetch.c:27
-msgid "git fetch [<options>] <group>"
-msgstr "git fetch [ОПЦИЯ…] ГРУПА"
+#: builtin/grep.c:918
+msgid "show only matches from files that match all patterns"
+msgstr ""
+"извеждане на редове само от файловете, които напасват на всички шаблони"
 
-#: builtin/fetch.c:28
-msgid "git fetch --multiple [<options>] [(<repository> | <group>)...]"
-msgstr "git fetch --multiple [ОПЦИЯ…] [(ХРАНИЛИЩЕ | ГРУПА)…]"
+#: builtin/grep.c:920
+msgid "show parse tree for grep expression"
+msgstr "извеждане на дървото за анализ на регулярния израз"
 
-#: builtin/fetch.c:29
-msgid "git fetch --all [<options>]"
-msgstr "git fetch --all [ОПЦИЯ…]"
+#: builtin/grep.c:924
+msgid "pager"
+msgstr "програма за преглед по страници"
 
-#: builtin/fetch.c:123 builtin/pull.c:193
-msgid "fetch from all remotes"
-msgstr "доставяне от всички отдалечени хранилища"
+#: builtin/grep.c:924
+msgid "show matching files in the pager"
+msgstr "извеждане на съвпадащите файлове в програма за преглед по страници"
 
-#: builtin/fetch.c:125 builtin/pull.c:196
-msgid "append to .git/FETCH_HEAD instead of overwriting"
-msgstr "добавяне към „.git/FETCH_HEAD“ вместо замяна"
+#: builtin/grep.c:928
+msgid "allow calling of grep(1) (ignored by this build)"
+msgstr ""
+"позволяване на стартирането на grep(1) (текущият компилат пренебрегва тази "
+"опция)"
 
-#: builtin/fetch.c:127 builtin/pull.c:199
-msgid "path to upload pack on remote end"
-msgstr "отдалечен път, където да се качи пакетът"
+#: builtin/grep.c:992
+msgid "no pattern given"
+msgstr "не сте задали шаблон"
 
-#: builtin/fetch.c:128 builtin/pull.c:201
-msgid "force overwrite of local branch"
-msgstr "принудително презаписване на локалния клон"
+#: builtin/grep.c:1028
+msgid "--no-index or --untracked cannot be used with revs"
+msgstr "опциите „--cached“ и „--untracked“ са несъвместими с версии."
 
-#: builtin/fetch.c:130
-msgid "fetch from multiple remotes"
-msgstr "доставяне от множество отдалечени хранилища"
+#: builtin/grep.c:1036
+#, c-format
+msgid "unable to resolve revision: %s"
+msgstr "версията „%s“ не може бъде открита"
 
-#: builtin/fetch.c:132 builtin/pull.c:203
-msgid "fetch all tags and associated objects"
-msgstr "доставяне на всички етикети и принадлежащи обекти"
+#: builtin/grep.c:1067
+msgid "invalid option combination, ignoring --threads"
+msgstr "неправилна комбинация от опции, „--threads“ ще се пренебрегне"
 
-#: builtin/fetch.c:134
-msgid "do not fetch all tags (--no-tags)"
-msgstr "без доставянето на всички етикети „--no-tags“"
+#: builtin/grep.c:1070 builtin/pack-objects.c:3400
+msgid "no threads support, ignoring --threads"
+msgstr "липсва поддръжка за нишки.  „--threads“ ще се пренебрегне"
 
-#: builtin/fetch.c:136
-msgid "number of submodules fetched in parallel"
-msgstr "брой подмодули доставени паралелно"
+#: builtin/grep.c:1073 builtin/index-pack.c:1531 builtin/pack-objects.c:2705
+#, c-format
+msgid "invalid number of threads specified (%d)"
+msgstr "зададен е неправилен брой нишки: %d"
 
-#: builtin/fetch.c:138 builtin/pull.c:206
-msgid "prune remote-tracking branches no longer on remote"
-msgstr "окастряне на клоните следящи вече несъществуващи отдалечени клони"
+#: builtin/grep.c:1096
+msgid "--open-files-in-pager only works on the worktree"
+msgstr "опцията „--open-files-in-pager“ изисква търсене в работното дърво"
 
-#: builtin/fetch.c:140
-msgid "prune local tags no longer on remote and clobber changed tags"
-msgstr ""
-"окастряне на локалните етикети, които вече не съществуват в отдалеченото "
-"хранилище и махане на променените"
+#: builtin/grep.c:1119
+msgid "option not supported with --recurse-submodules"
+msgstr "опцията е несъвместима с „--recurse-submodules“"
+
+#: builtin/grep.c:1125
+msgid "--cached or --untracked cannot be used with --no-index"
+msgstr "опциите „--cached“ и „--untracked“ са несъвместими с „--no-index“"
 
-#: builtin/fetch.c:141 builtin/fetch.c:164 builtin/pull.c:131
-msgid "on-demand"
-msgstr "ПРИ НУЖДА"
+#: builtin/grep.c:1131
+msgid "--[no-]exclude-standard cannot be used for tracked contents"
+msgstr ""
+"опциите „--(no-)exclude-standard“ са несъвместими с търсене по следени "
+"файлове"
 
-#: builtin/fetch.c:142
-msgid "control recursive fetching of submodules"
-msgstr "управление на рекурсивното доставяне на подмодулите"
+#: builtin/grep.c:1139
+msgid "both --cached and trees are given"
+msgstr "опцията „--cached“ е несъвместима със задаване на дърво"
 
-#: builtin/fetch.c:146 builtin/pull.c:214
-msgid "keep downloaded pack"
-msgstr "запазване на изтеглените пакети с обекти"
+#: builtin/hash-object.c:85
+msgid ""
+"git hash-object [-t <type>] [-w] [--path=<file> | --no-filters] [--stdin] "
+"[--] <file>..."
+msgstr ""
+"git hash-object [-t ВИД] [-w] [--path=ФАЙЛ | --no-filters] [--stdin] [--] "
+"ФАЙЛ…"
 
-#: builtin/fetch.c:148
-msgid "allow updating of HEAD ref"
-msgstr "позволяване на обновяването на указателя „HEAD“"
+#: builtin/hash-object.c:86
+msgid "git hash-object  --stdin-paths"
+msgstr "git hash-object --stdin-paths"
 
-#: builtin/fetch.c:151 builtin/fetch.c:157 builtin/pull.c:217
-msgid "deepen history of shallow clone"
-msgstr "задълбочаване на историята на плитко хранилище"
+#: builtin/hash-object.c:98
+msgid "object type"
+msgstr "ВИД на обекта"
 
-#: builtin/fetch.c:153
-msgid "deepen history of shallow repository based on time"
-msgstr "задълбочаване на историята на плитко хранилище до определено време"
+#: builtin/hash-object.c:99
+msgid "write the object into the object database"
+msgstr "записване на обекта в базата от данни за обектите"
 
-#: builtin/fetch.c:159 builtin/pull.c:220
-msgid "convert to a complete repository"
-msgstr "превръщане в пълно хранилище"
+#: builtin/hash-object.c:101
+msgid "read the object from stdin"
+msgstr "изчитане на обекта от стандартния вход"
 
-#: builtin/fetch.c:162
-msgid "prepend this to submodule path output"
-msgstr "добавяне на това пред пътя на подмодула"
+#: builtin/hash-object.c:103
+msgid "store file as is without filters"
+msgstr "запазване на файла както е — без филтри"
 
-#: builtin/fetch.c:165
+#: builtin/hash-object.c:104
 msgid ""
-"default for recursive fetching of submodules (lower priority than config "
-"files)"
+"just hash any random garbage to create corrupt objects for debugging Git"
 msgstr ""
-"стандартно рекурсивно изтегляне на подмодулите (файловете с настройки са с "
-"приоритет)"
+"създаване и изчисляване на контролни суми на произволни данни за повредени "
+"обекти за трасиране на Git"
 
-#: builtin/fetch.c:169 builtin/pull.c:223
-msgid "accept refs that update .git/shallow"
-msgstr "приемане на указатели, които обновяват „.git/shallow“"
+#: builtin/hash-object.c:105
+msgid "process file as it were from this path"
+msgstr "обработване на ФАЙЛа все едно е с този път"
 
-#: builtin/fetch.c:170 builtin/pull.c:225
-msgid "refmap"
-msgstr "КАРТА_С_УКАЗАТЕЛИ"
+#: builtin/help.c:46
+msgid "print all available commands"
+msgstr "показване на всички налични команди"
 
-#: builtin/fetch.c:171 builtin/pull.c:226
-msgid "specify fetch refmap"
-msgstr "указване на КАРТАта_С_УКАЗАТЕЛИ за доставяне"
+#: builtin/help.c:47
+msgid "exclude guides"
+msgstr "без въведения"
 
-#: builtin/fetch.c:172 builtin/ls-remote.c:77 builtin/push.c:582
-#: builtin/send-pack.c:172
-msgid "server-specific"
-msgstr "специфични за сървъра"
+#: builtin/help.c:48
+msgid "print list of useful guides"
+msgstr "показване на списък с въведения"
 
-#: builtin/fetch.c:172 builtin/ls-remote.c:77 builtin/push.c:582
-#: builtin/send-pack.c:173
-msgid "option to transmit"
-msgstr "опция за пренос"
+#: builtin/help.c:49
+msgid "print all configuration variable names"
+msgstr "показване на имената на всички конфигуриращи променливи"
 
-#: builtin/fetch.c:442
-msgid "Couldn't find remote ref HEAD"
-msgstr "Указателят „HEAD“ в отдалеченото хранилище не може да бъде открит"
+#: builtin/help.c:51
+msgid "show man page"
+msgstr "показване на страница от ръководството"
 
-#: builtin/fetch.c:560
-#, c-format
-msgid "configuration fetch.output contains invalid value %s"
-msgstr "настройката „fetch.output“ е с неправилна стойност „%s“"
+#: builtin/help.c:52
+msgid "show manual in web browser"
+msgstr "показване на страница от ръководството в уеб браузър"
 
-#: builtin/fetch.c:653
+#: builtin/help.c:54
+msgid "show info page"
+msgstr "показване на информационна страница"
+
+#: builtin/help.c:56
+msgid "print command description"
+msgstr "извеждане на описанието на команда"
+
+#: builtin/help.c:61
+msgid "git help [--all] [--guides] [--man | --web | --info] [<command>]"
+msgstr "git help [--all] [--guides] [--man | --web | --info] [КОМАНДА]"
+
+#: builtin/help.c:77
 #, c-format
-msgid "object %s not found"
-msgstr "обектът „%s“ липсва"
+msgid "unrecognized help format '%s'"
+msgstr "непознат формат на помощта „%s“"
 
-#: builtin/fetch.c:657
-msgid "[up to date]"
-msgstr "[актуализиран]"
+#: builtin/help.c:104
+msgid "Failed to start emacsclient."
+msgstr "Неуспешно стартиране на „emacsclient“."
 
-#: builtin/fetch.c:670 builtin/fetch.c:750
-msgid "[rejected]"
-msgstr "[отхвърлен]"
+#: builtin/help.c:117
+msgid "Failed to parse emacsclient version."
+msgstr "Версията на „emacsclient“ не може да се анализира."
 
-#: builtin/fetch.c:671
-msgid "can't fetch in current branch"
-msgstr "в текущия клон не може да се доставя"
+#: builtin/help.c:125
+#, c-format
+msgid "emacsclient version '%d' too old (< 22)."
+msgstr "Прекалено стара версия на „emacsclient“ — %d (< 22)."
 
-#: builtin/fetch.c:680
-msgid "[tag update]"
-msgstr "[обновяване на етикетите]"
+#: builtin/help.c:143 builtin/help.c:165 builtin/help.c:175 builtin/help.c:183
+#, c-format
+msgid "failed to exec '%s'"
+msgstr "неуспешно изпълнение на „%s“"
 
-#: builtin/fetch.c:681 builtin/fetch.c:714 builtin/fetch.c:730
-#: builtin/fetch.c:745
-msgid "unable to update local ref"
-msgstr "локален указател не може да бъде обновен"
+#: builtin/help.c:221
+#, c-format
+msgid ""
+"'%s': path for unsupported man viewer.\n"
+"Please consider using 'man.<tool>.cmd' instead."
+msgstr ""
+"„%s“: път към неподдържана програма за преглед на\n"
+" ръководството.  Вместо нея пробвайте „man.<tool>.cmd“."
 
-#: builtin/fetch.c:700
-msgid "[new tag]"
-msgstr "[нов етикет]"
+#: builtin/help.c:233
+#, c-format
+msgid ""
+"'%s': cmd for supported man viewer.\n"
+"Please consider using 'man.<tool>.path' instead."
+msgstr ""
+"„%s“: команда за поддържана програма за преглед на\n"
+" ръководството.  Вместо нея пробвайте „man.<tool>.path“."
 
-#: builtin/fetch.c:703
-msgid "[new branch]"
-msgstr "[нов клон]"
+#: builtin/help.c:350
+#, c-format
+msgid "'%s': unknown man viewer."
+msgstr "„%s“: непозната програма за преглед на ръководството."
 
-#: builtin/fetch.c:706
-msgid "[new ref]"
-msgstr "[нов указател]"
+#: builtin/help.c:367
+msgid "no man viewer handled the request"
+msgstr "никоя програма за преглед на ръководство не успя да обработи заявката"
 
-#: builtin/fetch.c:745
-msgid "forced update"
-msgstr "принудително обновяване"
+#: builtin/help.c:375
+msgid "no info viewer handled the request"
+msgstr ""
+"никоя програма за преглед на информационните страници не успя да обработи "
+"заявката"
 
-#: builtin/fetch.c:750
-msgid "non-fast-forward"
-msgstr "същинско сливане"
+#: builtin/help.c:434 builtin/help.c:445 git.c:336
+#, c-format
+msgid "'%s' is aliased to '%s'"
+msgstr "„%s“ е псевдоним на „%s“"
 
-#: builtin/fetch.c:795
+#: builtin/help.c:448 git.c:365
 #, c-format
-msgid "%s did not send all necessary objects\n"
-msgstr "хранилището „%s“ не изпрати всички необходими обекти\n"
+msgid "bad alias.%s string: %s"
+msgstr "неправилен низ за настройката „alias.%s“: „%s“"
 
-#: builtin/fetch.c:815
+#: builtin/help.c:477 builtin/help.c:507
 #, c-format
-msgid "reject %s because shallow roots are not allowed to be updated"
-msgstr ""
-"отхвърляне на върха „%s“, защото плитките хранилища не могат да бъдат "
-"обновявани"
+msgid "usage: %s%s"
+msgstr "употреба: %s%s"
 
-#: builtin/fetch.c:903 builtin/fetch.c:999
+#: builtin/help.c:491
+msgid "'git help config' for more information"
+msgstr "За повече информация изпълнете „git help config“"
+
+#: builtin/index-pack.c:185
 #, c-format
-msgid "From %.*s\n"
-msgstr "От %.*s\n"
+msgid "object type mismatch at %s"
+msgstr "неправилен вид на обекта „%s“"
 
-#: builtin/fetch.c:914
+#: builtin/index-pack.c:205
 #, c-format
-msgid ""
-"some local refs could not be updated; try running\n"
-" 'git remote prune %s' to remove any old, conflicting branches"
-msgstr ""
-"някои локални указатели не могат да бъдат обновени.  Изпълнете командата\n"
-"„git remote prune %s“, за да премахнете остарелите клони, които\n"
-"предизвикват конфликта"
+msgid "did not receive expected object %s"
+msgstr "очакваният обект „%s“ не бе получен"
 
-#: builtin/fetch.c:969
+#: builtin/index-pack.c:208
 #, c-format
-msgid "   (%s will become dangling)"
-msgstr "   (обектът „%s“ ще се окаже извън клон)"
+msgid "object %s: expected type %s, found %s"
+msgstr "неправилен вид на обекта „%s“: очакваше се „%s“, а бе получен „%s“"
 
-#: builtin/fetch.c:970
+#: builtin/index-pack.c:258
 #, c-format
-msgid "   (%s has become dangling)"
-msgstr "   (обектът „%s“ вече е извън клон)"
+msgid "cannot fill %d byte"
+msgid_plural "cannot fill %d bytes"
+msgstr[0] "не може да се запълни %d байт"
+msgstr[1] "не може да се запълнят %d байта"
 
-#: builtin/fetch.c:1002
-msgid "[deleted]"
-msgstr "[изтрит]"
+#: builtin/index-pack.c:268
+msgid "early EOF"
+msgstr "неочакван край на файл"
 
-#: builtin/fetch.c:1003 builtin/remote.c:1033
-msgid "(none)"
-msgstr "(нищо)"
+#: builtin/index-pack.c:269
+msgid "read error on input"
+msgstr "грешка при четене на входните данни"
 
-#: builtin/fetch.c:1026
-#, c-format
-msgid "Refusing to fetch into current branch %s of non-bare repository"
-msgstr "Не може да доставите в текущия клон „%s“ на хранилище, което не е голо"
+#: builtin/index-pack.c:281
+msgid "used more bytes than were available"
+msgstr "използвани са повече от наличните байтове"
 
-#: builtin/fetch.c:1045
-#, c-format
-msgid "Option \"%s\" value \"%s\" is not valid for %s"
-msgstr "Стойността „%2$s“ за опцията „%1$s“ не е съвместима с „%3$s“"
+#: builtin/index-pack.c:288 builtin/pack-objects.c:604
+msgid "pack too large for current definition of off_t"
+msgstr "пакетният файл е прекалено голям за текущата стойност на типа „off_t“"
 
-#: builtin/fetch.c:1048
-#, c-format
-msgid "Option \"%s\" is ignored for %s\n"
-msgstr "Опцията „%s“ се прескача при „%s“\n"
+#: builtin/index-pack.c:291 builtin/unpack-objects.c:95
+msgid "pack exceeds maximum allowed size"
+msgstr "пакетният файл надвишава максималния възможен размер"
 
-#: builtin/fetch.c:1287
+#: builtin/index-pack.c:312
 #, c-format
-msgid "Fetching %s\n"
-msgstr "Доставяне на „%s“\n"
+msgid "cannot open packfile '%s'"
+msgstr "пакетният файл „%s“ не може да бъде отворен"
 
-#: builtin/fetch.c:1289 builtin/remote.c:98
+#: builtin/index-pack.c:326
+msgid "pack signature mismatch"
+msgstr "несъответствие в подписа към пакетния файл"
+
+#: builtin/index-pack.c:328
 #, c-format
-msgid "Could not fetch %s"
-msgstr "„%s“ не може да се достави"
+msgid "pack version %<PRIu32> unsupported"
+msgstr "не се поддържа пакетиране вeрсия „%<PRIu32>“"
 
-#: builtin/fetch.c:1335 builtin/fetch.c:1503
-msgid ""
-"--filter can only be used with the remote configured in core.partialClone"
-msgstr ""
-"опцията „--filter“ може да се ползва само с отдалеченото хранилище указано в "
-"настройката „core.partialClone“"
+#: builtin/index-pack.c:346
+#, c-format
+msgid "pack has bad object at offset %<PRIuMAX>: %s"
+msgstr "повреден обект в пакетния файл при отместване %<PRIuMAX>: %s"
 
-#: builtin/fetch.c:1358
-msgid ""
-"No remote repository specified.  Please, specify either a URL or a\n"
-"remote name from which new revisions should be fetched."
-msgstr ""
-"Не сте указали отдалечено хранилище.  Задайте или адрес, или име\n"
-"на отдалечено хранилище, откъдето да се доставят новите версии."
+#: builtin/index-pack.c:466
+#, c-format
+msgid "inflate returned %d"
+msgstr "декомпресирането с „inflate“ върна %d"
 
-#: builtin/fetch.c:1395
-msgid "You need to specify a tag name."
-msgstr "Трябва да укажете име на етикет."
+#: builtin/index-pack.c:515
+msgid "offset value overflow for delta base object"
+msgstr "стойността на отместването за обекта-разлика води до препълване"
 
-#: builtin/fetch.c:1444
-msgid "Negative depth in --deepen is not supported"
-msgstr "Отрицателна дълбочина като аргумент на „--deepen“ не се поддържа"
+#: builtin/index-pack.c:523
+msgid "delta base offset is out of bound"
+msgstr "стойността на отместването за обекта-разлика е извън диапазона"
 
-#: builtin/fetch.c:1446
-msgid "--deepen and --depth are mutually exclusive"
-msgstr "Опциите „--deepen“ и „--depth“ са несъвместими една с друга"
+#: builtin/index-pack.c:531
+#, c-format
+msgid "unknown object type %d"
+msgstr "непознат вид обект %d"
 
-#: builtin/fetch.c:1451
-msgid "--depth and --unshallow cannot be used together"
-msgstr "опциите „--depth“ и „--unshallow“ са несъвместими"
+#: builtin/index-pack.c:562
+msgid "cannot pread pack file"
+msgstr "пакетният файл не може да бъде прочетен"
 
-#: builtin/fetch.c:1453
-msgid "--unshallow on a complete repository does not make sense"
-msgstr "не можете да използвате опцията „--unshallow“ върху пълно хранилище"
+#: builtin/index-pack.c:564
+#, c-format
+msgid "premature end of pack file, %<PRIuMAX> byte missing"
+msgid_plural "premature end of pack file, %<PRIuMAX> bytes missing"
+msgstr[0] "неочакван край на файл, липсва %<PRIuMAX> байт"
+msgstr[1] "неочакван край на файл, липсват %<PRIuMAX> байта"
 
-#: builtin/fetch.c:1469
-msgid "fetch --all does not take a repository argument"
-msgstr "към „git fetch --all“ не можете да добавите аргумент — хранилище"
+#: builtin/index-pack.c:590
+msgid "serious inflate inconsistency"
+msgstr "сериозна грешка при декомпресиране с „inflate“"
 
-#: builtin/fetch.c:1471
-msgid "fetch --all does not make sense with refspecs"
+#: builtin/index-pack.c:735 builtin/index-pack.c:741 builtin/index-pack.c:764
+#: builtin/index-pack.c:803 builtin/index-pack.c:812
+#, c-format
+msgid "SHA1 COLLISION FOUND WITH %s !"
 msgstr ""
-"към „git fetch --all“ не можете да добавите аргумент — указател на версия"
+"СЪВПАДЕНИЕ НА СТОЙНОСТИТЕ ЗА СУМИТЕ ЗА SHA1: „%s“ НА ДВА РАЗЛИЧНИ ОБЕКТА!"
 
-#: builtin/fetch.c:1480
+#: builtin/index-pack.c:738 builtin/pack-objects.c:157
+#: builtin/pack-objects.c:217 builtin/pack-objects.c:311
 #, c-format
-msgid "No such remote or remote group: %s"
-msgstr "Няма нито отдалечено хранилище, нито група от хранилища на име „%s“"
+msgid "unable to read %s"
+msgstr "обектът „%s“ не може да бъде прочетен"
 
-#: builtin/fetch.c:1487
-msgid "Fetching a group and specifying refspecs does not make sense"
-msgstr "Указването на група и указването на версия са несъвместими"
+#: builtin/index-pack.c:801
+#, c-format
+msgid "cannot read existing object info %s"
+msgstr "съществуващият обект в „%s“ не може да бъде прочетен"
 
-#: builtin/fmt-merge-msg.c:15
-msgid ""
-"git fmt-merge-msg [-m <message>] [--log[=<n>] | --no-log] [--file <file>]"
-msgstr ""
-"git fmt-merge-msg [-m СЪОБЩЕНИЕ] [--log[=БРОЙ] | --no-log] [--file ФАЙЛ]"
+#: builtin/index-pack.c:809
+#, c-format
+msgid "cannot read existing object %s"
+msgstr "съществуващият обект „%s“ не може да бъде прочетен"
 
-#: builtin/fmt-merge-msg.c:666
-msgid "populate log with at most <n> entries from shortlog"
-msgstr ""
-"вмъкване на журнал състоящ се от не повече от БРОЙ записа от съкратения "
-"журнал"
+#: builtin/index-pack.c:823
+#, c-format
+msgid "invalid blob object %s"
+msgstr "неправилен обект-BLOB „%s“"
 
-#: builtin/fmt-merge-msg.c:669
-msgid "alias for --log (deprecated)"
-msgstr "синоним на „--log“ (остаряло)"
+#: builtin/index-pack.c:826 builtin/index-pack.c:845
+msgid "fsck error in packed object"
+msgstr "грешка при проверката на пакетирани обекти"
 
-#: builtin/fmt-merge-msg.c:672
-msgid "text"
-msgstr "ТЕКСТ"
+#: builtin/index-pack.c:847
+#, c-format
+msgid "Not all child objects of %s are reachable"
+msgstr "Някои обекти, наследници на „%s“, не могат да бъдат достигнати"
 
-#: builtin/fmt-merge-msg.c:673
-msgid "use <text> as start of message"
-msgstr "за начало на съобщението да се ползва ТЕКСТ"
+#: builtin/index-pack.c:919 builtin/index-pack.c:950
+msgid "failed to apply delta"
+msgstr "разликата не може да бъде приложена"
 
-#: builtin/fmt-merge-msg.c:674
-msgid "file to read from"
-msgstr "файл, от който да се чете"
+#: builtin/index-pack.c:1118
+msgid "Receiving objects"
+msgstr "Получаване на обекти"
 
-#: builtin/for-each-ref.c:10
-msgid "git for-each-ref [<options>] [<pattern>]"
-msgstr "git for-each-ref [ОПЦИЯ…] [ШАБЛОН]"
+#: builtin/index-pack.c:1118
+msgid "Indexing objects"
+msgstr "Индексиране на обекти"
 
-#: builtin/for-each-ref.c:11
-msgid "git for-each-ref [--points-at <object>]"
-msgstr "git for-each-ref [--points ОБЕКТ]"
+#: builtin/index-pack.c:1152
+msgid "pack is corrupted (SHA1 mismatch)"
+msgstr "пакетният файл е повреден (нееднакви суми по SHA1)"
 
-#: builtin/for-each-ref.c:12
-msgid "git for-each-ref [(--merged | --no-merged) [<commit>]]"
-msgstr "git for-each-ref[(--merged | --no-merged) [ПОДАВАНЕ]]"
+#: builtin/index-pack.c:1157
+msgid "cannot fstat packfile"
+msgstr "не може да се получи информация за пакетния файл с „fstat“"
 
-#: builtin/for-each-ref.c:13
-msgid "git for-each-ref [--contains [<commit>]] [--no-contains [<commit>]]"
-msgstr "git for-each-ref [--contains [ПОДАВАНЕ]] [--no-contains [ПОДАВАНЕ]]"
+#: builtin/index-pack.c:1160
+msgid "pack has junk at the end"
+msgstr "в края на пакетния файл има повредени данни"
 
-#: builtin/for-each-ref.c:28
-msgid "quote placeholders suitably for shells"
-msgstr "цитиране подходящо за командни интерпретатори на обвивката"
+#: builtin/index-pack.c:1172
+msgid "confusion beyond insanity in parse_pack_objects()"
+msgstr ""
+"фатална грешка във функцията „parse_pack_objects“.  Това е грешка в Git, "
+"докладвайте я на разработчиците, като пратите е-писмо на адрес: „git@vger."
+"kernel.org“."
 
-#: builtin/for-each-ref.c:30
-msgid "quote placeholders suitably for perl"
-msgstr "цитиране подходящо за perl"
+#: builtin/index-pack.c:1195
+msgid "Resolving deltas"
+msgstr "Откриване на съответните разлики"
 
-#: builtin/for-each-ref.c:32
-msgid "quote placeholders suitably for python"
-msgstr "цитиране подходящо за python"
+#: builtin/index-pack.c:1205 builtin/pack-objects.c:2481
+#, c-format
+msgid "unable to create thread: %s"
+msgstr "не може да се създаде нишка: %s"
 
-#: builtin/for-each-ref.c:34
-msgid "quote placeholders suitably for Tcl"
-msgstr "цитиране подходящо за tcl"
+#: builtin/index-pack.c:1246
+msgid "confusion beyond insanity"
+msgstr ""
+"фатална грешка във функцията „conclude_pack“.  Това е грешка в Git, "
+"докладвайте я на разработчиците, като пратите е-писмо на адрес: „git@vger."
+"kernel.org“."
 
-#: builtin/for-each-ref.c:37
-msgid "show only <n> matched refs"
-msgstr "извеждане само на този БРОЙ напаснати указатели"
+#: builtin/index-pack.c:1252
+#, c-format
+msgid "completed with %d local object"
+msgid_plural "completed with %d local objects"
+msgstr[0] "действието завърши с %d локален обект"
+msgstr[1] "действието завърши с %d локални обекта"
 
-#: builtin/for-each-ref.c:39 builtin/tag.c:421
-msgid "respect format colors"
-msgstr "спазване на цветовете на форма̀та"
+#: builtin/index-pack.c:1264
+#, c-format
+msgid "Unexpected tail checksum for %s (disk corruption?)"
+msgstr ""
+"Неочаквана последваща сума за грешки за „%s“ (причината може да е грешка в "
+"диска)"
 
-#: builtin/for-each-ref.c:43
-msgid "print only refs which points at the given object"
-msgstr "извеждане само на указателите, сочещи към ОБЕКТА"
+#: builtin/index-pack.c:1268
+#, c-format
+msgid "pack has %d unresolved delta"
+msgid_plural "pack has %d unresolved deltas"
+msgstr[0] "в пакета има %d ненапасваща разлика"
+msgstr[1] "в пакета има %d ненапасващи разлики"
 
-#: builtin/for-each-ref.c:45
-msgid "print only refs that are merged"
-msgstr "извеждане само на слетите указатели"
+#: builtin/index-pack.c:1292
+#, c-format
+msgid "unable to deflate appended object (%d)"
+msgstr "добавеният обект не може да се компресира с „deflate“: %d"
 
-#: builtin/for-each-ref.c:46
-msgid "print only refs that are not merged"
-msgstr "извеждане само на неслетите указатели"
+#: builtin/index-pack.c:1388
+#, c-format
+msgid "local object %s is corrupt"
+msgstr "локалният обект „%s“ е повреден"
 
-#: builtin/for-each-ref.c:47
-msgid "print only refs which contain the commit"
-msgstr "извеждане само на указателите, които съдържат това ПОДАВАНЕ"
+#: builtin/index-pack.c:1402
+#, c-format
+msgid "packfile name '%s' does not end with '.pack'"
+msgstr "името на пакетния файл „%s“ не завършва на „.pack“"
 
-#: builtin/for-each-ref.c:48
-msgid "print only refs which don't contain the commit"
-msgstr "извеждане само на указателите, които не съдържат това ПОДАВАНЕ"
+#: builtin/index-pack.c:1427
+#, c-format
+msgid "cannot write %s file '%s'"
+msgstr "грешка при запис на файла „%s“ „%s“"
 
-#: builtin/fsck.c:569
-msgid "Checking object directories"
-msgstr "Проверка на директориите с обекти"
+#: builtin/index-pack.c:1435
+#, c-format
+msgid "cannot close written %s file '%s'"
+msgstr "грешка при затварянето на записания файл „%s“ „%s“"
 
-#: builtin/fsck.c:661
-msgid "git fsck [<options>] [<object>...]"
-msgstr "git fsck [ОПЦИЯ…] [ОБЕКТ…]"
+#: builtin/index-pack.c:1459
+msgid "error while closing pack file"
+msgstr "грешка при затварянето на пакетния файл"
 
-#: builtin/fsck.c:667
-msgid "show unreachable objects"
-msgstr "показване на недостижимите обекти"
+#: builtin/index-pack.c:1473
+msgid "cannot store pack file"
+msgstr "пакетният файл не може да бъде запазен"
 
-#: builtin/fsck.c:668
-msgid "show dangling objects"
-msgstr "показване на обектите извън клоните"
+#: builtin/index-pack.c:1481
+msgid "cannot store index file"
+msgstr "файлът за индекса не може да бъде съхранен"
 
-#: builtin/fsck.c:669
-msgid "report tags"
-msgstr "показване на етикетите"
+#: builtin/index-pack.c:1525 builtin/pack-objects.c:2716
+#, c-format
+msgid "bad pack.indexversion=%<PRIu32>"
+msgstr "зададена е неправилна версия пакетиране: „pack.indexversion=%<PRIu32>“"
 
-#: builtin/fsck.c:670
-msgid "report root nodes"
-msgstr "показване на кореновите възли"
+#: builtin/index-pack.c:1593
+#, c-format
+msgid "Cannot open existing pack file '%s'"
+msgstr "Съществуващият пакетен файл „%s“ не може да бъде отворен"
 
-#: builtin/fsck.c:671
-msgid "make index objects head nodes"
-msgstr "задаване на обекти от индекса да са коренови"
+#: builtin/index-pack.c:1595
+#, c-format
+msgid "Cannot open existing pack idx file for '%s'"
+msgstr "Съществуващият индекс за пакетния файл „%s“ не може да бъде отворен"
 
-# FIXME bad message
-#: builtin/fsck.c:672
-msgid "make reflogs head nodes (default)"
-msgstr "проследяване на указателите от журнала като глави (стандартно)"
+#: builtin/index-pack.c:1643
+#, c-format
+msgid "non delta: %d object"
+msgid_plural "non delta: %d objects"
+msgstr[0] "%d обект не е разлика"
+msgstr[1] "%d обекта не са разлика"
 
-#: builtin/fsck.c:673
-msgid "also consider packs and alternate objects"
-msgstr "допълнително да се проверяват пакетите и алтернативните обекти"
+#: builtin/index-pack.c:1650
+#, c-format
+msgid "chain length = %d: %lu object"
+msgid_plural "chain length = %d: %lu objects"
+msgstr[0] "дължината на веригата е %d: %lu обект"
+msgstr[1] "дължината на веригата е %d: %lu обекта"
 
-#: builtin/fsck.c:674
-msgid "check only connectivity"
-msgstr "проверка само на връзката"
+#: builtin/index-pack.c:1689
+msgid "Cannot come back to cwd"
+msgstr "Процесът не може да се върне към предишната работна директория"
 
-#: builtin/fsck.c:675
-msgid "enable more strict checking"
-msgstr "по-строги проверки"
+#: builtin/index-pack.c:1738 builtin/index-pack.c:1741
+#: builtin/index-pack.c:1757 builtin/index-pack.c:1761
+#, c-format
+msgid "bad %s"
+msgstr "неправилна стойност „%s“"
 
-#: builtin/fsck.c:677
-msgid "write dangling objects in .git/lost-found"
-msgstr "запазване на обектите извън клоните в директорията „.git/lost-found“"
+#: builtin/index-pack.c:1777
+msgid "--fix-thin cannot be used without --stdin"
+msgstr "опцията „--fix-thin“ изисква „--stdin“"
 
-#: builtin/fsck.c:678 builtin/prune.c:109
-msgid "show progress"
-msgstr "показване на напредъка"
+#: builtin/index-pack.c:1779
+msgid "--stdin requires a git repository"
+msgstr "„--stdin“ изисква хранилище на git"
 
-#: builtin/fsck.c:679
-msgid "show verbose names for reachable objects"
-msgstr "показване на подробни имена на достижимите обекти"
+#: builtin/index-pack.c:1785
+msgid "--verify with no packfile name given"
+msgstr "опцията „--verify“ изисква име на пакетен файл"
 
-#: builtin/fsck.c:745
-msgid "Checking objects"
-msgstr "Проверка на обектите"
+#: builtin/index-pack.c:1833 builtin/unpack-objects.c:581
+msgid "fsck error in pack objects"
+msgstr "грешка при проверка с „fsck“ на пакетните обекти"
 
-#: builtin/gc.c:33
-msgid "git gc [<options>]"
-msgstr "git gc [ОПЦИЯ…]"
+#: builtin/init-db.c:61
+#, c-format
+msgid "cannot stat template '%s'"
+msgstr "не може да се получи информация чрез „stat“ за шаблона „%s“"
 
-#: builtin/gc.c:88
+#: builtin/init-db.c:66
 #, c-format
-msgid "Failed to fstat %s: %s"
-msgstr "Неуспешно изпълнение на „fstat“ върху „%s“: %s"
+msgid "cannot opendir '%s'"
+msgstr "директорията „%s“ не може да бъде отворена"
 
-#: builtin/gc.c:452
+#: builtin/init-db.c:78
 #, c-format
-msgid "Can't stat %s"
-msgstr "Неуспешно изпълнение на „stat“ върху „%s“"
+msgid "cannot readlink '%s'"
+msgstr "връзката „%s“ не може да бъде прочетена"
 
-#: builtin/gc.c:461
+#: builtin/init-db.c:80
 #, c-format
-msgid ""
-"The last gc run reported the following. Please correct the root cause\n"
-"and remove %s.\n"
-"Automatic cleanup will not be performed until the file is removed.\n"
-"\n"
-"%s"
-msgstr ""
-"При последното изпълнение на „git gc“ бе докладвана грешка.  Коригирайте "
-"причината за\n"
-"нея и изтрийте „%s“.\n"
-"Автоматичното изчистване на боклука няма да работи, преди да изтриете "
-"файла.\n"
-"\n"
-"%s"
+msgid "cannot symlink '%s' '%s'"
+msgstr "не може да се създаде символна връзка „%s“ в „%s“"
 
-#: builtin/gc.c:502
-msgid "prune unreferenced objects"
-msgstr "окастряне на обектите, към които нищо не сочи"
+#: builtin/init-db.c:86
+#, c-format
+msgid "cannot copy '%s' to '%s'"
+msgstr "„%s“ не може да се копира в „%s“"
 
-#: builtin/gc.c:504
-msgid "be more thorough (increased runtime)"
-msgstr "изчерпателно търсене на боклука (за сметка на повече време работа)"
+#: builtin/init-db.c:90
+#, c-format
+msgid "ignoring template %s"
+msgstr "игнориране на шаблона „%s“"
 
-#: builtin/gc.c:505
-msgid "enable auto-gc mode"
-msgstr "включване на автоматичното събиране на боклука (auto-gc)"
+#: builtin/init-db.c:121
+#, c-format
+msgid "templates not found in %s"
+msgstr "няма шаблони в „%s“"
 
-#: builtin/gc.c:508
-msgid "force running gc even if there may be another gc running"
-msgstr ""
-"изрично стартиране на събирането на боклука, дори и ако вече работи друго "
-"събиране"
+#: builtin/init-db.c:136
+#, c-format
+msgid "not copying templates from '%s': %s"
+msgstr "шаблоните няма да бъдат копирани от „%s“: „%s“"
 
-#: builtin/gc.c:511
-msgid "repack all other packs except the largest pack"
-msgstr "препакетиране на всичко без най-големия пакет"
+#: builtin/init-db.c:334
+#, c-format
+msgid "unable to handle file type %d"
+msgstr "файлове от вид %d не се поддържат"
 
-#: builtin/gc.c:528
+#: builtin/init-db.c:337
 #, c-format
-msgid "failed to parse gc.logexpiry value %s"
-msgstr "неразпозната стойност на „gc.logexpiry“ %s"
+msgid "unable to move %s to %s"
+msgstr "„%s“ не може да се премести в „%s“"
 
-#: builtin/gc.c:539
+#: builtin/init-db.c:354 builtin/init-db.c:357
 #, c-format
-msgid "failed to parse prune expiry value %s"
-msgstr "неразпозната стойност на периода за окастряне: %s"
+msgid "%s already exists"
+msgstr "Директорията „%s“ вече съществува"
 
-#: builtin/gc.c:559
+#: builtin/init-db.c:413
 #, c-format
-msgid "Auto packing the repository in background for optimum performance.\n"
+msgid "Reinitialized existing shared Git repository in %s%s\n"
 msgstr ""
-"Автоматично пакетиране на заден фон на хранилището за по-добра "
-"производителност.\n"
+"Инициализиране наново на съществуващо, споделено хранилище на Git в „%s%s“\n"
 
-#: builtin/gc.c:561
+#: builtin/init-db.c:414
 #, c-format
-msgid "Auto packing the repository for optimum performance.\n"
-msgstr "Автоматично пакетиране на хранилището за по-добра производителност.\n"
+msgid "Reinitialized existing Git repository in %s%s\n"
+msgstr "Инициализиране наново на съществуващо хранилище на Git в „%s%s“\n"
 
-#: builtin/gc.c:562
+#: builtin/init-db.c:418
 #, c-format
-msgid "See \"git help gc\" for manual housekeeping.\n"
-msgstr ""
-"Погледнете ръководството за повече информация как да изпълните „git help "
-"gc“.\n"
+msgid "Initialized empty shared Git repository in %s%s\n"
+msgstr "Инициализиране на празно, споделено хранилище на Git в „%s%s“\n"
 
-#: builtin/gc.c:598
+#: builtin/init-db.c:419
 #, c-format
-msgid ""
-"gc is already running on machine '%s' pid %<PRIuMAX> (use --force if not)"
-msgstr ""
-"събирането на боклука вече е стартирано на машината „%s“ с идентификатор на\n"
-"процеса: %<PRIuMAX> (ако сте сигурни, че това не е вярно, това използвайте\n"
-"опцията „--force“)"
+msgid "Initialized empty Git repository in %s%s\n"
+msgstr "Инициализиране на празно хранилище на Git в „%s%s“\n"
 
-#: builtin/gc.c:645
+#: builtin/init-db.c:468
 msgid ""
-"There are too many unreachable loose objects; run 'git prune' to remove them."
+"git init [-q | --quiet] [--bare] [--template=<template-directory>] [--"
+"shared[=<permissions>]] [<directory>]"
 msgstr ""
-"Има прекалено много недостижими, непакетирани обекти.\n"
-"Използвайте „git prune“, за да ги окастрите."
-
-#: builtin/grep.c:28
-msgid "git grep [<options>] [-e] <pattern> [<rev>...] [[--] <path>...]"
-msgstr "git grep [ОПЦИЯ…] [-e] ШАБЛОН [ВЕРСИЯ…] [[--] ПЪТ…]"
+"git init [-q | --quiet] [--bare] [--template=ДИРЕКТОРИЯ_С_ШАБЛОНИ] [--"
+"shared[=ПРАВА]] [ДИРЕКТОРИЯ]"
 
-#: builtin/grep.c:226
-#, c-format
-msgid "grep: failed to create thread: %s"
-msgstr "grep: неуспешно създаване на нишка: %s"
+#: builtin/init-db.c:491
+msgid "permissions"
+msgstr "права"
 
-#: builtin/grep.c:284
-#, c-format
-msgid "invalid number of threads specified (%d) for %s"
-msgstr "зададен е неправилен брой нишки (%d) за %s"
+#: builtin/init-db.c:492
+msgid "specify that the git repository is to be shared amongst several users"
+msgstr ""
+"указване, че хранилището на Git ще бъде споделено от повече от един "
+"потребител"
 
-#. TRANSLATORS: %s is the configuration
-#. variable for tweaking threads, currently
-#. grep.threads
-#.
-#: builtin/grep.c:293 builtin/index-pack.c:1535 builtin/index-pack.c:1727
+#: builtin/init-db.c:529 builtin/init-db.c:534
 #, c-format
-msgid "no threads support, ignoring %s"
-msgstr "липсва поддръжка за нишки.  „%s“ ще се пренебрегне"
+msgid "cannot mkdir %s"
+msgstr "директорията „%s“ не може да бъде създадена"
 
-#: builtin/grep.c:461 builtin/grep.c:582 builtin/grep.c:623
+#: builtin/init-db.c:538
 #, c-format
-msgid "unable to read tree (%s)"
-msgstr "дървото не може да бъде прочетено (%s)"
+msgid "cannot chdir to %s"
+msgstr "не може да се влезе в директорията „%s“"
 
-#: builtin/grep.c:638
+#: builtin/init-db.c:559
 #, c-format
-msgid "unable to grep from object of type %s"
-msgstr "не може да се изпълни „grep“ от обект от вида %s"
+msgid ""
+"%s (or --work-tree=<directory>) not allowed without specifying %s (or --git-"
+"dir=<directory>)"
+msgstr ""
+"%s (или --work-tree=ДИРЕКТОРИЯ) изисква указването на %s (или --git-"
+"dir=ДИРЕКТОРИЯ)"
 
-#: builtin/grep.c:703
+#: builtin/init-db.c:587
 #, c-format
-msgid "switch `%c' expects a numerical value"
-msgstr "опцията „%c“ очаква число за аргумент"
+msgid "Cannot access work tree '%s'"
+msgstr "Работното дърво в „%s“ е недостъпно"
 
-#: builtin/grep.c:790
-msgid "search in index instead of in the work tree"
-msgstr "търсене в индекса, а не в работното дърво"
+#: builtin/interpret-trailers.c:16
+msgid ""
+"git interpret-trailers [--in-place] [--trim-empty] [(--trailer "
+"<token>[(=|:)<value>])...] [<file>...]"
+msgstr ""
+"git interpret-trailers [--in-place] [--trim-empty] [(--trailer "
+"ЛЕКСЕМА[(=|:)СТОЙНОСТ])…] [ФАЙЛ…]"
 
-#: builtin/grep.c:792
-msgid "find in contents not managed by git"
-msgstr "търсене и във файловете, които не са под управлението на git"
+#: builtin/interpret-trailers.c:95
+msgid "edit files in place"
+msgstr "директно редактиране на файловете"
 
-#: builtin/grep.c:794
-msgid "search in both tracked and untracked files"
-msgstr "търсене и в следените, и в неследените файлове"
+#: builtin/interpret-trailers.c:96
+msgid "trim empty trailers"
+msgstr "изчистване на празните епилози"
 
-#: builtin/grep.c:796
-msgid "ignore files specified via '.gitignore'"
-msgstr "игнориране на файловете указани в „.gitignore“"
+#: builtin/interpret-trailers.c:99
+msgid "where to place the new trailer"
+msgstr "къде да се постави новият епилог"
 
-#: builtin/grep.c:798
-msgid "recursively search in each submodule"
-msgstr "рекурсивно търсене във всички подмодули"
+#: builtin/interpret-trailers.c:101
+msgid "action if trailer already exists"
+msgstr "действие, ако епилог вече съществува"
 
-#: builtin/grep.c:801
-msgid "show non-matching lines"
-msgstr "извеждане на редовете, които не съвпадат"
+#: builtin/interpret-trailers.c:103
+msgid "action if trailer is missing"
+msgstr "действие при липсващ епилог"
 
-#: builtin/grep.c:803
-msgid "case insensitive matching"
-msgstr "без значение на регистъра на буквите (главни/малки)"
+#: builtin/interpret-trailers.c:105
+msgid "output only the trailers"
+msgstr "извеждане само на епилозите"
 
-#: builtin/grep.c:805
-msgid "match patterns only at word boundaries"
-msgstr "напасване на шаблоните само по границите на думите"
+#: builtin/interpret-trailers.c:106
+msgid "do not apply config rules"
+msgstr "без прилагане на правилата за настройките"
 
-#: builtin/grep.c:807
-msgid "process binary files as text"
-msgstr "обработване на двоичните файлове като текстови"
+#: builtin/interpret-trailers.c:107
+msgid "join whitespace-continued values"
+msgstr "сливане на стойностите последване от знаци за интервали"
 
-#: builtin/grep.c:809
-msgid "don't match patterns in binary files"
-msgstr "прескачане на двоичните файлове"
+#: builtin/interpret-trailers.c:108
+msgid "set parsing options"
+msgstr "опции при анализ"
 
-#: builtin/grep.c:812
-msgid "process binary files with textconv filters"
-msgstr ""
-"обработване на двоичните файлове чрез филтри за преобразуване към текст"
+#: builtin/interpret-trailers.c:110
+msgid "do not treat --- specially"
+msgstr "„---“ няма специално значение"
 
-#: builtin/grep.c:814
-msgid "descend at most <depth> levels"
-msgstr "навлизане максимално на тази ДЪЛБОЧИНА в дървото"
+#: builtin/interpret-trailers.c:111
+msgid "trailer"
+msgstr "епилог"
 
-#: builtin/grep.c:818
-msgid "use extended POSIX regular expressions"
-msgstr "разширени регулярни изрази по POSIX"
+#: builtin/interpret-trailers.c:112
+msgid "trailer(s) to add"
+msgstr "епилози за добавяне"
 
-#: builtin/grep.c:821
-msgid "use basic POSIX regular expressions (default)"
-msgstr "основни регулярни изрази по POSIX (стандартно)"
+#: builtin/interpret-trailers.c:123
+msgid "--trailer with --only-input does not make sense"
+msgstr "опцията „--trailer“ е несъвместима с „--name-only“"
 
-#: builtin/grep.c:824
-msgid "interpret patterns as fixed strings"
-msgstr "шаблоните са дословни низове"
+#: builtin/interpret-trailers.c:133
+msgid "no input file given for in-place editing"
+msgstr "не е зададен входен файл за редактиране на място"
 
-#: builtin/grep.c:827
-msgid "use Perl-compatible regular expressions"
-msgstr "регулярни изрази на Perl"
+#: builtin/log.c:56
+msgid "git log [<options>] [<revision-range>] [[--] <path>...]"
+msgstr "git log [ОПЦИЯ…] [ДИАПАЗОН_НА_ВЕРСИИТЕ] [[--] ПЪТ…]"
 
-#: builtin/grep.c:830
-msgid "show line numbers"
-msgstr "извеждане на номерата на редовете"
+#: builtin/log.c:57
+msgid "git show [<options>] <object>..."
+msgstr "git show [ОПЦИЯ…] ОБЕКТ…"
 
-#: builtin/grep.c:831
-msgid "don't show filenames"
-msgstr "без извеждане на имената на файловете"
+#: builtin/log.c:110
+#, c-format
+msgid "invalid --decorate option: %s"
+msgstr "неправилна опция „--decorate“: %s"
 
-#: builtin/grep.c:832
-msgid "show filenames"
-msgstr "извеждане на имената на файловете"
+#: builtin/log.c:174
+msgid "show source"
+msgstr "извеждане на изходния код"
 
-#: builtin/grep.c:834
-msgid "show filenames relative to top directory"
+#: builtin/log.c:175
+msgid "Use mail map file"
 msgstr ""
-"извеждане на относителните имена на файловете спрямо основната директория на "
-"хранилището"
-
-#: builtin/grep.c:836
-msgid "show only filenames instead of matching lines"
-msgstr "извеждане само на имената на файловете без напасващите редове"
+"Използване на файл за съответствията на имената и адресите на е-поща („."
+"mailmap“)"
 
-#: builtin/grep.c:838
-msgid "synonym for --files-with-matches"
-msgstr "синоним на „--files-with-matches“"
+#: builtin/log.c:177
+msgid "only decorate refs that match <pattern>"
+msgstr "специален формат само на указателите напасващи на ШАБЛОНа"
 
-#: builtin/grep.c:841
-msgid "show only the names of files without match"
-msgstr ""
-"извеждане само на имената на файловете, които не съдържат ред, напасващ на "
-"шаблона"
+#: builtin/log.c:179
+msgid "do not decorate refs that match <pattern>"
+msgstr "без специален формат на указателите напасващи на ШАБЛОНа"
 
-#: builtin/grep.c:843
-msgid "print NUL after filenames"
-msgstr "извеждане на нулевия знак „NUL“ след всяко име на файл"
+#: builtin/log.c:180
+msgid "decorate options"
+msgstr "настройки на форма̀та на извежданата информация"
 
-#: builtin/grep.c:846
-msgid "show the number of matches instead of matching lines"
-msgstr "извеждане на броя на съвпаденията вместо напасващите редове"
+#: builtin/log.c:183
+msgid "Process line range n,m in file, counting from 1"
+msgstr ""
+"Обработване само на редовете във файла в диапазона от n до m включително.  "
+"Броенето започва от 1"
 
-#: builtin/grep.c:847
-msgid "highlight matches"
-msgstr "оцветяване на напасванията"
+#: builtin/log.c:281
+#, c-format
+msgid "Final output: %d %s\n"
+msgstr "Резултат: %d %s\n"
 
-#: builtin/grep.c:849
-msgid "print empty line between matches from different files"
-msgstr "извеждане на празен ред между напасванията от различни файлове"
+#: builtin/log.c:535
+#, c-format
+msgid "git show %s: bad file"
+msgstr "git show %s: повреден файл"
 
-#: builtin/grep.c:851
-msgid "show filename only once above matches from same file"
-msgstr ""
-"извеждане на името на файла само веднъж за всички напасвания от този файл"
+#: builtin/log.c:550 builtin/log.c:645
+#, c-format
+msgid "could not read object %s"
+msgstr "обектът не може да бъде прочетен: %s"
 
-#: builtin/grep.c:854
-msgid "show <n> context lines before and after matches"
-msgstr "извеждане на такъв БРОЙ редове преди и след напасванията"
+#: builtin/log.c:670
+#, c-format
+msgid "unknown type: %d"
+msgstr "неизвестен вид: %d"
 
-#: builtin/grep.c:857
-msgid "show <n> context lines before matches"
-msgstr "извеждане на такъв БРОЙ редове преди напасванията"
+#: builtin/log.c:814
+#, c-format
+msgid "%s: invalid cover from description mode"
+msgstr "%s: неправилно придружаващо писмо от режима на описание"
 
-#: builtin/grep.c:859
-msgid "show <n> context lines after matches"
-msgstr "извеждане на такъв БРОЙ редове след напасванията"
+#: builtin/log.c:821
+msgid "format.headers without value"
+msgstr "не е зададена стойност на „format.headers“"
 
-#: builtin/grep.c:861
-msgid "use <n> worker threads"
-msgstr "използване на такъв БРОЙ работещи нишки"
+#: builtin/log.c:936
+msgid "name of output directory is too long"
+msgstr "прекалено дълго име на директорията за изходната информация"
 
-#: builtin/grep.c:862
-msgid "shortcut for -C NUM"
-msgstr "синоним на „-C БРОЙ“"
+#: builtin/log.c:952
+#, c-format
+msgid "cannot open patch file %s"
+msgstr "файлът-кръпка „%s“ не може да бъде отворен"
 
-#: builtin/grep.c:865
-msgid "show a line with the function name before matches"
-msgstr "извеждане на ред с името на функцията, в която е напаснат шаблона"
+#: builtin/log.c:969
+msgid "need exactly one range"
+msgstr "трябва да зададете точно един диапазон"
 
-#: builtin/grep.c:867
-msgid "show the surrounding function"
-msgstr "извеждане на обхващащата функция"
+#: builtin/log.c:979
+msgid "not a range"
+msgstr "не е диапазон"
 
-#: builtin/grep.c:870
-msgid "read patterns from file"
-msgstr "изчитане на шаблоните от ФАЙЛ"
+#: builtin/log.c:1143
+msgid "cover letter needs email format"
+msgstr "придружаващото писмо трябва да е форматирано като е-писмо"
 
-#: builtin/grep.c:872
-msgid "match <pattern>"
-msgstr "напасване на ШАБЛОН"
+#: builtin/log.c:1149
+msgid "failed to create cover-letter file"
+msgstr "неуспешно създаване на придружаващо писмо"
 
-#: builtin/grep.c:874
-msgid "combine patterns specified with -e"
-msgstr "комбиниране на шаблоните указани с опцията „-e“"
+#: builtin/log.c:1228
+#, c-format
+msgid "insane in-reply-to: %s"
+msgstr "неправилен формат на заглавната част за отговор „in-reply-to“: %s"
 
-#: builtin/grep.c:886
-msgid "indicate hit with exit status without output"
-msgstr ""
-"без извеждане на стандартния изход.  Изходният код указва наличието на "
-"напасване"
+#: builtin/log.c:1255
+msgid "git format-patch [<options>] [<since> | <revision-range>]"
+msgstr "git format-patch [ОПЦИЯ…] [ОТ | ДИАПАЗОН_НА_ВЕРСИИТЕ]"
 
-#: builtin/grep.c:888
-msgid "show only matches from files that match all patterns"
-msgstr ""
-"извеждане на редове само от файловете, които напасват на всички шаблони"
+#: builtin/log.c:1313
+msgid "two output directories?"
+msgstr "може да укажете максимум една директория за изход"
 
-#: builtin/grep.c:890
-msgid "show parse tree for grep expression"
-msgstr "извеждане на дървото за анализ на регулярния израз"
+#: builtin/log.c:1424 builtin/log.c:2197 builtin/log.c:2199 builtin/log.c:2211
+#, c-format
+msgid "unknown commit %s"
+msgstr "непознато подаване: „%s“"
 
-#: builtin/grep.c:894
-msgid "pager"
-msgstr "програма за преглед по страници"
+#: builtin/log.c:1434 builtin/replace.c:58 builtin/replace.c:207
+#: builtin/replace.c:210
+#, c-format
+msgid "failed to resolve '%s' as a valid ref"
+msgstr "„%s“ не е указател или не сочи към нищо"
 
-#: builtin/grep.c:894
-msgid "show matching files in the pager"
-msgstr "извеждане на съвпадащите файлове в програма за преглед по страници"
+#: builtin/log.c:1439
+msgid "could not find exact merge base"
+msgstr "точната база за сливане не може да бъде открита"
 
-#: builtin/grep.c:898
-msgid "allow calling of grep(1) (ignored by this build)"
+#: builtin/log.c:1443
+msgid ""
+"failed to get upstream, if you want to record base commit automatically,\n"
+"please use git branch --set-upstream-to to track a remote branch.\n"
+"Or you could specify base commit by --base=<base-commit-id> manually"
 msgstr ""
-"позволяване на стартирането на grep(1) (текущият компилат пренебрегва тази "
-"опция)"
+"следеният клон не може да бъде установен.  Ако искате ръчно да го\n"
+"зададете, използвайте „git branch --set-upstream-to“.\n"
+"Можете ръчно да зададете базово подаване чрез „--base=<base-commit-id>“."
 
-#: builtin/grep.c:962
-msgid "no pattern given."
-msgstr "липсва шаблон."
+#: builtin/log.c:1463
+msgid "failed to find exact merge base"
+msgstr "точната база при сливане не може да бъде открита"
 
-#: builtin/grep.c:994
-msgid "--no-index or --untracked cannot be used with revs"
-msgstr "опциите „--cached“ и „--untracked“ са несъвместими с версии."
+#: builtin/log.c:1474
+msgid "base commit should be the ancestor of revision list"
+msgstr "базовото подаване трябва да е предшественикът на списъка с версиите"
 
-#: builtin/grep.c:1001
-#, c-format
-msgid "unable to resolve revision: %s"
-msgstr "версията „%s“ не може бъде открита"
+#: builtin/log.c:1478
+msgid "base commit shouldn't be in revision list"
+msgstr "базовото подаване не може да е в списъка с версиите"
 
-#: builtin/grep.c:1036 builtin/index-pack.c:1531
-#, c-format
-msgid "invalid number of threads specified (%d)"
-msgstr "зададен е неправилен брой нишки: %d"
+#: builtin/log.c:1531
+msgid "cannot get patch id"
+msgstr "идентификаторът на кръпката не може да бъде получен"
 
-#: builtin/grep.c:1041
-msgid "no threads support, ignoring --threads"
-msgstr "липсва поддръжка за нишки.  „--threads“ ще се пренебрегне"
+#: builtin/log.c:1583
+msgid "failed to infer range-diff ranges"
+msgstr "неуспешно определяне на диапазоните за разлика"
 
-#: builtin/grep.c:1065
-msgid "--open-files-in-pager only works on the worktree"
-msgstr ""
-"опцията „--open-files-in-pager“ е съвместима само с търсене в работното дърво"
+#: builtin/log.c:1629
+msgid "use [PATCH n/m] even with a single patch"
+msgstr "номерация „[PATCH n/m]“ дори и при единствена кръпка"
 
-#: builtin/grep.c:1088
-msgid "option not supported with --recurse-submodules."
-msgstr "опцията е несъвместима с „--recurse-submodules“."
-
-#: builtin/grep.c:1094
-msgid "--cached or --untracked cannot be used with --no-index."
-msgstr "опциите „--cached“ и „--untracked“ са несъвместими с „--no-index“."
+#: builtin/log.c:1632
+msgid "use [PATCH] even with multiple patches"
+msgstr "номерация „[PATCH]“ дори и при множество кръпки"
 
-#: builtin/grep.c:1100
-msgid "--[no-]exclude-standard cannot be used for tracked contents."
-msgstr ""
-"опциите „--(no-)exclude-standard“ са несъвместими с търсене по следени "
-"файлове."
+#: builtin/log.c:1636
+msgid "print patches to standard out"
+msgstr "извеждане на кръпките на стандартния изход"
 
-#: builtin/grep.c:1108
-msgid "both --cached and trees are given."
-msgstr "опцията „--cached“ е несъвместима със задаване на дърво."
+#: builtin/log.c:1638
+msgid "generate a cover letter"
+msgstr "създаване на придружаващо писмо"
 
-#: builtin/hash-object.c:83
-msgid ""
-"git hash-object [-t <type>] [-w] [--path=<file> | --no-filters] [--stdin] "
-"[--] <file>..."
-msgstr ""
-"git hash-object [-t ВИД] [-w] [--path=ФАЙЛ | --no-filters] [--stdin] [--] "
-"ФАЙЛ…"
+#: builtin/log.c:1640
+msgid "use simple number sequence for output file names"
+msgstr "проста числова последователност за имената на файловете-кръпки"
 
-#: builtin/hash-object.c:84
-msgid "git hash-object  --stdin-paths"
-msgstr "git hash-object --stdin-paths"
+#: builtin/log.c:1641
+msgid "sfx"
+msgstr "ЗНАЦИ"
 
-#: builtin/hash-object.c:96
-msgid "type"
-msgstr "ВИД"
+#: builtin/log.c:1642
+msgid "use <sfx> instead of '.patch'"
+msgstr "използване на тези ЗНАЦИ за суфикс вместо „.patch“"
 
-#: builtin/hash-object.c:96
-msgid "object type"
-msgstr "ВИД на обекта"
+#: builtin/log.c:1644
+msgid "start numbering patches at <n> instead of 1"
+msgstr "номерирането на кръпките да започва от този БРОЙ, а не с 1"
 
-#: builtin/hash-object.c:97
-msgid "write the object into the object database"
-msgstr "записване на обекта в базата от данни за обектите"
+#: builtin/log.c:1646
+msgid "mark the series as Nth re-roll"
+msgstr "отбелязване, че това е N-тата поредна редакция на поредицата от кръпки"
 
-#: builtin/hash-object.c:99
-msgid "read the object from stdin"
-msgstr "изчитане на обекта от стандартния вход"
+#: builtin/log.c:1648
+msgid "Use [RFC PATCH] instead of [PATCH]"
+msgstr "Използване на „[RFC PATCH]“ вместо „[PATCH]“"
 
-#: builtin/hash-object.c:101
-msgid "store file as is without filters"
-msgstr "запазване на файла както е — без филтри"
+#: builtin/log.c:1651
+msgid "cover-from-description-mode"
+msgstr "режим-придружаващо-писмо-по-описание"
 
-#: builtin/hash-object.c:102
-msgid ""
-"just hash any random garbage to create corrupt objects for debugging Git"
+#: builtin/log.c:1652
+msgid "generate parts of a cover letter based on a branch's description"
 msgstr ""
-"създаване и хеширане на произволни данни за повредени обекти за трасиране на "
-"Git"
+"генериране на частите на придружаващото писмо на базата на описанието на "
+"клона"
 
-#: builtin/hash-object.c:103
-msgid "process file as it were from this path"
-msgstr "обработване на ФАЙЛа все едно е с този път"
-
-#: builtin/help.c:45
-msgid "print all available commands"
-msgstr "показване на всички налични команди"
+#: builtin/log.c:1654
+msgid "Use [<prefix>] instead of [PATCH]"
+msgstr "Използване на този „[ПРЕФИКС]“ вместо „[PATCH]“"
 
-#: builtin/help.c:46
-msgid "exclude guides"
-msgstr "без въведения"
+#: builtin/log.c:1657
+msgid "store resulting files in <dir>"
+msgstr "запазване на изходните файлове в тази ДИРЕКТОРИЯ"
 
-#: builtin/help.c:47
-msgid "print list of useful guides"
-msgstr "показване на списък с въведения"
+#: builtin/log.c:1660
+msgid "don't strip/add [PATCH]"
+msgstr "без добавяне/махане на префикса „[PATCH]“"
 
-#: builtin/help.c:48
-msgid "show man page"
-msgstr "показване на страница от ръководството"
+#: builtin/log.c:1663
+msgid "don't output binary diffs"
+msgstr "без извеждане на разлики между двоични файлове"
 
-#: builtin/help.c:49
-msgid "show manual in web browser"
-msgstr "показване на страница от ръководството в уеб браузър"
+#: builtin/log.c:1665
+msgid "output all-zero hash in From header"
+msgstr "в заглавната част „From:“ (от) контролната сума да е само от нули"
 
-#: builtin/help.c:51
-msgid "show info page"
-msgstr "показване на информационна страница"
+#: builtin/log.c:1667
+msgid "don't include a patch matching a commit upstream"
+msgstr "без кръпки, които присъстват в следения клон"
 
-#: builtin/help.c:53
-msgid "print command description"
-msgstr "извеждане на описанието на команда"
+#: builtin/log.c:1669
+msgid "show patch format instead of default (patch + stat)"
+msgstr ""
+"извеждане във формат за кръпки, а на в стандартния (кръпка и статистика)"
 
-#: builtin/help.c:58
-msgid "git help [--all] [--guides] [--man | --web | --info] [<command>]"
-msgstr "git help [--all] [--guides] [--man | --web | --info] [КОМАНДА]"
+#: builtin/log.c:1671
+msgid "Messaging"
+msgstr "Опции при изпращане"
 
-#: builtin/help.c:70
-#, c-format
-msgid "unrecognized help format '%s'"
-msgstr "непознат формат на помощта „%s“"
+#: builtin/log.c:1672
+msgid "header"
+msgstr "ЗАГЛАВНА_ЧАСТ"
 
-#: builtin/help.c:97
-msgid "Failed to start emacsclient."
-msgstr "Неуспешно стартиране на „emacsclient“."
+#: builtin/log.c:1673
+msgid "add email header"
+msgstr "добавяне на тази ЗАГЛАВНА_ЧАСТ"
 
-#: builtin/help.c:110
-msgid "Failed to parse emacsclient version."
-msgstr "Версията на „emacsclient“ не може да се анализира."
+#: builtin/log.c:1674 builtin/log.c:1676
+msgid "email"
+msgstr "Е-ПОЩА"
 
-#: builtin/help.c:118
-#, c-format
-msgid "emacsclient version '%d' too old (< 22)."
-msgstr "Прекалено стара версия на „emacsclient“ — %d (< 22)."
+#: builtin/log.c:1674
+msgid "add To: header"
+msgstr "добавяне на заглавна част „To:“ (до)"
 
-#: builtin/help.c:136 builtin/help.c:158 builtin/help.c:168 builtin/help.c:176
-#, c-format
-msgid "failed to exec '%s'"
-msgstr "неуспешно изпълнение на „%s“"
+#: builtin/log.c:1676
+msgid "add Cc: header"
+msgstr "добавяне на заглавна част „Cc:“ (и до)"
 
-#: builtin/help.c:214
-#, c-format
-msgid ""
-"'%s': path for unsupported man viewer.\n"
-"Please consider using 'man.<tool>.cmd' instead."
-msgstr ""
-"„%s“: път към неподдържана програма за преглед на\n"
-" ръководството.  Вместо нея пробвайте „man.<tool>.cmd“."
+#: builtin/log.c:1678
+msgid "ident"
+msgstr "ИДЕНТИЧНОСТ"
 
-#: builtin/help.c:226
-#, c-format
-msgid ""
-"'%s': cmd for supported man viewer.\n"
-"Please consider using 'man.<tool>.path' instead."
+#: builtin/log.c:1679
+msgid "set From address to <ident> (or committer ident if absent)"
 msgstr ""
-"„%s“: команда за поддържана програма за преглед на\n"
-" ръководството.  Вместо нея пробвайте „man.<tool>.path“."
-
-#: builtin/help.c:343
-#, c-format
-msgid "'%s': unknown man viewer."
-msgstr "„%s“: непозната програма за преглед на ръководството."
+"задаване на адреса в заглавната част „From“ (от) да е тази ИДЕНТИЧНОСТ.  Ако "
+"не е зададена такава, се взима адреса на подаващия"
 
-#: builtin/help.c:360
-msgid "no man viewer handled the request"
-msgstr "никоя програма за преглед на ръководство не успя да обработи заявката"
+#: builtin/log.c:1681
+msgid "message-id"
+msgstr "ИДЕНТИФИКАТОР_НА_СЪОБЩЕНИЕ"
 
-#: builtin/help.c:368
-msgid "no info viewer handled the request"
+#: builtin/log.c:1682
+msgid "make first mail a reply to <message-id>"
 msgstr ""
-"никоя програма за преглед на информационните страници не успя да обработи "
-"заявката"
-
-#: builtin/help.c:415
-#, c-format
-msgid "'%s' is aliased to '%s'"
-msgstr "„%s“ е синоним на „%s“"
+"първото съобщение да е в отговор на е-писмото с този "
+"ИДЕНТИФИКАТОР_НА_СЪОБЩЕНИЕ"
 
-#: builtin/help.c:442 builtin/help.c:459
-#, c-format
-msgid "usage: %s%s"
-msgstr "употреба: %s%s"
+#: builtin/log.c:1683 builtin/log.c:1686
+msgid "boundary"
+msgstr "граница"
 
-#: builtin/index-pack.c:158
-#, c-format
-msgid "unable to open %s"
-msgstr "обектът „%s“ не може да бъде отворен"
+#: builtin/log.c:1684
+msgid "attach the patch"
+msgstr "прикрепяне на кръпката"
 
-#: builtin/index-pack.c:208
-#, c-format
-msgid "object type mismatch at %s"
-msgstr "неправилен вид на обекта „%s“"
+#: builtin/log.c:1687
+msgid "inline the patch"
+msgstr "включване на кръпката в текста на писмата"
 
-#: builtin/index-pack.c:228
-#, c-format
-msgid "did not receive expected object %s"
-msgstr "очакваният обект „%s“ не бе получен"
+#: builtin/log.c:1691
+msgid "enable message threading, styles: shallow, deep"
+msgstr ""
+"използване на нишки за съобщенията.  СТИЛът е „shallow“ (плитък) или "
+"„deep“ (дълбок)"
 
-#: builtin/index-pack.c:231
-#, c-format
-msgid "object %s: expected type %s, found %s"
-msgstr "неправилен вид на обекта „%s“: очакваше се „%s“, а бе получен „%s“"
+#: builtin/log.c:1693
+msgid "signature"
+msgstr "подпис"
 
-#: builtin/index-pack.c:273
-#, c-format
-msgid "cannot fill %d byte"
-msgid_plural "cannot fill %d bytes"
-msgstr[0] "не може да се запълни %d байт"
-msgstr[1] "не може да се запълнят %d байта"
+#: builtin/log.c:1694
+msgid "add a signature"
+msgstr "добавяне на поле за подпис"
 
-#: builtin/index-pack.c:283
-msgid "early EOF"
-msgstr "неочакван край на файл"
+#: builtin/log.c:1695
+msgid "base-commit"
+msgstr "БАЗОВО_ПОДАВАНЕ"
 
-#: builtin/index-pack.c:284
-msgid "read error on input"
-msgstr "грешка при четене на входните данни"
+#: builtin/log.c:1696
+msgid "add prerequisite tree info to the patch series"
+msgstr "добавяне на необходимото БАЗово дърво към поредицата от кръпки"
 
-#: builtin/index-pack.c:296
-msgid "used more bytes than were available"
-msgstr "използвани са повече от наличните байтове"
+#: builtin/log.c:1698
+msgid "add a signature from a file"
+msgstr "добавяне на подпис от файл"
 
-#: builtin/index-pack.c:303
-msgid "pack too large for current definition of off_t"
-msgstr "пакетният файл е прекалено голям за текущата стойност на типа „off_t“"
+#: builtin/log.c:1699
+msgid "don't print the patch filenames"
+msgstr "без извеждане на имената на кръпките"
 
-#: builtin/index-pack.c:306 builtin/unpack-objects.c:93
-msgid "pack exceeds maximum allowed size"
-msgstr "пакетният файл надвишава максималния възможен размер"
+#: builtin/log.c:1701
+msgid "show progress while generating patches"
+msgstr "извеждане на напредъка във фазата на създаване на кръпките"
 
-#: builtin/index-pack.c:321
-#, c-format
-msgid "unable to create '%s'"
-msgstr "пакетният файл „%s“ не може да бъде създаден"
+#: builtin/log.c:1703
+msgid "show changes against <rev> in cover letter or single patch"
+msgstr ""
+"показване на промените спрямо ВЕРСията в придружаващото писмо или единствена "
+"кръпка"
 
-#: builtin/index-pack.c:327
-#, c-format
-msgid "cannot open packfile '%s'"
-msgstr "пакетният файл „%s“ не може да бъде отворен"
+#: builtin/log.c:1706
+msgid "show changes against <refspec> in cover letter or single patch"
+msgstr ""
+"показване на промените спрямо указателя на ВЕРСията в придружаващото писмо "
+"или единствена кръпка"
 
-#: builtin/index-pack.c:341
-msgid "pack signature mismatch"
-msgstr "несъответствие в подписа към пакетния файл"
+#: builtin/log.c:1708
+msgid "percentage by which creation is weighted"
+msgstr "процент за претегляне при оценка на създаването"
 
-#: builtin/index-pack.c:343
+#: builtin/log.c:1792
 #, c-format
-msgid "pack version %<PRIu32> unsupported"
-msgstr "не се поддържа пакетиране вeрсия „%<PRIu32>“"
+msgid "invalid ident line: %s"
+msgstr "грешна идентичност: %s"
 
-#: builtin/index-pack.c:361
-#, c-format
-msgid "pack has bad object at offset %<PRIuMAX>: %s"
-msgstr "повреден обект в пакетния файл при отместване %<PRIuMAX>: %s"
+#: builtin/log.c:1807
+msgid "-n and -k are mutually exclusive"
+msgstr "опциите „-n“ и „-k“ са несъвместими"
+
+#: builtin/log.c:1809
+msgid "--subject-prefix/--rfc and -k are mutually exclusive"
+msgstr "опциите „--subject-prefix“/„-rfc“ и „-k“ са несъвместими"
 
-#: builtin/index-pack.c:482
-#, c-format
-msgid "inflate returned %d"
-msgstr "декомпресирането с „inflate“ върна %d"
+#: builtin/log.c:1817
+msgid "--name-only does not make sense"
+msgstr "опцията „--name-only“ е несъвместима с генерирането на кръпки"
 
-#: builtin/index-pack.c:531
-msgid "offset value overflow for delta base object"
-msgstr "стойността на отместването за обекта-разлика води до препълване"
+#: builtin/log.c:1819
+msgid "--name-status does not make sense"
+msgstr "опцията „--name-status“ е несъвместима с генерирането на кръпки"
 
-#: builtin/index-pack.c:539
-msgid "delta base offset is out of bound"
-msgstr "стойността на отместването за обекта-разлика е извън диапазона"
+#: builtin/log.c:1821
+msgid "--check does not make sense"
+msgstr "опцията „--check“ е несъвместима с генерирането на кръпки"
 
-#: builtin/index-pack.c:547
-#, c-format
-msgid "unknown object type %d"
-msgstr "непознат вид обект %d"
+#: builtin/log.c:1854
+msgid "standard output, or directory, which one?"
+msgstr ""
+"изходът може да или стандартният, или да е в директория, но не и двете."
 
-#: builtin/index-pack.c:578
-msgid "cannot pread pack file"
-msgstr "пакетният файл не може да бъде прочетен"
+#: builtin/log.c:1958
+msgid "--interdiff requires --cover-letter or single patch"
+msgstr ""
+"опцията „--interdiff“ изисква опция „--cover-letter“ или единствена кръпка"
 
-#: builtin/index-pack.c:580
+#: builtin/log.c:1962
+msgid "Interdiff:"
+msgstr "Разлика в разликите:"
+
+#: builtin/log.c:1963
 #, c-format
-msgid "premature end of pack file, %<PRIuMAX> byte missing"
-msgid_plural "premature end of pack file, %<PRIuMAX> bytes missing"
-msgstr[0] "неочакван край на файл, липсва %<PRIuMAX> байт"
-msgstr[1] "неочакван край на файл, липсват %<PRIuMAX> байта"
+msgid "Interdiff against v%d:"
+msgstr "Разлика в разликите спрямо v%d:"
 
-#: builtin/index-pack.c:606
-msgid "serious inflate inconsistency"
-msgstr "сериозна грешка при декомпресиране с „inflate“"
+#: builtin/log.c:1969
+msgid "--creation-factor requires --range-diff"
+msgstr "опцията „--creation-factor“ изисква опция „--range-diff“"
 
-#: builtin/index-pack.c:751 builtin/index-pack.c:757 builtin/index-pack.c:780
-#: builtin/index-pack.c:819 builtin/index-pack.c:828
-#, c-format
-msgid "SHA1 COLLISION FOUND WITH %s !"
+#: builtin/log.c:1973
+msgid "--range-diff requires --cover-letter or single patch"
 msgstr ""
-"СЪВПАДЕНИЕ НА СТОЙНОСТИТЕ ЗА СУМИТЕ ЗА SHA1: „%s“ НА ДВА РАЗЛИЧНИ ОБЕКТА!"
+"опцията „--range-diff“ изисква опция „--cover-letter“ или единствена кръпка"
 
-#: builtin/index-pack.c:754 builtin/pack-objects.c:198
-#: builtin/pack-objects.c:292
-#, c-format
-msgid "unable to read %s"
-msgstr "обектът „%s“ не може да бъде прочетен"
+#: builtin/log.c:1981
+msgid "Range-diff:"
+msgstr "Диапазонна разлика:"
 
-#: builtin/index-pack.c:817
+#: builtin/log.c:1982
 #, c-format
-msgid "cannot read existing object info %s"
-msgstr "съществуващият обект в „%s“ не може да бъде прочетен"
+msgid "Range-diff against v%d:"
+msgstr "Диапазонна разлика спрямо v%d:"
 
-#: builtin/index-pack.c:825
+#: builtin/log.c:1993
 #, c-format
-msgid "cannot read existing object %s"
-msgstr "съществуващият обект „%s“ не може да бъде прочетен"
+msgid "unable to read signature file '%s'"
+msgstr "файлът „%s“ с подпис не може да бъде прочетен"
 
-#: builtin/index-pack.c:839
-#, c-format
-msgid "invalid blob object %s"
-msgstr "неправилен обект-BLOB „%s“"
+#: builtin/log.c:2029
+msgid "Generating patches"
+msgstr "Създаване на кръпки"
 
-#: builtin/index-pack.c:842 builtin/index-pack.c:860
-msgid "fsck error in packed object"
-msgstr "грешка при проверката на пакетирани обекти"
+#: builtin/log.c:2073
+msgid "failed to create output files"
+msgstr "неуспешно създаване на изходни файлове"
 
-# FIXME perhaps invalid object or pack
-#: builtin/index-pack.c:857
-#, c-format
-msgid "invalid %s"
-msgstr "неправилен обект „%s“"
+#: builtin/log.c:2132
+msgid "git cherry [-v] [<upstream> [<head> [<limit>]]]"
+msgstr "git cherry [-v] [ОТДАЛЕЧЕН_КЛОН [ВРЪХ [ПРЕДЕЛ]]]"
 
-#: builtin/index-pack.c:862
+#: builtin/log.c:2186
 #, c-format
-msgid "Not all child objects of %s are reachable"
-msgstr "Някои обекти, наследници на „%s“, не могат да бъдат достигнати"
+msgid ""
+"Could not find a tracked remote branch, please specify <upstream> manually.\n"
+msgstr ""
+"Следеният отдалечен клон не бе открит, затова изрично задайте "
+"ОТДАЛЕЧЕН_КЛОН.\n"
 
-#: builtin/index-pack.c:934 builtin/index-pack.c:965
-msgid "failed to apply delta"
-msgstr "разликата не може да бъде приложена"
+#: builtin/ls-files.c:470
+msgid "git ls-files [<options>] [<file>...]"
+msgstr "git ls-files [ОПЦИЯ…] [ФАЙЛ…]"
 
-#: builtin/index-pack.c:1135
-msgid "Receiving objects"
-msgstr "Получаване на обекти"
+#: builtin/ls-files.c:526
+msgid "identify the file status with tags"
+msgstr "извеждане на състоянието на файловете с еднобуквени флагове"
 
-#: builtin/index-pack.c:1135
-msgid "Indexing objects"
-msgstr "Индексиране на обекти"
+#: builtin/ls-files.c:528
+msgid "use lowercase letters for 'assume unchanged' files"
+msgstr "малки букви за файловете, които да се счетат за непроменени"
 
-#: builtin/index-pack.c:1169
-msgid "pack is corrupted (SHA1 mismatch)"
-msgstr "пакетният файл е повреден (нееднакви суми по SHA1)"
+#: builtin/ls-files.c:530
+msgid "use lowercase letters for 'fsmonitor clean' files"
+msgstr "малки букви за файловете за командата „fsmonitor clean“"
 
-#: builtin/index-pack.c:1174
-msgid "cannot fstat packfile"
-msgstr "не може да се получи информация за пакетния файл с „fstat“"
+#: builtin/ls-files.c:532
+msgid "show cached files in the output (default)"
+msgstr "извеждане на кешираните файлове (стандартно)"
 
-#: builtin/index-pack.c:1177
-msgid "pack has junk at the end"
-msgstr "в края на пакетния файл има повредени данни"
+#: builtin/ls-files.c:534
+msgid "show deleted files in the output"
+msgstr "извеждане на изтритите файлове"
 
-#: builtin/index-pack.c:1189
-msgid "confusion beyond insanity in parse_pack_objects()"
-msgstr ""
-"фатална грешка във функцията „parse_pack_objects“.  Това е грешка в Git, "
-"докладвайте я на разработчиците, като пратите е-писмо на адрес: „git@vger."
-"kernel.org“."
+#: builtin/ls-files.c:536
+msgid "show modified files in the output"
+msgstr "извеждане на променените файлове"
 
-#: builtin/index-pack.c:1212
-msgid "Resolving deltas"
-msgstr "Откриване на съответните разлики"
+#: builtin/ls-files.c:538
+msgid "show other files in the output"
+msgstr "извеждане на другите файлове"
 
-#: builtin/index-pack.c:1223
-#, c-format
-msgid "unable to create thread: %s"
-msgstr "не може да се създаде нишка: %s"
+#: builtin/ls-files.c:540
+msgid "show ignored files in the output"
+msgstr "извеждане на игнорираните файлове"
 
-#: builtin/index-pack.c:1265
-msgid "confusion beyond insanity"
-msgstr ""
-"фатална грешка във функцията „conclude_pack“.  Това е грешка в Git, "
-"докладвайте я на разработчиците, като пратите е-писмо на адрес: „git@vger."
-"kernel.org“."
+#: builtin/ls-files.c:543
+msgid "show staged contents' object name in the output"
+msgstr "извеждане на името на обекта за съдържанието на индекса"
 
-#: builtin/index-pack.c:1271
-#, c-format
-msgid "completed with %d local object"
-msgid_plural "completed with %d local objects"
-msgstr[0] "действието завърши с %d локален обект"
-msgstr[1] "действието завърши с %d локални обекта"
+#: builtin/ls-files.c:545
+msgid "show files on the filesystem that need to be removed"
+msgstr "извеждане на файловете, които трябва да бъдат изтрити"
 
-#: builtin/index-pack.c:1283
-#, c-format
-msgid "Unexpected tail checksum for %s (disk corruption?)"
-msgstr ""
-"Неочаквана последваща сума за грешки за „%s“ (причината може да е грешка в "
-"диска)"
+#: builtin/ls-files.c:547
+msgid "show 'other' directories' names only"
+msgstr "извеждане само на името на другите (неследените) директории"
 
-#: builtin/index-pack.c:1287
-#, c-format
-msgid "pack has %d unresolved delta"
-msgid_plural "pack has %d unresolved deltas"
-msgstr[0] "в пакета има %d ненапасваща разлика"
-msgstr[1] "в пакета има %d ненапасващи разлики"
+#: builtin/ls-files.c:549
+msgid "show line endings of files"
+msgstr "извеждане на знаците за край на ред във файловете"
 
-#: builtin/index-pack.c:1311
-#, c-format
-msgid "unable to deflate appended object (%d)"
-msgstr "добавеният обект не може да се компресира с „deflate“: %d"
+#: builtin/ls-files.c:551
+msgid "don't show empty directories"
+msgstr "без извеждане на празните директории"
 
-#: builtin/index-pack.c:1388
-#, c-format
-msgid "local object %s is corrupt"
-msgstr "локалният обект „%s“ е повреден"
+#: builtin/ls-files.c:554
+msgid "show unmerged files in the output"
+msgstr "извеждане на неслетите файлове"
 
-#: builtin/index-pack.c:1402
-#, c-format
-msgid "packfile name '%s' does not end with '.pack'"
-msgstr "името на пакетния файл „%s“ не завършва на „.pack“"
+#: builtin/ls-files.c:556
+msgid "show resolve-undo information"
+msgstr "извеждане на информацията за отмяна на разрешените подавания"
 
-#: builtin/index-pack.c:1427
-#, c-format
-msgid "cannot write %s file '%s'"
-msgstr "грешка при запис на файла „%s“ „%s“"
+#: builtin/ls-files.c:558
+msgid "skip files matching pattern"
+msgstr "прескачане на файловете напасващи ШАБЛОНа"
 
-#: builtin/index-pack.c:1435
-#, c-format
-msgid "cannot close written %s file '%s'"
-msgstr "грешка при затварянето на записания файл „%s“ „%s“"
+#: builtin/ls-files.c:561
+msgid "exclude patterns are read from <file>"
+msgstr "шаблоните за игнориране да се прочетат от този ФАЙЛ"
 
-#: builtin/index-pack.c:1459
-msgid "error while closing pack file"
-msgstr "грешка при затварянето на пакетния файл"
+#: builtin/ls-files.c:564
+msgid "read additional per-directory exclude patterns in <file>"
+msgstr ""
+"изчитане на допълнителните шаблони за игнориране по директория от този ФАЙЛ"
 
-#: builtin/index-pack.c:1473
-msgid "cannot store pack file"
-msgstr "пакетният файл не може да бъде запазен"
+#: builtin/ls-files.c:566
+msgid "add the standard git exclusions"
+msgstr "добавяне на стандартно игнорираните от Git файлове"
 
-#: builtin/index-pack.c:1481
-msgid "cannot store index file"
-msgstr "файлът за индекса не може да бъде съхранен"
+#: builtin/ls-files.c:570
+msgid "make the output relative to the project top directory"
+msgstr "пътищата да са относителни спрямо основната директория на проекта"
 
-#: builtin/index-pack.c:1525
-#, c-format
-msgid "bad pack.indexversion=%<PRIu32>"
-msgstr "зададена е неправилна версия пакетиране: „pack.indexversion=%<PRIu32>“"
+#: builtin/ls-files.c:573
+msgid "recurse through submodules"
+msgstr "рекурсивно обхождане подмодулите"
 
-#: builtin/index-pack.c:1594
-#, c-format
-msgid "Cannot open existing pack file '%s'"
-msgstr "Съществуващият пакетен файл „%s“ не може да бъде отворен"
+#: builtin/ls-files.c:575
+msgid "if any <file> is not in the index, treat this as an error"
+msgstr "грешка, ако някой от тези ФАЙЛове не е в индекса"
 
-#: builtin/index-pack.c:1596
-#, c-format
-msgid "Cannot open existing pack idx file for '%s'"
-msgstr "Съществуващият индекс за пакетния файл „%s“ не може да бъде отворен"
+#: builtin/ls-files.c:576
+msgid "tree-ish"
+msgstr "УКАЗАТЕЛ_КЪМ_ДЪРВО"
 
-#: builtin/index-pack.c:1644
-#, c-format
-msgid "non delta: %d object"
-msgid_plural "non delta: %d objects"
-msgstr[0] "%d обект не е разлика"
-msgstr[1] "%d обекта не са разлика"
+#: builtin/ls-files.c:577
+msgid "pretend that paths removed since <tree-ish> are still present"
+msgstr ""
+"считане, че пътищата изтрити след УКАЗАТЕЛя_КЪМ_ДЪРВО все още съществуват"
 
-#: builtin/index-pack.c:1651
-#, c-format
-msgid "chain length = %d: %lu object"
-msgid_plural "chain length = %d: %lu objects"
-msgstr[0] "дължината на веригата е %d: %lu обект"
-msgstr[1] "дължината на веригата е %d: %lu обекта"
+#: builtin/ls-files.c:579
+msgid "show debugging data"
+msgstr "извеждане на информацията за изчистване на грешки"
 
-#: builtin/index-pack.c:1688
-msgid "Cannot come back to cwd"
-msgstr "Процесът не може да се върне към предишната работна директория"
+#: builtin/ls-remote.c:9
+msgid ""
+"git ls-remote [--heads] [--tags] [--refs] [--upload-pack=<exec>]\n"
+"                     [-q | --quiet] [--exit-code] [--get-url]\n"
+"                     [--symref] [<repository> [<refs>...]]"
+msgstr ""
+"git ls-remote [--heads] [--tags] [--refs] [--upload-pack=КОМАНДА]\n"
+"                     [-q | --quiet] [--exit-code] [--get-url]\n"
+"                     [--symref] [ХРАНИЛИЩЕ [УКАЗАТЕЛ…]]"
 
-#: builtin/index-pack.c:1739 builtin/index-pack.c:1742
-#: builtin/index-pack.c:1758 builtin/index-pack.c:1762
-#, c-format
-msgid "bad %s"
-msgstr "неправилна стойност „%s“"
+#: builtin/ls-remote.c:59
+msgid "do not print remote URL"
+msgstr "без извеждане на адресите на отдалечените хранилища"
 
-#: builtin/index-pack.c:1778
-msgid "--fix-thin cannot be used without --stdin"
-msgstr "опцията „--fix-thin“ изисква „--stdin“"
+#: builtin/ls-remote.c:60 builtin/ls-remote.c:62 builtin/rebase.c:1518
+msgid "exec"
+msgstr "КОМАНДА"
 
-#: builtin/index-pack.c:1780
-msgid "--stdin requires a git repository"
-msgstr "„--stdin“ изисква хранилище на git"
+#: builtin/ls-remote.c:61 builtin/ls-remote.c:63
+msgid "path of git-upload-pack on the remote host"
+msgstr "път към командата „git-upload-pack“ на отдалечената машина"
 
-#: builtin/index-pack.c:1786
-msgid "--verify with no packfile name given"
-msgstr "опцията „--verify“ изисква име на пакетен файл"
+#: builtin/ls-remote.c:65
+msgid "limit to tags"
+msgstr "само етикетите"
 
-#: builtin/index-pack.c:1836 builtin/unpack-objects.c:578
-msgid "fsck error in pack objects"
-msgstr "грешка при проверка с „fsck“ на пакетните обекти"
+#: builtin/ls-remote.c:66
+msgid "limit to heads"
+msgstr "само върховете"
 
-#: builtin/init-db.c:55
-#, c-format
-msgid "cannot stat '%s'"
-msgstr "не може да се получи информация чрез „stat“ за директорията „%s“"
+#: builtin/ls-remote.c:67
+msgid "do not show peeled tags"
+msgstr "без проследяване на непреките етикети"
 
-#: builtin/init-db.c:61
-#, c-format
-msgid "cannot stat template '%s'"
-msgstr "не може да се получи информация чрез „stat“ за шаблона „%s“"
+#: builtin/ls-remote.c:69
+msgid "take url.<base>.insteadOf into account"
+msgstr "взимане предвид на „url.БАЗА.insteadOf“"
 
-#: builtin/init-db.c:66
-#, c-format
-msgid "cannot opendir '%s'"
-msgstr "директорията „%s“ не може да бъде отворена"
+#: builtin/ls-remote.c:72
+msgid "exit with exit code 2 if no matching refs are found"
+msgstr "изход с код 2, ако не се открият съвпадащи указатели"
 
-#: builtin/init-db.c:77
-#, c-format
-msgid "cannot readlink '%s'"
-msgstr "връзката „%s“ не може да бъде прочетена"
+#: builtin/ls-remote.c:75
+msgid "show underlying ref in addition to the object pointed by it"
+msgstr "извеждане на указателя заедно с обекта сочен от него"
 
-#: builtin/init-db.c:79
-#, c-format
-msgid "cannot symlink '%s' '%s'"
-msgstr "не може да се създаде символна връзка „%s“ в „%s“"
+#: builtin/ls-tree.c:30
+msgid "git ls-tree [<options>] <tree-ish> [<path>...]"
+msgstr "git ls-tree [ОПЦИЯ…] УКАЗАТЕЛ_КЪМ_ДЪРВО [ПЪТ…]"
 
-#: builtin/init-db.c:85
-#, c-format
-msgid "cannot copy '%s' to '%s'"
-msgstr "„%s“ не може да се копира в „%s“"
+#: builtin/ls-tree.c:128
+msgid "only show trees"
+msgstr "извеждане само на дървета"
 
-#: builtin/init-db.c:89
-#, c-format
-msgid "ignoring template %s"
-msgstr "игнориране на шаблона „%s“"
+#: builtin/ls-tree.c:130
+msgid "recurse into subtrees"
+msgstr "рекурсивно обхождане поддърветата"
 
-#: builtin/init-db.c:120
-#, c-format
-msgid "templates not found in %s"
-msgstr "няма шаблони в „%s“"
+#: builtin/ls-tree.c:132
+msgid "show trees when recursing"
+msgstr "извеждане на дърветата при рекурсивното обхождане"
 
-#: builtin/init-db.c:135
-#, c-format
-msgid "not copying templates from '%s': %s"
-msgstr "шаблоните няма да бъдат копирани от „%s“: „%s“"
+#: builtin/ls-tree.c:135
+msgid "terminate entries with NUL byte"
+msgstr "разделяне на обектите с нулевия знак „NUL“"
 
-#: builtin/init-db.c:328
-#, c-format
-msgid "unable to handle file type %d"
-msgstr "файлове от вид %d не се поддържат"
+#: builtin/ls-tree.c:136
+msgid "include object size"
+msgstr "извеждане на размера на обекта"
 
-#: builtin/init-db.c:331
-#, c-format
-msgid "unable to move %s to %s"
-msgstr "„%s“ не може да се премести в „%s“"
+#: builtin/ls-tree.c:138 builtin/ls-tree.c:140
+msgid "list only filenames"
+msgstr "извеждане само имената на файловете"
 
-#: builtin/init-db.c:348 builtin/init-db.c:351
-#, c-format
-msgid "%s already exists"
-msgstr "Директорията „%s“ вече съществува"
+#: builtin/ls-tree.c:143
+msgid "use full path names"
+msgstr "използване на пълните имена на пътищата"
 
-#: builtin/init-db.c:404
-#, c-format
-msgid "Reinitialized existing shared Git repository in %s%s\n"
+#: builtin/ls-tree.c:145
+msgid "list entire tree; not just current directory (implies --full-name)"
 msgstr ""
-"Инициализиране наново на съществуващо, споделено хранилище на Git в „%s%s“\n"
+"извеждане на цялото дърво, не само на текущата директория (включва опцията "
+"„--full-name“)"
 
-#: builtin/init-db.c:405
+#: builtin/mailsplit.c:241
 #, c-format
-msgid "Reinitialized existing Git repository in %s%s\n"
-msgstr "Инициализиране наново на съществуващо хранилище на Git в „%s%s“\n"
+msgid "empty mbox: '%s'"
+msgstr "празна пощенска кутия mbox: „%s“"
 
-#: builtin/init-db.c:409
-#, c-format
-msgid "Initialized empty shared Git repository in %s%s\n"
-msgstr "Инициализиране на празно, споделено хранилище на Git в „%s%s“\n"
+#: builtin/merge.c:55
+msgid "git merge [<options>] [<commit>...]"
+msgstr "git merge [ОПЦИЯ…] [ПОДАВАНЕ…]"
 
-#: builtin/init-db.c:410
-#, c-format
-msgid "Initialized empty Git repository in %s%s\n"
-msgstr "Инициализиране на празно хранилище на Git в „%s%s“\n"
+#: builtin/merge.c:56
+msgid "git merge --abort"
+msgstr "git merge --abort"
 
-#: builtin/init-db.c:458
-msgid ""
-"git init [-q | --quiet] [--bare] [--template=<template-directory>] [--"
-"shared[=<permissions>]] [<directory>]"
-msgstr ""
-"git init [-q | --quiet] [--bare] [--template=ДИРЕКТОРИЯ_С_ШАБЛОНИ] [--"
-"shared[=ПРАВА]] [ДИРЕКТОРИЯ]"
+#: builtin/merge.c:57
+msgid "git merge --continue"
+msgstr "git merge --continue"
 
-#: builtin/init-db.c:481
-msgid "permissions"
-msgstr "права"
+#: builtin/merge.c:118
+msgid "switch `m' requires a value"
+msgstr "опцията „-m“ изисква стойност"
 
-#: builtin/init-db.c:482
-msgid "specify that the git repository is to be shared amongst several users"
-msgstr ""
-"указване, че хранилището на Git ще бъде споделено от повече от един "
-"потребител"
+#: builtin/merge.c:141
+#, c-format
+msgid "option `%s' requires a value"
+msgstr "опцията „%s“ изисква стойност"
 
-#: builtin/init-db.c:525
+#: builtin/merge.c:187
 #, c-format
-msgid "cannot chdir to %s"
-msgstr "не може да се влезе в директорията „%s“"
+msgid "Could not find merge strategy '%s'.\n"
+msgstr "Няма такава стратегия за сливане: „%s“.\n"
 
-#: builtin/init-db.c:546
+#: builtin/merge.c:188
 #, c-format
-msgid ""
-"%s (or --work-tree=<directory>) not allowed without specifying %s (or --git-"
-"dir=<directory>)"
-msgstr ""
-"%s (или --work-tree=ДИРЕКТОРИЯ) изисква указването на %s (или --git-"
-"dir=ДИРЕКТОРИЯ)"
+msgid "Available strategies are:"
+msgstr "Наличните стратегии са:"
 
-#: builtin/init-db.c:574
+#: builtin/merge.c:193
 #, c-format
-msgid "Cannot access work tree '%s'"
-msgstr "Работното дърво в „%s“ е недостъпно"
+msgid "Available custom strategies are:"
+msgstr "Допълнителните стратегии са:"
 
-#: builtin/interpret-trailers.c:15
-msgid ""
-"git interpret-trailers [--in-place] [--trim-empty] [(--trailer "
-"<token>[(=|:)<value>])...] [<file>...]"
-msgstr ""
-"git interpret-trailers [--in-place] [--trim-empty] [(--trailer "
-"ЛЕКСЕМА[(=|:)СТОЙНОСТ])…] [ФАЙЛ…]"
+#: builtin/merge.c:244 builtin/pull.c:152
+msgid "do not show a diffstat at the end of the merge"
+msgstr "без извеждане на статистиката след завършване на сливане"
 
-#: builtin/interpret-trailers.c:92
-msgid "edit files in place"
-msgstr "директно редактиране на файловете"
+#: builtin/merge.c:247 builtin/pull.c:155
+msgid "show a diffstat at the end of the merge"
+msgstr "извеждане на статистиката след завършване на сливане"
 
-#: builtin/interpret-trailers.c:93
-msgid "trim empty trailers"
-msgstr "изчистване на празните епилози"
+#: builtin/merge.c:248 builtin/pull.c:158
+msgid "(synonym to --stat)"
+msgstr "(псевдоним на „--stat“)"
 
-#: builtin/interpret-trailers.c:96
-msgid "where to place the new trailer"
-msgstr "къде да се постави новият епилог"
+#: builtin/merge.c:250 builtin/pull.c:161
+msgid "add (at most <n>) entries from shortlog to merge commit message"
+msgstr ""
+"добавяне (на максимум такъв БРОЙ) записи от съкратения журнал в съобщението "
+"за подаване"
 
-#: builtin/interpret-trailers.c:98
-msgid "action if trailer already exists"
-msgstr "действие, ако епилог вече съществува"
+#: builtin/merge.c:253 builtin/pull.c:167
+msgid "create a single commit instead of doing a merge"
+msgstr "създаване на едно подаване вместо извършване на сливане"
 
-#: builtin/interpret-trailers.c:100
-msgid "action if trailer is missing"
-msgstr "действие при липсващ епилог"
+#: builtin/merge.c:255 builtin/pull.c:170
+msgid "perform a commit if the merge succeeds (default)"
+msgstr "извършване на подаване при успешно сливане (стандартно действие)"
 
-#: builtin/interpret-trailers.c:102
-msgid "output only the trailers"
-msgstr "извеждане само на епилозите"
+#: builtin/merge.c:257 builtin/pull.c:173
+msgid "edit message before committing"
+msgstr "редактиране на съобщението преди подаване"
 
-#: builtin/interpret-trailers.c:103
-msgid "do not apply config rules"
-msgstr "без прилагане на правилата за настройките"
+#: builtin/merge.c:259
+msgid "allow fast-forward (default)"
+msgstr "позволяване на превъртане (стандартно действие)"
 
-#: builtin/interpret-trailers.c:104
-msgid "join whitespace-continued values"
-msgstr "сливане на стойностите последване от знаци за интервали"
+#: builtin/merge.c:261 builtin/pull.c:180
+msgid "abort if fast-forward is not possible"
+msgstr "преустановяване, ако превъртането е невъзможно"
 
-#: builtin/interpret-trailers.c:105
-msgid "set parsing options"
-msgstr "опции при анализ"
+#: builtin/merge.c:265 builtin/pull.c:183
+msgid "verify that the named commit has a valid GPG signature"
+msgstr "проверка, че указаното подаване е с правилен подпис на GPG"
 
-#: builtin/interpret-trailers.c:107
-msgid "trailer"
-msgstr "епилог"
+#: builtin/merge.c:266 builtin/notes.c:787 builtin/pull.c:187
+#: builtin/rebase.c:512 builtin/rebase.c:1531 builtin/revert.c:114
+msgid "strategy"
+msgstr "СТРАТЕГИЯ"
 
-#: builtin/interpret-trailers.c:108
-msgid "trailer(s) to add"
-msgstr "епилози за добавяне"
+#: builtin/merge.c:267 builtin/pull.c:188
+msgid "merge strategy to use"
+msgstr "СТРАТЕГИЯ за сливане, която да се ползва"
 
-#: builtin/interpret-trailers.c:117
-msgid "--trailer with --only-input does not make sense"
-msgstr "опцията „--trailer“ е несъвместима с „--name-only“"
+#: builtin/merge.c:268 builtin/pull.c:191
+msgid "option=value"
+msgstr "ОПЦИЯ=СТОЙНОСТ"
 
-#: builtin/interpret-trailers.c:127
-msgid "no input file given for in-place editing"
-msgstr "не е зададен входен файл за редактиране на място"
+#: builtin/merge.c:269 builtin/pull.c:192
+msgid "option for selected merge strategy"
+msgstr "ОПЦИЯ за избраната стратегия за сливане"
 
-#: builtin/log.c:48
-msgid "git log [<options>] [<revision-range>] [[--] <path>...]"
-msgstr "git log [ОПЦИЯ…] [ДИАПАЗОН_НА_ВЕРСИИТЕ] [[--] ПЪТ…]"
+#: builtin/merge.c:271
+msgid "merge commit message (for a non-fast-forward merge)"
+msgstr "СЪОБЩЕНИЕ при подаването със сливане (при същински сливания)"
 
-#: builtin/log.c:49
-msgid "git show [<options>] <object>..."
-msgstr "git show [ОПЦИЯ…] ОБЕКТ…"
+#: builtin/merge.c:278
+msgid "abort the current in-progress merge"
+msgstr "преустановяване на текущото сливане"
 
-#: builtin/log.c:93
-#, c-format
-msgid "invalid --decorate option: %s"
-msgstr "неправилна опция „--decorate“: %s"
+#: builtin/merge.c:280
+msgid "--abort but leave index and working tree alone"
+msgstr "преустановяване без промяна на индекса и работното дърво"
 
-#: builtin/log.c:153
-msgid "suppress diff output"
-msgstr "без извеждане на разликите"
+#: builtin/merge.c:282
+msgid "continue the current in-progress merge"
+msgstr "продължаване на текущото сливане"
 
-#: builtin/log.c:154
-msgid "show source"
-msgstr "извеждане на изходния код"
+#: builtin/merge.c:284 builtin/pull.c:199
+msgid "allow merging unrelated histories"
+msgstr "позволяване на сливане на независими истории"
 
-#: builtin/log.c:155
-msgid "Use mail map file"
+#: builtin/merge.c:290
+msgid "bypass pre-merge-commit and commit-msg hooks"
 msgstr ""
-"Използване на файл за съответствията на имената и адресите на е-поща („."
-"mailmap“)"
+"без изпълнение на куките преди подаване и сливане и при промяна на "
+"съобщението за подаване (pre-merge-commit и commit-msg)"
 
-#: builtin/log.c:157
-msgid "only decorate refs that match <pattern>"
-msgstr "специален формат само на указателите напасващи на ШАБЛОНа"
+#: builtin/merge.c:307
+msgid "could not run stash."
+msgstr "не може да се извърши скатаване"
 
-#: builtin/log.c:159
-msgid "do not decorate refs that match <pattern>"
-msgstr "без специален формат на указателите напасващи на ШАБЛОНа"
+#: builtin/merge.c:312
+msgid "stash failed"
+msgstr "неуспешно скатаване"
 
-#: builtin/log.c:160
-msgid "decorate options"
-msgstr "настройки на форма̀та на извежданата информация"
+#: builtin/merge.c:317
+#, c-format
+msgid "not a valid object: %s"
+msgstr "неправилен обект: „%s“"
 
-#: builtin/log.c:163
-msgid "Process line range n,m in file, counting from 1"
-msgstr ""
-"Обработване само на редовете във файла в диапазона от n до m включително.  "
-"Броенето започва от 1"
+#: builtin/merge.c:339 builtin/merge.c:356
+msgid "read-tree failed"
+msgstr "неуспешно прочитане на обект-дърво"
 
-#: builtin/log.c:259
-#, c-format
-msgid "Final output: %d %s\n"
-msgstr "Резултат: %d %s\n"
+#: builtin/merge.c:386
+msgid " (nothing to squash)"
+msgstr " (няма какво да се вкара)"
 
-#: builtin/log.c:510
+#: builtin/merge.c:397
 #, c-format
-msgid "git show %s: bad file"
-msgstr "git show %s: повреден файл"
+msgid "Squash commit -- not updating HEAD\n"
+msgstr "Вкарано подаване — указателят „HEAD“ няма да бъде обновен\n"
 
-#: builtin/log.c:525 builtin/log.c:619
+#: builtin/merge.c:447
 #, c-format
-msgid "Could not read object %s"
-msgstr "Обектът не може да бъде прочетен: %s"
+msgid "No merge message -- not updating HEAD\n"
+msgstr ""
+"Липсва съобщение при подаване — указателят „HEAD“ няма да бъде обновен\n"
 
-#: builtin/log.c:643
+#: builtin/merge.c:498
 #, c-format
-msgid "Unknown type: %d"
-msgstr "Неизвестен вид: %d"
+msgid "'%s' does not point to a commit"
+msgstr "„%s“ не сочи към подаване"
 
-#: builtin/log.c:764
-msgid "format.headers without value"
-msgstr "не е зададена стойност на „format.headers“"
+#: builtin/merge.c:585
+#, c-format
+msgid "Bad branch.%s.mergeoptions string: %s"
+msgstr "Неправилен низ за настройката „branch.%s.mergeoptions“: „%s“"
 
-#: builtin/log.c:865
-msgid "name of output directory is too long"
-msgstr "прекалено дълго име на директорията за изходната информация"
+#: builtin/merge.c:705
+msgid "Not handling anything other than two heads merge."
+msgstr "Поддържа се само сливане на точно две истории."
 
-#: builtin/log.c:881
+#: builtin/merge.c:719
 #, c-format
-msgid "Cannot open patch file %s"
-msgstr "Файлът-кръпка „%s“ не може да бъде отворен"
-
-#: builtin/log.c:898
-msgid "Need exactly one range."
-msgstr "Трябва да зададете точно един диапазон."
+msgid "Unknown option for merge-recursive: -X%s"
+msgstr "Непозната опция за рекурсивното сливане „merge-recursive“: „-X%s“"
 
-#: builtin/log.c:908
-msgid "Not a range."
-msgstr "Не е диапазон."
+#: builtin/merge.c:734
+#, c-format
+msgid "unable to write %s"
+msgstr "„%s“ не може да бъде записан"
 
-#: builtin/log.c:1014
-msgid "Cover letter needs email format"
-msgstr "Придружаващото писмо трябва да е форматирано като е-писмо"
+#: builtin/merge.c:786
+#, c-format
+msgid "Could not read from '%s'"
+msgstr "От „%s“ не може да се чете"
 
-#: builtin/log.c:1095
+#: builtin/merge.c:795
 #, c-format
-msgid "insane in-reply-to: %s"
-msgstr "неправилен формат на заглавната част за отговор „in-reply-to“: %s"
+msgid "Not committing merge; use 'git commit' to complete the merge.\n"
+msgstr ""
+"Сливането няма да бъде подадено.  За завършването му и подаването му "
+"използвайте командата „git commit“.\n"
 
-#: builtin/log.c:1122
-msgid "git format-patch [<options>] [<since> | <revision-range>]"
-msgstr "git format-patch [ОПЦИЯ…] [ОТ | ДИАПАЗОН_НА_ВЕРСИИТЕ]"
+#: builtin/merge.c:801
+msgid ""
+"Please enter a commit message to explain why this merge is necessary,\n"
+"especially if it merges an updated upstream into a topic branch.\n"
+"\n"
+msgstr ""
+"В съобщението при подаване добавете информация за причината за\n"
+"сливането, особено ако сливате обновен отдалечен клон в тематичен клон.\n"
 
-#: builtin/log.c:1172
-msgid "Two output directories?"
-msgstr "Можете да укажете максимум една директория за изход."
+#: builtin/merge.c:806
+msgid "An empty message aborts the commit.\n"
+msgstr "Празно съобщение предотвратява подаването.\n"
 
-#: builtin/log.c:1279 builtin/log.c:1932 builtin/log.c:1934 builtin/log.c:1946
+#: builtin/merge.c:809
 #, c-format
-msgid "Unknown commit %s"
-msgstr "Непознато подаване „%s“"
+msgid ""
+"Lines starting with '%c' will be ignored, and an empty message aborts\n"
+"the commit.\n"
+msgstr ""
+"Редовете, които започват с „%c“, ще бъдат пропуснати, а празно\n"
+"съобщение преустановява подаването.\n"
 
-#: builtin/log.c:1289 builtin/notes.c:887 builtin/tag.c:523
-#, c-format
-msgid "Failed to resolve '%s' as a valid ref."
-msgstr "Не може да се открие към какво сочи „%s“."
+#: builtin/merge.c:862
+msgid "Empty commit message."
+msgstr "Празно съобщение при подаване."
 
-#: builtin/log.c:1294
-msgid "Could not find exact merge base."
-msgstr "Точната база за сливане не може да се открие."
+#: builtin/merge.c:877
+#, c-format
+msgid "Wonderful.\n"
+msgstr "Първият етап на сливането завърши.\n"
 
-#: builtin/log.c:1298
-msgid ""
-"Failed to get upstream, if you want to record base commit automatically,\n"
-"please use git branch --set-upstream-to to track a remote branch.\n"
-"Or you could specify base commit by --base=<base-commit-id> manually."
+#: builtin/merge.c:938
+#, c-format
+msgid "Automatic merge failed; fix conflicts and then commit the result.\n"
 msgstr ""
-"Следеният клон не може да бъде установен.  Ако искате ръчно да го\n"
-"зададете, използвайте „git branch --set-upstream-to“.\n"
-"Можете ръчно да зададете базово подаване чрез „--base=<base-commit-id>“."
-
-#: builtin/log.c:1318
-msgid "Failed to find exact merge base"
-msgstr "Точната база при сливане не може да бъде открита"
+"Неуспешно автоматично сливане — коригирайте конфликтите и подайте "
+"резултата.\n"
 
-#: builtin/log.c:1329
-msgid "base commit should be the ancestor of revision list"
-msgstr "базовото подаване трябва да е предшественикът на списъка с версиите"
+#: builtin/merge.c:977
+msgid "No current branch."
+msgstr "Няма текущ клон."
 
-#: builtin/log.c:1333
-msgid "base commit shouldn't be in revision list"
-msgstr "базовото подаване не може да е в списъка с версиите"
+#: builtin/merge.c:979
+msgid "No remote for the current branch."
+msgstr "Текущият клон не следи никой."
 
-#: builtin/log.c:1382
-msgid "cannot get patch id"
-msgstr "идентификаторът на кръпката не може да бъде получен"
+#: builtin/merge.c:981
+msgid "No default upstream defined for the current branch."
+msgstr "Текущият клон не следи никой клон."
 
-#: builtin/log.c:1441
-msgid "use [PATCH n/m] even with a single patch"
-msgstr "номерация „[PATCH n/m]“ дори и при единствена кръпка"
+#: builtin/merge.c:986
+#, c-format
+msgid "No remote-tracking branch for %s from %s"
+msgstr "Никой клон не следи клона „%s“ от хранилището „%s“"
 
-#: builtin/log.c:1444
-msgid "use [PATCH] even with multiple patches"
-msgstr "номерация „[PATCH]“ дори и при множество кръпки"
+#: builtin/merge.c:1043
+#, c-format
+msgid "Bad value '%s' in environment '%s'"
+msgstr "Неправилна стойност „%s“ в средата „%s“"
 
-#: builtin/log.c:1448
-msgid "print patches to standard out"
-msgstr "извеждане на кръпките на стандартния изход"
+#: builtin/merge.c:1146
+#, c-format
+msgid "not something we can merge in %s: %s"
+msgstr "не може да се слее в „%s“: %s"
 
-#: builtin/log.c:1450
-msgid "generate a cover letter"
-msgstr "създаване на придружаващо писмо"
+#: builtin/merge.c:1180
+msgid "not something we can merge"
+msgstr "не може да се слее"
 
-#: builtin/log.c:1452
-msgid "use simple number sequence for output file names"
-msgstr "проста числова последователност за имената на файловете-кръпки"
+#: builtin/merge.c:1283
+msgid "--abort expects no arguments"
+msgstr "опцията „--abort“ не приема аргументи"
 
-#: builtin/log.c:1453
-msgid "sfx"
-msgstr "ЗНАЦИ"
+#: builtin/merge.c:1287
+msgid "There is no merge to abort (MERGE_HEAD missing)."
+msgstr ""
+"Не може да преустановите сливане, защото в момента не се извършва такова "
+"(липсва указател „MERGE_HEAD“)."
 
-#: builtin/log.c:1454
-msgid "use <sfx> instead of '.patch'"
-msgstr "използване на тези ЗНАЦИ за суфикс вместо „.patch“"
+#: builtin/merge.c:1296
+msgid "--quit expects no arguments"
+msgstr "опцията „--quit“ не приема аргументи"
 
-#: builtin/log.c:1456
-msgid "start numbering patches at <n> instead of 1"
-msgstr "номерирането на кръпките да започва от този БРОЙ, а не с 1"
+#: builtin/merge.c:1309
+msgid "--continue expects no arguments"
+msgstr "опцията „--continue“ не приема аргументи"
 
-#: builtin/log.c:1458
-msgid "mark the series as Nth re-roll"
-msgstr "отбелязване, че това е N-тата поредна редакция на поредицата от кръпки"
+#: builtin/merge.c:1313
+msgid "There is no merge in progress (MERGE_HEAD missing)."
+msgstr "В момента не се извършва сливане (липсва указател „MERGE_HEAD“)."
 
-#: builtin/log.c:1460
-msgid "Use [RFC PATCH] instead of [PATCH]"
-msgstr "Използване на „[RFC PATCH]“ вместо „[PATCH]“"
+#: builtin/merge.c:1329
+msgid ""
+"You have not concluded your merge (MERGE_HEAD exists).\n"
+"Please, commit your changes before you merge."
+msgstr ""
+"Не сте завършили сливане.  (Указателят „MERGE_HEAD“ съществува).\n"
+"Подайте промените си, преди да започнете ново сливане."
 
-#: builtin/log.c:1463
-msgid "Use [<prefix>] instead of [PATCH]"
-msgstr "Използване на този „[ПРЕФИКС]“ вместо „[PATCH]“"
+#: builtin/merge.c:1336
+msgid ""
+"You have not concluded your cherry-pick (CHERRY_PICK_HEAD exists).\n"
+"Please, commit your changes before you merge."
+msgstr ""
+"Не сте завършили отбиране на подаване (указателят „CHERRY_PICK_HEAD“\n"
+"съществува).  Подайте промените си, преди да започнете ново сливане."
 
-#: builtin/log.c:1466
-msgid "store resulting files in <dir>"
-msgstr "запазване на изходните файлове в тази ДИРЕКТОРИЯ"
+#: builtin/merge.c:1339
+msgid "You have not concluded your cherry-pick (CHERRY_PICK_HEAD exists)."
+msgstr ""
+"Не сте завършили отбиране на подаване (указателят „CHERRY_PICK_HEAD“\n"
+"съществува)."
 
-#: builtin/log.c:1469
-msgid "don't strip/add [PATCH]"
-msgstr "без добавяне/махане на префикса „[PATCH]“"
+#: builtin/merge.c:1353
+msgid "You cannot combine --squash with --no-ff."
+msgstr "Опцията „--squash“ е несъвместима с „--no-ff“."
 
-#: builtin/log.c:1472
-msgid "don't output binary diffs"
-msgstr "без извеждане на разлики между двоични файлове"
+#: builtin/merge.c:1355
+msgid "You cannot combine --squash with --commit."
+msgstr "Опцията „--squash“ е несъвместима с „--commit“."
 
-#: builtin/log.c:1474
-msgid "output all-zero hash in From header"
-msgstr "в заглавната част „From:“ (от) хешът да е само от нули"
+#: builtin/merge.c:1371
+msgid "No commit specified and merge.defaultToUpstream not set."
+msgstr ""
+"Не е указано подаване и настройката „merge.defaultToUpstream“ не е зададена."
 
-#: builtin/log.c:1476
-msgid "don't include a patch matching a commit upstream"
-msgstr "да не се включват кръпки, които присъстват в следения клон"
+#: builtin/merge.c:1388
+msgid "Squash commit into empty head not supported yet"
+msgstr "Вкарване на подаване във връх без история все още не се поддържа"
 
-#: builtin/log.c:1478
-msgid "show patch format instead of default (patch + stat)"
+#: builtin/merge.c:1390
+msgid "Non-fast-forward commit does not make sense into an empty head"
 msgstr ""
-"извеждане във формат за кръпки, а на в стандартния (кръпка и статистика)"
+"Понеже върхът е без история, всички сливания са превъртания, не може да се "
+"извърши същинско сливане изисквано от опцията „--no-ff“"
 
-#: builtin/log.c:1480
-msgid "Messaging"
-msgstr "Опции при изпращане"
+#: builtin/merge.c:1395
+#, c-format
+msgid "%s - not something we can merge"
+msgstr "„%s“ — не е нещо, което може да се слее"
 
-#: builtin/log.c:1481
-msgid "header"
-msgstr "ЗАГЛАВНА_ЧАСТ"
+#: builtin/merge.c:1397
+msgid "Can merge only exactly one commit into empty head"
+msgstr "Можете да слеете точно едно подаване във връх без история"
 
-#: builtin/log.c:1482
-msgid "add email header"
-msgstr "добавяне на тази ЗАГЛАВНА_ЧАСТ"
+#: builtin/merge.c:1476
+msgid "refusing to merge unrelated histories"
+msgstr "независими истории не може да се слеят"
 
-#: builtin/log.c:1483 builtin/log.c:1485
-msgid "email"
-msgstr "Е-ПОЩА"
+#: builtin/merge.c:1485
+msgid "Already up to date."
+msgstr "Вече е обновено."
 
-#: builtin/log.c:1483
-msgid "add To: header"
-msgstr "добавяне на заглавна част „To:“ (до)"
+#: builtin/merge.c:1495
+#, c-format
+msgid "Updating %s..%s\n"
+msgstr "Обновяване „%s..%s“\n"
 
-#: builtin/log.c:1485
-msgid "add Cc: header"
-msgstr "добавяне на заглавна част „Cc:“ (и до)"
+#: builtin/merge.c:1537
+#, c-format
+msgid "Trying really trivial in-index merge...\n"
+msgstr "Проба със сливане в рамките на индекса…\n"
 
-#: builtin/log.c:1487
-msgid "ident"
-msgstr "ИДЕНТИЧНОСТ"
+#: builtin/merge.c:1544
+#, c-format
+msgid "Nope.\n"
+msgstr "Неуспешно сливане.\n"
 
-#: builtin/log.c:1488
-msgid "set From address to <ident> (or committer ident if absent)"
-msgstr ""
-"задаване на адреса в заглавната част „From“ (от) да е тази ИДЕНТИЧНОСТ.  Ако "
-"не е зададена такава, се взима адреса на подаващия"
+#: builtin/merge.c:1569
+msgid "Already up to date. Yeeah!"
+msgstr "Вече е обновено!"
 
-#: builtin/log.c:1490
-msgid "message-id"
-msgstr "ИДЕНТИФИКАТОР_НА_СЪОБЩЕНИЕ"
+#: builtin/merge.c:1575
+msgid "Not possible to fast-forward, aborting."
+msgstr "Не може да се извърши превъртане, преустановяване на действието."
 
-#: builtin/log.c:1491
-msgid "make first mail a reply to <message-id>"
-msgstr ""
-"първото съобщение да е в отговор на е-писмото с този "
-"ИДЕНТИФИКАТОР_НА_СЪОБЩЕНИЕ"
+#: builtin/merge.c:1598 builtin/merge.c:1663
+#, c-format
+msgid "Rewinding the tree to pristine...\n"
+msgstr "Привеждане на дървото към първоначалното…\n"
 
-#: builtin/log.c:1492 builtin/log.c:1495
-msgid "boundary"
-msgstr "граница"
+#: builtin/merge.c:1602
+#, c-format
+msgid "Trying merge strategy %s...\n"
+msgstr "Пробване със стратегията за сливане „%s“…\n"
 
-#: builtin/log.c:1493
-msgid "attach the patch"
-msgstr "прикрепяне на кръпката"
+#: builtin/merge.c:1654
+#, c-format
+msgid "No merge strategy handled the merge.\n"
+msgstr "Никоя стратегия за сливане не може да извърши сливането.\n"
 
-#: builtin/log.c:1496
-msgid "inline the patch"
-msgstr "включване на кръпката в текста на писмата"
+#: builtin/merge.c:1656
+#, c-format
+msgid "Merge with strategy %s failed.\n"
+msgstr "Неуспешно сливане със стратегия „%s“.\n"
 
-#: builtin/log.c:1500
-msgid "enable message threading, styles: shallow, deep"
+#: builtin/merge.c:1665
+#, c-format
+msgid "Using the %s to prepare resolving by hand.\n"
 msgstr ""
-"използване на нишки за съобщенията.  СТИЛът е „shallow“ (плитък) или "
-"„deep“ (дълбок)"
-
-#: builtin/log.c:1502
-msgid "signature"
-msgstr "подпис"
+"Ползва се стратегията „%s“, която ще подготви дървото за коригиране на "
+"ръка.\n"
 
-#: builtin/log.c:1503
-msgid "add a signature"
-msgstr "добавяне на поле за подпис"
+#: builtin/merge.c:1677
+#, c-format
+msgid "Automatic merge went well; stopped before committing as requested\n"
+msgstr ""
+"Автоматичното сливане завърши успешно.  Самото подаване не е извършено, "
+"защото бе зададена опцията „--no-commit“.\n"
 
-#: builtin/log.c:1504
-msgid "base-commit"
-msgstr "БАЗОВО_ПОДАВАНЕ"
+#: builtin/merge-base.c:32
+msgid "git merge-base [-a | --all] <commit> <commit>..."
+msgstr "git merge-base [-a | --all] ПОДАВАНЕ ПОДАВАНЕ…"
 
-#: builtin/log.c:1505
-msgid "add prerequisite tree info to the patch series"
-msgstr "добавяне на необходимото БАЗово дърво към поредицата от кръпки"
+#: builtin/merge-base.c:33
+msgid "git merge-base [-a | --all] --octopus <commit>..."
+msgstr "git merge-base [-a | --all] --octopus ПОДАВАНЕ…"
 
-#: builtin/log.c:1507
-msgid "add a signature from a file"
-msgstr "добавяне на подпис от файл"
+#: builtin/merge-base.c:34
+msgid "git merge-base --independent <commit>..."
+msgstr "git merge-base --independent ПОДАВАНЕ…"
 
-#: builtin/log.c:1508
-msgid "don't print the patch filenames"
-msgstr "без извеждане на имената на кръпките"
+#: builtin/merge-base.c:35
+msgid "git merge-base --is-ancestor <commit> <commit>"
+msgstr "git merge-base --is-ancestor ПОДАВАНЕ_1 ПОДАВАНЕ_2"
 
-#: builtin/log.c:1510
-msgid "show progress while generating patches"
-msgstr "извеждане на напредъка във фазата на създаване на кръпките"
+#: builtin/merge-base.c:36
+msgid "git merge-base --fork-point <ref> [<commit>]"
+msgstr "git merge-base --fork-point УКАЗАТЕЛ [ПОДАВАНЕ]"
 
-#: builtin/log.c:1585
-#, c-format
-msgid "invalid ident line: %s"
-msgstr "грешна идентичност: %s"
+#: builtin/merge-base.c:153
+msgid "output all common ancestors"
+msgstr "извеждане на всички общи предшественици"
 
-#: builtin/log.c:1600
-msgid "-n and -k are mutually exclusive."
-msgstr "опциите „-n“ и „-k“ са несъвместими."
-
-#: builtin/log.c:1602
-msgid "--subject-prefix/--rfc and -k are mutually exclusive."
-msgstr "опциите „--subject-prefix“/„-rfc“ и „-k“ са несъвместими."
+#: builtin/merge-base.c:155
+msgid "find ancestors for a single n-way merge"
+msgstr ""
+"откриване на предшествениците за еднократно сливане на множество истории"
 
-#: builtin/log.c:1610
-msgid "--name-only does not make sense"
-msgstr "опцията „--name-only“ е несъвместима с генерирането на кръпки"
+#: builtin/merge-base.c:157
+msgid "list revs not reachable from others"
+msgstr "извеждане на недостижимите от другите указатели"
 
-#: builtin/log.c:1612
-msgid "--name-status does not make sense"
-msgstr "опцията „--name-status“ е несъвместима с генерирането на кръпки"
+#: builtin/merge-base.c:159
+msgid "is the first one ancestor of the other?"
+msgstr "ПОДАВАНЕ_1 предшественик ли е на ПОДАВАНЕ_2?"
 
-#: builtin/log.c:1614
-msgid "--check does not make sense"
-msgstr "опцията „--check“ е несъвместима с генерирането на кръпки"
+#: builtin/merge-base.c:161
+msgid "find where <commit> forked from reflog of <ref>"
+msgstr "откриване къде ПОДАВАНЕто се е отклонило от историята на УКАЗАТЕЛя"
 
-#: builtin/log.c:1646
-msgid "standard output, or directory, which one?"
+#: builtin/merge-file.c:9
+msgid ""
+"git merge-file [<options>] [-L <name1> [-L <orig> [-L <name2>]]] <file1> "
+"<orig-file> <file2>"
 msgstr ""
-"изходът може да или стандартният, или да е в директория, но не и двете."
+"git merge-file [ОПЦИЯ…] [-L ИМЕ_1 [-L ОРИГИНАЛ [-L ИМЕ_2]]] ФАЙЛ_1 ОРИГ_ФАЙЛ "
+"ФАЙЛ_2"
 
-#: builtin/log.c:1648
-#, c-format
-msgid "Could not create directory '%s'"
-msgstr "Директорията „%s“ не може да бъде създадена"
+#: builtin/merge-file.c:35
+msgid "send results to standard output"
+msgstr "извеждане на резултатите на стандартния изход"
 
-#: builtin/log.c:1741
-#, c-format
-msgid "unable to read signature file '%s'"
-msgstr "файлът „%s“ с подпис не може да бъде прочетен"
+#: builtin/merge-file.c:36
+msgid "use a diff3 based merge"
+msgstr "сливане на базата на „diff3“"
 
-#: builtin/log.c:1773
-msgid "Generating patches"
-msgstr "Създаване на кръпки"
+#: builtin/merge-file.c:37
+msgid "for conflicts, use our version"
+msgstr "при конфликти да се ползва локалната версия"
 
-#: builtin/log.c:1817
-msgid "Failed to create output files"
-msgstr "Изходните файлове не могат да бъдат създадени"
+#: builtin/merge-file.c:39
+msgid "for conflicts, use their version"
+msgstr "при конфликти да се ползва чуждата версия"
 
-#: builtin/log.c:1867
-msgid "git cherry [-v] [<upstream> [<head> [<limit>]]]"
-msgstr "git cherry [-v] [ОТДАЛЕЧЕН_КЛОН [ВРЪХ [ПРЕДЕЛ]]]"
+#: builtin/merge-file.c:41
+msgid "for conflicts, use a union version"
+msgstr "при конфликти да се ползва обединена версия"
 
-#: builtin/log.c:1921
-#, c-format
-msgid ""
-"Could not find a tracked remote branch, please specify <upstream> manually.\n"
-msgstr ""
-"Следеният отдалечен клон не бе открит, затова изрично задайте "
-"ОТДАЛЕЧЕН_КЛОН.\n"
+#: builtin/merge-file.c:44
+msgid "for conflicts, use this marker size"
+msgstr "при конфликти да се ползва маркер с такъв БРОЙ знаци"
 
-#: builtin/ls-files.c:468
-msgid "git ls-files [<options>] [<file>...]"
-msgstr "git ls-files [ОПЦИЯ…] [ФАЙЛ…]"
+#: builtin/merge-file.c:45
+msgid "do not warn about conflicts"
+msgstr "без предупреждения при конфликти"
 
-#: builtin/ls-files.c:517
-msgid "identify the file status with tags"
-msgstr "извеждане на състоянието на файловете с еднобуквени флагове"
+#: builtin/merge-file.c:47
+msgid "set labels for file1/orig-file/file2"
+msgstr "задаване на етикети за ФАЙЛ_1/ОРИГИНАЛ/ФАЙЛ_2"
 
-#: builtin/ls-files.c:519
-msgid "use lowercase letters for 'assume unchanged' files"
-msgstr "малки букви за файловете, които да се счетат за непроменени"
+#: builtin/merge-recursive.c:47
+#, c-format
+msgid "unknown option %s"
+msgstr "непозната опция: „%s“"
 
-#: builtin/ls-files.c:521
-msgid "use lowercase letters for 'fsmonitor clean' files"
-msgstr "малки букви за файловете за командата „fsmonitor clean“"
+#: builtin/merge-recursive.c:53
+#, c-format
+msgid "could not parse object '%s'"
+msgstr "неуспешен анализ на обекта „%s“"
 
-#: builtin/ls-files.c:523
-msgid "show cached files in the output (default)"
-msgstr "извеждане на кешираните файлове (стандартно)"
+#: builtin/merge-recursive.c:57
+#, c-format
+msgid "cannot handle more than %d base. Ignoring %s."
+msgid_plural "cannot handle more than %d bases. Ignoring %s."
+msgstr[0] "не се поддържа повече от %d база.  „%s“ се прескача."
+msgstr[1] "не се поддържат повече от %d бази.  „%s“ се прескача."
 
-#: builtin/ls-files.c:525
-msgid "show deleted files in the output"
-msgstr "извеждане на изтритите файлове"
+#: builtin/merge-recursive.c:65
+msgid "not handling anything other than two heads merge."
+msgstr "поддържа се само сливане на точно две истории."
 
-#: builtin/ls-files.c:527
-msgid "show modified files in the output"
-msgstr "извеждане на променените файлове"
+#: builtin/merge-recursive.c:74 builtin/merge-recursive.c:76
+#, c-format
+msgid "could not resolve ref '%s'"
+msgstr "указателят „%s“ не може да бъде изтрит"
 
-#: builtin/ls-files.c:529
-msgid "show other files in the output"
-msgstr "извеждане на другите файлове"
+#: builtin/merge-recursive.c:82
+#, c-format
+msgid "Merging %s with %s\n"
+msgstr "Сливане на „%s“ с „%s“\n"
 
-#: builtin/ls-files.c:531
-msgid "show ignored files in the output"
-msgstr "извеждане на игнорираните файлове"
+#: builtin/mktree.c:66
+msgid "git mktree [-z] [--missing] [--batch]"
+msgstr "git mktree [-z] [--missing] [--batch]"
 
-#: builtin/ls-files.c:534
-msgid "show staged contents' object name in the output"
-msgstr "извеждане на името на обекта за съдържанието на индекса"
+#: builtin/mktree.c:154
+msgid "input is NUL terminated"
+msgstr "входните записи са разделени с нулевия знак „NUL“"
 
-#: builtin/ls-files.c:536
-msgid "show files on the filesystem that need to be removed"
-msgstr "извеждане на файловете, които трябва да бъдат изтрити"
+#: builtin/mktree.c:155 builtin/write-tree.c:26
+msgid "allow missing objects"
+msgstr "разрешаване на липсващи обекти"
 
-#: builtin/ls-files.c:538
-msgid "show 'other' directories' names only"
-msgstr "извеждане само на името на другите (неследените) директории"
+#: builtin/mktree.c:156
+msgid "allow creation of more than one tree"
+msgstr "разрешаване на създаването на повече от едно дърво"
 
-#: builtin/ls-files.c:540
-msgid "show line endings of files"
-msgstr "извеждане на знаците за край на ред във файловете"
+#: builtin/multi-pack-index.c:9
+msgid ""
+"git multi-pack-index [<options>] (write|verify|expire|repack --batch-"
+"size=<size>)"
+msgstr ""
+"git multi-pack-index [ОПЦИЯ…] (write|verify|expire|repack --batch-"
+"size=РАЗМЕР)"
 
-#: builtin/ls-files.c:542
-msgid "don't show empty directories"
-msgstr "без извеждане на празните директории"
+#: builtin/multi-pack-index.c:26
+msgid "object directory containing set of packfile and pack-index pairs"
+msgstr ""
+"ДИРекторията_с_ОБЕКТи съдържа множество двойки пакетни файлове със "
+"съответния им индекс"
 
-#: builtin/ls-files.c:545
-msgid "show unmerged files in the output"
-msgstr "извеждане на неслетите файлове"
+#: builtin/multi-pack-index.c:29
+msgid ""
+"during repack, collect pack-files of smaller size into a batch that is "
+"larger than this size"
+msgstr ""
+"при препакетиране пакетните файлове, които са с по-малък от този размер, да "
+"се обединяват в пакети с по-голям от този размер"
 
-#: builtin/ls-files.c:547
-msgid "show resolve-undo information"
-msgstr "извеждане на информацията за отмяна на разрешените подавания"
+#: builtin/multi-pack-index.c:50 builtin/prune-packed.c:67
+msgid "too many arguments"
+msgstr "прекалено много аргументи"
 
-#: builtin/ls-files.c:549
-msgid "skip files matching pattern"
-msgstr "прескачане на файловете напасващи ШАБЛОНа"
+#: builtin/multi-pack-index.c:60
+msgid "--batch-size option is only for 'repack' subcommand"
+msgstr "опцията „--batch-size“ изисква подкомандата „repack“"
 
-#: builtin/ls-files.c:552
-msgid "exclude patterns are read from <file>"
-msgstr "шаблоните за игнориране да се прочетат от този ФАЙЛ"
+#: builtin/multi-pack-index.c:69
+#, c-format
+msgid "unrecognized subcommand: %s"
+msgstr "непозната подкоманда: %s"
 
-#: builtin/ls-files.c:555
-msgid "read additional per-directory exclude patterns in <file>"
+#: builtin/mv.c:18
+msgid "git mv [<options>] <source>... <destination>"
+msgstr "git mv [ОПЦИЯ…] ОБЕКТ… ЦЕЛ"
+
+#: builtin/mv.c:83
+#, c-format
+msgid "Directory %s is in index and no submodule?"
+msgstr "Директорията „%s“ е в индекса, но не е подмодул"
+
+#: builtin/mv.c:85
+msgid "Please stage your changes to .gitmodules or stash them to proceed"
 msgstr ""
-"изчитане на допълнителните шаблони за игнориране по директория от този ФАЙЛ"
+"За да продължите, или вкарайте промените по файла „.gitmodules“ в индекса,\n"
+"или ги скатайте"
 
-#: builtin/ls-files.c:557
-msgid "add the standard git exclusions"
-msgstr "добавяне на стандартно игнорираните от Git файлове"
+#: builtin/mv.c:103
+#, c-format
+msgid "%.*s is in index"
+msgstr "„%.*s“ вече е в индекса"
 
-#: builtin/ls-files.c:560
-msgid "make the output relative to the project top directory"
-msgstr "пътищата да са относителни спрямо основната директория на проекта"
+#: builtin/mv.c:125
+msgid "force move/rename even if target exists"
+msgstr "принудително преместване/преименуване дори целта да съществува"
 
-#: builtin/ls-files.c:563
-msgid "recurse through submodules"
-msgstr "рекурсивно обхождане подмодулите"
+#: builtin/mv.c:127
+msgid "skip move/rename errors"
+msgstr "прескачане на грешките при преместване/преименуване"
 
-#: builtin/ls-files.c:565
-msgid "if any <file> is not in the index, treat this as an error"
-msgstr "грешка, ако някой от тези ФАЙЛове не е в индекса"
+#: builtin/mv.c:169
+#, c-format
+msgid "destination '%s' is not a directory"
+msgstr "целта „%s“ съществува и не е директория"
 
-#: builtin/ls-files.c:566
-msgid "tree-ish"
-msgstr "УКАЗАТЕЛ_КЪМ_ДЪРВО"
+#: builtin/mv.c:180
+#, c-format
+msgid "Checking rename of '%s' to '%s'\n"
+msgstr "Проверка на преименуването на обект от „%s“ на „%s“\n"
 
-#: builtin/ls-files.c:567
-msgid "pretend that paths removed since <tree-ish> are still present"
-msgstr ""
-"считане, че пътищата изтрити след УКАЗАТЕЛя_КЪМ_ДЪРВО все още съществуват"
+#: builtin/mv.c:184
+msgid "bad source"
+msgstr "неправилен обект"
 
-#: builtin/ls-files.c:569
-msgid "show debugging data"
-msgstr "извеждане на информацията за изчистване на грешки"
+#: builtin/mv.c:187
+msgid "can not move directory into itself"
+msgstr "директория не може да се премести в себе си"
 
-#: builtin/ls-remote.c:9
-msgid ""
-"git ls-remote [--heads] [--tags] [--refs] [--upload-pack=<exec>]\n"
-"                     [-q | --quiet] [--exit-code] [--get-url]\n"
-"                     [--symref] [<repository> [<refs>...]]"
-msgstr ""
-"git ls-remote [--heads] [--tags] [--refs] [--upload-pack=КОМАНДА]\n"
-"                     [-q | --quiet] [--exit-code] [--get-url]\n"
-"                     [--symref] [ХРАНИЛИЩЕ [УКАЗАТЕЛ…]]"
+#: builtin/mv.c:190
+msgid "cannot move directory over file"
+msgstr "директория не може да се премести върху файл"
 
-#: builtin/ls-remote.c:59
-msgid "do not print remote URL"
-msgstr "без извеждане на адресите на отдалечените хранилища"
+#: builtin/mv.c:199
+msgid "source directory is empty"
+msgstr "първоначалната директория е празна"
 
-#: builtin/ls-remote.c:60 builtin/ls-remote.c:62
-msgid "exec"
-msgstr "КОМАНДА"
+#: builtin/mv.c:224
+msgid "not under version control"
+msgstr "не е под контрола на Git"
 
-#: builtin/ls-remote.c:61 builtin/ls-remote.c:63
-msgid "path of git-upload-pack on the remote host"
-msgstr "път към командата „git-upload-pack“ на отдалечената машина"
+#: builtin/mv.c:227
+msgid "destination exists"
+msgstr "целта съществува"
 
-#: builtin/ls-remote.c:65
-msgid "limit to tags"
-msgstr "само етикетите"
+#: builtin/mv.c:235
+#, c-format
+msgid "overwriting '%s'"
+msgstr "презаписване на „%s“"
 
-#: builtin/ls-remote.c:66
-msgid "limit to heads"
-msgstr "само върховете"
+#: builtin/mv.c:238
+msgid "Cannot overwrite"
+msgstr "Презаписването е невъзможно"
 
-#: builtin/ls-remote.c:67
-msgid "do not show peeled tags"
-msgstr "без извеждане на проследените етикети"
+#: builtin/mv.c:241
+msgid "multiple sources for the same target"
+msgstr "множество източници за една цел"
 
-#: builtin/ls-remote.c:69
-msgid "take url.<base>.insteadOf into account"
-msgstr "взимане предвид на „url.БАЗА.insteadOf“"
+#: builtin/mv.c:243
+msgid "destination directory does not exist"
+msgstr "целевата директория не съществува"
 
-#: builtin/ls-remote.c:73
-msgid "exit with exit code 2 if no matching refs are found"
-msgstr "изход с код 2, ако не се открият съвпадащи указатели"
+#: builtin/mv.c:250
+#, c-format
+msgid "%s, source=%s, destination=%s"
+msgstr "%s, обект: „%s“, цел: „%s“"
 
-#: builtin/ls-remote.c:76
-msgid "show underlying ref in addition to the object pointed by it"
-msgstr "извеждане на указателя заедно с обекта сочен от него"
+#: builtin/mv.c:271
+#, c-format
+msgid "Renaming %s to %s\n"
+msgstr "Преименуване на „%s“ на „%s“\n"
 
-#: builtin/ls-tree.c:29
-msgid "git ls-tree [<options>] <tree-ish> [<path>...]"
-msgstr "git ls-tree [ОПЦИЯ…] УКАЗАТЕЛ_КЪМ_ДЪРВО [ПЪТ…]"
+#: builtin/mv.c:277 builtin/remote.c:716 builtin/repack.c:518
+#, c-format
+msgid "renaming '%s' failed"
+msgstr "неуспешно преименуване на „%s“"
 
-#: builtin/ls-tree.c:127
-msgid "only show trees"
-msgstr "извеждане само на дървета"
+#: builtin/name-rev.c:403
+msgid "git name-rev [<options>] <commit>..."
+msgstr "git name-rev [ОПЦИЯ…] ПОДАВАНЕ…"
 
-#: builtin/ls-tree.c:129
-msgid "recurse into subtrees"
-msgstr "рекурсивно обхождане поддърветата"
+#: builtin/name-rev.c:404
+msgid "git name-rev [<options>] --all"
+msgstr "git name-rev [ОПЦИЯ…] --all"
 
-#: builtin/ls-tree.c:131
-msgid "show trees when recursing"
-msgstr "извеждане на дърветата при рекурсивното обхождане"
+#: builtin/name-rev.c:405
+msgid "git name-rev [<options>] --stdin"
+msgstr "git name-rev [ОПЦИЯ…] --stdin"
 
-#: builtin/ls-tree.c:134
-msgid "terminate entries with NUL byte"
-msgstr "разделяне на обектите с нулевия знак „NUL“"
+#: builtin/name-rev.c:462
+msgid "print only names (no SHA-1)"
+msgstr "извеждане само на имената (без сумите по SHA1)"
 
-#: builtin/ls-tree.c:135
-msgid "include object size"
-msgstr "извеждане на размера на обекта"
+#: builtin/name-rev.c:463
+msgid "only use tags to name the commits"
+msgstr "използване само на етикетите за именуване на подаванията"
 
-#: builtin/ls-tree.c:137 builtin/ls-tree.c:139
-msgid "list only filenames"
-msgstr "извеждане само имената на файловете"
+#: builtin/name-rev.c:465
+msgid "only use refs matching <pattern>"
+msgstr "използване само на указателите напасващи на ШАБЛОНа"
 
-#: builtin/ls-tree.c:142
-msgid "use full path names"
-msgstr "използване на пълните имена на пътищата"
+#: builtin/name-rev.c:467
+msgid "ignore refs matching <pattern>"
+msgstr "игнориране на указателите напасващи на ШАБЛОНа"
 
-#: builtin/ls-tree.c:144
-msgid "list entire tree; not just current directory (implies --full-name)"
+#: builtin/name-rev.c:469
+msgid "list all commits reachable from all refs"
 msgstr ""
-"извеждане на цялото дърво, не само на текущата директория (включва опцията "
-"„--full-name“)"
+"извеждане на всички подавания, които могат да бъдат достигнати от всички "
+"указатели"
 
-#: builtin/mailsplit.c:241
-#, c-format
-msgid "empty mbox: '%s'"
-msgstr "празна пощенска кутия mbox: „%s“"
+#: builtin/name-rev.c:470
+msgid "read from stdin"
+msgstr "четене от стандартния вход"
 
-#: builtin/merge.c:51
-msgid "git merge [<options>] [<commit>...]"
-msgstr "git merge [ОПЦИЯ…] [ПОДАВАНЕ…]"
+#: builtin/name-rev.c:471
+msgid "allow to print `undefined` names (default)"
+msgstr "да се извеждат и недефинираните имена (стандартна стойност на опцията)"
 
-#: builtin/merge.c:52
-msgid "git merge --abort"
-msgstr "git merge --abort"
+#: builtin/name-rev.c:477
+msgid "dereference tags in the input (internal use)"
+msgstr "извеждане на идентификаторите на обекти-етикети (за вътрешни нужди)"
 
-#: builtin/merge.c:53
-msgid "git merge --continue"
-msgstr "git merge --continue"
+#: builtin/notes.c:28
+msgid "git notes [--ref <notes-ref>] [list [<object>]]"
+msgstr "git notes [--ref УКАЗАТЕЛ_ЗА_БЕЛЕЖКА] [list [ОБЕКТ]]"
 
-#: builtin/merge.c:110
-msgid "switch `m' requires a value"
-msgstr "опцията „-m“ изисква стойност"
+#: builtin/notes.c:29
+msgid ""
+"git notes [--ref <notes-ref>] add [-f] [--allow-empty] [-m <msg> | -F <file> "
+"| (-c | -C) <object>] [<object>]"
+msgstr ""
+"git notes [--ref УКАЗАТЕЛ_ЗА_БЕЛЕЖКА] add [-f] [--allow-empty] [-m СЪОБЩЕНИЕ "
+"| -F ФАЙЛ | (-c | -C) ОБЕКТ] [ОБЕКТ]"
 
-#: builtin/merge.c:147
-#, c-format
-msgid "Could not find merge strategy '%s'.\n"
-msgstr "Няма такава стратегия за сливане: „%s“.\n"
+#: builtin/notes.c:30
+msgid "git notes [--ref <notes-ref>] copy [-f] <from-object> <to-object>"
+msgstr ""
+"git notes [--ref УКАЗАТЕЛ_ЗА_БЕЛЕЖКА] copy [-f] ОБЕКТ_ИЗТОЧНИК ОБЕКТ_ЦЕЛ"
 
-#: builtin/merge.c:148
-#, c-format
-msgid "Available strategies are:"
-msgstr "Наличните стратегии са:"
+#: builtin/notes.c:31
+msgid ""
+"git notes [--ref <notes-ref>] append [--allow-empty] [-m <msg> | -F <file> | "
+"(-c | -C) <object>] [<object>]"
+msgstr ""
+"git notes [--ref УКАЗАТЕЛ_ЗА_БЕЛЕЖКА] append [--allow-empty] [-m СЪОБЩЕНИЕ | "
+"-F ФАЙЛ | (-c | -C) ОБЕКТ] [ОБЕКТ]"
 
-#: builtin/merge.c:153
-#, c-format
-msgid "Available custom strategies are:"
-msgstr "Допълнителните стратегии са:"
+#: builtin/notes.c:32
+msgid "git notes [--ref <notes-ref>] edit [--allow-empty] [<object>]"
+msgstr "git notes [--ref УКАЗАТЕЛ_ЗА_БЕЛЕЖКА] edit [--allow-empty] [ОБЕКТ]"
 
-#: builtin/merge.c:203 builtin/pull.c:142
-msgid "do not show a diffstat at the end of the merge"
-msgstr "без извеждане на статистиката след завършване на сливане"
+#: builtin/notes.c:33
+msgid "git notes [--ref <notes-ref>] show [<object>]"
+msgstr "git notes [--ref УКАЗАТЕЛ_ЗА_БЕЛЕЖКА] show [ОБЕКТ]"
 
-#: builtin/merge.c:206 builtin/pull.c:145
-msgid "show a diffstat at the end of the merge"
-msgstr "извеждане на статистиката след завършване на сливане"
+#: builtin/notes.c:34
+msgid ""
+"git notes [--ref <notes-ref>] merge [-v | -q] [-s <strategy>] <notes-ref>"
+msgstr ""
+"git notes [--ref УКАЗАТЕЛ_ЗА_БЕЛЕЖКА] merge [-v | -q] [-s СТРАТЕГИЯ] "
+"УКАЗАТЕЛ_ЗА_БЕЛЕЖКА"
 
-#: builtin/merge.c:207 builtin/pull.c:148
-msgid "(synonym to --stat)"
-msgstr "(синоним на „--stat“)"
+#: builtin/notes.c:35
+msgid "git notes merge --commit [-v | -q]"
+msgstr "git notes merge --commit [-v | -q]"
 
-#: builtin/merge.c:209 builtin/pull.c:151
-msgid "add (at most <n>) entries from shortlog to merge commit message"
-msgstr ""
-"добавяне (на максимум такъв БРОЙ) записи от съкратения журнал в съобщението "
-"за подаване"
+#: builtin/notes.c:36
+msgid "git notes merge --abort [-v | -q]"
+msgstr "git notes merge --abort [-v | -q]"
 
-#: builtin/merge.c:212 builtin/pull.c:157
-msgid "create a single commit instead of doing a merge"
-msgstr "създаване на едно подаване вместо извършване на сливане"
+#: builtin/notes.c:37
+msgid "git notes [--ref <notes-ref>] remove [<object>...]"
+msgstr "git notes [--ref УКАЗАТЕЛ_ЗА_БЕЛЕЖКА] remove [ОБЕКТ…]"
 
-#: builtin/merge.c:214 builtin/pull.c:160
-msgid "perform a commit if the merge succeeds (default)"
-msgstr "извършване на подаване при успешно сливане (стандартно действие)"
+#: builtin/notes.c:38
+msgid "git notes [--ref <notes-ref>] prune [-n] [-v]"
+msgstr "git notes [--ref УКАЗАТЕЛ_ЗА_БЕЛЕЖКА] prune [-n] [-v]"
 
-#: builtin/merge.c:216 builtin/pull.c:163
-msgid "edit message before committing"
-msgstr "редактиране на съобщението преди подаване"
+#: builtin/notes.c:39
+msgid "git notes [--ref <notes-ref>] get-ref"
+msgstr "git notes [--ref УКАЗАТЕЛ_ЗА_БЕЛЕЖКА] get-ref"
 
-#: builtin/merge.c:217
-msgid "allow fast-forward (default)"
-msgstr "позволяване на превъртане (стандартно действие)"
+#: builtin/notes.c:44
+msgid "git notes [list [<object>]]"
+msgstr "git notes [list [ОБЕКТ]]"
 
-#: builtin/merge.c:219 builtin/pull.c:169
-msgid "abort if fast-forward is not possible"
-msgstr "преустановяване, ако превъртането е невъзможно"
+#: builtin/notes.c:49
+msgid "git notes add [<options>] [<object>]"
+msgstr "git notes add [ОПЦИЯ…] [ОБЕКТ]"
 
-#: builtin/merge.c:223 builtin/pull.c:172
-msgid "verify that the named commit has a valid GPG signature"
-msgstr "проверка, че указаното подаване е с правилен подпис на GPG"
+#: builtin/notes.c:54
+msgid "git notes copy [<options>] <from-object> <to-object>"
+msgstr "git notes copy [ОПЦИЯ…] ОБЕКТ_ИЗТОЧНИК ОБЕКТ_ЦЕЛ"
 
-#: builtin/merge.c:224 builtin/notes.c:777 builtin/pull.c:176
-#: builtin/revert.c:109
-msgid "strategy"
-msgstr "СТРАТЕГИЯ"
+#: builtin/notes.c:55
+msgid "git notes copy --stdin [<from-object> <to-object>]..."
+msgstr "git notes copy --stdin [ОБЕКТ_ИЗТОЧНИК ОБЕКТ_ЦЕЛ…]"
 
-#: builtin/merge.c:225 builtin/pull.c:177
-msgid "merge strategy to use"
-msgstr "СТРАТЕГИЯ за сливане, която да се ползва"
+#: builtin/notes.c:60
+msgid "git notes append [<options>] [<object>]"
+msgstr "git notes append [ОПЦИЯ…] [ОБЕКТ]"
 
-#: builtin/merge.c:226 builtin/pull.c:180
-msgid "option=value"
-msgstr "ОПЦИЯ=СТОЙНОСТ"
+#: builtin/notes.c:65
+msgid "git notes edit [<object>]"
+msgstr "git notes edit [ОБЕКТ]"
 
-#: builtin/merge.c:227 builtin/pull.c:181
-msgid "option for selected merge strategy"
-msgstr "ОПЦИЯ за избраната стратегия за сливане"
+#: builtin/notes.c:70
+msgid "git notes show [<object>]"
+msgstr "git notes show [ОБЕКТ]"
+
+#: builtin/notes.c:75
+msgid "git notes merge [<options>] <notes-ref>"
+msgstr "git notes merge [ОПЦИЯ…] УКАЗАТЕЛ_ЗА_БЕЛЕЖКА"
+
+#: builtin/notes.c:76
+msgid "git notes merge --commit [<options>]"
+msgstr "git notes merge --commit [ОПЦИЯ…]"
 
-#: builtin/merge.c:229
-msgid "merge commit message (for a non-fast-forward merge)"
-msgstr "СЪОБЩЕНИЕ при подаването със сливане (при същински сливания)"
+#: builtin/notes.c:77
+msgid "git notes merge --abort [<options>]"
+msgstr "git notes merge --abort [ОПЦИЯ…]"
 
-#: builtin/merge.c:233
-msgid "abort the current in-progress merge"
-msgstr "преустановяване на текущото сливане"
+#: builtin/notes.c:82
+msgid "git notes remove [<object>]"
+msgstr "git notes remove [ОБЕКТ]"
 
-#: builtin/merge.c:235
-msgid "continue the current in-progress merge"
-msgstr "продължаване на текущото сливане"
+#: builtin/notes.c:87
+msgid "git notes prune [<options>]"
+msgstr "git notes prune [ОПЦИЯ…]"
 
-#: builtin/merge.c:237 builtin/pull.c:188
-msgid "allow merging unrelated histories"
-msgstr "позволяване на сливане на независими истории"
+#: builtin/notes.c:92
+msgid "git notes get-ref"
+msgstr "git notes get-ref"
 
-#: builtin/merge.c:243
-msgid "verify commit-msg hook"
-msgstr ""
-"проверка на куката при промяна на съобщението при подаване (commit-msg)"
+#: builtin/notes.c:97
+msgid "Write/edit the notes for the following object:"
+msgstr "Записване/редактиране на бележките за следния обект:"
 
-#: builtin/merge.c:268
-msgid "could not run stash."
-msgstr "не може да се извърши скатаване"
+#: builtin/notes.c:150
+#, c-format
+msgid "unable to start 'show' for object '%s'"
+msgstr "действието „show“ не може да се изпълни за обект „%s“"
 
-#: builtin/merge.c:273
-msgid "stash failed"
-msgstr "неуспешно скатаване"
+#: builtin/notes.c:154
+msgid "could not read 'show' output"
+msgstr "изведената информация от действието „show“ не може да се прочете"
 
-#: builtin/merge.c:278
+#: builtin/notes.c:162
 #, c-format
-msgid "not a valid object: %s"
-msgstr "неправилен обект: „%s“"
+msgid "failed to finish 'show' for object '%s'"
+msgstr "действието „show“ не може да се завърши за обект „%s“"
 
-#: builtin/merge.c:300 builtin/merge.c:317
-msgid "read-tree failed"
-msgstr "неуспешно прочитане на обект-дърво"
+#: builtin/notes.c:197
+msgid "please supply the note contents using either -m or -F option"
+msgstr "задайте съдържанието на бележката с някоя от опциите „-m“ или „-F“"
 
-#: builtin/merge.c:347
-msgid " (nothing to squash)"
-msgstr " (няма какво да се вкара)"
+#: builtin/notes.c:206
+msgid "unable to write note object"
+msgstr "обектът-бележка не може да бъде записан"
 
-#: builtin/merge.c:358
+#: builtin/notes.c:208
 #, c-format
-msgid "Squash commit -- not updating HEAD\n"
-msgstr "Вкарано подаване — указателят „HEAD“ няма да бъде обновен\n"
+msgid "the note contents have been left in %s"
+msgstr "съдържанието на бележката е във файла „%s“"
 
-#: builtin/merge.c:408
+#: builtin/notes.c:242 builtin/tag.c:532
 #, c-format
-msgid "No merge message -- not updating HEAD\n"
-msgstr ""
-"Липсва съобщение при подаване — указателят „HEAD“ няма да бъде обновен\n"
+msgid "could not open or read '%s'"
+msgstr "файлът „%s“ не може да бъде отворен или прочетен"
 
-#: builtin/merge.c:458
+#: builtin/notes.c:263 builtin/notes.c:313 builtin/notes.c:315
+#: builtin/notes.c:383 builtin/notes.c:438 builtin/notes.c:526
+#: builtin/notes.c:531 builtin/notes.c:610 builtin/notes.c:672
 #, c-format
-msgid "'%s' does not point to a commit"
-msgstr "„%s“ не сочи към подаване"
+msgid "failed to resolve '%s' as a valid ref."
+msgstr "не може да се открие към какво сочи „%s“."
 
-#: builtin/merge.c:548
+#: builtin/notes.c:265
 #, c-format
-msgid "Bad branch.%s.mergeoptions string: %s"
-msgstr "Неправилен низ за настройката „branch.%s.mergeoptions“: „%s“"
-
-#: builtin/merge.c:669
-msgid "Not handling anything other than two heads merge."
-msgstr "Поддържа се само сливане на точно две истории."
+msgid "failed to read object '%s'."
+msgstr "обектът „%s“ не може да бъде прочетен."
 
-#: builtin/merge.c:683
+#: builtin/notes.c:268
 #, c-format
-msgid "Unknown option for merge-recursive: -X%s"
-msgstr "Непозната опция за рекурсивното сливане „merge-recursive“: „-X%s“"
+msgid "cannot read note data from non-blob object '%s'."
+msgstr ""
+"съдържанието на бележка не може да се вземе от обект, който не е BLOB: „%s“."
 
-#: builtin/merge.c:698
+#: builtin/notes.c:309
 #, c-format
-msgid "unable to write %s"
-msgstr "„%s“ не може да бъде записан"
+msgid "malformed input line: '%s'."
+msgstr "входен ред с неправилен формат: „%s“."
 
-#: builtin/merge.c:749
+#: builtin/notes.c:324
 #, c-format
-msgid "Could not read from '%s'"
-msgstr "От „%s“ не може да се чете"
+msgid "failed to copy notes from '%s' to '%s'"
+msgstr "бележката не може да се копира от „%s“ към „%s“"
 
-#: builtin/merge.c:758
+#. TRANSLATORS: the first %s will be replaced by a git
+#. notes command: 'add', 'merge', 'remove', etc.
+#.
+#: builtin/notes.c:356
 #, c-format
-msgid "Not committing merge; use 'git commit' to complete the merge.\n"
+msgid "refusing to %s notes in %s (outside of refs/notes/)"
 msgstr ""
-"Сливането няма да бъде подадено.  За завършването му и подаването му "
-"използвайте командата „git commit“.\n"
+"няма да се извърши „%s“ върху бележките в „%s“, защото са извън „refs/"
+"notes/“."
 
-#: builtin/merge.c:764
+#: builtin/notes.c:376 builtin/notes.c:431 builtin/notes.c:509
+#: builtin/notes.c:521 builtin/notes.c:598 builtin/notes.c:665
+#: builtin/notes.c:815 builtin/notes.c:963 builtin/notes.c:985
+msgid "too many parameters"
+msgstr "прекалено много параметри"
+
+#: builtin/notes.c:389 builtin/notes.c:678
 #, c-format
-msgid ""
-"Please enter a commit message to explain why this merge is necessary,\n"
-"especially if it merges an updated upstream into a topic branch.\n"
-"\n"
-"Lines starting with '%c' will be ignored, and an empty message aborts\n"
-"the commit.\n"
-msgstr ""
-"В съобщението при подаване добавете информация за причината за\n"
-"сливането, особено ако сливате обновен отдалечен клон в тематичен клон.\n"
-"\n"
-"Редовете, които започват с „%c“ ще бъдат пропуснати, а празно съобщение\n"
-"преустановява подаването.\n"
+msgid "no note found for object %s."
+msgstr "няма бележки за обекта „%s“."
 
-#: builtin/merge.c:800
-msgid "Empty commit message."
-msgstr "Празно съобщение при подаване."
+#: builtin/notes.c:410 builtin/notes.c:576
+msgid "note contents as a string"
+msgstr "низ, който е съдържанието на бележката"
 
-#: builtin/merge.c:819
-#, c-format
-msgid "Wonderful.\n"
-msgstr "Първият етап на сливането завърши.\n"
+#: builtin/notes.c:413 builtin/notes.c:579
+msgid "note contents in a file"
+msgstr "ФАЙЛ със съдържанието на бележката"
 
-#: builtin/merge.c:872
-#, c-format
-msgid "Automatic merge failed; fix conflicts and then commit the result.\n"
-msgstr ""
-"Неуспешно автоматично сливане — коригирайте конфликтите и подайте "
-"резултата.\n"
+#: builtin/notes.c:416 builtin/notes.c:582
+msgid "reuse and edit specified note object"
+msgstr "преизползване и редактиране на указания ОБЕКТ-бележка"
 
-#: builtin/merge.c:911
-msgid "No current branch."
-msgstr "Няма текущ клон."
+#: builtin/notes.c:419 builtin/notes.c:585
+msgid "reuse specified note object"
+msgstr "преизползване на указания ОБЕКТ-бележка"
 
-#: builtin/merge.c:913
-msgid "No remote for the current branch."
-msgstr "Текущият клон не следи никой."
+#: builtin/notes.c:422 builtin/notes.c:588
+msgid "allow storing empty note"
+msgstr "приемане и на празни бележки"
 
-#: builtin/merge.c:915
-msgid "No default upstream defined for the current branch."
-msgstr "Текущият клон не следи никой клон."
+#: builtin/notes.c:423 builtin/notes.c:496
+msgid "replace existing notes"
+msgstr "замяна на съществуващите бележки"
 
-#: builtin/merge.c:920
+#: builtin/notes.c:448
 #, c-format
-msgid "No remote-tracking branch for %s from %s"
-msgstr "Никой клон не следи клона „%s“ от хранилището „%s“"
+msgid ""
+"Cannot add notes. Found existing notes for object %s. Use '-f' to overwrite "
+"existing notes"
+msgstr ""
+"Не може да се добави бележка, защото такава вече съществува за обекта „%s“.  "
+"Използвайте опцията „-f“, за да презапишете съществуващи бележки."
 
-#: builtin/merge.c:973
+#: builtin/notes.c:463 builtin/notes.c:544
 #, c-format
-msgid "Bad value '%s' in environment '%s'"
-msgstr "Неправилна стойност „%s“ в средата „%s“"
+msgid "Overwriting existing notes for object %s\n"
+msgstr "Презаписване на съществуващите бележки за обекта „%s“\n"
 
-#: builtin/merge.c:1075
+#: builtin/notes.c:475 builtin/notes.c:637 builtin/notes.c:902
 #, c-format
-msgid "not something we can merge in %s: %s"
-msgstr "не може да се слее в „%s“: %s"
-
-#: builtin/merge.c:1109
-msgid "not something we can merge"
-msgstr "не може да се слее"
+msgid "Removing note for object %s\n"
+msgstr "Изтриване на бележката за обекта „%s“\n"
 
-#: builtin/merge.c:1211
-msgid "--abort expects no arguments"
-msgstr "опцията „--abort“ не приема аргументи"
+#: builtin/notes.c:497
+msgid "read objects from stdin"
+msgstr "изчитане на обектите от стандартния вход"
 
-#: builtin/merge.c:1215
-msgid "There is no merge to abort (MERGE_HEAD missing)."
+#: builtin/notes.c:499
+msgid "load rewriting config for <command> (implies --stdin)"
 msgstr ""
-"Не може да преустановите сливане, защото в момента не се извършва такова "
-"(липсва указател „MERGE_HEAD“)."
-
-#: builtin/merge.c:1227
-msgid "--continue expects no arguments"
-msgstr "опцията „--continue“ не приема аргументи"
+"зареждане на настройките за КОМАНДАта, която презаписва подавания (включва "
+"опцията „--stdin“)"
 
-#: builtin/merge.c:1231
-msgid "There is no merge in progress (MERGE_HEAD missing)."
-msgstr "В момента не се извършва сливане (липсва указател „MERGE_HEAD“)."
+#: builtin/notes.c:517
+msgid "too few parameters"
+msgstr "прекалено малко параметри"
 
-#: builtin/merge.c:1247
+#: builtin/notes.c:538
+#, c-format
 msgid ""
-"You have not concluded your merge (MERGE_HEAD exists).\n"
-"Please, commit your changes before you merge."
+"Cannot copy notes. Found existing notes for object %s. Use '-f' to overwrite "
+"existing notes"
 msgstr ""
-"Не сте завършили сливане.  (Указателят „MERGE_HEAD“ съществува).\n"
-"Подайте промените си, преди да започнете ново сливане."
+"Не може да се копира бележка, защото такава вече съществува за обекта „%s“.  "
+"Използвайте опцията „-f“, за да презапишете съществуващи бележки."
 
-#: builtin/merge.c:1254
-msgid ""
-"You have not concluded your cherry-pick (CHERRY_PICK_HEAD exists).\n"
-"Please, commit your changes before you merge."
-msgstr ""
-"Не сте завършили отбиране на подаване (указателят „CHERRY_PICK_HEAD“\n"
-"съществува).  Подайте промените си, преди да започнете ново сливане."
+#: builtin/notes.c:550
+#, c-format
+msgid "missing notes on source object %s. Cannot copy."
+msgstr "няма бележки за обекта-източник „%s“.  Не може да се копира."
 
-#: builtin/merge.c:1257
-msgid "You have not concluded your cherry-pick (CHERRY_PICK_HEAD exists)."
+#: builtin/notes.c:603
+#, c-format
+msgid ""
+"The -m/-F/-c/-C options have been deprecated for the 'edit' subcommand.\n"
+"Please use 'git notes add -f -m/-F/-c/-C' instead.\n"
 msgstr ""
-"Не сте завършили отбиране на подаване (указателят „CHERRY_PICK_HEAD“\n"
-"съществува)."
+"Задаването на опциите „-m“/„-F“/„-c“/„-C“ с командата „edit“ вече е "
+"остаряло.\n"
+"Вместо това ги използвайте с подкомандата „add“: „git notes add -f -m/-F/-c/-"
+"C“.\n"
 
-#: builtin/merge.c:1266
-msgid "You cannot combine --squash with --no-ff."
-msgstr "Опцията „--squash“ е несъвместима с „--no-ff“."
+#: builtin/notes.c:698
+msgid "failed to delete ref NOTES_MERGE_PARTIAL"
+msgstr "указателят „NOTES_MERGE_PARTIAL“ не може да бъде изтрит"
 
-#: builtin/merge.c:1274
-msgid "No commit specified and merge.defaultToUpstream not set."
-msgstr ""
-"Не е указано подаване и настройката „merge.defaultToUpstream“ не е зададена."
+#: builtin/notes.c:700
+msgid "failed to delete ref NOTES_MERGE_REF"
+msgstr "указателят „NOTES_MERGE_REF“ не може да бъде изтрит"
 
-#: builtin/merge.c:1291
-msgid "Squash commit into empty head not supported yet"
-msgstr "Вкарване на подаване във връх без история все още не се поддържа"
+#: builtin/notes.c:702
+msgid "failed to remove 'git notes merge' worktree"
+msgstr "работната директория на „git notes merge“ не може да бъде изтрита"
 
-#: builtin/merge.c:1293
-msgid "Non-fast-forward commit does not make sense into an empty head"
-msgstr ""
-"Понеже върхът е без история, всички сливания са превъртания, не може да се "
-"извърши същинско сливане изисквано от опцията „--no-ff“"
+#: builtin/notes.c:722
+msgid "failed to read ref NOTES_MERGE_PARTIAL"
+msgstr "указателят „NOTES_MERGE_PARTIAL“ не може да бъде прочетен"
 
-#: builtin/merge.c:1298
-#, c-format
-msgid "%s - not something we can merge"
-msgstr "„%s“ — не е нещо, което може да се слее"
+#: builtin/notes.c:724
+msgid "could not find commit from NOTES_MERGE_PARTIAL."
+msgstr "подаването от „NOTES_MERGE_PARTIAL“ не може да се открие."
 
-#: builtin/merge.c:1300
-msgid "Can merge only exactly one commit into empty head"
-msgstr "Можете да слеете точно едно подаване във връх без история"
+#: builtin/notes.c:726
+msgid "could not parse commit from NOTES_MERGE_PARTIAL."
+msgstr "подаването от „NOTES_MERGE_PARTIAL“ не може да се анализира."
 
-#: builtin/merge.c:1334
-#, c-format
-msgid "Commit %s has an untrusted GPG signature, allegedly by %s."
-msgstr ""
-"Подаването „%s“ е с недоверен подпис от GPG, който твърди, че е на „%s“."
+#: builtin/notes.c:739
+msgid "failed to resolve NOTES_MERGE_REF"
+msgstr "не може да се открие към какво сочи „NOTES_MERGE_REF“"
 
-#: builtin/merge.c:1337
-#, c-format
-msgid "Commit %s has a bad GPG signature allegedly by %s."
-msgstr ""
-"Подаването „%s“ е с неправилен подпис от GPG, който твърди, че е на „%s“."
+#: builtin/notes.c:742
+msgid "failed to finalize notes merge"
+msgstr "неуспешно сливане на бележките"
 
-#: builtin/merge.c:1340
+#: builtin/notes.c:768
 #, c-format
-msgid "Commit %s does not have a GPG signature."
-msgstr "Подаването „%s“ е без подпис от GPG."
+msgid "unknown notes merge strategy %s"
+msgstr "непозната стратегия за сливане на бележки „%s“"
 
-#: builtin/merge.c:1343
-#, c-format
-msgid "Commit %s has a good GPG signature by %s\n"
-msgstr "Подаването „%s“ е с коректен подпис от GPG на „%s“.\n"
+#: builtin/notes.c:784
+msgid "General options"
+msgstr "Общи опции"
 
-#: builtin/merge.c:1402
-msgid "refusing to merge unrelated histories"
-msgstr "независими истории не може да се слеят"
+#: builtin/notes.c:786
+msgid "Merge options"
+msgstr "Опции при сливане"
 
-#: builtin/merge.c:1411
-msgid "Already up to date."
-msgstr "Вече е обновено."
+#: builtin/notes.c:788
+msgid ""
+"resolve notes conflicts using the given strategy (manual/ours/theirs/union/"
+"cat_sort_uniq)"
+msgstr ""
+"коригиране на конфликтите при сливане на бележките чрез тази СТРАТЕГИЯ — "
+"„manual“ (ръчно), „ours“ (вашата версия), „theirs“ (чуждата версия), "
+"„union“ (обединяване), „cat_sort_uniq“ (обединяване, подреждане, уникални "
+"резултати)"
 
-#: builtin/merge.c:1421
-#, c-format
-msgid "Updating %s..%s\n"
-msgstr "Обновяване „%s..%s“\n"
+#: builtin/notes.c:790
+msgid "Committing unmerged notes"
+msgstr "Подаване на неслети бележки"
 
-#: builtin/merge.c:1462
-#, c-format
-msgid "Trying really trivial in-index merge...\n"
-msgstr "Проба със сливане в рамките на индекса…\n"
+#: builtin/notes.c:792
+msgid "finalize notes merge by committing unmerged notes"
+msgstr "завършване на сливането чрез подаване на неслети бележки"
 
-#: builtin/merge.c:1469
-#, c-format
-msgid "Nope.\n"
-msgstr "Неуспешно сливане.\n"
+#: builtin/notes.c:794
+msgid "Aborting notes merge resolution"
+msgstr "Преустановяване на корекцията при сливането на бележки"
 
-#: builtin/merge.c:1494
-msgid "Already up to date. Yeeah!"
-msgstr "Вече е обновено!"
+#: builtin/notes.c:796
+msgid "abort notes merge"
+msgstr "преустановяване на сливането на бележки"
 
-#: builtin/merge.c:1500
-msgid "Not possible to fast-forward, aborting."
-msgstr "Не може да се извърши превъртане, преустановяване на действието."
+#: builtin/notes.c:807
+msgid "cannot mix --commit, --abort or -s/--strategy"
+msgstr "опциите „--commit“, „--abort“ и „-s“/„--strategy“ са несъвместими"
 
-#: builtin/merge.c:1523 builtin/merge.c:1602
-#, c-format
-msgid "Rewinding the tree to pristine...\n"
-msgstr "Привеждане на дървото към първоначалното…\n"
+#: builtin/notes.c:812
+msgid "must specify a notes ref to merge"
+msgstr "трябва да укажете указател към бележка за сливане."
 
-#: builtin/merge.c:1527
+#: builtin/notes.c:836
 #, c-format
-msgid "Trying merge strategy %s...\n"
-msgstr "Пробване със стратегията за сливане „%s“…\n"
+msgid "unknown -s/--strategy: %s"
+msgstr "неизвестна стратегия към опцията „-s“/„--strategy“: „%s“"
 
-#: builtin/merge.c:1593
+#: builtin/notes.c:873
 #, c-format
-msgid "No merge strategy handled the merge.\n"
-msgstr "Никоя стратегия за сливане не може да извърши сливането.\n"
+msgid "a notes merge into %s is already in-progress at %s"
+msgstr "в момента се извършва сливане на бележките в „%s“ при „%s“"
 
-#: builtin/merge.c:1595
+#: builtin/notes.c:876
 #, c-format
-msgid "Merge with strategy %s failed.\n"
-msgstr "Неуспешно сливане със стратегия „%s“.\n"
+msgid "failed to store link to current notes ref (%s)"
+msgstr "не може да се запази връзка към указателя на текущата бележка („%s“)."
 
-#: builtin/merge.c:1604
+#: builtin/notes.c:878
 #, c-format
-msgid "Using the %s to prepare resolving by hand.\n"
+msgid ""
+"Automatic notes merge failed. Fix conflicts in %s and commit the result with "
+"'git notes merge --commit', or abort the merge with 'git notes merge --"
+"abort'.\n"
 msgstr ""
-"Ползва се стратегията „%s“, която ще подготви дървото за коригиране на "
-"ръка.\n"
+"Неуспешно сливане на бележките.  Разрешете конфликтите в „%s“ и подайте "
+"резултата с „git notes merge --commit“ или преустановете сливането с "
+"командата „git notes merge --abort“.\n"
 
-#: builtin/merge.c:1616
+#: builtin/notes.c:897 builtin/tag.c:545
 #, c-format
-msgid "Automatic merge went well; stopped before committing as requested\n"
-msgstr ""
-"Автоматичното сливане завърши успешно.  Самото подаване не е извършено, "
-"защото бе зададена опцията „--no-commit“.\n"
-
-#: builtin/merge-base.c:30
-msgid "git merge-base [-a | --all] <commit> <commit>..."
-msgstr "git merge-base [-a | --all] ПОДАВАНЕ ПОДАВАНЕ…"
-
-#: builtin/merge-base.c:31
-msgid "git merge-base [-a | --all] --octopus <commit>..."
-msgstr "git merge-base [-a | --all] --octopus ПОДАВАНЕ…"
+msgid "Failed to resolve '%s' as a valid ref."
+msgstr "Не може да се открие към какво сочи „%s“."
 
-#: builtin/merge-base.c:32
-msgid "git merge-base --independent <commit>..."
-msgstr "git merge-base --independent ПОДАВАНЕ…"
+#: builtin/notes.c:900
+#, c-format
+msgid "Object %s has no note\n"
+msgstr "Няма бележки за обекта „%s“\n"
 
-#: builtin/merge-base.c:33
-msgid "git merge-base --is-ancestor <commit> <commit>"
-msgstr "git merge-base --is-ancestor ПОДАВАНЕ_1 ПОДАВАНЕ_2"
+#: builtin/notes.c:912
+msgid "attempt to remove non-existent note is not an error"
+msgstr "опитът за изтриването на несъществуваща бележка не се счита за грешка"
 
-#: builtin/merge-base.c:34
-msgid "git merge-base --fork-point <ref> [<commit>]"
-msgstr "git merge-base --fork-point УКАЗАТЕЛ [ПОДАВАНЕ]"
+#: builtin/notes.c:915
+msgid "read object names from the standard input"
+msgstr "изчитане на имената на обектите от стандартния вход"
 
-#: builtin/merge-base.c:220
-msgid "output all common ancestors"
-msgstr "извеждане на всички общи предшественици"
+#: builtin/notes.c:954 builtin/prune.c:130 builtin/worktree.c:164
+msgid "do not remove, show only"
+msgstr "само извеждане без действително окастряне"
 
-#: builtin/merge-base.c:222
-msgid "find ancestors for a single n-way merge"
-msgstr ""
-"откриване на предшествениците за еднократно сливане на множество истории"
+#: builtin/notes.c:955
+msgid "report pruned notes"
+msgstr "докладване на окастрените обекти"
 
-#: builtin/merge-base.c:224
-msgid "list revs not reachable from others"
-msgstr "извеждане на недостижимите от другите указатели"
+#: builtin/notes.c:998
+msgid "notes-ref"
+msgstr "УКАЗАТЕЛ_ЗА_БЕЛЕЖКА"
 
-#: builtin/merge-base.c:226
-msgid "is the first one ancestor of the other?"
-msgstr "ПОДАВАНЕ_1 предшественик ли е на ПОДАВАНЕ_2?"
+#: builtin/notes.c:999
+msgid "use notes from <notes-ref>"
+msgstr "да се използва бележката сочена от този УКАЗАТЕЛ_ЗА_БЕЛЕЖКА"
 
-#: builtin/merge-base.c:228
-msgid "find where <commit> forked from reflog of <ref>"
-msgstr "откриване къде ПОДАВАНЕто се е отклонило от историята на УКАЗАТЕЛя"
+#: builtin/notes.c:1034 builtin/stash.c:1607
+#, c-format
+msgid "unknown subcommand: %s"
+msgstr "непозната подкоманда: %s"
 
-#: builtin/merge-file.c:9
+#: builtin/pack-objects.c:52
 msgid ""
-"git merge-file [<options>] [-L <name1> [-L <orig> [-L <name2>]]] <file1> "
-"<orig-file> <file2>"
+"git pack-objects --stdout [<options>...] [< <ref-list> | < <object-list>]"
 msgstr ""
-"git merge-file [ОПЦИЯ…] [-L ИМЕ_1 [-L ОРИГИНАЛ [-L ИМЕ_2]]] ФАЙЛ_1 ОРИГ_ФАЙЛ "
-"ФАЙЛ_2"
-
-#: builtin/merge-file.c:33
-msgid "send results to standard output"
-msgstr "извеждане на резултатите на стандартния изход"
-
-#: builtin/merge-file.c:34
-msgid "use a diff3 based merge"
-msgstr "сливане на базата на „diff3“"
-
-#: builtin/merge-file.c:35
-msgid "for conflicts, use our version"
-msgstr "при конфликти да се ползва локалната версия"
-
-#: builtin/merge-file.c:37
-msgid "for conflicts, use their version"
-msgstr "при конфликти да се ползва чуждата версия"
-
-#: builtin/merge-file.c:39
-msgid "for conflicts, use a union version"
-msgstr "при конфликти да се ползва обединена версия"
-
-#: builtin/merge-file.c:42
-msgid "for conflicts, use this marker size"
-msgstr "при конфликти да се ползва маркер с такъв БРОЙ знаци"
-
-#: builtin/merge-file.c:43
-msgid "do not warn about conflicts"
-msgstr "без предупреждения при конфликти"
+"git pack-objects --stdout [ОПЦИЯ…] [< СПИСЪК_С_УКАЗАТЕЛИ | < СПИСЪК_С_ОБЕКТИ]"
 
-#: builtin/merge-file.c:45
-msgid "set labels for file1/orig-file/file2"
-msgstr "задаване на етикети за ФАЙЛ_1/ОРИГИНАЛ/ФАЙЛ_2"
+#: builtin/pack-objects.c:53
+msgid ""
+"git pack-objects [<options>...] <base-name> [< <ref-list> | < <object-list>]"
+msgstr ""
+"git pack-objects [ОПЦИЯ…] ПРЕФИКС_НА_ИМЕТО [< СПИСЪК_С_УКАЗАТЕЛИ | < "
+"СПИСЪК_С_ОБЕКТИ]"
 
-#: builtin/merge-recursive.c:45
+#: builtin/pack-objects.c:428
 #, c-format
-msgid "unknown option %s"
-msgstr "непозната опция: „%s“"
+msgid "bad packed object CRC for %s"
+msgstr "лоша контролна сума за пакетирания обект „%s“"
 
-#: builtin/merge-recursive.c:51
+#: builtin/pack-objects.c:439
 #, c-format
-msgid "could not parse object '%s'"
-msgstr "неуспешен анализ на обекта „%s“"
+msgid "corrupt packed object for %s"
+msgstr "пакетиран обект с грешки за „%s“"
 
-#: builtin/merge-recursive.c:55
+#: builtin/pack-objects.c:570
 #, c-format
-msgid "cannot handle more than %d base. Ignoring %s."
-msgid_plural "cannot handle more than %d bases. Ignoring %s."
-msgstr[0] "не се поддържа повече от %d база.  „%s“ се прескача."
-msgstr[1] "не се поддържат повече от %d бази.  „%s“ се прескача."
+msgid "recursive delta detected for object %s"
+msgstr "рекурсивна разлика за обект „%s“"
 
-#: builtin/merge-recursive.c:63
-msgid "not handling anything other than two heads merge."
-msgstr "поддържа се само сливане на точно две истории."
+#: builtin/pack-objects.c:781
+#, c-format
+msgid "ordered %u objects, expected %<PRIu32>"
+msgstr "подредени бяха %u обекта, а се очакваха %<PRIu32>"
 
-#: builtin/merge-recursive.c:69 builtin/merge-recursive.c:71
+#: builtin/pack-objects.c:794
 #, c-format
-msgid "could not resolve ref '%s'"
-msgstr "указателят „%s“ не може да бъде изтрит"
+msgid "packfile is invalid: %s"
+msgstr "неправилен пакетен файл: „%s“"
 
-#: builtin/merge-recursive.c:77
+#: builtin/pack-objects.c:798
 #, c-format
-msgid "Merging %s with %s\n"
-msgstr "Сливане на „%s“ с „%s“\n"
+msgid "unable to open packfile for reuse: %s"
+msgstr "пакетният файл „%s“ не може да бъде повторно отворен"
 
-#: builtin/mktree.c:65
-msgid "git mktree [-z] [--missing] [--batch]"
-msgstr "git mktree [-z] [--missing] [--batch]"
+#: builtin/pack-objects.c:802
+msgid "unable to seek in reused packfile"
+msgstr "неуспешно търсене в преизползван пакетен файл"
 
-#: builtin/mktree.c:153
-msgid "input is NUL terminated"
-msgstr "входните записи са разделени с нулевия знак „NUL“"
+#: builtin/pack-objects.c:813
+msgid "unable to read from reused packfile"
+msgstr "неуспешно четене от преизползван пакетен файл"
 
-#: builtin/mktree.c:154 builtin/write-tree.c:25
-msgid "allow missing objects"
-msgstr "разрешаване на липсващи обекти"
+#: builtin/pack-objects.c:841
+msgid "disabling bitmap writing, packs are split due to pack.packSizeLimit"
+msgstr ""
+"изключване на записването на битовата маска, пакетите са разделени поради "
+"стойността на „pack.packSizeLimit“"
 
-#: builtin/mktree.c:155
-msgid "allow creation of more than one tree"
-msgstr "разрешаване на създаването на повече от едно дърво"
+#: builtin/pack-objects.c:854
+msgid "Writing objects"
+msgstr "Записване на обектите"
 
-#: builtin/mv.c:17
-msgid "git mv [<options>] <source>... <destination>"
-msgstr "git mv [ОПЦИЯ…] ОБЕКТ… ЦЕЛ"
+#: builtin/pack-objects.c:917 builtin/update-index.c:90
+#, c-format
+msgid "failed to stat %s"
+msgstr "не може да бъде получена информация чрез „stat“ за „%s“"
 
-#: builtin/mv.c:82
+#: builtin/pack-objects.c:970
 #, c-format
-msgid "Directory %s is in index and no submodule?"
-msgstr "Директорията „%s“ е в индекса, но не е подмодул"
+msgid "wrote %<PRIu32> objects while expecting %<PRIu32>"
+msgstr "бяха записани %<PRIu32> обекти, а се очакваха %<PRIu32>"
 
-#: builtin/mv.c:84 builtin/rm.c:288
-msgid "Please stage your changes to .gitmodules or stash them to proceed"
+#: builtin/pack-objects.c:1164
+msgid "disabling bitmap writing, as some objects are not being packed"
 msgstr ""
-"За да продължите, или вкарайте промените по файла „.gitmodules“ в индекса,\n"
-"или ги скатайте"
+"изключване на записването на битовата маска, защото някои обекти няма да се "
+"пакетират"
 
-#: builtin/mv.c:102
+#: builtin/pack-objects.c:1592
 #, c-format
-msgid "%.*s is in index"
-msgstr "„%.*s“ вече е в индекса"
+msgid "delta base offset overflow in pack for %s"
+msgstr "прекалено далечно начало на отместването за обектите-разлика за „%s“"
 
-#: builtin/mv.c:124
-msgid "force move/rename even if target exists"
-msgstr "принудително преместване/преименуване дори целта да съществува"
+#: builtin/pack-objects.c:1601
+#, c-format
+msgid "delta base offset out of bound for %s"
+msgstr "недостижимо начало на отместването за обектите-разлика за „%s“"
 
-#: builtin/mv.c:126
-msgid "skip move/rename errors"
-msgstr "прескачане на грешките при преместване/преименуване"
+#: builtin/pack-objects.c:1870
+msgid "Counting objects"
+msgstr "Преброяване на обектите"
 
-#: builtin/mv.c:168
+#: builtin/pack-objects.c:2000
 #, c-format
-msgid "destination '%s' is not a directory"
-msgstr "целта „%s“ съществува и не е директория"
+msgid "unable to get size of %s"
+msgstr "размерът на „%s“ не може да бъде получен"
 
-#: builtin/mv.c:179
+#: builtin/pack-objects.c:2015
 #, c-format
-msgid "Checking rename of '%s' to '%s'\n"
-msgstr "Проверка на преименуването на обект от „%s“ на „%s“\n"
-
-#: builtin/mv.c:183
-msgid "bad source"
-msgstr "неправилен обект"
-
-#: builtin/mv.c:186
-msgid "can not move directory into itself"
-msgstr "директория не може да се премести в себе си"
-
-#: builtin/mv.c:189
-msgid "cannot move directory over file"
-msgstr "директория не може да се премести върху файл"
+msgid "unable to parse object header of %s"
+msgstr "заглавната част на „%s“ не може да бъде анализирана"
 
-#: builtin/mv.c:198
-msgid "source directory is empty"
-msgstr "първоначалната директория е празна"
+#: builtin/pack-objects.c:2085 builtin/pack-objects.c:2101
+#: builtin/pack-objects.c:2111
+#, c-format
+msgid "object %s cannot be read"
+msgstr "обектът „%s“ не може да се прочете"
 
-#: builtin/mv.c:223
-msgid "not under version control"
-msgstr "не е под контрола на Git"
+#: builtin/pack-objects.c:2088 builtin/pack-objects.c:2115
+#, c-format
+msgid "object %s inconsistent object length (%<PRIuMAX> vs %<PRIuMAX>)"
+msgstr "обектът „%s“ е с неправилна дължина (%<PRIuMAX>, а не %<PRIuMAX>)"
 
-#: builtin/mv.c:226
-msgid "destination exists"
-msgstr "целта съществува"
+#: builtin/pack-objects.c:2125
+msgid "suboptimal pack - out of memory"
+msgstr "неоптимизиран пакет — паметта свърши"
 
-#: builtin/mv.c:234
+#: builtin/pack-objects.c:2440
 #, c-format
-msgid "overwriting '%s'"
-msgstr "презаписване на „%s“"
+msgid "Delta compression using up to %d threads"
+msgstr "Делта компресията ще използва до %d нишки"
 
-#: builtin/mv.c:237
-msgid "Cannot overwrite"
-msgstr "Презаписването е невъзможно"
+#: builtin/pack-objects.c:2572
+#, c-format
+msgid "unable to pack objects reachable from tag %s"
+msgstr ""
+"обектите, които могат да бъдат достигнати от етикета „%s“, не може да бъдат "
+"пакетирани"
 
-#: builtin/mv.c:240
-msgid "multiple sources for the same target"
-msgstr "множество източници за една цел"
+#: builtin/pack-objects.c:2659
+msgid "Compressing objects"
+msgstr "Компресиране на обектите"
 
-#: builtin/mv.c:242
-msgid "destination directory does not exist"
-msgstr "целевата директория не съществува"
+#: builtin/pack-objects.c:2665
+msgid "inconsistency with delta count"
+msgstr "неправилен брой разлики"
 
-#: builtin/mv.c:249
+#: builtin/pack-objects.c:2742
 #, c-format
-msgid "%s, source=%s, destination=%s"
-msgstr "%s, обект: „%s“, цел: „%s“"
+msgid ""
+"expected edge object ID, got garbage:\n"
+" %s"
+msgstr ""
+"очаква се идентификатор на краен обект, а не:\n"
+" %s"
 
-#: builtin/mv.c:270
+#: builtin/pack-objects.c:2748
 #, c-format
-msgid "Renaming %s to %s\n"
-msgstr "Преименуване на „%s“ на „%s“\n"
+msgid ""
+"expected object ID, got garbage:\n"
+" %s"
+msgstr ""
+"очаква се идентификатор на обект, а не:\n"
+" %s"
+
+#: builtin/pack-objects.c:2846
+msgid "invalid value for --missing"
+msgstr "неправилна стойност за „--missing“"
+
+#: builtin/pack-objects.c:2905 builtin/pack-objects.c:3013
+msgid "cannot open pack index"
+msgstr "индексът на пакетния файл не може да бъде отворен"
 
-#: builtin/mv.c:276 builtin/remote.c:715 builtin/repack.c:409
+#: builtin/pack-objects.c:2936
 #, c-format
-msgid "renaming '%s' failed"
-msgstr "неуспешно преименуване на „%s“"
+msgid "loose object at %s could not be examined"
+msgstr "непакетираният обект в „%s“ не може да бъде анализиран"
 
-#: builtin/name-rev.c:338
-msgid "git name-rev [<options>] <commit>..."
-msgstr "git name-rev [ОПЦИЯ…] ПОДАВАНЕ…"
+#: builtin/pack-objects.c:3021
+msgid "unable to force loose object"
+msgstr "оставането на обекта непакетиран не може да бъде наложено"
 
-#: builtin/name-rev.c:339
-msgid "git name-rev [<options>] --all"
-msgstr "git name-rev [ОПЦИЯ…] --all"
+#: builtin/pack-objects.c:3113
+#, c-format
+msgid "not a rev '%s'"
+msgstr "„%s“ не е версия"
 
-#: builtin/name-rev.c:340
-msgid "git name-rev [<options>] --stdin"
-msgstr "git name-rev [ОПЦИЯ…] --stdin"
+#: builtin/pack-objects.c:3116
+#, c-format
+msgid "bad revision '%s'"
+msgstr "неправилна версия „%s“"
 
-#: builtin/name-rev.c:395
-msgid "print only names (no SHA-1)"
-msgstr "извеждане само на имената (без сумите по SHA1)"
+#: builtin/pack-objects.c:3141
+msgid "unable to add recent objects"
+msgstr "скорошните обекти не могат да бъдат добавени"
 
-#: builtin/name-rev.c:396
-msgid "only use tags to name the commits"
-msgstr "използване само на етикетите за именуване на подаванията"
+#: builtin/pack-objects.c:3194
+#, c-format
+msgid "unsupported index version %s"
+msgstr "неподдържана версия на индекса „%s“"
 
-#: builtin/name-rev.c:398
-msgid "only use refs matching <pattern>"
-msgstr "използване само на указателите напасващи на ШАБЛОНа"
+#: builtin/pack-objects.c:3198
+#, c-format
+msgid "bad index version '%s'"
+msgstr "неправилна версия на индекса „%s“"
 
-#: builtin/name-rev.c:400
-msgid "ignore refs matching <pattern>"
-msgstr "игнориране на указателите напасващи на ШАБЛОНа"
+#: builtin/pack-objects.c:3236
+msgid "<version>[,<offset>]"
+msgstr "ВЕРСИЯ[,ОТМЕСТВАНЕ]"
 
-#: builtin/name-rev.c:402
-msgid "list all commits reachable from all refs"
+#: builtin/pack-objects.c:3237
+msgid "write the pack index file in the specified idx format version"
 msgstr ""
-"извеждане на всички подавания, които могат да бъдат достигнати от всички "
-"указатели"
+"запазване на индекса на пакетните файлове във форма̀та с указаната версия"
 
-#: builtin/name-rev.c:403
-msgid "read from stdin"
-msgstr "четене от стандартния вход"
+#: builtin/pack-objects.c:3240
+msgid "maximum size of each output pack file"
+msgstr "максимален размер на всеки пакетен файл"
 
-#: builtin/name-rev.c:404
-msgid "allow to print `undefined` names (default)"
-msgstr "да се извеждат и недефинираните имена (стандартна стойност на опцията)"
+#: builtin/pack-objects.c:3242
+msgid "ignore borrowed objects from alternate object store"
+msgstr "игнориране на обектите заети от други хранилища на обекти"
 
-#: builtin/name-rev.c:410
-msgid "dereference tags in the input (internal use)"
-msgstr "извеждане на идентификаторите на обекти-етикети (за вътрешни нужди)"
+#: builtin/pack-objects.c:3244
+msgid "ignore packed objects"
+msgstr "игнориране на пакетираните обекти"
 
-#: builtin/notes.c:26
-msgid "git notes [--ref <notes-ref>] [list [<object>]]"
-msgstr "git notes [--ref УКАЗАТЕЛ_ЗА_БЕЛЕЖКА] [list [ОБЕКТ]]"
+#: builtin/pack-objects.c:3246
+msgid "limit pack window by objects"
+msgstr "ограничаване на прозореца за пакетиране по брой обекти"
 
-#: builtin/notes.c:27
-msgid ""
-"git notes [--ref <notes-ref>] add [-f] [--allow-empty] [-m <msg> | -F <file> "
-"| (-c | -C) <object>] [<object>]"
+#: builtin/pack-objects.c:3248
+msgid "limit pack window by memory in addition to object limit"
 msgstr ""
-"git notes [--ref УКАЗАТЕЛ_ЗА_БЕЛЕЖКА] add [-f] [--allow-empty] [-m СЪОБЩЕНИЕ "
-"| -F ФАЙЛ | (-c | -C) ОБЕКТ] [ОБЕКТ]"
+"ограничаване на прозореца за пакетиране и по памет освен по брой обекти"
 
-#: builtin/notes.c:28
-msgid "git notes [--ref <notes-ref>] copy [-f] <from-object> <to-object>"
+#: builtin/pack-objects.c:3250
+msgid "maximum length of delta chain allowed in the resulting pack"
 msgstr ""
-"git notes [--ref УКАЗАТЕЛ_ЗА_БЕЛЕЖКА] copy [-f] ОБЕКТ_ИЗТОЧНИК ОБЕКТ_ЦЕЛ"
+"максимална дължина на веригата от разлики, която е позволена в пакетния файл"
 
-#: builtin/notes.c:29
-msgid ""
-"git notes [--ref <notes-ref>] append [--allow-empty] [-m <msg> | -F <file> | "
-"(-c | -C) <object>] [<object>]"
-msgstr ""
-"git notes [--ref УКАЗАТЕЛ_ЗА_БЕЛЕЖКА] append [--allow-empty] [-m СЪОБЩЕНИЕ | "
-"-F ФАЙЛ | (-c | -C) ОБЕКТ] [ОБЕКТ]"
+#: builtin/pack-objects.c:3252
+msgid "reuse existing deltas"
+msgstr "преизползване на съществуващите разлики"
 
-#: builtin/notes.c:30
-msgid "git notes [--ref <notes-ref>] edit [--allow-empty] [<object>]"
-msgstr "git notes [--ref УКАЗАТЕЛ_ЗА_БЕЛЕЖКА] edit [--allow-empty] [ОБЕКТ]"
+#: builtin/pack-objects.c:3254
+msgid "reuse existing objects"
+msgstr "преизползване на съществуващите обекти"
 
-#: builtin/notes.c:31
-msgid "git notes [--ref <notes-ref>] show [<object>]"
-msgstr "git notes [--ref УКАЗАТЕЛ_ЗА_БЕЛЕЖКА] show [ОБЕКТ]"
+#: builtin/pack-objects.c:3256
+msgid "use OFS_DELTA objects"
+msgstr "използване на обекти „OFS_DELTA“"
 
-#: builtin/notes.c:32
-msgid ""
-"git notes [--ref <notes-ref>] merge [-v | -q] [-s <strategy>] <notes-ref>"
+#: builtin/pack-objects.c:3258
+msgid "use threads when searching for best delta matches"
 msgstr ""
-"git notes [--ref УКАЗАТЕЛ_ЗА_БЕЛЕЖКА] merge [-v | -q] [-s СТРАТЕГИЯ] "
-"УКАЗАТЕЛ_ЗА_БЕЛЕЖКА"
-
-#: builtin/notes.c:33
-msgid "git notes merge --commit [-v | -q]"
-msgstr "git notes merge --commit [-v | -q]"
+"стартиране на нишки за претърсване на най-добрите съвпадения на разликите"
 
-#: builtin/notes.c:34
-msgid "git notes merge --abort [-v | -q]"
-msgstr "git notes merge --abort [-v | -q]"
+#: builtin/pack-objects.c:3260
+msgid "do not create an empty pack output"
+msgstr "без създаване на празен пакетен файл"
 
-#: builtin/notes.c:35
-msgid "git notes [--ref <notes-ref>] remove [<object>...]"
-msgstr "git notes [--ref УКАЗАТЕЛ_ЗА_БЕЛЕЖКА] remove [ОБЕКТ…]"
+#: builtin/pack-objects.c:3262
+msgid "read revision arguments from standard input"
+msgstr "изчитане на версиите от стандартния вход"
 
-#: builtin/notes.c:36
-msgid "git notes [--ref <notes-ref>] prune [-n] [-v]"
-msgstr "git notes [--ref УКАЗАТЕЛ_ЗА_БЕЛЕЖКА] prune [-n] [-v]"
+#: builtin/pack-objects.c:3264
+msgid "limit the objects to those that are not yet packed"
+msgstr "ограничаване до все още непакетираните обекти"
 
-#: builtin/notes.c:37
-msgid "git notes [--ref <notes-ref>] get-ref"
-msgstr "git notes [--ref УКАЗАТЕЛ_ЗА_БЕЛЕЖКА] get-ref"
+#: builtin/pack-objects.c:3267
+msgid "include objects reachable from any reference"
+msgstr ""
+"включване на всички обекти, които могат да се достигнат от произволен "
+"указател"
 
-#: builtin/notes.c:42
-msgid "git notes [list [<object>]]"
-msgstr "git notes [list [ОБЕКТ]]"
+#: builtin/pack-objects.c:3270
+msgid "include objects referred by reflog entries"
+msgstr "включване и на обектите сочени от записите в журнала на указателите"
 
-#: builtin/notes.c:47
-msgid "git notes add [<options>] [<object>]"
-msgstr "git notes add [ОПЦИЯ…] [ОБЕКТ]"
+#: builtin/pack-objects.c:3273
+msgid "include objects referred to by the index"
+msgstr "включване и на обектите сочени от индекса"
 
-#: builtin/notes.c:52
-msgid "git notes copy [<options>] <from-object> <to-object>"
-msgstr "git notes copy [ОПЦИЯ…] ОБЕКТ_ИЗТОЧНИК ОБЕКТ_ЦЕЛ"
+#: builtin/pack-objects.c:3276
+msgid "output pack to stdout"
+msgstr "извеждане на пакета на стандартния изход"
 
-#: builtin/notes.c:53
-msgid "git notes copy --stdin [<from-object> <to-object>]..."
-msgstr "git notes copy --stdin [ОБЕКТ_ИЗТОЧНИК ОБЕКТ_ЦЕЛ…]"
+#: builtin/pack-objects.c:3278
+msgid "include tag objects that refer to objects to be packed"
+msgstr ""
+"включване и на обектите-етикети, които сочат към обектите, които ще бъдат "
+"пакетирани"
 
-#: builtin/notes.c:58
-msgid "git notes append [<options>] [<object>]"
-msgstr "git notes append [ОПЦИЯ…] [ОБЕКТ]"
+#: builtin/pack-objects.c:3280
+msgid "keep unreachable objects"
+msgstr "запазване на недостижимите обекти"
 
-#: builtin/notes.c:63
-msgid "git notes edit [<object>]"
-msgstr "git notes edit [ОБЕКТ]"
+#: builtin/pack-objects.c:3282
+msgid "pack loose unreachable objects"
+msgstr "пакетиране и на недостижимите обекти"
 
-#: builtin/notes.c:68
-msgid "git notes show [<object>]"
-msgstr "git notes show [ОБЕКТ]"
+#: builtin/pack-objects.c:3284
+msgid "unpack unreachable objects newer than <time>"
+msgstr "разпакетиране на недостижимите обекти, които са по-нови от това ВРЕМЕ"
 
-#: builtin/notes.c:73
-msgid "git notes merge [<options>] <notes-ref>"
-msgstr "git notes merge [ОПЦИЯ…] УКАЗАТЕЛ_ЗА_БЕЛЕЖКА"
+#: builtin/pack-objects.c:3287
+msgid "use the sparse reachability algorithm"
+msgstr "използване на алгоритъм за частична достижимост"
 
-#: builtin/notes.c:74
-msgid "git notes merge --commit [<options>]"
-msgstr "git notes merge --commit [ОПЦИЯ…]"
+#: builtin/pack-objects.c:3289
+msgid "create thin packs"
+msgstr "създаване на съкратени пакети"
 
-#: builtin/notes.c:75
-msgid "git notes merge --abort [<options>]"
-msgstr "git notes merge --abort [ОПЦИЯ…]"
+#: builtin/pack-objects.c:3291
+msgid "create packs suitable for shallow fetches"
+msgstr "пакетиране подходящо за плитко доставяне"
 
-#: builtin/notes.c:80
-msgid "git notes remove [<object>]"
-msgstr "git notes remove [ОБЕКТ]"
+#: builtin/pack-objects.c:3293
+msgid "ignore packs that have companion .keep file"
+msgstr "игнориране на пакетите, които са придружени от файл „.keep“"
 
-#: builtin/notes.c:85
-msgid "git notes prune [<options>]"
-msgstr "git notes prune [ОПЦИЯ…]"
+#: builtin/pack-objects.c:3295
+msgid "ignore this pack"
+msgstr "пропускане на този пакет"
 
-#: builtin/notes.c:90
-msgid "git notes get-ref"
-msgstr "git notes get-ref"
+#: builtin/pack-objects.c:3297
+msgid "pack compression level"
+msgstr "ниво на компресиране при пакетиране"
 
-#: builtin/notes.c:95
-msgid "Write/edit the notes for the following object:"
-msgstr "Записване/редактиране на бележките за следния обект:"
+#: builtin/pack-objects.c:3299
+msgid "do not hide commits by grafts"
+msgstr ""
+"извеждане на всички родители — дори и тези, които нормално са скрити при "
+"присажданията"
 
-#: builtin/notes.c:148
-#, c-format
-msgid "unable to start 'show' for object '%s'"
-msgstr "действието „show“ не може да се изпълни за обект „%s“"
+#: builtin/pack-objects.c:3301
+msgid "use a bitmap index if available to speed up counting objects"
+msgstr ""
+"използване на съществуващи индекси на база битови маски за ускоряване на "
+"преброяването на обектите"
 
-#: builtin/notes.c:152
-msgid "could not read 'show' output"
-msgstr "изведената информация от действието „show“ не може да се прочете"
+#: builtin/pack-objects.c:3303
+msgid "write a bitmap index together with the pack index"
+msgstr ""
+"запазване и на индекс на база побитова маска, заедно с индекса за пакета"
 
-#: builtin/notes.c:160
-#, c-format
-msgid "failed to finish 'show' for object '%s'"
-msgstr "действието „show“ не може да се завърши за обект „%s“"
+#: builtin/pack-objects.c:3307
+msgid "write a bitmap index if possible"
+msgstr "записване на индекси на база битови маски при възможност"
 
-#: builtin/notes.c:195
-msgid "please supply the note contents using either -m or -F option"
-msgstr "задайте съдържанието на бележката с някоя от опциите „-m“ или „-F“"
+#: builtin/pack-objects.c:3311
+msgid "handling for missing objects"
+msgstr "как да се обработват липсващите обекти"
 
-#: builtin/notes.c:204
-msgid "unable to write note object"
-msgstr "обектът-бележка не може да бъде записан"
+#: builtin/pack-objects.c:3314
+msgid "do not pack objects in promisor packfiles"
+msgstr "без пакетиране на обекти в гарантиращи пакети"
 
-#: builtin/notes.c:206
-#, c-format
-msgid "the note contents have been left in %s"
-msgstr "съдържанието на бележката е във файла „%s“"
+#: builtin/pack-objects.c:3316
+msgid "respect islands during delta compression"
+msgstr "без промяна на групите при делта компресия"
 
-#: builtin/notes.c:234 builtin/tag.c:507
+#: builtin/pack-objects.c:3345
 #, c-format
-msgid "cannot read '%s'"
-msgstr "файлът „%s“ не може да бъде прочетен"
+msgid "delta chain depth %d is too deep, forcing %d"
+msgstr "веригата с разлики е прекалено дълбока — %d, ще се ползва %d"
 
-#: builtin/notes.c:236 builtin/tag.c:510
+#: builtin/pack-objects.c:3350
 #, c-format
-msgid "could not open or read '%s'"
-msgstr "файлът „%s“ не може да бъде отворен или прочетен"
+msgid "pack.deltaCacheLimit is too high, forcing %d"
+msgstr ""
+"Стойността на настройката „pack.deltaCacheLimit“ е прекалено голяма.  Ще се "
+"ползва %d"
 
-#: builtin/notes.c:255 builtin/notes.c:306 builtin/notes.c:308
-#: builtin/notes.c:376 builtin/notes.c:431 builtin/notes.c:517
-#: builtin/notes.c:522 builtin/notes.c:600 builtin/notes.c:662
-#, c-format
-msgid "failed to resolve '%s' as a valid ref."
-msgstr "не може да се открие към какво сочи „%s“."
+#: builtin/pack-objects.c:3404
+msgid "--max-pack-size cannot be used to build a pack for transfer"
+msgstr ""
+"опцията „--max-pack-size“ не може да се използва за създаване на пакетни "
+"файлове за пренос"
 
-#: builtin/notes.c:258
-#, c-format
-msgid "failed to read object '%s'."
-msgstr "обектът „%s“ не може да бъде прочетен."
+#: builtin/pack-objects.c:3406
+msgid "minimum pack size limit is 1 MiB"
+msgstr "минималният размер на пакетите е 1 MiB"
 
-#: builtin/notes.c:262
-#, c-format
-msgid "cannot read note data from non-blob object '%s'."
+#: builtin/pack-objects.c:3411
+msgid "--thin cannot be used to build an indexable pack"
 msgstr ""
-"съдържанието на бележка не може да се вземе от обект, който не е BLOB: „%s“."
+"опцията „--thin“не може да се използва за създаване на пакетни файлове с "
+"индекс"
 
-#: builtin/notes.c:302
-#, c-format
-msgid "malformed input line: '%s'."
-msgstr "входен ред с неправилен формат: „%s“."
+#: builtin/pack-objects.c:3414
+msgid "--keep-unreachable and --unpack-unreachable are incompatible"
+msgstr "опциите „--keep-unreachable“ и „--unpack-unreachable“ са несъвместими"
 
-#: builtin/notes.c:317
-#, c-format
-msgid "failed to copy notes from '%s' to '%s'"
-msgstr "бележката не може да се копира от „%s“ към „%s“"
+#: builtin/pack-objects.c:3420
+msgid "cannot use --filter without --stdout"
+msgstr "опцията „-filter“ изисква „-stdout“"
 
-#. TRANSLATORS: the first %s will be replaced by a git
-#. notes command: 'add', 'merge', 'remove', etc.
-#.
-#: builtin/notes.c:349
+#: builtin/pack-objects.c:3481
+msgid "Enumerating objects"
+msgstr "Изброяване на обектите"
+
+#: builtin/pack-objects.c:3511
 #, c-format
-msgid "refusing to %s notes in %s (outside of refs/notes/)"
+msgid "Total %<PRIu32> (delta %<PRIu32>), reused %<PRIu32> (delta %<PRIu32>)"
 msgstr ""
-"няма да се извърши „%s“ върху бележките в „%s“, защото са извън „refs/"
-"notes/“."
+"Общо %<PRIu32> (разлики %<PRIu32>), преизползвани %<PRIu32> (разлики "
+"%<PRIu32>)"
 
-#: builtin/notes.c:369 builtin/notes.c:424 builtin/notes.c:500
-#: builtin/notes.c:512 builtin/notes.c:588 builtin/notes.c:655
-#: builtin/notes.c:805 builtin/notes.c:952 builtin/notes.c:973
-msgid "too many parameters"
-msgstr "прекалено много параметри"
+#: builtin/pack-refs.c:8
+msgid "git pack-refs [<options>]"
+msgstr "git pack-refs [ОПЦИЯ…]"
+
+#: builtin/pack-refs.c:16
+msgid "pack everything"
+msgstr "пакетиране на всичко"
+
+#: builtin/pack-refs.c:17
+msgid "prune loose refs (default)"
+msgstr "окастряне на недостижимите указатели (стандартно)"
+
+#: builtin/prune-packed.c:9
+msgid "git prune-packed [-n | --dry-run] [-q | --quiet]"
+msgstr "git prune-packed [-n | --dry-run] [-q | --quiet]"
+
+#: builtin/prune-packed.c:42
+msgid "Removing duplicate objects"
+msgstr "Изтриване на повтарящите се обекти"
+
+#: builtin/prune.c:12
+msgid "git prune [-n] [-v] [--progress] [--expire <time>] [--] [<head>...]"
+msgstr "git prune [-n] [-v] [--progress] [--expire ВРЕМЕ] [--] [ВРЪХ…]"
+
+#: builtin/prune.c:131
+msgid "report pruned objects"
+msgstr "информация за окастрените обекти"
+
+#: builtin/prune.c:134
+msgid "expire objects older than <time>"
+msgstr "окастряне на обектите по-стари от това ВРЕМЕ"
+
+#: builtin/prune.c:136
+msgid "limit traversal to objects outside promisor packfiles"
+msgstr "ограничаване на обхождането до обекти извън гарантиращи пакети"
+
+#: builtin/prune.c:150
+msgid "cannot prune in a precious-objects repo"
+msgstr "хранилище с важни обекти не може да се окастря"
+
+#: builtin/pull.c:66 builtin/pull.c:68
+#, c-format
+msgid "Invalid value for %s: %s"
+msgstr "Неправилна стойност за „%s“: „%s“"
 
-#: builtin/notes.c:382 builtin/notes.c:668
-#, c-format
-msgid "no note found for object %s."
-msgstr "няма бележки за обекта „%s“."
+#: builtin/pull.c:88
+msgid "git pull [<options>] [<repository> [<refspec>...]]"
+msgstr "git push [ОПЦИЯ…] [ХРАНИЛИЩЕ [УКАЗАТЕЛ_НА_ВЕРСИЯ…]]"
 
-#: builtin/notes.c:403 builtin/notes.c:566
-msgid "note contents as a string"
-msgstr "низ, който е съдържанието на бележката"
+#: builtin/pull.c:142
+msgid "control for recursive fetching of submodules"
+msgstr "управление на рекурсивното доставяне на подмодулите"
 
-#: builtin/notes.c:406 builtin/notes.c:569
-msgid "note contents in a file"
-msgstr "ФАЙЛ със съдържанието на бележката"
+#: builtin/pull.c:146
+msgid "Options related to merging"
+msgstr "Опции при сливане"
 
-#: builtin/notes.c:409 builtin/notes.c:572
-msgid "reuse and edit specified note object"
-msgstr "преизползване и редактиране на указания ОБЕКТ-бележка"
+#: builtin/pull.c:149
+msgid "incorporate changes by rebasing rather than merging"
+msgstr "внасяне на промените чрез пребазиране, а не чрез сливане"
 
-#: builtin/notes.c:412 builtin/notes.c:575
-msgid "reuse specified note object"
-msgstr "преизползване на указания ОБЕКТ-бележка"
+#: builtin/pull.c:177 builtin/rebase.c:467 builtin/revert.c:126
+msgid "allow fast-forward"
+msgstr "позволяване на превъртания"
 
-#: builtin/notes.c:415 builtin/notes.c:578
-msgid "allow storing empty note"
-msgstr "приемане и на празни бележки"
+#: builtin/pull.c:186
+msgid "automatically stash/stash pop before and after rebase"
+msgstr "автоматично скатаване/прилагане на скатаното преди и след пребазиране"
 
-#: builtin/notes.c:416 builtin/notes.c:487
-msgid "replace existing notes"
-msgstr "замяна на съществуващите бележки"
+#: builtin/pull.c:202
+msgid "Options related to fetching"
+msgstr "Опции при доставяне"
 
-#: builtin/notes.c:441
-#, c-format
-msgid ""
-"Cannot add notes. Found existing notes for object %s. Use '-f' to overwrite "
-"existing notes"
-msgstr ""
-"Не може да се добави бележка, защото такава вече съществува за обекта „%s“.  "
-"Използвайте опцията „-f“, за да презапишете съществуващи бележки."
+#: builtin/pull.c:212
+msgid "force overwrite of local branch"
+msgstr "принудително презаписване на локалния клон"
 
-#: builtin/notes.c:456 builtin/notes.c:535
-#, c-format
-msgid "Overwriting existing notes for object %s\n"
-msgstr "Презаписване на съществуващите бележки за обекта „%s“\n"
+#: builtin/pull.c:220
+msgid "number of submodules pulled in parallel"
+msgstr "брой подмодули издърпани паралелно"
 
-#: builtin/notes.c:467 builtin/notes.c:627 builtin/notes.c:892
+#: builtin/pull.c:320
 #, c-format
-msgid "Removing note for object %s\n"
-msgstr "Изтриване на бележката за обекта „%s“\n"
-
-#: builtin/notes.c:488
-msgid "read objects from stdin"
-msgstr "изчитане на обектите от стандартния вход"
+msgid "Invalid value for pull.ff: %s"
+msgstr "Неправилна стойност за „pull.ff“: „%s“"
 
-#: builtin/notes.c:490
-msgid "load rewriting config for <command> (implies --stdin)"
+#: builtin/pull.c:437
+msgid ""
+"There is no candidate for rebasing against among the refs that you just "
+"fetched."
 msgstr ""
-"зареждане на настройките за КОМАНДАта, която презаписва подавания (включва "
-"опцията „--stdin“)"
-
-#: builtin/notes.c:508
-msgid "too few parameters"
-msgstr "прекалено малко параметри"
+"Между указателите, които току що доставихте, няма подходящ кандидат, върху "
+"който да пребазирате."
 
-#: builtin/notes.c:529
-#, c-format
+#: builtin/pull.c:439
 msgid ""
-"Cannot copy notes. Found existing notes for object %s. Use '-f' to overwrite "
-"existing notes"
+"There are no candidates for merging among the refs that you just fetched."
 msgstr ""
-"Не може да се копира бележка, защото такава вече съществува за обекта „%s“.  "
-"Използвайте опцията „-f“, за да презапишете съществуващи бележки."
+"Между указателите, които току що доставихте, няма подходящ кандидат, който "
+"да слеете."
 
-#: builtin/notes.c:541
-#, c-format
-msgid "missing notes on source object %s. Cannot copy."
-msgstr "няма бележки за обекта-източник „%s“.  Не може да се копира."
+#: builtin/pull.c:440
+msgid ""
+"Generally this means that you provided a wildcard refspec which had no\n"
+"matches on the remote end."
+msgstr ""
+"Най вероятно сте подали шаблон за указатели, който не е напаснал с нищо в "
+"отдалеченото хранилище."
 
-#: builtin/notes.c:593
+#: builtin/pull.c:443
 #, c-format
 msgid ""
-"The -m/-F/-c/-C options have been deprecated for the 'edit' subcommand.\n"
-"Please use 'git notes add -f -m/-F/-c/-C' instead.\n"
+"You asked to pull from the remote '%s', but did not specify\n"
+"a branch. Because this is not the default configured remote\n"
+"for your current branch, you must specify a branch on the command line."
 msgstr ""
-"Задаването на опциите „-m“/„-F“/„-c“/„-C“ с командата „edit“ вече е "
-"остаряло.\n"
-"Вместо това ги използвайте с подкомандата „add“: „git notes add -f -m/-F/-c/-"
-"C“.\n"
+"Заявихте издърпване от отдалеченото хранилище „%s“, но не указахте клон.\n"
+"Понеже това не е хранилището по подразбиране на текущия клон, трябва\n"
+"да укажете отдалечения клон на командния ред."
 
-#: builtin/notes.c:688
-msgid "failed to delete ref NOTES_MERGE_PARTIAL"
-msgstr "указателят „NOTES_MERGE_PARTIAL“ не може да бъде изтрит"
+#: builtin/pull.c:448 builtin/rebase.c:1375 git-parse-remote.sh:73
+msgid "You are not currently on a branch."
+msgstr "Извън всички клони."
 
-#: builtin/notes.c:690
-msgid "failed to delete ref NOTES_MERGE_REF"
-msgstr "указателят „NOTES_MERGE_REF“ не може да бъде изтрит"
+#: builtin/pull.c:450 builtin/pull.c:465 git-parse-remote.sh:79
+msgid "Please specify which branch you want to rebase against."
+msgstr "Укажете върху кой клон искате да пребазирате."
 
-#: builtin/notes.c:692
-msgid "failed to remove 'git notes merge' worktree"
-msgstr "работната директория на „git notes merge“ не може да бъде изтрита"
+#: builtin/pull.c:452 builtin/pull.c:467 git-parse-remote.sh:82
+msgid "Please specify which branch you want to merge with."
+msgstr "Укажете кой клон искате да слеете."
 
-#: builtin/notes.c:712
-msgid "failed to read ref NOTES_MERGE_PARTIAL"
-msgstr "указателят „NOTES_MERGE_PARTIAL“ не може да бъде прочетен"
+#: builtin/pull.c:453 builtin/pull.c:468
+msgid "See git-pull(1) for details."
+msgstr "За повече информация погледнете ръководството „git-pull(1)“"
 
-#: builtin/notes.c:714
-msgid "could not find commit from NOTES_MERGE_PARTIAL."
-msgstr "подаването от „NOTES_MERGE_PARTIAL“ не може да се открие."
+#: builtin/pull.c:455 builtin/pull.c:461 builtin/pull.c:470
+#: builtin/rebase.c:1381 git-parse-remote.sh:64
+msgid "<remote>"
+msgstr "ОТДАЛЕЧЕНО_ХРАНИЛИЩЕ"
 
-#: builtin/notes.c:716
-msgid "could not parse commit from NOTES_MERGE_PARTIAL."
-msgstr "подаването от „NOTES_MERGE_PARTIAL“ не може да се анализира."
+#: builtin/pull.c:455 builtin/pull.c:470 builtin/pull.c:475
+#: git-parse-remote.sh:65
+msgid "<branch>"
+msgstr "КЛОН"
 
-#: builtin/notes.c:729
-msgid "failed to resolve NOTES_MERGE_REF"
-msgstr "не може да се открие към какво сочи „NOTES_MERGE_REF“"
+#: builtin/pull.c:463 builtin/rebase.c:1373 git-parse-remote.sh:75
+msgid "There is no tracking information for the current branch."
+msgstr "Текущият клон не следи никой."
 
-#: builtin/notes.c:732
-msgid "failed to finalize notes merge"
-msgstr "неуспешно сливане на бележките"
+#: builtin/pull.c:472 git-parse-remote.sh:95
+msgid ""
+"If you wish to set tracking information for this branch you can do so with:"
+msgstr ""
+"Ако искате да зададете информация за следен клон, можете да направите това с "
+"командата:"
 
-#: builtin/notes.c:758
+#: builtin/pull.c:477
 #, c-format
-msgid "unknown notes merge strategy %s"
-msgstr "непозната стратегия за сливане на бележки „%s“"
-
-#: builtin/notes.c:774
-msgid "General options"
-msgstr "Общи опции"
-
-#: builtin/notes.c:776
-msgid "Merge options"
-msgstr "Опции при сливане"
-
-#: builtin/notes.c:778
 msgid ""
-"resolve notes conflicts using the given strategy (manual/ours/theirs/union/"
-"cat_sort_uniq)"
+"Your configuration specifies to merge with the ref '%s'\n"
+"from the remote, but no such ref was fetched."
 msgstr ""
-"коригиране на конфликтите при сливане на бележките чрез тази СТРАТЕГИЯ — "
-"„manual“ (ръчно), „ours“ (вашата версия), „theirs“ (чуждата версия), "
-"„union“ (обединяване), „cat_sort_uniq“ (обединяване, подреждане, уникални "
-"резултати)"
-
-#: builtin/notes.c:780
-msgid "Committing unmerged notes"
-msgstr "Подаване на неслети бележки"
-
-#: builtin/notes.c:782
-msgid "finalize notes merge by committing unmerged notes"
-msgstr "завършване на сливането чрез подаване на неслети бележки"
+"За сливане е указан отдалеченият указател „%s“,\n"
+"но такъв не е доставен."
 
-#: builtin/notes.c:784
-msgid "Aborting notes merge resolution"
-msgstr "Преустановяване на корекцията при сливането на бележки"
+#: builtin/pull.c:587
+#, c-format
+msgid "unable to access commit %s"
+msgstr "недостъпно подаване: %s"
 
-#: builtin/notes.c:786
-msgid "abort notes merge"
-msgstr "преустановяване на сливането на бележки"
+#: builtin/pull.c:867
+msgid "ignoring --verify-signatures for rebase"
+msgstr "без „--verify-signatures“ при пребазиране"
 
-#: builtin/notes.c:797
-msgid "cannot mix --commit, --abort or -s/--strategy"
-msgstr "опциите „--commit“, „--abort“ и „-s“/„--strategy“ са несъвместими"
+#: builtin/pull.c:922
+msgid "--[no-]autostash option is only valid with --rebase."
+msgstr "опцията „--[no-]autostash“ изисква „--rebase“"
 
-#: builtin/notes.c:802
-msgid "must specify a notes ref to merge"
-msgstr "трябва да укажете указател към бележка за сливане."
+#: builtin/pull.c:930
+msgid "Updating an unborn branch with changes added to the index."
+msgstr "Обновяване на все още несъздаден клон с промените от индекса"
 
-#: builtin/notes.c:826
-#, c-format
-msgid "unknown -s/--strategy: %s"
-msgstr "неизвестна стратегия към опцията „-s“/„--strategy“: „%s“"
+#: builtin/pull.c:934
+msgid "pull with rebase"
+msgstr "издърпване с пребазиране"
 
-#: builtin/notes.c:863
-#, c-format
-msgid "a notes merge into %s is already in-progress at %s"
-msgstr "в момента се извършва сливане на бележките в „%s“ при „%s“"
+#: builtin/pull.c:935
+msgid "please commit or stash them."
+msgstr "трябва да подадете или скатаете промените."
 
-#: builtin/notes.c:866
+#: builtin/pull.c:960
 #, c-format
-msgid "failed to store link to current notes ref (%s)"
-msgstr "не може да се запази връзка към указателя на текущата бележка („%s“)."
+msgid ""
+"fetch updated the current branch head.\n"
+"fast-forwarding your working tree from\n"
+"commit %s."
+msgstr ""
+"доставянето обнови върха на текущия клон.  Работното\n"
+"ви копие бе превъртяно от подаване „%s“."
 
-#: builtin/notes.c:868
+#: builtin/pull.c:966
 #, c-format
 msgid ""
-"Automatic notes merge failed. Fix conflicts in %s and commit the result with "
-"'git notes merge --commit', or abort the merge with 'git notes merge --"
-"abort'.\n"
+"Cannot fast-forward your working tree.\n"
+"After making sure that you saved anything precious from\n"
+"$ git diff %s\n"
+"output, run\n"
+"$ git reset --hard\n"
+"to recover."
 msgstr ""
-"Неуспешно сливане на бележките.  Разрешете конфликтите в „%s“ и подайте "
-"резултата с „git notes merge --commit“ или преустановете сливането с "
-"командата „git notes merge --abort“.\n"
+"Работното ви копие не може да бъде превъртяно.\n"
+"След като запазите всичко необходимо посочено от командата:\n"
+"    git diff %s\n"
+"изпълнете:\n"
+"    git reset --hard\n"
+"за връщане към нормално състояние."
 
-#: builtin/notes.c:890
-#, c-format
-msgid "Object %s has no note\n"
-msgstr "Няма бележки за обекта „%s“\n"
+#: builtin/pull.c:981
+msgid "Cannot merge multiple branches into empty head."
+msgstr "Не може да сливате множество клони в празен върхов указател."
 
-#: builtin/notes.c:902
-msgid "attempt to remove non-existent note is not an error"
-msgstr "опитът за изтриването на несъществуваща бележка не се счита за грешка"
+#: builtin/pull.c:985
+msgid "Cannot rebase onto multiple branches."
+msgstr "Не може да пребазирате върху повече от един клон."
 
-#: builtin/notes.c:905
-msgid "read object names from the standard input"
-msgstr "изчитане на имената на обектите от стандартния вход"
+#: builtin/pull.c:992
+msgid "cannot rebase with locally recorded submodule modifications"
+msgstr ""
+"пребазирането е невъзможно заради локално записаните промени по подмодулите"
 
-#: builtin/notes.c:943 builtin/prune.c:107 builtin/worktree.c:151
-msgid "do not remove, show only"
-msgstr "само извеждане без действително окастряне"
+#: builtin/push.c:19
+msgid "git push [<options>] [<repository> [<refspec>...]]"
+msgstr "git push [ОПЦИЯ…] [ХРАНИЛИЩЕ [УКАЗАТЕЛ_НА_ВЕРСИЯ…]]"
 
-#: builtin/notes.c:944
-msgid "report pruned notes"
-msgstr "докладване на окастрените обекти"
+#: builtin/push.c:112
+msgid "tag shorthand without <tag>"
+msgstr "съкращение за етикет без ЕТИКЕТ"
 
-#: builtin/notes.c:986
-msgid "notes-ref"
-msgstr "УКАЗАТЕЛ_ЗА_БЕЛЕЖКА"
+#: builtin/push.c:122
+msgid "--delete only accepts plain target ref names"
+msgstr "опцията „--delete“ приема за цел само прости имена на указатели"
 
-#: builtin/notes.c:987
-msgid "use notes from <notes-ref>"
-msgstr "да се използва бележката сочена от този УКАЗАТЕЛ_ЗА_БЕЛЕЖКА"
+#: builtin/push.c:168
+msgid ""
+"\n"
+"To choose either option permanently, see push.default in 'git help config'."
+msgstr ""
+"\n"
+"За да включите тази опция за постоянно, погледнете документацията за "
+"настройката „push.default“ в „git help config“."
+
+#: builtin/push.c:171
+#, c-format
+msgid ""
+"The upstream branch of your current branch does not match\n"
+"the name of your current branch.  To push to the upstream branch\n"
+"on the remote, use\n"
+"\n"
+"    git push %s HEAD:%s\n"
+"\n"
+"To push to the branch of the same name on the remote, use\n"
+"\n"
+"    git push %s HEAD\n"
+"%s"
+msgstr ""
+"Името на текущия клон се различава от името на клона, който той следи.\n"
+"За да изтласкате към следения клон използвайте командата:\n"
+"\n"
+"    git push %s HEAD:%s\n"
+"\n"
+"За да изтласкате към отдалечения клон с име като локалния, използвайте "
+"командата:\n"
+"\n"
+"    git push %s HEAD\n"
+"%s"
 
-#: builtin/notes.c:1022
+#: builtin/push.c:186
 #, c-format
-msgid "unknown subcommand: %s"
-msgstr "непозната подкоманда: %s"
-
-#: builtin/pack-objects.c:48
 msgid ""
-"git pack-objects --stdout [<options>...] [< <ref-list> | < <object-list>]"
+"You are not currently on a branch.\n"
+"To push the history leading to the current (detached HEAD)\n"
+"state now, use\n"
+"\n"
+"    git push %s HEAD:<name-of-remote-branch>\n"
 msgstr ""
-"git pack-objects --stdout [ОПЦИЯ…] [< СПИСЪК_С_УКАЗАТЕЛИ | < СПИСЪК_С_ОБЕКТИ]"
+"В момента не сте на никой клон.  За да изтласкате историята до състоянието,\n"
+"сочено в момента от указателя „HEAD“, използвайте командата:\n"
+"\n"
+"    git push %s HEAD:ИМЕ_НА_ОТДАЛЕЧЕНИЯ_КЛОН\n"
 
-#: builtin/pack-objects.c:49
+#: builtin/push.c:200
+#, c-format
 msgid ""
-"git pack-objects [<options>...] <base-name> [< <ref-list> | < <object-list>]"
+"The current branch %s has no upstream branch.\n"
+"To push the current branch and set the remote as upstream, use\n"
+"\n"
+"    git push --set-upstream %s %s\n"
 msgstr ""
-"git pack-objects [ОПЦИЯ…] ПРЕФИКС_НА_ИМЕТО [< СПИСЪК_С_УКАЗАТЕЛИ | < "
-"СПИСЪК_С_ОБЕКТИ]"
+"Не е зададен отдалечен клон, който текущият клон „%s“ да следи.\n"
+"За да изтласкате локалния клон към отдалечен и същевременно да зададете\n"
+"втория като този, който първият следи, използвайте командата:\n"
+"\n"
+"    git push --set-upstream %s %s\n"
 
-#: builtin/pack-objects.c:211 builtin/pack-objects.c:214
+#: builtin/push.c:208
 #, c-format
-msgid "deflate error (%d)"
-msgstr "грешка при декомпресиране с „deflate“ (%d)"
-
-#: builtin/pack-objects.c:810
-msgid "disabling bitmap writing, packs are split due to pack.packSizeLimit"
+msgid "The current branch %s has multiple upstream branches, refusing to push."
 msgstr ""
-"изключване на записването на битовата маска, пакетите са разделени поради "
-"стойността на „pack.packSizeLimit“"
+"Текущият клон „%s“ следи няколко отдалечени клона, не можете просто да "
+"изтласкате."
 
-#: builtin/pack-objects.c:823
-msgid "Writing objects"
-msgstr "Записване на обектите"
+#: builtin/push.c:211
+#, c-format
+msgid ""
+"You are pushing to remote '%s', which is not the upstream of\n"
+"your current branch '%s', without telling me what to push\n"
+"to update which remote branch."
+msgstr ""
+"Изтласквате към отдалечения клон „%s“, който не е следен от текущия клон "
+"„%s“.\n"
+"Трябва да укажете коя версия да се изтласка, за обновяване на отдалечения "
+"клон."
 
-#: builtin/pack-objects.c:1106
-msgid "disabling bitmap writing, as some objects are not being packed"
+#: builtin/push.c:270
+msgid ""
+"You didn't specify any refspecs to push, and push.default is \"nothing\"."
 msgstr ""
-"изключване на записването на битовата маска, защото някои обекти няма да се "
-"пакетират"
+"Не сте указали версия за подаване, а настройката „push.default“ е "
+"„nothing“ (нищо без изрично указана версия да не се изтласква)"
 
-#: builtin/pack-objects.c:1765
-msgid "Counting objects"
-msgstr "Преброяване на обектите"
+#: builtin/push.c:277
+msgid ""
+"Updates were rejected because the tip of your current branch is behind\n"
+"its remote counterpart. Integrate the remote changes (e.g.\n"
+"'git pull ...') before pushing again.\n"
+"See the 'Note about fast-forwards' in 'git push --help' for details."
+msgstr ""
+"Обновяването е отхвърлено, защото върхът на текущия ви клон е преди върха "
+"на\n"
+"отдалечения клон.  Внесете отдалечените промени (напр. с командата „git "
+"pull…“),\n"
+"преди отново да изтласкате промените.  За повече информация вижте раздела\n"
+"„Note about fast-forwards“ в страницата от ръководството „git push --help“."
 
-#: builtin/pack-objects.c:1895
-#, c-format
-msgid "unable to get size of %s"
-msgstr "размерът на „%s“ не може да бъде получен"
+#: builtin/push.c:283
+msgid ""
+"Updates were rejected because a pushed branch tip is behind its remote\n"
+"counterpart. Check out this branch and integrate the remote changes\n"
+"(e.g. 'git pull ...') before pushing again.\n"
+"See the 'Note about fast-forwards' in 'git push --help' for details."
+msgstr ""
+"Обновяването е отхвърлено, защото върхът на изтласквания клон е преди върха\n"
+"на отдалечения клон.  Преминете към клона и внесете отдалечените промени "
+"(напр.\n"
+"с командата „git pull…“), преди отново да изтласкате промените.  За повече\n"
+"информация погледнете раздела „Note about fast-forwards“ в страницата от\n"
+"ръководството „git push --help“."
 
-#: builtin/pack-objects.c:1910
-#, c-format
-msgid "unable to parse object header of %s"
-msgstr "заглавната част на „%s“ не може да бъде анализирана"
+#: builtin/push.c:289
+msgid ""
+"Updates were rejected because the remote contains work that you do\n"
+"not have locally. This is usually caused by another repository pushing\n"
+"to the same ref. You may want to first integrate the remote changes\n"
+"(e.g., 'git pull ...') before pushing again.\n"
+"See the 'Note about fast-forwards' in 'git push --help' for details."
+msgstr ""
+"Обновяването е отхвърлено, защото хранилището, към което изтласквате, "
+"съдържа\n"
+"промени, които липсват в локалното хранилище.  Най-честата причина за това "
+"е,\n"
+"че някой друг е изтласквал към същия клон.  Първо внесете отдалечените "
+"промени\n"
+"(напр. с командата „git pull…“), преди отново да изтласкате промените.\n"
+"За повече информация погледнете раздела „Note about fast-forwards“ в "
+"страницата\n"
+"от ръководството „git push --help“."
 
-#: builtin/pack-objects.c:2564
-msgid "Compressing objects"
-msgstr "Компресиране на обектите"
+#: builtin/push.c:296
+msgid "Updates were rejected because the tag already exists in the remote."
+msgstr ""
+"Изтласкването е отхвърлено, защото в отдалеченото хранилище съществува "
+"етикет,\n"
+"който ще припокриете с етикет от вашето хранилище."
 
-#: builtin/pack-objects.c:2735
-msgid "invalid value for --missing"
-msgstr "неправилна стойност за „--missing“"
+#: builtin/push.c:299
+msgid ""
+"You cannot update a remote ref that points at a non-commit object,\n"
+"or update a remote ref to make it point at a non-commit object,\n"
+"without using the '--force' option.\n"
+msgstr ""
+"Без да укажете опцията „--force“, не може да обновите отдалечен\n"
+"указател, който вече сочи към обект, който не е подаване, както и тепърва\n"
+"да го промените да сочи към подобен обект.\n"
 
-#: builtin/pack-objects.c:3067
+#: builtin/push.c:360
 #, c-format
-msgid "unsupported index version %s"
-msgstr "неподдържана версия на индекса „%s“"
+msgid "Pushing to %s\n"
+msgstr "Изтласкване към „%s“\n"
 
-#: builtin/pack-objects.c:3071
+#: builtin/push.c:367
 #, c-format
-msgid "bad index version '%s'"
-msgstr "неправилна версия на индекса „%s“"
-
-#: builtin/pack-objects.c:3102
-msgid "do not show progress meter"
-msgstr "без извеждане на напредъка"
+msgid "failed to push some refs to '%s'"
+msgstr "част от указателите не бяха изтласкани към „%s“"
 
-#: builtin/pack-objects.c:3104
-msgid "show progress meter"
-msgstr "извеждане на напредъка"
+#: builtin/push.c:542
+msgid "repository"
+msgstr "хранилище"
 
-#: builtin/pack-objects.c:3106
-msgid "show progress meter during object writing phase"
-msgstr "извеждане на напредъка във фазата на запазване на обектите"
+#: builtin/push.c:543 builtin/send-pack.c:164
+msgid "push all refs"
+msgstr "изтласкване на всички указатели"
 
-#: builtin/pack-objects.c:3109
-msgid "similar to --all-progress when progress meter is shown"
-msgstr ""
-"същото действие като опцията „--all-progress“ при извеждането на напредъка"
+#: builtin/push.c:544 builtin/send-pack.c:166
+msgid "mirror all refs"
+msgstr "огледално копие на всички указатели"
 
-#: builtin/pack-objects.c:3110
-msgid "version[,offset]"
-msgstr "ВЕРСИЯ[,ОТМЕСТВАНЕ]"
+#: builtin/push.c:546
+msgid "delete refs"
+msgstr "изтриване на указателите"
 
-#: builtin/pack-objects.c:3111
-msgid "write the pack index file in the specified idx format version"
-msgstr ""
-"запазване на индекса на пакетните файлове във форма̀та с указаната версия"
+#: builtin/push.c:547
+msgid "push tags (can't be used with --all or --mirror)"
+msgstr "изтласкване на етикетите (несъвместимо с опциите „--all“ и „--mirror“)"
 
-#: builtin/pack-objects.c:3114
-msgid "maximum size of each output pack file"
-msgstr "максимален размер на всеки пакетен файл"
+#: builtin/push.c:550 builtin/send-pack.c:167
+msgid "force updates"
+msgstr "принудително обновяване"
 
-#: builtin/pack-objects.c:3116
-msgid "ignore borrowed objects from alternate object store"
-msgstr "игнориране на обектите заети от други хранилища на обекти"
+#: builtin/push.c:552 builtin/send-pack.c:181
+msgid "<refname>:<expect>"
+msgstr "ИМЕ_НА_УКАЗАТЕЛ:ОЧАКВАНА_СТОЙНОСТ"
 
-#: builtin/pack-objects.c:3118
-msgid "ignore packed objects"
-msgstr "игнориране на пакетираните обекти"
+#: builtin/push.c:553 builtin/send-pack.c:182
+msgid "require old value of ref to be at this value"
+msgstr "УКАЗАТЕЛят трябва първоначално да е с тази ОЧАКВАНА_СТОЙНОСТ"
 
-#: builtin/pack-objects.c:3120
-msgid "limit pack window by objects"
-msgstr "ограничаване на прозореца за пакетиране по брой обекти"
+#: builtin/push.c:556
+msgid "control recursive pushing of submodules"
+msgstr "управление на рекурсивното изтласкване на подмодулите"
 
-#: builtin/pack-objects.c:3122
-msgid "limit pack window by memory in addition to object limit"
-msgstr ""
-"ограничаване на прозореца за пакетиране и по памет освен по брой обекти"
+#: builtin/push.c:558 builtin/send-pack.c:175
+msgid "use thin pack"
+msgstr "използване на съкратени пакети"
 
-#: builtin/pack-objects.c:3124
-msgid "maximum length of delta chain allowed in the resulting pack"
-msgstr ""
-"максимална дължина на веригата от разлики, която е позволена в пакетния файл"
+#: builtin/push.c:559 builtin/push.c:560 builtin/send-pack.c:161
+#: builtin/send-pack.c:162
+msgid "receive pack program"
+msgstr "програма за получаването на пакети"
 
-#: builtin/pack-objects.c:3126
-msgid "reuse existing deltas"
-msgstr "преизползване на съществуващите разлики"
+#: builtin/push.c:561
+msgid "set upstream for git pull/status"
+msgstr "задаване на отдалеченото хранилище за командите „git pull/status“"
 
-#: builtin/pack-objects.c:3128
-msgid "reuse existing objects"
-msgstr "преизползване на съществуващите обекти"
+#: builtin/push.c:564
+msgid "prune locally removed refs"
+msgstr "окастряне на указателите, които са премахнати от локалното хранилище"
 
-#: builtin/pack-objects.c:3130
-msgid "use OFS_DELTA objects"
-msgstr "използване на обекти „OFS_DELTA“"
+#: builtin/push.c:566
+msgid "bypass pre-push hook"
+msgstr "без изпълнение на куката преди изтласкване (pre-push)"
 
-#: builtin/pack-objects.c:3132
-msgid "use threads when searching for best delta matches"
+#: builtin/push.c:567
+msgid "push missing but relevant tags"
 msgstr ""
-"стартиране на нишки за претърсване на най-добрите съвпадения на разликите"
-
-#: builtin/pack-objects.c:3134
-msgid "do not create an empty pack output"
-msgstr "без създаване на празен пакетен файл"
+"изтласкване на липсващите в отдалеченото хранилище, но свързани с текущото "
+"изтласкване, етикети"
 
-#: builtin/pack-objects.c:3136
-msgid "read revision arguments from standard input"
-msgstr "изчитане на версиите от стандартния вход"
+#: builtin/push.c:570 builtin/send-pack.c:169
+msgid "GPG sign the push"
+msgstr "подписване на изтласкването с GPG"
 
-#: builtin/pack-objects.c:3138
-msgid "limit the objects to those that are not yet packed"
-msgstr "ограничаване до все още непакетираните обекти"
+#: builtin/push.c:572 builtin/send-pack.c:176
+msgid "request atomic transaction on remote side"
+msgstr "изискване на атомарни операции от отсрещната страна"
 
-#: builtin/pack-objects.c:3141
-msgid "include objects reachable from any reference"
+#: builtin/push.c:590
+msgid "--delete is incompatible with --all, --mirror and --tags"
 msgstr ""
-"включване на всички обекти, които могат да се достигнат от произволен "
-"указател"
-
-#: builtin/pack-objects.c:3144
-msgid "include objects referred by reflog entries"
-msgstr "включване и на обектите сочени от записите в журнала на указателите"
+"опцията „--delete“ е несъвместима с опциите  „--all“, „--mirror“ и „--tags“"
 
-#: builtin/pack-objects.c:3147
-msgid "include objects referred to by the index"
-msgstr "включване и на обектите сочени от индекса"
+#: builtin/push.c:592
+msgid "--delete doesn't make sense without any refs"
+msgstr "опцията „--delete“ изисква поне един указател на версия"
 
-#: builtin/pack-objects.c:3150
-msgid "output pack to stdout"
-msgstr "извеждане на пакета на стандартния изход"
+#: builtin/push.c:612
+#, c-format
+msgid "bad repository '%s'"
+msgstr "неправилно указано хранилище „%s“"
 
-#: builtin/pack-objects.c:3152
-msgid "include tag objects that refer to objects to be packed"
+#: builtin/push.c:613
+msgid ""
+"No configured push destination.\n"
+"Either specify the URL from the command-line or configure a remote "
+"repository using\n"
+"\n"
+"    git remote add <name> <url>\n"
+"\n"
+"and then push using the remote name\n"
+"\n"
+"    git push <name>\n"
 msgstr ""
-"включване и на обектите-етикети, които сочат към обектите, които ще бъдат "
-"пакетирани"
-
-#: builtin/pack-objects.c:3154
-msgid "keep unreachable objects"
-msgstr "запазване на недостижимите обекти"
+"Не е указано хранилище, към което да се изтласква.\n"
+"Или укажете адреса на командния ред, или настройте отдалечено хранилище с "
+"командата:\n"
+"\n"
+"    git remote add ИМЕ АДРЕС\n"
+"\n"
+"и след това изтласкайте, като укажете името на отдалеченото хранилище:\n"
+"\n"
+"    git push ИМЕ\n"
 
-#: builtin/pack-objects.c:3156
-msgid "pack loose unreachable objects"
-msgstr "пакетиране и на недостижимите обекти"
+#: builtin/push.c:628
+msgid "--all and --tags are incompatible"
+msgstr "опциите „--all“ и „--tags“ са несъвместими"
 
-#: builtin/pack-objects.c:3158
-msgid "unpack unreachable objects newer than <time>"
-msgstr "разпакетиране на недостижимите обекти, които са по-нови от това ВРЕМЕ"
+#: builtin/push.c:630
+msgid "--all can't be combined with refspecs"
+msgstr "опцията „--all“ е несъвместима с указването на версия"
 
-#: builtin/pack-objects.c:3161
-msgid "create thin packs"
-msgstr "създаване на съкратени пакети"
+#: builtin/push.c:634
+msgid "--mirror and --tags are incompatible"
+msgstr "опциите „--mirror“ и „--tags“ са несъвместими"
 
-#: builtin/pack-objects.c:3163
-msgid "create packs suitable for shallow fetches"
-msgstr "пакетиране подходящо за плитко доставяне"
+#: builtin/push.c:636
+msgid "--mirror can't be combined with refspecs"
+msgstr "опцията „--mirror“ е несъвместима с указването на версия"
 
-#: builtin/pack-objects.c:3165
-msgid "ignore packs that have companion .keep file"
-msgstr "игнориране на пакетите, които са придружени от файл „.keep“"
+#: builtin/push.c:639
+msgid "--all and --mirror are incompatible"
+msgstr "опциите „--all“ и „--mirror“ са несъвместими"
 
-#: builtin/pack-objects.c:3167
-msgid "ignore this pack"
-msgstr "пропускане на този пакет"
+#: builtin/push.c:643
+msgid "push options must not have new line characters"
+msgstr "опциите за изтласкване не трябва да съдържат знак за нов ред"
 
-#: builtin/pack-objects.c:3169
-msgid "pack compression level"
-msgstr "ниво на компресиране при пакетиране"
+#: builtin/range-diff.c:8
+msgid "git range-diff [<options>] <old-base>..<old-tip> <new-base>..<new-tip>"
+msgstr "git range-diff [ОПЦИЯ…] СТАРА_БАЗА..СТАР_ВРЪХ НОВА_БАЗА..НОВ_ВРЪХ"
 
-#: builtin/pack-objects.c:3171
-msgid "do not hide commits by grafts"
-msgstr ""
-"извеждане на всички родители — дори и тези, които нормално са скрити при "
-"присажданията"
+#: builtin/range-diff.c:9
+msgid "git range-diff [<options>] <old-tip>...<new-tip>"
+msgstr "git range-diff [ОПЦИЯ…] СТАР_ВРЪХ...НОВ_ВРЪХ"
 
-#: builtin/pack-objects.c:3173
-msgid "use a bitmap index if available to speed up counting objects"
-msgstr ""
-"използване на съществуващи индекси на база битови маски за ускоряване на "
-"преброяването на обектите"
+#: builtin/range-diff.c:10
+msgid "git range-diff [<options>] <base> <old-tip> <new-tip>"
+msgstr "git range-diff [ОПЦИЯ…] БАЗА СТАР_ВРЪХ НОВ_ВРЪХ"
 
-#: builtin/pack-objects.c:3175
-msgid "write a bitmap index together with the pack index"
-msgstr ""
-"запазване и на индекс на база побитова маска, заедно с индекса за пакета"
+#: builtin/range-diff.c:22
+msgid "Percentage by which creation is weighted"
+msgstr "Процент за оценка на създаването"
 
-#: builtin/pack-objects.c:3178
-msgid "handling for missing objects"
-msgstr "как да се обработват липсващите обекти"
+#: builtin/range-diff.c:24
+msgid "use simple diff colors"
+msgstr "използване на прости цветове за разликите"
 
-#: builtin/pack-objects.c:3181
-msgid "do not pack objects in promisor packfiles"
-msgstr "без пакетиране на обекти в гарантиращи пакети"
+#: builtin/range-diff.c:26
+msgid "notes"
+msgstr "бележки"
 
-#: builtin/pack-objects.c:3205
-#, c-format
-msgid "delta chain depth %d is too deep, forcing %d"
-msgstr "веригата с разлики е прекалено дълбока — %d, ще се ползва %d"
+#: builtin/range-diff.c:26
+msgid "passed to 'git log'"
+msgstr "подава се на командата „git log“"
 
-#: builtin/pack-objects.c:3210
+#: builtin/range-diff.c:50 builtin/range-diff.c:54
 #, c-format
-msgid "pack.deltaCacheLimit is too high, forcing %d"
-msgstr ""
-"Стойността на настройката „pack.deltaCacheLimit“ е прекалено голяма.  Ще се "
-"ползва %d"
+msgid "no .. in range: '%s'"
+msgstr "„..“ липсва в диапазона „%s“"
 
-#: builtin/pack-objects.c:3338
-msgid "Enumerating objects"
-msgstr "Изброяване на обектите"
+#: builtin/range-diff.c:64
+msgid "single arg format must be symmetric range"
+msgstr "вариантът с единствен аргумент изисква симетричен диапазон"
 
-#: builtin/pack-refs.c:7
-msgid "git pack-refs [<options>]"
-msgstr "git pack-refs [ОПЦИЯ…]"
+#: builtin/range-diff.c:79
+msgid "need two commit ranges"
+msgstr "необходими са два диапазона с подавания"
 
-#: builtin/pack-refs.c:15
-msgid "pack everything"
-msgstr "пакетиране на всичко"
+#: builtin/read-tree.c:41
+msgid ""
+"git read-tree [(-m [--trivial] [--aggressive] | --reset | --prefix=<prefix>) "
+"[-u [--exclude-per-directory=<gitignore>] | -i]] [--no-sparse-checkout] [--"
+"index-output=<file>] (--empty | <tree-ish1> [<tree-ish2> [<tree-ish3>]])"
+msgstr ""
+"git read-tree [(-m [--trivial] [--aggressive] | --reset | --prefix=ПРЕФИКС) "
+"[-u [--exclude-per-directory=ФАЙЛ_С_ИЗКЛЮЧЕНИЯ] | -i]] [--no-sparse-"
+"checkout] [--index-output=ФАЙЛ] (--empty | УКАЗАТЕЛ_КЪМ_ДЪРВО_1 "
+"[УКАЗАТЕЛ_КЪМ_ДЪРВО_2 [УКАЗАТЕЛ_КЪМ_ДЪРВО_3]])"
 
-#: builtin/pack-refs.c:16
-msgid "prune loose refs (default)"
-msgstr "окастряне на недостижимите указатели (стандартно)"
+#: builtin/read-tree.c:124
+msgid "write resulting index to <file>"
+msgstr "запазване на индекса в този ФАЙЛ"
 
-#: builtin/prune-packed.c:8
-msgid "git prune-packed [-n | --dry-run] [-q | --quiet]"
-msgstr "git prune-packed [-n | --dry-run] [-q | --quiet]"
+#: builtin/read-tree.c:127
+msgid "only empty the index"
+msgstr "само зануляване на индекса"
 
-#: builtin/prune-packed.c:41
-msgid "Removing duplicate objects"
-msgstr "Изтриване на повтарящите се обекти"
+#: builtin/read-tree.c:129
+msgid "Merging"
+msgstr "Сливане"
 
-#: builtin/prune.c:11
-msgid "git prune [-n] [-v] [--progress] [--expire <time>] [--] [<head>...]"
-msgstr "git prune [-n] [-v] [--progress] [--expire ВРЕМЕ] [--] [ВРЪХ…]"
+#: builtin/read-tree.c:131
+msgid "perform a merge in addition to a read"
+msgstr "да се извърши и сливане след освен изчитането"
 
-#: builtin/prune.c:108
-msgid "report pruned objects"
-msgstr "информация за окастрените обекти"
+#: builtin/read-tree.c:133
+msgid "3-way merge if no file level merging required"
+msgstr "тройно сливане, ако не се налага пофайлово сливане"
 
-#: builtin/prune.c:111
-msgid "expire objects older than <time>"
-msgstr "окастряне на обектите по-стари от това ВРЕМЕ"
+#: builtin/read-tree.c:135
+msgid "3-way merge in presence of adds and removes"
+msgstr "тройно сливане при добавяне на добавяне и изтриване на файлове"
 
-#: builtin/prune.c:113
-msgid "limit traversal to objects outside promisor packfiles"
-msgstr "ограничаване на обхождането до обекти извън гарантиращи пакети"
+#: builtin/read-tree.c:137
+msgid "same as -m, but discard unmerged entries"
+msgstr "същото като опцията „-m“, но неслетите обекти се пренебрегват"
 
-#: builtin/prune.c:127
-msgid "cannot prune in a precious-objects repo"
-msgstr "хранилище с важни обекти не може да се окастря"
+#: builtin/read-tree.c:138
+msgid "<subdirectory>/"
+msgstr "ПОДДИРЕКТОРИЯ/"
 
-#: builtin/pull.c:59 builtin/pull.c:61
-#, c-format
-msgid "Invalid value for %s: %s"
-msgstr "Неправилна стойност за „%s“: „%s“"
+#: builtin/read-tree.c:139
+msgid "read the tree into the index under <subdirectory>/"
+msgstr "изчитане на дървото към индекса като да е в тази ПОДДИРЕКТОРИЯ/"
 
-#: builtin/pull.c:81
-msgid "git pull [<options>] [<repository> [<refspec>...]]"
-msgstr "git push [ОПЦИЯ…] [ХРАНИЛИЩЕ [УКАЗАТЕЛ_НА_ВЕРСИЯ…]]"
+#: builtin/read-tree.c:142
+msgid "update working tree with merge result"
+msgstr "обновяване на работното дърво с резултата от сливането"
 
-#: builtin/pull.c:132
-msgid "control for recursive fetching of submodules"
-msgstr "управление на рекурсивното доставяне на подмодулите"
+#: builtin/read-tree.c:144
+msgid "gitignore"
+msgstr "ФАЙЛ_С_ИЗКЛЮЧЕНИЯ"
 
-#: builtin/pull.c:136
-msgid "Options related to merging"
-msgstr "Опции при сливане"
+#: builtin/read-tree.c:145
+msgid "allow explicitly ignored files to be overwritten"
+msgstr "позволяване на презаписването на изрично пренебрегваните файлове"
 
-#: builtin/pull.c:139
-msgid "incorporate changes by rebasing rather than merging"
-msgstr "внасяне на промените чрез пребазиране, а не чрез сливане"
+#: builtin/read-tree.c:148
+msgid "don't check the working tree after merging"
+msgstr "без проверка на работното дърво след сливането"
 
-#: builtin/pull.c:166 builtin/rebase--helper.c:23 builtin/revert.c:121
-msgid "allow fast-forward"
-msgstr "позволяване на превъртания"
+#: builtin/read-tree.c:149
+msgid "don't update the index or the work tree"
+msgstr "без обновяване и на индекса, и на работното дърво"
 
-#: builtin/pull.c:175
-msgid "automatically stash/stash pop before and after rebase"
-msgstr "автоматично скатаване/прилагане на скатаното преди и след пребазиране"
+#: builtin/read-tree.c:151
+msgid "skip applying sparse checkout filter"
+msgstr "без прилагане на филтъра за частично изтегляне"
 
-#: builtin/pull.c:191
-msgid "Options related to fetching"
-msgstr "Опции при доставяне"
+#: builtin/read-tree.c:153
+msgid "debug unpack-trees"
+msgstr "изчистване на грешки в командата „unpack-trees“"
 
-#: builtin/pull.c:209
-msgid "number of submodules pulled in parallel"
-msgstr "брой подмодули издърпани паралелно"
+#: builtin/read-tree.c:157
+msgid "suppress feedback messages"
+msgstr "без информационни съобщения"
 
-#: builtin/pull.c:304
-#, c-format
-msgid "Invalid value for pull.ff: %s"
-msgstr "Неправилна стойност за „pull.ff“: „%s“"
+#: builtin/read-tree.c:188
+msgid "You need to resolve your current index first"
+msgstr "Първо трябва да коригирате индекса си"
 
-#: builtin/pull.c:420
+#: builtin/rebase.c:32
 msgid ""
-"There is no candidate for rebasing against among the refs that you just "
-"fetched."
+"git rebase [-i] [options] [--exec <cmd>] [--onto <newbase> | --keep-base] "
+"[<upstream> [<branch>]]"
 msgstr ""
-"Между указателите, които току що доставихте, няма подходящ кандидат, върху "
-"който да пребазирате."
+"git rebase [-i] [ОПЦИЯ…] [--exec КОМАНДА] [--onto НОВА_БАЗА | --keep-base] "
+"[КЛОН_ИЗТОЧНИК [КЛОН]]"
 
-#: builtin/pull.c:422
+#: builtin/rebase.c:34
 msgid ""
-"There are no candidates for merging among the refs that you just fetched."
+"git rebase [-i] [options] [--exec <cmd>] [--onto <newbase>] --root [<branch>]"
 msgstr ""
-"Между указателите, които току що доставихте, няма подходящ кандидат, който "
-"да слеете."
+"git rebase [-i] [ОПЦИЯ…] [--exec КОМАНДА] [--onto НОВА_БАЗА] --root [КЛОН]"
 
-#: builtin/pull.c:423
-msgid ""
-"Generally this means that you provided a wildcard refspec which had no\n"
-"matches on the remote end."
-msgstr ""
-"Най вероятно сте подали шаблон за указатели, който не е напаснал с нищо в "
-"отдалеченото хранилище."
+#: builtin/rebase.c:36
+msgid "git rebase --continue | --abort | --skip | --edit-todo"
+msgstr "git rebase --continue | --abort | --skip | --edit-todo"
 
-#: builtin/pull.c:426
+#: builtin/rebase.c:177 builtin/rebase.c:201 builtin/rebase.c:228
 #, c-format
-msgid ""
-"You asked to pull from the remote '%s', but did not specify\n"
-"a branch. Because this is not the default configured remote\n"
-"for your current branch, you must specify a branch on the command line."
-msgstr ""
-"Заявихте издърпване от отдалеченото хранилище „%s“, но не указахте клон.\n"
-"Понеже това не е хранилището по подразбиране на текущия клон, трябва\n"
-"да укажете отдалечения клон на командния ред."
+msgid "unusable todo list: '%s'"
+msgstr "неуспешно изтриване на списъка за изпълнение: „%s“"
 
-#: builtin/pull.c:431 git-parse-remote.sh:73
-msgid "You are not currently on a branch."
-msgstr "Извън всички клони."
+#: builtin/rebase.c:186 builtin/rebase.c:212 builtin/rebase.c:236
+#, c-format
+msgid "could not write '%s'."
+msgstr "„%s“ не може да се запише."
 
-#: builtin/pull.c:433 builtin/pull.c:448 git-parse-remote.sh:79
-msgid "Please specify which branch you want to rebase against."
-msgstr "Укажете върху кой клон искате да пребазирате."
+#: builtin/rebase.c:271
+msgid "no HEAD?"
+msgstr "Липсва указател „HEAD“"
 
-#: builtin/pull.c:435 builtin/pull.c:450 git-parse-remote.sh:82
-msgid "Please specify which branch you want to merge with."
-msgstr "Укажете кой клон искате да слеете."
+#: builtin/rebase.c:298
+#, c-format
+msgid "could not create temporary %s"
+msgstr "не може да се създаде временна директория „%s“"
 
-#: builtin/pull.c:436 builtin/pull.c:451
-msgid "See git-pull(1) for details."
-msgstr "За повече информация погледнете ръководството „git-pull(1)“"
+#: builtin/rebase.c:304
+msgid "could not mark as interactive"
+msgstr "невъзможно задаване на интерактивна работа"
 
-#: builtin/pull.c:438 builtin/pull.c:444 builtin/pull.c:453
-#: git-parse-remote.sh:64
-msgid "<remote>"
-msgstr "ОТДАЛЕЧЕНО_ХРАНИЛИЩЕ"
+#: builtin/rebase.c:362
+msgid "could not generate todo list"
+msgstr "файлът с командите не може да се генерира"
 
-#: builtin/pull.c:438 builtin/pull.c:453 builtin/pull.c:458 git-rebase.sh:523
-#: git-parse-remote.sh:65
-msgid "<branch>"
-msgstr "КЛОН"
+#: builtin/rebase.c:402
+msgid "a base commit must be provided with --upstream or --onto"
+msgstr "опциите „--upstream“ и „--onto“ изискват базово подаване"
 
-#: builtin/pull.c:446 git-parse-remote.sh:75
-msgid "There is no tracking information for the current branch."
-msgstr "Текущият клон не следи никой."
+#: builtin/rebase.c:457
+msgid "git rebase--interactive [<options>]"
+msgstr "git rebase--interactive [ОПЦИЯ…]"
 
-#: builtin/pull.c:455 git-parse-remote.sh:95
-msgid ""
-"If you wish to set tracking information for this branch you can do so with:"
-msgstr ""
-"Ако искате да зададете информация за следен клон, можете да направите това с "
-"командата:"
+#: builtin/rebase.c:469
+msgid "keep empty commits"
+msgstr "запазване на празните подавания"
 
-#: builtin/pull.c:460
-#, c-format
-msgid ""
-"Your configuration specifies to merge with the ref '%s'\n"
-"from the remote, but no such ref was fetched."
+#: builtin/rebase.c:471 builtin/revert.c:128
+msgid "allow commits with empty messages"
+msgstr "позволяване на празни съобщения при подаване"
+
+#: builtin/rebase.c:472
+msgid "rebase merge commits"
+msgstr "пребазиране на подаванията със сливания"
+
+#: builtin/rebase.c:474
+msgid "keep original branch points of cousins"
 msgstr ""
-"За сливане е указан отдалеченият указател „%s“,\n"
-"но такъв не е доставен."
+"запазване на първоначалните точки на разклоняване на сестринските клони"
 
-#: builtin/pull.c:826
-msgid "ignoring --verify-signatures for rebase"
-msgstr "без „--verify-signatures“ при пребазиране"
+#: builtin/rebase.c:476
+msgid "move commits that begin with squash!/fixup!"
+msgstr "преместване на подаванията, които започват със „squash!“/“fixup!“"
+
+#: builtin/rebase.c:477
+msgid "sign commits"
+msgstr "подписване на подаванията"
+
+#: builtin/rebase.c:479 builtin/rebase.c:1455
+msgid "display a diffstat of what changed upstream"
+msgstr "извеждане на статистика с промените в следения клон"
 
-#: builtin/pull.c:874
-msgid "--[no-]autostash option is only valid with --rebase."
-msgstr "опцията „--[no-]autostash“ изисква „--rebase“"
+#: builtin/rebase.c:481
+msgid "continue rebase"
+msgstr "продължаване на пребазирането"
 
-#: builtin/pull.c:882
-msgid "Updating an unborn branch with changes added to the index."
-msgstr "Обновяване на все още несъздаден клон с промените от индекса"
+#: builtin/rebase.c:483
+msgid "skip commit"
+msgstr "прескачане на подаване"
+
+#: builtin/rebase.c:484
+msgid "edit the todo list"
+msgstr "редактиране на списъка с команди за изпълнение"
+
+#: builtin/rebase.c:486
+msgid "show the current patch"
+msgstr "извеждане на текущата кръпка"
 
-#: builtin/pull.c:885
-msgid "pull with rebase"
-msgstr "издърпване с пребазиране"
+#: builtin/rebase.c:489
+msgid "shorten commit ids in the todo list"
+msgstr "съкратени идентификатори в списъка за изпълнение"
 
-#: builtin/pull.c:886
-msgid "please commit or stash them."
-msgstr "трябва да подадете или скатаете промените."
+#: builtin/rebase.c:491
+msgid "expand commit ids in the todo list"
+msgstr "пълни идентификатори в списъка за изпълнение"
 
-#: builtin/pull.c:911
-#, c-format
-msgid ""
-"fetch updated the current branch head.\n"
-"fast-forwarding your working tree from\n"
-"commit %s."
-msgstr ""
-"доставянето обнови върха на текущия клон.  Работното\n"
-"ви копие бе превъртяно от подаване „%s“."
+#: builtin/rebase.c:493
+msgid "check the todo list"
+msgstr "проверка на списъка за изпълнение"
 
-#: builtin/pull.c:916
-#, c-format
-msgid ""
-"Cannot fast-forward your working tree.\n"
-"After making sure that you saved anything precious from\n"
-"$ git diff %s\n"
-"output, run\n"
-"$ git reset --hard\n"
-"to recover."
+#: builtin/rebase.c:495
+msgid "rearrange fixup/squash lines"
 msgstr ""
-"Работното ви копие не може да бъде превъртяно.\n"
-"След като запазите всичко необходимо посочено от командата:\n"
-"  $ git diff %s\n"
-"изпълнете:\n"
-"  $ git reset --hard\n"
-"за връщане към нормално състояние."
+"преподреждане на редовете за вкарване на подаванията подаванията в "
+"предходните им със и без смени на съобщението"
+
+#: builtin/rebase.c:497
+msgid "insert exec commands in todo list"
+msgstr "вмъкване на командите за изпълнение в списъка за изпълнение"
 
-#: builtin/pull.c:931
-msgid "Cannot merge multiple branches into empty head."
-msgstr "Не може да сливате множество клони в празен върхов указател."
+#: builtin/rebase.c:498
+msgid "onto"
+msgstr "върху"
+
+#: builtin/rebase.c:501
+msgid "restrict-revision"
+msgstr "ограничена версия"
+
+#: builtin/rebase.c:501
+msgid "restrict revision"
+msgstr "ограничена версия"
+
+#: builtin/rebase.c:503
+msgid "squash-onto"
+msgstr "подаване, в което другите да се вкарат"
+
+#: builtin/rebase.c:504
+msgid "squash onto"
+msgstr "подаване, в което другите да се вкарат"
+
+#: builtin/rebase.c:506
+msgid "the upstream commit"
+msgstr "подаване на източника"
+
+#: builtin/rebase.c:508
+msgid "head-name"
+msgstr "име на върха"
+
+#: builtin/rebase.c:508
+msgid "head name"
+msgstr "име на върха"
+
+#: builtin/rebase.c:513
+msgid "rebase strategy"
+msgstr "стратегия на пребазиране"
+
+#: builtin/rebase.c:514
+msgid "strategy-opts"
+msgstr "опции на стратегията"
+
+#: builtin/rebase.c:515
+msgid "strategy options"
+msgstr "опции на стратегията"
+
+#: builtin/rebase.c:516
+msgid "switch-to"
+msgstr "преминаване към"
+
+#: builtin/rebase.c:517
+msgid "the branch or commit to checkout"
+msgstr "клонът, към който да се премине"
+
+#: builtin/rebase.c:518
+msgid "onto-name"
+msgstr "име на база"
+
+#: builtin/rebase.c:518
+msgid "onto name"
+msgstr "име на база"
 
-#: builtin/pull.c:935
-msgid "Cannot rebase onto multiple branches."
-msgstr "Не може да пребазирате върху повече от един клон."
+#: builtin/rebase.c:519
+msgid "cmd"
+msgstr "команда"
 
-#: builtin/pull.c:942
-msgid "cannot rebase with locally recorded submodule modifications"
+#: builtin/rebase.c:519
+msgid "the command to run"
+msgstr "команда за изпълнение"
+
+#: builtin/rebase.c:522 builtin/rebase.c:1540
+msgid "automatically re-schedule any `exec` that fails"
 msgstr ""
-"пребазирането е невъзможно заради локално записаните промени по подмодулите"
+"автоматично подаване за повторно изпълнение на командите завършили с неуспех"
 
-#: builtin/push.c:19
-msgid "git push [<options>] [<repository> [<refspec>...]]"
-msgstr "git push [ОПЦИЯ…] [ХРАНИЛИЩЕ [УКАЗАТЕЛ_НА_ВЕРСИЯ…]]"
+#: builtin/rebase.c:540
+msgid "--[no-]rebase-cousins has no effect without --rebase-merges"
+msgstr "опциите „--[no-]rebase-cousins“ изискват опцията „--rebase-merges“"
 
-#: builtin/push.c:111
-msgid "tag shorthand without <tag>"
-msgstr "съкращение за етикет без ЕТИКЕТ"
+#: builtin/rebase.c:556
+#, c-format
+msgid "%s requires an interactive rebase"
+msgstr "„%s“ изисква интерактивно пребазиране"
 
-#: builtin/push.c:121
-msgid "--delete only accepts plain target ref names"
-msgstr "опцията „--delete“ приема за цел само прости имена на указатели"
+#: builtin/rebase.c:608
+#, c-format
+msgid "could not get 'onto': '%s'"
+msgstr "не може да се премине към новата база, зададена с „onto“: „%s“"
+
+#: builtin/rebase.c:623
+#, c-format
+msgid "invalid orig-head: '%s'"
+msgstr "неправилен указател към първоначален връх „orig-head“: „%s“"
+
+#: builtin/rebase.c:648
+#, c-format
+msgid "ignoring invalid allow_rerere_autoupdate: '%s'"
+msgstr "неправилната стойност на „allow_rerere_autoupdate“ се прескача: „%s“"
+
+#: builtin/rebase.c:724
+#, c-format
+msgid "Could not read '%s'"
+msgstr "Пътят „%s“ не може да бъде прочетен"
+
+#: builtin/rebase.c:742
+#, c-format
+msgid "Cannot store %s"
+msgstr "„%s“ не може да бъде запазен"
+
+#: builtin/rebase.c:849
+msgid "could not determine HEAD revision"
+msgstr "не може да се определи към какво да сочи указателят „HEAD“"
 
-#: builtin/push.c:165
+#: builtin/rebase.c:972 git-rebase--preserve-merges.sh:81
 msgid ""
-"\n"
-"To choose either option permanently, see push.default in 'git help config'."
+"Resolve all conflicts manually, mark them as resolved with\n"
+"\"git add/rm <conflicted_files>\", then run \"git rebase --continue\".\n"
+"You can instead skip this commit: run \"git rebase --skip\".\n"
+"To abort and get back to the state before \"git rebase\", run \"git rebase --"
+"abort\"."
 msgstr ""
-"\n"
-"За да включите тази опция за постоянно, погледнете документацията за "
-"настройката „push.default“ в „git help config“."
+"След коригирането на конфликтите отбележете решаването им чрез:\n"
+"„git add/rm ФАЙЛ_С_КОНФЛИКТ…“ и изпълнете „git rebase --continue“.\n"
+"Ако предпочитате да прескочите тази кръпка, изпълнете „git rebase --skip“.\n"
+"За да откажете пребазирането и да се върнете към първоначалното състояние,\n"
+"изпълнете „git rebase --abort“."
 
-#: builtin/push.c:168
+#: builtin/rebase.c:1060
 #, c-format
 msgid ""
-"The upstream branch of your current branch does not match\n"
-"the name of your current branch.  To push to the upstream branch\n"
-"on the remote, use\n"
 "\n"
-"    git push %s HEAD:%s\n"
+"git encountered an error while preparing the patches to replay\n"
+"these revisions:\n"
 "\n"
-"To push to the branch of the same name on the remote, use\n"
+"    %s\n"
 "\n"
-"    git push %s %s\n"
-"%s"
+"As a result, git cannot rebase them."
 msgstr ""
-"Името на текущия клон се различава от името на клона, който той следи.\n"
-"За да изтласкате към следения клон използвайте командата:\n"
 "\n"
-"    git push %s HEAD:%s\n"
+"Грешка при приготвянето на кръпките за прилагането на следните версии:\n"
 "\n"
-"За да изтласкате към отдалечения клон с име като локалния, използвайте "
-"командата:\n"
+"    %s\n"
 "\n"
-"    git push %s %s\n"
-"%s"
+"В резултат те не могат да се пребазират."
 
-#: builtin/push.c:183
+#: builtin/rebase.c:1367
 #, c-format
 msgid ""
-"You are not currently on a branch.\n"
-"To push the history leading to the current (detached HEAD)\n"
-"state now, use\n"
+"%s\n"
+"Please specify which branch you want to rebase against.\n"
+"See git-rebase(1) for details.\n"
+"\n"
+"    git rebase '<branch>'\n"
 "\n"
-"    git push %s HEAD:<name-of-remote-branch>\n"
 msgstr ""
-"В момента не сте на никой клон.  За да изтласкате историята до състоянието,\n"
-"сочено в момента от указателя „HEAD“, използвайте командата:\n"
+"%s\n"
+"Укажете върху кой клон искате да пребазирате.\n"
+"Погледнете „git-rebase(1)“\n"
+"\n"
+"    git rebase КЛОН\n"
 "\n"
-"    git push %s HEAD:ИМЕ_НА_ОТДАЛЕЧЕНИЯ_КЛОН\n"
 
-#: builtin/push.c:197
+#: builtin/rebase.c:1383
 #, c-format
 msgid ""
-"The current branch %s has no upstream branch.\n"
-"To push the current branch and set the remote as upstream, use\n"
+"If you wish to set tracking information for this branch you can do so with:\n"
+"\n"
+"    git branch --set-upstream-to=%s/<branch> %s\n"
 "\n"
-"    git push --set-upstream %s %s\n"
 msgstr ""
-"Не е зададен отдалечен клон, който текущият клон „%s“ да следи.\n"
-"За да изтласкате локалния клон към отдалечен и същевременно да зададете\n"
-"втория като този, който първият следи, използвайте командата:\n"
+"Ако искате да зададете информация за следен клон, можете да направите това с "
+"командата:\n"
 "\n"
-"    git push --set-upstream %s %s\n"
+"    git branch --set-upstream-to=%s/КЛОН %s\n"
 
-#: builtin/push.c:205
-#, c-format
-msgid "The current branch %s has multiple upstream branches, refusing to push."
-msgstr ""
-"Текущият клон „%s“ следи няколко отдалечени клона, не можете просто да "
-"изтласкате."
+#: builtin/rebase.c:1413
+msgid "exec commands cannot contain newlines"
+msgstr "командите за изпълнение не може да съдържат нови редове"
 
-#: builtin/push.c:208
-#, c-format
-msgid ""
-"You are pushing to remote '%s', which is not the upstream of\n"
-"your current branch '%s', without telling me what to push\n"
-"to update which remote branch."
-msgstr ""
-"Изтласквате към отдалечения клон „%s“, който не е следен от текущия клон "
-"„%s“.\n"
-"Трябва да укажете коя версия да се изтласка, за обновяване на отдалечения "
-"клон."
+#: builtin/rebase.c:1417
+msgid "empty exec command"
+msgstr "празна команда за изпълнение"
 
-#: builtin/push.c:267
-msgid ""
-"You didn't specify any refspecs to push, and push.default is \"nothing\"."
-msgstr ""
-"Не сте указали версия за подаване, а настройката „push.default“ е "
-"„nothing“ (нищо без изрично указана версия да не се изтласква)"
+#: builtin/rebase.c:1446
+msgid "rebase onto given branch instead of upstream"
+msgstr "пребазиране върху зададения, а не следения клон"
 
-#: builtin/push.c:274
-msgid ""
-"Updates were rejected because the tip of your current branch is behind\n"
-"its remote counterpart. Integrate the remote changes (e.g.\n"
-"'git pull ...') before pushing again.\n"
-"See the 'Note about fast-forwards' in 'git push --help' for details."
-msgstr ""
-"Обновяването е отхвърлено, защото върхът на текущия ви клон е преди върха "
-"на\n"
-"отдалечения клон.  Внесете отдалечените промени (напр. с командата „git "
-"pull…“),\n"
-"преди отново да изтласкате промените.  За повече информация вижте раздела\n"
-"„Note about fast-forwards“ в страницата от ръководството „git push --help“."
+#: builtin/rebase.c:1448
+msgid "use the merge-base of upstream and branch as the current base"
+msgstr "за текуща база да се ползва базата за сливане на клона и следеното"
 
-#: builtin/push.c:280
-msgid ""
-"Updates were rejected because a pushed branch tip is behind its remote\n"
-"counterpart. Check out this branch and integrate the remote changes\n"
-"(e.g. 'git pull ...') before pushing again.\n"
-"See the 'Note about fast-forwards' in 'git push --help' for details."
-msgstr ""
-"Обновяването е отхвърлено, защото върхът на изтласквания клон е преди върха\n"
-"на отдалечения клон.  Преминете към клона и внесете отдалечените промени "
-"(напр.\n"
-"с командата „git pull…“), преди отново да изтласкате промените.  За повече\n"
-"информация погледнете раздела „Note about fast-forwards“ в страницата от\n"
-"ръководството „git push --help“."
+#: builtin/rebase.c:1450
+msgid "allow pre-rebase hook to run"
+msgstr "позволяване на куката преди пребазиране да се изпълни"
 
-#: builtin/push.c:286
-msgid ""
-"Updates were rejected because the remote contains work that you do\n"
-"not have locally. This is usually caused by another repository pushing\n"
-"to the same ref. You may want to first integrate the remote changes\n"
-"(e.g., 'git pull ...') before pushing again.\n"
-"See the 'Note about fast-forwards' in 'git push --help' for details."
-msgstr ""
-"Обновяването е отхвърлено, защото хранилището, към което изтласквате, "
-"съдържа\n"
-"промени, които липсват в локалното хранилище.  Най-честата причина за това "
-"е,\n"
-"че някой друг е изтласквал към същия клон.  Първо внесете отдалечените "
-"промени\n"
-"(напр. с командата „git pull…“), преди отново да изтласкате промените.\n"
-"За повече информация погледнете раздела „Note about fast-forwards“ в "
-"страницата\n"
-"от ръководството „git push --help“."
+#: builtin/rebase.c:1452
+msgid "be quiet. implies --no-stat"
+msgstr "без извеждане на информация.  Включва опцията „--no-stat“"
 
-#: builtin/push.c:293
-msgid "Updates were rejected because the tag already exists in the remote."
-msgstr ""
-"Изтласкването е отхвърлено, защото в отдалеченото хранилище съществува "
-"етикет,\n"
-"който ще припокриете с етикет от вашето хранилище."
+#: builtin/rebase.c:1458
+msgid "do not show diffstat of what changed upstream"
+msgstr "без извеждане на статистика с промените в следения клон"
 
-#: builtin/push.c:296
-msgid ""
-"You cannot update a remote ref that points at a non-commit object,\n"
-"or update a remote ref to make it point at a non-commit object,\n"
-"without using the '--force' option.\n"
+#: builtin/rebase.c:1461
+msgid "add a Signed-off-by: line to each commit"
 msgstr ""
-"Без да укажете опцията „--force“, не може да обновите отдалечен\n"
-"указател, който вече сочи към обект, който не е подаване, както и тепърва\n"
-"да го промените да сочи към подобен обект.\n"
+"добавяне на ред за подпис „Signed-off-by“ в съобщението на всяко подаване"
 
-#: builtin/push.c:357
-#, c-format
-msgid "Pushing to %s\n"
-msgstr "Изтласкване към „%s“\n"
+#: builtin/rebase.c:1464
+msgid "make committer date match author date"
+msgstr "датата на подаване да е датата от автора"
 
-#: builtin/push.c:361
-#, c-format
-msgid "failed to push some refs to '%s'"
-msgstr "част от указателите не бяха изтласкани към „%s“"
+#: builtin/rebase.c:1466
+msgid "ignore author date and use current date"
+msgstr "ползване на текущата дата, а не тази от автора"
 
-#: builtin/push.c:395
-#, c-format
-msgid "bad repository '%s'"
-msgstr "неправилно указано хранилище „%s“"
+#: builtin/rebase.c:1468
+msgid "synonym of --reset-author-date"
+msgstr "псевдоним на „--reset-author-date“"
 
-#: builtin/push.c:396
-msgid ""
-"No configured push destination.\n"
-"Either specify the URL from the command-line or configure a remote "
-"repository using\n"
-"\n"
-"    git remote add <name> <url>\n"
-"\n"
-"and then push using the remote name\n"
-"\n"
-"    git push <name>\n"
+#: builtin/rebase.c:1470 builtin/rebase.c:1474
+msgid "passed to 'git apply'"
+msgstr "подава се на командата „git apply“"
+
+#: builtin/rebase.c:1472
+msgid "ignore changes in whitespace"
+msgstr "без промени в празните знаци"
+
+#: builtin/rebase.c:1476 builtin/rebase.c:1479
+msgid "cherry-pick all commits, even if unchanged"
+msgstr "отбиране на всички подавания дори да няма промени"
+
+#: builtin/rebase.c:1481
+msgid "continue"
+msgstr "продължаване"
+
+#: builtin/rebase.c:1484
+msgid "skip current patch and continue"
+msgstr "прескачане на текущата кръпка и продължаване"
+
+#: builtin/rebase.c:1486
+msgid "abort and check out the original branch"
+msgstr "преустановяване и възстановяване на първоначалния клон"
+
+#: builtin/rebase.c:1489
+msgid "abort but keep HEAD where it is"
+msgstr "преустановяване без промяна към какво сочи „HEAD“"
+
+#: builtin/rebase.c:1490
+msgid "edit the todo list during an interactive rebase"
+msgstr "редактиране на файла с команди при интерактивно пребазиране"
+
+#: builtin/rebase.c:1493
+msgid "show the patch file being applied or merged"
+msgstr "показване на кръпката, която се прилага или слива"
+
+#: builtin/rebase.c:1496
+msgid "use merging strategies to rebase"
+msgstr "при пребазиране да се ползва стратегия за сливане"
+
+#: builtin/rebase.c:1500
+msgid "let the user edit the list of commits to rebase"
 msgstr ""
-"Не е указано хранилище, към което да се изтласква.\n"
-"Или укажете адреса на командния ред, или настройте отдалечено хранилище с "
-"командата:\n"
-"\n"
-"    git remote add ИМЕ АДРЕС\n"
-"\n"
-"и след това изтласкайте, като укажете името на отдалеченото хранилище:\n"
-"\n"
-"    git push ИМЕ\n"
+"позволяване на потребителя да редактира списъка с подавания за пребазиране"
 
-#: builtin/push.c:551
-msgid "repository"
-msgstr "хранилище"
+#: builtin/rebase.c:1504
+msgid "(DEPRECATED) try to recreate merges instead of ignoring them"
+msgstr "(остаряло) пресъздаване на сливанията вместо да се прескачат"
 
-#: builtin/push.c:552 builtin/send-pack.c:164
-msgid "push all refs"
-msgstr "изтласкване на всички указатели"
+#: builtin/rebase.c:1509
+msgid "preserve empty commits during rebase"
+msgstr "запазване на празните подавания при пребазиране"
 
-#: builtin/push.c:553 builtin/send-pack.c:166
-msgid "mirror all refs"
-msgstr "огледално копие на всички указатели"
+#: builtin/rebase.c:1511
+msgid "move commits that begin with squash!/fixup! under -i"
+msgstr ""
+"преместване на подаванията, които започват със „squash!“/“fixup!“ при „-i“"
 
-#: builtin/push.c:555
-msgid "delete refs"
-msgstr "изтриване на указателите"
+#: builtin/rebase.c:1517
+msgid "automatically stash/stash pop before and after"
+msgstr "автоматично скатаване/прилагане на скатаното преди и след пребазиране"
 
-#: builtin/push.c:556
-msgid "push tags (can't be used with --all or --mirror)"
-msgstr "изтласкване на етикетите (несъвместимо с опциите „--all“ и „--mirror“)"
+#: builtin/rebase.c:1519
+msgid "add exec lines after each commit of the editable list"
+msgstr ""
+"добавяне на редове с команди за изпълнение след всяко подаване в "
+"редактирания списък"
 
-#: builtin/push.c:559 builtin/send-pack.c:167
-msgid "force updates"
-msgstr "принудително обновяване"
+#: builtin/rebase.c:1523
+msgid "allow rebasing commits with empty messages"
+msgstr "позволяване на пребазиране на подавания с празни съобщения"
 
-#: builtin/push.c:561 builtin/send-pack.c:181
-msgid "refname>:<expect"
-msgstr "УКАЗАТЕЛ>:<ОЧАКВАНА_СТОЙНОСТ"
+#: builtin/rebase.c:1526
+msgid "try to rebase merges instead of skipping them"
+msgstr "опит за пребазиране на сливанията вместо те да се прескачат"
 
-#: builtin/push.c:562 builtin/send-pack.c:182
-msgid "require old value of ref to be at this value"
-msgstr "УКАЗАТЕЛят трябва първоначално да е с тази ОЧАКВАНА_СТОЙНОСТ"
+#: builtin/rebase.c:1529
+msgid "use 'merge-base --fork-point' to refine upstream"
+msgstr ""
+"за доуточняването на следения клон, използвайте:\n"
+"\n"
+"    git merge-base --fork-point"
 
-#: builtin/push.c:565
-msgid "control recursive pushing of submodules"
-msgstr "управление на рекурсивното изтласкване на подмодулите"
+#: builtin/rebase.c:1531
+msgid "use the given merge strategy"
+msgstr "използване на зададената стратегията на сливане"
 
-#: builtin/push.c:567 builtin/send-pack.c:175
-msgid "use thin pack"
-msgstr "използване на съкратени пакети"
+#: builtin/rebase.c:1533 builtin/revert.c:115
+msgid "option"
+msgstr "опция"
 
-#: builtin/push.c:568 builtin/push.c:569 builtin/send-pack.c:161
-#: builtin/send-pack.c:162
-msgid "receive pack program"
-msgstr "програма за получаването на пакети"
+#: builtin/rebase.c:1534
+msgid "pass the argument through to the merge strategy"
+msgstr "аргументът да се подаде на стратегията за сливане"
 
-#: builtin/push.c:570
-msgid "set upstream for git pull/status"
-msgstr "задаване на отдалеченото хранилище за командите „git pull/status“"
+#: builtin/rebase.c:1537
+msgid "rebase all reachable commits up to the root(s)"
+msgstr "пребазиране на всички достижими подавания до началното им подаване"
 
-#: builtin/push.c:573
-msgid "prune locally removed refs"
-msgstr "окастряне на указателите, които са премахнати от локалното хранилище"
+#: builtin/rebase.c:1554
+msgid ""
+"the rebase.useBuiltin support has been removed!\n"
+"See its entry in 'git help config' for details."
+msgstr ""
+"поддръжката на „rebase.useBuiltin“ е премахната.\n"
+"За повече информация вижте „git help config“."
 
-#: builtin/push.c:575
-msgid "bypass pre-push hook"
-msgstr "без изпълнение на куката преди изтласкване (pre-push)"
+#: builtin/rebase.c:1560
+msgid "It looks like 'git am' is in progress. Cannot rebase."
+msgstr ""
+"Изглежда, че сега се прилагат кръпки чрез командата „git-am“.  Не може да "
+"пребазирате в момента."
 
-#: builtin/push.c:576
-msgid "push missing but relevant tags"
+#: builtin/rebase.c:1601
+msgid ""
+"git rebase --preserve-merges is deprecated. Use --rebase-merges instead."
 msgstr ""
-"изтласкване на липсващите в отдалеченото хранилище, но свързани с текущото "
-"изтласкване, етикети"
+"Опцията „--preserve-merges“ е остаряла.  Ползвайте „--rebase-merges“ вместо "
+"нея."
 
-#: builtin/push.c:579 builtin/send-pack.c:169
-msgid "GPG sign the push"
-msgstr "подписване на изтласкването с GPG"
+#: builtin/rebase.c:1606
+msgid "cannot combine '--keep-base' with '--onto'"
+msgstr "опциите „--keep-base“ и „--onto“ са несъвместими"
 
-#: builtin/push.c:581 builtin/send-pack.c:176
-msgid "request atomic transaction on remote side"
-msgstr "изискване на атомарни операции от отсрещната страна"
+#: builtin/rebase.c:1608
+msgid "cannot combine '--keep-base' with '--root'"
+msgstr "опциите „--keep-base“ и „--root“ са несъвместими"
 
-#: builtin/push.c:599
-msgid "--delete is incompatible with --all, --mirror and --tags"
+#: builtin/rebase.c:1612
+msgid "No rebase in progress?"
+msgstr "Изглежда в момента не тече пребазиране"
+
+#: builtin/rebase.c:1616
+msgid "The --edit-todo action can only be used during interactive rebase."
 msgstr ""
-"опцията „--delete“ е несъвместима с опциите  „--all“, „--mirror“ и „--tags“"
+"Опцията „--edit-todo“ е достъпна само по време на интерактивно пребазиране."
 
-#: builtin/push.c:601
-msgid "--delete doesn't make sense without any refs"
-msgstr "опцията „--delete“ изисква поне един указател на версия"
+#: builtin/rebase.c:1639
+msgid "Cannot read HEAD"
+msgstr "Указателят „HEAD“ не може да бъде прочетен"
 
-#: builtin/push.c:604
-msgid "--all and --tags are incompatible"
-msgstr "опциите „--all“ и „--tags“ са несъвместими"
+#: builtin/rebase.c:1651
+msgid ""
+"You must edit all merge conflicts and then\n"
+"mark them as resolved using git add"
+msgstr ""
+"Трябва да редактирате всички конфликти при сливането.  След това\n"
+"отбележете коригирането им чрез командата „git add“"
 
-#: builtin/push.c:606
-msgid "--all can't be combined with refspecs"
-msgstr "опцията „--all“ е несъвместима с указването на версия"
+#: builtin/rebase.c:1670
+msgid "could not discard worktree changes"
+msgstr "промените в работното дърво не могат да бъдат занулени"
 
-#: builtin/push.c:610
-msgid "--mirror and --tags are incompatible"
-msgstr "опциите „--mirror“ и „--tags“ са несъвместими"
+#: builtin/rebase.c:1689
+#, c-format
+msgid "could not move back to %s"
+msgstr "връщането към „%s“ е невъзможно"
 
-#: builtin/push.c:612
-msgid "--mirror can't be combined with refspecs"
-msgstr "опцията „--mirror“ е несъвместима с указването на версия"
+#: builtin/rebase.c:1734
+#, c-format
+msgid ""
+"It seems that there is already a %s directory, and\n"
+"I wonder if you are in the middle of another rebase.  If that is the\n"
+"case, please try\n"
+"\t%s\n"
+"If that is not the case, please\n"
+"\t%s\n"
+"and run me again.  I am stopping in case you still have something\n"
+"valuable there.\n"
+msgstr ""
+"Директорията „%s“ вече съществува.  Възможно ли е да сте\n"
+"в процес на друго пребазиране? Ако това е така, изпълнете:\n"
+"    %s\n"
+"Ако не сте в процес на друго пребазиране, изпълнете:\n"
+"    %s\n"
+"и отново започнете пребазирането.  Текущото пребазиране се преустановява, "
+"за\n"
+"да не загубите случайно промени.\n"
 
-#: builtin/push.c:615
-msgid "--all and --mirror are incompatible"
-msgstr "опциите „--all“ и „--mirror“ са несъвместими"
+#: builtin/rebase.c:1757
+msgid "switch `C' expects a numerical value"
+msgstr "опцията „C“ очаква число за аргумент"
 
-#: builtin/push.c:634
-msgid "push options must not have new line characters"
-msgstr "опциите за изтласкване не трябва да съдържат знак за нов ред"
+#: builtin/rebase.c:1798
+#, c-format
+msgid "Unknown mode: %s"
+msgstr "Неизвестна стратегия: „%s“"
 
-#: builtin/read-tree.c:40
-msgid ""
-"git read-tree [(-m [--trivial] [--aggressive] | --reset | --prefix=<prefix>) "
-"[-u [--exclude-per-directory=<gitignore>] | -i]] [--no-sparse-checkout] [--"
-"index-output=<file>] (--empty | <tree-ish1> [<tree-ish2> [<tree-ish3>]])"
+#: builtin/rebase.c:1820
+msgid "--strategy requires --merge or --interactive"
 msgstr ""
-"git read-tree [(-m [--trivial] [--aggressive] | --reset | --prefix=ПРЕФИКС) "
-"[-u [--exclude-per-directory=ФАЙЛ_С_ИЗКЛЮЧЕНИЯ] | -i]] [--no-sparse-"
-"checkout] [--index-output=ФАЙЛ] (--empty | УКАЗАТЕЛ_КЪМ_ДЪРВО_1 "
-"[УКАЗАТЕЛ_КЪМ_ДЪРВО_2 [УКАЗАТЕЛ_КЪМ_ДЪРВО_3]])"
+"опцията „--strategy“ изисква някоя от опциите „--merge“ или „--interactive“"
 
-#: builtin/read-tree.c:120
-msgid "write resulting index to <file>"
-msgstr "запазване на индекса в този ФАЙЛ"
+#: builtin/rebase.c:1860
+msgid "--reschedule-failed-exec requires --exec or --interactive"
+msgstr ""
+"опцията „--reschedule-failed-exec“ изисква някоя от опциите „--exec“ или „--"
+"interactive“"
 
-#: builtin/read-tree.c:123
-msgid "only empty the index"
-msgstr "само зануляване на индекса"
+#: builtin/rebase.c:1872
+msgid "cannot combine am options with either interactive or merge options"
+msgstr ""
+"опциите за „am“ са несъвместими с опциите за сливане или за интерактивна "
+"работа"
 
-#: builtin/read-tree.c:125
-msgid "Merging"
-msgstr "Сливане"
+#: builtin/rebase.c:1891
+msgid "cannot combine '--preserve-merges' with '--rebase-merges'"
+msgstr "опциите „--preserve-merges“ и „--rebase-merges“ са несъвместими"
 
-#: builtin/read-tree.c:127
-msgid "perform a merge in addition to a read"
-msgstr "да се извърши и сливане след освен изчитането"
+#: builtin/rebase.c:1895
+msgid ""
+"error: cannot combine '--preserve-merges' with '--reschedule-failed-exec'"
+msgstr ""
+"ГРЕШКА: опциите „--preserve-merges“ и „--reschedule-failed-exec“ са "
+"несъвместими"
 
-#: builtin/read-tree.c:129
-msgid "3-way merge if no file level merging required"
-msgstr "тройно сливане, ако не се налага пофайлово сливане"
+#: builtin/rebase.c:1919
+#, c-format
+msgid "invalid upstream '%s'"
+msgstr "неправилен следен клон: „%s“"
 
-#: builtin/read-tree.c:131
-msgid "3-way merge in presence of adds and removes"
-msgstr "тройно сливане при добавяне на добавяне и изтриване на файлове"
+#: builtin/rebase.c:1925
+msgid "Could not create new root commit"
+msgstr "Не може да се създаде ново начално подаване"
 
-#: builtin/read-tree.c:133
-msgid "same as -m, but discard unmerged entries"
-msgstr "същото като опцията „-m“, но неслетите обекти се пренебрегват"
+#: builtin/rebase.c:1951
+#, c-format
+msgid "'%s': need exactly one merge base with branch"
+msgstr "„%s“: изисква се точно една база за сливане с клона"
 
-#: builtin/read-tree.c:134
-msgid "<subdirectory>/"
-msgstr "ПОДДИРЕКТОРИЯ/"
+#: builtin/rebase.c:1954
+#, c-format
+msgid "'%s': need exactly one merge base"
+msgstr "„%s“: изисква се точно една база за пребазиране"
 
-#: builtin/read-tree.c:135
-msgid "read the tree into the index under <subdirectory>/"
-msgstr "изчитане на дървото към индекса като да е в тази ПОДДИРЕКТОРИЯ/"
+#: builtin/rebase.c:1962
+#, c-format
+msgid "Does not point to a valid commit '%s'"
+msgstr "Указателят „%s“ не сочи към подаване"
 
-#: builtin/read-tree.c:138
-msgid "update working tree with merge result"
-msgstr "обновяване на работното дърво с резултата от сливането"
+#: builtin/rebase.c:1987
+#, c-format
+msgid "fatal: no such branch/commit '%s'"
+msgstr "ФАТАЛНА ГРЕШКА: не съществува клон „%s“"
 
-#: builtin/read-tree.c:140
-msgid "gitignore"
-msgstr "ФАЙЛ_С_ИЗКЛЮЧЕНИЯ"
+#: builtin/rebase.c:1995 builtin/submodule--helper.c:40
+#: builtin/submodule--helper.c:1961
+#, c-format
+msgid "No such ref: %s"
+msgstr "Такъв указател няма: %s"
 
-#: builtin/read-tree.c:141
-msgid "allow explicitly ignored files to be overwritten"
-msgstr "позволяване на презаписването на изрично пренебрегваните файлове"
+#: builtin/rebase.c:2006
+msgid "Could not resolve HEAD to a revision"
+msgstr "Подаването, сочено от указателя „HEAD“, не може да бъде открито"
 
-#: builtin/read-tree.c:144
-msgid "don't check the working tree after merging"
-msgstr "без проверка на работното дърво след сливането"
+#: builtin/rebase.c:2044
+msgid "Cannot autostash"
+msgstr "Не може да се скатае автоматично"
 
-#: builtin/read-tree.c:145
-msgid "don't update the index or the work tree"
-msgstr "без обновяване и на индекса, и на работното дърво"
+#: builtin/rebase.c:2047
+#, c-format
+msgid "Unexpected stash response: '%s'"
+msgstr "Неочакван резултат при скатаване: „%s“"
 
-#: builtin/read-tree.c:147
-msgid "skip applying sparse checkout filter"
-msgstr "без прилагане на филтъра за частично изтегляне"
+#: builtin/rebase.c:2053
+#, c-format
+msgid "Could not create directory for '%s'"
+msgstr "Директорията за „%s“ не може да бъде създадена"
 
-#: builtin/read-tree.c:149
-msgid "debug unpack-trees"
-msgstr "изчистване на грешки в командата „unpack-trees“"
+#: builtin/rebase.c:2056
+#, c-format
+msgid "Created autostash: %s\n"
+msgstr "Автоматично скатано: „%s“\n"
 
-#: builtin/rebase--helper.c:8
-msgid "git rebase--helper [<options>]"
-msgstr "git rebase--helper [ОПЦИЯ…]"
+#: builtin/rebase.c:2059
+msgid "could not reset --hard"
+msgstr "неуспешно изпълнение на „git reset --hard“"
 
-#: builtin/rebase--helper.c:24
-msgid "keep empty commits"
-msgstr "запазване на празните подавания"
+#: builtin/rebase.c:2068
+msgid "Please commit or stash them."
+msgstr "Промените трябва или да се подадат, или да се скатаят."
 
-#: builtin/rebase--helper.c:26 builtin/revert.c:123
-msgid "allow commits with empty messages"
-msgstr "позволяване на празни съобщения при подаване"
+#: builtin/rebase.c:2095
+#, c-format
+msgid "could not parse '%s'"
+msgstr "„%s“ не може да се анализира"
 
-#: builtin/rebase--helper.c:27
-msgid "rebase merge commits"
-msgstr "пребазиране на подаванията със сливания"
+#: builtin/rebase.c:2108
+#, c-format
+msgid "could not switch to %s"
+msgstr "не може да се премине към „%s“"
 
-#: builtin/rebase--helper.c:29
-msgid "keep original branch points of cousins"
-msgstr ""
-"запазване на първоначалните точки на разклоняване на сестринските клони"
+#: builtin/rebase.c:2119
+msgid "HEAD is up to date."
+msgstr "Указателят „HEAD“ е напълно актуален."
 
-#: builtin/rebase--helper.c:30
-msgid "continue rebase"
-msgstr "продължаване на пребазирането"
+#: builtin/rebase.c:2121
+#, c-format
+msgid "Current branch %s is up to date.\n"
+msgstr "Текущият клон „%s“ е напълно актуален.\n"
 
-#: builtin/rebase--helper.c:32
-msgid "abort rebase"
-msgstr "преустановяване на пребазирането"
-
-#: builtin/rebase--helper.c:35
-msgid "make rebase script"
-msgstr "създаване на скрипт за пребазиране"
+#: builtin/rebase.c:2129
+msgid "HEAD is up to date, rebase forced."
+msgstr "Указателят „HEAD“ е напълно актуален — принудително пребазиране"
 
-#: builtin/rebase--helper.c:37
-msgid "shorten commit ids in the todo list"
-msgstr "съкратени идентификатори в списъка за изпълнение"
+#: builtin/rebase.c:2131
+#, c-format
+msgid "Current branch %s is up to date, rebase forced.\n"
+msgstr "Текущият клон „%s“ е напълно актуален — принудително пребазиране\n"
 
-#: builtin/rebase--helper.c:39
-msgid "expand commit ids in the todo list"
-msgstr "пълни идентификатори в списъка за изпълнение"
+#: builtin/rebase.c:2139
+msgid "The pre-rebase hook refused to rebase."
+msgstr "Куката за изпълнение преди пребазиране отхвърли пребазирането."
 
-#: builtin/rebase--helper.c:41
-msgid "check the todo list"
-msgstr "проверка на списъка за изпълнение"
+#: builtin/rebase.c:2146
+#, c-format
+msgid "Changes to %s:\n"
+msgstr "Промените в „%s“:\n"
 
-#: builtin/rebase--helper.c:43
-msgid "skip unnecessary picks"
-msgstr "прескачане на излишните команди за отбиране"
+#: builtin/rebase.c:2149
+#, c-format
+msgid "Changes from %s to %s:\n"
+msgstr "Промените от „%s“ към „%s“:\n"
 
-#: builtin/rebase--helper.c:45
-msgid "rearrange fixup/squash lines"
+#: builtin/rebase.c:2174
+#, c-format
+msgid "First, rewinding head to replay your work on top of it...\n"
 msgstr ""
-"преподреждане на редовете за вкарване на подаванията подаванията в "
-"предходните им със и без смени на съобщението"
+"Първо, указателят „HEAD“ започва да сочи към базата, върху която "
+"пребазирате…\n"
 
-#: builtin/rebase--helper.c:47
-msgid "insert exec commands in todo list"
-msgstr "вмъкване на командите за изпълнение в списъка за изпълнение"
+#: builtin/rebase.c:2183
+msgid "Could not detach HEAD"
+msgstr "Указателят „HEAD“ не може да се отделѝ"
 
-#: builtin/rebase--helper.c:68
-msgid "--[no-]rebase-cousins has no effect without --rebase-merges"
-msgstr "опциите „--[no-]rebase-cousins“ изискват опцията „--rebase-merges“"
+#: builtin/rebase.c:2192
+#, c-format
+msgid "Fast-forwarded %s to %s.\n"
+msgstr "Превъртане на „%s“ към „%s“.\n"
 
-#: builtin/receive-pack.c:31
+#: builtin/receive-pack.c:32
 msgid "git receive-pack <git-dir>"
 msgstr "git receive-pack ДИРЕКТОРИЯ_НА_GIT"
 
-#: builtin/receive-pack.c:842
+#: builtin/receive-pack.c:830
 msgid ""
 "By default, updating the current branch in a non-bare repository\n"
 "is denied, because it will make the index and work tree inconsistent\n"
@@ -13160,7 +18903,7 @@ msgstr ""
 "За да заглушите това съобщение, като запазите стандартното поведение,\n"
 "задайте настройката „receive.denyCurrentBranch“ да е „refuse“ (отказ)."
 
-#: builtin/receive-pack.c:862
+#: builtin/receive-pack.c:850
 msgid ""
 "By default, deleting the current branch is denied, because the next\n"
 "'git clone' won't result in any file checked out, causing confusion.\n"
@@ -13181,24 +18924,78 @@ msgstr ""
 "За да заглушите това съобщение, задайте настройката\n"
 "„receive.denyDeleteCurrent“ да е „refuse“ (отказ)."
 
-#: builtin/receive-pack.c:1935
+#: builtin/receive-pack.c:1936
 msgid "quiet"
 msgstr "без извеждане на информация"
 
-#: builtin/receive-pack.c:1949
+#: builtin/receive-pack.c:1950
 msgid "You must specify a directory."
 msgstr "Трябва да укажете директория."
 
-#: builtin/reflog.c:532 builtin/reflog.c:537
+#: builtin/reflog.c:17
+msgid ""
+"git reflog expire [--expire=<time>] [--expire-unreachable=<time>] [--"
+"rewrite] [--updateref] [--stale-fix] [--dry-run | -n] [--verbose] [--all] "
+"<refs>..."
+msgstr ""
+"git reflog expire [--expire=ВРЕМЕ] [--expire-unreachable=ВРЕМЕ] [--rewrite] "
+"[--updateref] [--stale-fix] [--dry-run | -n] [--verbose] [--all] УКАЗАТЕЛ…"
+
+#: builtin/reflog.c:22
+msgid ""
+"git reflog delete [--rewrite] [--updateref] [--dry-run | -n] [--verbose] "
+"<refs>..."
+msgstr ""
+"git reflog delete [--rewrite] [--updateref] [--dry-run | -n] [--verbose] "
+"УКАЗАТЕЛ…"
+
+#: builtin/reflog.c:25
+msgid "git reflog exists <ref>"
+msgstr "git reflog exists УКАЗАТЕЛ"
+
+#: builtin/reflog.c:567 builtin/reflog.c:572
 #, c-format
 msgid "'%s' is not a valid timestamp"
 msgstr "„%s“ не е правилна стойност за време"
 
-#: builtin/remote.c:14
+#: builtin/reflog.c:605
+#, c-format
+msgid "Marking reachable objects..."
+msgstr "Отбелязване на достижимите обекти…"
+
+#: builtin/reflog.c:643
+#, c-format
+msgid "%s points nowhere!"
+msgstr "„%s“ не сочи наникъде!"
+
+#: builtin/reflog.c:695
+msgid "no reflog specified to delete"
+msgstr "не е указан журнал с подавания за изтриване"
+
+#: builtin/reflog.c:704
+#, c-format
+msgid "not a reflog: %s"
+msgstr "„%s“ не е журнал с подавания"
+
+#: builtin/reflog.c:709
+#, c-format
+msgid "no reflog for '%s'"
+msgstr "липсва журнал с подаванията за „%s“"
+
+#: builtin/reflog.c:755
+#, c-format
+msgid "invalid ref format: %s"
+msgstr "неправилен формат на указател: %s"
+
+#: builtin/reflog.c:764
+msgid "git reflog [ show | expire | delete | exists ]"
+msgstr "git reflog [ show | expire | delete | exists ]"
+
+#: builtin/remote.c:16
 msgid "git remote [-v | --verbose]"
 msgstr "git remote [-v | --verbose]"
 
-#: builtin/remote.c:15
+#: builtin/remote.c:17
 msgid ""
 "git remote add [-t <branch>] [-m <master>] [-f] [--tags | --no-tags] [--"
 "mirror=<fetch|push>] <name> <url>"
@@ -13206,83 +19003,83 @@ msgstr ""
 "git remote add [-t КЛОН] [-m ОСНОВЕН_КЛОН] [-f] [--tags | --no-tags] [--"
 "mirror=<fetch|push>] ИМЕ АДРЕС"
 
-#: builtin/remote.c:16 builtin/remote.c:36
+#: builtin/remote.c:18 builtin/remote.c:38
 msgid "git remote rename <old> <new>"
 msgstr "git remote rename СТАРО_ИМЕ НОВО_ИМЕ"
 
-#: builtin/remote.c:17 builtin/remote.c:41
+#: builtin/remote.c:19 builtin/remote.c:43
 msgid "git remote remove <name>"
 msgstr "git remote remove ИМЕ"
 
-#: builtin/remote.c:18 builtin/remote.c:46
+#: builtin/remote.c:20 builtin/remote.c:48
 msgid "git remote set-head <name> (-a | --auto | -d | --delete | <branch>)"
 msgstr "git remote set-head ИМЕ (-a | --auto | -d | --delete | КЛОН)"
 
-#: builtin/remote.c:19
+#: builtin/remote.c:21
 msgid "git remote [-v | --verbose] show [-n] <name>"
 msgstr "git remote [-v | --verbose] show [-n] ИМЕ"
 
-#: builtin/remote.c:20
+#: builtin/remote.c:22
 msgid "git remote prune [-n | --dry-run] <name>"
 msgstr "git remote prune [-n | --dry-run] ИМЕ"
 
-#: builtin/remote.c:21
+#: builtin/remote.c:23
 msgid ""
 "git remote [-v | --verbose] update [-p | --prune] [(<group> | <remote>)...]"
 msgstr ""
 "git remote [-v | --verbose] update [-p | --prune] [(ГРУПА | "
 "ОТДАЛЕЧЕНО_ХРАНИЛИЩЕ)…]"
 
-#: builtin/remote.c:22
+#: builtin/remote.c:24
 msgid "git remote set-branches [--add] <name> <branch>..."
 msgstr "git remote set-branches [--add] ИМЕ КЛОН…"
 
-#: builtin/remote.c:23 builtin/remote.c:72
+#: builtin/remote.c:25 builtin/remote.c:74
 msgid "git remote get-url [--push] [--all] <name>"
 msgstr "git remote get-url [--push] [--all] ИМЕ"
 
-#: builtin/remote.c:24 builtin/remote.c:77
+#: builtin/remote.c:26 builtin/remote.c:79
 msgid "git remote set-url [--push] <name> <newurl> [<oldurl>]"
 msgstr "git remote set-url [--push] ИМЕ НОВ_АДРЕС [СТАР_АДРЕС]"
 
-#: builtin/remote.c:25 builtin/remote.c:78
+#: builtin/remote.c:27 builtin/remote.c:80
 msgid "git remote set-url --add <name> <newurl>"
 msgstr "git remote set-url --add ИМЕ НОВ_АДРЕС"
 
-#: builtin/remote.c:26 builtin/remote.c:79
+#: builtin/remote.c:28 builtin/remote.c:81
 msgid "git remote set-url --delete <name> <url>"
 msgstr "git remote set-url --delete ИМЕ АДРЕС"
 
-#: builtin/remote.c:31
+#: builtin/remote.c:33
 msgid "git remote add [<options>] <name> <url>"
 msgstr "git remote add [ОПЦИЯ…] ИМЕ АДРЕС"
 
-#: builtin/remote.c:51
+#: builtin/remote.c:53
 msgid "git remote set-branches <name> <branch>..."
 msgstr "git remote set-branches ИМЕ КЛОН…"
 
-#: builtin/remote.c:52
+#: builtin/remote.c:54
 msgid "git remote set-branches --add <name> <branch>..."
 msgstr "git remote set-branches --add ИМЕ КЛОН…"
 
-#: builtin/remote.c:57
+#: builtin/remote.c:59
 msgid "git remote show [<options>] <name>"
 msgstr "git remote show [ОПЦИЯ…] ИМЕ"
 
-#: builtin/remote.c:62
+#: builtin/remote.c:64
 msgid "git remote prune [<options>] <name>"
 msgstr "git remote prune [ОПЦИЯ…] ИМЕ"
 
-#: builtin/remote.c:67
+#: builtin/remote.c:69
 msgid "git remote update [<options>] [<group> | <remote>]..."
 msgstr "git remote update [ОПЦИЯ…] [ГРУПА | ОТДАЛЕЧЕНО_ХРАНИЛИЩЕ…]"
 
-#: builtin/remote.c:96
+#: builtin/remote.c:98
 #, c-format
 msgid "Updating %s"
 msgstr "Обновяване на „%s“"
 
-#: builtin/remote.c:128
+#: builtin/remote.c:130
 msgid ""
 "--mirror is dangerous and deprecated; please\n"
 "\t use --mirror=fetch or --mirror=push instead"
@@ -13290,90 +19087,86 @@ msgstr ""
 "Използването само на „--mirror“ е опасно.  Вместо това\n"
 "ползвайте „--mirror=fetch“ или „--mirror=push“"
 
-#: builtin/remote.c:145
+#: builtin/remote.c:147
 #, c-format
 msgid "unknown mirror argument: %s"
 msgstr "неправилна стойност за „--mirror“: %s"
 
-#: builtin/remote.c:161
+#: builtin/remote.c:163
 msgid "fetch the remote branches"
 msgstr "отдалечените клони не могат да бъдат доставени"
 
-#: builtin/remote.c:163
+#: builtin/remote.c:165
 msgid "import all tags and associated objects when fetching"
 msgstr "внасяне на всички етикети и принадлежащите им обекти при доставяне"
 
-#: builtin/remote.c:166
+#: builtin/remote.c:168
 msgid "or do not fetch any tag at all (--no-tags)"
 msgstr "може и да не се доставят никакви етикети (чрез опцията „--no-tags“)"
 
-#: builtin/remote.c:168
+#: builtin/remote.c:170
 msgid "branch(es) to track"
 msgstr "клон/и за следене"
 
-#: builtin/remote.c:169
+#: builtin/remote.c:171
 msgid "master branch"
 msgstr "основен клон"
 
-#: builtin/remote.c:170
-msgid "push|fetch"
-msgstr "издърпване|доставяне"
-
-#: builtin/remote.c:171
+#: builtin/remote.c:173
 msgid "set up remote as a mirror to push to or fetch from"
 msgstr ""
 "настройване на отдалечено хранилище, от което да се издърпва или доставя"
 
-#: builtin/remote.c:183
+#: builtin/remote.c:185
 msgid "specifying a master branch makes no sense with --mirror"
 msgstr ""
 "няма смисъл да се указва основен клон при използване на опцията „--mirror“"
 
-#: builtin/remote.c:185
+#: builtin/remote.c:187
 msgid "specifying branches to track makes sense only with fetch mirrors"
 msgstr ""
 "указването на следени клони е смислено само за отдалечени хранилища, от "
 "които се доставя"
 
-#: builtin/remote.c:192 builtin/remote.c:634
+#: builtin/remote.c:194 builtin/remote.c:636
 #, c-format
 msgid "remote %s already exists."
 msgstr "вече съществува отдалечено хранилище с име „%s“."
 
-#: builtin/remote.c:196 builtin/remote.c:638
+#: builtin/remote.c:198 builtin/remote.c:640
 #, c-format
 msgid "'%s' is not a valid remote name"
 msgstr "„%s“ е неправилно име за отдалечено хранилище"
 
-#: builtin/remote.c:236
+#: builtin/remote.c:238
 #, c-format
 msgid "Could not setup master '%s'"
 msgstr "Основният клон „%s“ не може да бъде настроен"
 
-#: builtin/remote.c:342
+#: builtin/remote.c:344
 #, c-format
 msgid "Could not get fetch map for refspec %s"
 msgstr "Обектите за доставяне за указателя „%s“ не могат да бъдат получени"
 
-#: builtin/remote.c:441 builtin/remote.c:449
+#: builtin/remote.c:443 builtin/remote.c:451
 msgid "(matching)"
 msgstr "(съвпадащи)"
 
-#: builtin/remote.c:453
+#: builtin/remote.c:455
 msgid "(delete)"
 msgstr "(за изтриване)"
 
-#: builtin/remote.c:627 builtin/remote.c:762 builtin/remote.c:861
+#: builtin/remote.c:629 builtin/remote.c:764 builtin/remote.c:863
 #, c-format
-msgid "No such remote: %s"
-msgstr "Такова отдалечено хранилище няма: %s"
+msgid "No such remote: '%s'"
+msgstr "Няма отдалечено хранилище на име „%s“"
 
-#: builtin/remote.c:644
+#: builtin/remote.c:646
 #, c-format
 msgid "Could not rename config section '%s' to '%s'"
 msgstr "Разделът „%s“ в настройките не може да бъде преименуван на „%s“"
 
-#: builtin/remote.c:664
+#: builtin/remote.c:666
 #, c-format
 msgid ""
 "Not updating non-default fetch refspec\n"
@@ -13384,17 +19177,17 @@ msgstr ""
 "    %s\n"
 "  Променете настройките ръчно, ако е необходимо."
 
-#: builtin/remote.c:700
+#: builtin/remote.c:701
 #, c-format
 msgid "deleting '%s' failed"
 msgstr "неуспешно изтриване на „%s“"
 
-#: builtin/remote.c:734
+#: builtin/remote.c:735
 #, c-format
 msgid "creating '%s' failed"
 msgstr "неуспешно създаване на „%s“"
 
-#: builtin/remote.c:799
+#: builtin/remote.c:801
 msgid ""
 "Note: A branch outside the refs/remotes/ hierarchy was not removed;\n"
 "to delete it, use:"
@@ -13408,121 +19201,121 @@ msgstr[1] ""
 "Бележка: Няколко клона извън йерархията „refs/remotes/“ не бяха изтрити.\n"
 "Изтрийте ги чрез командата:"
 
-#: builtin/remote.c:813
+#: builtin/remote.c:815
 #, c-format
 msgid "Could not remove config section '%s'"
 msgstr "Разделът „%s“ в настройките не може да бъде изтрит"
 
-#: builtin/remote.c:914
+#: builtin/remote.c:916
 #, c-format
 msgid " new (next fetch will store in remotes/%s)"
 msgstr " нов (следващото доставяне ще го разположи в „remotes/%s“)"
 
-#: builtin/remote.c:917
+#: builtin/remote.c:919
 msgid " tracked"
 msgstr " следен"
 
-#: builtin/remote.c:919
+#: builtin/remote.c:921
 msgid " stale (use 'git remote prune' to remove)"
 msgstr " стар (изтрийте чрез „git remote prune“)"
 
-#: builtin/remote.c:921
+#: builtin/remote.c:923
 msgid " ???"
 msgstr " неясно състояние"
 
 # CHECK
-#: builtin/remote.c:962
+#: builtin/remote.c:964
 #, c-format
 msgid "invalid branch.%s.merge; cannot rebase onto > 1 branch"
 msgstr ""
 "неправилен клон за сливане „%s“.  Невъзможно е да пребазирате върху повече "
 "от 1 клон"
 
-#: builtin/remote.c:971
+#: builtin/remote.c:973
 #, c-format
 msgid "rebases interactively onto remote %s"
 msgstr "интерактивно пребазиране върху отдалечения клон „%s“"
 
-#: builtin/remote.c:973
+#: builtin/remote.c:975
 #, c-format
 msgid "rebases interactively (with merges) onto remote %s"
 msgstr "интерактивно пребазиране (със сливания) върху отдалечения клон „%s“"
 
-#: builtin/remote.c:976
+#: builtin/remote.c:978
 #, c-format
 msgid "rebases onto remote %s"
 msgstr "пребазиране върху отдалечения клон „%s“"
 
-#: builtin/remote.c:980
+#: builtin/remote.c:982
 #, c-format
 msgid " merges with remote %s"
 msgstr " сливане с отдалечения клон „%s“"
 
-#: builtin/remote.c:983
+#: builtin/remote.c:985
 #, c-format
 msgid "merges with remote %s"
 msgstr "сливане с отдалечения клон „%s“"
 
-#: builtin/remote.c:986
+#: builtin/remote.c:988
 #, c-format
 msgid "%-*s    and with remote %s\n"
 msgstr "%-*s    и с отдалечения клон „%s“\n"
 
-#: builtin/remote.c:1029
+#: builtin/remote.c:1031
 msgid "create"
 msgstr "създаден"
 
-#: builtin/remote.c:1032
+#: builtin/remote.c:1034
 msgid "delete"
 msgstr "изтрит"
 
-#: builtin/remote.c:1036
+#: builtin/remote.c:1038
 msgid "up to date"
 msgstr "актуален"
 
-#: builtin/remote.c:1039
+#: builtin/remote.c:1041
 msgid "fast-forwardable"
 msgstr "може да се превърти"
 
-#: builtin/remote.c:1042
+#: builtin/remote.c:1044
 msgid "local out of date"
 msgstr "локалният е изостанал"
 
-#: builtin/remote.c:1049
+#: builtin/remote.c:1051
 #, c-format
 msgid "    %-*s forces to %-*s (%s)"
 msgstr "    %-*s принудително изтласква към %-*s (%s)"
 
-#: builtin/remote.c:1052
+#: builtin/remote.c:1054
 #, c-format
 msgid "    %-*s pushes to %-*s (%s)"
 msgstr "    %-*s изтласква към %-*s (%s)"
 
-#: builtin/remote.c:1056
+#: builtin/remote.c:1058
 #, c-format
 msgid "    %-*s forces to %s"
 msgstr "    %-*s принудително изтласква към %s"
 
-#: builtin/remote.c:1059
+#: builtin/remote.c:1061
 #, c-format
 msgid "    %-*s pushes to %s"
 msgstr "    %-*s изтласква към %s"
 
-#: builtin/remote.c:1127
+#: builtin/remote.c:1129
 msgid "do not query remotes"
 msgstr "без заявки към отдалечените хранилища"
 
-#: builtin/remote.c:1154
+#: builtin/remote.c:1156
 #, c-format
 msgid "* remote %s"
 msgstr "● отдалечено хранилище „%s“"
 
-#: builtin/remote.c:1155
+#: builtin/remote.c:1157
 #, c-format
 msgid "  Fetch URL: %s"
 msgstr "  Адрес за доставяне: %s"
 
-#: builtin/remote.c:1156 builtin/remote.c:1172 builtin/remote.c:1311
+#: builtin/remote.c:1158 builtin/remote.c:1174 builtin/remote.c:1313
 msgid "(no URL)"
 msgstr "(без адрес)"
 
@@ -13530,25 +19323,25 @@ msgstr "(без адрес)"
 #. with the one in " Fetch URL: %s"
 #. translation.
 #.
-#: builtin/remote.c:1170 builtin/remote.c:1172
+#: builtin/remote.c:1172 builtin/remote.c:1174
 #, c-format
 msgid "  Push  URL: %s"
 msgstr "  Адрес за изтласкване: %s"
 
-#: builtin/remote.c:1174 builtin/remote.c:1176 builtin/remote.c:1178
+#: builtin/remote.c:1176 builtin/remote.c:1178 builtin/remote.c:1180
 #, c-format
 msgid "  HEAD branch: %s"
 msgstr "  клон сочен от HEAD: %s"
 
-#: builtin/remote.c:1174
+#: builtin/remote.c:1176
 msgid "(not queried)"
 msgstr "(без проверка)"
 
-#: builtin/remote.c:1176
+#: builtin/remote.c:1178
 msgid "(unknown)"
 msgstr "(непознат)"
 
-#: builtin/remote.c:1180
+#: builtin/remote.c:1182
 #, c-format
 msgid ""
 "  HEAD branch (remote HEAD is ambiguous, may be one of the following):\n"
@@ -13557,170 +19350,161 @@ msgstr ""
 "хранилище\n"
 "  не е еднозначен и е някой от следните):\n"
 
-#: builtin/remote.c:1192
+#: builtin/remote.c:1194
 #, c-format
 msgid "  Remote branch:%s"
 msgid_plural "  Remote branches:%s"
 msgstr[0] "  Отдалечен клон:%s"
 msgstr[1] "  Отдалечени клони:%s"
 
-#: builtin/remote.c:1195 builtin/remote.c:1221
+#: builtin/remote.c:1197 builtin/remote.c:1223
 msgid " (status not queried)"
 msgstr " (състоянието не бе проверено)"
 
-#: builtin/remote.c:1204
+#: builtin/remote.c:1206
 msgid "  Local branch configured for 'git pull':"
 msgid_plural "  Local branches configured for 'git pull':"
 msgstr[0] "  Локален клон настроен за издърпване чрез „git pull“:"
 msgstr[1] "  Локални клони настроени за издърпване чрез „git pull“:"
 
-#: builtin/remote.c:1212
+#: builtin/remote.c:1214
 msgid "  Local refs will be mirrored by 'git push'"
 msgstr "  Локалните указатели ще бъдат пренесени чрез „ push“"
 
-#: builtin/remote.c:1218
+#: builtin/remote.c:1220
 #, c-format
 msgid "  Local ref configured for 'git push'%s:"
 msgid_plural "  Local refs configured for 'git push'%s:"
 msgstr[0] "  Локалният указател, настроен за „git push“%s:"
 msgstr[1] "  Локалните указатели, настроени за „git push“%s:"
 
-#: builtin/remote.c:1239
+#: builtin/remote.c:1241
 msgid "set refs/remotes/<name>/HEAD according to remote"
 msgstr "задаване на refs/remotes/ИМЕ/HEAD според отдалеченото хранилище"
 
-#: builtin/remote.c:1241
+#: builtin/remote.c:1243
 msgid "delete refs/remotes/<name>/HEAD"
 msgstr "изтриване на refs/remotes/ИМЕ/HEAD"
 
-#: builtin/remote.c:1256
+#: builtin/remote.c:1258
 msgid "Cannot determine remote HEAD"
 msgstr "Не може да се установи отдалеченият връх"
 
-#: builtin/remote.c:1258
+#: builtin/remote.c:1260
 msgid "Multiple remote HEAD branches. Please choose one explicitly with:"
 msgstr ""
 "Множество клони с върхове.  Изберете изрично някой от тях чрез командата:"
 
-#: builtin/remote.c:1268
+#: builtin/remote.c:1270
 #, c-format
 msgid "Could not delete %s"
 msgstr "„%s“ не може да бъде изтрит"
 
-#: builtin/remote.c:1276
+#: builtin/remote.c:1278
 #, c-format
 msgid "Not a valid ref: %s"
 msgstr "Неправилен указател: %s"
 
-#: builtin/remote.c:1278
+#: builtin/remote.c:1280
 #, c-format
 msgid "Could not setup %s"
 msgstr "„%s“ не може да се настрои"
 
-#: builtin/remote.c:1296
+#: builtin/remote.c:1298
 #, c-format
 msgid " %s will become dangling!"
 msgstr "„%s“ ще се превърне в обект извън клоните!"
 
-#: builtin/remote.c:1297
+#: builtin/remote.c:1299
 #, c-format
 msgid " %s has become dangling!"
 msgstr "„%s“ се превърна в обект извън клоните!"
 
-#: builtin/remote.c:1307
+#: builtin/remote.c:1309
 #, c-format
 msgid "Pruning %s"
 msgstr "Окастряне на „%s“"
 
-#: builtin/remote.c:1308
+#: builtin/remote.c:1310
 #, c-format
 msgid "URL: %s"
 msgstr "адрес: %s"
 
-#: builtin/remote.c:1324
+#: builtin/remote.c:1326
 #, c-format
 msgid " * [would prune] %s"
 msgstr " ● [ще бъде окастрено] %s"
 
-#: builtin/remote.c:1327
+#: builtin/remote.c:1329
 #, c-format
 msgid " * [pruned] %s"
 msgstr " ● [окастрено] %s"
 
-#: builtin/remote.c:1372
+#: builtin/remote.c:1374
 msgid "prune remotes after fetching"
 msgstr "окастряне на огледалата на отдалечените хранилища след доставяне"
 
-#: builtin/remote.c:1435 builtin/remote.c:1489 builtin/remote.c:1557
+#: builtin/remote.c:1437 builtin/remote.c:1491 builtin/remote.c:1559
 #, c-format
 msgid "No such remote '%s'"
 msgstr "Няма отдалечено хранилище на име „%s“"
 
-#: builtin/remote.c:1451
+#: builtin/remote.c:1453
 msgid "add branch"
 msgstr "добавяне на клон"
 
-#: builtin/remote.c:1458
+#: builtin/remote.c:1460
 msgid "no remote specified"
 msgstr "не е указано отдалечено хранилище"
 
-#: builtin/remote.c:1475
+#: builtin/remote.c:1477
 msgid "query push URLs rather than fetch URLs"
 msgstr "запитване към адресите за изтласкване, а не за доставяне"
 
-#: builtin/remote.c:1477
+#: builtin/remote.c:1479
 msgid "return all URLs"
 msgstr "извеждане на всички адреси"
 
-#: builtin/remote.c:1505
+#: builtin/remote.c:1507
 #, c-format
 msgid "no URLs configured for remote '%s'"
 msgstr "не е зададен адрес за отдалеченото хранилище „%s“"
 
-#: builtin/remote.c:1531
+#: builtin/remote.c:1533
 msgid "manipulate push URLs"
 msgstr "промяна на адресите за изтласкване"
 
-#: builtin/remote.c:1533
+#: builtin/remote.c:1535
 msgid "add URL"
 msgstr "добавяне на адреси"
 
-#: builtin/remote.c:1535
+#: builtin/remote.c:1537
 msgid "delete URLs"
 msgstr "изтриване на адреси"
 
-#: builtin/remote.c:1542
+#: builtin/remote.c:1544
 msgid "--add --delete doesn't make sense"
 msgstr "опциите „--add“ и „--delete“ са несъвместими"
 
-#: builtin/remote.c:1581
+#: builtin/remote.c:1583
 #, c-format
 msgid "Invalid old URL pattern: %s"
 msgstr "Неправилен (стар) формат за адрес: %s"
 
-#: builtin/remote.c:1589
+#: builtin/remote.c:1591
 #, c-format
 msgid "No such URL found: %s"
 msgstr "Такъв адрес не е открит: %s"
 
-#: builtin/remote.c:1591
+#: builtin/remote.c:1593
 msgid "Will not delete all non-push URLs"
 msgstr "Никой от адресите, които не са за изтласкване, няма да се изтрие"
 
-#: builtin/remote.c:1607
-msgid "be verbose; must be placed before a subcommand"
-msgstr "повече подробности.  Поставя се пред подкоманда"
-
-#: builtin/remote.c:1638
-#, c-format
-msgid "Unknown subcommand: %s"
-msgstr "Непозната подкоманда: %s"
-
-#: builtin/repack.c:18
+#: builtin/repack.c:23
 msgid "git repack [<options>]"
 msgstr "git repack [ОПЦИЯ…]"
 
-#: builtin/repack.c:23
+#: builtin/repack.c:28
 msgid ""
 "Incremental repacks are incompatible with bitmap indexes.  Use\n"
 "--no-write-bitmap-index or disable the pack.writebitmaps configuration."
@@ -13729,100 +19513,144 @@ msgstr ""
 "Ползвайте опцията --no-write-bitmap-index или изключете настройката\n"
 "„pack.writebitmaps“."
 
-#: builtin/repack.c:180
+#: builtin/repack.c:191
+msgid "could not start pack-objects to repack promisor objects"
+msgstr ""
+"командата „pack-objects“ не може да се стартира за препакетирането на "
+"гарантиращите обекти"
+
+#: builtin/repack.c:230 builtin/repack.c:416
+msgid "repack: Expecting full hex object ID lines only from pack-objects."
+msgstr ""
+"repack: от „pack-objects“ се изискват редове само с пълни шестнайсетични "
+"указатели."
+
+#: builtin/repack.c:254
+msgid "could not finish pack-objects to repack promisor objects"
+msgstr ""
+"командата „pack-objects“ не може да завърши за препакетирането на "
+"гарантиращите обекти"
+
+#: builtin/repack.c:292
 msgid "pack everything in a single pack"
 msgstr "пакетиране на всичко в пакет"
 
-#: builtin/repack.c:182
+#: builtin/repack.c:294
 msgid "same as -a, and turn unreachable objects loose"
 msgstr ""
 "същото като опцията „-a“.  Допълнително — недостижимите обекти да станат "
 "непакетирани"
 
-#: builtin/repack.c:185
+#: builtin/repack.c:297
 msgid "remove redundant packs, and run git-prune-packed"
 msgstr ""
 "премахване на ненужните пакетирани файлове и изпълнение на командата „git-"
 "prune-packed“"
 
-#: builtin/repack.c:187
+#: builtin/repack.c:299
 msgid "pass --no-reuse-delta to git-pack-objects"
 msgstr "подаване на опцията „--no-reuse-delta“ на командата „git-pack-objects“"
 
-#: builtin/repack.c:189
+#: builtin/repack.c:301
 msgid "pass --no-reuse-object to git-pack-objects"
 msgstr ""
 "подаване на опцията „--no-reuse-object“ на командата „git-pack-objects“"
 
-#: builtin/repack.c:191
+#: builtin/repack.c:303
 msgid "do not run git-update-server-info"
 msgstr "без изпълнение на командата „git-update-server-info“"
 
-#: builtin/repack.c:194
+#: builtin/repack.c:306
 msgid "pass --local to git-pack-objects"
 msgstr "подаване на опцията „--local“ на командата „git-pack-objects“"
 
-#: builtin/repack.c:196
+#: builtin/repack.c:308
 msgid "write bitmap index"
 msgstr "създаване и записване на индекси на база битови маски"
 
-#: builtin/repack.c:197
+#: builtin/repack.c:310
+msgid "pass --delta-islands to git-pack-objects"
+msgstr "подаване на опцията „--delta-islands“ на командата „git-pack-objects“"
+
+#: builtin/repack.c:311
 msgid "approxidate"
 msgstr "евристична дата"
 
-#: builtin/repack.c:198
+#: builtin/repack.c:312
 msgid "with -A, do not loosen objects older than this"
 msgstr ""
 "при комбинирането с опцията „-A“ — без разпакетиране на обектите по стари от "
 "това"
 
-#: builtin/repack.c:200
+#: builtin/repack.c:314
 msgid "with -a, repack unreachable objects"
 msgstr "с „-a“ — препакетиране на недостижимите обекти"
 
-#: builtin/repack.c:202
+#: builtin/repack.c:316
 msgid "size of the window used for delta compression"
 msgstr "размер на прозореца за делта компресията"
 
-#: builtin/repack.c:203 builtin/repack.c:209
+#: builtin/repack.c:317 builtin/repack.c:323
 msgid "bytes"
 msgstr "байтове"
 
-#: builtin/repack.c:204
+#: builtin/repack.c:318
 msgid "same as the above, but limit memory size instead of entries count"
 msgstr ""
 "същото като горната опция, но ограничението да е по размер на паметта, а не "
 "по броя на обектите"
 
-#: builtin/repack.c:206
+#: builtin/repack.c:320
 msgid "limits the maximum delta depth"
 msgstr "ограничаване на максималната дълбочина на делтата"
 
-#: builtin/repack.c:208
+#: builtin/repack.c:322
 msgid "limits the maximum number of threads"
 msgstr "ограничаване на максималния брой нишки"
 
-#: builtin/repack.c:210
+#: builtin/repack.c:324
 msgid "maximum size of each packfile"
 msgstr "максимален размер на всеки пакет"
 
-#: builtin/repack.c:212
+#: builtin/repack.c:326
 msgid "repack objects in packs marked with .keep"
 msgstr "препакетиране на обектите в пакети белязани с „.keep“"
 
-#: builtin/repack.c:214
+#: builtin/repack.c:328
 msgid "do not repack this pack"
 msgstr "без препакетиране на този пакет"
 
-#: builtin/repack.c:224
+#: builtin/repack.c:338
 msgid "cannot delete packs in a precious-objects repo"
 msgstr "пакетите в хранилище с важни обекти не може да се трият"
 
-#: builtin/repack.c:228
+#: builtin/repack.c:342
 msgid "--keep-unreachable and -A are incompatible"
 msgstr "Опциите „--keep-unreachable“ и „-A“ са несъвместими"
 
-#: builtin/repack.c:425 builtin/worktree.c:139
+#: builtin/repack.c:425
+msgid "Nothing new to pack."
+msgstr "Нищо ново за пакетиране"
+
+#: builtin/repack.c:486
+#, c-format
+msgid ""
+"WARNING: Some packs in use have been renamed by\n"
+"WARNING: prefixing old- to their name, in order to\n"
+"WARNING: replace them with the new version of the\n"
+"WARNING: file.  But the operation failed, and the\n"
+"WARNING: attempt to rename them back to their\n"
+"WARNING: original names also failed.\n"
+"WARNING: Please rename them in %s manually:\n"
+msgstr ""
+"ПРЕДУПРЕЖДЕНИЕ: За да бъдат заменени с нови версии, някои\n"
+"ПРЕДУПРЕЖДЕНИЕ: пакетни файлове бяха преименувани, като към\n"
+"ПРЕДУПРЕЖДЕНИЕ: имената им бе добавен префиксът „old-“.\n"
+"ПРЕДУПРЕЖДЕНИЕ: Тази операция бе неуспешна, както и обратната\n"
+"ПРЕДУПРЕЖДЕНИЕ: ѝ — за връщането на първоначалните имена.\n"
+"ПРЕДУПРЕЖДЕНИЕ: Преименувайте файловете в „%s“ ръчно:\n"
+
+#: builtin/repack.c:534
 #, c-format
 msgid "failed to remove '%s'"
 msgstr "директорията „%s“ не може да бъде изтрита"
@@ -13851,22 +19679,121 @@ msgstr "git replace -d ОБЕКТ…"
 msgid "git replace [--format=<format>] [-l [<pattern>]]"
 msgstr "git replace [--format=ФОРМАТ] [-l [ШАБЛОН]]"
 
-#: builtin/replace.c:371 builtin/replace.c:415 builtin/replace.c:445
+#: builtin/replace.c:90
+#, c-format
+msgid ""
+"invalid replace format '%s'\n"
+"valid formats are 'short', 'medium' and 'long'"
+msgstr ""
+"неправилен формат са заместване: „%s“\n"
+"възможните формати са „short“ (кратък), „medium“ (среден) и „long“ (дълъг)"
+
+#: builtin/replace.c:125
+#, c-format
+msgid "replace ref '%s' not found"
+msgstr "указателят за замяна „%s“ не може да бъде открит"
+
+#: builtin/replace.c:141
+#, c-format
+msgid "Deleted replace ref '%s'"
+msgstr "Указателят за замяна е изтрит: „%s“"
+
+#: builtin/replace.c:153
+#, c-format
+msgid "'%s' is not a valid ref name"
+msgstr "„%s“ е неправилно име за указател за замяна"
+
+#: builtin/replace.c:158
+#, c-format
+msgid "replace ref '%s' already exists"
+msgstr "указателят за замяна „%s“ вече съществува"
+
+#: builtin/replace.c:178
+#, c-format
+msgid ""
+"Objects must be of the same type.\n"
+"'%s' points to a replaced object of type '%s'\n"
+"while '%s' points to a replacement object of type '%s'."
+msgstr ""
+"Обектите трябва да са еднакъв вид.\n"
+"„%s“ сочи към заменен обект „%s“,\n"
+"а „%s“ сочи към заместващ обект от вид „%s“."
+
+#: builtin/replace.c:229
+#, c-format
+msgid "unable to open %s for writing"
+msgstr "„%s“ не може да бъде отворен за запис"
+
+#: builtin/replace.c:242
+msgid "cat-file reported failure"
+msgstr "изпълнението на „cat-file“ завърши с грешка"
+
+#: builtin/replace.c:258
+#, c-format
+msgid "unable to open %s for reading"
+msgstr "„%s“ не може да бъде отворен за четене"
+
+#: builtin/replace.c:272
+msgid "unable to spawn mktree"
+msgstr "не може да се създаде процес за „mktree“"
+
+#: builtin/replace.c:276
+msgid "unable to read from mktree"
+msgstr "не може да се прочете от „mktree“"
+
+#: builtin/replace.c:285
+msgid "mktree reported failure"
+msgstr "„mktree“ завърши с грешка"
+
+#: builtin/replace.c:289
+msgid "mktree did not return an object name"
+msgstr "„mktree“ не върна име на обект"
+
+#: builtin/replace.c:298
+#, c-format
+msgid "unable to fstat %s"
+msgstr "„fstat“ не може да се изпълни върху „%s“"
+
+#: builtin/replace.c:303
+msgid "unable to write object to database"
+msgstr "обектът не може да бъде записан в базата от данни"
+
+#: builtin/replace.c:322 builtin/replace.c:378 builtin/replace.c:423
+#: builtin/replace.c:453
+#, c-format
+msgid "not a valid object name: '%s'"
+msgstr "неправилно име на обект: „%s“"
+
+#: builtin/replace.c:326
+#, c-format
+msgid "unable to get object type for %s"
+msgstr "не може да се определи видът на обекта „%s“"
+
+#: builtin/replace.c:342
+msgid "editing object file failed"
+msgstr "неуспешно редактиране на файла с обектите"
+
+#: builtin/replace.c:351
+#, c-format
+msgid "new object is the same as the old one: '%s'"
+msgstr "новият и старият обект са един и същ: „%s“"
+
+#: builtin/replace.c:384
 #, c-format
-msgid "Not a valid object name: '%s'"
-msgstr "Неправилно име на обект: „%s“"
+msgid "could not parse %s as a commit"
+msgstr "„%s“ не може да се анализира като подаване"
 
-#: builtin/replace.c:407
+#: builtin/replace.c:415
 #, c-format
 msgid "bad mergetag in commit '%s'"
 msgstr "етикетът при сливане в подаването „%s“ e неправилен"
 
-#: builtin/replace.c:409
+#: builtin/replace.c:417
 #, c-format
 msgid "malformed mergetag in commit '%s'"
 msgstr "етикетът при сливане в подаването „%s“ e неправилен"
 
-#: builtin/replace.c:421
+#: builtin/replace.c:429
 #, c-format
 msgid ""
 "original commit '%s' contains mergetag '%s' that is discarded; use --edit "
@@ -13875,21 +19802,31 @@ msgstr ""
 "Първоначалното подаване „%s“ съдържа етикета при сливане „%s“, който е "
 "изхвърлен, затова използвайте опцията „--edit“, а не „--graft“."
 
-#: builtin/replace.c:460
+#: builtin/replace.c:468
 #, c-format
-msgid "the original commit '%s' has a gpg signature."
-msgstr "Първоначалното подаване „%s“ е с подпис на GPG."
+msgid "the original commit '%s' has a gpg signature"
+msgstr "първоначалното подаване „%s“ е с подпис на GPG"
 
-#: builtin/replace.c:461
+#: builtin/replace.c:469
 msgid "the signature will be removed in the replacement commit!"
 msgstr "Подписът ще бъде премахнат в заменящото подаване!"
 
-#: builtin/replace.c:471
+#: builtin/replace.c:479
 #, c-format
 msgid "could not write replacement commit for: '%s'"
 msgstr "заменящото подаване за „%s“ не може да бъде записано"
 
-#: builtin/replace.c:514
+#: builtin/replace.c:487
+#, c-format
+msgid "graft for '%s' unnecessary"
+msgstr "присадката за „%s“ е излишна"
+
+#: builtin/replace.c:491
+#, c-format
+msgid "new commit is the same as the old one: '%s'"
+msgstr "новото и старото подаване са едно и също: „%s“"
+
+#: builtin/replace.c:526
 #, c-format
 msgid ""
 "could not convert the following graft(s):\n"
@@ -13898,214 +19835,276 @@ msgstr ""
 "следните присадки не могат да се преобразуват:\n"
 "%s"
 
-#: builtin/replace.c:535
+#: builtin/replace.c:547
 msgid "list replace refs"
 msgstr "извеждане на списъка с указателите за замяна"
 
-#: builtin/replace.c:536
+#: builtin/replace.c:548
 msgid "delete replace refs"
 msgstr "изтриване на указателите за замяна"
 
-#: builtin/replace.c:537
+#: builtin/replace.c:549
 msgid "edit existing object"
 msgstr "редактиране на съществуващ обект"
 
-#: builtin/replace.c:538
+#: builtin/replace.c:550
 msgid "change a commit's parents"
 msgstr "смяна на родителите на подаване"
 
-#: builtin/replace.c:539
+#: builtin/replace.c:551
 msgid "convert existing graft file"
 msgstr "преобразуване на файла за присадките"
 
-#: builtin/replace.c:540
+#: builtin/replace.c:552
 msgid "replace the ref if it exists"
 msgstr "замяна на указателя, ако съществува"
 
-#: builtin/replace.c:542
+#: builtin/replace.c:554
 msgid "do not pretty-print contents for --edit"
 msgstr "без форматирано извеждане на съдържанието — за опцията „--edit“"
 
-#: builtin/replace.c:543
+#: builtin/replace.c:555
 msgid "use this format"
 msgstr "използване на този ФОРМАТ"
 
+#: builtin/replace.c:568
+msgid "--format cannot be used when not listing"
+msgstr "опцията „--format“ изисква извеждане на списък"
+
+#: builtin/replace.c:576
+msgid "-f only makes sense when writing a replacement"
+msgstr "опцията „-f“ изисква запазването на заместител"
+
+#: builtin/replace.c:580
+msgid "--raw only makes sense with --edit"
+msgstr "опцията „--raw“ изисква „--edit“"
+
+#: builtin/replace.c:586
+msgid "-d needs at least one argument"
+msgstr "опцията „-d“ изисква поне един аргумент"
+
+#: builtin/replace.c:592
+msgid "bad number of arguments"
+msgstr "неправилен брой аргументи"
+
+#: builtin/replace.c:598
+msgid "-e needs exactly one argument"
+msgstr "опцията „-e“ изисква поне един аргумент"
+
+#: builtin/replace.c:604
+msgid "-g needs at least one argument"
+msgstr "опцията „-g“ изисква поне един аргумент"
+
+#: builtin/replace.c:610
+msgid "--convert-graft-file takes no argument"
+msgstr "опцията „--convert-graft-file“ не приема аргументи"
+
+#: builtin/replace.c:616
+msgid "only one pattern can be given with -l"
+msgstr "опцията „-l“ приема точно един шаблон"
+
 #: builtin/rerere.c:13
 msgid "git rerere [clear | forget <path>... | status | remaining | diff | gc]"
 msgstr "git rerere [clear | forget ПЪТ… | status | remaining | diff | gc]"
 
-#: builtin/rerere.c:59
+#: builtin/rerere.c:60
 msgid "register clean resolutions in index"
 msgstr "регистриране на чисти корекции на конфликти в индекса"
 
-#: builtin/reset.c:29
+#: builtin/rerere.c:79
+msgid "'git rerere forget' without paths is deprecated"
+msgstr "командата „git rerere forget“ изисква указването на път"
+
+#: builtin/rerere.c:113
+#, c-format
+msgid "unable to generate diff for '%s'"
+msgstr "неуспешно генериране на разлика за „%s“"
+
+#: builtin/reset.c:32
 msgid ""
 "git reset [--mixed | --soft | --hard | --merge | --keep] [-q] [<commit>]"
 msgstr ""
 "git reset [--mixed | --soft | --hard | --merge | --keep] [-q] [ПОДАВАНЕ]"
 
-#: builtin/reset.c:30
-msgid "git reset [-q] [<tree-ish>] [--] <paths>..."
-msgstr "git reset [-q] УКАЗАТЕЛ_КЪМ_ДЪРВО [--] ПЪТИЩА…"
+#: builtin/reset.c:33
+msgid "git reset [-q] [<tree-ish>] [--] <pathspec>..."
+msgstr "git reset [-q] [УКАЗАТЕЛ_КЪМ_ДЪРВО] [--] ПЪТИЩА…"
+
+#: builtin/reset.c:34
+msgid ""
+"git reset [-q] [--pathspec-from-file [--pathspec-file-nul]] [<tree-ish>]"
+msgstr ""
+"git reset [-q] [--pathspec-from-file [--pathspec-file-nul]] "
+"[УКАЗАТЕЛ_КЪМ_ДЪРВО]"
 
-#: builtin/reset.c:31
-msgid "git reset --patch [<tree-ish>] [--] [<paths>...]"
+#: builtin/reset.c:35
+msgid "git reset --patch [<tree-ish>] [--] [<pathspec>...]"
 msgstr "git reset --patch [УКАЗАТЕЛ_КЪМ_ДЪРВО] [--] [ПЪТИЩА…]"
 
-#: builtin/reset.c:37
+#: builtin/reset.c:41
 msgid "mixed"
 msgstr "смесено (mixed)"
 
-#: builtin/reset.c:37
+#: builtin/reset.c:41
 msgid "soft"
 msgstr "меко (soft)"
 
-#: builtin/reset.c:37
+#: builtin/reset.c:41
 msgid "hard"
 msgstr "пълно (hard)"
 
-#: builtin/reset.c:37
+#: builtin/reset.c:41
 msgid "merge"
 msgstr "слято (merge)"
 
-#: builtin/reset.c:37
+#: builtin/reset.c:41
 msgid "keep"
 msgstr "запазващо (keep)"
 
-#: builtin/reset.c:78
+#: builtin/reset.c:82
 msgid "You do not have a valid HEAD."
 msgstr "Указателят „HEAD“ е повреден."
 
-#: builtin/reset.c:80
+#: builtin/reset.c:84
 msgid "Failed to find tree of HEAD."
 msgstr "Дървото, сочено от указателя „HEAD“, не може да бъде открито."
 
-#: builtin/reset.c:86
+#: builtin/reset.c:90
 #, c-format
 msgid "Failed to find tree of %s."
 msgstr "Дървото, сочено от „%s“, не може да бъде открито."
 
-#: builtin/reset.c:111
+#: builtin/reset.c:115
 #, c-format
 msgid "HEAD is now at %s"
 msgstr "Указателят „HEAD“ сочи към „%s“"
 
-#: builtin/reset.c:189
+#: builtin/reset.c:194
 #, c-format
 msgid "Cannot do a %s reset in the middle of a merge."
 msgstr "Не може да се извърши %s зануляване по време на сливане."
 
-#: builtin/reset.c:289
+#: builtin/reset.c:294 builtin/stash.c:519 builtin/stash.c:594
+#: builtin/stash.c:618
 msgid "be quiet, only report errors"
 msgstr "по-малко подробности, да се извеждат само грешките"
 
-#: builtin/reset.c:291
+#: builtin/reset.c:296
 msgid "reset HEAD and index"
 msgstr "индекса и указателя „HEAD“, без работното дърво"
 
-#: builtin/reset.c:292
+#: builtin/reset.c:297
 msgid "reset only HEAD"
 msgstr "само указателя „HEAD“, без индекса и работното дърво"
 
-#: builtin/reset.c:294 builtin/reset.c:296
+#: builtin/reset.c:299 builtin/reset.c:301
 msgid "reset HEAD, index and working tree"
 msgstr "указателя „HEAD“, индекса и работното дърво"
 
-#: builtin/reset.c:298
+#: builtin/reset.c:303
 msgid "reset HEAD but keep local changes"
 msgstr "зануляване на указателя „HEAD“, но запазване на локалните промени"
 
-#: builtin/reset.c:304
+#: builtin/reset.c:309
 msgid "record only the fact that removed paths will be added later"
 msgstr ""
 "отбелязване само на факта, че изтритите пътища ще бъдат добавени по-късно"
 
-#: builtin/reset.c:321
+#: builtin/reset.c:343
 #, c-format
 msgid "Failed to resolve '%s' as a valid revision."
 msgstr "Стойността „%s“ не е разпозната като съществуваща версия."
 
-#: builtin/reset.c:329
+#: builtin/reset.c:351
 #, c-format
 msgid "Failed to resolve '%s' as a valid tree."
 msgstr "„%s“ не е разпознат като дърво."
 
-#: builtin/reset.c:338
+#: builtin/reset.c:360
 msgid "--patch is incompatible with --{hard,mixed,soft}"
 msgstr ""
-"опцията „--patch“ е несъвместима с всяка от опциите „--hard/--mixed/--soft“"
+"опцията „--patch“ е несъвместима с всяка от опциите „--hard“/„--mixed“/„--"
+"soft“"
 
-#: builtin/reset.c:347
+#: builtin/reset.c:370
 msgid "--mixed with paths is deprecated; use 'git reset -- <paths>' instead."
 msgstr ""
 "опцията „--mixed“ не бива да се използва заедно с пътища.  Вместо това "
 "изпълнете „git reset -- ПЪТ…“."
 
-#: builtin/reset.c:349
+#: builtin/reset.c:372
 #, c-format
 msgid "Cannot do %s reset with paths."
 msgstr "Не може да извършите %s зануляване, когато сте задали ПЪТ."
 
-#: builtin/reset.c:359
+#: builtin/reset.c:387
 #, c-format
 msgid "%s reset is not allowed in a bare repository"
 msgstr "В голо хранилище не може да извършите %s зануляване"
 
-#: builtin/reset.c:363
+#: builtin/reset.c:391
 msgid "-N can only be used with --mixed"
-msgstr "Опцията „-N“ е съвместима само с „--mixed“"
+msgstr "Опцията „-N“ изисква опцията „--mixed“"
 
-#: builtin/reset.c:380
+#: builtin/reset.c:412
 msgid "Unstaged changes after reset:"
 msgstr "Промени извън индекса след зануляването:"
 
-#: builtin/reset.c:386
+#: builtin/reset.c:415
+#, c-format
+msgid ""
+"\n"
+"It took %.2f seconds to enumerate unstaged changes after reset.  You can\n"
+"use '--quiet' to avoid this.  Set the config setting reset.quiet to true\n"
+"to make this the default.\n"
+msgstr ""
+"\n"
+"Изброяването на промените извън индекса след зануляване отне %.2f сек.\n"
+"Опцията „--quiet“ заглушава това съобщение еднократно.  За постоянно\n"
+"заглушаване задайте настройката „reset.quiet“ да е „true“ (истина).\n"
+
+#: builtin/reset.c:425
 #, c-format
 msgid "Could not reset index file to revision '%s'."
 msgstr "Индексът не може да бъде занулен към версия „%s“."
 
-#: builtin/reset.c:390
+#: builtin/reset.c:429
 msgid "Could not write new index file."
 msgstr "Новият индекс не може да бъде записан."
 
-#: builtin/rev-list.c:397
+#: builtin/rev-list.c:411
 msgid "cannot combine --exclude-promisor-objects and --missing"
 msgstr "опциите „--exclude-promisor-objects“ и „--missing“ и са несъвместими"
 
-#: builtin/rev-list.c:455
+#: builtin/rev-list.c:472
 msgid "object filtering requires --objects"
 msgstr "филтрирането на обекти изисква опцията „--objects“"
 
-#: builtin/rev-list.c:458
-#, c-format
-msgid "invalid sparse value '%s'"
-msgstr "неправилна частична стойност: %s"
-
-#: builtin/rev-list.c:499
+#: builtin/rev-list.c:522
 msgid "rev-list does not support display of notes"
 msgstr "командата „rev-list“ не поддържа извеждането на бележки"
 
-#: builtin/rev-list.c:502
+#: builtin/rev-list.c:525
 msgid "cannot combine --use-bitmap-index with object filtering"
 msgstr "опцията „--use-bitmap-index“ е несъвместима с филтриране на обектите"
 
-#: builtin/rev-parse.c:406
+#: builtin/rev-parse.c:408
 msgid "git rev-parse --parseopt [<options>] -- [<args>...]"
 msgstr "git rev-parse --parseopt [ОПЦИЯ…] -- [АРГУМЕНТ…]"
 
-#: builtin/rev-parse.c:411
+#: builtin/rev-parse.c:413
 msgid "keep the `--` passed as an arg"
 msgstr "зададеният низ „--“ да се тълкува като аргумент"
 
-#: builtin/rev-parse.c:413
+#: builtin/rev-parse.c:415
 msgid "stop parsing after the first non-option argument"
 msgstr "спиране на анализа след първия аргумент, който не е опция"
 
-#: builtin/rev-parse.c:416
+#: builtin/rev-parse.c:418
 msgid "output in stuck long form"
 msgstr "изход в дългия формат"
 
-#: builtin/rev-parse.c:549
+#: builtin/rev-parse.c:551
 msgid ""
 "git rev-parse --parseopt [<options>] -- [<args>...]\n"
 "   or: git rev-parse --sq-quote [<arg>...]\n"
@@ -14120,92 +20119,97 @@ msgstr ""
 "За повече информация за първия вариант изпълнете „git rev-parse --parseopt -"
 "h“"
 
-#: builtin/revert.c:23
+#: builtin/revert.c:24
 msgid "git revert [<options>] <commit-ish>..."
 msgstr "git revert [ОПЦИЯ…] УКАЗАТЕЛ_КЪМ_ПОДАВАНЕ…"
 
-#: builtin/revert.c:24
+#: builtin/revert.c:25
 msgid "git revert <subcommand>"
 msgstr "git revert ПОДКОМАНДА"
 
-#: builtin/revert.c:29
+#: builtin/revert.c:30
 msgid "git cherry-pick [<options>] <commit-ish>..."
 msgstr "git cherry-pick [ОПЦИЯ…] УКАЗАТЕЛ_КЪМ_ПОДАВАНЕ…"
 
-#: builtin/revert.c:30
+#: builtin/revert.c:31
 msgid "git cherry-pick <subcommand>"
 msgstr "git cherry-pick ПОДКОМАНДА"
 
-#: builtin/revert.c:90
+#: builtin/revert.c:72
+#, c-format
+msgid "option `%s' expects a number greater than zero"
+msgstr "опцията „%s“ очаква положително число за аргумент"
+
+#: builtin/revert.c:92
 #, c-format
 msgid "%s: %s cannot be used with %s"
 msgstr "%s: опцията „%s“ е несъвместима с „%s“"
 
-#: builtin/revert.c:99
+#: builtin/revert.c:102
 msgid "end revert or cherry-pick sequence"
 msgstr "завършване на поредица от отбирания или отмени на подавания"
 
-#: builtin/revert.c:100
+#: builtin/revert.c:103
 msgid "resume revert or cherry-pick sequence"
 msgstr "продължаване на поредица от отбирания или отмени на подавания"
 
-#: builtin/revert.c:101
+#: builtin/revert.c:104
 msgid "cancel revert or cherry-pick sequence"
 msgstr "отмяна на поредица от отбирания или отмени на подавания"
 
-#: builtin/revert.c:102
+#: builtin/revert.c:105
+msgid "skip current commit and continue"
+msgstr "прескачане на текущото подаване и продължаване"
+
+#: builtin/revert.c:107
 msgid "don't automatically commit"
 msgstr "без автоматично подаване"
 
-#: builtin/revert.c:103
+#: builtin/revert.c:108
 msgid "edit the commit message"
 msgstr "редактиране на съобщението при подаване"
 
-#: builtin/revert.c:106
+#: builtin/revert.c:111
 msgid "parent-number"
 msgstr "номер на родителя"
 
-#: builtin/revert.c:107
+#: builtin/revert.c:112
 msgid "select mainline parent"
 msgstr "избор на основния родител"
 
-#: builtin/revert.c:109
+#: builtin/revert.c:114
 msgid "merge strategy"
 msgstr "стратегия на сливане"
 
-#: builtin/revert.c:110
-msgid "option"
-msgstr "опция"
-
-#: builtin/revert.c:111
+#: builtin/revert.c:116
 msgid "option for merge strategy"
 msgstr "опция за стратегията на сливане"
 
-#: builtin/revert.c:120
+#: builtin/revert.c:125
 msgid "append commit name"
 msgstr "добавяне на името на подаването"
 
-#: builtin/revert.c:122
+#: builtin/revert.c:127
 msgid "preserve initially empty commits"
 msgstr "запазване на първоначално празните подавания"
 
-#: builtin/revert.c:124
+#: builtin/revert.c:129
 msgid "keep redundant, empty commits"
 msgstr "запазване на излишните, празни подавания"
 
-#: builtin/revert.c:214
+#: builtin/revert.c:232
 msgid "revert failed"
 msgstr "неуспешна отмяна"
 
-#: builtin/revert.c:227
+#: builtin/revert.c:245
 msgid "cherry-pick failed"
 msgstr "неуспешно отбиране"
 
-#: builtin/rm.c:18
+#: builtin/rm.c:19
 msgid "git rm [<options>] [--] <file>..."
 msgstr "git rm [ОПЦИЯ…] [--] ФАЙЛ…"
 
-#: builtin/rm.c:206
+#: builtin/rm.c:207
 msgid ""
 "the following file has staged content different from both the\n"
 "file and the HEAD:"
@@ -14221,7 +20225,7 @@ msgstr[1] ""
 "съдържание и\n"
 "различно от съответстващото на HEAD:"
 
-#: builtin/rm.c:211
+#: builtin/rm.c:212
 msgid ""
 "\n"
 "(use -f to force removal)"
@@ -14229,13 +20233,13 @@ msgstr ""
 "\n"
 "(за принудително изтриване използвайте опцията „-f“)"
 
-#: builtin/rm.c:215
+#: builtin/rm.c:216
 msgid "the following file has changes staged in the index:"
 msgid_plural "the following files have changes staged in the index:"
 msgstr[0] "следният файл е с променено съдържание в индекса:"
 msgstr[1] "следните файлове са с променено съдържание в индекса:"
 
-#: builtin/rm.c:219 builtin/rm.c:228
+#: builtin/rm.c:220 builtin/rm.c:229
 msgid ""
 "\n"
 "(use --cached to keep the file, or -f to force removal)"
@@ -14244,49 +20248,50 @@ msgstr ""
 "(за запазване на файла използвайте опцията „--cached“, а за принудително\n"
 "изтриване — „-f“)"
 
-#: builtin/rm.c:225
+#: builtin/rm.c:226
 msgid "the following file has local modifications:"
 msgid_plural "the following files have local modifications:"
 msgstr[0] "следният файл е с променено съдържание"
 msgstr[1] "следните файлове са с променено съдържание"
 
-#: builtin/rm.c:241
+#: builtin/rm.c:242
 msgid "do not list removed files"
 msgstr "да не се извеждат изтритите файлове"
 
-#: builtin/rm.c:242
+#: builtin/rm.c:243
 msgid "only remove from the index"
 msgstr "изтриване само от индекса"
 
-#: builtin/rm.c:243
+#: builtin/rm.c:244
 msgid "override the up-to-date check"
 msgstr "въпреки проверката за актуалността на съдържанието"
 
-#: builtin/rm.c:244
+#: builtin/rm.c:245
 msgid "allow recursive removal"
 msgstr "рекурсивно изтриване"
 
-#: builtin/rm.c:246
+#: builtin/rm.c:247
 msgid "exit with a zero status even if nothing matched"
 msgstr ""
 "изходният код да е 0, дори ако никой файл нe e напаснал с шаблона за "
 "изтриване"
 
-#: builtin/rm.c:306
+#: builtin/rm.c:289
+msgid "please stage your changes to .gitmodules or stash them to proceed"
+msgstr ""
+"за да продължите, или вкарайте промените по файла „.gitmodules“ в индекса,\n"
+"или ги скатайте"
+
+#: builtin/rm.c:307
 #, c-format
 msgid "not removing '%s' recursively without -r"
 msgstr "без използването на опцията „-r“ „%s“ няма да се изтрие рекурсивно"
 
-#: builtin/rm.c:345
+#: builtin/rm.c:346
 #, c-format
 msgid "git rm: unable to remove %s"
 msgstr "git rm: „%s“ не може да се изтрие"
 
-#: builtin/rm.c:368
-#, c-format
-msgid "could not remove '%s'"
-msgstr "„%s“ не може да бъде изтрит"
-
 #: builtin/send-pack.c:20
 msgid ""
 "git send-pack [--all | --mirror] [--dry-run] [--force] [--receive-pack=<git-"
@@ -14314,18 +20319,6 @@ msgstr "четене на указате
 msgid "print status from remote helper"
 msgstr "извеждане на състоянието от отдалечената помощна функция"
 
-#: builtin/serve.c:7
-msgid "git serve [<options>]"
-msgstr "git serve [ОПЦИЯ…]"
-
-#: builtin/serve.c:17 builtin/upload-pack.c:23
-msgid "quit after a single request/response exchange"
-msgstr "изход след първоначалната размяна на заявка и отговор"
-
-#: builtin/serve.c:19
-msgid "exit immediately after advertising capabilities"
-msgstr "изход след първоначалната обява на възможностите"
-
 #: builtin/shortlog.c:14
 msgid "git shortlog [<options>] [<revision-range>] [[--] <path>...]"
 msgstr "git shortlog [ОПЦИЯ…] [ДИАПАЗОН_НА_ВЕРСИИТЕ] [[--] [ПЪТ…]]"
@@ -14351,8 +20344,8 @@ msgid "Show the email address of each au
 msgstr "Извеждане на адреса на е-поща за всеки автор"
 
 #: builtin/shortlog.c:271
-msgid "w[,i1[,i2]]"
-msgstr "ШИРОЧИНА[,ОТСТЪП_1[,ОТСТЪП_2]]"
+msgid "<w>[,<i1>[,<i2>]]"
+msgstr "<ШИРОЧИНА>[,<ОТСТЪП_1>[,<ОТСТЪП_2>]]"
 
 #: builtin/shortlog.c:272
 msgid "Linewrap output"
@@ -14360,11 +20353,11 @@ msgstr ""
 "Пренасяне на редовете до тази обща ШИРОЧИНА (76), с ОТСТЪП_1 (6) за първия "
 "ред и ОТСТЪП_2 (9) за останалите"
 
-#: builtin/shortlog.c:298
+#: builtin/shortlog.c:301
 msgid "too many arguments given outside repository"
 msgstr "прекалено много аргументи извън хранилище"
 
-#: builtin/show-branch.c:12
+#: builtin/show-branch.c:13
 msgid ""
 "git show-branch [-a | --all] [-r | --remotes] [--topo-order | --date-order]\n"
 "\t\t[--current] [--color[=<when>] | --no-color] [--sparse]\n"
@@ -14376,133 +20369,133 @@ msgstr ""
 "    [--more=БРОЙ | --list | --independent | --merge-base]\n"
 "    [--no-name | --sha1-name] [--topics] [(РЕВИЗИЯ | УКАЗАТЕЛ)…]"
 
-#: builtin/show-branch.c:16
+#: builtin/show-branch.c:17
 msgid "git show-branch (-g | --reflog)[=<n>[,<base>]] [--list] [<ref>]"
 msgstr "git show-branch (-g | --reflog)[=БРОЙ[,БАЗА]] [--list] [УКАЗАТЕЛ]"
 
-#: builtin/show-branch.c:376
+#: builtin/show-branch.c:395
 #, c-format
 msgid "ignoring %s; cannot handle more than %d ref"
 msgid_plural "ignoring %s; cannot handle more than %d refs"
 msgstr[0] "„%s“ се прескача — не може да се обработят повече от %d указател"
 msgstr[1] "„%s“ се прескача — не може да се обработят повече от %d указатели"
 
-#: builtin/show-branch.c:530
+#: builtin/show-branch.c:548
 #, c-format
 msgid "no matching refs with %s"
 msgstr "никой указател не съвпада с „%s“"
 
-#: builtin/show-branch.c:626
+#: builtin/show-branch.c:645
 msgid "show remote-tracking and local branches"
 msgstr "извеждане на следящите и локалните клони"
 
-#: builtin/show-branch.c:628
+#: builtin/show-branch.c:647
 msgid "show remote-tracking branches"
 msgstr "извеждане на следящите клони"
 
-#: builtin/show-branch.c:630
+#: builtin/show-branch.c:649
 msgid "color '*!+-' corresponding to the branch"
 msgstr "оцветяване на „*!+-“ според клоните"
 
-#: builtin/show-branch.c:632
+#: builtin/show-branch.c:651
 msgid "show <n> more commits after the common ancestor"
 msgstr "извеждане на такъв БРОЙ подавания от общия предшественик"
 
-#: builtin/show-branch.c:634
+#: builtin/show-branch.c:653
 msgid "synonym to more=-1"
-msgstr "синоним на „more=-1“"
+msgstr "псевдоним на „more=-1“"
 
-#: builtin/show-branch.c:635
+#: builtin/show-branch.c:654
 msgid "suppress naming strings"
 msgstr "без низове за имената на клоните"
 
-#: builtin/show-branch.c:637
+#: builtin/show-branch.c:656
 msgid "include the current branch"
 msgstr "включване и на текущия клон"
 
-#: builtin/show-branch.c:639
+#: builtin/show-branch.c:658
 msgid "name commits with their object names"
 msgstr "именуване на подаванията с имената им на обекти"
 
-#: builtin/show-branch.c:641
+#: builtin/show-branch.c:660
 msgid "show possible merge bases"
 msgstr "извеждане на възможните бази за сливания"
 
-#: builtin/show-branch.c:643
+#: builtin/show-branch.c:662
 msgid "show refs unreachable from any other ref"
 msgstr "извеждане на недостижимите указатели"
 
-#: builtin/show-branch.c:645
+#: builtin/show-branch.c:664
 msgid "show commits in topological order"
 msgstr "извеждане на подаванията в топологическа подредба"
 
-#: builtin/show-branch.c:648
+#: builtin/show-branch.c:667
 msgid "show only commits not on the first branch"
 msgstr "извеждане само на подаванията, които не са от първия клон"
 
-#: builtin/show-branch.c:650
+#: builtin/show-branch.c:669
 msgid "show merges reachable from only one tip"
 msgstr "извеждане на сливанията, които могат да се достигнат само от един връх"
 
-#: builtin/show-branch.c:652
+#: builtin/show-branch.c:671
 msgid "topologically sort, maintaining date order where possible"
 msgstr ""
 "топологическа подредба, при запазване на подредбата по дата, доколкото е\n"
 "възможно"
 
-#: builtin/show-branch.c:655
+#: builtin/show-branch.c:674
 msgid "<n>[,<base>]"
 msgstr "БРОЙ[,БАЗА]"
 
-#: builtin/show-branch.c:656
+#: builtin/show-branch.c:675
 msgid "show <n> most recent ref-log entries starting at base"
 msgstr "показване на най-много БРОЙ журнални записа с начало съответната БАЗА"
 
-#: builtin/show-branch.c:690
+#: builtin/show-branch.c:711
 msgid ""
 "--reflog is incompatible with --all, --remotes, --independent or --merge-base"
 msgstr ""
 "опцията „--reflog“ е несъвместима с опциите  „--all“, „--remotes“, „--"
 "independent“ и „--merge-base“"
 
-#: builtin/show-branch.c:714
+#: builtin/show-branch.c:735
 msgid "no branches given, and HEAD is not valid"
 msgstr "не е зададен клон, а указателят „HEAD“ е неправилен"
 
-#: builtin/show-branch.c:717
+#: builtin/show-branch.c:738
 msgid "--reflog option needs one branch name"
 msgstr "опцията „--track“ изисква точно едно име на клон"
 
-#: builtin/show-branch.c:720
+#: builtin/show-branch.c:741
 #, c-format
 msgid "only %d entry can be shown at one time."
 msgid_plural "only %d entries can be shown at one time."
 msgstr[0] "само %d запис може да бъде показан наведнъж."
 msgstr[1] "само %d записа може да бъде показани наведнъж."
 
-#: builtin/show-branch.c:724
+#: builtin/show-branch.c:745
 #, c-format
 msgid "no such ref %s"
 msgstr "такъв указател няма: %s"
 
-#: builtin/show-branch.c:808
+#: builtin/show-branch.c:831
 #, c-format
 msgid "cannot handle more than %d rev."
 msgid_plural "cannot handle more than %d revs."
 msgstr[0] "не може да се обработи повече от %d указател."
 msgstr[1] "не може да се обработят повече от %d указатели."
 
-#: builtin/show-branch.c:812
+#: builtin/show-branch.c:835
 #, c-format
 msgid "'%s' is not a valid ref."
 msgstr "„%s“ е неправилен указател."
 
-#: builtin/show-branch.c:815
+#: builtin/show-branch.c:838
 #, c-format
 msgid "cannot find commit %s (%s)"
 msgstr "подаването „%s“ (%s) липсва"
 
-#: builtin/show-ref.c:10
+#: builtin/show-ref.c:12
 msgid ""
 "git show-ref [-q | --quiet] [--verify] [--head] [-d | --dereference] [-s | --"
 "hash[=<n>]] [--abbrev[=<n>]] [--tags] [--heads] [--] [<pattern>...]"
@@ -14510,46 +20503,324 @@ msgstr ""
 "git show-ref [-q | --quiet] [--verify] [--head] [-d | --dereference] [-s | --"
 "hash[=ЧИСЛО]] [--abbrev[=ЧИСЛО]] [--tags] [--heads] [--] [ШАБЛОН…]"
 
-#: builtin/show-ref.c:11
+#: builtin/show-ref.c:13
 msgid "git show-ref --exclude-existing[=<pattern>]"
 msgstr "git show-ref --exclude-existing[=ШАБЛОН]"
 
-#: builtin/show-ref.c:159
+#: builtin/show-ref.c:162
 msgid "only show tags (can be combined with heads)"
 msgstr "извеждане на етикетите (може да се комбинира с върховете)"
 
-#: builtin/show-ref.c:160
+#: builtin/show-ref.c:163
 msgid "only show heads (can be combined with tags)"
 msgstr "извеждане на върховете (може да се комбинира с етикетите)"
 
-#: builtin/show-ref.c:161
+#: builtin/show-ref.c:164
 msgid "stricter reference checking, requires exact ref path"
 msgstr "строга проверка на указателите, изисква се указател с пълен път"
 
-#: builtin/show-ref.c:164 builtin/show-ref.c:166
+#: builtin/show-ref.c:167 builtin/show-ref.c:169
 msgid "show the HEAD reference, even if it would be filtered out"
 msgstr "задължително извеждане и на указателя HEAD"
 
-#: builtin/show-ref.c:168
+#: builtin/show-ref.c:171
 msgid "dereference tags into object IDs"
 msgstr "да се извеждат идентификаторите на обектите-етикети"
 
-#: builtin/show-ref.c:170
+#: builtin/show-ref.c:173
 msgid "only show SHA1 hash using <n> digits"
 msgstr "извеждане само на този БРОЙ цифри от всяка сума по SHA1"
 
-#: builtin/show-ref.c:174
+#: builtin/show-ref.c:177
 msgid "do not print results to stdout (useful with --verify)"
 msgstr ""
 "без извеждане на резултатите на стандартния изход (полезно с опцията „--"
 "verify“)"
 
-#: builtin/show-ref.c:176
+#: builtin/show-ref.c:179
 msgid "show refs from stdin that aren't in local repository"
 msgstr ""
 "извеждане на указателите приети от стандартния вход, които липсват в "
 "локалното хранилище"
 
+#: builtin/sparse-checkout.c:20
+msgid "git sparse-checkout (init|list|set|disable) <options>"
+msgstr "git sparse-checkout (init|list|set|disable) ОПЦИЯ…"
+
+#: builtin/sparse-checkout.c:63
+msgid "this worktree is not sparse (sparse-checkout file may not exist)"
+msgstr ""
+"това не е частично работно дърво (вероятно липсва файл „sparse-checkout“)"
+
+#: builtin/sparse-checkout.c:241
+msgid "failed to set extensions.worktreeConfig setting"
+msgstr "неуспешно задаване на настройката „extensions.worktreeConfig“"
+
+#: builtin/sparse-checkout.c:258
+msgid "git sparse-checkout init [--cone]"
+msgstr "git sparse-checkout init [--cone]"
+
+#: builtin/sparse-checkout.c:277
+msgid "initialize the sparse-checkout in cone mode"
+msgstr "инициализиране на частичното изтегляне в пътеводен режим"
+
+#: builtin/sparse-checkout.c:283
+msgid "initialize sparse-checkout"
+msgstr "инициализиране на частичното изтегляне"
+
+#: builtin/sparse-checkout.c:316
+#, c-format
+msgid "failed to open '%s'"
+msgstr "„%s“ не може да се отвори"
+
+#: builtin/sparse-checkout.c:382
+msgid "git sparse-checkout set (--stdin | <patterns>)"
+msgstr "git sparse-checkout set (--stdin | ШАБЛОН…)"
+
+#: builtin/sparse-checkout.c:399
+msgid "read patterns from standard in"
+msgstr "изчитане на шаблоните от стандартния вход"
+
+#: builtin/sparse-checkout.c:405
+msgid "set sparse-checkout patterns"
+msgstr "задаване на шаблоните за частичното изтегляне"
+
+#: builtin/sparse-checkout.c:468
+msgid "disable sparse-checkout"
+msgstr "без използване на частично изтегляне"
+
+#: builtin/sparse-checkout.c:480
+msgid "error while refreshing working directory"
+msgstr "грешка при обновяване на работната директория"
+
+#: builtin/stash.c:22 builtin/stash.c:37
+msgid "git stash list [<options>]"
+msgstr "git stash list [ОПЦИЯ…]"
+
+#: builtin/stash.c:23 builtin/stash.c:42
+msgid "git stash show [<options>] [<stash>]"
+msgstr "git stash show [ОПЦИЯ…] [СКАТАНО]"
+
+#: builtin/stash.c:24 builtin/stash.c:47
+msgid "git stash drop [-q|--quiet] [<stash>]"
+msgstr "git stash drop [-q|--quiet] [СКАТАНО]"
+
+#: builtin/stash.c:25
+msgid "git stash ( pop | apply ) [--index] [-q|--quiet] [<stash>]"
+msgstr "git stash ( pop | apply ) [--index] [-q|--quiet] [СКАТАНО]"
+
+#: builtin/stash.c:26 builtin/stash.c:62
+msgid "git stash branch <branchname> [<stash>]"
+msgstr "git stash branch КЛОН [СКАТАНО]"
+
+#: builtin/stash.c:27 builtin/stash.c:67
+msgid "git stash clear"
+msgstr "git stash clear"
+
+#: builtin/stash.c:28 builtin/stash.c:77
+msgid ""
+"git stash [push [-p|--patch] [-k|--[no-]keep-index] [-q|--quiet]\n"
+"          [-u|--include-untracked] [-a|--all] [-m|--message <message>]\n"
+"          [--] [<pathspec>...]]"
+msgstr ""
+"git stash [push [-p|--patch] [-k|--[no-]keep-index] [-q|--quiet]\n"
+"          [-u|--include-untracked] [-a|--all] [-m|--message СЪОБЩЕНИЕ]\n"
+"          [--] [ПЪТ…]]"
+
+#: builtin/stash.c:31 builtin/stash.c:84
+msgid ""
+"git stash save [-p|--patch] [-k|--[no-]keep-index] [-q|--quiet]\n"
+"          [-u|--include-untracked] [-a|--all] [<message>]"
+msgstr ""
+"git stash save [-p|--patch] [-k|--[no-]keep-index] [-q|--quiet]\n"
+"          [-u|--include-untracked] [-a|--all] [СЪОБЩЕНИЕ]"
+
+#: builtin/stash.c:52
+msgid "git stash pop [--index] [-q|--quiet] [<stash>]"
+msgstr "git stash pop [--index] [-q|--quiet] [СКАТАНО]"
+
+#: builtin/stash.c:57
+msgid "git stash apply [--index] [-q|--quiet] [<stash>]"
+msgstr "git stash apply [--index] [-q|--quiet] [СКАТАНО]"
+
+#: builtin/stash.c:72
+msgid "git stash store [-m|--message <message>] [-q|--quiet] <commit>"
+msgstr "git stash store [-m|--message СЪОБЩЕНИЕ] [-q|--quiet] ПОДАВАНЕ"
+
+#: builtin/stash.c:127
+#, c-format
+msgid "'%s' is not a stash-like commit"
+msgstr "„%s“ не е подаване, приличащо на нещо скатано"
+
+#: builtin/stash.c:147
+#, c-format
+msgid "Too many revisions specified:%s"
+msgstr "Указани са прекалено много версии:%s"
+
+#: builtin/stash.c:161 git-legacy-stash.sh:549
+msgid "No stash entries found."
+msgstr "Не е открито нищо скатано."
+
+#: builtin/stash.c:175
+#, c-format
+msgid "%s is not a valid reference"
+msgstr "„%s“ е неправилно име за указател"
+
+#: builtin/stash.c:224 git-legacy-stash.sh:75
+msgid "git stash clear with parameters is unimplemented"
+msgstr "командата „git stash clear“ не поддържа аргументи"
+
+#: builtin/stash.c:403
+msgid "cannot apply a stash in the middle of a merge"
+msgstr "по време на сливане не може да приложите нещо скатано"
+
+#: builtin/stash.c:414
+#, c-format
+msgid "could not generate diff %s^!."
+msgstr "файлът с разликите „%s^!“ не може да се генерира"
+
+#: builtin/stash.c:421
+msgid "conflicts in index.Try without --index."
+msgstr ""
+"в индекса има конфликти.  Пробвайте да изпълните командата без опцията „--"
+"index“."
+
+#: builtin/stash.c:427
+msgid "could not save index tree"
+msgstr "дървото сочено от индекса не може да бъде запазено"
+
+#: builtin/stash.c:436
+msgid "could not restore untracked files from stash"
+msgstr "неследени файлове не могат да се възстановят от скатаното"
+
+#: builtin/stash.c:450
+#, c-format
+msgid "Merging %s with %s"
+msgstr "Сливане на „%s“ с „%s“"
+
+#: builtin/stash.c:460 git-legacy-stash.sh:681
+msgid "Index was not unstashed."
+msgstr "Индексът не е изваден от скатаното."
+
+#: builtin/stash.c:521 builtin/stash.c:620
+msgid "attempt to recreate the index"
+msgstr "опит за повторно създаване на индекса"
+
+#: builtin/stash.c:554
+#, c-format
+msgid "Dropped %s (%s)"
+msgstr "Изтрито: „%s“ (%s)"
+
+#: builtin/stash.c:557
+#, c-format
+msgid "%s: Could not drop stash entry"
+msgstr "Скатаното „%s“ не може да бъде изтрито"
+
+#: builtin/stash.c:582
+#, c-format
+msgid "'%s' is not a stash reference"
+msgstr "„%s“ не е указател към нещо скатано"
+
+#: builtin/stash.c:632 git-legacy-stash.sh:695
+msgid "The stash entry is kept in case you need it again."
+msgstr "Скатаното е запазено в случай, че ви потрябва отново."
+
+#: builtin/stash.c:655 git-legacy-stash.sh:713
+msgid "No branch name specified"
+msgstr "Не е указано име на клон"
+
+#: builtin/stash.c:795 builtin/stash.c:832
+#, c-format
+msgid "Cannot update %s with %s"
+msgstr "Указателят „%s“ не може да бъде обновен да сочи към „%s“"
+
+#: builtin/stash.c:813 builtin/stash.c:1470 builtin/stash.c:1506
+msgid "stash message"
+msgstr "съобщение при скатаване"
+
+#: builtin/stash.c:823
+msgid "\"git stash store\" requires one <commit> argument"
+msgstr "командата „git stash store“ изисква точно един аргумент-ПОДАВАНЕ"
+
+#: builtin/stash.c:1045 git-legacy-stash.sh:218
+msgid "No changes selected"
+msgstr "Не са избрани никакви промени"
+
+#: builtin/stash.c:1145 git-legacy-stash.sh:150
+msgid "You do not have the initial commit yet"
+msgstr "Все още липсва първоначално подаване"
+
+#: builtin/stash.c:1172 git-legacy-stash.sh:165
+msgid "Cannot save the current index state"
+msgstr "Състоянието на текущия индекс не може да бъде запазено"
+
+#: builtin/stash.c:1181 git-legacy-stash.sh:180
+msgid "Cannot save the untracked files"
+msgstr "Неследените файлове не могат да се запазят"
+
+#: builtin/stash.c:1192 builtin/stash.c:1201 git-legacy-stash.sh:201
+#: git-legacy-stash.sh:214
+msgid "Cannot save the current worktree state"
+msgstr "Състоянието на работното дърво не може да бъде запазено"
+
+#: builtin/stash.c:1229 git-legacy-stash.sh:234
+msgid "Cannot record working tree state"
+msgstr "Състоянието на работното дърво не може да бъде запазено"
+
+#: builtin/stash.c:1278 git-legacy-stash.sh:338
+msgid "Can't use --patch and --include-untracked or --all at the same time"
+msgstr "Опцията „--patch“ е несъвместима с „--include-untracked“ и „--all“"
+
+#: builtin/stash.c:1294
+msgid "Did you forget to 'git add'?"
+msgstr "Пробвайте да използвате „git add“"
+
+#: builtin/stash.c:1309 git-legacy-stash.sh:346
+msgid "No local changes to save"
+msgstr "Няма никакви локални промени за скатаване"
+
+#: builtin/stash.c:1316 git-legacy-stash.sh:351
+msgid "Cannot initialize stash"
+msgstr "Скатаването не може да стартира"
+
+#: builtin/stash.c:1331 git-legacy-stash.sh:355
+msgid "Cannot save the current status"
+msgstr "Текущото състояние не може да бъде запазено"
+
+#: builtin/stash.c:1336
+#, c-format
+msgid "Saved working directory and index state %s"
+msgstr "Състоянието на работната директория и индекса e запазено: „%s“"
+
+#: builtin/stash.c:1426 git-legacy-stash.sh:385
+msgid "Cannot remove worktree changes"
+msgstr "Промените в работното дърво не могат да бъдат занулени"
+
+#: builtin/stash.c:1461 builtin/stash.c:1497
+msgid "keep index"
+msgstr "запазване на индекса"
+
+#: builtin/stash.c:1463 builtin/stash.c:1499
+msgid "stash in patch mode"
+msgstr "скатаване в режим за кръпки"
+
+#: builtin/stash.c:1464 builtin/stash.c:1500
+msgid "quiet mode"
+msgstr "без извеждане на информация"
+
+#: builtin/stash.c:1466 builtin/stash.c:1502
+msgid "include untracked files in stash"
+msgstr "скатаване и на неследените файлове"
+
+#: builtin/stash.c:1468 builtin/stash.c:1504
+msgid "include ignore files"
+msgstr "скатаване и на игнорираните файлове"
+
+#: builtin/stash.c:1564
+#, c-format
+msgid "could not exec %s"
+msgstr "„%s“ не може да се изпълни"
+
 #: builtin/stripspace.c:18
 msgid "git stripspace [-s | --strip-comments]"
 msgstr "git stripspace [-s | --strip-comments]"
@@ -14558,105 +20829,138 @@ msgstr "git stripspace [-s | --strip-com
 msgid "git stripspace [-c | --comment-lines]"
 msgstr "git stripspace [-c | --comment-lines]"
 
-#: builtin/stripspace.c:36
+#: builtin/stripspace.c:37
 msgid "skip and remove all lines starting with comment character"
 msgstr "пропускане на всички редове, които започват с „#“"
 
-#: builtin/stripspace.c:39
+#: builtin/stripspace.c:40
 msgid "prepend comment character and space to each line"
 msgstr "добавяне на „# “ в началото на всеки ред"
 
-#: builtin/submodule--helper.c:37 builtin/submodule--helper.c:1688
-#, c-format
-msgid "No such ref: %s"
-msgstr "Такъв указател няма: %s"
-
-#: builtin/submodule--helper.c:44 builtin/submodule--helper.c:1697
+#: builtin/submodule--helper.c:47 builtin/submodule--helper.c:1970
 #, c-format
 msgid "Expecting a full ref name, got %s"
 msgstr "Очаква се пълно име на указател, а не „%s“"
 
-#: builtin/submodule--helper.c:61
+#: builtin/submodule--helper.c:64
 msgid "submodule--helper print-default-remote takes no arguments"
 msgstr ""
 "командата „print-default-remote“ на „submodule--helper“ не приема аргументи"
 
-#: builtin/submodule--helper.c:98
+#: builtin/submodule--helper.c:102
 #, c-format
 msgid "cannot strip one component off url '%s'"
 msgstr "не може да се махне компонент от адреса „%s“"
 
-#: builtin/submodule--helper.c:406 builtin/submodule--helper.c:1211
+#: builtin/submodule--helper.c:410 builtin/submodule--helper.c:1380
 msgid "alternative anchor for relative paths"
 msgstr "директория за определянето на относителните пътища"
 
-#: builtin/submodule--helper.c:411
+#: builtin/submodule--helper.c:415
 msgid "git submodule--helper list [--prefix=<path>] [<path>...]"
 msgstr "git submodule--helper list [--prefix=ПЪТ] [ПЪТ…]"
 
-#: builtin/submodule--helper.c:462 builtin/submodule--helper.c:485
+#: builtin/submodule--helper.c:472 builtin/submodule--helper.c:630
+#: builtin/submodule--helper.c:653
 #, c-format
 msgid "No url found for submodule path '%s' in .gitmodules"
 msgstr "Във файла „.gitmodules“ не е открит адрес за пътя към подмодул „%s“"
 
-#: builtin/submodule--helper.c:500
+#: builtin/submodule--helper.c:524
+#, c-format
+msgid "Entering '%s'\n"
+msgstr "Влизане в „%s“\n"
+
+#: builtin/submodule--helper.c:527
+#, c-format
+msgid ""
+"run_command returned non-zero status for %s\n"
+"."
+msgstr ""
+"изпълнената команда завърши с ненулев изход за „%s“\n"
+"."
+
+#: builtin/submodule--helper.c:549
+#, c-format
+msgid ""
+"run_command returned non-zero status while recursing in the nested "
+"submodules of %s\n"
+"."
+msgstr ""
+"изпълнената команда завърши с ненулев изход при обхождане на подмодулите, "
+"вложени в „%s“\n"
+"."
+
+#: builtin/submodule--helper.c:565
+msgid "Suppress output of entering each submodule command"
+msgstr "Без извеждане на изход при въвеждането на всяка команда за подмодули"
+
+#: builtin/submodule--helper.c:567 builtin/submodule--helper.c:1053
+msgid "Recurse into nested submodules"
+msgstr "Рекурсивно обхождане на подмодулите"
+
+#: builtin/submodule--helper.c:572
+msgid "git submodule--helper foreach [--quiet] [--recursive] [--] <command>"
+msgstr "git submodule--helper foreach [--quiet] [--recursive] [--] КОМАНДА"
+
+#: builtin/submodule--helper.c:599
 #, c-format
 msgid ""
-"could not lookup configuration '%s'. Assuming this repository is its own "
+"could not look up configuration '%s'. Assuming this repository is its own "
 "authoritative upstream."
 msgstr ""
 "настройката „%s“ липсва.  Приема се, че това хранилище е правилният източник "
 "за себе си."
 
-#: builtin/submodule--helper.c:511
+#: builtin/submodule--helper.c:667
 #, c-format
 msgid "Failed to register url for submodule path '%s'"
 msgstr "Неуспешно регистриране на адрес за пътя към подмодул „%s“"
 
-#: builtin/submodule--helper.c:515
+#: builtin/submodule--helper.c:671
 #, c-format
 msgid "Submodule '%s' (%s) registered for path '%s'\n"
 msgstr "Регистриран е подмодул „%s“ (%s) за пътя към подмодул „%s“\n"
 
-#: builtin/submodule--helper.c:525
+#: builtin/submodule--helper.c:681
 #, c-format
 msgid "warning: command update mode suggested for submodule '%s'\n"
 msgstr "ПРЕДУПРЕЖДЕНИЕ: препоръчва се режим на обновяване за подмодула „%s“\n"
 
-#: builtin/submodule--helper.c:532
+#: builtin/submodule--helper.c:688
 #, c-format
 msgid "Failed to register update mode for submodule path '%s'"
 msgstr ""
 "Неуспешно регистриране на режима на обновяване за пътя към подмодул „%s“"
 
-#: builtin/submodule--helper.c:554
+#: builtin/submodule--helper.c:710
 msgid "Suppress output for initializing a submodule"
 msgstr "Без извеждане на информация при инициализирането на подмодул"
 
-#: builtin/submodule--helper.c:559
-msgid "git submodule--helper init [<path>]"
-msgstr "git submodule--helper name [ПЪТ]"
+#: builtin/submodule--helper.c:715
+msgid "git submodule--helper init [<options>] [<path>]"
+msgstr "git submodule--helper init [ОПЦИЯ…] [ПЪТ]"
 
-#: builtin/submodule--helper.c:631 builtin/submodule--helper.c:757
+#: builtin/submodule--helper.c:787 builtin/submodule--helper.c:914
 #, c-format
 msgid "no submodule mapping found in .gitmodules for path '%s'"
 msgstr "Във файла „.gitmodules“ липсва информация за пътя „%s“"
 
-#: builtin/submodule--helper.c:670
+#: builtin/submodule--helper.c:827
 #, c-format
 msgid "could not resolve HEAD ref inside the submodule '%s'"
 msgstr "указателят сочен от „HEAD“ в подмодула „%s“ не може да бъде открит"
 
-#: builtin/submodule--helper.c:697 builtin/submodule--helper.c:866
+#: builtin/submodule--helper.c:854 builtin/submodule--helper.c:1023
 #, c-format
 msgid "failed to recurse into submodule '%s'"
 msgstr "неуспешно рекурсивно обхождане на подмодула „%s“"
 
-#: builtin/submodule--helper.c:721 builtin/submodule--helper.c:1031
+#: builtin/submodule--helper.c:878 builtin/submodule--helper.c:1189
 msgid "Suppress submodule status output"
 msgstr "Заглушаване на изхода за състоянието на подмодула"
 
-#: builtin/submodule--helper.c:722
+#: builtin/submodule--helper.c:879
 msgid ""
 "Use commit stored in the index instead of the one stored in the submodule "
 "HEAD"
@@ -14664,51 +20968,47 @@ msgstr ""
 "Използване на подаването указано в индекса, а не това от указателя „HEAD“ на "
 "подмодула"
 
-#: builtin/submodule--helper.c:723
+#: builtin/submodule--helper.c:880
 msgid "recurse into nested submodules"
 msgstr "рекурсивно обхождане на подмодулите"
 
-#: builtin/submodule--helper.c:728
+#: builtin/submodule--helper.c:885
 msgid "git submodule status [--quiet] [--cached] [--recursive] [<path>...]"
 msgstr "git submodule status [--quiet] [--cached] [--recursive] [ПЪТ…]"
 
-#: builtin/submodule--helper.c:752
+#: builtin/submodule--helper.c:909
 msgid "git submodule--helper name <path>"
 msgstr "git submodule--helper name ПЪТ"
 
-#: builtin/submodule--helper.c:816
+#: builtin/submodule--helper.c:973
 #, c-format
 msgid "Synchronizing submodule url for '%s'\n"
 msgstr "Синхронизиране на адреса на подмодул за „%s“\n"
 
-#: builtin/submodule--helper.c:822
+#: builtin/submodule--helper.c:979
 #, c-format
 msgid "failed to register url for submodule path '%s'"
 msgstr "неуспешно регистриране на адрес за пътя към подмодул „%s“"
 
-#: builtin/submodule--helper.c:836
+#: builtin/submodule--helper.c:993
 #, c-format
 msgid "failed to get the default remote for submodule '%s'"
 msgstr "отдалеченият адрес на подмодула „%s“ не може да бъде получен"
 
-#: builtin/submodule--helper.c:847
+#: builtin/submodule--helper.c:1004
 #, c-format
 msgid "failed to update remote for submodule '%s'"
 msgstr "отдалеченият адрес на подмодула „%s“ не може да бъде променен"
 
-#: builtin/submodule--helper.c:895
+#: builtin/submodule--helper.c:1051
 msgid "Suppress output of synchronizing submodule url"
 msgstr "Без извеждане на информация при синхронизирането на подмодул"
 
-#: builtin/submodule--helper.c:897
-msgid "Recurse into nested submodules"
-msgstr "Рекурсивно обхождане на подмодулите"
-
-#: builtin/submodule--helper.c:902
+#: builtin/submodule--helper.c:1058
 msgid "git submodule--helper sync [--quiet] [--recursive] [<path>]"
 msgstr "git submodule--helper sync [--quiet] [--recursive] [ПЪТ]"
 
-#: builtin/submodule--helper.c:956
+#: builtin/submodule--helper.c:1112
 #, c-format
 msgid ""
 "Submodule work tree '%s' contains a .git directory (use 'rm -rf' if you "
@@ -14717,7 +21017,7 @@ msgstr ""
 "Работното дърво на подмодул „%s“ съдържа директория „.git“.\n"
 "(ако искате да ги изтриете заедно с цялата им история, използвайте „rm -rf“)"
 
-#: builtin/submodule--helper.c:968
+#: builtin/submodule--helper.c:1124
 #, c-format
 msgid ""
 "Submodule work tree '%s' contains local modifications; use '-f' to discard "
@@ -14726,83 +21026,99 @@ msgstr ""
 "Работното дърво на подмодул „%s“ съдържа локални промени.  Можете да ги "
 "отхвърлите с опцията „-f“"
 
-#: builtin/submodule--helper.c:976
+#: builtin/submodule--helper.c:1132
 #, c-format
 msgid "Cleared directory '%s'\n"
 msgstr "Директорията „%s“ е изчистена\n"
 
-#: builtin/submodule--helper.c:978
+#: builtin/submodule--helper.c:1134
 #, c-format
 msgid "Could not remove submodule work tree '%s'\n"
 msgstr ""
 "Директорията към работното дърво на подмодула „%s“ не може да бъде изтрита\n"
 
-#: builtin/submodule--helper.c:987
+#: builtin/submodule--helper.c:1145
 #, c-format
 msgid "could not create empty submodule directory %s"
 msgstr "празната директория за подмодула „%s“ не може да бъде създадена"
 
-#: builtin/submodule--helper.c:1003
+#: builtin/submodule--helper.c:1161
 #, c-format
 msgid "Submodule '%s' (%s) unregistered for path '%s'\n"
 msgstr "Регистрацията на подмодула „%s“ (%s) за пътя „%s“ е премахната\n"
 
-#: builtin/submodule--helper.c:1032
+#: builtin/submodule--helper.c:1190
 msgid "Remove submodule working trees even if they contain local changes"
 msgstr ""
 "Изтриване на работните дървета на подмодулите, дори когато те съдържат "
 "локални промени"
 
-#: builtin/submodule--helper.c:1033
+#: builtin/submodule--helper.c:1191
 msgid "Unregister all submodules"
 msgstr "Премахване на регистрациите на всички подмодули"
 
-#: builtin/submodule--helper.c:1038
+#: builtin/submodule--helper.c:1196
 msgid ""
 "git submodule deinit [--quiet] [-f | --force] [--all | [--] [<path>...]]"
 msgstr "git submodule deinit [--quiet] [-f | --force] [--all | [--] [ПЪТ…]]"
 
-#: builtin/submodule--helper.c:1052
+#: builtin/submodule--helper.c:1210
 msgid "Use '--all' if you really want to deinitialize all submodules"
 msgstr "Използвайте „--all“, за да премахнете всички подмодули"
 
-#: builtin/submodule--helper.c:1145 builtin/submodule--helper.c:1148
+#: builtin/submodule--helper.c:1275
+msgid ""
+"An alternate computed from a superproject's alternate is invalid.\n"
+"To allow Git to clone without an alternate in such a case, set\n"
+"submodule.alternateErrorStrategy to 'info' or, equivalently, clone with\n"
+"'--reference-if-able' instead of '--reference'."
+msgstr ""
+"Алтернативният източник, определен от обхващащия проект е неправилен.\n"
+"За да позволите на git да клонира без алтернативен източник в този случай,\n"
+"задайте настройката „submodule.alternateErrorStrategy“ да е „info“ или\n"
+"при клониране ползвайте опцията „--reference-if-able“ вместо „--reference“."
+
+#: builtin/submodule--helper.c:1314 builtin/submodule--helper.c:1317
 #, c-format
 msgid "submodule '%s' cannot add alternate: %s"
 msgstr "към подмодула „%s“ не може да се добави алтернативен източник: %s"
 
-#: builtin/submodule--helper.c:1184
+#: builtin/submodule--helper.c:1353
 #, c-format
 msgid "Value '%s' for submodule.alternateErrorStrategy is not recognized"
 msgstr ""
 "Непозната стойност „%s“ за настройката „submodule.alternateErrorStrategy“"
 
-#: builtin/submodule--helper.c:1191
+#: builtin/submodule--helper.c:1360
 #, c-format
 msgid "Value '%s' for submodule.alternateLocation is not recognized"
 msgstr "Непозната стойност „%s“ за настройката „submodule.alternateLocation“"
 
-#: builtin/submodule--helper.c:1214
+#: builtin/submodule--helper.c:1383
 msgid "where the new submodule will be cloned to"
 msgstr "къде да се клонира новият подмодул"
 
-#: builtin/submodule--helper.c:1217
+#: builtin/submodule--helper.c:1386
 msgid "name of the new submodule"
 msgstr "име на новия подмодул"
 
-#: builtin/submodule--helper.c:1220
+#: builtin/submodule--helper.c:1389
 msgid "url where to clone the submodule from"
 msgstr "адрес, от който да се клонира новият подмодул"
 
-#: builtin/submodule--helper.c:1228
+#: builtin/submodule--helper.c:1397
 msgid "depth for shallow clones"
 msgstr "дълбочина на плитките хранилища"
 
-#: builtin/submodule--helper.c:1231 builtin/submodule--helper.c:1606
+#: builtin/submodule--helper.c:1400 builtin/submodule--helper.c:1897
 msgid "force cloning progress"
 msgstr "извеждане на напредъка на клонирането"
 
-#: builtin/submodule--helper.c:1236
+#: builtin/submodule--helper.c:1402 builtin/submodule--helper.c:1899
+msgid "disallow cloning into non-empty directory"
+msgstr "предотвратяване на клониране в непразна история"
+
+#: builtin/submodule--helper.c:1407
 msgid ""
 "git submodule--helper clone [--prefix=<path>] [--quiet] [--reference "
 "<repository>] [--name <name>] [--depth <depth>] --url <url> --path <path>"
@@ -14810,85 +21126,108 @@ msgstr ""
 "git submodule--helper clone [--prefix=ПЪТ] [--quiet] [--reference ХРАНИЛИЩЕ] "
 "[--name ИМЕ] [--depth ДЪЛБОЧИНА] --url АДРЕС --path ПЪТ…"
 
-#: builtin/submodule--helper.c:1267
+#: builtin/submodule--helper.c:1431
+#, c-format
+msgid "refusing to create/use '%s' in another submodule's git dir"
+msgstr ""
+"„%s“ не може нито да се създаде, нито да се ползва в директорията на git на "
+"друг подмодул"
+
+#: builtin/submodule--helper.c:1442
 #, c-format
 msgid "clone of '%s' into submodule path '%s' failed"
 msgstr "Неуспешно клониране на адреса „%s“ в пътя „%s“ като подмодул"
 
-#: builtin/submodule--helper.c:1281
+#: builtin/submodule--helper.c:1446
+#, c-format
+msgid "directory not empty: '%s'"
+msgstr "директорията не е празна: „%s“"
+
+#: builtin/submodule--helper.c:1458
 #, c-format
 msgid "could not get submodule directory for '%s'"
 msgstr "директорията на подмодула „%s“ не може да бъде получена"
 
-#: builtin/submodule--helper.c:1347
+#: builtin/submodule--helper.c:1494
+#, c-format
+msgid "Invalid update mode '%s' for submodule path '%s'"
+msgstr "Неправилен режим на обновяване „%s“ за пътя към подмодул „%s“"
+
+#: builtin/submodule--helper.c:1498
+#, c-format
+msgid "Invalid update mode '%s' configured for submodule path '%s'"
+msgstr ""
+"Настроен е неправилен режим на обновяване „%s“ за пътя към подмодул „%s“"
+
+#: builtin/submodule--helper.c:1594
 #, c-format
 msgid "Submodule path '%s' not initialized"
 msgstr "Пътят на подмодула „%s“ не е инициализиран"
 
-#: builtin/submodule--helper.c:1351
+#: builtin/submodule--helper.c:1598
 msgid "Maybe you want to use 'update --init'?"
 msgstr "Вероятно искахте да използвате „update --init“?"
 
-#: builtin/submodule--helper.c:1380
+#: builtin/submodule--helper.c:1628
 #, c-format
 msgid "Skipping unmerged submodule %s"
 msgstr "Прескачане на неслетия подмодул „%s“"
 
-#: builtin/submodule--helper.c:1409
+#: builtin/submodule--helper.c:1657
 #, c-format
 msgid "Skipping submodule '%s'"
 msgstr "Прескачане на подмодула „%s“"
 
-#: builtin/submodule--helper.c:1544
+#: builtin/submodule--helper.c:1803
 #, c-format
 msgid "Failed to clone '%s'. Retry scheduled"
 msgstr "Неуспешен опит за клониране на „%s“.  Насрочен е втори опит"
 
-#: builtin/submodule--helper.c:1555
+#: builtin/submodule--helper.c:1814
 #, c-format
 msgid "Failed to clone '%s' a second time, aborting"
 msgstr ""
 "Втори неуспешен опит за клониране на „%s“.  Действието се преустановява"
 
-#: builtin/submodule--helper.c:1585 builtin/submodule--helper.c:1808
+#: builtin/submodule--helper.c:1876 builtin/submodule--helper.c:2120
 msgid "path into the working tree"
 msgstr "път към работното дърво"
 
-#: builtin/submodule--helper.c:1588
+#: builtin/submodule--helper.c:1879
 msgid "path into the working tree, across nested submodule boundaries"
 msgstr "път към работното дърво, през границите на вложените подмодули"
 
-#: builtin/submodule--helper.c:1592
+#: builtin/submodule--helper.c:1883
 msgid "rebase, merge, checkout or none"
 msgstr ""
 "„rebase“ (пребазиране), „merge“ (сливане), „checkout“ (изтегляне) или "
 "„none“ (нищо да не се прави)"
 
-#: builtin/submodule--helper.c:1598
+#: builtin/submodule--helper.c:1889
 msgid "Create a shallow clone truncated to the specified number of revisions"
 msgstr "Плитко клониране, отрязано до указания брой версии"
 
-#: builtin/submodule--helper.c:1601
+#: builtin/submodule--helper.c:1892
 msgid "parallel jobs"
 msgstr "брой паралелни процеси"
 
-#: builtin/submodule--helper.c:1603
+#: builtin/submodule--helper.c:1894
 msgid "whether the initial clone should follow the shallow recommendation"
 msgstr "дали първоначалното клониране да е плитко, както се препоръчва"
 
-#: builtin/submodule--helper.c:1604
+#: builtin/submodule--helper.c:1895
 msgid "don't print cloning progress"
 msgstr "без извеждане на напредъка на клонирането"
 
-#: builtin/submodule--helper.c:1611
-msgid "git submodule--helper update_clone [--prefix=<path>] [<path>...]"
-msgstr "git submodule--helper update_clone [--prefix=ПЪТ] [ПЪТ…]"
+#: builtin/submodule--helper.c:1904
+msgid "git submodule--helper update-clone [--prefix=<path>] [<path>...]"
+msgstr "git submodule--helper update-clone [--prefix=ПЪТ] [ПЪТ…]"
 
-#: builtin/submodule--helper.c:1624
+#: builtin/submodule--helper.c:1917
 msgid "bad value for update parameter"
 msgstr "неправилен параметър към опцията „--update“"
 
-#: builtin/submodule--helper.c:1692
+#: builtin/submodule--helper.c:1965
 #, c-format
 msgid ""
 "Submodule (%s) branch configured to inherit branch from superproject, but "
@@ -14897,20 +21236,50 @@ msgstr ""
 "Клонът на подмодула „%s“ е настроен да наследява клона от обхващащия проект, "
 "но той не е на никой клон"
 
-#: builtin/submodule--helper.c:1809
+#: builtin/submodule--helper.c:2088
+#, c-format
+msgid "could not get a repository handle for submodule '%s'"
+msgstr "не може да се получи връзка към хранилище за подмодула „%s“"
+
+#: builtin/submodule--helper.c:2121
 msgid "recurse into submodules"
 msgstr "рекурсивно обхождане подмодулите"
 
-#: builtin/submodule--helper.c:1815
-msgid "git submodule--helper embed-git-dir [<path>...]"
-msgstr "git submodule--helper name embed-git-dir [ПЪТ…]"
+#: builtin/submodule--helper.c:2127
+msgid "git submodule--helper absorb-git-dirs [<options>] [<path>...]"
+msgstr "git submodule--helper absorb-git-dirs [ОПЦИЯ…] [ПЪТ…]"
+
+#: builtin/submodule--helper.c:2183
+msgid "check if it is safe to write to the .gitmodules file"
+msgstr "проверка дали писането във файла „.gitmodules“ е безопасно"
+
+#: builtin/submodule--helper.c:2186
+msgid "unset the config in the .gitmodules file"
+msgstr "изтриване на настройка във файла „.gitmodules“"
+
+#: builtin/submodule--helper.c:2191
+msgid "git submodule--helper config <name> [<value>]"
+msgstr "git submodule--helper config ИМЕ [СТОЙНОСТ]"
+
+#: builtin/submodule--helper.c:2192
+msgid "git submodule--helper config --unset <name>"
+msgstr "git submodule--helper config --unset ИМЕ"
+
+#: builtin/submodule--helper.c:2193
+msgid "git submodule--helper config --check-writeable"
+msgstr "git submodule--helper config --check-writeable"
+
+#: builtin/submodule--helper.c:2212 git-submodule.sh:173
+#, sh-format
+msgid "please make sure that the .gitmodules file is in the working tree"
+msgstr "файлът „.gitmodules“ трябва да е в работното дърво"
 
-#: builtin/submodule--helper.c:1901
+#: builtin/submodule--helper.c:2262 git.c:433 git.c:684
 #, c-format
 msgid "%s doesn't support --super-prefix"
 msgstr "„%s“ не поддържа опцията „--super-prefix“"
 
-#: builtin/submodule--helper.c:1907
+#: builtin/submodule--helper.c:2268
 #, c-format
 msgid "'%s' is not a valid submodule--helper subcommand"
 msgstr "„%s“ не е подкоманда на „submodule--helper“"
@@ -14935,27 +21304,27 @@ msgstr "изтриване на симв
 msgid "shorten ref output"
 msgstr "кратка информация за указателя"
 
-#: builtin/symbolic-ref.c:43 builtin/update-ref.c:362
+#: builtin/symbolic-ref.c:43 builtin/update-ref.c:363
 msgid "reason"
 msgstr "причина"
 
-#: builtin/symbolic-ref.c:43 builtin/update-ref.c:362
+#: builtin/symbolic-ref.c:43 builtin/update-ref.c:363
 msgid "reason of the update"
 msgstr "причина за обновяването"
 
-#: builtin/tag.c:24
+#: builtin/tag.c:25
 msgid ""
-"git tag [-a | -s | -u <key-id>] [-f] [-m <msg> | -F <file>] <tagname> "
-"[<head>]"
+"git tag [-a | -s | -u <key-id>] [-f] [-m <msg> | -F <file>]\n"
+"\t\t<tagname> [<head>]"
 msgstr ""
-"git tag [-a | -s | -u ИДЕНТИФИКАТОР_НА_КЛЮЧ] [-f] [-m СЪОБЩЕНИЕ | -F ФАЙЛ] "
-"ЕТИКЕТ [ВРЪХ]"
+"git tag [-a | -s | -u ИДЕНТИФИКАТОР_НА_КЛЮЧ] [-f] [-m СЪОБЩЕНИЕ | -F ФАЙЛ]\n"
+"        ЕТИКЕТ [ВРЪХ]"
 
-#: builtin/tag.c:25
+#: builtin/tag.c:27
 msgid "git tag -d <tagname>..."
 msgstr "git tag -d ЕТИКЕТ…"
 
-#: builtin/tag.c:26
+#: builtin/tag.c:28
 msgid ""
 "git tag -l [-n[<num>]] [--contains <commit>] [--no-contains <commit>] [--"
 "points-at <object>]\n"
@@ -14964,21 +21333,21 @@ msgstr ""
 "git tag -l [-n[БРОЙ]] [--contains ПОДАВАНЕ] [--points-at ОБЕКТ]\n"
 "           [--format=ФОРМАТ] [--[no-]merged [ПОДАВАНЕ]] [ШАБЛОН…]"
 
-#: builtin/tag.c:28
+#: builtin/tag.c:30
 msgid "git tag -v [--format=<format>] <tagname>..."
 msgstr "git tag -v [--format=ФОРМАТ] ЕТИКЕТ…"
 
-#: builtin/tag.c:86
+#: builtin/tag.c:89
 #, c-format
 msgid "tag '%s' not found."
 msgstr "етикетът „%s“ не е открит."
 
-#: builtin/tag.c:102
+#: builtin/tag.c:105
 #, c-format
 msgid "Deleted tag '%s' (was %s)\n"
 msgstr "Изтрит е етикетът „%s“ (бе „%s“)\n"
 
-#: builtin/tag.c:132
+#: builtin/tag.c:135
 #, c-format
 msgid ""
 "\n"
@@ -14988,10 +21357,10 @@ msgid ""
 msgstr ""
 "\n"
 "Въведете съобщение за етикета.\n"
-"  %s\n"
+"    %s\n"
 "Редовете, които започват с „%c“, ще бъдат пропуснати.\n"
 
-#: builtin/tag.c:136
+#: builtin/tag.c:139
 #, c-format
 msgid ""
 "\n"
@@ -15002,375 +21371,388 @@ msgid ""
 msgstr ""
 "\n"
 "Въведете съобщение за етикет.\n"
-"  %s\n"
+"    %s\n"
 "Редовете, които започват с „%c“, също ще бъдат включени — може да ги "
 "изтриете вие.\n"
 
-#: builtin/tag.c:190
+#: builtin/tag.c:198
 msgid "unable to sign the tag"
 msgstr "етикетът не може да бъде подписан"
 
-#: builtin/tag.c:192
+#: builtin/tag.c:200
 msgid "unable to write tag file"
 msgstr "файлът за етикета не може да бъде запазен"
 
-#: builtin/tag.c:217
+#: builtin/tag.c:216
+#, c-format
+msgid ""
+"You have created a nested tag. The object referred to by your new tag is\n"
+"already a tag. If you meant to tag the object that it points to, use:\n"
+"\n"
+"\tgit tag -f %s %s^{}"
+msgstr ""
+"Създали сте непряк етикет — обектът, сочен от новосъздадения етикет,\n"
+"е също етикет.  Ако вместо това искате новият етикет да сочи към това,\n"
+"което се сочи от стария, изпълнете:\n"
+"\n"
+"    git tag -f %s %s^{}"
+
+#: builtin/tag.c:232
 msgid "bad object type."
 msgstr "неправилен вид обект."
 
-#: builtin/tag.c:266
+#: builtin/tag.c:284
 msgid "no tag message?"
 msgstr "липсва съобщение за етикета"
 
-#: builtin/tag.c:273
+#: builtin/tag.c:291
 #, c-format
 msgid "The tag message has been left in %s\n"
 msgstr "Съобщението за етикета е запазено във файла „%s“\n"
 
-#: builtin/tag.c:382
+#: builtin/tag.c:402
 msgid "list tag names"
 msgstr "извеждане на имената на етикетите"
 
-#: builtin/tag.c:384
+#: builtin/tag.c:404
 msgid "print <n> lines of each tag message"
 msgstr "извеждане на този БРОЙ редове от всяко съобщение за етикет"
 
-#: builtin/tag.c:386
+#: builtin/tag.c:406
 msgid "delete tags"
 msgstr "изтриване на етикети"
 
-#: builtin/tag.c:387
+#: builtin/tag.c:407
 msgid "verify tags"
 msgstr "проверка на етикети"
 
-#: builtin/tag.c:389
+#: builtin/tag.c:409
 msgid "Tag creation options"
 msgstr "Опции при създаването на етикети"
 
-#: builtin/tag.c:391
+#: builtin/tag.c:411
 msgid "annotated tag, needs a message"
 msgstr "анотирането на етикети изисква съобщение"
 
-#: builtin/tag.c:393
+#: builtin/tag.c:413
 msgid "tag message"
 msgstr "СЪОБЩЕНИЕ за етикет"
 
-#: builtin/tag.c:395
+#: builtin/tag.c:415
 msgid "force edit of tag message"
 msgstr "принудително редактиране на съобщение за етикет"
 
-#: builtin/tag.c:396
+#: builtin/tag.c:416
 msgid "annotated and GPG-signed tag"
 msgstr "анотиран етикет с подпис по GPG"
 
-#: builtin/tag.c:400
+#: builtin/tag.c:419
 msgid "use another key to sign the tag"
 msgstr "използване на друг ключ за подписването на етикет"
 
-#: builtin/tag.c:401
+#: builtin/tag.c:420
 msgid "replace the tag if exists"
 msgstr "замяна на етикета, ако съществува"
 
-#: builtin/tag.c:402 builtin/update-ref.c:368
+#: builtin/tag.c:421 builtin/update-ref.c:369
 msgid "create a reflog"
 msgstr "създаване на журнал на указателите"
 
-#: builtin/tag.c:404
+#: builtin/tag.c:423
 msgid "Tag listing options"
 msgstr "Опции за извеждането на етикети"
 
-#: builtin/tag.c:405
+#: builtin/tag.c:424
 msgid "show tag list in columns"
 msgstr "извеждане на списъка на етикетите по колони"
 
-#: builtin/tag.c:406 builtin/tag.c:408
+#: builtin/tag.c:425 builtin/tag.c:427
 msgid "print only tags that contain the commit"
 msgstr "извеждане само на етикетите, които съдържат подаването"
 
-#: builtin/tag.c:407 builtin/tag.c:409
+#: builtin/tag.c:426 builtin/tag.c:428
 msgid "print only tags that don't contain the commit"
 msgstr "извеждане само на етикетите, които не съдържат подаването"
 
-#: builtin/tag.c:410
+#: builtin/tag.c:429
 msgid "print only tags that are merged"
 msgstr "извеждане само на слетите етикети"
 
-#: builtin/tag.c:411
+#: builtin/tag.c:430
 msgid "print only tags that are not merged"
 msgstr "извеждане само на неслетите етикети"
 
-#: builtin/tag.c:416
+#: builtin/tag.c:434
 msgid "print only tags of the object"
 msgstr "извеждане само на етикетите на ОБЕКТА"
 
-#: builtin/tag.c:460
+#: builtin/tag.c:482
 msgid "--column and -n are incompatible"
 msgstr "Опциите „--column“ и „-n“ са несъвместими"
 
-#: builtin/tag.c:482
+#: builtin/tag.c:504
 msgid "-n option is only allowed in list mode"
 msgstr "Опцията „-n“ изисква режим на списък."
 
-#: builtin/tag.c:484
+#: builtin/tag.c:506
 msgid "--contains option is only allowed in list mode"
 msgstr "Опцията „-contains“ изисква режим на списък."
 
-#: builtin/tag.c:486
+#: builtin/tag.c:508
 msgid "--no-contains option is only allowed in list mode"
 msgstr "Опцията „-contains“ изисква  режим на списък."
 
-#: builtin/tag.c:488
+#: builtin/tag.c:510
 msgid "--points-at option is only allowed in list mode"
 msgstr "Опцията „-points-at“ изисква режим на списък."
 
-#: builtin/tag.c:490
+#: builtin/tag.c:512
 msgid "--merged and --no-merged options are only allowed in list mode"
 msgstr "Опциите „--merged“ и „--no-merged“ изискват режим на списък."
 
-#: builtin/tag.c:501
+#: builtin/tag.c:523
 msgid "only one -F or -m option is allowed."
 msgstr "Опциите „-F“ и „-m“ са несъвместими."
 
-#: builtin/tag.c:520
+#: builtin/tag.c:542
 msgid "too many params"
 msgstr "Прекалено много аргументи"
 
-#: builtin/tag.c:526
+#: builtin/tag.c:548
 #, c-format
 msgid "'%s' is not a valid tag name."
 msgstr "„%s“ е неправилно име за етикет."
 
-#: builtin/tag.c:531
+#: builtin/tag.c:553
 #, c-format
 msgid "tag '%s' already exists"
 msgstr "етикетът „%s“ вече съществува"
 
-#: builtin/tag.c:562
+#: builtin/tag.c:584
 #, c-format
 msgid "Updated tag '%s' (was %s)\n"
 msgstr "Обновен етикет „%s“ (бе „%s“)\n"
 
-#: builtin/unpack-objects.c:498
+#: builtin/unpack-objects.c:501
 msgid "Unpacking objects"
 msgstr "Разпакетиране на обектите"
 
-#: builtin/update-index.c:82
+#: builtin/update-index.c:84
 #, c-format
 msgid "failed to create directory %s"
 msgstr "директорията „%s“ не може да бъде създадена"
 
-#: builtin/update-index.c:88
-#, c-format
-msgid "failed to stat %s"
-msgstr "не може да бъде получена информация чрез „stat“ за „%s“"
-
-#: builtin/update-index.c:98
+#: builtin/update-index.c:100
 #, c-format
 msgid "failed to create file %s"
 msgstr "файлът „%s“ не може да бъде създаден"
 
-#: builtin/update-index.c:106
+#: builtin/update-index.c:108
 #, c-format
 msgid "failed to delete file %s"
 msgstr "файлът „%s“ не може да бъде изтрит"
 
-#: builtin/update-index.c:113 builtin/update-index.c:219
+#: builtin/update-index.c:115 builtin/update-index.c:221
 #, c-format
 msgid "failed to delete directory %s"
 msgstr "директорията „%s“ не може да бъде изтрита"
 
-#: builtin/update-index.c:138
+#: builtin/update-index.c:140
 #, c-format
 msgid "Testing mtime in '%s' "
 msgstr "Проверка на времето на промяна (mtime) на файла „%s“"
 
-#: builtin/update-index.c:152
+#: builtin/update-index.c:154
 msgid "directory stat info does not change after adding a new file"
 msgstr ""
 "информацията получена чрез „stat“ за директорията не се променя след "
 "добавянето на нов файл"
 
-#: builtin/update-index.c:165
+#: builtin/update-index.c:167
 msgid "directory stat info does not change after adding a new directory"
 msgstr ""
 "информацията получена чрез „stat“ за директорията не се променя след "
 "добавянето на нова директория"
 
-#: builtin/update-index.c:178
+#: builtin/update-index.c:180
 msgid "directory stat info changes after updating a file"
 msgstr ""
 "информацията получена чрез „stat“ за директорията се променя след "
 "обновяването на нов файл"
 
-#: builtin/update-index.c:189
+#: builtin/update-index.c:191
 msgid "directory stat info changes after adding a file inside subdirectory"
 msgstr ""
 "информацията получена чрез „stat“ за директорията се променя след добавянето "
 "на файл в поддиректория"
 
-#: builtin/update-index.c:200
+#: builtin/update-index.c:202
 msgid "directory stat info does not change after deleting a file"
 msgstr ""
 "информацията получена чрез „stat“ за директорията не се променя след "
 "изтриването на файл"
 
-#: builtin/update-index.c:213
+#: builtin/update-index.c:215
 msgid "directory stat info does not change after deleting a directory"
 msgstr ""
 "информацията получена чрез „stat“ за директорията не се променя след "
 "изтриването на директория"
 
-#: builtin/update-index.c:220
+#: builtin/update-index.c:222
 msgid " OK"
 msgstr " Добре"
 
-#: builtin/update-index.c:589
+#: builtin/update-index.c:591
 msgid "git update-index [<options>] [--] [<file>...]"
 msgstr "git update-index [ОПЦИЯ…] [--] [ФАЙЛ…]"
 
-#: builtin/update-index.c:946
+#: builtin/update-index.c:974
 msgid "continue refresh even when index needs update"
 msgstr ""
 "продължаване с обновяването, дори когато индексът трябва да бъде обновен"
 
-#: builtin/update-index.c:949
+#: builtin/update-index.c:977
 msgid "refresh: ignore submodules"
 msgstr "подмодулите да се игнорират при обновяването"
 
-#: builtin/update-index.c:952
+#: builtin/update-index.c:980
 msgid "do not ignore new files"
 msgstr "новите файлове да не се игнорират"
 
-#: builtin/update-index.c:954
+#: builtin/update-index.c:982
 msgid "let files replace directories and vice-versa"
 msgstr "файлове да могат да заменят директории и обратно"
 
-#: builtin/update-index.c:956
+#: builtin/update-index.c:984
 msgid "notice files missing from worktree"
 msgstr "предупреждаване при липсващи в работното дърво файлове"
 
-#: builtin/update-index.c:958
+#: builtin/update-index.c:986
 msgid "refresh even if index contains unmerged entries"
 msgstr "обновяване дори и индексът да съдържа неслети обекти"
 
-#: builtin/update-index.c:961
+#: builtin/update-index.c:989
 msgid "refresh stat information"
 msgstr "обновяване на информацията от функцията „stat“"
 
-#: builtin/update-index.c:965
+#: builtin/update-index.c:993
 msgid "like --refresh, but ignore assume-unchanged setting"
 msgstr ""
 "като опцията „--refresh“, но да се проверят и обектите, които са били приети "
 "за непроменени"
 
-#: builtin/update-index.c:969
+#: builtin/update-index.c:997
 msgid "<mode>,<object>,<path>"
 msgstr "РЕЖИМ,ОБЕКТ,ПЪТ"
 
-#: builtin/update-index.c:970
+#: builtin/update-index.c:998
 msgid "add the specified entry to the index"
 msgstr "добавяне на изброените обекти към индекса"
 
-#: builtin/update-index.c:979
+#: builtin/update-index.c:1008
 msgid "mark files as \"not changing\""
 msgstr "задаване на флаг, че файлът не се променя"
 
-#: builtin/update-index.c:982
+#: builtin/update-index.c:1011
 msgid "clear assumed-unchanged bit"
 msgstr "изчистване на флага, че файлът не се променя"
 
-#: builtin/update-index.c:985
+#: builtin/update-index.c:1014
 msgid "mark files as \"index-only\""
 msgstr "задаване на флаг, че файловете са само за индекса"
 
-#: builtin/update-index.c:988
+#: builtin/update-index.c:1017
 msgid "clear skip-worktree bit"
-msgstr "изчистване на флага,  че файловете са само за индекса"
+msgstr "изчистване на флага, че файловете са само за индекса"
+
+#: builtin/update-index.c:1020
+msgid "do not touch index-only entries"
+msgstr "без промяна на файловете само за индекса"
 
-#: builtin/update-index.c:991
+#: builtin/update-index.c:1022
 msgid "add to index only; do not add content to object database"
 msgstr "добавяне само към индекса без добавяне към базата от данни за обектите"
 
-#: builtin/update-index.c:993
+#: builtin/update-index.c:1024
 msgid "remove named paths even if present in worktree"
 msgstr "изтриване на указаните пътища, дори и да съществуват в работното дърво"
 
-#: builtin/update-index.c:995
+#: builtin/update-index.c:1026
 msgid "with --stdin: input lines are terminated by null bytes"
 msgstr ""
 "при комбиниране с опцията „--stdin“ — входните редове са разделени с нулевия "
 "байт"
 
-#: builtin/update-index.c:997
+#: builtin/update-index.c:1028
 msgid "read list of paths to be updated from standard input"
 msgstr "изчитане на списъка с пътища за обновяване от стандартния вход"
 
-#: builtin/update-index.c:1001
+#: builtin/update-index.c:1032
 msgid "add entries from standard input to the index"
 msgstr "добавяне на елементите от стандартния вход към индекса"
 
-#: builtin/update-index.c:1005
+#: builtin/update-index.c:1036
 msgid "repopulate stages #2 and #3 for the listed paths"
 msgstr ""
 "възстановяване на състоянието преди сливане или нужда от обновяване за "
 "изброените пътища"
 
-#: builtin/update-index.c:1009
+#: builtin/update-index.c:1040
 msgid "only update entries that differ from HEAD"
 msgstr "добавяне само на съдържанието, което се различава от това в „HEAD“"
 
-#: builtin/update-index.c:1013
+#: builtin/update-index.c:1044
 msgid "ignore files missing from worktree"
 msgstr "игнориране на файловете, които липсват в работното дърво"
 
-#: builtin/update-index.c:1016
+#: builtin/update-index.c:1047
 msgid "report actions to standard output"
 msgstr "извеждане на действията на стандартния изход"
 
-#: builtin/update-index.c:1018
+#: builtin/update-index.c:1049
 msgid "(for porcelains) forget saved unresolved conflicts"
 msgstr ""
 "забравяне на записаната информация за неразрешени конфликти — за командите "
 "от потребителско ниво"
 
-#: builtin/update-index.c:1022
+#: builtin/update-index.c:1053
 msgid "write index in this format"
 msgstr "записване на индекса в този формат"
 
-#: builtin/update-index.c:1024
+#: builtin/update-index.c:1055
 msgid "enable or disable split index"
 msgstr "включване или изключване на разделянето на индекса"
 
-#: builtin/update-index.c:1026
+#: builtin/update-index.c:1057
 msgid "enable/disable untracked cache"
 msgstr "включване/изключване на кеша за неследените файлове"
 
-#: builtin/update-index.c:1028
+#: builtin/update-index.c:1059
 msgid "test if the filesystem supports untracked cache"
 msgstr "проверка дали файловата система поддържа кеш за неследени файлове"
 
-#: builtin/update-index.c:1030
+#: builtin/update-index.c:1061
 msgid "enable untracked cache without testing the filesystem"
 msgstr ""
 "включване на кеша за неследените файлове без проверка на файловата система"
 
-#: builtin/update-index.c:1032
+#: builtin/update-index.c:1063
 msgid "write out the index even if is not flagged as changed"
 msgstr "запис на индекса, дори да не е отбелязан като променен"
 
-#: builtin/update-index.c:1034
+#: builtin/update-index.c:1065
 msgid "enable or disable file system monitor"
 msgstr "включване или изключване на наблюдението на файловата система"
 
-#: builtin/update-index.c:1036
+#: builtin/update-index.c:1067
 msgid "mark files as fsmonitor valid"
 msgstr "отбелязване на файловете, че могат да се следят чрез файловата система"
 
-#: builtin/update-index.c:1039
+#: builtin/update-index.c:1070
 msgid "clear fsmonitor valid bit"
 msgstr "изчистване на флага за следенето чрез файловата система"
 
-#: builtin/update-index.c:1138
+#: builtin/update-index.c:1173
 msgid ""
 "core.splitIndex is set to false; remove or change it, if you really want to "
 "enable split index"
@@ -15378,7 +21760,7 @@ msgstr ""
 "Настройката „core.splitIndex“ е зададена на „false“ (лъжа).  Сменете я или я "
 "изтрийте, за да включите разделянето на индекса"
 
-#: builtin/update-index.c:1147
+#: builtin/update-index.c:1182
 msgid ""
 "core.splitIndex is set to true; remove or change it, if you really want to "
 "disable split index"
@@ -15386,7 +21768,7 @@ msgstr ""
 "Настройката „core.splitIndex“ е зададена на „true“ (истина).  Сменете я или "
 "я изтрийте, за да изключите разделянето на индекса."
 
-#: builtin/update-index.c:1158
+#: builtin/update-index.c:1194
 msgid ""
 "core.untrackedCache is set to true; remove or change it, if you really want "
 "to disable the untracked cache"
@@ -15394,11 +21776,11 @@ msgstr ""
 "Настройката „core.untrackedCache“ е зададена на „true“ (истина).  Сменете я "
 "или я изтрийте, за да изключите кеша за неследените файлове"
 
-#: builtin/update-index.c:1162
+#: builtin/update-index.c:1198
 msgid "Untracked cache disabled"
 msgstr "Кешът за неследените файлове е изключен"
 
-#: builtin/update-index.c:1170
+#: builtin/update-index.c:1206
 msgid ""
 "core.untrackedCache is set to false; remove or change it, if you really want "
 "to enable the untracked cache"
@@ -15406,29 +21788,29 @@ msgstr ""
 "Настройката „core.untrackedCache“ е зададена на „false“ (лъжа).  Сменете я "
 "или я изтрийте, за да включите кеша за неследените файлове"
 
-#: builtin/update-index.c:1174
+#: builtin/update-index.c:1210
 #, c-format
 msgid "Untracked cache enabled for '%s'"
 msgstr "Кешът за неследените файлове е включен за „%s“"
 
-#: builtin/update-index.c:1182
+#: builtin/update-index.c:1218
 msgid "core.fsmonitor is unset; set it if you really want to enable fsmonitor"
 msgstr ""
 "Настройката „core.fsmonitor“ не е зададена.  Задайте я, за да включите "
 "следенето чрез файловата система."
 
-#: builtin/update-index.c:1186
+#: builtin/update-index.c:1222
 msgid "fsmonitor enabled"
 msgstr "следенето чрез файловата система е включено"
 
-#: builtin/update-index.c:1189
+#: builtin/update-index.c:1225
 msgid ""
 "core.fsmonitor is set; remove it if you really want to disable fsmonitor"
 msgstr ""
 "Настройката „core.fsmonitor“ е зададена.  Изтрийте я, за да изключите "
 "следенето чрез файловата система."
 
-#: builtin/update-index.c:1193
+#: builtin/update-index.c:1229
 msgid "fsmonitor disabled"
 msgstr "следенето чрез файловата система е изключено"
 
@@ -15444,21 +21826,21 @@ msgstr "git update-ref [ОПЦИЯ…] 
 msgid "git update-ref [<options>] --stdin [-z]"
 msgstr "git update-ref [ОПЦИЯ…] --stdin [-z]"
 
-#: builtin/update-ref.c:363
+#: builtin/update-ref.c:364
 msgid "delete the reference"
 msgstr "изтриване на указателя"
 
-#: builtin/update-ref.c:365
+#: builtin/update-ref.c:366
 msgid "update <refname> not the one it points to"
 msgstr "обновяване на ИМЕто_НА_УКАЗАТЕЛя, а не това, към което сочи"
 
-#: builtin/update-ref.c:366
+#: builtin/update-ref.c:367
 msgid "stdin has NUL-terminated arguments"
 msgstr ""
 "някои от елементите подадени на стандартния вход завършват с нулевия знак "
 "„NUL“"
 
-#: builtin/update-ref.c:367
+#: builtin/update-ref.c:368
 msgid "read updates from stdin"
 msgstr "изчитане на указателите от стандартния вход"
 
@@ -15474,6 +21856,10 @@ msgstr "обновяване на инф
 msgid "git upload-pack [<options>] <dir>"
 msgstr "git upload-repack [ОПЦИЯ…] ДИРЕКТОРИЯ"
 
+#: builtin/upload-pack.c:23 t/helper/test-serve-v2.c:17
+msgid "quit after a single request/response exchange"
+msgstr "изход след първоначалната размяна на заявка и отговор"
+
 #: builtin/upload-pack.c:25
 msgid "exit immediately after initial ref advertisement"
 msgstr "изход след първоначалната обява на указатели"
@@ -15487,15 +21873,15 @@ msgstr ""
 msgid "interrupt transfer after <n> seconds of inactivity"
 msgstr "трансферът да се преустанови след този БРОЙ секунди"
 
-#: builtin/verify-commit.c:18
+#: builtin/verify-commit.c:19
 msgid "git verify-commit [-v | --verbose] <commit>..."
 msgstr "git verify-tag [-v | --verbose] ПОДАВАНЕ…"
 
-#: builtin/verify-commit.c:73
+#: builtin/verify-commit.c:68
 msgid "print commit contents"
 msgstr "извеждане на съдържанието на подаването"
 
-#: builtin/verify-commit.c:74 builtin/verify-tag.c:38
+#: builtin/verify-commit.c:69 builtin/verify-tag.c:37
 msgid "print raw gpg status output"
 msgstr "извеждане на необработения изход от състоянието на „gpg“"
 
@@ -15511,11 +21897,11 @@ msgstr "извеждане на подр
 msgid "show statistics only"
 msgstr "извеждане само на статистиката"
 
-#: builtin/verify-tag.c:19
+#: builtin/verify-tag.c:18
 msgid "git verify-tag [-v | --verbose] [--format=<format>] <tag>..."
 msgstr "git verify-tag [-v | --verbose] [--format=ФОРМАТ] ЕТИКЕТ…"
 
-#: builtin/verify-tag.c:37
+#: builtin/verify-tag.c:36
 msgid "print tag contents"
 msgstr "извеждане на съдържанието на ЕТИКЕТи"
 
@@ -15547,23 +21933,28 @@ msgstr "git worktree remove [ОПЦИЯ
 msgid "git worktree unlock <path>"
 msgstr "git worktree unlock [ПЪТ]"
 
-#: builtin/worktree.c:58
+#: builtin/worktree.c:60 builtin/worktree.c:898
+#, c-format
+msgid "failed to delete '%s'"
+msgstr "неуспешно изтриване на „%s“"
+
+#: builtin/worktree.c:79
 #, c-format
 msgid "Removing worktrees/%s: not a valid directory"
 msgstr "Изтриване на „worktrees/%s“: не е правилна поддиректория"
 
-#: builtin/worktree.c:64
+#: builtin/worktree.c:85
 #, c-format
 msgid "Removing worktrees/%s: gitdir file does not exist"
 msgstr "Изтриване на „worktrees/%s“: файлът „gitdir“ не съществува"
 
-#: builtin/worktree.c:69 builtin/worktree.c:78
+#: builtin/worktree.c:90 builtin/worktree.c:99
 #, c-format
 msgid "Removing worktrees/%s: unable to read gitdir file (%s)"
 msgstr ""
 "Изтриване на „worktrees/%s“: файлът „gitdir“ (%s) не може да бъде прочетен"
 
-#: builtin/worktree.c:88
+#: builtin/worktree.c:109
 #, c-format
 msgid ""
 "Removing worktrees/%s: short read (expected %<PRIuMAX> bytes, read "
@@ -15572,215 +21963,256 @@ msgstr ""
 "Изтриване на „worktrees/%s“: изчитането върна по-малко байтове от очакваното "
 "(очаквани: %<PRIuMAX> байта, получени: %<PRIuMAX>)"
 
-#: builtin/worktree.c:96
+#: builtin/worktree.c:117
 #, c-format
 msgid "Removing worktrees/%s: invalid gitdir file"
 msgstr "Изтриване на „worktrees/%s“: неправилен файл „gitdir“"
 
-#: builtin/worktree.c:105
+#: builtin/worktree.c:126
 #, c-format
 msgid "Removing worktrees/%s: gitdir file points to non-existent location"
 msgstr ""
 "Изтриване на „worktrees/%s“: файлът „gitdir“ сочи несъществуващо "
 "местоположение"
 
-#: builtin/worktree.c:152
+#: builtin/worktree.c:165
 msgid "report pruned working trees"
 msgstr "докладване на окастрените работни дървета"
 
-#: builtin/worktree.c:154
+#: builtin/worktree.c:167
 msgid "expire working trees older than <time>"
 msgstr "обявяване на работните копия по-стари от това ВРЕМЕ за остарели"
 
-#: builtin/worktree.c:229
+#: builtin/worktree.c:234
 #, c-format
 msgid "'%s' already exists"
 msgstr "„%s“ вече съществува"
 
-#: builtin/worktree.c:260
+#: builtin/worktree.c:251
+#, c-format
+msgid "unable to re-add worktree '%s'"
+msgstr "дървото „%s“ не може да бъде добавено наново"
+
+#: builtin/worktree.c:256
+#, c-format
+msgid ""
+"'%s' is a missing but locked worktree;\n"
+"use 'add -f -f' to override, or 'unlock' and 'prune' or 'remove' to clear"
+msgstr ""
+"„%s“ липсва, но е заключено работно дърво.\n"
+"За изрично задаване ползвайте „add -f“, а за изчистване — „prune“ или "
+"„remove“"
+
+#: builtin/worktree.c:258
+#, c-format
+msgid ""
+"'%s' is a missing but already registered worktree;\n"
+"use 'add -f' to override, or 'prune' or 'remove' to clear"
+msgstr ""
+"„%s“ липсва, но е регистрирано като работно дърво.\n"
+"За изрично задаване ползвайте „add -f“, а за изчистване — „prune“ или "
+"„remove“"
+
+#: builtin/worktree.c:308
 #, c-format
 msgid "could not create directory of '%s'"
 msgstr "директорията „%s“ не може да бъде създадена"
 
-#: builtin/worktree.c:373 builtin/worktree.c:379
+#: builtin/worktree.c:439 builtin/worktree.c:445
 #, c-format
 msgid "Preparing worktree (new branch '%s')"
 msgstr "Приготвяне на работното дърво (нов клон „%s“)"
 
-#: builtin/worktree.c:375
+#: builtin/worktree.c:441
 #, c-format
 msgid "Preparing worktree (resetting branch '%s'; was at %s)"
 msgstr ""
 "Приготвяне на работното дърво (зануляване на клона „%s“, който сочеше към "
 "„%s“)"
 
-#: builtin/worktree.c:384
+#: builtin/worktree.c:450
 #, c-format
 msgid "Preparing worktree (checking out '%s')"
 msgstr "Приготвяне на работното дърво (изтегляне на „%s“)"
 
-#: builtin/worktree.c:390
+#: builtin/worktree.c:456
 #, c-format
 msgid "Preparing worktree (detached HEAD %s)"
 msgstr "Подготвяне на работно дърво (указателят „HEAD“ не свързан: %s)"
 
-#: builtin/worktree.c:431
+#: builtin/worktree.c:497
 msgid "checkout <branch> even if already checked out in other worktree"
 msgstr "Изтегляне КЛОНа, дори и да е изтеглен в друго работно дърво"
 
-#: builtin/worktree.c:434
+#: builtin/worktree.c:500
 msgid "create a new branch"
 msgstr "създаване на нов клон"
 
-#: builtin/worktree.c:436
+#: builtin/worktree.c:502
 msgid "create or reset a branch"
 msgstr "създаване или зануляване на клони"
 
-#: builtin/worktree.c:438
+#: builtin/worktree.c:504
 msgid "populate the new working tree"
 msgstr "подготвяне на новото работно дърво"
 
-#: builtin/worktree.c:439
+#: builtin/worktree.c:505
 msgid "keep the new working tree locked"
 msgstr "новото работно дърво да остане заключено"
 
-#: builtin/worktree.c:441
+#: builtin/worktree.c:508
 msgid "set up tracking mode (see git-branch(1))"
 msgstr "задаване на режима на следене (виж git-branch(1))"
 
-#: builtin/worktree.c:444
+#: builtin/worktree.c:511
 msgid "try to match the new branch name with a remote-tracking branch"
 msgstr "опит за напасване на името на новия клон с това на следящ клон"
 
-#: builtin/worktree.c:452
+#: builtin/worktree.c:519
 msgid "-b, -B, and --detach are mutually exclusive"
 msgstr "Опциите „-b“, „-B“ и „--detach“ са несъвместими една с друга"
 
-#: builtin/worktree.c:511
+#: builtin/worktree.c:580
 msgid "--[no-]track can only be used if a new branch is created"
 msgstr "„--[no-]track“ може да се използва само при създаването на нов клон"
 
-#: builtin/worktree.c:611
+#: builtin/worktree.c:680
 msgid "reason for locking"
 msgstr "причина за заключване"
 
-#: builtin/worktree.c:623 builtin/worktree.c:656 builtin/worktree.c:710
-#: builtin/worktree.c:850
+#: builtin/worktree.c:692 builtin/worktree.c:725 builtin/worktree.c:799
+#: builtin/worktree.c:926
 #, c-format
 msgid "'%s' is not a working tree"
 msgstr "„%s“ не е работно дърво"
 
-#: builtin/worktree.c:625 builtin/worktree.c:658
+#: builtin/worktree.c:694 builtin/worktree.c:727
 msgid "The main working tree cannot be locked or unlocked"
 msgstr "Основното дърво не може да се отключи или заключи"
 
-#: builtin/worktree.c:630
+#: builtin/worktree.c:699
 #, c-format
 msgid "'%s' is already locked, reason: %s"
 msgstr "„%s“ вече е заключено, защото „%s“"
 
-#: builtin/worktree.c:632
+#: builtin/worktree.c:701
 #, c-format
 msgid "'%s' is already locked"
 msgstr "„%s“ вече е заключено"
 
-#: builtin/worktree.c:660
+#: builtin/worktree.c:729
 #, c-format
 msgid "'%s' is not locked"
 msgstr "„%s“ не е заключено"
 
-#: builtin/worktree.c:685
+#: builtin/worktree.c:770
 msgid "working trees containing submodules cannot be moved or removed"
 msgstr ""
 "не може да местите или изтривате работни дървета, в които има подмодули"
 
-#: builtin/worktree.c:712 builtin/worktree.c:852
+#: builtin/worktree.c:778
+msgid "force move even if worktree is dirty or locked"
+msgstr ""
+"принудително преместване, дори работното дърво да не е чисто или да е "
+"заключено"
+
+#: builtin/worktree.c:801 builtin/worktree.c:928
 #, c-format
 msgid "'%s' is a main working tree"
 msgstr "„%s“ е основно работно дърво"
 
-#: builtin/worktree.c:717
+#: builtin/worktree.c:806
 #, c-format
 msgid "could not figure out destination name from '%s'"
 msgstr "името на целта не може да се определи от „%s“"
 
-#: builtin/worktree.c:723
+#: builtin/worktree.c:812
 #, c-format
 msgid "target '%s' already exists"
 msgstr "целта „%s“ вече съществува"
 
-#: builtin/worktree.c:730
+#: builtin/worktree.c:820
 #, c-format
-msgid "cannot move a locked working tree, lock reason: %s"
+msgid ""
+"cannot move a locked working tree, lock reason: %s\n"
+"use 'move -f -f' to override or unlock first"
 msgstr ""
-"не може да преместите заключено работно дърво, причина за заключването: %s"
+"не може да преместите заключено работно дърво, причина за заключването: %s\n"
+"или го отключете, или го преместете принудително с „move -f -f“"
 
-#: builtin/worktree.c:732
-msgid "cannot move a locked working tree"
-msgstr "не може да местите заключено работно дърво"
+#: builtin/worktree.c:822
+msgid ""
+"cannot move a locked working tree;\n"
+"use 'move -f -f' to override or unlock first"
+msgstr ""
+"не може да преместите заключено работно дърво:\n"
+"или го отключете, или го преместете принудително с „move -f -f“"
 
-#: builtin/worktree.c:735
+#: builtin/worktree.c:825
 #, c-format
 msgid "validation failed, cannot move working tree: %s"
 msgstr ""
 "проверките са неуспешни, работното дърво не може да бъде преместено: %s"
 
-#: builtin/worktree.c:740
+#: builtin/worktree.c:830
 #, c-format
 msgid "failed to move '%s' to '%s'"
 msgstr "„%s“ не може да се премести в „%s“"
 
-#: builtin/worktree.c:788
+#: builtin/worktree.c:878
 #, c-format
 msgid "failed to run 'git status' on '%s'"
 msgstr "не може да изпълни „git status“ върху „%s“"
 
-#: builtin/worktree.c:792
+#: builtin/worktree.c:882
 #, c-format
-msgid "'%s' is dirty, use --force to delete it"
+msgid "'%s' contains modified or untracked files, use --force to delete it"
 msgstr ""
-"работното дърво „%s“ не е чисто, за принудително изтриване е необходима "
-"опцията „--force“ "
+"„%s“ съдържа променени или нови файлове, за принудително изтриване е "
+"необходима опцията „--force“"
 
-#: builtin/worktree.c:797
+#: builtin/worktree.c:887
 #, c-format
 msgid "failed to run 'git status' on '%s', code %d"
 msgstr ""
 "командата „git status“ не може да се изпълни за „%s“, код за грешка: %d"
 
-#: builtin/worktree.c:808 builtin/worktree.c:822
-#, c-format
-msgid "failed to delete '%s'"
-msgstr "неуспешно изтриване на „%s“"
-
-#: builtin/worktree.c:834
-msgid "force removing even if the worktree is dirty"
-msgstr "принудително изтриване, дори работното дърво да не е чисто"
+#: builtin/worktree.c:910
+msgid "force removal even if worktree is dirty or locked"
+msgstr ""
+"принудително изтриване, дори работното дърво да не е чисто или да е заключено"
 
-#: builtin/worktree.c:856
+#: builtin/worktree.c:933
 #, c-format
-msgid "cannot remove a locked working tree, lock reason: %s"
+msgid ""
+"cannot remove a locked working tree, lock reason: %s\n"
+"use 'remove -f -f' to override or unlock first"
 msgstr ""
-"не може да изтриете заключено работно дърво, причина за заключването: %s"
+"не може да изтриете заключено работно дърво, причина за заключването: %s\n"
+"или го отключете, или го изтрийте принудително с „remove -f -f“"
 
-#: builtin/worktree.c:858
-msgid "cannot remove a locked working tree"
-msgstr "не може да изтриете заключено работно дърво"
+#: builtin/worktree.c:935
+msgid ""
+"cannot remove a locked working tree;\n"
+"use 'remove -f -f' to override or unlock first"
+msgstr ""
+"не може да изтриете заключено работно дърво:\n"
+"или го отключете, или го изтрийте принудително с „remove -f -f“"
 
-#: builtin/worktree.c:861
+#: builtin/worktree.c:938
 #, c-format
 msgid "validation failed, cannot remove working tree: %s"
 msgstr "проверките са неуспешни, работното дърво не може да бъде изтрито: %s"
 
-#: builtin/write-tree.c:14
+#: builtin/write-tree.c:15
 msgid "git write-tree [--missing-ok] [--prefix=<prefix>/]"
 msgstr "git write-tree [--missing-ok] [--prefix=ПРЕФИКС/]"
 
-#: builtin/write-tree.c:27
+#: builtin/write-tree.c:28
 msgid "<prefix>/"
 msgstr "ПРЕФИКС/"
 
-#: builtin/write-tree.c:28
+#: builtin/write-tree.c:29
 msgid "write tree object for a subdirectory <prefix>"
 msgstr "запис на обект-дърво за поддиректорията започваща с тази ПРЕФИКС"
 
@@ -15788,7 +22220,22 @@ msgstr "запис на обект-дъ
 msgid "only useful for debugging"
 msgstr "само за изчистване на грешки"
 
-#: credential-cache--daemon.c:222
+#: fast-import.c:3125
+#, c-format
+msgid "Expected 'mark' command, got %s"
+msgstr "очаква се команда „mark“, а бе получена: „%s“"
+
+#: fast-import.c:3130
+#, c-format
+msgid "Expected 'to' command, got %s"
+msgstr "очаква се команда „to“, а бе получена: „%s“"
+
+#: fast-import.c:3254
+#, c-format
+msgid "feature '%s' forbidden in input without --allow-unsafe-features"
+msgstr "„%s“ изисква изричното задаване на опцията „--allow-unsafe-features“"
+
+#: credential-cache--daemon.c:223
 #, c-format
 msgid ""
 "The permissions on your socket directory are too loose; other\n"
@@ -15803,10 +22250,27 @@ msgstr ""
 "\n"
 "    chmod 0700 %s"
 
-#: credential-cache--daemon.c:271
+#: credential-cache--daemon.c:272
 msgid "print debugging messages to stderr"
 msgstr "извеждане на съобщенията за трасиране на стандартната грешка"
 
+#: t/helper/test-reach.c:152
+#, c-format
+msgid "commit %s is not marked reachable"
+msgstr "подаването „%s“ не е отбелязано като достижимо"
+
+#: t/helper/test-reach.c:162
+msgid "too many commits marked reachable"
+msgstr "прекалено много подавания са отбелязани като достижими"
+
+#: t/helper/test-serve-v2.c:7
+msgid "test-tool serve-v2 [<options>]"
+msgstr "test-tool serve-v2 [ОПЦИЯ…]"
+
+#: t/helper/test-serve-v2.c:19
+msgid "exit immediately after advertising capabilities"
+msgstr "изход след първоначалната обява на възможностите"
+
 #: git.c:27
 msgid ""
 "git [--version] [--help] [-C <path>] [-c <name>=<value>]\n"
@@ -15826,78 +22290,160 @@ msgstr ""
 msgid ""
 "'git help -a' and 'git help -g' list available subcommands and some\n"
 "concept guides. See 'git help <command>' or 'git help <concept>'\n"
-"to read about a specific subcommand or concept."
+"to read about a specific subcommand or concept.\n"
+"See 'git help git' for an overview of the system."
 msgstr ""
 "„git help -a“ извежда наличните подкоманди, а „git help -g“ извежда "
 "наличните\n"
 "въведения.  За помощ за специфична КОМАНДА ползвайте „git help КОМАНДА“, а "
 "за\n"
-"някое определено ПОНЯТИЕ използвайте „git help ПОНЯТИЕ“.\n"
-"\n"
-"Български превод на книгата „Pro Git“ от Чакън и Страуб:\n"
-"http://i-can.eu/progit2-bg/progit.html"
+"някое определено ПОНЯТИЕ използвайте „git help ПОНЯТИЕ“.  За преглед на\n"
+"системата за помощ използвайте „git help git“."
 
-#: git.c:173
+#: git.c:186
 #, c-format
 msgid "no directory given for --git-dir\n"
 msgstr "опцията „--git-dir“ изисква директория\n"
 
-#: git.c:187
+#: git.c:200
 #, c-format
 msgid "no namespace given for --namespace\n"
 msgstr "опцията „--namespace“ изисква име\n"
 
-#: git.c:201
+#: git.c:214
 #, c-format
 msgid "no directory given for --work-tree\n"
 msgstr "опцията „--work-tree“ изисква директория\n"
 
-#: git.c:215
+#: git.c:228
 #, c-format
 msgid "no prefix given for --super-prefix\n"
 msgstr "опцията „--super-prefix“ изисква префикс\n"
 
-#: git.c:237
+#: git.c:250
 #, c-format
 msgid "-c expects a configuration string\n"
 msgstr "опцията „-c“ изисква низ за настройка\n"
 
-#: git.c:275
+#: git.c:288
 #, c-format
 msgid "no directory given for -C\n"
 msgstr "опцията „-C“ изисква директория\n"
 
-#: git.c:300
+#: git.c:314
 #, c-format
 msgid "unknown option: %s\n"
 msgstr "непозната опция: „%s“\n"
 
-#: git.c:765
+#: git.c:360
+#, c-format
+msgid "while expanding alias '%s': '%s'"
+msgstr "при заместването на псевдоним „%s“: „%s“"
+
+#: git.c:369
+#, c-format
+msgid ""
+"alias '%s' changes environment variables.\n"
+"You can use '!git' in the alias to do this"
+msgstr ""
+"псевдонимът „%s“ променя променливи на средата.\n"
+"За това може да ползвате „!git“ в псевдонима"
+
+#: git.c:376
+#, c-format
+msgid "empty alias for %s"
+msgstr "празен псевдоним за „%s“"
+
+#: git.c:379
+#, c-format
+msgid "recursive alias: %s"
+msgstr "зациклен псевдоним: „%s“"
+
+#: git.c:459
+msgid "write failure on standard output"
+msgstr "грешка при запис на стандартния изход"
+
+#: git.c:461
+msgid "unknown write failure on standard output"
+msgstr "неизвестна грешка при запис на стандартния изход"
+
+#: git.c:463
+msgid "close failed on standard output"
+msgstr "грешка при затваряне на стандартния изход"
+
+#: git.c:793
+#, c-format
+msgid "alias loop detected: expansion of '%s' does not terminate:%s"
+msgstr "зацикляне в псевдонимите: заместванията на „%s“ не приключват:%s"
+
+#: git.c:843
+#, c-format
+msgid "cannot handle %s as a builtin"
+msgstr "„%s“ не може да се обработи като вградена команда"
+
+#: git.c:856
+#, c-format
+msgid ""
+"usage: %s\n"
+"\n"
+msgstr ""
+"употреба: %s\n"
+"\n"
+
+#: git.c:876
 #, c-format
 msgid "expansion of alias '%s' failed; '%s' is not a git command\n"
 msgstr ""
-"неуспешно заместване на синонима „%s“ — резултатът „%s“ не е команда на git\n"
+"неуспешно заместване на псевдонима „%s“ — резултатът „%s“ не е команда на "
+"git\n"
 
-#: git.c:777
+#: git.c:888
 #, c-format
 msgid "failed to run command '%s': %s\n"
 msgstr "командата „%s“ не може да се изпълни: %s\n"
 
-#: http.c:348
+#: http.c:378
 #, c-format
 msgid "negative value for http.postbuffer; defaulting to %d"
 msgstr ""
 "отрицателна стойност за „http.postbuffer“.  Ще се ползва стандартната: %d"
 
-#: http.c:369
+#: http.c:399
 msgid "Delegation control is not supported with cURL < 7.22.0"
 msgstr "Управлението на делегирането не се поддържа от cURL < 7.22.0"
 
-#: http.c:378
+#: http.c:408
 msgid "Public key pinning not supported with cURL < 7.44.0"
 msgstr "Задаването на постоянен публичен ключ не се поддържа от cURL < 7.44.0"
 
-#: http.c:1854
+#: http.c:876
+msgid "CURLSSLOPT_NO_REVOKE not supported with cURL < 7.44.0"
+msgstr "„CURLSSLOPT_NO_REVOKE“ не се поддържа от cURL < 7.44.0"
+
+#: http.c:949
+msgid "Protocol restrictions not supported with cURL < 7.19.4"
+msgstr "Ограничаването на протоколите не се поддържа от cURL < 7.44.0"
+
+#: http.c:1086
+#, c-format
+msgid "Unsupported SSL backend '%s'. Supported SSL backends:"
+msgstr "Неподдържана реализация на SSL „%s“. Поддържат се:"
+
+#: http.c:1093
+#, c-format
+msgid "Could not set SSL backend to '%s': cURL was built without SSL backends"
+msgstr ""
+"Реализацията на SSL не може да се зададе да е „%s“: cURL е компилиран без "
+"поддръжка на SSL"
+
+#: http.c:1097
+#, c-format
+msgid "Could not set SSL backend to '%s': already set"
+msgstr ""
+"Реализацията на SSL не може да се зададе да е „%s“, защото вече е зададена "
+"друга"
+
+#: http.c:1966
 #, c-format
 msgid ""
 "unable to update url base from redirection:\n"
@@ -15908,39 +22454,189 @@ msgstr ""
 "    ● заявен адрес: %s\n"
 "    ● пренасочване: %s"
 
-#: remote-curl.c:401
+#: remote-curl.c:166
+#, c-format
+msgid "invalid quoting in push-option value: '%s'"
+msgstr ""
+"неправилно екраниране или цитиране в стойността към опция за изтласкване: "
+"„%s“"
+
+#: remote-curl.c:263
+#, c-format
+msgid "%sinfo/refs not valid: is this a git repository?"
+msgstr "„%sinfo/refs“ е неизползваемо, проверете дали е хранилище на git"
+
+#: remote-curl.c:364
+msgid "invalid server response; expected service, got flush packet"
+msgstr ""
+"неправилен отговор от сървъра: очакваше се услуга, а бе получен изчистващ "
+"пакет „flush“"
+
+#: remote-curl.c:395
+#, c-format
+msgid "invalid server response; got '%s'"
+msgstr "неправилен отговор от сървъра, бе получено: „%s“"
+
+#: remote-curl.c:455
+#, c-format
+msgid "repository '%s' not found"
+msgstr "хранилището „%s“ липсва"
+
+#: remote-curl.c:459
+#, c-format
+msgid "Authentication failed for '%s'"
+msgstr "Неуспешна идентификация към „%s“"
+
+#: remote-curl.c:463
+#, c-format
+msgid "unable to access '%s': %s"
+msgstr "няма достъп до „%s“: %s"
+
+#: remote-curl.c:469
 #, c-format
 msgid "redirecting to %s"
 msgstr "пренасочване към „%s“"
 
-#: list-objects-filter-options.h:59
+#: remote-curl.c:593
+msgid "shouldn't have EOF when not gentle on EOF"
+msgstr "получен е EOF, в режим без поддръжка за това"
+
+#: remote-curl.c:673
+msgid "unable to rewind rpc post data - try increasing http.postBuffer"
+msgstr ""
+"данните за POST не могат да се прочетат наново, пробвайте да увеличите "
+"настройката „http.postBuffer“"
+
+#: remote-curl.c:733
+#, c-format
+msgid "RPC failed; %s"
+msgstr "Неуспешно отдалечено извикване.  %s"
+
+#: remote-curl.c:773
+msgid "cannot handle pushes this big"
+msgstr "толкова големи изтласквания не може да се изпълнят"
+
+#: remote-curl.c:888
+#, c-format
+msgid "cannot deflate request; zlib deflate error %d"
+msgstr ""
+"заявката не може да бъде декомпресирана, грешка от „zlib“ при "
+"декомпресиране: %d"
+
+#: remote-curl.c:892
+#, c-format
+msgid "cannot deflate request; zlib end error %d"
+msgstr ""
+"заявката не може да бъде декомпресирана; грешка от „zlib“ при завършване: %d<"
+
+#: remote-curl.c:1023
+msgid "dumb http transport does not support shallow capabilities"
+msgstr "опростеният транспорт по http не поддържа плитки клиенти"
+
+#: remote-curl.c:1037
+msgid "fetch failed."
+msgstr "неуспешно доставяне."
+
+#: remote-curl.c:1085
+msgid "cannot fetch by sha1 over smart http"
+msgstr "умният вариант на http не може да доставя по SHA1"
+
+#: remote-curl.c:1129 remote-curl.c:1135
+#, c-format
+msgid "protocol error: expected sha/ref, got '%s'"
+msgstr "протоколна грешка: очаква се SHA1 или указател, а бе получено: „%s“"
+
+#: remote-curl.c:1147 remote-curl.c:1261
+#, c-format
+msgid "http transport does not support %s"
+msgstr "транспортът по http не поддържа „%s“"
+
+#: remote-curl.c:1183
+msgid "git-http-push failed"
+msgstr "неуспешно изпълнение на „git-http-push“"
+
+#: remote-curl.c:1367
+msgid "remote-curl: usage: git remote-curl <remote> [<url>]"
+msgstr "remote-curl: употреба: git remote-curl ХРАНИЛИЩЕ [АДРЕС]"
+
+#: remote-curl.c:1399
+msgid "remote-curl: error reading command stream from git"
+msgstr "remote-curl: грешка при изчитането на потока команди от git"
+
+#: remote-curl.c:1406
+msgid "remote-curl: fetch attempted without a local repo"
+msgstr "remote-curl: опит за доставяне без локално хранилище"
+
+#: remote-curl.c:1446
+#, c-format
+msgid "remote-curl: unknown command '%s' from git"
+msgstr "remote-curl: непозната команда „%s“ от git"
+
+#: list-objects-filter-options.h:85
 msgid "args"
 msgstr "АРГУМЕНТИ"
 
-#: list-objects-filter-options.h:60
+#: list-objects-filter-options.h:86
 msgid "object filtering"
 msgstr "филтриране по вид на обекта"
 
-#: parse-options.h:157
+#: parse-options.h:183
 msgid "expiry-date"
 msgstr "период на валидност/запазване"
 
-#: parse-options.h:172
+#: parse-options.h:197
 msgid "no-op (backward compatibility)"
 msgstr "нулева операция (за съвместимост с предишни версии)"
 
-#: parse-options.h:251
+#: parse-options.h:309
 msgid "be more verbose"
 msgstr "повече подробности"
 
-#: parse-options.h:253
+#: parse-options.h:311
 msgid "be more quiet"
 msgstr "по-малко подробности"
 
-#: parse-options.h:259
+#: parse-options.h:317
 msgid "use <n> digits to display SHA-1s"
 msgstr "да се показват такъв БРОЙ цифри от сумите по SHA1"
 
+#: parse-options.h:336
+msgid "how to strip spaces and #comments from message"
+msgstr "кои празни знаци и #коментари да се махат от съобщенията"
+
+#: parse-options.h:337
+msgid "read pathspec from file"
+msgstr "изчитане на пътищата от ФАЙЛ"
+
+#: parse-options.h:338
+msgid ""
+"with --pathspec-from-file, pathspec elements are separated with NUL character"
+msgstr ""
+"при ползването на „--pathspec-from-file“, пътищата са разделени с нулевия "
+"знак „NUL“"
+
+#: ref-filter.h:101
+msgid "key"
+msgstr "КЛЮЧ"
+
+#: ref-filter.h:101
+msgid "field name to sort on"
+msgstr "име на полето, по което да е подредбата"
+
+#: rerere.h:44
+msgid "update the index with reused conflict resolution if possible"
+msgstr ""
+"при възможност преизползване на решението на конфликта за обновяване на "
+"индекса"
+
+#: wt-status.h:67
+msgid "HEAD detached at "
+msgstr "Указателят „HEAD“ не е свързан и е при "
+
+#: wt-status.h:68
+msgid "HEAD detached from "
+msgstr "Указателят „HEAD“ не е свързан и е отделѐн от "
+
 #: command-list.h:50
 msgid "Add file contents to the index"
 msgstr "Добавяне на съдържанието на файла към индекса"
@@ -15951,15 +22647,15 @@ msgstr "Прилагане на поре
 
 #: command-list.h:52
 msgid "Annotate file lines with commit information"
-msgstr "Анотиране на редовете на файловете с информация за подаванията"
+msgstr "Добавяне на информация за подаванията към редовете на файловете"
 
 #: command-list.h:53
 msgid "Apply a patch to files and/or to the index"
 msgstr "Прилагане на кръпка към файловете и/или индекса"
 
 #: command-list.h:54
-msgid "Import an Arch repository into Git"
-msgstr "Внасяне на хранилище на Arch в Git"
+msgid "Import a GNU Arch repository into Git"
+msgstr "Внасяне на хранилище на GNU Arch в Git"
 
 #: command-list.h:55
 msgid "Create an archive of files from a named tree"
@@ -16043,7 +22739,7 @@ msgid "Record changes to the repository"
 msgstr "Подаване на промени в хранилището"
 
 #: command-list.h:74
-msgid "Write and verify Git commit graph files"
+msgid "Write and verify Git commit-graph files"
 msgstr "Запис и проверка на файловете с гра̀фа на подаванията на Git"
 
 #: command-list.h:75
@@ -16209,9 +22905,9 @@ msgid "Instantly browse your working rep
 msgstr "Незабавно разглеждане на работното ви хранилище чрез „gitweb“"
 
 #: command-list.h:113
-msgid "add or parse structured information in commit messages"
+msgid "Add or parse structured information in commit messages"
 msgstr ""
-"добавяне или обработка на структурирана информация в съобщенията при подаване"
+"Добавяне или обработка на структурирана информация в съобщенията при подаване"
 
 #: command-list.h:114
 msgid "The Git repository browser"
@@ -16270,329 +22966,347 @@ msgid "Show three-way merge without touc
 msgstr "Извеждане на тройно сливане без промяна на индекса"
 
 #: command-list.h:128
+msgid "Write and verify multi-pack-indexes"
+msgstr "Запис и проверка на индексите за множество пакети"
+
+#: command-list.h:129
 msgid "Creates a tag object"
 msgstr "Създаване на обект-етикет"
 
-#: command-list.h:129
+#: command-list.h:130
 msgid "Build a tree-object from ls-tree formatted text"
 msgstr "Създаване на обект-дърво от текст във формат „ls-tree“"
 
-#: command-list.h:130
+#: command-list.h:131
 msgid "Move or rename a file, a directory, or a symlink"
 msgstr "Преместване или преименуване на файл, директория или символна връзка"
 
-#: command-list.h:131
+#: command-list.h:132
 msgid "Find symbolic names for given revs"
 msgstr "Откриване на имената дадени на версия"
 
-#: command-list.h:132
+#: command-list.h:133
 msgid "Add or inspect object notes"
 msgstr "Добавяне или преглед на бележки към обект"
 
-#: command-list.h:133
+#: command-list.h:134
 msgid "Import from and submit to Perforce repositories"
 msgstr "Внасяне и подаване към хранилища на Perforce"
 
-#: command-list.h:134
+#: command-list.h:135
 msgid "Create a packed archive of objects"
 msgstr "Създаване на пакетиран архив от обекти"
 
-#: command-list.h:135
+#: command-list.h:136
 msgid "Find redundant pack files"
 msgstr "Намиране на повтарящи се пакетни файлове"
 
-#: command-list.h:136
+#: command-list.h:137
 msgid "Pack heads and tags for efficient repository access"
 msgstr "Пакетиране на върховете и етикетите за бърз достъп до хранилище"
 
-#: command-list.h:137
+#: command-list.h:138
 msgid "Routines to help parsing remote repository access parameters"
 msgstr ""
 "Помощни програми за анализа на параметрите за достъп до отдалечено хранилище"
 
-#: command-list.h:138
+#: command-list.h:139
 msgid "Compute unique ID for a patch"
 msgstr "Генериране на уникален идентификатор на кръпка"
 
-#: command-list.h:139
+#: command-list.h:140
 msgid "Prune all unreachable objects from the object database"
 msgstr "Окастряне на всички недостижими обекти в базата от данни за обектите"
 
-#: command-list.h:140
+#: command-list.h:141
 msgid "Remove extra objects that are already in pack files"
 msgstr "Изтриване на допълнителните обекти, които вече са в пакетни файлове"
 
-#: command-list.h:141
+#: command-list.h:142
 msgid "Fetch from and integrate with another repository or a local branch"
 msgstr "Доставяне и внасяне на промените от друго хранилище или клон"
 
-#: command-list.h:142
+#: command-list.h:143
 msgid "Update remote refs along with associated objects"
 msgstr "Обновяване на отдалечените указатели и свързаните с тях обекти"
 
-#: command-list.h:143
+#: command-list.h:144
 msgid "Applies a quilt patchset onto the current branch"
 msgstr "Прилагане на поредица от кръпки от quilt към текущия клон"
 
-#: command-list.h:144
+#: command-list.h:145
+msgid "Compare two commit ranges (e.g. two versions of a branch)"
+msgstr "Сравняване на два диапазона от подавания (напр. две версии на клон)"
+
+#: command-list.h:146
 msgid "Reads tree information into the index"
 msgstr "Изчитане на информация за обект-дърво в индекса"
 
-#: command-list.h:145
+#: command-list.h:147
 msgid "Reapply commits on top of another base tip"
 msgstr "Прилагане на подаванията върху друг връх"
 
-#: command-list.h:146
+#: command-list.h:148
 msgid "Receive what is pushed into the repository"
 msgstr "Получаване на изтласканото в хранилището"
 
-#: command-list.h:147
+#: command-list.h:149
 msgid "Manage reflog information"
 msgstr "Управление на информацията в журнала на указателите"
 
-#: command-list.h:148
+#: command-list.h:150
 msgid "Manage set of tracked repositories"
 msgstr "Управление на набор от следени хранилища"
 
-#: command-list.h:149
+#: command-list.h:151
 msgid "Pack unpacked objects in a repository"
 msgstr "Пакетиране на непакетираните обекти в хранилище"
 
-#: command-list.h:150
+#: command-list.h:152
 msgid "Create, list, delete refs to replace objects"
 msgstr "Създаване, извеждане, изтриване на указатели за замяна на обекти"
 
-#: command-list.h:151
+#: command-list.h:153
 msgid "Generates a summary of pending changes"
 msgstr "Обобщение на предстоящите промени"
 
-#: command-list.h:152
+#: command-list.h:154
 msgid "Reuse recorded resolution of conflicted merges"
 msgstr "Преизползване на вече запазено коригиране на конфликт при сливане"
 
-#: command-list.h:153
+#: command-list.h:155
 msgid "Reset current HEAD to the specified state"
 msgstr "Привеждане на указателя „HEAD“ към зададеното състояние"
 
-#: command-list.h:154
+#: command-list.h:156
+msgid "Restore working tree files"
+msgstr "Възстановяване на файловете в работното дърво"
+
+#: command-list.h:157
 msgid "Revert some existing commits"
 msgstr "Отменяне на съществуващи подавания"
 
-#: command-list.h:155
+#: command-list.h:158
 msgid "Lists commit objects in reverse chronological order"
 msgstr "Извеждане на подаванията в обратна хронологическа подредба"
 
-#: command-list.h:156
+#: command-list.h:159
 msgid "Pick out and massage parameters"
 msgstr "Избор и промяна на параметри"
 
-#: command-list.h:157
+#: command-list.h:160
 msgid "Remove files from the working tree and from the index"
 msgstr "Изтриване на файлове от работното дърво и индекса"
 
-#: command-list.h:158
+#: command-list.h:161
 msgid "Send a collection of patches as emails"
 msgstr "Изпращане на поредица от кръпки по е-поща"
 
-#: command-list.h:159
+#: command-list.h:162
 msgid "Push objects over Git protocol to another repository"
 msgstr "Изтласкване на обекти по протокола на Git към друго хранилище"
 
-#: command-list.h:160
+#: command-list.h:163
 msgid "Restricted login shell for Git-only SSH access"
 msgstr "Ограничена входна обвивка за достъп през SSH само до Git"
 
-#: command-list.h:161
+#: command-list.h:164
 msgid "Summarize 'git log' output"
 msgstr "Обобщен изход от „git log“"
 
-#: command-list.h:162
+#: command-list.h:165
 msgid "Show various types of objects"
 msgstr "Извеждане на различните видове обекти в Git"
 
-#: command-list.h:163
+#: command-list.h:166
 msgid "Show branches and their commits"
 msgstr "Извеждане на клоните и подаванията в тях"
 
-#: command-list.h:164
+#: command-list.h:167
 msgid "Show packed archive index"
 msgstr "Извеждане на индекса на пакетирания архив"
 
-#: command-list.h:165
+#: command-list.h:168
 msgid "List references in a local repository"
 msgstr "Извеждане на указателите в локално хранилище"
 
-#: command-list.h:166
+#: command-list.h:169
 msgid "Git's i18n setup code for shell scripts"
 msgstr "Настройки на Git за интернационализация на скриптовете на обвивката"
 
-#: command-list.h:167
+#: command-list.h:170
 msgid "Common Git shell script setup code"
 msgstr "Настройки на Git за скриптовете на обвивката"
 
-#: command-list.h:168
+#: command-list.h:171
+msgid "Initialize and modify the sparse-checkout"
+msgstr "Инициализиране и промяна на частичното изтегляне"
+
+#: command-list.h:172
 msgid "Stash the changes in a dirty working directory away"
 msgstr "Скатаване на неподадените промени в работното дърво"
 
-#: command-list.h:169
+#: command-list.h:173
 msgid "Add file contents to the staging area"
 msgstr "Добавяне на съдържанието на файла към индекса"
 
-#: command-list.h:170
+#: command-list.h:174
 msgid "Show the working tree status"
 msgstr "Извеждане на състоянието на работното дърво"
 
-#: command-list.h:171
+#: command-list.h:175
 msgid "Remove unnecessary whitespace"
 msgstr "Премахване на излишните знаци за интервали"
 
-#: command-list.h:172
+#: command-list.h:176
 msgid "Initialize, update or inspect submodules"
 msgstr "Инициализиране, обновяване или разглеждане на подмодули"
 
-#: command-list.h:173
+#: command-list.h:177
 msgid "Bidirectional operation between a Subversion repository and Git"
 msgstr "Двупосочна работа между хранилища под Subversion и Git"
 
-#: command-list.h:174
+#: command-list.h:178
+msgid "Switch branches"
+msgstr "Преминаване към друг клон"
+
+#: command-list.h:179
 msgid "Read, modify and delete symbolic refs"
 msgstr "Извеждане, промяна и изтриване на символни указатели"
 
-#: command-list.h:175
+#: command-list.h:180
 msgid "Create, list, delete or verify a tag object signed with GPG"
 msgstr "Извеждане, създаване, изтриване, проверка на етикети подписани с GPG"
 
-#: command-list.h:176
+#: command-list.h:181
 msgid "Creates a temporary file with a blob's contents"
 msgstr "Създаване на временен файл със същото съдържание като обектът-BLOB"
 
-#: command-list.h:177
+#: command-list.h:182
 msgid "Unpack objects from a packed archive"
 msgstr "Разпакетиране на обекти от пакетиран архив"
 
-#: command-list.h:178
+#: command-list.h:183
 msgid "Register file contents in the working tree to the index"
 msgstr "Регистриране на съдържанието на файловете от работното дърво в индекса"
 
-#: command-list.h:179
+#: command-list.h:184
 msgid "Update the object name stored in a ref safely"
 msgstr "Безопасно обновяване на името на обект в указател"
 
-#: command-list.h:180
+#: command-list.h:185
 msgid "Update auxiliary info file to help dumb servers"
 msgstr ""
 "Обновяване на файла с допълнителна информация в помощ на опростените сървъри"
 
-#: command-list.h:181
+#: command-list.h:186
 msgid "Send archive back to git-archive"
 msgstr "Изпращане на архива обратно към „git-archive“"
 
-#: command-list.h:182
+#: command-list.h:187
 msgid "Send objects packed back to git-fetch-pack"
 msgstr "Изпращане на пакетираните обекти обратно към „git-fetch-pack“"
 
-#: command-list.h:183
+#: command-list.h:188
 msgid "Show a Git logical variable"
 msgstr "Извеждане на логическа променлива на Git"
 
-#: command-list.h:184
+#: command-list.h:189
 msgid "Check the GPG signature of commits"
 msgstr "Проверка на подписите GPG върху подаванията"
 
-#: command-list.h:185
+#: command-list.h:190
 msgid "Validate packed Git archive files"
 msgstr "Проверка на пакетираните архивни файлове на Git"
 
-#: command-list.h:186
+#: command-list.h:191
 msgid "Check the GPG signature of tags"
 msgstr "Проверка на подписите GPG върху етикетите"
 
-#: command-list.h:187
+#: command-list.h:192
 msgid "Git web interface (web frontend to Git repositories)"
 msgstr "Уеб интерфейс на Git"
 
-#: command-list.h:188
+#: command-list.h:193
 msgid "Show logs with difference each commit introduces"
 msgstr "Извеждане на журнал с разликите, въведени с всяко подаване"
 
-#: command-list.h:189
+#: command-list.h:194
 msgid "Manage multiple working trees"
 msgstr "Управление на множество работни дървета"
 
-#: command-list.h:190
+#: command-list.h:195
 msgid "Create a tree object from the current index"
 msgstr "Създаване на обект-дърво от текущия индекс"
 
-#: command-list.h:191
+#: command-list.h:196
 msgid "Defining attributes per path"
 msgstr "Указване на атрибути към път"
 
-#: command-list.h:192
+#: command-list.h:197
 msgid "Git command-line interface and conventions"
 msgstr "Команден ред и конвенции на Git"
 
-#: command-list.h:193
+#: command-list.h:198
 msgid "A Git core tutorial for developers"
 msgstr "Въвеждащ урок в Git за разработчици"
 
-#: command-list.h:194
+#: command-list.h:199
 msgid "Git for CVS users"
 msgstr "Git за потребители на CVS"
 
-#: command-list.h:195
+#: command-list.h:200
 msgid "Tweaking diff output"
 msgstr "Настройване на изгледа на разликите"
 
-#: command-list.h:196
+#: command-list.h:201
 msgid "A useful minimum set of commands for Everyday Git"
 msgstr "Полезен минимален набор от команди за ежедневната работа с Git"
 
-#: command-list.h:197
+#: command-list.h:202
 msgid "A Git Glossary"
 msgstr "Речник с термините на Git"
 
-#: command-list.h:198
+#: command-list.h:203
 msgid "Hooks used by Git"
 msgstr "Куки на Git"
 
-#: command-list.h:199
+#: command-list.h:204
 msgid "Specifies intentionally untracked files to ignore"
 msgstr "Указване на неследени файлове, които да бъдат нарочно пренебрегвани"
 
-#: command-list.h:200
+#: command-list.h:205
 msgid "Defining submodule properties"
 msgstr "Дефиниране на свойствата на подмодулите"
 
-#: command-list.h:201
+#: command-list.h:206
 msgid "Git namespaces"
 msgstr "Пространства от имена на Git"
 
-#: command-list.h:202
+#: command-list.h:207
 msgid "Git Repository Layout"
 msgstr "Устройство на хранилището на Git"
 
-#: command-list.h:203
+#: command-list.h:208
 msgid "Specifying revisions and ranges for Git"
 msgstr "Указване на версии и диапазони в Git"
 
-#: command-list.h:204
+#: command-list.h:209
+msgid "Mounting one repository inside another"
+msgstr "Монтиране на едно хранилище в друго"
+
+#: command-list.h:210
 msgid "A tutorial introduction to Git: part two"
 msgstr "Въвеждащ урок за Git: втора част"
 
-#: command-list.h:205
+#: command-list.h:211
 msgid "A tutorial introduction to Git"
 msgstr "Въвеждащ урок за Git"
 
-#: command-list.h:206
+#: command-list.h:212
 msgid "An overview of recommended workflows with Git"
 msgstr "Общ преглед на препоръчваните начини за работа с Git"
 
-#: rerere.h:40
-msgid "update the index with reused conflict resolution if possible"
-msgstr ""
-"при възможност преизползване на решението на конфликта за обновяване на "
-"индекса"
-
 #: git-bisect.sh:54
 msgid "You need to start by \"git bisect start\""
 msgstr "Започнете като изпълните командата „git bisect start“"
@@ -16604,142 +23318,52 @@ msgstr "Започнете като из
 msgid "Do you want me to do it for you [Y/n]? "
 msgstr "Да се извърши ли автоматично? „Y“ —  ДА, „n“ — не"
 
-#: git-bisect.sh:121
-#, sh-format
-msgid "unrecognised option: '$arg'"
-msgstr "непозната опция „${arg}“"
-
-#: git-bisect.sh:125
-#, sh-format
-msgid "'$arg' does not appear to be a valid revision"
-msgstr "„$arg“ не изглежда като указател към версия"
-
-#: git-bisect.sh:154
-msgid "Bad HEAD - I need a HEAD"
-msgstr "Текущият указател „HEAD“ е неправилен."
-
-#: git-bisect.sh:167
-#, sh-format
-msgid ""
-"Checking out '$start_head' failed. Try 'git bisect reset <valid-branch>'."
-msgstr ""
-"Неуспешно преминаване към „${start_head}“.  Изпълнете командата „git bisect "
-"reset СЪЩЕСТВУВАЩ_КЛОН“."
-
-#: git-bisect.sh:177
-msgid "won't bisect on cg-seek'ed tree"
-msgstr ""
-"не може да се търси двоично, когато е изпълнена командата „cg-seek“ от "
-"„cogito“"
-
-#: git-bisect.sh:181
-msgid "Bad HEAD - strange symbolic ref"
-msgstr "Неправилен указател „HEAD“"
-
-#: git-bisect.sh:233
-#, sh-format
-msgid "Bad bisect_write argument: $state"
-msgstr "Неправилен аргумент на функцията „bisect_write“: „${state}“"
-
-#: git-bisect.sh:246
+#: git-bisect.sh:101
 #, sh-format
 msgid "Bad rev input: $arg"
 msgstr "Неправилна версия: „${arg}“"
 
-#: git-bisect.sh:265
+#: git-bisect.sh:121
 #, sh-format
 msgid "Bad rev input: $bisected_head"
 msgstr "Неправилна версия: „$bisected_head“"
 
-#: git-bisect.sh:274
+#: git-bisect.sh:130
 #, sh-format
 msgid "Bad rev input: $rev"
 msgstr "Неправилна версия: „${rev}“"
 
-#: git-bisect.sh:283
+#: git-bisect.sh:139
 #, sh-format
 msgid "'git bisect $TERM_BAD' can take only one argument."
 msgstr "Командата „git bisect ${TERM_BAD}“ приема само един аргумент."
 
-#: git-bisect.sh:306
-#, sh-format
-msgid "Warning: bisecting only with a $TERM_BAD commit."
-msgstr "ПРЕДУПРЕЖДЕНИЕ: двоично търсене само по ${TERM_BAD} подаване."
-
-#. TRANSLATORS: Make sure to include [Y] and [n] in your
-#. translation. The program will only accept English input
-#. at this point.
-#: git-bisect.sh:312
-msgid "Are you sure [Y/n]? "
-msgstr "Да се продължи ли? „Y“ —  ДА, „n“ — не"
-
-#: git-bisect.sh:324
-#, sh-format
-msgid ""
-"You need to give me at least one $bad_syn and one $good_syn revision.\n"
-"(You can use \"git bisect $bad_syn\" and \"git bisect $good_syn\" for that.)"
-msgstr ""
-"Трябва да зададете поне една ${bad_syn} и една ${good_syn} версия.  (Това "
-"може да се\n"
-"направи съответно и чрез командите „git bisect ${bad_syn}“ и „git bisect "
-"${good_syn}“.)"
-
-#: git-bisect.sh:327
-#, sh-format
-msgid ""
-"You need to start by \"git bisect start\".\n"
-"You then need to give me at least one $good_syn and one $bad_syn revision.\n"
-"(You can use \"git bisect $bad_syn\" and \"git bisect $good_syn\" for that.)"
-msgstr ""
-"Трябва да започнете двоичното търсене чрез командата „git bisect start“.\n"
-"трябва да зададете поне една добра и една лоша версия.  (Това може да се\n"
-"направи съответно и чрез командите „git bisect ${bad_syn}“ и „git bisect "
-"${good_syn}“.)"
-
-#: git-bisect.sh:398 git-bisect.sh:512
-msgid "We are not bisecting."
-msgstr "В момента не се извършва двоично търсене."
-
-#: git-bisect.sh:405
-#, sh-format
-msgid "'$invalid' is not a valid commit"
-msgstr "„${invalid}“ е неправилно подаване"
-
-#: git-bisect.sh:414
-#, sh-format
-msgid ""
-"Could not check out original HEAD '$branch'.\n"
-"Try 'git bisect reset <commit>'."
-msgstr ""
-"Първоначално указаният клон „${branch}“ в указателя „HEAD“ не може да бъде\n"
-"изтеглен.  Пробвайте да изпълните командата „git bisect reset ПОДАВАНЕ“."
-
-#: git-bisect.sh:422
+#: git-bisect.sh:209
 msgid "No logfile given"
 msgstr "Не е зададен журнален файл"
 
-#: git-bisect.sh:423
+#: git-bisect.sh:210
 #, sh-format
 msgid "cannot read $file for replaying"
 msgstr ""
 "Журналният файл „${file}“ не може да бъде прочетен, за да се изпълнят "
 "командите от него наново"
 
-#: git-bisect.sh:444
+#: git-bisect.sh:232
 msgid "?? what are you talking about?"
 msgstr ""
 "Непозната команда.  Възможните варианти са: „start“, „good“, „bad“, „skip“"
 
-#: git-bisect.sh:453
+#: git-bisect.sh:241
 msgid "bisect run failed: no command provided."
 msgstr "неуспешно двоично търсене, не е зададена команда."
 
-#: git-bisect.sh:458
+#: git-bisect.sh:246
 #, sh-format
 msgid "running $command"
 msgstr "изпълнение на командата „${command}“"
 
-#: git-bisect.sh:465
+#: git-bisect.sh:253
 #, sh-format
 msgid ""
 "bisect run failed:\n"
@@ -16749,11 +23373,11 @@ msgstr ""
 "изходният код от командата „${command}“ е ${res} — това е извън интервала "
 "[0, 128)"
 
-#: git-bisect.sh:491
+#: git-bisect.sh:279
 msgid "bisect run cannot continue any more"
 msgstr "двоичното търсене не може да продължи"
 
-#: git-bisect.sh:497
+#: git-bisect.sh:285
 #, sh-format
 msgid ""
 "bisect run failed:\n"
@@ -16762,403 +23386,167 @@ msgstr ""
 "неуспешно двоично търсене:\n"
 "функцията „bisect_state ${state}“ завърши с код за грешка ${res}"
 
-#: git-bisect.sh:504
+#: git-bisect.sh:292
 msgid "bisect run success"
 msgstr "успешно двоично търсене"
 
-#: git-bisect.sh:533
-#, sh-format
-msgid "Invalid command: you're currently in a $TERM_BAD/$TERM_GOOD bisect."
-msgstr ""
-"Неправилна команда: в момента се изпълнява двоично търсене по ${TERM_BAD}/"
-"${TERM_GOOD}."
-
-#: git-bisect.sh:567
-msgid "no terms defined"
-msgstr "не са указани управляващи думи"
-
-#: git-bisect.sh:584
-#, sh-format
-msgid ""
-"invalid argument $arg for 'git bisect terms'.\n"
-"Supported options are: --term-good|--term-old and --term-bad|--term-new."
-msgstr ""
-"на „git bisect terms“ е подаден неправилен аргумент „${arg}“\n"
-"Поддържат се опциите „--term-good|--term-old“ и „--term-bad|--term-new“."
+#: git-bisect.sh:300
+msgid "We are not bisecting."
+msgstr "В момента не се извършва двоично търсене."
 
 #: git-merge-octopus.sh:46
 msgid ""
-"Error: Your local changes to the following files would be overwritten by "
-"merge"
-msgstr "Грешка: Сливането ще презапише локалните промени на тези файлове:"
-
-#: git-merge-octopus.sh:61
-msgid "Automated merge did not work."
-msgstr "Автоматичното сливане не сработи."
-
-#: git-merge-octopus.sh:62
-msgid "Should not be doing an octopus."
-msgstr "Не трябва да се прави множествено сливане."
-
-#: git-merge-octopus.sh:73
-#, sh-format
-msgid "Unable to find common commit with $pretty_name"
-msgstr "Не може да се открие общо подаване с „$pretty_name“"
-
-#: git-merge-octopus.sh:77
-#, sh-format
-msgid "Already up to date with $pretty_name"
-msgstr "Вече е обновено до „$pretty_name“"
-
-#: git-merge-octopus.sh:89
-#, sh-format
-msgid "Fast-forwarding to: $pretty_name"
-msgstr "Превъртане до „$pretty_name“"
-
-#: git-merge-octopus.sh:97
-#, sh-format
-msgid "Trying simple merge with $pretty_name"
-msgstr "Опит за просто сливане с „$pretty_name“"
-
-#: git-merge-octopus.sh:102
-msgid "Simple merge did not work, trying automatic merge."
-msgstr "Простото сливане не сработи, пробва се автоматично сливане."
-
-#: git-rebase.sh:61
-msgid ""
-"Resolve all conflicts manually, mark them as resolved with\n"
-"\"git add/rm <conflicted_files>\", then run \"git rebase --continue\".\n"
-"You can instead skip this commit: run \"git rebase --skip\".\n"
-"To abort and get back to the state before \"git rebase\", run \"git rebase --"
-"abort\"."
-msgstr ""
-"След коригирането на конфликтите, отбележете решаването им чрез:\n"
-"„git add/rm ФАЙЛ_С_КОНФЛИКТ…“ и изпълнете „git rebase --continue“.\n"
-"Ако предпочитате да прескочите тази кръпка, изпълнете „git rebase --skip“.\n"
-"За да откажете пребазирането и да се върнете към първоначалното състояние,\n"
-"изпълнете „git rebase --abort“."
-
-#: git-rebase.sh:173 git-rebase.sh:442
-#, sh-format
-msgid "Could not move back to $head_name"
-msgstr "Връщането към „${head_name}“ е невъзможно"
-
-#: git-rebase.sh:184
-msgid "Applied autostash."
-msgstr "Автоматично скатаното е приложено."
-
-#: git-rebase.sh:187
-#, sh-format
-msgid "Cannot store $stash_sha1"
-msgstr "„${stash_sha1}“ не може да бъде запазен"
-
-#: git-rebase.sh:229
-msgid "The pre-rebase hook refused to rebase."
-msgstr "Куката за изпълнение преди пребазиране отхвърли пребазирането."
-
-#: git-rebase.sh:234
-msgid "It looks like 'git am' is in progress. Cannot rebase."
-msgstr ""
-"Изглежда, че сега се прилагат кръпки чрез командата „git-am“.  Не може да "
-"пребазирате в момента."
-
-#: git-rebase.sh:403
-msgid "No rebase in progress?"
-msgstr "Изглежда в момента не тече пребазиране"
-
-#: git-rebase.sh:414
-msgid "The --edit-todo action can only be used during interactive rebase."
-msgstr ""
-"Опцията „--edit-todo“ е достъпна само по време на интерактивно пребазиране."
-
-#: git-rebase.sh:421
-msgid "Cannot read HEAD"
-msgstr "Указателят „HEAD“ не може да бъде прочетен"
-
-#: git-rebase.sh:424
-msgid ""
-"You must edit all merge conflicts and then\n"
-"mark them as resolved using git add"
-msgstr ""
-"Трябва да редактирате всички конфликти при сливането.  След това\n"
-"отбележете коригирането им чрез командата „git add“"
-
-#: git-rebase.sh:468
-#, sh-format
-msgid ""
-"It seems that there is already a $state_dir_base directory, and\n"
-"I wonder if you are in the middle of another rebase.  If that is the\n"
-"case, please try\n"
-"\t$cmd_live_rebase\n"
-"If that is not the case, please\n"
-"\t$cmd_clear_stale_rebase\n"
-"and run me again.  I am stopping in case you still have something\n"
-"valuable there."
-msgstr ""
-"Вече съществува директория „${state_dir_base}“.  Възможно ли е да сте\n"
-"в процес на друго пребазиране? Ако това е така, изпълнете:\n"
-"    ${cmd_live_rebase}\n"
-"Ако не сте в процес на друго пребазиране, изпълнете:\n"
-"    ${cmd_clear_stale_rebase}\n"
-"и отново започнете пребазирането.  Текущото пребазиране се преустановява, "
-"за\n"
-"да не загубите случайно промени."
-
-#: git-rebase.sh:509
-msgid "error: cannot combine '--signoff' with '--preserve-merges'"
-msgstr "грешка: опциите „--signoff“ и „--preserve-merges“ са несъвместими"
-
-#: git-rebase.sh:537
-#, sh-format
-msgid "invalid upstream '$upstream_name'"
-msgstr "неправилна основа за сравнение „${upstream_name}“"
-
-#: git-rebase.sh:561
-#, sh-format
-msgid "$onto_name: there are more than one merge bases"
-msgstr ""
-"указателят „${onto_name}“ може да сочи към повече от една основа за "
-"пребазирането"
-
-#: git-rebase.sh:564 git-rebase.sh:568
-#, sh-format
-msgid "$onto_name: there is no merge base"
-msgstr "указателят „${onto_name}“ не сочи към никаква основа за пребазирането"
-
-#: git-rebase.sh:573
-#, sh-format
-msgid "Does not point to a valid commit: $onto_name"
-msgstr "Указателят „${onto_name}“ не сочи към подаване"
-
-#: git-rebase.sh:599
-#, sh-format
-msgid "fatal: no such branch/commit '$branch_name'"
-msgstr "ФАТАЛНА ГРЕШКА: не съществува клон „${branch_name}“"
-
-#: git-rebase.sh:632
-msgid "Cannot autostash"
-msgstr "Не може да се скатае автоматично"
-
-#: git-rebase.sh:637
-#, sh-format
-msgid "Created autostash: $stash_abbrev"
-msgstr "Автоматично скатано: „${stash_abbrev}“"
-
-#: git-rebase.sh:641
-msgid "Please commit or stash them."
-msgstr "Промените трябва или да се подадат, или да се скатаят."
+"Error: Your local changes to the following files would be overwritten by "
+"merge"
+msgstr "Грешка: Сливането ще презапише локалните промени на тези файлове:"
 
-#: git-rebase.sh:664
-#, sh-format
-msgid "HEAD is up to date."
-msgstr "Указателят „HEAD“ е напълно актуален"
+#: git-merge-octopus.sh:61
+msgid "Automated merge did not work."
+msgstr "Автоматичното сливане не сработи."
 
-#: git-rebase.sh:666
-#, sh-format
-msgid "Current branch $branch_name is up to date."
-msgstr "Текущият клон „${branch_name}“ е напълно актуален."
+#: git-merge-octopus.sh:62
+msgid "Should not be doing an octopus."
+msgstr "Не трябва да се прави множествено сливане."
 
-#: git-rebase.sh:674
+#: git-merge-octopus.sh:73
 #, sh-format
-msgid "HEAD is up to date, rebase forced."
-msgstr "Указателят „HEAD“ е напълно актуален.  Пребазирането е принудително."
+msgid "Unable to find common commit with $pretty_name"
+msgstr "Не може да се открие общо подаване с „$pretty_name“"
 
-#: git-rebase.sh:676
+#: git-merge-octopus.sh:77
 #, sh-format
-msgid "Current branch $branch_name is up to date, rebase forced."
-msgstr ""
-"Текущият клон „${branch_name}“ е напълно актуален.  Пребазирането е "
-"принудително."
+msgid "Already up to date with $pretty_name"
+msgstr "Вече е обновено до „$pretty_name“"
 
-#: git-rebase.sh:688
+#: git-merge-octopus.sh:89
 #, sh-format
-msgid "Changes from $mb to $onto:"
-msgstr "Промените от „${mb}“ към „${onto}“:"
-
-#: git-rebase.sh:697
-msgid "First, rewinding head to replay your work on top of it..."
-msgstr ""
-"Първо, указателят „HEAD“ започва да сочи към базата, върху която пребазирате…"
+msgid "Fast-forwarding to: $pretty_name"
+msgstr "Превъртане до „$pretty_name“"
 
-#: git-rebase.sh:707
+#: git-merge-octopus.sh:97
 #, sh-format
-msgid "Fast-forwarded $branch_name to $onto_name."
-msgstr "Превъртане на „${branch_name}“ върху „${onto_name}“."
-
-#: git-stash.sh:61
-msgid "git stash clear with parameters is unimplemented"
-msgstr "Командата „git stash clear“ не поддържа аргументи"
-
-#: git-stash.sh:108
-msgid "You do not have the initial commit yet"
-msgstr "Все още липсва първоначално подаване"
-
-#: git-stash.sh:123
-msgid "Cannot save the current index state"
-msgstr "Състоянието на текущия индекс не може да бъде запазено"
-
-#: git-stash.sh:138
-msgid "Cannot save the untracked files"
-msgstr "Неследените файлове не могат да се запазят"
-
-#: git-stash.sh:158 git-stash.sh:171
-msgid "Cannot save the current worktree state"
-msgstr "Състоянието на работното дърво не може да бъде запазено"
+msgid "Trying simple merge with $pretty_name"
+msgstr "Опит за просто сливане с „$pretty_name“"
 
-#: git-stash.sh:175
-msgid "No changes selected"
-msgstr "Не са избрани никакви промени"
+#: git-merge-octopus.sh:102
+msgid "Simple merge did not work, trying automatic merge."
+msgstr "Простото сливане не сработи, пробва се автоматично сливане."
 
-#: git-stash.sh:178
+#: git-legacy-stash.sh:221
 msgid "Cannot remove temporary index (can't happen)"
 msgstr "Временният индекс не може да бъде изтрит"
 
-#: git-stash.sh:191
-msgid "Cannot record working tree state"
-msgstr "Състоянието на работното дърво не може да бъде запазено"
-
-#: git-stash.sh:229
+#: git-legacy-stash.sh:272
 #, sh-format
 msgid "Cannot update $ref_stash with $w_commit"
 msgstr ""
 "Указателят „${ref_stash}“ не може да бъде обновен да сочи към „${w_commit}“"
 
-#: git-stash.sh:281
+#: git-legacy-stash.sh:324
 #, sh-format
 msgid "error: unknown option for 'stash push': $option"
 msgstr "ГРЕШКА: командата „stash push“ не приема опцията „$option“"
 
-#: git-stash.sh:295
-msgid "Can't use --patch and --include-untracked or --all at the same time"
-msgstr "Опцията „--patch“ е несъвместима с „--include-untracked“ и „--all“"
-
-#: git-stash.sh:303
-msgid "No local changes to save"
-msgstr "Няма никакви локални промени за скатаване"
-
-#: git-stash.sh:308
-msgid "Cannot initialize stash"
-msgstr "Скатаването не може да стартира"
-
-#: git-stash.sh:312
-msgid "Cannot save the current status"
-msgstr "Текущото състояние не може да бъде запазено"
-
-#: git-stash.sh:313
+#: git-legacy-stash.sh:356
 #, sh-format
 msgid "Saved working directory and index state $stash_msg"
 msgstr ""
 "Състоянието на работната директория и индекса са запазени: „$stash_msg“"
 
-#: git-stash.sh:342
-msgid "Cannot remove worktree changes"
-msgstr "Промените в работното дърво не могат да бъдат занулени"
-
-#: git-stash.sh:490
+#: git-legacy-stash.sh:536
 #, sh-format
 msgid "unknown option: $opt"
 msgstr "непозната опция: ${opt}"
 
-#: git-stash.sh:503
-msgid "No stash entries found."
-msgstr "Не е открито нищо скатано."
-
-#: git-stash.sh:510
+#: git-legacy-stash.sh:556
 #, sh-format
 msgid "Too many revisions specified: $REV"
 msgstr "Указани са прекалено много версии: „${REV}“"
 
-#: git-stash.sh:525
+#: git-legacy-stash.sh:571
 #, sh-format
 msgid "$reference is not a valid reference"
 msgstr "Указателят „${reference}“ е грешен"
 
-#: git-stash.sh:553
+#: git-legacy-stash.sh:599
 #, sh-format
 msgid "'$args' is not a stash-like commit"
 msgstr "„${args}“ не е подаване, приличащо на нещо скатано"
 
-#: git-stash.sh:564
+#: git-legacy-stash.sh:610
 #, sh-format
 msgid "'$args' is not a stash reference"
 msgstr "„${args}“ не е указател към нещо скатано"
 
-#: git-stash.sh:572
+#: git-legacy-stash.sh:618
 msgid "unable to refresh index"
 msgstr "индексът не може да бъде обновен"
 
-#: git-stash.sh:576
+#: git-legacy-stash.sh:622
 msgid "Cannot apply a stash in the middle of a merge"
 msgstr "По време на сливане не може да приложите нещо скатано"
 
-#: git-stash.sh:584
+#: git-legacy-stash.sh:630
 msgid "Conflicts in index. Try without --index."
 msgstr ""
 "В индекса има конфликти.  Пробвайте да изпълните командата без опцията „--"
 "index“."
 
-#: git-stash.sh:586
+#: git-legacy-stash.sh:632
 msgid "Could not save index tree"
 msgstr "Дървото сочено от индекса не може да бъде запазено"
 
-#: git-stash.sh:595
+#: git-legacy-stash.sh:641
 msgid "Could not restore untracked files from stash entry"
 msgstr "Неследени файлове не могат да се възстановят от скатаното"
 
-#: git-stash.sh:620
+#: git-legacy-stash.sh:666
 msgid "Cannot unstage modified files"
 msgstr "Променените файлове не могат да бъдат извадени от индекса"
 
-#: git-stash.sh:635
-msgid "Index was not unstashed."
-msgstr "Индексът не е скатан."
-
-#: git-stash.sh:649
-msgid "The stash entry is kept in case you need it again."
-msgstr "Скатаното е запазено в случай, че ви потрябва отново"
-
-#: git-stash.sh:658
+#: git-legacy-stash.sh:704
 #, sh-format
 msgid "Dropped ${REV} ($s)"
 msgstr "Изтрито е скатаното „${REV}“ ($s)"
 
-#: git-stash.sh:659
+#: git-legacy-stash.sh:705
 #, sh-format
 msgid "${REV}: Could not drop stash entry"
 msgstr "Скатаното „${REV}“ не може да бъде изтрито"
 
-#: git-stash.sh:667
-msgid "No branch name specified"
-msgstr "Не е указано име на клон"
-
-#: git-stash.sh:746
+#: git-legacy-stash.sh:792
 msgid "(To restore them type \"git stash apply\")"
 msgstr "(За да ги възстановите, изпълнете командата „git stash apply“)"
 
-#: git-submodule.sh:188
+#: git-submodule.sh:202
 msgid "Relative path can only be used from the toplevel of the working tree"
 msgstr ""
 "Относителен път може да се ползва само от основната директория на работното "
 "дърво"
 
-#: git-submodule.sh:198
+#: git-submodule.sh:212
 #, sh-format
 msgid "repo URL: '$repo' must be absolute or begin with ./|../"
 msgstr ""
 "адрес на хранилище: „${repo}“ трябва или да е абсолютен, или да започва с "
 "„./“ или „../“"
 
-#: git-submodule.sh:217
+#: git-submodule.sh:231
 #, sh-format
 msgid "'$sm_path' already exists in the index"
 msgstr "„${sm_path}“ вече съществува в индекса"
 
-#: git-submodule.sh:220
+#: git-submodule.sh:234
 #, sh-format
 msgid "'$sm_path' already exists in the index and is not a submodule"
 msgstr "„${sm_path}“ вече съществува в индекса и не е подмодул"
 
-#: git-submodule.sh:226
+#: git-submodule.sh:241
+#, sh-format
+msgid "'$sm_path' does not have a commit checked out"
+msgstr "в „${sm_path}“ не е изтеглено подаване"
+
+#: git-submodule.sh:247
 #, sh-format
 msgid ""
 "The following path is ignored by one of your .gitignore files:\n"
@@ -17169,24 +23557,24 @@ msgstr ""
 "${sm_path}\n"
 "Използвайте опцията „-f“, ако за да го добавите наистина."
 
-#: git-submodule.sh:249
+#: git-submodule.sh:270
 #, sh-format
 msgid "Adding existing repo at '$sm_path' to the index"
 msgstr "Добавяне на съществуващото хранилище в „${sm_path}“ към индекса"
 
-#: git-submodule.sh:251
+#: git-submodule.sh:272
 #, sh-format
 msgid "'$sm_path' already exists and is not a valid git repo"
 msgstr "„${sm_path}“ съществува, а не е хранилище на Git"
 
-#: git-submodule.sh:259
+#: git-submodule.sh:280
 #, sh-format
 msgid "A git directory for '$sm_name' is found locally with remote(s):"
 msgstr ""
 "Открита е локална директория на Git — „${sm_name}“, която сочи към "
 "отдалечените хранилища:"
 
-#: git-submodule.sh:261
+#: git-submodule.sh:282
 #, sh-format
 msgid ""
 "If you want to reuse this local git directory instead of cloning again from\n"
@@ -17203,48 +23591,37 @@ msgstr ""
 "правилното хранилище или ако не знаете какво означава това, използвайте\n"
 "друго име като аргумент към опцията „--name“."
 
-#: git-submodule.sh:267
+#: git-submodule.sh:288
 #, sh-format
 msgid "Reactivating local git directory for submodule '$sm_name'."
 msgstr "Активиране на локалното хранилище за подмодула „${sm_name}“ наново."
 
-#: git-submodule.sh:279
+#: git-submodule.sh:300
 #, sh-format
 msgid "Unable to checkout submodule '$sm_path'"
 msgstr "Подмодулът „${sm_path}“ не може да бъде изтеглен"
 
-#: git-submodule.sh:284
+#: git-submodule.sh:305
 #, sh-format
 msgid "Failed to add submodule '$sm_path'"
 msgstr "Неуспешно добавяне на подмодула „${sm_path}“"
 
-#: git-submodule.sh:293
+#: git-submodule.sh:314
 #, sh-format
 msgid "Failed to register submodule '$sm_path'"
 msgstr "Неуспешно регистриране на подмодула „${sm_path}“"
 
-#: git-submodule.sh:354
-#, sh-format
-msgid "Entering '$displaypath'"
-msgstr "Влизане в „${displaypath}“"
-
-#: git-submodule.sh:374
-#, sh-format
-msgid "Stopping at '$displaypath'; script returned non-zero status."
-msgstr ""
-"Спиране при „${displaypath}“ — изходният код от скрипта бе различен от 0."
-
-#: git-submodule.sh:600
+#: git-submodule.sh:580
 #, sh-format
 msgid "Unable to find current revision in submodule path '$displaypath'"
 msgstr "Текущата версия за подмодула в „${displaypath}“ липсва"
 
-#: git-submodule.sh:610
+#: git-submodule.sh:590
 #, sh-format
 msgid "Unable to fetch in submodule path '$sm_path'"
 msgstr "Неуспешно доставяне в пътя към подмодул „${sm_path}“"
 
-#: git-submodule.sh:615
+#: git-submodule.sh:595
 #, sh-format
 msgid ""
 "Unable to find current ${remote_name}/${branch} revision in submodule path "
@@ -17253,94 +23630,98 @@ msgstr ""
 "Текущата версия „${remote_name}/${branch}“ в пътя към подмодул „${sm_path}“ "
 "липсва"
 
-#: git-submodule.sh:633
+#: git-submodule.sh:613
 #, sh-format
-msgid "Unable to fetch in submodule path '$displaypath'"
-msgstr "Неуспешно доставяне в пътя към подмодул „${displaypath}“"
+msgid ""
+"Unable to fetch in submodule path '$displaypath'; trying to directly fetch "
+"$sha1:"
+msgstr ""
+"Неуспешно доставяне в пътя към подмодул „${displaypath}“, опит за директно "
+"доставяне на „${sha1}“"
 
-#: git-submodule.sh:639
+#: git-submodule.sh:619
 #, sh-format
 msgid ""
 "Fetched in submodule path '$displaypath', but it did not contain $sha1. "
 "Direct fetching of that commit failed."
 msgstr ""
 "Подмодулът в пътя „$displaypath“ е доставен, но не съдържа обекта със сума\n"
-"„$sha1“.  Директното доставяне на това подаване е неуспешно."
+"„${sha1}“.  Директното доставяне на това подаване е неуспешно."
 
-#: git-submodule.sh:646
+#: git-submodule.sh:626
 #, sh-format
 msgid "Unable to checkout '$sha1' in submodule path '$displaypath'"
 msgstr ""
 "Неуспешно изтегляне на версия „${sha1}“ в пътя към подмодул „${displaypath}“'"
 
-#: git-submodule.sh:647
+#: git-submodule.sh:627
 #, sh-format
 msgid "Submodule path '$displaypath': checked out '$sha1'"
 msgstr "Път към подмодул „${displaypath}“: изтеглена е версия „${sha1}“"
 
-#: git-submodule.sh:651
+#: git-submodule.sh:631
 #, sh-format
 msgid "Unable to rebase '$sha1' in submodule path '$displaypath'"
 msgstr ""
 "Неуспешно пребазиране на версия „${sha1}“ в пътя към подмодул "
 "„${displaypath}“"
 
-#: git-submodule.sh:652
+#: git-submodule.sh:632
 #, sh-format
 msgid "Submodule path '$displaypath': rebased into '$sha1'"
 msgstr "Път към подмодул „${displaypath}“: пребазиране върху версия „${sha1}“"
 
-#: git-submodule.sh:657
+#: git-submodule.sh:637
 #, sh-format
 msgid "Unable to merge '$sha1' in submodule path '$displaypath'"
 msgstr ""
 "Неуспешно сливане на версия „${sha1}“ в пътя към подмодул „${displaypath}“"
 
-#: git-submodule.sh:658
+#: git-submodule.sh:638
 #, sh-format
 msgid "Submodule path '$displaypath': merged in '$sha1'"
 msgstr "Път към подмодул „${displaypath}“: сливане с версия „${sha1}“"
 
-#: git-submodule.sh:663
+#: git-submodule.sh:643
 #, sh-format
 msgid "Execution of '$command $sha1' failed in submodule path '$displaypath'"
 msgstr ""
 "Неуспешно изпълнение на командата „${command} ${sha1}“ в пътя към подмодул "
 "„${displaypath}“"
 
-#: git-submodule.sh:664
+#: git-submodule.sh:644
 #, sh-format
 msgid "Submodule path '$displaypath': '$command $sha1'"
 msgstr "Път към подмодул „${displaypath}“: „${command} ${sha1}“"
 
-#: git-submodule.sh:695
+#: git-submodule.sh:675
 #, sh-format
 msgid "Failed to recurse into submodule path '$displaypath'"
 msgstr ""
 "Неуспешна обработка на поддиректориите в пътя към подмодул „${displaypath}“"
 
-#: git-submodule.sh:791
+#: git-submodule.sh:886
 msgid "The --cached option cannot be used with the --files option"
 msgstr "Опциите „--cached“ и „--files“ са несъвместими"
 
-#: git-submodule.sh:843
+#: git-submodule.sh:938
 #, sh-format
 msgid "unexpected mode $mod_dst"
 msgstr "неочакван режим „${mod_dst}“"
 
-#: git-submodule.sh:863
+#: git-submodule.sh:958
 #, sh-format
 msgid "  Warn: $display_name doesn't contain commit $sha1_src"
 msgstr ""
 "  ПРЕДУПРЕЖДЕНИЕ: „${display_name}“ не съдържа подаването „${sha1_src}“"
 
-#: git-submodule.sh:866
+#: git-submodule.sh:961
 #, sh-format
 msgid "  Warn: $display_name doesn't contain commit $sha1_dst"
 msgstr ""
 "  ПРЕДУПРЕЖДЕНИЕ: „${display_name}“ не съдържа подаването „${sha1_dst}“"
 
-#: git-submodule.sh:869
+#: git-submodule.sh:964
 #, sh-format
 msgid "  Warn: $display_name doesn't contain commits $sha1_src and $sha1_dst"
 msgstr ""
@@ -17352,12 +23733,21 @@ msgstr ""
 msgid "See git-${cmd}(1) for details."
 msgstr "За повече информация погледнете ръководството на „git-${cmd}(1)“"
 
-#: git-rebase--interactive.sh:142
+#: git-rebase--preserve-merges.sh:109
+msgid "Applied autostash."
+msgstr "Автоматично скатаното е приложено."
+
+#: git-rebase--preserve-merges.sh:112
+#, sh-format
+msgid "Cannot store $stash_sha1"
+msgstr "„$stash_sha1“ не може да бъде запазен"
+
+#: git-rebase--preserve-merges.sh:191
 #, sh-format
 msgid "Rebasing ($new_count/$total)"
 msgstr "Пребазиране ($new_count/$total)"
 
-#: git-rebase--interactive.sh:158
+#: git-rebase--preserve-merges.sh:207
 msgid ""
 "\n"
 "Commands:\n"
@@ -17366,7 +23756,7 @@ msgid ""
 "e, edit <commit> = use commit, but stop for amending\n"
 "s, squash <commit> = use commit, but meld into previous commit\n"
 "f, fixup <commit> = like \"squash\", but discard this commit's log message\n"
-"x, exec <command> = run command (the rest of the line) using shell\n"
+"x, exec <commit> = run command (the rest of the line) using shell\n"
 "d, drop <commit> = remove commit\n"
 "l, label <label> = label current HEAD with a name\n"
 "t, reset <label> = reset HEAD to a label\n"
@@ -17379,42 +23769,29 @@ msgid ""
 msgstr ""
 "\n"
 "Команди:\n"
-" p, pick — прилагане на подаването\n"
-" r, reword — прилагане на подаването, но смяна на съобщението му\n"
-" e, edit — прилагане на подаването и спиране при него за още промени\n"
-" s, squash — вкарване на подаването в предходното му\n"
-" f, fixup —  вкарване на подаването в предходното му, без смяна на "
-"съобщението\n"
-" x, exec — изпълнение на команда към обвивката: останалата част на реда\n"
-" d, drop — прескачане на подаването\n"
-" l, label ЕТИКЕТ — задаване на етикет на указаното от HEAD\n"
-" t, reset ЕТИКЕТ — занулявяне на HEAD към ЕТИКЕТа\n"
+" p, pick ПОДАВАНЕ   — прилагане на подаването\n"
+" r, reword ПОДАВАНЕ — прилагане на подаването, но смяна на съобщението му\n"
+" e, edit ПОДАВАНЕ   — прилагане на подаването и спиране при него за още "
+"промени\n"
+" s, squash ПОДАВАНЕ — вкарване на подаването в предходното му\n"
+" f, fixup ПОДАВАНЕ  — вкарване на подаването в предходното му, без смяна на\n"
+"                      съобщението\n"
+" x, exec ПОДАВАНЕ   — изпълнение на команда към обвивката: останалата част "
+"на\n"
+"                      реда\n"
+" d, drop ПОДАВАНЕ   — прескачане на подаването\n"
+" l, label ЕТИКЕТ    — задаване на етикет на указаното от HEAD\n"
+" t, reset ЕТИКЕТ    — зануляване на HEAD към ЕТИКЕТа\n"
 " m, merge [-C ПОДАВАНЕ | -c ПОДАВАНЕ] ЕТИКЕТ [# ЕДИН_РЕД]\n"
-"        създаване на подаване със сливане със съобщението от първоначалното\n"
-"        подаване (или съобщението от ЕДИН_РЕД,  ако не е зададено подаване\n"
-"        със сливане.  С опцията „-c ПОДАВАНЕ“, може да смените съобщението.\n"
+"                    — създаване на подаване със сливане със съобщението от\n"
+"                      първоначалното подаване (или съобщението от ЕДИН_РЕД,\n"
+"                      ако не е зададено подаване със сливане.  С опцията\n"
+"                      „-c ПОДАВАНЕ“, може да смените съобщението.\n"
 "\n"
 "Може да променяте последователността на редовете — те се изпълняват\n"
 "последователно отгоре-надолу.\n"
 
-#: git-rebase--interactive.sh:179
-msgid ""
-"\n"
-"Do not remove any line. Use 'drop' explicitly to remove a commit.\n"
-msgstr ""
-"\n"
-"Не изтривайте редове.  Подаванията могат да се прескачат с командата "
-"„drop“.\n"
-
-#: git-rebase--interactive.sh:183
-msgid ""
-"\n"
-"If you remove a line here THAT COMMIT WILL BE LOST.\n"
-msgstr ""
-"\n"
-"Ако изтриете ред, съответстващото му подаване ще бъде ИЗТРИТО.\n"
-
-#: git-rebase--interactive.sh:221
+#: git-rebase--preserve-merges.sh:270
 #, sh-format
 msgid ""
 "You can amend the commit now, with\n"
@@ -17433,84 +23810,84 @@ msgstr ""
 "\n"
 "    git rebase --continue"
 
-#: git-rebase--interactive.sh:246
+#: git-rebase--preserve-merges.sh:295
 #, sh-format
 msgid "$sha1: not a commit that can be picked"
 msgstr "$sha1: това не е подаване, което може да бъде отбрано"
 
-#: git-rebase--interactive.sh:285
+#: git-rebase--preserve-merges.sh:334
 #, sh-format
 msgid "Invalid commit name: $sha1"
 msgstr "Неправилно име на подаване: „$sha1“"
 
-#: git-rebase--interactive.sh:325
+#: git-rebase--preserve-merges.sh:364
 msgid "Cannot write current commit's replacement sha1"
 msgstr ""
 "Заместващата сума по SHA1 за текущото подаване не може да бъде запазена"
 
-#: git-rebase--interactive.sh:376
+#: git-rebase--preserve-merges.sh:415
 #, sh-format
 msgid "Fast-forward to $sha1"
 msgstr "Превъртане до „$sha1“"
 
-#: git-rebase--interactive.sh:378
+#: git-rebase--preserve-merges.sh:417
 #, sh-format
 msgid "Cannot fast-forward to $sha1"
 msgstr "Не може да се превърти до „$sha1“"
 
-#: git-rebase--interactive.sh:387
+#: git-rebase--preserve-merges.sh:426
 #, sh-format
 msgid "Cannot move HEAD to $first_parent"
 msgstr "Указателят „HEAD“ не може да се насочи към „$first_parent“"
 
-#: git-rebase--interactive.sh:392
+#: git-rebase--preserve-merges.sh:431
 #, sh-format
 msgid "Refusing to squash a merge: $sha1"
 msgstr "Подаването не може да се смачка: „$sha1“"
 
-#: git-rebase--interactive.sh:410
+#: git-rebase--preserve-merges.sh:449
 #, sh-format
 msgid "Error redoing merge $sha1"
 msgstr "Грешка при повтарянето на сливането на „$sha1“"
 
-#: git-rebase--interactive.sh:419
+#: git-rebase--preserve-merges.sh:458
 #, sh-format
 msgid "Could not pick $sha1"
 msgstr "„$sha1“ не може да се отбере."
 
-#: git-rebase--interactive.sh:428
+#: git-rebase--preserve-merges.sh:467
 #, sh-format
 msgid "This is the commit message #${n}:"
 msgstr "Това е съобщение при подаване №${n}:"
 
-#: git-rebase--interactive.sh:433
+#: git-rebase--preserve-merges.sh:472
 #, sh-format
 msgid "The commit message #${n} will be skipped:"
 msgstr "Съобщение при подаване №${n} ще бъде прескочено."
 
-#: git-rebase--interactive.sh:444
+#: git-rebase--preserve-merges.sh:483
 #, sh-format
 msgid "This is a combination of $count commit."
 msgid_plural "This is a combination of $count commits."
 msgstr[0] "Това е обединение от $count подаване."
 msgstr[1] "Това е обединение от $count подавания."
 
-#: git-rebase--interactive.sh:453
+#: git-rebase--preserve-merges.sh:492
 #, sh-format
 msgid "Cannot write $fixup_msg"
 msgstr "Новото съобщение при подаване „$fixup_msg“ не може да бъде запазено"
 
-#: git-rebase--interactive.sh:456
+#: git-rebase--preserve-merges.sh:495
 msgid "This is a combination of 2 commits."
 msgstr "Това е обединение от 2 подавания"
 
-#: git-rebase--interactive.sh:497 git-rebase--interactive.sh:540
-#: git-rebase--interactive.sh:543
+#: git-rebase--preserve-merges.sh:536 git-rebase--preserve-merges.sh:579
+#: git-rebase--preserve-merges.sh:582
 #, sh-format
 msgid "Could not apply $sha1... $rest"
 msgstr "Не може да се подаде $sha1… $rest"
 
-#: git-rebase--interactive.sh:572
+#: git-rebase--preserve-merges.sh:611
 #, sh-format
 msgid ""
 "Could not amend commit after successfully picking $sha1... $rest\n"
@@ -17526,31 +23903,31 @@ msgstr ""
 "коригирате,\n"
 "преди да можете да промените подаването."
 
-#: git-rebase--interactive.sh:587
+#: git-rebase--preserve-merges.sh:626
 #, sh-format
 msgid "Stopped at $sha1_abbrev... $rest"
 msgstr "Спиране при „$sha1_abbrev…“ $rest"
 
-#: git-rebase--interactive.sh:602
+#: git-rebase--preserve-merges.sh:641
 #, sh-format
 msgid "Cannot '$squash_style' without a previous commit"
 msgstr "Без предходно подаване не може да се изпълни „$squash_style“"
 
-#: git-rebase--interactive.sh:644
+#: git-rebase--preserve-merges.sh:683
 #, sh-format
 msgid "Executing: $rest"
 msgstr "В момента се изпълнява: $rest"
 
-#: git-rebase--interactive.sh:652
+#: git-rebase--preserve-merges.sh:691
 #, sh-format
 msgid "Execution failed: $rest"
 msgstr "Неуспешно изпълнение: $rest"
 
-#: git-rebase--interactive.sh:654
+#: git-rebase--preserve-merges.sh:693
 msgid "and made changes to the index and/or the working tree"
 msgstr "и промени индекса и/или работното дърво"
 
-#: git-rebase--interactive.sh:656
+#: git-rebase--preserve-merges.sh:695
 msgid ""
 "You can fix the problem, and then run\n"
 "\n"
@@ -17561,7 +23938,7 @@ msgstr ""
 "    git rebase --continue"
 
 #. TRANSLATORS: after these lines is a command to be issued by the user
-#: git-rebase--interactive.sh:669
+#: git-rebase--preserve-merges.sh:708
 #, sh-format
 msgid ""
 "Execution succeeded: $rest\n"
@@ -17576,29 +23953,25 @@ msgstr ""
 "\n"
 "    git rebase --continue"
 
-#: git-rebase--interactive.sh:680
+#: git-rebase--preserve-merges.sh:719
 #, sh-format
 msgid "Unknown command: $command $sha1 $rest"
 msgstr "Непозната команда: $command $sha1 $rest"
 
-#: git-rebase--interactive.sh:681
+#: git-rebase--preserve-merges.sh:720
 msgid "Please fix this using 'git rebase --edit-todo'."
 msgstr "Коригирайте това чрез „git rebase --edit-todo“."
 
-#: git-rebase--interactive.sh:716
+#: git-rebase--preserve-merges.sh:755
 #, sh-format
 msgid "Successfully rebased and updated $head_name."
 msgstr "Успешно пребазиране и обновяване на „$head_name“."
 
-#: git-rebase--interactive.sh:740
-msgid "could not detach HEAD"
-msgstr "указателят „HEAD“ не може да се отдели"
-
-#: git-rebase--interactive.sh:778
+#: git-rebase--preserve-merges.sh:812
 msgid "Could not remove CHERRY_PICK_HEAD"
 msgstr "Указателят „CHERRY_PICK_HEAD“ не може да бъде изтрит"
 
-#: git-rebase--interactive.sh:783
+#: git-rebase--preserve-merges.sh:817
 #, sh-format
 msgid ""
 "You have staged changes in your working tree.\n"
@@ -17628,11 +24001,11 @@ msgstr ""
 "\n"
 "    git rebase --continue\n"
 
-#: git-rebase--interactive.sh:800
+#: git-rebase--preserve-merges.sh:834
 msgid "Error trying to find the author identity to amend commit"
 msgstr "Не може да бъде открит автор за поправянето на подаването"
 
-#: git-rebase--interactive.sh:805
+#: git-rebase--preserve-merges.sh:839
 msgid ""
 "You have uncommitted changes in your working tree. Please commit them\n"
 "first and then run 'git rebase --continue' again."
@@ -17640,48 +24013,33 @@ msgstr ""
 "В работното дърво има неподадени промени.  Първо ги подайте, а след това\n"
 "отново изпълнете „git rebase --continue“."
 
-#: git-rebase--interactive.sh:810 git-rebase--interactive.sh:814
+#: git-rebase--preserve-merges.sh:844 git-rebase--preserve-merges.sh:848
 msgid "Could not commit staged changes."
 msgstr "Промените в индекса не могат да бъдат подадени."
 
-#: git-rebase--interactive.sh:843
-msgid ""
-"\n"
-"You are editing the todo file of an ongoing interactive rebase.\n"
-"To continue rebase after editing, run:\n"
-"    git rebase --continue\n"
-"\n"
-msgstr ""
-"\n"
-"В момента редактирате файла с командите на текущото интерактивно "
-"пребазиране.\n"
-"За да продължите пребазирането след това, изпълнете:\n"
-"    git rebase --continue\n"
-"\n"
-
-#: git-rebase--interactive.sh:851 git-rebase--interactive.sh:937
+#: git-rebase--preserve-merges.sh:879 git-rebase--preserve-merges.sh:965
 msgid "Could not execute editor"
 msgstr "Текстовият редактор не може да бъде стартиран"
 
-#: git-rebase--interactive.sh:872
+#: git-rebase--preserve-merges.sh:900
 #, sh-format
 msgid "Could not checkout $switch_to"
 msgstr "„$switch_to“ не може да се изтегли"
 
-#: git-rebase--interactive.sh:879
+#: git-rebase--preserve-merges.sh:907
 msgid "No HEAD?"
 msgstr "Липсва указател „HEAD“"
 
-#: git-rebase--interactive.sh:880
+#: git-rebase--preserve-merges.sh:908
 #, sh-format
 msgid "Could not create temporary $state_dir"
 msgstr "Временната директория „$state_dir“ не може да бъде създадена"
 
-#: git-rebase--interactive.sh:883
+#: git-rebase--preserve-merges.sh:911
 msgid "Could not mark as interactive"
 msgstr "Пребазирането не е интерактивно"
 
-#: git-rebase--interactive.sh:915
+#: git-rebase--preserve-merges.sh:943
 #, sh-format
 msgid "Rebase $shortrevisions onto $shortonto ($todocount command)"
 msgid_plural "Rebase $shortrevisions onto $shortonto ($todocount commands)"
@@ -17690,27 +24048,7 @@ msgstr[0] ""
 msgstr[1] ""
 "Пребазиране на $shortrevisions върху $shortonto ($todocount команди)"
 
-#: git-rebase--interactive.sh:920
-msgid ""
-"\n"
-"\tHowever, if you remove everything, the rebase will be aborted.\n"
-"\n"
-"\t"
-msgstr ""
-"\n"
-"    Ако изтриете всичко, пребазирането ще бъде преустановено.\n"
-"\n"
-"    "
-
-#: git-rebase--interactive.sh:927
-msgid "Note that empty commits are commented out"
-msgstr "Празните подавания са коментирани"
-
-#: git-rebase--interactive.sh:980
-msgid "Could not generate todo list"
-msgstr "Файлът с командите не може да се генерира"
-
-#: git-rebase--interactive.sh:1001 git-rebase--interactive.sh:1006
+#: git-rebase--preserve-merges.sh:997 git-rebase--preserve-merges.sh:1002
 msgid "Could not init rewritten commits"
 msgstr "Списъкът с презаписаните подавания не може да бъде създаден"
 
@@ -17719,144 +24057,82 @@ msgstr "Списъкът с презап
 msgid "usage: $dashless $USAGE"
 msgstr "Употреба: $dashless $USAGE"
 
-#: git-sh-setup.sh:190
+#: git-sh-setup.sh:191
 #, sh-format
 msgid "Cannot chdir to $cdup, the toplevel of the working tree"
 msgstr ""
 "Не може да се премине към „$cdup“ — основната директория на работното дърво."
 
-#: git-sh-setup.sh:199 git-sh-setup.sh:206
+#: git-sh-setup.sh:200 git-sh-setup.sh:207
 #, sh-format
 msgid "fatal: $program_name cannot be used without a working tree."
 msgstr ""
 "ФАТАЛНА ГРЕШКА: „$program_name“ не може да се ползва без работно дърво."
 
-#: git-sh-setup.sh:220
+#: git-sh-setup.sh:221
 msgid "Cannot rebase: You have unstaged changes."
 msgstr "Не може да пребазирате, защото има промени, които не са в индекса."
 
-#: git-sh-setup.sh:223
+#: git-sh-setup.sh:224
 msgid "Cannot rewrite branches: You have unstaged changes."
 msgstr ""
 "Не може да презапишете клоните, защото има промени, които не са в индекса."
 
-#: git-sh-setup.sh:226
+#: git-sh-setup.sh:227
 msgid "Cannot pull with rebase: You have unstaged changes."
 msgstr ""
 "Не можете да издърпвате при това пребазиране, защото има промени, които не "
 "са в индекса."
 
-#: git-sh-setup.sh:229
+#: git-sh-setup.sh:230
 #, sh-format
 msgid "Cannot $action: You have unstaged changes."
 msgstr ""
 "Не можете да изпълните „$action“, защото има промени, които не са в индекса."
 
-#: git-sh-setup.sh:242
+#: git-sh-setup.sh:243
 msgid "Cannot rebase: Your index contains uncommitted changes."
 msgstr "Не може да пребазирате, защото в индекса има неподадени промени."
 
-#: git-sh-setup.sh:245
+#: git-sh-setup.sh:246
 msgid "Cannot pull with rebase: Your index contains uncommitted changes."
 msgstr ""
 "Не можете да издърпвате при това пребазиране, защото в индекса има "
 "неподадени промени."
 
-#: git-sh-setup.sh:248
+#: git-sh-setup.sh:249
 #, sh-format
 msgid "Cannot $action: Your index contains uncommitted changes."
 msgstr ""
 "Не можете да изпълните „$action“, защото в индекса има неподадени промени."
 
-#: git-sh-setup.sh:252
+#: git-sh-setup.sh:253
 msgid "Additionally, your index contains uncommitted changes."
 msgstr "Освен това в индекса има неподадени промени."
 
-#: git-sh-setup.sh:372
+#: git-sh-setup.sh:373
 msgid "You need to run this command from the toplevel of the working tree."
 msgstr ""
 "Тази команда трябва да се изпълни от основната директория на работното дърво"
 
-#: git-sh-setup.sh:377
+#: git-sh-setup.sh:378
 msgid "Unable to determine absolute path of git directory"
 msgstr "Абсолютният път на работното дърво не може да се определи"
 
 #. TRANSLATORS: you can adjust this to align "git add -i" status menu
-#: git-add--interactive.perl:196
+#: git-add--interactive.perl:212
 #, perl-format
 msgid "%12s %12s %s"
 msgstr "%14s %14s %s"
 
-#: git-add--interactive.perl:197
-msgid "staged"
-msgstr "в индекса"
-
-#: git-add--interactive.perl:197
-msgid "unstaged"
-msgstr "извън индекса"
-
-#: git-add--interactive.perl:253 git-add--interactive.perl:278
-msgid "binary"
-msgstr "двоично"
-
-#: git-add--interactive.perl:262 git-add--interactive.perl:316
-msgid "nothing"
-msgstr "нищо"
-
-#: git-add--interactive.perl:298 git-add--interactive.perl:313
-msgid "unchanged"
-msgstr "няма промени"
-
-#: git-add--interactive.perl:609
-#, perl-format
-msgid "added %d path\n"
-msgid_plural "added %d paths\n"
-msgstr[0] "%d файл добавен\n"
-msgstr[1] "%d файла добавени\n"
-
-#: git-add--interactive.perl:612
-#, perl-format
-msgid "updated %d path\n"
-msgid_plural "updated %d paths\n"
-msgstr[0] "%d файл обновен\n"
-msgstr[1] "%d файла обновени\n"
-
-#: git-add--interactive.perl:615
-#, perl-format
-msgid "reverted %d path\n"
-msgid_plural "reverted %d paths\n"
-msgstr[0] "%d файл с отменени промени\n"
-msgstr[1] "%d файла с отменени промени\n"
-
-#: git-add--interactive.perl:618
+#: git-add--interactive.perl:634
 #, perl-format
 msgid "touched %d path\n"
 msgid_plural "touched %d paths\n"
 msgstr[0] "%d файл засегнат\n"
 msgstr[1] "%d файла засегнати\n"
 
-#: git-add--interactive.perl:627
-msgid "Update"
-msgstr "Обновяване"
-
-#: git-add--interactive.perl:639
-msgid "Revert"
-msgstr "Отмяна"
-
-#: git-add--interactive.perl:662
-#, perl-format
-msgid "note: %s is untracked now.\n"
-msgstr "БЕЛЕЖКА: „%s“ вече не се следи.\n"
-
-#: git-add--interactive.perl:673
-msgid "Add untracked"
-msgstr "Добавяне на неследени"
-
-#: git-add--interactive.perl:679
-msgid "No untracked files.\n"
-msgstr "Няма неследени файлове.\n"
-
-#: git-add--interactive.perl:1033
+#: git-add--interactive.perl:1053
 msgid ""
 "If the patch applies cleanly, the edited hunk will immediately be\n"
 "marked for staging."
@@ -17865,7 +24141,7 @@ msgstr ""
 "незабавно\n"
 "добавено към индекса"
 
-#: git-add--interactive.perl:1036
+#: git-add--interactive.perl:1056
 msgid ""
 "If the patch applies cleanly, the edited hunk will immediately be\n"
 "marked for stashing."
@@ -17874,7 +24150,7 @@ msgstr ""
 "незабавно\n"
 "скътано"
 
-#: git-add--interactive.perl:1039
+#: git-add--interactive.perl:1059
 msgid ""
 "If the patch applies cleanly, the edited hunk will immediately be\n"
 "marked for unstaging."
@@ -17883,7 +24159,8 @@ msgstr ""
 "незабавно\n"
 "извадено от индекса."
 
-#: git-add--interactive.perl:1042 git-add--interactive.perl:1051
+#: git-add--interactive.perl:1062 git-add--interactive.perl:1071
+#: git-add--interactive.perl:1077
 msgid ""
 "If the patch applies cleanly, the edited hunk will immediately be\n"
 "marked for applying."
@@ -17892,7 +24169,8 @@ msgstr ""
 "незабавно\n"
 "набелязано за прилагане."
 
-#: git-add--interactive.perl:1045 git-add--interactive.perl:1048
+#: git-add--interactive.perl:1065 git-add--interactive.perl:1068
+#: git-add--interactive.perl:1074
 msgid ""
 "If the patch applies cleanly, the edited hunk will immediately be\n"
 "marked for discarding."
@@ -17901,16 +24179,12 @@ msgstr ""
 "незабавно\n"
 "набелязано за зануляване."
 
-#: git-add--interactive.perl:1085
+#: git-add--interactive.perl:1111
 #, perl-format
 msgid "failed to open hunk edit file for writing: %s"
 msgstr "файлът за редактиране на парчето код не може да бъде отворен: „%s“"
 
-#: git-add--interactive.perl:1086
-msgid "Manual hunk edit mode -- see bottom for a quick guide.\n"
-msgstr "Ръчно редактиране на парчета код — отдолу има подсказка.\n"
-
-#: git-add--interactive.perl:1092
+#: git-add--interactive.perl:1118
 #, perl-format
 msgid ""
 "---\n"
@@ -17924,38 +24198,13 @@ msgstr ""
 "За да пропуснете редовете започващи с „%s“ — изтрийте ги.\n"
 "Редовете, които започват с „%s“ ще бъдат пропуснати.\n"
 
-#. TRANSLATORS: 'it' refers to the patch mentioned in the previous messages.
-#: git-add--interactive.perl:1100
-msgid ""
-"If it does not apply cleanly, you will be given an opportunity to\n"
-"edit again.  If all lines of the hunk are removed, then the edit is\n"
-"aborted and the hunk is left unchanged.\n"
-msgstr ""
-"Ако е невъзможно чисто прилагане на кода, ще може пак да редактирате.  Ако\n"
-"изтриете всички редове от парчето код, то ще бъде оставено непроменено, а\n"
-"редактирането — отказано.\n"
-
-#: git-add--interactive.perl:1114
+#: git-add--interactive.perl:1140
 #, perl-format
 msgid "failed to open hunk edit file for reading: %s"
 msgstr ""
 "файлът за редактиране на парчето код не може да бъде отворен за четене: „%s“"
 
-#. TRANSLATORS: do not translate [y/n]
-#. The program will only accept that input
-#. at this point.
-#. Consider translating (saying "no" discards!) as
-#. (saying "n" for "no" discards!) if the translation
-#. of the word "no" does not start with n.
-#: git-add--interactive.perl:1213
-msgid ""
-"Your edited hunk does not apply. Edit again (saying \"no\" discards!) [y/n]? "
-msgstr ""
-"Редактираното парче не може да се приложи.  Да се продължи ли с "
-"редактирането? (текущите редакции ще се отменят при отказ!): „y“ (да)/ "
-"„n“ (не)? "
-
-#: git-add--interactive.perl:1222
+#: git-add--interactive.perl:1248
 msgid ""
 "y - stage this hunk\n"
 "n - do not stage this hunk\n"
@@ -17969,7 +24218,7 @@ msgstr ""
 "a — добавяне на това и всички следващи парчета от файла в индекса\n"
 "d — без добавяне на това и всички следващи парчета от файла в индекса"
 
-#: git-add--interactive.perl:1228
+#: git-add--interactive.perl:1254
 msgid ""
 "y - stash this hunk\n"
 "n - do not stash this hunk\n"
@@ -17983,7 +24232,7 @@ msgstr ""
 "a — скатаване на това и всички следващи парчета от файла\n"
 "d — без скатаване на това и всички следващи парчета от файла"
 
-#: git-add--interactive.perl:1234
+#: git-add--interactive.perl:1260
 msgid ""
 "y - unstage this hunk\n"
 "n - do not unstage this hunk\n"
@@ -17997,7 +24246,7 @@ msgstr ""
 "a — изваждане на това и всички следващи парчета от файла от индекса\n"
 "d — без изваждане на това и всички следващи парчета от файла от индекса"
 
-#: git-add--interactive.perl:1240
+#: git-add--interactive.perl:1266
 msgid ""
 "y - apply this hunk to index\n"
 "n - do not apply this hunk to index\n"
@@ -18011,7 +24260,7 @@ msgstr ""
 "a — прилагане на това и всички следващи парчета от файла към индекса\n"
 "d — без прилагане на това и всички следващи парчета от файла към индекса"
 
-#: git-add--interactive.perl:1246
+#: git-add--interactive.perl:1272 git-add--interactive.perl:1290
 msgid ""
 "y - discard this hunk from worktree\n"
 "n - do not discard this hunk from worktree\n"
@@ -18028,7 +24277,7 @@ msgstr ""
 "d — без премахване на това и всички следващи парчета от файла от работното "
 "дърво"
 
-#: git-add--interactive.perl:1252
+#: git-add--interactive.perl:1278
 msgid ""
 "y - discard this hunk from index and worktree\n"
 "n - do not discard this hunk from index and worktree\n"
@@ -18045,7 +24294,7 @@ msgstr ""
 "d — без премахване на това и всички следващи парчета от файла от индекса и "
 "работното дърво"
 
-#: git-add--interactive.perl:1258
+#: git-add--interactive.perl:1284
 msgid ""
 "y - apply this hunk to index and worktree\n"
 "n - do not apply this hunk to index and worktree\n"
@@ -18062,7 +24311,21 @@ msgstr ""
 "d — без прилагане на това и всички следващи парчета от файла от индекса и "
 "работното дърво"
 
-#: git-add--interactive.perl:1273
+#: git-add--interactive.perl:1296
+msgid ""
+"y - apply this hunk to worktree\n"
+"n - do not apply this hunk to worktree\n"
+"q - quit; do not apply this hunk or any of the remaining ones\n"
+"a - apply this hunk and all later hunks in the file\n"
+"d - do not apply this hunk or any of the later hunks in the file"
+msgstr ""
+"y — прилагане на парчето към работното дърво\n"
+"n — без прилагане на парчето към работното дърво\n"
+"q — изход, без прилагане на това и всички оставащи парчета\n"
+"a — прилагане на това и всички следващи парчета от файла\n"
+"d — без прилагане на това и всички следващи парчета от файла"
+
+#: git-add--interactive.perl:1311
 msgid ""
 "g - select a hunk to go to\n"
 "/ - search for a hunk matching the given regex\n"
@@ -18084,220 +24347,209 @@ msgstr ""
 "e — ръчно редактиране на текущото парче\n"
 "? — извеждане не помощта\n"
 
-#: git-add--interactive.perl:1304
+#: git-add--interactive.perl:1342
 msgid "The selected hunks do not apply to the index!\n"
 msgstr "Избраните парчета не могат да се добавят в индекса!\n"
 
-#: git-add--interactive.perl:1305
+#: git-add--interactive.perl:1343
 msgid "Apply them to the worktree anyway? "
 msgstr "Да се приложат ли към работното дърво? "
 
-#: git-add--interactive.perl:1308
+#: git-add--interactive.perl:1346
 msgid "Nothing was applied.\n"
 msgstr "Нищо не е приложено.\n"
 
-#: git-add--interactive.perl:1319
+#: git-add--interactive.perl:1357
 #, perl-format
 msgid "ignoring unmerged: %s\n"
 msgstr "пренебрегване на неслятото: „%s“\n"
 
-#: git-add--interactive.perl:1328
-msgid "Only binary files changed.\n"
-msgstr "Само двоични файлове са променени.\n"
-
-#: git-add--interactive.perl:1330
-msgid "No changes.\n"
-msgstr "Няма промени.\n"
-
-#: git-add--interactive.perl:1338
-msgid "Patch update"
-msgstr "Обновяване на кръпка"
-
-#: git-add--interactive.perl:1390
+#: git-add--interactive.perl:1428
 #, perl-format
 msgid "Stage mode change [y,n,q,a,d%s,?]? "
 msgstr "Добавяне на промяната на правата за достъп [y,n,q,a,d%s,?]? "
 
-#: git-add--interactive.perl:1391
+#: git-add--interactive.perl:1429
 #, perl-format
 msgid "Stage deletion [y,n,q,a,d%s,?]? "
 msgstr "Добавяне на изтриването [y,n,q,a,d%s,?]? "
 
-#: git-add--interactive.perl:1392
+#: git-add--interactive.perl:1430
 #, perl-format
 msgid "Stage this hunk [y,n,q,a,d%s,?]? "
 msgstr "Добавяне на това парче [y,n,q,a,d%s,?]? "
 
-#: git-add--interactive.perl:1395
+#: git-add--interactive.perl:1433
 #, perl-format
 msgid "Stash mode change [y,n,q,a,d%s,?]? "
 msgstr "Скатаване на промяната на правата за достъп [y,n,q,a,d%s,?]? "
 
-#: git-add--interactive.perl:1396
+#: git-add--interactive.perl:1434
 #, perl-format
 msgid "Stash deletion [y,n,q,a,d%s,?]? "
 msgstr "Скатаване на изтриването [y,n,q,a,d%s,?]? "
 
-#: git-add--interactive.perl:1397
+#: git-add--interactive.perl:1435
 #, perl-format
 msgid "Stash this hunk [y,n,q,a,d%s,?]? "
 msgstr "Скатаване на това парче [y,n,q,a,d%s,?]? "
 
-#: git-add--interactive.perl:1400
+#: git-add--interactive.perl:1438
 #, perl-format
 msgid "Unstage mode change [y,n,q,a,d%s,?]? "
 msgstr "Изваждане на промяната на правата за достъп [y,n,q,a,d%s,?]? "
 
-#: git-add--interactive.perl:1401
+#: git-add--interactive.perl:1439
 #, perl-format
 msgid "Unstage deletion [y,n,q,a,d%s,?]? "
 msgstr "Изваждане на изтриването [y,n,q,a,d%s,?]? "
 
-#: git-add--interactive.perl:1402
+#: git-add--interactive.perl:1440
 #, perl-format
 msgid "Unstage this hunk [y,n,q,a,d%s,?]? "
 msgstr "Изваждане на това парче [y,n,q,a,d%s,?]? "
 
-#: git-add--interactive.perl:1405
+#: git-add--interactive.perl:1443
 #, perl-format
 msgid "Apply mode change to index [y,n,q,a,d%s,?]? "
 msgstr ""
 "Прилагане на промяната на правата за достъп към индекса [y,n,q,a,d%s,?]? "
 
-#: git-add--interactive.perl:1406
+#: git-add--interactive.perl:1444
 #, perl-format
 msgid "Apply deletion to index [y,n,q,a,d%s,?]? "
 msgstr "Прилагане на изтриването към индекса [y,n,q,a,d%s,?]? "
 
-#: git-add--interactive.perl:1407
+#: git-add--interactive.perl:1445
 #, perl-format
 msgid "Apply this hunk to index [y,n,q,a,d%s,?]? "
 msgstr "Прилагане на това парче към индекса [y,n,q,a,d%s,?]? "
 
-#: git-add--interactive.perl:1410
+#: git-add--interactive.perl:1448 git-add--interactive.perl:1463
 #, perl-format
 msgid "Discard mode change from worktree [y,n,q,a,d%s,?]? "
 msgstr ""
 "Премахване на промяната в правата за достъп от работното дърво [y,n,q,a,d"
 "%s,?]? "
 
-#: git-add--interactive.perl:1411
+#: git-add--interactive.perl:1449 git-add--interactive.perl:1464
 #, perl-format
 msgid "Discard deletion from worktree [y,n,q,a,d%s,?]? "
 msgstr "Премахване на изтриването от работното дърво [y,n,q,a,d%s,?]? "
 
-#: git-add--interactive.perl:1412
+#: git-add--interactive.perl:1450 git-add--interactive.perl:1465
 #, perl-format
 msgid "Discard this hunk from worktree [y,n,q,a,d%s,?]? "
 msgstr "Премахване на парчето от работното дърво [y,n,q,a,d%s,?]? "
 
-#: git-add--interactive.perl:1415
+#: git-add--interactive.perl:1453
 #, perl-format
 msgid "Discard mode change from index and worktree [y,n,q,a,d%s,?]? "
 msgstr ""
 "Премахване на промяната в правата за достъп от индекса и работното дърво [y,"
 "n,q,a,d%s,?]? "
 
-#: git-add--interactive.perl:1416
+#: git-add--interactive.perl:1454
 #, perl-format
 msgid "Discard deletion from index and worktree [y,n,q,a,d%s,?]? "
 msgstr ""
 "Премахване на изтриването от индекса и работното дърво [y,n,q,a,d%s,?]? "
 
-#: git-add--interactive.perl:1417
+#: git-add--interactive.perl:1455
 #, perl-format
 msgid "Discard this hunk from index and worktree [y,n,q,a,d%s,?]? "
 msgstr "Премахване на парчето от индекса и работното дърво [y,n,q,a,d%s,?]? "
 
-#: git-add--interactive.perl:1420
+#: git-add--interactive.perl:1458
 #, perl-format
 msgid "Apply mode change to index and worktree [y,n,q,a,d%s,?]? "
 msgstr ""
 "Прилагане на промяната в правата за достъп от индекса и работното дърво [y,n,"
 "q,a,d%s,?]? "
 
-#: git-add--interactive.perl:1421
+#: git-add--interactive.perl:1459
 #, perl-format
 msgid "Apply deletion to index and worktree [y,n,q,a,d%s,?]? "
 msgstr ""
 "Прилагане на изтриването от индекса и работното дърво [y,n,q,a,d%s,?]? "
 
-#: git-add--interactive.perl:1422
+#: git-add--interactive.perl:1460
 #, perl-format
 msgid "Apply this hunk to index and worktree [y,n,q,a,d%s,?]? "
 msgstr "Прилагане на парчето от индекса и работното дърво [y,n,q,a,d%s,?]? "
 
-#: git-add--interactive.perl:1522
-msgid "No other hunks to goto\n"
-msgstr "Няма други парчета\n"
+#: git-add--interactive.perl:1468
+#, perl-format
+msgid "Apply mode change to worktree [y,n,q,a,d%s,?]? "
+msgstr ""
+"Прилагане на промяната в правата за достъп към работното дърво [y,n,q,a,d"
+"%s,?]? "
 
-#: git-add--interactive.perl:1529
-msgid "go to which hunk (<ret> to see more)? "
-msgstr "към кое парче да се придвижи (за повече варианти натиснете „enter“)? "
+#: git-add--interactive.perl:1469
+#, perl-format
+msgid "Apply deletion to worktree [y,n,q,a,d%s,?]? "
+msgstr "Прилагане на изтриването към работното дърво [y,n,q,a,d%s,?]? "
 
-#: git-add--interactive.perl:1531
-msgid "go to which hunk? "
-msgstr "към кое парче да се придвижи? "
+#: git-add--interactive.perl:1470
+#, perl-format
+msgid "Apply this hunk to worktree [y,n,q,a,d%s,?]? "
+msgstr "Прилагане на парчето към работното дърво [y,n,q,a,d%s,?]? "
+
+#: git-add--interactive.perl:1570
+msgid "No other hunks to goto\n"
+msgstr "Няма други парчета\n"
 
-#: git-add--interactive.perl:1540
+#: git-add--interactive.perl:1588
 #, perl-format
 msgid "Invalid number: '%s'\n"
 msgstr "Неправилен номер: „%s“\n"
 
-#: git-add--interactive.perl:1545
+#: git-add--interactive.perl:1593
 #, perl-format
 msgid "Sorry, only %d hunk available.\n"
 msgid_plural "Sorry, only %d hunks available.\n"
 msgstr[0] "Има само %d парче.\n"
 msgstr[1] "Има само %d парчета.\n"
 
-#: git-add--interactive.perl:1571
+#: git-add--interactive.perl:1619
 msgid "No other hunks to search\n"
 msgstr "Няма други парчета за търсене\n"
 
-#: git-add--interactive.perl:1575
-msgid "search for regex? "
-msgstr "да се търси с регулярен израз? "
-
-#: git-add--interactive.perl:1588
+#: git-add--interactive.perl:1636
 #, perl-format
 msgid "Malformed search regexp %s: %s\n"
 msgstr "Сгрешен регулярен израз „%s“: %s\n"
 
-#: git-add--interactive.perl:1598
+#: git-add--interactive.perl:1646
 msgid "No hunk matches the given pattern\n"
 msgstr "Никое парче не напасва на регулярния израз\n"
 
-#: git-add--interactive.perl:1610 git-add--interactive.perl:1632
+#: git-add--interactive.perl:1658 git-add--interactive.perl:1680
 msgid "No previous hunk\n"
 msgstr "Няма друго парче преди това\n"
 
-#: git-add--interactive.perl:1619 git-add--interactive.perl:1638
+#: git-add--interactive.perl:1667 git-add--interactive.perl:1686
 msgid "No next hunk\n"
 msgstr "Няма друго парче след това\n"
 
-#: git-add--interactive.perl:1644
+#: git-add--interactive.perl:1692
 msgid "Sorry, cannot split this hunk\n"
 msgstr "Това парче не може да бъде разделено\n"
 
-#: git-add--interactive.perl:1650
+#: git-add--interactive.perl:1698
 #, perl-format
 msgid "Split into %d hunk.\n"
 msgid_plural "Split into %d hunks.\n"
 msgstr[0] "Разделяне на %d парче.\n"
 msgstr[1] "Разделяне на %d парчета.\n"
 
-#: git-add--interactive.perl:1660
+#: git-add--interactive.perl:1708
 msgid "Sorry, cannot edit this hunk\n"
 msgstr "Това парче не може да бъде редактирано\n"
 
-#: git-add--interactive.perl:1706
-msgid "Review diff"
-msgstr "Преглед на разликата"
-
 #. TRANSLATORS: please do not translate the command names
 #. 'status', 'update', 'revert', etc.
-#: git-add--interactive.perl:1725
+#: git-add--interactive.perl:1773
 msgid ""
 "status        - show paths with changes\n"
 "update        - add working tree state to the staged set of changes\n"
@@ -18318,57 +24570,58 @@ msgstr ""
 "                и индекса\n"
 "add untracked — добавяне на неследените файлове към промените в индекса\n"
 
-#: git-add--interactive.perl:1742 git-add--interactive.perl:1747
-#: git-add--interactive.perl:1750 git-add--interactive.perl:1757
-#: git-add--interactive.perl:1761 git-add--interactive.perl:1767
+#: git-add--interactive.perl:1790 git-add--interactive.perl:1795
+#: git-add--interactive.perl:1798 git-add--interactive.perl:1805
+#: git-add--interactive.perl:1808 git-add--interactive.perl:1815
+#: git-add--interactive.perl:1819 git-add--interactive.perl:1825
 msgid "missing --"
 msgstr "„--“ липсва"
 
-#: git-add--interactive.perl:1763
+#: git-add--interactive.perl:1821
 #, perl-format
 msgid "unknown --patch mode: %s"
 msgstr "неизвестна стратегия за прилагане на кръпка: „%s“"
 
-#: git-add--interactive.perl:1769 git-add--interactive.perl:1775
+#: git-add--interactive.perl:1827 git-add--interactive.perl:1833
 #, perl-format
 msgid "invalid argument %s, expecting --"
 msgstr "указан е неправилен аргумент „%s“, а се очаква „--“."
 
-#: git-send-email.perl:130
+#: git-send-email.perl:138
 msgid "local zone differs from GMT by a non-minute interval\n"
 msgstr ""
 "разликата между местния часови пояс и GMT съдържа дробна част от минута\n"
 "\n"
 
-#: git-send-email.perl:137 git-send-email.perl:143
+#: git-send-email.perl:145 git-send-email.perl:151
 msgid "local time offset greater than or equal to 24 hours\n"
 msgstr "разликата между местния часовия пояс и GMT е 24 часа или повече\n"
 
-#: git-send-email.perl:211 git-send-email.perl:217
+#: git-send-email.perl:223 git-send-email.perl:229
 msgid "the editor exited uncleanly, aborting everything"
 msgstr ""
 "текстовият редактор приключи работата с грешка, всичко се преустановява"
 
-#: git-send-email.perl:294
+#: git-send-email.perl:310
 #, perl-format
 msgid ""
 "'%s' contains an intermediate version of the email you were composing.\n"
 msgstr "„%s“ съдържа временна версия на подготвяното е-писмо.\n"
 
-#: git-send-email.perl:299
+#: git-send-email.perl:315
 #, perl-format
 msgid "'%s.final' contains the composed email.\n"
 msgstr "„%s.final“ съдържа подготвеното е-писмо.\n"
 
-#: git-send-email.perl:317
+#: git-send-email.perl:408
 msgid "--dump-aliases incompatible with other options\n"
 msgstr "опцията „--dump-aliases“ е несъвместима с другите опции\n"
 
-#: git-send-email.perl:383 git-send-email.perl:638
+#: git-send-email.perl:481 git-send-email.perl:683
 msgid "Cannot run git format-patch from outside a repository\n"
 msgstr "Командата „git format-patch“ не може да се изпълни извън хранилище\n"
 
-#: git-send-email.perl:386
+#: git-send-email.perl:484
 msgid ""
 "`batch-size` and `relogin` must be specified together (via command-line or "
 "configuration option)\n"
@@ -18376,40 +24629,40 @@ msgstr ""
 "„batch-size“ и „relogin“ трябва да се указват заедно (или чрез командния "
 "ред, или чрез настройките)\n"
 
-#: git-send-email.perl:456
+#: git-send-email.perl:497
 #, perl-format
 msgid "Unknown --suppress-cc field: '%s'\n"
 msgstr "Непознато поле за опцията „--suppress-cc“: „%s“\n"
 
-#: git-send-email.perl:485
+#: git-send-email.perl:528
 #, perl-format
 msgid "Unknown --confirm setting: '%s'\n"
 msgstr "Непозната стойност за „--confirm“: %s\n"
 
-#: git-send-email.perl:513
+#: git-send-email.perl:556
 #, perl-format
 msgid "warning: sendmail alias with quotes is not supported: %s\n"
 msgstr ""
-"ПРЕДУПРЕЖДЕНИЕ: синоними за sendmail съдържащи кавички („\"“) не се "
+"ПРЕДУПРЕЖДЕНИЕ: псевдоними за sendmail съдържащи кавички („\"“) не се "
 "поддържат: %s\n"
 
-#: git-send-email.perl:515
+#: git-send-email.perl:558
 #, perl-format
 msgid "warning: `:include:` not supported: %s\n"
 msgstr "ПРЕДУПРЕЖДЕНИЕ: „:include:“ не се поддържа: %s\n"
 
-#: git-send-email.perl:517
+#: git-send-email.perl:560
 #, perl-format
 msgid "warning: `/file` or `|pipe` redirection not supported: %s\n"
 msgstr ""
 "ПРЕДУПРЕЖДЕНИЕ: пренасочвания „/file“ или „|pipe“ не се поддържат: %s\n"
 
-#: git-send-email.perl:522
+#: git-send-email.perl:565
 #, perl-format
 msgid "warning: sendmail line is not recognized: %s\n"
 msgstr "ПРЕДУПРЕЖДЕНИЕ: редът за „sendmail“ не е разпознат: %s\n"
 
-#: git-send-email.perl:604
+#: git-send-email.perl:649
 #, perl-format
 msgid ""
 "File '%s' exists but it could also be the range of commits\n"
@@ -18424,12 +24677,12 @@ msgstr ""
 "    ● укажете „./%s“ за файл;\n"
 "    ● използвате опцията „--format-patch“ за диапазон.\n"
 
-#: git-send-email.perl:625
+#: git-send-email.perl:670
 #, perl-format
 msgid "Failed to opendir %s: %s"
 msgstr "Директорията „%s“ не може да се отвори: %s"
 
-#: git-send-email.perl:649
+#: git-send-email.perl:694
 #, perl-format
 msgid ""
 "fatal: %s: %s\n"
@@ -18438,7 +24691,7 @@ msgstr ""
 "ФАТАЛНА ГРЕШКА: %s: %s\n"
 "ПРЕДУПРЕЖДЕНИЕ: не са пратени никакви кръпки\n"
 
-#: git-send-email.perl:660
+#: git-send-email.perl:705
 msgid ""
 "\n"
 "No patch files specified!\n"
@@ -18448,17 +24701,17 @@ msgstr ""
 "Не са указани кръпки!\n"
 "\n"
 
-#: git-send-email.perl:673
+#: git-send-email.perl:718
 #, perl-format
 msgid "No subject line in %s?"
 msgstr "В „%s“ липсва тема"
 
-#: git-send-email.perl:683
+#: git-send-email.perl:728
 #, perl-format
 msgid "Failed to open for writing %s: %s"
 msgstr "„%s“ не може да се отвори за запис: %s"
 
-#: git-send-email.perl:694
+#: git-send-email.perl:739
 msgid ""
 "Lines beginning in \"GIT:\" will be removed.\n"
 "Consider including an overall diffstat or table of contents\n"
@@ -18473,27 +24726,27 @@ msgstr ""
 "\n"
 "Изтрийте всичко, ако не искате да изпратите обобщаващо писмо.\n"
 
-#: git-send-email.perl:718
+#: git-send-email.perl:763
 #, perl-format
 msgid "Failed to open %s: %s"
 msgstr "„%s“ не може да се отвори: %s"
 
-#: git-send-email.perl:735
+#: git-send-email.perl:780
 #, perl-format
 msgid "Failed to open %s.final: %s"
 msgstr "„%s.final“ не може да се отвори: %s"
 
-#: git-send-email.perl:778
+#: git-send-email.perl:823
 msgid "Summary email is empty, skipping it\n"
 msgstr "Обобщаващото писмо е празно и се прескача\n"
 
 #. TRANSLATORS: please keep [y/N] as is.
-#: git-send-email.perl:813
+#: git-send-email.perl:858
 #, perl-format
 msgid "Are you sure you want to use <%s> [y/N]? "
 msgstr "Сигурни ли сте, че искате да ползвате „%s“ [y/N]? "
 
-#: git-send-email.perl:868
+#: git-send-email.perl:913
 msgid ""
 "The following files are 8bit, but do not declare a Content-Transfer-"
 "Encoding.\n"
@@ -18501,11 +24754,11 @@ msgstr ""
 "Следните файлове са 8 битови, но не са с обявена заглавна част „Content-"
 "Transfer-Encoding“.\n"
 
-#: git-send-email.perl:873
+#: git-send-email.perl:918
 msgid "Which 8bit encoding should I declare [UTF-8]? "
 msgstr "Кое 8 битово кодиране се ползва [стандартно: UTF-8]? "
 
-#: git-send-email.perl:881
+#: git-send-email.perl:926
 #, perl-format
 msgid ""
 "Refusing to send because the patch\n"
@@ -18518,22 +24771,22 @@ msgstr ""
 "все още е с шаблонното заглавие „*** SUBJECT HERE ***“.  Ползвайте опцията\n"
 "„--force“, ако сте сигурни, че точно това искате да изпратите.\n"
 
-#: git-send-email.perl:900
+#: git-send-email.perl:945
 msgid "To whom should the emails be sent (if anyone)?"
 msgstr "На кой да се пратят е-писмата (незадължително поле)"
 
-#: git-send-email.perl:918
+#: git-send-email.perl:963
 #, perl-format
 msgid "fatal: alias '%s' expands to itself\n"
-msgstr "ФАТАЛНА ГРЕШКА: „%s“ е синоним на себе си\n"
+msgstr "ФАТАЛНА ГРЕШКА: „%s“ е псевдоним на себе си\n"
 
-#: git-send-email.perl:930
+#: git-send-email.perl:975
 msgid "Message-ID to be used as In-Reply-To for the first email (if any)? "
 msgstr ""
 "Идентификатор на съобщение „Message-ID“, което да се използва за обявяването "
 "на отговор „In-Reply-To“ (незадължително поле)"
 
-#: git-send-email.perl:988 git-send-email.perl:996
+#: git-send-email.perl:1033 git-send-email.perl:1041
 #, perl-format
 msgid "error: unable to extract a valid address from: %s\n"
 msgstr "ГРЕШКА: не може да се извлече адрес от „%s“\n"
@@ -18541,18 +24794,18 @@ msgstr "ГРЕШКА: не може да
 #. TRANSLATORS: Make sure to include [q] [d] [e] in your
 #. translation. The program will only accept English input
 #. at this point.
-#: git-send-email.perl:1000
+#: git-send-email.perl:1045
 msgid "What to do with this address? ([q]uit|[d]rop|[e]dit): "
 msgstr ""
 "Какво да се направи с този адрес? „q“ (спиране), „d“ (изтриване), "
 "„e“ (редактиране): "
 
-#: git-send-email.perl:1317
+#: git-send-email.perl:1362
 #, perl-format
 msgid "CA path \"%s\" does not exist"
 msgstr "Пътят към сертификат „%s“ не съществува."
 
-#: git-send-email.perl:1400
+#: git-send-email.perl:1445
 msgid ""
 "    The Cc list above has been expanded by additional\n"
 "    addresses found in the patch commit message. By default\n"
@@ -18580,132 +24833,132 @@ msgstr ""
 #. TRANSLATORS: Make sure to include [y] [n] [e] [q] [a] in your
 #. translation. The program will only accept English input
 #. at this point.
-#: git-send-email.perl:1415
+#: git-send-email.perl:1460
 msgid "Send this email? ([y]es|[n]o|[e]dit|[q]uit|[a]ll): "
 msgstr ""
 "Изпращане на е-писмото? „y“ (да), „n“ (не), „e“ (редактиране), „q“ (изход), "
 "„a“ (всичко): "
 
-#: git-send-email.perl:1418
+#: git-send-email.perl:1463
 msgid "Send this email reply required"
 msgstr "Изискване на отговор към това е-писмо"
 
-#: git-send-email.perl:1446
+#: git-send-email.perl:1491
 msgid "The required SMTP server is not properly defined."
 msgstr "Сървърът за SMTP не е настроен правилно."
 
-#: git-send-email.perl:1493
+#: git-send-email.perl:1538
 #, perl-format
 msgid "Server does not support STARTTLS! %s"
 msgstr "Сървърът не поддържа „STARTTLS“! %s"
 
-#: git-send-email.perl:1498 git-send-email.perl:1502
+#: git-send-email.perl:1543 git-send-email.perl:1547
 #, perl-format
 msgid "STARTTLS failed! %s"
 msgstr "Неуспешно изпълнение на STARTTLS! %s"
 
-#: git-send-email.perl:1512
+#: git-send-email.perl:1556
 msgid "Unable to initialize SMTP properly. Check config and use --smtp-debug."
 msgstr ""
 "Подсистемата за SMTP не може да се инициализира.  Проверете настройките и "
 "използвайте опцията: „--smtp-debug“."
 
-#: git-send-email.perl:1530
+#: git-send-email.perl:1574
 #, perl-format
 msgid "Failed to send %s\n"
 msgstr "„%s“ не може да бъде изпратен\n"
 
-#: git-send-email.perl:1533
+#: git-send-email.perl:1577
 #, perl-format
 msgid "Dry-Sent %s\n"
 msgstr "Проба за изпращане на „%s“\n"
 
-#: git-send-email.perl:1533
+#: git-send-email.perl:1577
 #, perl-format
 msgid "Sent %s\n"
 msgstr "Изпращане на „%s“\n"
 
-#: git-send-email.perl:1535
+#: git-send-email.perl:1579
 msgid "Dry-OK. Log says:\n"
 msgstr "Успех при пробата.  От журнала:\n"
 
-#: git-send-email.perl:1535
+#: git-send-email.perl:1579
 msgid "OK. Log says:\n"
 msgstr "Успех.  От журнала:\n"
 
-#: git-send-email.perl:1547
+#: git-send-email.perl:1591
 msgid "Result: "
 msgstr "Резултат: "
 
-#: git-send-email.perl:1550
+#: git-send-email.perl:1594
 msgid "Result: OK\n"
 msgstr "Резултат: успех\n"
 
-#: git-send-email.perl:1568
+#: git-send-email.perl:1612
 #, perl-format
 msgid "can't open file %s"
 msgstr "файлът „%s“ не може да бъде отворен"
 
-#: git-send-email.perl:1615 git-send-email.perl:1635
+#: git-send-email.perl:1659 git-send-email.perl:1679
 #, perl-format
 msgid "(mbox) Adding cc: %s from line '%s'\n"
 msgstr "(mbox) Добавяне на „як: %s“ от ред „%s“\n"
 
-#: git-send-email.perl:1621
+#: git-send-email.perl:1665
 #, perl-format
 msgid "(mbox) Adding to: %s from line '%s'\n"
 msgstr "(mbox) Добавяне на „до: %s“ от ред „%s“\n"
 
-#: git-send-email.perl:1674
+#: git-send-email.perl:1718
 #, perl-format
 msgid "(non-mbox) Adding cc: %s from line '%s'\n"
 msgstr "(не-mbox) Добавяне на „як: %s“ от ред „%s“\n"
 
-#: git-send-email.perl:1699
+#: git-send-email.perl:1753
 #, perl-format
 msgid "(body) Adding cc: %s from line '%s'\n"
 msgstr "(тяло) Добавяне на „як: %s“ от ред „%s“\n"
 
-#: git-send-email.perl:1817
+#: git-send-email.perl:1864
 #, perl-format
 msgid "(%s) Could not execute '%s'"
 msgstr "(%s) Не може да бъде се изпълни „%s“"
 
-#: git-send-email.perl:1824
+#: git-send-email.perl:1871
 #, perl-format
 msgid "(%s) Adding %s: %s from: '%s'\n"
 msgstr "(%s) Добавяне на „%s: %s“ от: „%s“\n"
 
-#: git-send-email.perl:1828
+#: git-send-email.perl:1875
 #, perl-format
 msgid "(%s) failed to close pipe to '%s'"
 msgstr "(%s) програмният канал не може да се затвори за изпълнението на „%s“"
 
-#: git-send-email.perl:1855
+#: git-send-email.perl:1905
 msgid "cannot send message as 7bit"
 msgstr "съобщението не може да се изпрати чрез 7 битови знаци"
 
-#: git-send-email.perl:1863
+#: git-send-email.perl:1913
 msgid "invalid transfer encoding"
 msgstr "неправилно кодиране за пренос"
 
-#: git-send-email.perl:1901 git-send-email.perl:1952 git-send-email.perl:1962
+#: git-send-email.perl:1954 git-send-email.perl:2006 git-send-email.perl:2016
 #, perl-format
 msgid "unable to open %s: %s\n"
 msgstr "„%s“ не може да се отвори: %s\n"
 
-#: git-send-email.perl:1904
+#: git-send-email.perl:1957
 #, perl-format
 msgid "%s: patch contains a line longer than 998 characters"
 msgstr "„%s“: кръпката съдържа ред с над 988 знака"
 
-#: git-send-email.perl:1920
+#: git-send-email.perl:1974
 #, perl-format
 msgid "Skipping %s with backup suffix '%s'.\n"
 msgstr "„%s“ се пропуска, защото е с разширение за архивен файл: „%s“.\n"
 
 #. TRANSLATORS: please keep "[y|N]" as is.
-#: git-send-email.perl:1924
+#: git-send-email.perl:1978
 #, perl-format
 msgid "Do you really want to send %s? [y|N]: "
 msgstr "Наистина ли искате да изпратите „%s“? [y|N]: "
diff -pruN 1.2.1+git2.18.0-1/git/po/ca.po 1.2.3+git2.25.1-1/git/po/ca.po
--- 1.2.1+git2.18.0-1/git/po/ca.po	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/po/ca.po	2020-02-17 04:47:35.000000000 +0000
@@ -1,7 +1,7 @@
 # Catalan translations for Git.
 # This file is distributed under the same license as the Git package.
 # Alex Henrie <alexhenrie24@gmail.com>, 2014-2016.
-# Jordi Mas i Hernàndez <jmas@softcatala.org>, 2016-2018
+# Jordi Mas i Hernàndez <jmas@softcatala.org>, 2016-2019
 #
 # Terminologia i criteris utilitzats
 #
@@ -9,6 +9,7 @@
 #   -----------------+---------------------------------
 #   ahead            |  davant per
 #   amend            |  esmenar
+#   bundle           |  farcell
 #   broken           |  malmès
 #   delta            |  diferència
 #   deprecated       |  en desús
@@ -23,8 +24,9 @@
 #   squelch          |  silenciar
 #   token            |  testimoni
 #   unset            |  desassignar
+#   upstream         |  font
 #
-# Alguns termes que són comandes específiques del git i d'àmbit molt tècnic
+# Alguns termes que són ordres específiques del git i d'àmbit molt tècnic
 # hem decidit no traduir-los per facilitar-ne la compressió a l'usuari i perquè
 # no tenen una transcendència al gran públic. Es tracta de casos similars
 # a «ping» en l'àmbit de xarxes.
@@ -47,8 +49,8 @@ msgid ""
 msgstr ""
 "Project-Id-Version: Git\n"
 "Report-Msgid-Bugs-To: Git Mailing List <git@vger.kernel.org>\n"
-"POT-Creation-Date: 2018-03-16 07:29+0800\n"
-"PO-Revision-Date: 2018-03-29 15:32+0200\n"
+"POT-Creation-Date: 2019-12-30 08:48+0800\n"
+"PO-Revision-Date: 2020-01-09 10:10+0100\n"
 "Last-Translator: Jordi Mas <jmas@softcatala.org>\n"
 "Language-Team: Catalan\n"
 "Language: ca\n"
@@ -56,39 +58,464 @@ msgstr ""
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
 "Plural-Forms: nplurals=2; plural=(n != 1);\n"
-"X-Generator: Poedit 2.0.4\n"
+"X-Generator: Poedit 2.2.4\n"
 
-#: advice.c:62
+#: add-interactive.c:347
 #, c-format
-msgid "hint: %.*s\n"
-msgstr "pista: %.*s\n"
+msgid "Huh (%s)?"
+msgstr "Perdó (%s)?"
 
-#: advice.c:90
+#: add-interactive.c:500 add-interactive.c:801 sequencer.c:3216
+#: sequencer.c:3656 builtin/rebase.c:871 builtin/rebase.c:1643
+#: builtin/rebase.c:2019 builtin/rebase.c:2063
+msgid "could not read index"
+msgstr "no s'ha pogut llegir l'índex"
+
+#: add-interactive.c:555 git-add--interactive.perl:269
+#: git-add--interactive.perl:294
+msgid "binary"
+msgstr "binari"
+
+#: add-interactive.c:613 git-add--interactive.perl:278
+#: git-add--interactive.perl:332
+msgid "nothing"
+msgstr "res"
+
+#: add-interactive.c:614 git-add--interactive.perl:314
+#: git-add--interactive.perl:329
+msgid "unchanged"
+msgstr "sense canvis"
+
+#: add-interactive.c:651 git-add--interactive.perl:643
+msgid "Update"
+msgstr "Actualitza"
+
+#: add-interactive.c:668 add-interactive.c:856
+#, c-format
+msgid "could not stage '%s'"
+msgstr "no s'ha pogut fer «stage» «%s»"
+
+#: add-interactive.c:674 add-interactive.c:863 sequencer.c:3409
+#: builtin/rebase.c:895
+msgid "could not write index"
+msgstr "no s'ha pogut escriure l'índex"
+
+#: add-interactive.c:677 git-add--interactive.perl:628
+#, c-format, perl-format
+msgid "updated %d path\n"
+msgid_plural "updated %d paths\n"
+msgstr[0] "actualitzat %d camí\n"
+msgstr[1] "actualitzats %d camins\n"
+
+#: add-interactive.c:695 git-add--interactive.perl:678
+#, c-format, perl-format
+msgid "note: %s is untracked now.\n"
+msgstr "nota: %s està ara sense seguiment.\n"
+
+#: add-interactive.c:700 apply.c:4108 builtin/checkout.c:281
+#: builtin/reset.c:144
+#, c-format
+msgid "make_cache_entry failed for path '%s'"
+msgstr "make_cache_entry ha fallat per al camí «%s»"
+
+#: add-interactive.c:730 git-add--interactive.perl:655
+msgid "Revert"
+msgstr "Reverteix"
+
+#: add-interactive.c:746
+msgid "Could not parse HEAD^{tree}"
+msgstr "No s'ha pogut analitzar HEAD^{tree}"
+
+#: add-interactive.c:784 git-add--interactive.perl:631
+#, c-format, perl-format
+msgid "reverted %d path\n"
+msgid_plural "reverted %d paths\n"
+msgstr[0] "revertit %d camí\n"
+msgstr[1] "revertits %d camins\n"
+
+#: add-interactive.c:835 git-add--interactive.perl:695
+#, c-format
+msgid "No untracked files.\n"
+msgstr "Sense fitxers no seguits.\n"
+
+#: add-interactive.c:839 git-add--interactive.perl:689
+msgid "Add untracked"
+msgstr "Afegeix sense seguiment"
+
+#: add-interactive.c:866 git-add--interactive.perl:625
+#, c-format, perl-format
+msgid "added %d path\n"
+msgid_plural "added %d paths\n"
+msgstr[0] "afegit %d camí\n"
+msgstr[1] "afegits %d camins\n"
+
+#: add-interactive.c:896
+#,  c-format
+msgid "ignoring unmerged: %s"
+msgstr "s'està ignorant allò no fusionat: %s"
+
+#: add-interactive.c:908 add-patch.c:1331 git-add--interactive.perl:1366
+#, c-format
+msgid "Only binary files changed.\n"
+msgstr "Només s'han canviat els fitxers binaris.\n"
+
+#: add-interactive.c:910 add-patch.c:1329 git-add--interactive.perl:1368
+#, c-format
+msgid "No changes.\n"
+msgstr "Sense canvis.\n"
+
+#: add-interactive.c:914 git-add--interactive.perl:1376
+msgid "Patch update"
+msgstr "Actualització del pedaç"
+
+#: add-interactive.c:953 git-add--interactive.perl:1754
+msgid "Review diff"
+msgstr "Reviseu les diferències"
+
+#: add-interactive.c:981
+msgid "show paths with changes"
+msgstr "mostra els camins amb canvis"
+
+#: add-interactive.c:983
+msgid "add working tree state to the staged set of changes"
+msgstr ""
+
+#: add-interactive.c:985
+msgid "revert staged set of changes back to the HEAD version"
+msgstr ""
+
+#: add-interactive.c:987
+msgid "pick hunks and update selectively"
+msgstr "selecciona els trossos i actualitza selectivament"
+
+#: add-interactive.c:989
+msgid "view diff between HEAD and index"
+msgstr "visualitza les diferències entre HEAD i l'índex"
+
+#: add-interactive.c:991
+msgid "add contents of untracked files to the staged set of changes"
+msgstr ""
+
+#: add-interactive.c:999 add-interactive.c:1048
+msgid "Prompt help:"
+msgstr "Mostra ajuda:"
+
+#: add-interactive.c:1001
+msgid "select a single item"
+msgstr "seleccioneu un únic ítem"
+
+#: add-interactive.c:1003
+msgid "select a range of items"
+msgstr "seleccioneu un rang d'ítems"
+
+#: add-interactive.c:1005
+msgid "select multiple ranges"
+msgstr "seleccioneu rangs múltiples"
+
+#: add-interactive.c:1007 add-interactive.c:1052
+msgid "select item based on unique prefix"
+msgstr "seleccioneu un ítem basant-se en un prefix únic"
+
+#: add-interactive.c:1009
+msgid "unselect specified items"
+msgstr "desselecciona els ítems especificats"
+
+#: add-interactive.c:1011
+msgid "choose all items"
+msgstr "escolliu tots els ítems"
+
+#: add-interactive.c:1013
+msgid "(empty) finish selecting"
+msgstr "(buit) finalitza la selecció"
+
+#: add-interactive.c:1050
+msgid "select a numbered item"
+msgstr "seleccioneu un ítem numerat"
+
+#: add-interactive.c:1054
+msgid "(empty) select nothing"
+msgstr "(buit) no seleccionis res"
+
+#: add-interactive.c:1062 builtin/clean.c:822 git-add--interactive.perl:1851
+msgid "*** Commands ***"
+msgstr "*** Ordres ***"
+
+#: add-interactive.c:1063 builtin/clean.c:823 git-add--interactive.perl:1848
+msgid "What now"
+msgstr "I ara què"
+
+#: add-interactive.c:1115 git-add--interactive.perl:213
+msgid "staged"
+msgstr "staged"
+
+#: add-interactive.c:1115 git-add--interactive.perl:213
+msgid "unstaged"
+msgstr "unstaged"
+
+#: add-interactive.c:1115 apply.c:4965 apply.c:4968 builtin/am.c:2197
+#: builtin/am.c:2200 builtin/clone.c:123 builtin/fetch.c:144
+#: builtin/merge.c:273 builtin/pull.c:209 builtin/submodule--helper.c:409
+#: builtin/submodule--helper.c:1379 builtin/submodule--helper.c:1382
+#: builtin/submodule--helper.c:1875 builtin/submodule--helper.c:1878
+#: builtin/submodule--helper.c:2119 git-add--interactive.perl:213
+msgid "path"
+msgstr "camí"
+
+#: add-interactive.c:1122
+msgid "could not refresh index"
+msgstr "no s'ha pogut actualitzar l'índex"
+
+#: add-interactive.c:1136 builtin/clean.c:787 git-add--interactive.perl:1765
+#, c-format
+msgid "Bye.\n"
+msgstr "Adéu.\n"
+
+#: add-patch.c:15
+#, c-format
+msgid "Stage mode change [y,n,a,q,d%s,?]? "
+msgstr "Canvia el mode de «stage» [y,n,a,q,d%s,?]? "
+
+#: add-patch.c:16
+#, c-format
+msgid "Stage deletion [y,n,a,q,d%s,?]? "
+msgstr "Suprimeix «stage» [y,n,a,q,d%s,?]? "
+
+#: add-patch.c:17
+#, c-format
+msgid "Stage this hunk [y,n,a,q,d%s,?]? "
+msgstr "Fer un «stage» d'aquest tros [y,n,a,q,d%s,?]? "
+
+#: add-patch.c:111
+#, c-format
+msgid "could not parse hunk header '%.*s'"
+msgstr "no s'ha pogut analitzar la capçalera del tros «%.*s»"
+
+#: add-patch.c:130 add-patch.c:134
+#, c-format
+msgid "could not parse colored hunk header '%.*s'"
+msgstr "no s'ha pogut analitzar la capçalera del tros acolorida «%.*s»"
+
+#: add-patch.c:176
+msgid "could not parse diff"
+msgstr "no s'ha pogut analitzar el diff"
+
+#: add-patch.c:194
+msgid "could not parse colored diff"
+msgstr "no s'ha pogut analitzar el diff acolorit"
+
+#: add-patch.c:508
+#, c-format
+msgid ""
+"expected context line #%d in\n"
+"%.*s"
+msgstr ""
+"s'esperava la línia amb contingut #%d a\n"
+"%.*s"
+
+
+#: add-patch.c:523
+#, c-format
+msgid ""
+"hunks do not overlap:\n"
+"%.*s\n"
+"\tdoes not end with:\n"
+"%.*s"
+msgstr ""
+
+#: add-patch.c:799 git-add--interactive.perl:1112
+msgid "Manual hunk edit mode -- see bottom for a quick guide.\n"
+msgstr ""
+"Mode d'edició de trossos manual - vegeu més avall per una guia ràpida.\n"
+
+#: add-patch.c:803
+#, c-format
+msgid ""
+"---\n"
+"To remove '%c' lines, make them ' ' lines (context).\n"
+"To remove '%c' lines, delete them.\n"
+"Lines starting with %c will be removed.\n"
+msgstr ""
+"---\n"
+"Per suprimir «%c» línies, convertiu-les a ' ' (context).\n"
+"Per suprimir «%c» línies, suprimiu-les.\n"
+"Les línies que comencin per %c seran suprimides.\n"
+
+#: add-patch.c:810
+msgid ""
+"If the patch applies cleanly, the edited hunk will immediately be\n"
+"marked for staging.\n"
+msgstr ""
+"Si el pedaç s'aplica correctament, el tros editat es marcarà immediatament\n"
+"per «staging».\n"
+
+#. TRANSLATORS: 'it' refers to the patch mentioned in the previous messages.
+#: add-patch.c:818 git-add--interactive.perl:1126
+msgid ""
+"If it does not apply cleanly, you will be given an opportunity to\n"
+"edit again.  If all lines of the hunk are removed, then the edit is\n"
+"aborted and the hunk is left unchanged.\n"
+msgstr ""
+"Si no s'aplica correctament, tindreu una oportunitat per editar-lo\n"
+"de nou. Si totes les línies del tros se suprimeixen, llavors l'edició "
+"s'avorta\n"
+"i el tros es deixa sense cap canvi.\n"
+
+#: add-patch.c:851
+msgid "could not parse hunk header"
+msgstr "no s'ha pogut analitzar la capçalera del tros"
+
+#: add-patch.c:895 add-patch.c:1294
+msgid "'git apply --cached' failed"
+msgstr ""
+
+#. TRANSLATORS: do not translate [y/n]
+#. The program will only accept that input at this point.
+#. Consider translating (saying "no" discards!) as
+#. (saying "n" for "no" discards!) if the translation
+#. of the word "no" does not start with n.
+#.
+#. TRANSLATORS: do not translate [y/n]
+#. The program will only accept that input
+#. at this point.
+#. Consider translating (saying "no" discards!) as
+#. (saying "n" for "no" discards!) if the translation
+#. of the word "no" does not start with n.
+#: add-patch.c:952 git-add--interactive.perl:1239
+msgid ""
+"Your edited hunk does not apply. Edit again (saying \"no\" discards!) [y/n]? "
+msgstr ""
+"El tros editat no s'aplica. Editeu-lo de nou (si responeu \"no\" es "
+"descartarà) [y/n]? "
+
+#: add-patch.c:1009
+msgid ""
+"y - stage this hunk\n"
+"n - do not stage this hunk\n"
+"q - quit; do not stage this hunk or any of the remaining ones\n"
+"a - stage this and all the remaining hunks\n"
+"d - do not stage this hunk nor any of the remaining hunks\n"
+msgstr ""
+"y - fes «stage» d'aquest tros\n"
+"n - no facis «stage» d'aquest tros\n"
+"q - surt; no facis «stage» d'aquest tros o de cap altre restant\n"
+"a - fes «stage» d'aquest tros i de tota la resta de trossos del fitxer\n"
+"d - no facis «stage» d'aquest tros o de cap altre restant del fitxer\n"
+
+#: add-patch.c:1016
+msgid ""
+"j - leave this hunk undecided, see next undecided hunk\n"
+"J - leave this hunk undecided, see next hunk\n"
+"k - leave this hunk undecided, see previous undecided hunk\n"
+"K - leave this hunk undecided, see previous hunk\n"
+"g - select a hunk to go to\n"
+"/ - search for a hunk matching the given regex\n"
+"s - split the current hunk into smaller hunks\n"
+"e - manually edit the current hunk\n"
+"? - print help\n"
+msgstr ""
+"j - deixa aquest tros sense decidir, veure el tros sense decidir següent\n"
+"J - deixa aquest tros sense decidir, veure el tros següent\n"
+"k - deixa aquest tros sense decidir, veure el tros sense decidir anterior\n"
+"K - deixa aquest tros sense decidir, veure el tros anterior\n"
+"g - selecciona el tros on voleu anar\n"
+"/ - cerca un tros que coincideixi amb l'expressió regular donada\n"
+"s - divideix el tros actual en trossos més petits\n"
+"e - edita manualment el tros actual\n"
+"? - mostra l'ajuda\n"
+
+#: add-patch.c:1137 add-patch.c:1147
+msgid "No previous hunk"
+msgstr "Sense tros previ"
+
+#: add-patch.c:1142 add-patch.c:1152
+msgid "No next hunk"
+msgstr "No hi ha tros següent"
+
+#: add-patch.c:1158
+msgid "No other hunks to goto"
+msgstr "No hi ha altres trossos on anar-hi"
+
+#: add-patch.c:1169 git-add--interactive.perl:1577
+msgid "go to which hunk (<ret> to see more)? "
+msgstr "vés a quin tros (<ret> per veure'n més)? "
+
+#: add-patch.c:1170 git-add--interactive.perl:1579
+msgid "go to which hunk? "
+msgstr "vés a quin tros? "
+
+#: add-patch.c:1181
+#, c-format
+msgid "Invalid number: '%s'"
+msgstr "Número no vàlid: «%s»"
+
+#: add-patch.c:1186
+#, c-format
+msgid "Sorry, only %d hunk available."
+msgid_plural "Sorry, only %d hunks available."
+msgstr[0] "Només %d tros disponible."
+msgstr[1] "Només %d trossos disponibles."
+
+#: add-patch.c:1195
+msgid "No other hunks to search"
+msgstr "No hi ha cap altre tros a cercar"
+
+#: add-patch.c:1201 git-add--interactive.perl:1623
+msgid "search for regex? "
+msgstr "Cerca per expressió regular? "
+
+#: add-patch.c:1216
+#, c-format
+msgid "Malformed search regexp %s: %s"
+msgstr "Expressió regular de cerca mal formada %s: %s"
+
+#: add-patch.c:1233
+msgid "No hunk matches the given pattern"
+msgstr "No hi ha trossos que coincideixin amb el patró donat"
+
+#: add-patch.c:1240
+msgid "Sorry, cannot split this hunk"
+msgstr "No es pot dividir aquest tros"
+
+#: add-patch.c:1244
+#, c-format
+msgid "Split into %d hunks."
+msgstr "Divideix en %d trossos."
+
+#: add-patch.c:1248
+msgid "Sorry, cannot edit this hunk"
+msgstr "No es pot editar aquest tros"
+
+#: advice.c:111
+#, c-format
+msgid "%shint: %.*s%s\n"
+msgstr "%spista: %.*s%s\n"
+
+#: advice.c:164
 msgid "Cherry-picking is not possible because you have unmerged files."
 msgstr "Fer «cherry pick» no és possible perquè teniu fitxers sense fusionar."
 
-#: advice.c:92
+#: advice.c:166
 msgid "Committing is not possible because you have unmerged files."
 msgstr "Cometre no és possible perquè teniu fitxers sense fusionar."
 
-#: advice.c:94
+#: advice.c:168
 msgid "Merging is not possible because you have unmerged files."
 msgstr "Fusionar no és possible perquè teniu fitxers sense fusionar."
 
-#: advice.c:96
+#: advice.c:170
 msgid "Pulling is not possible because you have unmerged files."
 msgstr "Baixar no és possible perquè teniu fitxers sense fusionar."
 
-#: advice.c:98
+#: advice.c:172
 msgid "Reverting is not possible because you have unmerged files."
 msgstr "Revertir no és possible perquè teniu fitxers sense fusionar."
 
-#: advice.c:100
+#: advice.c:174
 #, c-format
 msgid "It is not possible to %s because you have unmerged files."
 msgstr "No és possible %s perquè teniu fitxers sense fusionar."
 
-#: advice.c:108
+#: advice.c:182
 msgid ""
 "Fix them up in the work tree, and then use 'git add/rm <file>'\n"
 "as appropriate to mark resolution and make a commit."
@@ -97,141 +524,146 @@ msgstr ""
 "'git add/rm <fitxer>' segons sigui apropiat per a marcar la\n"
 "resolució i feu una comissió."
 
-#: advice.c:116
+#: advice.c:190
 msgid "Exiting because of an unresolved conflict."
 msgstr "S'està sortint a causa d'un conflicte no resolt."
 
-#: advice.c:121 builtin/merge.c:1251
+#: advice.c:195 builtin/merge.c:1332
 msgid "You have not concluded your merge (MERGE_HEAD exists)."
 msgstr "No heu conclòs la vostra fusió (MERGE_HEAD existeix)."
 
-#: advice.c:123
+#: advice.c:197
 msgid "Please, commit your changes before merging."
 msgstr "Cometeu els vostres canvis abans de fusionar."
 
-#: advice.c:124
+#: advice.c:198
 msgid "Exiting because of unfinished merge."
 msgstr "S'està sortint a causa d'una fusió no terminada."
 
-#: advice.c:130
-#, c-format
+#: advice.c:204
+#, fuzzy, c-format
 msgid ""
-"Note: checking out '%s'.\n"
+"Note: switching to '%s'.\n"
 "\n"
 "You are in 'detached HEAD' state. You can look around, make experimental\n"
 "changes and commit them, and you can discard any commits you make in this\n"
-"state without impacting any branches by performing another checkout.\n"
+"state without impacting any branches by switching back to a branch.\n"
 "\n"
 "If you want to create a new branch to retain commits you create, you may\n"
-"do so (now or later) by using -b with the checkout command again. Example:\n"
+"do so (now or later) by using -c with the switch command. Example:\n"
+"\n"
+"  git switch -c <new-branch-name>\n"
+"\n"
+"Or undo this operation with:\n"
+"\n"
+"  git switch -\n"
 "\n"
-"  git checkout -b <new-branch-name>\n"
+"Turn off this advice by setting config variable advice.detachedHead to "
+"false\n"
 "\n"
 msgstr ""
-"Avís: s'està agafant «%s».\n"
+"Avís: s'està canviant a «%s».\n"
 "\n"
-"Esteu en un estat de 'HEAD separat'. Podeu mirar al voltant, fer canvis\n"
-"experimentals i cometre-los i podeu descartar qualsevol comissió que feu\n"
-"en aquest estat sense impactar cap branca realitzant un altre agafament.\n"
+"Esteu en un estat de «HEAD separat». Podeu mirar al voltant, fer canvis\n"
+"experimentals i cometre'ls, i podeu descartar qualsevol comissió que feu\n"
+"en aquest estat sense cap branca realitzant un altre agafament.\n"
 "\n"
 "Si voleu crear una branca nova per a conservar les comissions que creeu,\n"
-"poder fer així (ara o més tard) usant -b de nou amb l'ordre checkout.\n"
+"poder fer-ho (ara o més tard) usant -b de nou amb l'ordre checkout.\n"
 "Exemple:\n"
 "\n"
 "  git checkout -b <nom-de-branca-nova>\n"
 
-#: apply.c:58
+#: alias.c:50
+msgid "cmdline ends with \\"
+msgstr "la línia d'ordres acaba amb \\"
+
+#: alias.c:51
+msgid "unclosed quote"
+msgstr ""
+
+#: apply.c:69
 #, c-format
 msgid "unrecognized whitespace option '%s'"
 msgstr "opció d'espai en blanc «%s» no reconeguda"
 
-#: apply.c:74
+#: apply.c:85
 #, c-format
 msgid "unrecognized whitespace ignore option '%s'"
 msgstr "opció ignora l'espai en blanc «%s» no reconeguda"
 
-#: apply.c:122
+#: apply.c:135
 msgid "--reject and --3way cannot be used together."
 msgstr "--reject i --3way no es poden usar junts."
 
-#: apply.c:124
+#: apply.c:137
 msgid "--cached and --3way cannot be used together."
 msgstr "--cached i --3way no es poden usar junts."
 
-#: apply.c:127
+#: apply.c:140
 msgid "--3way outside a repository"
 msgstr "--3way fora d'un dipòsit"
 
-#: apply.c:138
+#: apply.c:151
 msgid "--index outside a repository"
 msgstr "--index fora d'un dipòsit"
 
-#: apply.c:141
+#: apply.c:154
 msgid "--cached outside a repository"
 msgstr "--cached fora d'un dipòsit"
 
-#: apply.c:821
+#: apply.c:801
 #, c-format
 msgid "Cannot prepare timestamp regexp %s"
 msgstr "No es pot preparar l'expressió regular de marca de temps %s"
 
-#: apply.c:830
+#: apply.c:810
 #, c-format
 msgid "regexec returned %d for input: %s"
 msgstr "regexec ha retornat %d per l'entrada: %s"
 
-#: apply.c:904
+#: apply.c:884
 #, c-format
 msgid "unable to find filename in patch at line %d"
 msgstr "no s'ha pogut trobar el nom de fitxer en el pedaç a la línia %d"
 
-#: apply.c:942
+#: apply.c:922
 #, c-format
 msgid "git apply: bad git-diff - expected /dev/null, got %s on line %d"
 msgstr ""
 "git apply: git-diff incorrecte - s'esperava /dev/null, s'ha rebut %s en la "
 "línia %d"
 
-#: apply.c:948
+#: apply.c:928
 #, c-format
 msgid "git apply: bad git-diff - inconsistent new filename on line %d"
 msgstr ""
 "git apply: git-diff incorrecte - nom de fitxer nou inconsistent en la línia "
 "%d"
 
-#: apply.c:949
+#: apply.c:929
 #, c-format
 msgid "git apply: bad git-diff - inconsistent old filename on line %d"
 msgstr ""
 "git apply: git-diff incorrecte - nom de fitxer antic inconsistent en la "
 "línia %d"
 
-#: apply.c:954
+#: apply.c:934
 #, c-format
 msgid "git apply: bad git-diff - expected /dev/null on line %d"
 msgstr "git apply: git-diff incorrecte - s'esperava /dev/null en la línia %d"
 
-#: apply.c:983
+#: apply.c:963
 #, c-format
 msgid "invalid mode on line %d: %s"
 msgstr "mode no vàlid en la línia %d: %s"
 
-#: apply.c:1301
+#: apply.c:1282
 #, c-format
 msgid "inconsistent header lines %d and %d"
 msgstr "línies de capçalera %d i %d inconsistents"
 
-#: apply.c:1473
-#, c-format
-msgid "recount: unexpected line: %.*s"
-msgstr "recompte: línia inesperada: %.*s"
-
-#: apply.c:1542
-#, c-format
-msgid "patch fragment without header at line %d: %.*s"
-msgstr "fragment de pedaç sense capçalera a la línia %d: %.*s"
-
-#: apply.c:1562
+#: apply.c:1372
 #, c-format
 msgid ""
 "git diff header lacks filename information when removing %d leading pathname "
@@ -246,83 +678,93 @@ msgstr[1] ""
 "a la capçalera de git diff li manca informació de nom de fitxer en eliminar "
 "%d components de nom de camí inicial (línia %d)"
 
-#: apply.c:1575
+#: apply.c:1385
 #, c-format
 msgid "git diff header lacks filename information (line %d)"
 msgstr ""
 "a la capçalera de git diff li manca informació de nom de fitxer (línia %d)"
 
-#: apply.c:1763
+#: apply.c:1481
+#, c-format
+msgid "recount: unexpected line: %.*s"
+msgstr "recompte: línia inesperada: %.*s"
+
+#: apply.c:1550
+#, c-format
+msgid "patch fragment without header at line %d: %.*s"
+msgstr "fragment de pedaç sense capçalera a la línia %d: %.*s"
+
+#: apply.c:1753
 msgid "new file depends on old contents"
 msgstr "el fitxer nou depèn dels continguts antics"
 
-#: apply.c:1765
+#: apply.c:1755
 msgid "deleted file still has contents"
 msgstr "el fitxer suprimit encara té continguts"
 
-#: apply.c:1799
+#: apply.c:1789
 #, c-format
 msgid "corrupt patch at line %d"
 msgstr "pedaç malmès a la línia %d"
 
-#: apply.c:1836
+#: apply.c:1826
 #, c-format
 msgid "new file %s depends on old contents"
 msgstr "el fitxer nou %s depèn dels continguts antics"
 
-#: apply.c:1838
+#: apply.c:1828
 #, c-format
 msgid "deleted file %s still has contents"
 msgstr "el fitxer suprimit %s encara té continguts"
 
-#: apply.c:1841
+#: apply.c:1831
 #, c-format
 msgid "** warning: file %s becomes empty but is not deleted"
 msgstr "** advertència: el fitxer %s queda buit però no se suprimeix"
 
-#: apply.c:1988
+#: apply.c:1978
 #, c-format
 msgid "corrupt binary patch at line %d: %.*s"
 msgstr "pedaç binari malmès a la línia %d: %.*s"
 
-#: apply.c:2025
+#: apply.c:2015
 #, c-format
 msgid "unrecognized binary patch at line %d"
 msgstr "pedaç binari no reconegut a la línia %d"
 
-#: apply.c:2185
+#: apply.c:2177
 #, c-format
 msgid "patch with only garbage at line %d"
 msgstr "pedaç amb només escombraries a la línia %d"
 
-#: apply.c:2271
+#: apply.c:2263
 #, c-format
 msgid "unable to read symlink %s"
 msgstr "no s'ha pogut llegir l'enllaç simbòlic %s"
 
-#: apply.c:2275
+#: apply.c:2267
 #, c-format
 msgid "unable to open or read %s"
 msgstr "no s'ha pogut obrir o llegir %s"
 
-#: apply.c:2934
+#: apply.c:2936
 #, c-format
 msgid "invalid start of line: '%c'"
-msgstr "inici de línia no vàlid: '%c'"
+msgstr "inici de línia no vàlid: «%c»"
 
-#: apply.c:3055
+#: apply.c:3057
 #, c-format
 msgid "Hunk #%d succeeded at %d (offset %d line)."
 msgid_plural "Hunk #%d succeeded at %d (offset %d lines)."
 msgstr[0] "El tros #%d ha tingut èxit a %d (desplaçament d'%d línia)."
 msgstr[1] "El tros #%d ha tingut èxit a %d (desplaçament de %d línies)."
 
-#: apply.c:3067
+#: apply.c:3069
 #, c-format
 msgid "Context reduced to (%ld/%ld) to apply fragment at %d"
 msgstr "El context s'ha reduït a (%ld/%ld) per a aplicar el fragment a %d"
 
-#: apply.c:3073
+#: apply.c:3075
 #, c-format
 msgid ""
 "while searching for:\n"
@@ -331,23 +773,23 @@ msgstr ""
 "tot cercant:\n"
 "%.*s"
 
-#: apply.c:3095
+#: apply.c:3097
 #, c-format
 msgid "missing binary patch data for '%s'"
 msgstr "manquen les dades de pedaç binari de «%s»"
 
-#: apply.c:3103
+#: apply.c:3105
 #, c-format
 msgid "cannot reverse-apply a binary patch without the reverse hunk to '%s'"
 msgstr "no es pot aplicar al revés un pedaç binari sense el tros revés a «%s»"
 
-#: apply.c:3149
+#: apply.c:3152
 #, c-format
 msgid "cannot apply binary patch to '%s' without full index line"
 msgstr ""
 "no es pot aplicar un pedaç binari a «%s» sense la línia d'índex completa"
 
-#: apply.c:3159
+#: apply.c:3162
 #, c-format
 msgid ""
 "the patch applies to '%s' (%s), which does not match the current contents."
@@ -355,288 +797,284 @@ msgstr ""
 "el pedaç s'aplica a «%s» (%s), el qual no coincideix amb els continguts "
 "actuals."
 
-#: apply.c:3167
+#: apply.c:3170
 #, c-format
 msgid "the patch applies to an empty '%s' but it is not empty"
 msgstr "el pedaç s'aplica a un «%s» buit però no és buit"
 
-#: apply.c:3185
+#: apply.c:3188
 #, c-format
 msgid "the necessary postimage %s for '%s' cannot be read"
 msgstr "no es pot llegir la postimatge %s necessària per a «%s»"
 
-#: apply.c:3198
+#: apply.c:3201
 #, c-format
 msgid "binary patch does not apply to '%s'"
 msgstr "el pedaç binari no s'aplica a «%s»"
 
-#: apply.c:3204
+#: apply.c:3207
 #, c-format
 msgid "binary patch to '%s' creates incorrect result (expecting %s, got %s)"
 msgstr ""
 "el pedaç binari a «%s» crea un resultat incorrecte (s'esperava %s, s'ha "
 "rebut %s)"
 
-#: apply.c:3225
+#: apply.c:3228
 #, c-format
 msgid "patch failed: %s:%ld"
 msgstr "el pedaç ha fallat: %s:%ld"
 
-#: apply.c:3347
+#: apply.c:3351
 #, c-format
 msgid "cannot checkout %s"
 msgstr "no es pot agafar %s"
 
-#: apply.c:3396 apply.c:3407 apply.c:3453 setup.c:277
+#: apply.c:3403 apply.c:3414 apply.c:3460 midx.c:61 setup.c:280
 #, c-format
 msgid "failed to read %s"
 msgstr "s'ha produït un error en llegir %s"
 
-#: apply.c:3404
+#: apply.c:3411
 #, c-format
 msgid "reading from '%s' beyond a symbolic link"
 msgstr "s'està llegint de «%s» més enllà d'un enllaç simbòlic"
 
-#: apply.c:3433 apply.c:3673
+#: apply.c:3440 apply.c:3683
 #, c-format
 msgid "path %s has been renamed/deleted"
 msgstr "el camí %s s'ha canviat de nom / s'ha suprimit"
 
-#: apply.c:3516 apply.c:3687
+#: apply.c:3526 apply.c:3698
 #, c-format
 msgid "%s: does not exist in index"
 msgstr "%s: no existeix en l'índex"
 
-#: apply.c:3525 apply.c:3695
+#: apply.c:3535 apply.c:3706
 #, c-format
 msgid "%s: does not match index"
 msgstr "%s: no coincideix amb l'índex"
 
-#: apply.c:3560
+#: apply.c:3570
 msgid "repository lacks the necessary blob to fall back on 3-way merge."
 msgstr ""
 "al dipòsit li manca el blob necessari per a retrocedir a una fusió de 3 vies."
 
-#: apply.c:3563
+#: apply.c:3573
 #, c-format
 msgid "Falling back to three-way merge...\n"
 msgstr "S'està retrocedint a una fusió de 3 vies...\n"
 
-#: apply.c:3579 apply.c:3583
+#: apply.c:3589 apply.c:3593
 #, c-format
 msgid "cannot read the current contents of '%s'"
 msgstr "no es poden llegir els continguts actuals de «%s»"
 
-#: apply.c:3595
+#: apply.c:3605
 #, c-format
 msgid "Failed to fall back on three-way merge...\n"
 msgstr "S'ha produït un error en retrocedir a una fusió de 3 vies...\n"
 
-#: apply.c:3609
+#: apply.c:3619
 #, c-format
 msgid "Applied patch to '%s' with conflicts.\n"
 msgstr "S'ha aplicat el pedaç a «%s» amb conflictes.\n"
 
-#: apply.c:3614
+#: apply.c:3624
 #, c-format
 msgid "Applied patch to '%s' cleanly.\n"
 msgstr "S'ha aplicat el pedaç a «%s» netament.\n"
 
-#: apply.c:3640
+#: apply.c:3650
 msgid "removal patch leaves file contents"
 msgstr "el pedaç d'eliminació deixa els continguts dels fitxers"
 
-#: apply.c:3712
+#: apply.c:3723
 #, c-format
 msgid "%s: wrong type"
 msgstr "%s: tipus erroni"
 
-#: apply.c:3714
+#: apply.c:3725
 #, c-format
 msgid "%s has type %o, expected %o"
 msgstr "%s és del tipus %o, s'esperava %o"
 
-#: apply.c:3864 apply.c:3866
+#: apply.c:3876 apply.c:3878 read-cache.c:830 read-cache.c:856
+#: read-cache.c:1320
 #, c-format
 msgid "invalid path '%s'"
 msgstr "camí no vàlid: «%s»"
 
-#: apply.c:3922
+#: apply.c:3934
 #, c-format
 msgid "%s: already exists in index"
 msgstr "%s: ja existeix en l'índex"
 
-#: apply.c:3925
+#: apply.c:3937
 #, c-format
 msgid "%s: already exists in working directory"
 msgstr "%s: ja existeix en el directori de treball"
 
-#: apply.c:3945
+#: apply.c:3957
 #, c-format
 msgid "new mode (%o) of %s does not match old mode (%o)"
 msgstr "el mode nou (%o) de %s no coincideix amb el mode antic (%o)"
 
-#: apply.c:3950
+#: apply.c:3962
 #, c-format
 msgid "new mode (%o) of %s does not match old mode (%o) of %s"
 msgstr "el mode nou (%o) de %s no coincideix amb el mode antic (%o) de %s"
 
-#: apply.c:3970
+#: apply.c:3982
 #, c-format
 msgid "affected file '%s' is beyond a symbolic link"
 msgstr "el fitxer afectat «%s» és més enllà d'un enllaç simbòlic"
 
-#: apply.c:3974
+#: apply.c:3986
 #, c-format
 msgid "%s: patch does not apply"
 msgstr "%s: el pedaç no s'aplica"
 
-#: apply.c:3989
+#: apply.c:4001
 #, c-format
 msgid "Checking patch %s..."
 msgstr "S'està comprovant el pedaç %s..."
 
-#: apply.c:4080
+#: apply.c:4093
 #, c-format
 msgid "sha1 information is lacking or useless for submodule %s"
 msgstr "falta la informació sha1 o és inútil per al submòdul %s"
 
-#: apply.c:4087
+#: apply.c:4100
 #, c-format
 msgid "mode change for %s, which is not in current HEAD"
 msgstr "canvi de mode per a %s, el qual no està en la HEAD actual"
 
-#: apply.c:4090
+#: apply.c:4103
 #, c-format
 msgid "sha1 information is lacking or useless (%s)."
 msgstr "falta informació sha1 o és inútil (%s)."
 
-#: apply.c:4095 builtin/checkout.c:235 builtin/reset.c:140
-#, c-format
-msgid "make_cache_entry failed for path '%s'"
-msgstr "make_cache_entry ha fallat per al camí «%s»"
-
-#: apply.c:4099
+#: apply.c:4112
 #, c-format
 msgid "could not add %s to temporary index"
 msgstr "no s'ha pogut afegir %s a l'índex temporal"
 
-#: apply.c:4109
+#: apply.c:4122
 #, c-format
 msgid "could not write temporary index to %s"
 msgstr "no s'ha pogut escriure l'índex temporal a %s"
 
-#: apply.c:4247
+#: apply.c:4260
 #, c-format
 msgid "unable to remove %s from index"
 msgstr "no s'ha pogut eliminar %s de l'índex"
 
-#: apply.c:4282
+#: apply.c:4294
 #, c-format
 msgid "corrupt patch for submodule %s"
 msgstr "pedaç malmès per al submòdul %s"
 
-#: apply.c:4288
+#: apply.c:4300
 #, c-format
 msgid "unable to stat newly created file '%s'"
 msgstr "no s'ha pogut fer stat al fitxer novament creat «%s»"
 
-#: apply.c:4296
+#: apply.c:4308
 #, c-format
 msgid "unable to create backing store for newly created file %s"
 msgstr ""
 "no s'ha pogut crear un magatzem de recolzament per al fitxer novament creat "
 "%s"
 
-#: apply.c:4302 apply.c:4446
+#: apply.c:4314 apply.c:4459
 #, c-format
 msgid "unable to add cache entry for %s"
 msgstr "no s'ha pogut afegir una entrada de cau per a %s"
 
-#: apply.c:4343
+#: apply.c:4357
 #, c-format
 msgid "failed to write to '%s'"
 msgstr "no s'ha pogut escriure a «%s»"
 
-#: apply.c:4347
+#: apply.c:4361
 #, c-format
 msgid "closing file '%s'"
 msgstr "s'està tancant el fitxer «%s»"
 
-#: apply.c:4417
+#: apply.c:4431
 #, c-format
 msgid "unable to write file '%s' mode %o"
 msgstr "no s'ha pogut escriure el fitxer «%s» mode %o"
 
-#: apply.c:4515
+#: apply.c:4529
 #, c-format
 msgid "Applied patch %s cleanly."
 msgstr "El pedaç %s s'ha aplicat netament."
 
-#: apply.c:4523
+#: apply.c:4537
 msgid "internal error"
 msgstr "error intern"
 
-#: apply.c:4526
+#: apply.c:4540
 #, c-format
 msgid "Applying patch %%s with %d reject..."
 msgid_plural "Applying patch %%s with %d rejects..."
 msgstr[0] "S'està aplicant el pedaç %%s amb %d rebuig..."
 msgstr[1] "S'està aplicant el pedaç %%s amb %d rebutjos..."
 
-#: apply.c:4537
+#: apply.c:4551
 #, c-format
 msgid "truncating .rej filename to %.*s.rej"
 msgstr "s'està truncant el nom del fitxer .rej a %.*s.rej"
 
-#: apply.c:4545 builtin/fetch.c:775 builtin/fetch.c:1025
+#: apply.c:4559 builtin/fetch.c:901 builtin/fetch.c:1192
 #, c-format
 msgid "cannot open %s"
 msgstr "no es pot obrir %s"
 
-#: apply.c:4559
+#: apply.c:4573
 #, c-format
 msgid "Hunk #%d applied cleanly."
 msgstr "El tros #%d s'ha aplicat netament."
 
-#: apply.c:4563
+#: apply.c:4577
 #, c-format
 msgid "Rejected hunk #%d."
 msgstr "S'ha rebutjat el tros #%d."
 
-#: apply.c:4673
+#: apply.c:4696
 #, c-format
 msgid "Skipped patch '%s'."
 msgstr "S'ha omès el pedaç «%s»."
 
-#: apply.c:4681
+#: apply.c:4704
 msgid "unrecognized input"
 msgstr "entrada no reconeguda"
 
-#: apply.c:4700
+#: apply.c:4724
 msgid "unable to read index file"
 msgstr "no es pot llegir el fitxer d'índex"
 
-#: apply.c:4837
+#: apply.c:4881
 #, c-format
 msgid "can't open patch '%s': %s"
 msgstr "no es pot obrir el pedaç «%s»: %s"
 
-#: apply.c:4864
+#: apply.c:4908
 #, c-format
 msgid "squelched %d whitespace error"
 msgid_plural "squelched %d whitespace errors"
 msgstr[0] "s'ha silenciat %d error d'espai en blanc"
 msgstr[1] "s'han silenciat %d errors d'espai en blanc"
 
-#: apply.c:4870 apply.c:4885
+#: apply.c:4914 apply.c:4929
 #, c-format
 msgid "%d line adds whitespace errors."
 msgid_plural "%d lines add whitespace errors."
 msgstr[0] "%d línia afegeix errors d'espai en blanc."
 msgstr[1] "%d línies afegeixen errors d'espai en blanc."
 
-#: apply.c:4878
+#: apply.c:4922
 #, c-format
 msgid "%d line applied after fixing whitespace errors."
 msgid_plural "%d lines applied after fixing whitespace errors."
@@ -645,264 +1083,334 @@ msgstr[0] ""
 msgstr[1] ""
 "S'han aplicat %d línies després d'arreglar els errors d'espai en blanc."
 
-#: apply.c:4894 builtin/add.c:539 builtin/mv.c:298 builtin/rm.c:390
+#: apply.c:4938 builtin/add.c:579 builtin/mv.c:301 builtin/rm.c:390
 msgid "Unable to write new index file"
 msgstr "No s'ha pogut escriure un fitxer d'índex nou"
 
-#: apply.c:4921 apply.c:4924 builtin/am.c:2254 builtin/am.c:2257
-#: builtin/clone.c:118 builtin/fetch.c:127 builtin/pull.c:193
-#: builtin/submodule--helper.c:403 builtin/submodule--helper.c:1197
-#: builtin/submodule--helper.c:1200 builtin/submodule--helper.c:1567
-#: builtin/submodule--helper.c:1570 builtin/submodule--helper.c:1787
-#: git-add--interactive.perl:197
-msgid "path"
-msgstr "camí"
-
-#: apply.c:4922
+#: apply.c:4966
 msgid "don't apply changes matching the given path"
 msgstr "no apliquis els canvis que coincideixin amb el camí donat"
 
-#: apply.c:4925
+#: apply.c:4969
 msgid "apply changes matching the given path"
 msgstr "aplica els canvis que coincideixin amb el camí donat"
 
-#: apply.c:4927 builtin/am.c:2263
+#: apply.c:4971 builtin/am.c:2206
 msgid "num"
 msgstr "número"
 
-#: apply.c:4928
+#: apply.c:4972
 msgid "remove <num> leading slashes from traditional diff paths"
 msgstr ""
 "elimina <nombre> barres obliqües inicials dels camins de diferència "
 "tradicionals"
 
-#: apply.c:4931
+#: apply.c:4975
 msgid "ignore additions made by the patch"
 msgstr "ignora afegiments fets pel pedaç"
 
-#: apply.c:4933
+#: apply.c:4977
 msgid "instead of applying the patch, output diffstat for the input"
 msgstr ""
 "en lloc d'aplicar el pedaç, emet les estadístiques de diferència de l'entrada"
 
-#: apply.c:4937
+#: apply.c:4981
 msgid "show number of added and deleted lines in decimal notation"
 msgstr "mostra el nombre de línies afegides i suprimides en notació decimal"
 
-#: apply.c:4939
+#: apply.c:4983
 msgid "instead of applying the patch, output a summary for the input"
 msgstr "en lloc d'aplicar el pedaç, emet un resum de l'entrada"
 
-#: apply.c:4941
+#: apply.c:4985
 msgid "instead of applying the patch, see if the patch is applicable"
 msgstr "en lloc d'aplicar el pedaç, veges si el pedaç és aplicable"
 
-#: apply.c:4943
+#: apply.c:4987
 msgid "make sure the patch is applicable to the current index"
 msgstr "assegura que el pedaç sigui aplicable a l'índex actual"
 
-#: apply.c:4945
+#: apply.c:4989
+msgid "mark new files with `git add --intent-to-add`"
+msgstr ""
+
+#: apply.c:4991
 msgid "apply a patch without touching the working tree"
 msgstr "aplica un pedaç sense tocar l'arbre de treball"
 
-#: apply.c:4947
+#: apply.c:4993
 msgid "accept a patch that touches outside the working area"
 msgstr "accepta un pedaç que toqui fora de l'àrea de treball"
 
-#: apply.c:4950
+#: apply.c:4996
 msgid "also apply the patch (use with --stat/--summary/--check)"
 msgstr "aplica el pedaç també (useu amb --stat/--summary/--check)"
 
-#: apply.c:4952
+#: apply.c:4998
 msgid "attempt three-way merge if a patch does not apply"
 msgstr "intenta una fusió de tres vies si el pedaç no s'aplica"
 
-#: apply.c:4954
+#: apply.c:5000
 msgid "build a temporary index based on embedded index information"
 msgstr "construeix un índex temporal basat en la informació d'índex incrustada"
 
-#: apply.c:4957 builtin/checkout-index.c:168 builtin/ls-files.c:515
+#: apply.c:5003 builtin/checkout-index.c:173 builtin/ls-files.c:524
 msgid "paths are separated with NUL character"
 msgstr "els camins se separen amb el caràcter NUL"
 
-#: apply.c:4959
+#: apply.c:5005
 msgid "ensure at least <n> lines of context match"
 msgstr "assegura't que almenys <n> línies de context coincideixin"
 
-#: apply.c:4960 builtin/am.c:2242 builtin/interpret-trailers.c:95
-#: builtin/interpret-trailers.c:97 builtin/interpret-trailers.c:99
-#: builtin/pack-objects.c:3035
+#: apply.c:5006 builtin/am.c:2185 builtin/interpret-trailers.c:98
+#: builtin/interpret-trailers.c:100 builtin/interpret-trailers.c:102
+#: builtin/pack-objects.c:3310 builtin/rebase.c:1474
 msgid "action"
 msgstr "acció"
 
-#: apply.c:4961
+#: apply.c:5007
 msgid "detect new or modified lines that have whitespace errors"
 msgstr ""
 "detecta les línies noves o modificades que tinguin errors d'espai en blanc"
 
-#: apply.c:4964 apply.c:4967
+#: apply.c:5010 apply.c:5013
 msgid "ignore changes in whitespace when finding context"
 msgstr "ignora els canvis d'espai en blanc en cercar context"
 
-#: apply.c:4970
+#: apply.c:5016
 msgid "apply the patch in reverse"
 msgstr "aplica el pedaç al revés"
 
-#: apply.c:4972
+#: apply.c:5018
 msgid "don't expect at least one line of context"
 msgstr "no esperis almenys una línia de context"
 
-#: apply.c:4974
+#: apply.c:5020
 msgid "leave the rejected hunks in corresponding *.rej files"
 msgstr "deixa els trossos rebutjats en fitxers *.rej corresponents"
 
-#: apply.c:4976
+#: apply.c:5022
 msgid "allow overlapping hunks"
 msgstr "permet trossos encavalcants"
 
-#: apply.c:4977 builtin/add.c:292 builtin/check-ignore.c:21
-#: builtin/commit.c:1276 builtin/count-objects.c:96 builtin/fsck.c:665
-#: builtin/log.c:1901 builtin/mv.c:123 builtin/read-tree.c:125
+#: apply.c:5023 builtin/add.c:309 builtin/check-ignore.c:22
+#: builtin/commit.c:1355 builtin/count-objects.c:98 builtin/fsck.c:774
+#: builtin/log.c:2166 builtin/mv.c:123 builtin/read-tree.c:128
 msgid "be verbose"
 msgstr "sigues detallat"
 
-#: apply.c:4979
+#: apply.c:5025
 msgid "tolerate incorrectly detected missing new-line at the end of file"
 msgstr "tolera una línia nova incorrectament detectada al final del fitxer"
 
-#: apply.c:4982
+#: apply.c:5028
 msgid "do not trust the line counts in the hunk headers"
 msgstr "no confiïs en els recomptes de línia en les capçaleres dels trossos"
 
-#: apply.c:4984 builtin/am.c:2251
+#: apply.c:5030 builtin/am.c:2194
 msgid "root"
 msgstr "arrel"
 
-#: apply.c:4985
+#: apply.c:5031
 msgid "prepend <root> to all filenames"
 msgstr "anteposa <arrel> a tots els noms de fitxer"
 
-#: archive.c:13
+#: archive.c:14
 msgid "git archive [<options>] <tree-ish> [<path>...]"
 msgstr "git archive [<opcions>] <arbre> [<camí>...]"
 
-#: archive.c:14
+#: archive.c:15
 msgid "git archive --list"
 msgstr "git archive --list"
 
-#: archive.c:15
+#: archive.c:16
 msgid ""
 "git archive --remote <repo> [--exec <cmd>] [<options>] <tree-ish> [<path>...]"
 msgstr ""
 "git archive --remote <dipòsit> [--exec <ordre>] [<opcions>] <arbre> "
 "[<camí>...]"
 
-#: archive.c:16
+#: archive.c:17
 msgid "git archive --remote <repo> [--exec <cmd>] --list"
 msgstr "git archive --remote <dipòsit> [--exec <ordre>] --list"
 
-#: archive.c:351 builtin/add.c:176 builtin/add.c:515 builtin/rm.c:299
+#: archive.c:372 builtin/add.c:180 builtin/add.c:555 builtin/rm.c:299
 #, c-format
 msgid "pathspec '%s' did not match any files"
 msgstr "l'especificació de camí «%s» no ha coincidit amb cap fitxer"
 
-#: archive.c:436
+#: archive.c:396
+#, c-format
+msgid "no such ref: %.*s"
+msgstr "no existeix la referència: %.*s"
+
+#: archive.c:401
+#, c-format
+msgid "not a valid object name: %s"
+msgstr "no és un nom d'objecte vàlid: %s"
+
+#: archive.c:414
+#, c-format
+msgid "not a tree object: %s"
+msgstr "no és un objecte d'arbre: %s"
+
+#: archive.c:426
+msgid "current working directory is untracked"
+msgstr "no es segueix el directori de treball actual"
+
+#: archive.c:457
 msgid "fmt"
 msgstr "format"
 
-#: archive.c:436
+#: archive.c:457
 msgid "archive format"
 msgstr "format d'arxiu"
 
-#: archive.c:437 builtin/log.c:1462
+#: archive.c:458 builtin/log.c:1653
 msgid "prefix"
 msgstr "prefix"
 
-#: archive.c:438
+#: archive.c:459
 msgid "prepend prefix to each pathname in the archive"
 msgstr "anteposa el prefix a cada nom de camí en l'arxiu"
 
-#: archive.c:439 builtin/blame.c:702 builtin/blame.c:703 builtin/config.c:62
-#: builtin/fast-export.c:1005 builtin/fast-export.c:1007 builtin/grep.c:869
-#: builtin/hash-object.c:103 builtin/ls-files.c:551 builtin/ls-files.c:554
-#: builtin/notes.c:405 builtin/notes.c:568 builtin/read-tree.c:120
-#: parse-options.h:165
+#: archive.c:460 builtin/blame.c:861 builtin/blame.c:865 builtin/blame.c:866
+#: builtin/commit-tree.c:117 builtin/config.c:129 builtin/fast-export.c:1162
+#: builtin/fast-export.c:1164 builtin/fast-export.c:1168 builtin/grep.c:899
+#: builtin/hash-object.c:105 builtin/ls-files.c:560 builtin/ls-files.c:563
+#: builtin/notes.c:412 builtin/notes.c:578 builtin/read-tree.c:123
+#: parse-options.h:190
 msgid "file"
 msgstr "fitxer"
 
-#: archive.c:440 builtin/archive.c:89
+#: archive.c:461 builtin/archive.c:90
 msgid "write the archive to this file"
 msgstr "escriu l'arxiu a aquest fitxer"
 
-#: archive.c:442
+#: archive.c:463
 msgid "read .gitattributes in working directory"
 msgstr "llegeix .gitattributes en el directori de treball"
 
-#: archive.c:443
+#: archive.c:464
 msgid "report archived files on stderr"
 msgstr "informa de fitxers arxivats en stderr"
 
-#: archive.c:444
+#: archive.c:465
 msgid "store only"
 msgstr "només emmagatzema"
 
-#: archive.c:445
+#: archive.c:466
 msgid "compress faster"
 msgstr "comprimeix més ràpidament"
 
-#: archive.c:453
+#: archive.c:474
 msgid "compress better"
 msgstr "comprimeix millor"
 
-#: archive.c:456
+#: archive.c:477
 msgid "list supported archive formats"
 msgstr "llista els formats d'arxiu admesos"
 
-#: archive.c:458 builtin/archive.c:90 builtin/clone.c:108 builtin/clone.c:111
-#: builtin/submodule--helper.c:1209 builtin/submodule--helper.c:1576
+#: archive.c:479 builtin/archive.c:91 builtin/clone.c:113 builtin/clone.c:116
+#: builtin/submodule--helper.c:1391 builtin/submodule--helper.c:1884
 msgid "repo"
 msgstr "dipòsit"
 
-#: archive.c:459 builtin/archive.c:91
+#: archive.c:480 builtin/archive.c:92
 msgid "retrieve the archive from remote repository <repo>"
 msgstr "recupera l'arxiu del dipòsit remot <dipòsit>"
 
-#: archive.c:460 builtin/archive.c:92 builtin/notes.c:489
+#: archive.c:481 builtin/archive.c:93 builtin/difftool.c:715
+#: builtin/notes.c:498
 msgid "command"
 msgstr "ordre"
 
-#: archive.c:461 builtin/archive.c:93
+#: archive.c:482 builtin/archive.c:94
 msgid "path to the remote git-upload-archive command"
 msgstr "camí a l'ordre git-upload-archive remota"
 
-#: archive.c:468
+#: archive.c:489
 msgid "Unexpected option --remote"
 msgstr "Opció inesperada --remote"
 
-#: archive.c:470
+#: archive.c:491
 msgid "Option --exec can only be used together with --remote"
 msgstr "L'opció --exec només es pot usar juntament amb --remote"
 
-#: archive.c:472
+#: archive.c:493
 msgid "Unexpected option --output"
 msgstr "Opció inesperada --output"
 
-#: archive.c:494
+#: archive.c:515
 #, c-format
 msgid "Unknown archive format '%s'"
 msgstr "Format d'arxiu desconegut «%s»"
 
-#: archive.c:501
+#: archive.c:522
 #, c-format
 msgid "Argument not supported for format '%s': -%d"
 msgstr "Paràmetre no admès per al format «%s»: -%d"
 
-#: attr.c:218
+#: archive-tar.c:125 archive-zip.c:350
+#, c-format
+msgid "cannot stream blob %s"
+msgstr "no es pot transmetre el blob %s"
+
+#: archive-tar.c:266 archive-zip.c:368
+#, c-format
+msgid "unsupported file mode: 0%o (SHA1: %s)"
+msgstr "mode de fitxer no compatible: 0%o (SHA1: %s)"
+
+#: archive-tar.c:293 archive-zip.c:358
+#, c-format
+msgid "cannot read %s"
+msgstr "no es pot llegir «%s»"
+
+#: archive-tar.c:465
+#, c-format
+msgid "unable to start '%s' filter"
+msgstr "no s'ha pogut iniciar el filtre «%s»"
+
+#: archive-tar.c:468
+msgid "unable to redirect descriptor"
+msgstr "no s'ha pogut redirigir el descriptor"
+
+#: archive-tar.c:475
+#, c-format
+msgid "'%s' filter reported error"
+msgstr "«%s» error reportat pel filtre"
+
+#: archive-zip.c:319
+#, c-format
+msgid "path is not valid UTF-8: %s"
+msgstr "el camí no és vàlid en UTF-8: %s"
+
+#: archive-zip.c:323
+#, c-format
+msgid "path too long (%d chars, SHA1: %s): %s"
+msgstr "el camí és massa llarg (%d caràcters, SHA1: %s): %s"
+
+#: archive-zip.c:479 builtin/pack-objects.c:230 builtin/pack-objects.c:233
+#, c-format
+msgid "deflate error (%d)"
+msgstr "error de deflació (%d)"
+
+#: archive-zip.c:614
+#, c-format
+msgid "timestamp too large for this system: %<PRIuMAX>"
+msgstr "marca de temps massa gran per a aquest sistema: %<PRIuMAX>"
+
+#: attr.c:212
 #, c-format
 msgid "%.*s is not a valid attribute name"
 msgstr "%.*s no és un nom d'atribut vàlid"
 
-#: attr.c:415
+#: attr.c:369
+#, c-format
+msgid "%s not allowed: %s:%d"
+msgstr "%s no està permès: %s:%d"
+
+#: attr.c:409
 msgid ""
 "Negative patterns are ignored in git attributes\n"
 "Use '\\!' for literal leading exclamation."
@@ -910,22 +1418,22 @@ msgstr ""
 "Els patrons negatius s'ignoren en els atributs de git\n"
 "Useu '\\!' per exclamació capdavantera literal."
 
-#: bisect.c:460
+#: bisect.c:468
 #, c-format
 msgid "Badly quoted content in file '%s': %s"
 msgstr "Comentari amb cometes errònies en el fitxer «%s»: %s"
 
-#: bisect.c:668
+#: bisect.c:678
 #, c-format
 msgid "We cannot bisect more!\n"
 msgstr "No podem bisecar més!\n"
 
-#: bisect.c:722
+#: bisect.c:733
 #, c-format
 msgid "Not a valid commit name %s"
 msgstr "No és un nom de comissió vàlid %s"
 
-#: bisect.c:746
+#: bisect.c:758
 #, c-format
 msgid ""
 "The merge base %s is bad.\n"
@@ -934,7 +1442,7 @@ msgstr ""
 "La base de fusió %s és errònia.\n"
 "Això vol dir que el defecte s'ha arreglat entre %s i [%s].\n"
 
-#: bisect.c:751
+#: bisect.c:763
 #, c-format
 msgid ""
 "The merge base %s is new.\n"
@@ -943,7 +1451,7 @@ msgstr ""
 "La base de fusió %s és nova.\n"
 "La propietat s'ha canviat entre %s i [%s].\n"
 
-#: bisect.c:756
+#: bisect.c:768
 #, c-format
 msgid ""
 "The merge base %s is %s.\n"
@@ -952,7 +1460,7 @@ msgstr ""
 "La base de fusió %s és %s.\n"
 "Això vol dir que la primera comissió «%s» és entre %s i [%s].\n"
 
-#: bisect.c:764
+#: bisect.c:776
 #, c-format
 msgid ""
 "Some %s revs are not ancestors of the %s rev.\n"
@@ -963,7 +1471,7 @@ msgstr ""
 "git bisect no pot funcionar correctament en aquest cas.\n"
 "Potser heu confós les revisions %s i %s?\n"
 
-#: bisect.c:777
+#: bisect.c:789
 #, c-format
 msgid ""
 "the merge base between %s and [%s] must be skipped.\n"
@@ -975,36 +1483,36 @@ msgstr ""
 "%s.\n"
 "Continuem de totes maneres."
 
-#: bisect.c:810
+#: bisect.c:822
 #, c-format
 msgid "Bisecting: a merge base must be tested\n"
 msgstr "Bisecant: s'ha de provar una base de fusió\n"
 
-#: bisect.c:850
+#: bisect.c:865
 #, c-format
 msgid "a %s revision is needed"
 msgstr "es necessita una revisió %s"
 
-#: bisect.c:869 builtin/notes.c:175 builtin/tag.c:235
+#: bisect.c:884 builtin/notes.c:177 builtin/tag.c:254
 #, c-format
 msgid "could not create file '%s'"
 msgstr "no s'ha pogut crear el fitxer «%s»"
 
-#: bisect.c:920
+#: bisect.c:928 builtin/merge.c:148
 #, c-format
 msgid "could not read file '%s'"
 msgstr "no s'ha pogut llegir el fitxer «%s»"
 
-#: bisect.c:950
+#: bisect.c:958
 msgid "reading bisect refs failed"
 msgstr "la lectura de les referències de bisecció ha fallat"
 
-#: bisect.c:969
+#: bisect.c:977
 #, c-format
 msgid "%s was both %s and %s\n"
 msgstr "%s era ambdós %s i %s\n"
 
-#: bisect.c:977
+#: bisect.c:985
 #, c-format
 msgid ""
 "No testable commit found.\n"
@@ -1013,7 +1521,7 @@ msgstr ""
 "No s'ha trobat cap comissió comprovable.\n"
 "Potser heu començat amb paràmetres de camí incorrectes?\n"
 
-#: bisect.c:996
+#: bisect.c:1004
 #, c-format
 msgid "(roughly %d step)"
 msgid_plural "(roughly %d steps)"
@@ -1023,47 +1531,48 @@ msgstr[1] "(aproximadament %d passos)"
 #. TRANSLATORS: the last %s will be replaced with "(roughly %d
 #. steps)" translation.
 #.
-#: bisect.c:1002
+#: bisect.c:1010
 #, c-format
 msgid "Bisecting: %d revision left to test after this %s\n"
 msgid_plural "Bisecting: %d revisions left to test after this %s\n"
 msgstr[0] "Bisecant: manca %d revisió a provar després d'aquesta %s\n"
 msgstr[1] "Bisecant: manquen %d revisions a provar després d'aquesta %s\n"
 
-#: blame.c:1758
+#: blame.c:2700
 msgid "--contents and --reverse do not blend well."
 msgstr "--contents i --reverse no funcionen bé juntes."
 
-#: blame.c:1769
+#: blame.c:2714
 msgid "cannot use --contents with final commit object name"
 msgstr "no es pot usar --contents amb el nom d'objecte de la comissió final"
 
-#: blame.c:1789
+#: blame.c:2735
 msgid "--reverse and --first-parent together require specified latest commit"
 msgstr ""
 "--reverse i --first-parent-together requereixen una última comissió "
 "especificada"
 
-#: blame.c:1798 bundle.c:160 ref-filter.c:1978 sequencer.c:1699
-#: sequencer.c:2901 builtin/commit.c:976 builtin/log.c:366 builtin/log.c:920
-#: builtin/log.c:1371 builtin/log.c:1702 builtin/log.c:1950 builtin/merge.c:370
-#: builtin/shortlog.c:191
+#: blame.c:2744 bundle.c:167 ref-filter.c:2203 remote.c:1941 sequencer.c:2093
+#: sequencer.c:4460 builtin/commit.c:1040 builtin/log.c:388 builtin/log.c:991
+#: builtin/log.c:1520 builtin/log.c:1925 builtin/log.c:2215 builtin/merge.c:411
+#: builtin/pack-objects.c:3128 builtin/pack-objects.c:3143
+#: builtin/shortlog.c:192
 msgid "revision walk setup failed"
 msgstr "la configuració del passeig per revisions ha fallat"
 
-#: blame.c:1816
+#: blame.c:2762
 msgid ""
 "--reverse --first-parent together require range along first-parent chain"
 msgstr ""
 "--reverse --first-parent junts requereixen un rang de la cadena de mares "
 "primeres"
 
-#: blame.c:1827
+#: blame.c:2773
 #, c-format
 msgid "no such path %s in %s"
 msgstr "no hi ha tal camí %s en %s"
 
-#: blame.c:1838
+#: blame.c:2784
 #, c-format
 msgid "cannot read blob %s for path %s"
 msgstr "no es pot llegir el blob %s per al camí %s"
@@ -1192,100 +1701,109 @@ msgstr ""
 "«git push -u» per a establir la configuració font\n"
 "mentre pugeu."
 
-#: branch.c:280
+#: branch.c:281
 #, c-format
 msgid "Not a valid object name: '%s'."
 msgstr "No és un nom d'objecte vàlid: «%s»."
 
-#: branch.c:300
+#: branch.c:301
 #, c-format
 msgid "Ambiguous object name: '%s'."
 msgstr "Nom d'objecte ambigu: «%s»."
 
-#: branch.c:305
+#: branch.c:306
 #, c-format
 msgid "Not a valid branch point: '%s'."
 msgstr "No és un punt de ramificació vàlid: «%s»."
 
-#: branch.c:359
+#: branch.c:364
 #, c-format
 msgid "'%s' is already checked out at '%s'"
 msgstr "«%s» ja s'ha agafat a «%s»"
 
-#: branch.c:382
+#: branch.c:387
 #, c-format
 msgid "HEAD of working tree %s is not updated"
 msgstr "HEAD de l'arbre de treball %s no està actualitzat"
 
-#: bundle.c:34
+#: bundle.c:36
 #, c-format
 msgid "'%s' does not look like a v2 bundle file"
 msgstr "«%s» no sembla un fitxer de farcell v2"
 
-#: bundle.c:62
+#: bundle.c:64
 #, c-format
 msgid "unrecognized header: %s%s (%d)"
 msgstr "capçalera no reconeguda: %s%s (%d)"
 
-#: bundle.c:88 sequencer.c:1879 sequencer.c:2337 builtin/commit.c:750
+#: bundle.c:90 rerere.c:480 rerere.c:690 sequencer.c:2344 sequencer.c:3108
+#: builtin/commit.c:811
 #, c-format
 msgid "could not open '%s'"
 msgstr "no s'ha pogut obrir «%s»"
 
-#: bundle.c:139
+#: bundle.c:143
 msgid "Repository lacks these prerequisite commits:"
-msgstr "Al dipòsit li manquen aquestes comissions prerequisits:"
+msgstr "Al dipòsit li manquen aquestes comissions prerequerides:"
+
+#: bundle.c:146
+msgid "need a repository to verify a bundle"
+msgstr "cal un dipòsit per verificar un farcell"
 
-#: bundle.c:190
+#: bundle.c:197
 #, c-format
 msgid "The bundle contains this ref:"
 msgid_plural "The bundle contains these %d refs:"
 msgstr[0] "El farcell conté aquesta referència:"
 msgstr[1] "El farcell conté aquestes %d referències:"
 
-#: bundle.c:197
+#: bundle.c:204
 msgid "The bundle records a complete history."
 msgstr "El farcell registra una història completa."
 
-#: bundle.c:199
+#: bundle.c:206
 #, c-format
 msgid "The bundle requires this ref:"
 msgid_plural "The bundle requires these %d refs:"
 msgstr[0] "El farcell requereix aquesta referència:"
 msgstr[1] "El farcell requereix aquestes %d referències:"
 
-#: bundle.c:258
+#: bundle.c:273
+msgid "unable to dup bundle descriptor"
+msgstr "no s'ha pogut duplicar el descriptor del farcell"
+
+#: bundle.c:280
 msgid "Could not spawn pack-objects"
 msgstr "No s'ha pogut executar el pack-objects"
 
-#: bundle.c:269
+#: bundle.c:291
 msgid "pack-objects died"
 msgstr "El pack-objects s'ha mort"
 
-#: bundle.c:311
+#: bundle.c:333
 msgid "rev-list died"
 msgstr "El rev-list s'ha mort"
 
-#: bundle.c:360
+#: bundle.c:382
 #, c-format
 msgid "ref '%s' is excluded by the rev-list options"
 msgstr "les opcions de la llista de revisions exclouen la referència «%s»"
 
-#: bundle.c:450 builtin/log.c:183 builtin/log.c:1607 builtin/shortlog.c:296
+#: bundle.c:461 builtin/log.c:203 builtin/log.c:1814 builtin/shortlog.c:306
 #, c-format
 msgid "unrecognized argument: %s"
 msgstr "paràmetre no reconegut: %s"
 
-#: bundle.c:458
+#: bundle.c:469
 msgid "Refusing to create empty bundle."
 msgstr "S'està refusant crear un farcell buit."
 
-#: bundle.c:470
+#: bundle.c:479
 #, c-format
 msgid "cannot create '%s'"
 msgstr "no es pot crear «%s»"
 
-#: bundle.c:498
+#: bundle.c:504
 msgid "index-pack died"
 msgstr "L'index-pack s'ha mort"
 
@@ -1294,18 +1812,50 @@ msgstr "L'index-pack s'ha mort"
 msgid "invalid color value: %.*s"
 msgstr "valor de color no vàlid: %.*s"
 
-#: commit.c:41 sequencer.c:2141 builtin/am.c:421 builtin/am.c:465
-#: builtin/am.c:1436 builtin/am.c:2072
+#: commit.c:51 sequencer.c:2811 builtin/am.c:354 builtin/am.c:398
+#: builtin/am.c:1366 builtin/am.c:2009 builtin/replace.c:456
 #, c-format
 msgid "could not parse %s"
 msgstr "no s'ha pogut analitzar %s"
 
-#: commit.c:43
+#: commit.c:53
 #, c-format
 msgid "%s %s is not a commit!"
 msgstr "%s %s no és una comissió!"
 
-#: commit.c:1506
+#: commit.c:193
+msgid ""
+"Support for <GIT_DIR>/info/grafts is deprecated\n"
+"and will be removed in a future Git version.\n"
+"\n"
+"Please use \"git replace --convert-graft-file\"\n"
+"to convert the grafts into replace refs.\n"
+"\n"
+"Turn this message off by running\n"
+"\"git config advice.graftFileDeprecated false\""
+msgstr ""
+
+#: commit.c:1152
+#, c-format
+msgid "Commit %s has an untrusted GPG signature, allegedly by %s."
+msgstr "La comissió %s té una signatura GPG no fiable, suposadament de %s."
+
+#: commit.c:1155
+#, c-format
+msgid "Commit %s has a bad GPG signature allegedly by %s."
+msgstr "La comissió %s té una signatura GPG incorrecta suposadament de %s."
+
+#: commit.c:1158
+#, c-format
+msgid "Commit %s does not have a GPG signature."
+msgstr "La comissió %s no té signatura GPG."
+
+#: commit.c:1161
+#, c-format
+msgid "Commit %s has a good GPG signature by %s\n"
+msgstr "La comissió %s té una signatura GPG bona de %s\n"
+
+#: commit.c:1415
 msgid ""
 "Warning: commit message did not conform to UTF-8.\n"
 "You may want to amend it after fixing the message, or set the config\n"
@@ -1316,178 +1866,582 @@ msgstr ""
 "la variable de configuració i18n.commitencoding a la codificació que\n"
 "usi el vostre projecte.\n"
 
-#: compat/obstack.c:405 compat/obstack.c:407
+#: commit-graph.c:130
+msgid "commit-graph file is too small"
+msgstr ""
+
+#: commit-graph.c:195
+#, c-format
+msgid "commit-graph signature %X does not match signature %X"
+msgstr ""
+"la signatura del graf de comissions %X no coincideix amb la signatura %X"
+
+#: commit-graph.c:202
+#, c-format
+msgid "commit-graph version %X does not match version %X"
+msgstr "la versió del graf de comissions %X no coincideix amb la versió %X"
+
+#: commit-graph.c:209
+#, c-format
+msgid "commit-graph hash version %X does not match version %X"
+msgstr ""
+"la versió del hash del graf de comissions %X no coincideix amb la versió %X"
+
+#: commit-graph.c:232
+msgid "commit-graph chunk lookup table entry missing; file may be incomplete"
+msgstr ""
+
+#: commit-graph.c:243
+#, c-format
+msgid "commit-graph improper chunk offset %08x%08x"
+msgstr ""
+
+#: commit-graph.c:286
+#, c-format
+msgid "commit-graph chunk id %08x appears multiple times"
+msgstr ""
+
+#: commit-graph.c:350
+msgid "commit-graph has no base graphs chunk"
+msgstr ""
+
+#: commit-graph.c:360
+msgid "commit-graph chain does not match"
+msgstr "la cadena del graf de comissions no coincideix"
+
+#: commit-graph.c:407
+#, c-format
+msgid "invalid commit-graph chain: line '%s' not a hash"
+msgstr ""
+
+#: commit-graph.c:433
+msgid "unable to find all commit-graph files"
+msgstr "no es poden trobar tots els fitxers del graf de comissions"
+
+#: commit-graph.c:564 commit-graph.c:624
+msgid "invalid commit position. commit-graph is likely corrupt"
+msgstr ""
+"posició de la comissió no vàlida. Probablement el graf de comissions està "
+"malmès"
+
+#: commit-graph.c:585
+#, c-format
+msgid "could not find commit %s"
+msgstr "no s'ha pogut trobar la comissió %s"
+
+#: commit-graph.c:858 builtin/am.c:1287
+#, c-format
+msgid "unable to parse commit %s"
+msgstr "no s'ha pogut analitzar la comissió %s"
+
+#: commit-graph.c:1017 builtin/pack-objects.c:2641
+#, c-format
+msgid "unable to get type of object %s"
+msgstr "no s'ha pogut obtenir el tipus de l'objecte: %s"
+
+#: commit-graph.c:1049
+msgid "Loading known commits in commit graph"
+msgstr "S'estan carregant comissions conegudes al graf de comissions"
+
+#: commit-graph.c:1066
+msgid "Expanding reachable commits in commit graph"
+msgstr "S'estan expandint les comissions abastables al graf de comissions"
+
+#: commit-graph.c:1085
+msgid "Clearing commit marks in commit graph"
+msgstr "S'estan netejant les marques de comissions al graf de comissions"
+
+#: commit-graph.c:1104
+msgid "Computing commit graph generation numbers"
+msgstr "S'estan calculant els nombres de generació del graf de comissions"
+
+#: commit-graph.c:1179
+#, c-format
+msgid "Finding commits for commit graph in %d pack"
+msgid_plural "Finding commits for commit graph in %d packs"
+msgstr[0] "S'estan cercant les comissions pel graf de comissions en %d paquet"
+msgstr[1] "S'estan cercant les comissions pel graf de comissions en %d paquets"
+
+#: commit-graph.c:1192
+#, c-format
+msgid "error adding pack %s"
+msgstr "error en afegir paquet %s"
+
+#: commit-graph.c:1196
+#, c-format
+msgid "error opening index for %s"
+msgstr "s'ha produït un error en obrir l'índex per «%s»"
+
+#: commit-graph.c:1220
+#, c-format
+msgid "Finding commits for commit graph from %d ref"
+msgid_plural "Finding commits for commit graph from %d refs"
+msgstr[0] ""
+"S'estan cercant les comissions pel graf de comissions des de %d referència"
+msgstr[1] ""
+"S'estan cercant les comissions pel graf de comissions des de %d referències"
+
+#: commit-graph.c:1240
+#, c-format
+msgid "invalid commit object id: %s"
+msgstr "identificador d'objecte de comissió no vàlid: %s"
+
+#: commit-graph.c:1255
+msgid "Finding commits for commit graph among packed objects"
+msgstr ""
+"S'estan cercant les comissions pel graf de comissions entre els objectes "
+"empaquetats"
+
+#: commit-graph.c:1270
+msgid "Counting distinct commits in commit graph"
+msgstr "S'estan comptant les comissions diferents al graf de comissions"
+
+#: commit-graph.c:1300
+msgid "Finding extra edges in commit graph"
+msgstr "S'estan cercant les vores addicionals al graf de comissions"
+
+#: commit-graph.c:1346
+msgid "failed to write correct number of base graph ids"
+msgstr ""
+"s'ha produït un error en escriure el nombre correcte d'ids base del graf"
+
+#: commit-graph.c:1379 midx.c:814
+#, c-format
+msgid "unable to create leading directories of %s"
+msgstr "no s'han pogut crear els directoris inicials de «%s»"
+
+#: commit-graph.c:1391 builtin/index-pack.c:306 builtin/repack.c:248
+#, c-format
+msgid "unable to create '%s'"
+msgstr "no s'ha pogut crear «%s»"
+
+#: commit-graph.c:1451
+#, c-format
+msgid "Writing out commit graph in %d pass"
+msgid_plural "Writing out commit graph in %d passes"
+msgstr[0] "S'està escrivint el graf de comissions en %d pas"
+msgstr[1] "S'està escrivint el graf de comissions en %d passos"
+
+#: commit-graph.c:1492
+msgid "unable to open commit-graph chain file"
+msgstr "no s'ha pogut obrir el fitxer d'encadenament del graf de comissions"
+
+#: commit-graph.c:1504
+msgid "failed to rename base commit-graph file"
+msgstr "no s'ha pogut canviar el nom del fitxer base del graf de comissions"
+
+#: commit-graph.c:1524
+msgid "failed to rename temporary commit-graph file"
+msgstr ""
+"no s'ha pogut canviar el nom del fitxer temporal del graf de comissions"
+
+#: commit-graph.c:1635
+msgid "Scanning merged commits"
+msgstr "S'estan escanejant les comissions fusionades"
+
+#: commit-graph.c:1646
+#, c-format
+msgid "unexpected duplicate commit id %s"
+msgstr "id de comissió duplicat %s no esperat"
+
+#: commit-graph.c:1670
+msgid "Merging commit-graph"
+msgstr "S'està fusionant el graf de comissions"
+
+#: commit-graph.c:1860
+#, c-format
+msgid "the commit graph format cannot write %d commits"
+msgstr "el format del graf de comissions no pot escriure %d comissions"
+
+#: commit-graph.c:1871
+msgid "too many commits to write graph"
+msgstr "massa comissions per escriure un graf"
+
+#: commit-graph.c:1961
+msgid "the commit-graph file has incorrect checksum and is likely corrupt"
+msgstr ""
+"el fitxer commit-graph (graf de comissions) té una suma de verificació "
+"incorrecta i probablement és corrupte"
+
+#: commit-graph.c:1971
+#, c-format
+msgid "commit-graph has incorrect OID order: %s then %s"
+msgstr ""
+
+#: commit-graph.c:1981 commit-graph.c:1996
+#, c-format
+msgid "commit-graph has incorrect fanout value: fanout[%d] = %u != %u"
+msgstr ""
+
+#: commit-graph.c:1988
+#, c-format
+msgid "failed to parse commit %s from commit-graph"
+msgstr ""
+"s'ha produït un error en analitzar la comissió %s del graf de comissions"
+
+#: commit-graph.c:2006
+msgid "Verifying commits in commit graph"
+msgstr "S'estan verificant les comissions al graf de comissions"
+
+#: commit-graph.c:2020
+#, c-format
+msgid "failed to parse commit %s from object database for commit-graph"
+msgstr ""
+
+#: commit-graph.c:2027
+#, c-format
+msgid "root tree OID for commit %s in commit-graph is %s != %s"
+msgstr ""
+
+#: commit-graph.c:2037
+#, c-format
+msgid "commit-graph parent list for commit %s is too long"
+msgstr ""
+
+#: commit-graph.c:2046
+#, c-format
+msgid "commit-graph parent for %s is %s != %s"
+msgstr ""
+
+#: commit-graph.c:2059
+#, c-format
+msgid "commit-graph parent list for commit %s terminates early"
+msgstr ""
+
+#: commit-graph.c:2064
+#, c-format
+msgid ""
+"commit-graph has generation number zero for commit %s, but non-zero elsewhere"
+msgstr ""
+
+#: commit-graph.c:2068
+#, c-format
+msgid ""
+"commit-graph has non-zero generation number for commit %s, but zero elsewhere"
+msgstr ""
+
+#: commit-graph.c:2083
+#, c-format
+msgid "commit-graph generation for commit %s is %u != %u"
+msgstr ""
+
+#: commit-graph.c:2089
+#, c-format
+msgid "commit date for commit %s in commit-graph is %<PRIuMAX> != %<PRIuMAX>"
+msgstr ""
+
+#: compat/obstack.c:406 compat/obstack.c:408
 msgid "memory exhausted"
 msgstr "memòria esgotada"
 
-#: config.c:186
+#: config.c:124
+#, c-format
+msgid ""
+"exceeded maximum include depth (%d) while including\n"
+"\t%s\n"
+"from\n"
+"\t%s\n"
+"This might be due to circular includes."
+msgstr ""
+
+#: config.c:140
+#, c-format
+msgid "could not expand include path '%s'"
+msgstr "no s'ha pogut expandir el camí d'inclusió «%s»"
+
+#: config.c:151
+msgid "relative config includes must come from files"
+msgstr "les inclusions de configuració relatives han de venir de fitxers"
+
+#: config.c:197
 msgid "relative config include conditionals must come from files"
 msgstr ""
 "els condicionals d'inclusió de configuració relatius han de venir de fitxers"
 
-#: config.c:720
+#: config.c:376
+#, c-format
+msgid "key does not contain a section: %s"
+msgstr "la clau no conté una secció: «%s»"
+
+#: config.c:382
+#, c-format
+msgid "key does not contain variable name: %s"
+msgstr "la clau no conté un nom de variable: «%s»"
+
+#: config.c:406 sequencer.c:2530
+#, c-format
+msgid "invalid key: %s"
+msgstr "clau no vàlida: %s"
+
+#: config.c:412
+#, c-format
+msgid "invalid key (newline): %s"
+msgstr "clau no vàlida (línea nova): %s"
+
+#: config.c:448 config.c:460
+#, c-format
+msgid "bogus config parameter: %s"
+msgstr "paràmetre de configuració erroni: %s"
+
+#: config.c:495
+#, c-format
+msgid "bogus format in %s"
+msgstr "format erroni a %s"
+
+#: config.c:821
 #, c-format
 msgid "bad config line %d in blob %s"
 msgstr "línia de configuració %d errònia en el blob %s"
 
-#: config.c:724
+#: config.c:825
 #, c-format
 msgid "bad config line %d in file %s"
 msgstr "línia de configuració %d errònia en el fitxer %s"
 
-#: config.c:728
+#: config.c:829
 #, c-format
 msgid "bad config line %d in standard input"
 msgstr "línia de configuració %d errònia en l'entrada estàndard"
 
-#: config.c:732
+#: config.c:833
 #, c-format
 msgid "bad config line %d in submodule-blob %s"
 msgstr "línia de configuració %d errònia en el blob de submòdul %s"
 
-#: config.c:736
+#: config.c:837
 #, c-format
 msgid "bad config line %d in command line %s"
 msgstr "línia de configuració %d errònia en la línia d'ordres %s"
 
-#: config.c:740
+#: config.c:841
 #, c-format
 msgid "bad config line %d in %s"
 msgstr "línia de configuració %d errònia en %s"
 
-#: config.c:868
+#: config.c:978
 msgid "out of range"
 msgstr "fora de rang"
 
-#: config.c:868
+#: config.c:978
 msgid "invalid unit"
 msgstr "unitat no vàlida"
 
-#: config.c:874
+#: config.c:979
 #, c-format
 msgid "bad numeric config value '%s' for '%s': %s"
 msgstr "valor de configuració numèric erroni «%s» per «%s»: %s"
 
-#: config.c:879
+#: config.c:998
 #, c-format
 msgid "bad numeric config value '%s' for '%s' in blob %s: %s"
 msgstr "valor de configuració numèric erroni «%s» per «%s» en el blob %s: %s"
 
-#: config.c:882
+#: config.c:1001
 #, c-format
 msgid "bad numeric config value '%s' for '%s' in file %s: %s"
 msgstr "valor de configuració numèric «%s» erroni per «%s» en el fitxer %s: %s"
 
-#: config.c:885
+#: config.c:1004
 #, c-format
 msgid "bad numeric config value '%s' for '%s' in standard input: %s"
 msgstr ""
 "valor de configuració numèric «%s» erroni per «%s» en l'entrada estàndard: %s"
 
-#: config.c:888
+#: config.c:1007
 #, c-format
 msgid "bad numeric config value '%s' for '%s' in submodule-blob %s: %s"
 msgstr ""
 "valor de configuració numèric «%s» erroni' per «%s» en el blob de submòdul "
 "%s: %s"
 
-#: config.c:891
+#: config.c:1010
 #, c-format
 msgid "bad numeric config value '%s' for '%s' in command line %s: %s"
 msgstr ""
 "valor de configuració numèric «%s» erroni per «%s» en la línia d'ordres %s: "
 "%s"
 
-#: config.c:894
+#: config.c:1013
 #, c-format
 msgid "bad numeric config value '%s' for '%s' in %s: %s"
 msgstr "valor de configuració numèric incorrecte «%s» per «%s» en %s: %s"
 
-#: config.c:989
+#: config.c:1108
 #, c-format
 msgid "failed to expand user dir in: '%s'"
 msgstr "s'ha produït un error en expandir el directori d'usuari en: «%s»"
 
-#: config.c:998
+#: config.c:1117
 #, c-format
 msgid "'%s' for '%s' is not a valid timestamp"
 msgstr "«%s» per a «%s» no és una marca de temps vàlida"
 
-#: config.c:1094 config.c:1105
+#: config.c:1208
+#, c-format
+msgid "abbrev length out of range: %d"
+msgstr ""
+
+#: config.c:1222 config.c:1233
 #, c-format
 msgid "bad zlib compression level %d"
 msgstr "nivell de compressió de zlib incorrecte %d"
 
-#: config.c:1225
+#: config.c:1325
+msgid "core.commentChar should only be one character"
+msgstr ""
+
+#: config.c:1358
 #, c-format
 msgid "invalid mode for object creation: %s"
 msgstr "mode de creació d'objecte no vàlid: %s"
 
-#: config.c:1386
+#: config.c:1430
+#, c-format
+msgid "malformed value for %s"
+msgstr "valor no vàlid per a %s"
+
+#: config.c:1456
+#, c-format
+msgid "malformed value for %s: %s"
+msgstr "valor no vàlid per a %s: %s"
+
+#: config.c:1457
+msgid "must be one of nothing, matching, simple, upstream or current"
+msgstr ""
+
+#: config.c:1518 builtin/pack-objects.c:3394
 #, c-format
 msgid "bad pack compression level %d"
 msgstr "nivell de compressió de paquet %d Erroni"
 
-#: config.c:1582
+#: config.c:1639
+#, c-format
+msgid "unable to load config blob object '%s'"
+msgstr "no s'ha pogut carregar l'objecte blob de configuració «%s»"
+
+#: config.c:1642
+#, c-format
+msgid "reference '%s' does not point to a blob"
+msgstr "la referència «%s» no assenyala a un blob"
+
+#: config.c:1659
+#, c-format
+msgid "unable to resolve config blob '%s'"
+msgstr "no s'ha pogut resoldre el blob de configuració: «%s»"
+
+#: config.c:1689
+#, c-format
+msgid "failed to parse %s"
+msgstr "s'ha produït un error en analitzar %s"
+
+#: config.c:1745
 msgid "unable to parse command-line config"
 msgstr "no s'ha pogut analitzar la configuració de la línia d'ordres"
 
-#: config.c:1914
+#: config.c:2096
 msgid "unknown error occurred while reading the configuration files"
 msgstr "un error desconegut ha ocorregut en llegir els fitxers de configuració"
 
-#: config.c:2101
+#: config.c:2266
 #, c-format
 msgid "Invalid %s: '%s'"
 msgstr "%s no vàlid: «%s»"
 
-#: config.c:2144
-#, c-format
-msgid "unknown core.untrackedCache value '%s'; using 'keep' default value"
-msgstr ""
-"valor «%s» a core.untrackedCache desconegut; utilitzant el valor per defecte "
-"«keep»"
-
-#: config.c:2170
+#: config.c:2311
 #, c-format
 msgid "splitIndex.maxPercentChange value '%d' should be between 0 and 100"
 msgstr "valor «%d» a splitIndex.maxPercentChange ha d'estar entre 0 i 100"
 
-#: config.c:2195
+#: config.c:2357
 #, c-format
 msgid "unable to parse '%s' from command-line config"
 msgstr "no s'ha pogut analitzar «%s» de la configuració de la línia d'ordres"
 
-#: config.c:2197
+#: config.c:2359
 #, c-format
 msgid "bad config variable '%s' in file '%s' at line %d"
 msgstr "variable de configuració «%s» errònia en el fitxer «%s» a la línia %d"
 
-#: config.c:2256
+#: config.c:2440
+#, c-format
+msgid "invalid section name '%s'"
+msgstr "nom de secció no vàlid «%s»"
+
+#: config.c:2472
 #, c-format
 msgid "%s has multiple values"
 msgstr "%s té múltiples valors"
 
-#: config.c:2599 config.c:2816
+#: config.c:2501
 #, c-format
-msgid "fstat on %s failed"
-msgstr "ha fallat fstat a %s"
+msgid "failed to write new configuration file %s"
+msgstr "no es pot escriure un nou fitxer de configuració %s"
 
-#: config.c:2706
+#: config.c:2753 config.c:3077
 #, c-format
-msgid "could not set '%s' to '%s'"
-msgstr "no s'ha pogut establir «%s» a «%s»"
+msgid "could not lock config file %s"
+msgstr "no s'ha pogut blocar el fitxer de configuració %s"
 
-#: config.c:2708 builtin/remote.c:776
+#: config.c:2764
 #, c-format
-msgid "could not unset '%s'"
-msgstr "no s'ha pogut desassignar «%s»"
+msgid "opening %s"
+msgstr "s'està obrint %s"
 
-#: connect.c:52
-msgid "The remote end hung up upon initial contact"
-msgstr "El costat remot ha penjat en el moment de contacte inicial"
+#: config.c:2799 builtin/config.c:328
+#, c-format
+msgid "invalid pattern: %s"
+msgstr "patró no vàlid: %s"
+
+#: config.c:2824
+#, c-format
+msgid "invalid config file %s"
+msgstr "fitxer de configuració no vàlid %s"
+
+#: config.c:2837 config.c:3090
+#, c-format
+msgid "fstat on %s failed"
+msgstr "ha fallat «fstat» a %s"
+
+#: config.c:2848
+#, c-format
+msgid "unable to mmap '%s'"
+msgstr "no s'ha pogut fer «mmap» «%s»"
+
+#: config.c:2857 config.c:3095
+#, c-format
+msgid "chmod on %s failed"
+msgstr "ha fallat chmod a %s"
+
+#: config.c:2942 config.c:3192
+#, c-format
+msgid "could not write config file %s"
+msgstr "no s'ha pogut escriure el fitxer de configuració «%s»"
+
+#: config.c:2976
+#, c-format
+msgid "could not set '%s' to '%s'"
+msgstr "no s'ha pogut establir «%s» a «%s»"
 
-#: connect.c:54
+#: config.c:2978 builtin/remote.c:781
+#, c-format
+msgid "could not unset '%s'"
+msgstr "no s'ha pogut desassignar «%s»"
+
+#: config.c:3068
+#, c-format
+msgid "invalid section name: %s"
+msgstr "nom de secció no vàlida: %s"
+
+#: config.c:3235
+#, c-format
+msgid "missing value for '%s'"
+msgstr "falta el valor per «%s»"
+
+#: connect.c:61
+msgid "the remote end hung up upon initial contact"
+msgstr "el costat remot ha penjat en el moment de contacte inicial"
+
+#: connect.c:63
 msgid ""
 "Could not read from remote repository.\n"
 "\n"
@@ -1499,99 +2453,338 @@ msgstr ""
 "Assegureu-vos que tingueu els permisos\n"
 "d'accés correctes i que el dipòsit existeixi."
 
-#: connected.c:66 builtin/fsck.c:198 builtin/prune.c:144
+#: connect.c:81
+#, c-format
+msgid "server doesn't support '%s'"
+msgstr "el servidor no és compatible amb «%s»"
+
+#: connect.c:103
+#, c-format
+msgid "server doesn't support feature '%s'"
+msgstr "el servidor no és compatible amb la característica «%s»"
+
+#: connect.c:114
+msgid "expected flush after capabilities"
+msgstr ""
+
+#: connect.c:233
+#, c-format
+msgid "ignoring capabilities after first line '%s'"
+msgstr ""
+
+#: connect.c:252
+msgid "protocol error: unexpected capabilities^{}"
+msgstr ""
+
+#: connect.c:273
+#, c-format
+msgid "protocol error: expected shallow sha-1, got '%s'"
+msgstr ""
+"s'ha produït un error de protocol: s'esperava shallow sha-1, s'ha rebut «%s»"
+
+#: connect.c:275
+msgid "repository on the other end cannot be shallow"
+msgstr ""
+
+#: connect.c:313
+msgid "invalid packet"
+msgstr "paquet no vàlid"
+
+#: connect.c:333
+#, c-format
+msgid "protocol error: unexpected '%s'"
+msgstr "s'ha produït un error de protocol: no s'esperava «%s»"
+
+#: connect.c:441
+#, c-format
+msgid "invalid ls-refs response: %s"
+msgstr "resposta de ls-refs no vàlida: %s"
+
+#: connect.c:445
+msgid "expected flush after ref listing"
+msgstr ""
+
+#: connect.c:544
+#, c-format
+msgid "protocol '%s' is not supported"
+msgstr "el protocol «%s» no és compatible"
+
+#: connect.c:595
+msgid "unable to set SO_KEEPALIVE on socket"
+msgstr "no s'ha pogut establir SO_KEEPALIVE al sòcol"
+
+#: connect.c:635 connect.c:698
+#, c-format
+msgid "Looking up %s ... "
+msgstr "S'està cercant %s..."
+
+#: connect.c:639
+#, c-format
+msgid "unable to look up %s (port %s) (%s)"
+msgstr "no s'ha pogut trobar %s (port %s) (%s)"
+
+#. TRANSLATORS: this is the end of "Looking up %s ... "
+#: connect.c:643 connect.c:714
+#, c-format
+msgid ""
+"done.\n"
+"Connecting to %s (port %s) ... "
+msgstr ""
+"fet.\n"
+"S'està connectant a %s (port %s) ... "
+
+#: connect.c:665 connect.c:742
+#, c-format
+msgid ""
+"unable to connect to %s:\n"
+"%s"
+msgstr ""
+"no s'ha pogut connectar a %s:\n"
+"%s"
+
+#. TRANSLATORS: this is the end of "Connecting to %s (port %s) ... "
+#: connect.c:671 connect.c:748
+msgid "done."
+msgstr "fet."
+
+#: connect.c:702
+#, c-format
+msgid "unable to look up %s (%s)"
+msgstr "no s'ha pogut trobar %s (%s)"
+
+#: connect.c:708
+#, c-format
+msgid "unknown port %s"
+msgstr "port desconegut %s"
+
+#: connect.c:845 connect.c:1175
+#, c-format
+msgid "strange hostname '%s' blocked"
+msgstr "s'ha bloquejat el nom estrany d'amfitrió «%s»"
+
+#: connect.c:847
+#, c-format
+msgid "strange port '%s' blocked"
+msgstr "s'ha bloquejat el port estrany «%s»"
+
+#: connect.c:857
+#, c-format
+msgid "cannot start proxy %s"
+msgstr "no s'ha pogut iniciar servidor intermediari «%s»"
+
+#: connect.c:928
+msgid "no path specified; see 'git help pull' for valid url syntax"
+msgstr ""
+"no s'ha especificat un camí; vegeu «git help pull» per la sintaxi vàlida per "
+"URL"
+
+#: connect.c:1123
+msgid "ssh variant 'simple' does not support -4"
+msgstr "la variant «simple» d'ssh no és compatible amb -4"
+
+#: connect.c:1135
+msgid "ssh variant 'simple' does not support -6"
+msgstr "la variant «simple» d'ssh no és compatible amb -6"
+
+#: connect.c:1152
+msgid "ssh variant 'simple' does not support setting port"
+msgstr "la variant «simple» d'ssh no permet definir el port"
+
+#: connect.c:1264
+#, c-format
+msgid "strange pathname '%s' blocked"
+msgstr "s'ha bloquejat el nom de fitxer estrany «%s»"
+
+#: connect.c:1311
+msgid "unable to fork"
+msgstr "no s'ha pogut bifurcar"
+
+#: connected.c:89 builtin/fsck.c:208 builtin/prune.c:43
 msgid "Checking connectivity"
 msgstr "S'està comprovant la connectivitat"
 
-#: connected.c:78
+#: connected.c:101
 msgid "Could not run 'git rev-list'"
 msgstr "No s'ha pogut executar 'git rev-list'"
 
-#: connected.c:98
+#: connected.c:121
 msgid "failed write to rev-list"
 msgstr "escriptura fallada al rev-list"
 
-#: connected.c:105
+#: connected.c:128
 msgid "failed to close rev-list's stdin"
 msgstr "s'ha produït un error en tancar l'stdin del rev-list"
 
-#: convert.c:205
+#: convert.c:194
 #, c-format
-msgid "CRLF would be replaced by LF in %s."
-msgstr "LF reemplaçaria CRLF en %s."
+msgid "illegal crlf_action %d"
+msgstr ""
 
 #: convert.c:207
 #, c-format
+msgid "CRLF would be replaced by LF in %s"
+msgstr "CRLF es reemplaçà per LF en %s"
+
+#: convert.c:209
+#, c-format
 msgid ""
 "CRLF will be replaced by LF in %s.\n"
-"The file will have its original line endings in your working directory."
+"The file will have its original line endings in your working directory"
 msgstr ""
-"LF reemplaçarà CRLF en %s.\n"
+"CRLF serà reemplaçat per LF en %s.\n"
 "El fitxer tindrà els seus terminadors de línia originals en el vostre "
-"directori de treball."
+"directori de treball"
 
-#: convert.c:215
+#: convert.c:217
 #, c-format
 msgid "LF would be replaced by CRLF in %s"
-msgstr "CRLF reemplaçaria LF en %s"
+msgstr "LF es reemplaçà per LF en %s"
 
-#: convert.c:217
+#: convert.c:219
 #, c-format
 msgid ""
 "LF will be replaced by CRLF in %s.\n"
-"The file will have its original line endings in your working directory."
+"The file will have its original line endings in your working directory"
 msgstr ""
-"CRLF reemplaçarà LF en %s.\n"
+"LF serà reemplaçat per CRLF en %s.\n"
 "El fitxer tindrà els seus terminadors de línia originals en el vostre "
-"directori de treball."
+"directori de treball"
+
+#: convert.c:284
+#, c-format
+msgid "BOM is prohibited in '%s' if encoded as %s"
+msgstr ""
+
+#: convert.c:291
+#, c-format
+msgid ""
+"The file '%s' contains a byte order mark (BOM). Please use UTF-%.*s as "
+"working-tree-encoding."
+msgstr ""
+
+#: convert.c:304
+#, c-format
+msgid "BOM is required in '%s' if encoded as %s"
+msgstr ""
+
+#: convert.c:306
+#, c-format
+msgid ""
+"The file '%s' is missing a byte order mark (BOM). Please use UTF-%sBE or UTF-"
+"%sLE (depending on the byte order) as working-tree-encoding."
+msgstr ""
+
+#: convert.c:419 convert.c:490
+#, c-format
+msgid "failed to encode '%s' from %s to %s"
+msgstr "s'ha produït un error en codificar «%s» des de %s a %s"
+
+#: convert.c:462
+#, c-format
+msgid "encoding '%s' from %s to %s and back is not the same"
+msgstr "codificar «%s» des de %s a %s i cap enrere no és el mateix"
+
+#: convert.c:668
+#, c-format
+msgid "cannot fork to run external filter '%s'"
+msgstr "no es pot bifurcar per a executar el filtre extern «%s»"
+
+#: convert.c:688
+#, c-format
+msgid "cannot feed the input to external filter '%s'"
+msgstr "no es pot alimentar l'entrada al filtre extern «%s»"
+
+#: convert.c:695
+#, c-format
+msgid "external filter '%s' failed %d"
+msgstr "el filtre extern «%s» ha fallat %d"
+
+#: convert.c:730 convert.c:733
+#, c-format
+msgid "read from external filter '%s' failed"
+msgstr "la lectura del filtre extern «%s» ha fallat"
+
+#: convert.c:736 convert.c:791
+#, c-format
+msgid "external filter '%s' failed"
+msgstr "el filtre extern «%s» ha fallat"
+
+#: convert.c:839
+msgid "unexpected filter type"
+msgstr "tipus de filtre inesperat"
+
+#: convert.c:850
+msgid "path name too long for external filter"
+msgstr ""
+
+#: convert.c:924
+#, c-format
+msgid ""
+"external filter '%s' is not available anymore although not all paths have "
+"been filtered"
+msgstr ""
+
+#: convert.c:1223
+msgid "true/false are no valid working-tree-encodings"
+msgstr ""
+
+#: convert.c:1411 convert.c:1445
+#, c-format
+msgid "%s: clean filter '%s' failed"
+msgstr "%s: el filtre de netejat «%s» ha fallat"
 
-#: date.c:116
+#: convert.c:1489
+#, fuzzy, c-format
+msgid "%s: smudge filter %s failed"
+msgstr "s'ha produït un error en actualitzar els fitxers"
+
+#: date.c:138
 msgid "in the future"
 msgstr "en el futur"
 
-#: date.c:122
+#: date.c:144
 #, c-format
 msgid "%<PRIuMAX> second ago"
 msgid_plural "%<PRIuMAX> seconds ago"
 msgstr[0] "fa %<PRIuMAX> segon"
 msgstr[1] "fa %<PRIuMAX> segons"
 
-#: date.c:129
+#: date.c:151
 #, c-format
 msgid "%<PRIuMAX> minute ago"
 msgid_plural "%<PRIuMAX> minutes ago"
 msgstr[0] "fa %<PRIuMAX> minut"
 msgstr[1] "fa %<PRIuMAX> minuts"
 
-#: date.c:136
+#: date.c:158
 #, c-format
 msgid "%<PRIuMAX> hour ago"
 msgid_plural "%<PRIuMAX> hours ago"
 msgstr[0] "fa %<PRIuMAX> hora"
 msgstr[1] "fa %<PRIuMAX> hores"
 
-#: date.c:143
+#: date.c:165
 #, c-format
 msgid "%<PRIuMAX> day ago"
 msgid_plural "%<PRIuMAX> days ago"
 msgstr[0] "fa %<PRIuMAX> dia"
 msgstr[1] "fa %<PRIuMAX> dies"
 
-#: date.c:149
+#: date.c:171
 #, c-format
 msgid "%<PRIuMAX> week ago"
 msgid_plural "%<PRIuMAX> weeks ago"
 msgstr[0] "fa %<PRIuMAX> setmana"
 msgstr[1] "fa %<PRIuMAX> setmanes"
 
-#: date.c:156
+#: date.c:178
 #, c-format
 msgid "%<PRIuMAX> month ago"
 msgid_plural "%<PRIuMAX> months ago"
 msgstr[0] "fa %<PRIuMAX> mes"
 msgstr[1] "fa %<PRIuMAX> mesos"
 
-#: date.c:167
+#: date.c:189
 #, c-format
 msgid "%<PRIuMAX> year"
 msgid_plural "%<PRIuMAX> years"
@@ -1599,61 +2792,108 @@ msgstr[0] "%<PRIuMAX> any"
 msgstr[1] "%<PRIuMAX> anys"
 
 #. TRANSLATORS: "%s" is "<n> years"
-#: date.c:170
+#: date.c:192
 #, c-format
 msgid "%s, %<PRIuMAX> month ago"
 msgid_plural "%s, %<PRIuMAX> months ago"
 msgstr[0] "fa %s i %<PRIuMAX> mes"
 msgstr[1] "fa %s i %<PRIuMAX> mesos"
 
-#: date.c:175 date.c:180
+#: date.c:197 date.c:202
 #, c-format
 msgid "%<PRIuMAX> year ago"
 msgid_plural "%<PRIuMAX> years ago"
 msgstr[0] "fa %<PRIuMAX> any"
 msgstr[1] "fa %<PRIuMAX> anys"
 
+#: delta-islands.c:272
+msgid "Propagating island marks"
+msgstr "S'estan propagant les marques d'illa"
+
+#: delta-islands.c:290
+#, c-format
+msgid "bad tree object %s"
+msgstr "objecte d'arbre malmès %s"
+
+#: delta-islands.c:334
+#, c-format
+msgid "failed to load island regex for '%s': %s"
+msgstr ""
+"s'ha produït un error en carregar l'expressió regular de l'illa per «%s»: %s"
+
+#: delta-islands.c:390
+#, c-format
+msgid "island regex from config has too many capture groups (max=%d)"
+msgstr ""
+"l'expressió regular de l'illa des de la configuració té massa grups de "
+"captura (màx=%d)"
+
+#: delta-islands.c:467
+#, c-format
+msgid "Marked %d islands, done.\n"
+msgstr "Marcades %d illes, fet.\n"
+
 #: diffcore-order.c:24
 #, c-format
 msgid "failed to read orderfile '%s'"
 msgstr "s'ha produït un error en llegir el fitxer d'ordres «%s»"
 
-#: diffcore-rename.c:535
+#: diffcore-rename.c:543
 msgid "Performing inexact rename detection"
 msgstr "S'està realitzant una detecció inexacta de canvis de nom"
 
-#: diff.c:74
-#, c-format
-msgid "option '%s' requires a value"
-msgstr "l'opció «%s» requereix un valor"
+#: diff-no-index.c:238
+msgid "git diff --no-index [<options>] <path> <path>"
+msgstr "git diff --no-index [<opcions>] <camí> <camí>"
 
-#: diff.c:152
+#: diff-no-index.c:263
+msgid ""
+"Not a git repository. Use --no-index to compare two paths outside a working "
+"tree"
+msgstr ""
+"No és un dipòsit Git. Useu --no-index per a comparar dos camins fora del "
+"directori de treball"
+
+#: diff.c:155
 #, c-format
 msgid "  Failed to parse dirstat cut-off percentage '%s'\n"
 msgstr ""
 "  S'ha produït un error en analitzar el percentatge limitant de dirstat "
 "«%s»\n"
 
-#: diff.c:157
+#: diff.c:160
 #, c-format
 msgid "  Unknown dirstat parameter '%s'\n"
 msgstr "  Paràmetre de dirstat desconegut «%s»\n"
 
-#: diff.c:281
+#: diff.c:296
+msgid ""
+"color moved setting must be one of 'no', 'default', 'blocks', 'zebra', "
+"'dimmed-zebra', 'plain'"
+msgstr ""
+"el paràmetre de color en moviment ha de ser «no», «default», «blocks», "
+"«zebra», «dimmed-zebra» o «plain»"
+
+#: diff.c:324
+#, c-format
+msgid ""
+"unknown color-moved-ws mode '%s', possible values are 'ignore-space-change', "
+"'ignore-space-at-eol', 'ignore-all-space', 'allow-indentation-change'"
+msgstr ""
+
+#: diff.c:332
 msgid ""
-"color moved setting must be one of 'no', 'default', 'zebra', 'dimmed_zebra', "
-"'plain'"
+"color-moved-ws: allow-indentation-change cannot be combined with other "
+"whitespace modes"
 msgstr ""
-"el paràmetre de color en moviment ha de ser «no», «default», «zebra», "
-"«dimmed_zebra» o «plain»"
 
-#: diff.c:341
+#: diff.c:405
 #, c-format
 msgid "Unknown value for 'diff.submodule' config variable: '%s'"
 msgstr ""
 "Valor desconegut de la variable de configuració de 'diff.submodule': «%s»"
 
-#: diff.c:401
+#: diff.c:465
 #, c-format
 msgid ""
 "Found errors in 'diff.dirstat' config variable:\n"
@@ -1662,24 +2902,35 @@ msgstr ""
 "S'han trobat errors en la variable de configuració 'diff.dirstat':\n"
 "%s"
 
-#: diff.c:3822
+#: diff.c:4202
 #, c-format
 msgid "external diff died, stopping at %s"
 msgstr "el diff external s'ha mort, s'està aturant a %s"
 
-#: diff.c:4146
+#: diff.c:4547
 msgid "--name-only, --name-status, --check and -s are mutually exclusive"
 msgstr "--name-only, --name-status, --check i -s són mútuament excloents"
 
-#: diff.c:4149
+#: diff.c:4550
 msgid "-G, -S and --find-object are mutually exclusive"
 msgstr "-G, -S and --find-object són mútuament excloents"
 
-#: diff.c:4237
+#: diff.c:4628
 msgid "--follow requires exactly one pathspec"
 msgstr "--follow requereix exactament una especificació de camí"
 
-#: diff.c:4403
+#: diff.c:4676
+#, c-format
+msgid "invalid --stat value: %s"
+msgstr "valor --stat no vàlid: %s"
+
+#: diff.c:4681 diff.c:4686 diff.c:4691 diff.c:4696 diff.c:5209
+#: parse-options.c:199 parse-options.c:203
+#, c-format
+msgid "%s expects a numerical value"
+msgstr "%s espera un valor numèric"
+
+#: diff.c:4713
 #, c-format
 msgid ""
 "Failed to parse --dirstat/-X option parameter:\n"
@@ -1688,13524 +2939,19844 @@ msgstr ""
 "S'ha produït un error en analitzar el paràmetre d'opció de --dirstat/-X:\n"
 "%s"
 
-#: diff.c:4417
+#: diff.c:4798
 #, c-format
-msgid "Failed to parse --submodule option parameter: '%s'"
-msgstr ""
-"S'ha produït un error en analitzar el paràmetre d'opció de --submodule: «%s»"
+msgid "unknown change class '%c' in --diff-filter=%s"
+msgstr "classe de canvi «%c» desconeguda a --diff-filter=%s"
 
-#: diff.c:5493
-msgid "inexact rename detection was skipped due to too many files."
-msgstr "s'ha omès la detecció de canvi de nom a causa de massa fitxers."
+#: diff.c:4822
+#, c-format
+msgid "unknown value after ws-error-highlight=%.*s"
+msgstr "valor desconegut després de ws-error-highlight=%.*s"
 
-#: diff.c:5496
-msgid "only found copies from modified paths due to too many files."
-msgstr ""
-"només s'han trobat còpies des de camins modificats a causa de massa fitxers."
+#: diff.c:4836
+#, c-format
+msgid "unable to resolve '%s'"
+msgstr "no s'ha pogut resoldre «%s»"
 
-#: diff.c:5499
+#: diff.c:4886 diff.c:4892
 #, c-format
-msgid ""
-"you may want to set your %s variable to at least %d and retry the command."
+msgid "%s expects <n>/<m> form"
 msgstr ""
-"potser voleu establir la vostra variable %s a almenys %d i tornar a intentar "
-"l'ordre."
 
-#: dir.c:1866
+#: diff.c:4904
 #, c-format
-msgid "could not open directory '%s'"
-msgstr "no s'ha pogut obrir el directori «%s»"
+msgid "%s expects a character, got '%s'"
+msgstr "%s esperava un caràcter, s'ha rebut «%s»"
 
-#: dir.c:2108
-msgid "failed to get kernel name and information"
-msgstr "s'ha produït un error en obtenir el nombre i la informació del nucli"
+#: diff.c:4925
+#, c-format
+msgid "bad --color-moved argument: %s"
+msgstr "paràmetre --color-moved incorrecte: %s"
+
+#: diff.c:4944
+#, c-format
+msgid "invalid mode '%s' in --color-moved-ws"
+msgstr "mode «%s» no vàlid en -color-moved-ws"
 
-#: dir.c:2232
-msgid "Untracked cache is disabled on this system or location."
+#: diff.c:4984
+msgid ""
+"option diff-algorithm accepts \"myers\", \"minimal\", \"patience\" and "
+"\"histogram\""
 msgstr ""
-"La memòria cau no seguida està inhabilitada en aquest sistema o ubicació."
+"l'opció diff-algorithm accepta «myers», «minimal», «patience» i «histogram»"
 
-#: dir.c:3024 dir.c:3029
+#: diff.c:5020 diff.c:5040
 #, c-format
-msgid "could not create directories for %s"
-msgstr "no s'han pogut crear directoris per %s"
+msgid "invalid argument to %s"
+msgstr "argument no vàlid a %s"
 
-#: dir.c:3054
+#: diff.c:5178
 #, c-format
-msgid "could not migrate git directory from '%s' to '%s'"
-msgstr "no s'ha pogut migrar el directori de «%s» a «%s»"
+msgid "failed to parse --submodule option parameter: '%s'"
+msgstr ""
+"s'ha produït un error en analitzar el paràmetre d'opció de --submodule: «%s»"
 
-#: editor.c:61
+#: diff.c:5234
 #, c-format
-msgid "hint: Waiting for your editor to close the file...%c"
-msgstr ""
+msgid "bad --word-diff argument: %s"
+msgstr "paràmetre --word-diff incorrecte: %s"
 
-#: entry.c:177
-msgid "Filtering content"
-msgstr "S'està filtrant el contingut"
+#: diff.c:5257
+msgid "Diff output format options"
+msgstr "Opcions del format de sortida del diff"
 
-#: entry.c:435
-#, c-format
-msgid "could not stat file '%s'"
-msgstr "no s'ha pogut fer «stat» sobre el fitxer «%s»"
+#: diff.c:5259 diff.c:5265
+msgid "generate patch"
+msgstr "generant pedaç"
 
-#: fetch-object.c:17
-msgid "Remote with no URL"
-msgstr "Remot sense URL"
+#: diff.c:5262 builtin/log.c:173
+msgid "suppress diff output"
+msgstr "omet la sortida de diferències"
 
-#: fetch-pack.c:253
-msgid "git fetch-pack: expected shallow list"
-msgstr "git fetch-pack: llista superficial esperada"
+#: diff.c:5267 diff.c:5381 diff.c:5388
+msgid "<n>"
+msgstr "<n>"
 
-#: fetch-pack.c:265
-msgid "git fetch-pack: expected ACK/NAK, got a flush packet"
-msgstr "git fetch-pack: s'esperava ACK/NAK, s'ha rebut un paquet de neteja"
+#: diff.c:5268 diff.c:5271
+msgid "generate diffs with <n> lines context"
+msgstr "genera diffs amb <n> línies de context"
 
-#: fetch-pack.c:284 builtin/archive.c:63
-#, c-format
-msgid "remote error: %s"
-msgstr "error remot: %s"
+#: diff.c:5273
+msgid "generate the diff in raw format"
+msgstr "genera el diff en format cru"
 
-#: fetch-pack.c:285
-#, c-format
-msgid "git fetch-pack: expected ACK/NAK, got '%s'"
-msgstr "git fetch-pack: s'esperava ACK/NAK, s'ha rebut «%s»"
+#: diff.c:5276
+msgid "synonym for '-p --raw'"
+msgstr "sinònim de per a «-p --raw»"
 
-#: fetch-pack.c:337
-msgid "--stateless-rpc requires multi_ack_detailed"
-msgstr "--stateless-rpc requereix multi_ack_detailed"
+#: diff.c:5280
+msgid "synonym for '-p --stat'"
+msgstr "sinònim de per a «-p --stat»"
 
-#: fetch-pack.c:428
-#, c-format
-msgid "invalid shallow line: %s"
-msgstr "línia de shallow no vàlida: %s"
+#: diff.c:5284
+msgid "machine friendly --stat"
+msgstr "llegible per màquina --stat"
 
-#: fetch-pack.c:434
-#, c-format
-msgid "invalid unshallow line: %s"
-msgstr "línia d'unshallow no vàlida: %s"
+#: diff.c:5287
+msgid "output only the last line of --stat"
+msgstr "mostra només l'última línia de --stat"
 
-#: fetch-pack.c:436
-#, c-format
-msgid "object not found: %s"
-msgstr "objecte no trobat: %s"
+#: diff.c:5289 diff.c:5297
+msgid "<param1,param2>..."
+msgstr "<param1,param2>..."
 
-#: fetch-pack.c:439
-#, c-format
-msgid "error in object: %s"
-msgstr "error en objecte: %s"
+#: diff.c:5290
+msgid ""
+"output the distribution of relative amount of changes for each sub-directory"
+msgstr ""
 
-#: fetch-pack.c:441
-#, c-format
-msgid "no shallow found: %s"
-msgstr "no s'ha trobat cap shallow: %s"
+#: diff.c:5294
+msgid "synonym for --dirstat=cumulative"
+msgstr "sinònim per -dirstat=cumulative"
 
-#: fetch-pack.c:444
-#, c-format
-msgid "expected shallow/unshallow, got %s"
-msgstr "s'esperava shallow/unshallow, s'ha rebut %s"
+#: diff.c:5298
+msgid "synonym for --dirstat=files,param1,param2..."
+msgstr "sinònim per --dirstat=files,param1,param2..."
 
-#: fetch-pack.c:485
-#, c-format
-msgid "got %s %d %s"
-msgstr "s'ha rebut %s %d %s"
+#: diff.c:5302
+msgid "warn if changes introduce conflict markers or whitespace errors"
+msgstr ""
 
-#: fetch-pack.c:499
-#, c-format
-msgid "invalid commit %s"
-msgstr "comissió no vàlida %s"
+#: diff.c:5305
+msgid "condensed summary such as creations, renames and mode changes"
+msgstr ""
 
-#: fetch-pack.c:532
-msgid "giving up"
-msgstr "s'està rendint"
+#: diff.c:5308
+msgid "show only names of changed files"
+msgstr "mostra només els noms de fitxers canviats"
 
-#: fetch-pack.c:542 progress.c:229
-msgid "done"
-msgstr "fet"
+#: diff.c:5311
+msgid "show only names and status of changed files"
+msgstr "mostra només els noms i l'estat dels fitxers canviats"
 
-#: fetch-pack.c:554
-#, c-format
-msgid "got %s (%d) %s"
-msgstr "s'ha rebut %s (%d) %s"
+#: diff.c:5313
+msgid "<width>[,<name-width>[,<count>]]"
+msgstr ""
 
-#: fetch-pack.c:600
-#, c-format
-msgid "Marking %s as complete"
-msgstr "S'està marcant %s com a complet"
+#: diff.c:5314
+msgid "generate diffstat"
+msgstr "genera diffstat"
 
-#: fetch-pack.c:788
-#, c-format
-msgid "already have %s (%s)"
-msgstr "ja es té %s (%s)"
+#: diff.c:5316 diff.c:5319 diff.c:5322
+msgid "<width>"
+msgstr "<amplada>"
 
-#: fetch-pack.c:829
-msgid "fetch-pack: unable to fork off sideband demultiplexer"
-msgstr "fetch-pack: no s'ha pogut bifurcar del desmultiplexor de banda lateral"
+#: diff.c:5317
+msgid "generate diffstat with a given width"
+msgstr "genera diffstat amb una amplada donada"
 
-#: fetch-pack.c:837
-msgid "protocol error: bad pack header"
-msgstr "error de protocol: capçalera de paquet errònia"
+#: diff.c:5320
+msgid "generate diffstat with a given name width"
+msgstr "genera diffstat amb un nom d'amplada donat"
 
-#: fetch-pack.c:895
-#, c-format
-msgid "fetch-pack: unable to fork off %s"
-msgstr "fetch-pack: no es pot bifurcar de %s"
+#: diff.c:5323
+msgid "generate diffstat with a given graph width"
+msgstr "genera diffstat amb una amplada de graf donada"
 
-#: fetch-pack.c:911
-#, c-format
-msgid "%s failed"
-msgstr "%s ha fallat"
+#: diff.c:5325
+msgid "<count>"
+msgstr "<comptador>"
 
-#: fetch-pack.c:913
-msgid "error in sideband demultiplexer"
-msgstr "error en desmultiplexor de banda lateral"
+#: diff.c:5326
+msgid "generate diffstat with limited lines"
+msgstr "genera diffstat amb línies limitades"
 
-#: fetch-pack.c:940
-msgid "Server does not support shallow clients"
-msgstr "El servidor no permet clients superficials"
+#: diff.c:5329
+msgid "generate compact summary in diffstat"
+msgstr "genera un resum compacte a diffstat"
 
-#: fetch-pack.c:944
-msgid "Server supports multi_ack_detailed"
-msgstr "El servidor accepta multi_ack_detailed"
-
-#: fetch-pack.c:947
-msgid "Server supports no-done"
-msgstr "El servidor accepta no-done"
-
-#: fetch-pack.c:953
-msgid "Server supports multi_ack"
-msgstr "El servidor accepta multi_ack"
-
-#: fetch-pack.c:957
-msgid "Server supports side-band-64k"
-msgstr "El servidor accepta side-band-64k"
-
-#: fetch-pack.c:961
-msgid "Server supports side-band"
-msgstr "El servidor accepta banda lateral"
+#: diff.c:5332
+msgid "output a binary diff that can be applied"
+msgstr "diff amb sortida binaria que pot ser aplicada"
 
-#: fetch-pack.c:965
-msgid "Server supports allow-tip-sha1-in-want"
-msgstr "El servidor accepta allow-tip-sha1-in-want"
+#: diff.c:5335
+msgid "show full pre- and post-image object names on the \"index\" lines"
+msgstr ""
 
-#: fetch-pack.c:969
-msgid "Server supports allow-reachable-sha1-in-want"
-msgstr "El servidor accepta allow-reachable-sha1-in-want"
-
-#: fetch-pack.c:979
-msgid "Server supports ofs-delta"
-msgstr "El servidor accepta ofs-delta"
+#: diff.c:5337
+msgid "show colored diff"
+msgstr "mostra un diff amb colors"
 
-#: fetch-pack.c:985
-msgid "Server supports filter"
-msgstr "El servidor accepta filtre"
+#: diff.c:5338
+msgid "<kind>"
+msgstr ""
 
-#: fetch-pack.c:993
-#, c-format
-msgid "Server version is %.*s"
-msgstr "La versió del servidor és %.*s"
+#: diff.c:5339
+msgid ""
+"highlight whitespace errors in the 'context', 'old' or 'new' lines in the "
+"diff"
+msgstr ""
 
-#: fetch-pack.c:999
-msgid "Server does not support --shallow-since"
-msgstr "El servidor no admet --shallow-since"
+#: diff.c:5342
+msgid ""
+"do not munge pathnames and use NULs as output field terminators in --raw or "
+"--numstat"
+msgstr ""
 
-#: fetch-pack.c:1003
-msgid "Server does not support --shallow-exclude"
-msgstr "El servidor no admet --shallow-exclude"
+#: diff.c:5345 diff.c:5348 diff.c:5351 diff.c:5457
+msgid "<prefix>"
+msgstr "<prefix>"
 
-#: fetch-pack.c:1005
-msgid "Server does not support --deepen"
-msgstr "El servidor no admet --deepen"
+#: diff.c:5346
+msgid "show the given source prefix instead of \"a/\""
+msgstr ""
 
-#: fetch-pack.c:1016
-msgid "no common commits"
-msgstr "cap comissió en comú"
+#: diff.c:5349
+msgid "show the given destination prefix instead of \"b/\""
+msgstr ""
 
-#: fetch-pack.c:1028
-msgid "git fetch-pack: fetch failed."
-msgstr "git fetch-pack: l'obtenció ha fallat."
+#: diff.c:5352
+msgid "prepend an additional prefix to every line of output"
+msgstr "afegir un prefix addicional per a cada línia de sortida"
 
-#: fetch-pack.c:1190
-msgid "no matching remote head"
-msgstr "no hi ha cap HEAD remot coincident"
+#: diff.c:5355
+msgid "do not show any source or destination prefix"
+msgstr "no mostris cap prefix d'origen o destí"
 
-#: fetch-pack.c:1212
-#, c-format
-msgid "no such remote ref %s"
-msgstr "no existeix la referència remota %s"
+#: diff.c:5358
+#, fuzzy
+msgid "show context between diff hunks up to the specified number of lines"
+msgstr "Crea un clon superficial truncat al nombre de revisions especificat"
 
-#: fetch-pack.c:1215
-#, c-format
-msgid "Server does not allow request for unadvertised object %s"
-msgstr "El servidor no permet sol·licitar objectes no anunciats %s"
+#: diff.c:5362 diff.c:5367 diff.c:5372
+msgid "<char>"
+msgstr "<char>"
 
-#: gpg-interface.c:181
-msgid "gpg failed to sign the data"
-msgstr "gpg ha fallat en signar les dades"
+#: diff.c:5363
+msgid "specify the character to indicate a new line instead of '+'"
+msgstr ""
+"especifiqueu el caràcter per a indicar una línia nova en comptes de «+»"
 
-#: gpg-interface.c:211
-msgid "could not create temporary file"
-msgstr "no s'ha pogut crear el fitxer temporal"
+#: diff.c:5368
+msgid "specify the character to indicate an old line instead of '-'"
+msgstr ""
+"especifiqueu el caràcter per a indicar una línia antiga en comptes de «-»"
 
-#: gpg-interface.c:214
-#, c-format
-msgid "failed writing detached signature to '%s'"
-msgstr "s'ha produït un error en escriure la signatura separada a «%s»"
+#: diff.c:5373
+msgid "specify the character to indicate a context instead of ' '"
+msgstr "especifiqueu el caràcter per a indicar context en comptes de « »"
 
-#: graph.c:97
-#, c-format
-msgid "ignore invalid color '%.*s' in log.graphColors"
-msgstr "ignora el color no vàlid «%.*s» en log.graphColors"
+#: diff.c:5376
+msgid "Diff rename options"
+msgstr "Opcions de canvi de nom del diff"
 
-#: grep.c:2022
-#, c-format
-msgid "'%s': unable to read %s"
-msgstr "«%s»: no s'ha pogut llegir %s"
+#: diff.c:5377
+msgid "<n>[/<m>]"
+msgstr "<n>[/<m>]"
 
-#: grep.c:2039 setup.c:163 builtin/clone.c:407 builtin/diff.c:81
-#: builtin/rm.c:134
-#, c-format
-msgid "failed to stat '%s'"
-msgstr "s'ha produït un error en fer stat a «%s»"
+#: diff.c:5378
+msgid "break complete rewrite changes into pairs of delete and create"
+msgstr ""
+"divideix els canvis de reescriptura completa en parells de suprimir i crear"
 
-#: grep.c:2050
-#, c-format
-msgid "'%s': short read"
-msgstr "«%s»: lectura curta"
+#: diff.c:5382
+msgid "detect renames"
+msgstr "detecta els canvis de noms"
 
-#: help.c:179
-#, c-format
-msgid "available git commands in '%s'"
-msgstr "ordres de git disponibles en «%s»"
+#: diff.c:5386
+msgid "omit the preimage for deletes"
+msgstr "omet les preimatges per les supressions"
 
-#: help.c:186
-msgid "git commands available from elsewhere on your $PATH"
-msgstr "ordres de git disponibles d'altres llocs en el vostre $PATH"
+#: diff.c:5389
+msgid "detect copies"
+msgstr "detecta còpies"
 
-#: help.c:217
-msgid "These are common Git commands used in various situations:"
+#: diff.c:5393
+msgid "use unmodified files as source to find copies"
+msgstr "usa els fitxers no modificats com a font per trobar còpies"
+
+#: diff.c:5395
+msgid "disable rename detection"
+msgstr "inhabilita la detecció de canvis de nom"
+
+#: diff.c:5398
+msgid "use empty blobs as rename source"
+msgstr "usa els blobs buits com a font de canvi de nom"
+
+#: diff.c:5400
+msgid "continue listing the history of a file beyond renames"
 msgstr ""
-"Aquestes són ordres del Git habitualment usades en diverses situacions:"
+"continua llistant l'històric d'un un fitxer més enllà dels canvis de nom"
 
-#: help.c:281
-#, c-format
+#: diff.c:5403
 msgid ""
-"'%s' appears to be a git command, but we were not\n"
-"able to execute it. Maybe git-%s is broken?"
+"prevent rename/copy detection if the number of rename/copy targets exceeds "
+"given limit"
 msgstr ""
-"«%s» sembla una ordre de git, però no hem pogut\n"
-"executar-la. Pot ser que git-%s estigui malmès?"
 
-#: help.c:336
-msgid "Uh oh. Your system reports no Git commands at all."
-msgstr "Ai. El vostre sistema no informa de cap ordre de Git."
+#: diff.c:5405
+msgid "Diff algorithm options"
+msgstr "Opcions d'algorisme Diff"
 
-#: help.c:358
-#, c-format
-msgid "WARNING: You called a Git command named '%s', which does not exist."
-msgstr ""
-"ADVERTÈNCIA: Heu invocat una ordre de Git amb nom «%s», la qual no existeix."
+#: diff.c:5407
+msgid "produce the smallest possible diff"
+msgstr "produeix el diff més petit possible"
 
-#: help.c:363
-#, c-format
-msgid "Continuing under the assumption that you meant '%s'."
-msgstr "El procés continuarà, pressuposant que volíeu dir «%s»."
+#: diff.c:5410
+msgid "ignore whitespace when comparing lines"
+msgstr "ignora els espai en blanc en comparar línies"
 
-#: help.c:368
-#, c-format
-msgid "Continuing in %0.1f seconds, assuming that you meant '%s'."
+#: diff.c:5413
+msgid "ignore changes in amount of whitespace"
+msgstr "ignora els canvis en la quantitat d'espai en blanc"
+
+#: diff.c:5416
+msgid "ignore changes in whitespace at EOL"
+msgstr "ignora els canvis d'espai en blanc al final de la línia"
+
+#: diff.c:5419
+msgid "ignore carrier-return at the end of line"
+msgstr "ignora els retorns de línia al final de la línia"
+
+#: diff.c:5422
+msgid "ignore changes whose lines are all blank"
+msgstr "ignora els canvis en línies que estan en blanc"
+
+#: diff.c:5425
+msgid "heuristic to shift diff hunk boundaries for easy reading"
 msgstr ""
-"El procés continuarà en %0.1f segons, pressuposant que volíeu dir «%s»."
 
-#: help.c:376
-#, c-format
-msgid "git: '%s' is not a git command. See 'git --help'."
-msgstr "git: «%s» no és una ordre de git. Vegeu 'git --help'."
+#: diff.c:5428
+msgid "generate diff using the \"patience diff\" algorithm"
+msgstr "genera diff usant l'algorisme «patience diff»"
 
-#: help.c:380
-msgid ""
-"\n"
-"The most similar command is"
-msgid_plural ""
-"\n"
-"The most similar commands are"
-msgstr[0] ""
-"\n"
-"L'ordre més similar és"
-msgstr[1] ""
-"\n"
-"Les ordres més similar són"
+#: diff.c:5432
+msgid "generate diff using the \"histogram diff\" algorithm"
+msgstr "genera diff usant l'algorisme «histogram diff»"
 
-#: help.c:395
-msgid "git version [<options>]"
-msgstr "git version [<opcions>]"
+#: diff.c:5434
+msgid "<algorithm>"
+msgstr "<algorisme>"
 
-#: help.c:462
-#, c-format
-msgid "%s: %s - %s"
-msgstr "%s: %s - %s"
+#: diff.c:5435
+msgid "choose a diff algorithm"
+msgstr "escolliu un algorisme pel diff"
 
-#: help.c:466
-msgid ""
-"\n"
-"Did you mean this?"
-msgid_plural ""
-"\n"
-"Did you mean one of these?"
-msgstr[0] ""
-"\n"
-"Volíeu dir això?"
-msgstr[1] ""
-"\n"
-"Volíeu dir un d'aquests?"
+#: diff.c:5437
+msgid "<text>"
+msgstr "<text>"
 
-#: ident.c:342
-msgid ""
-"\n"
-"*** Please tell me who you are.\n"
-"\n"
-"Run\n"
-"\n"
-"  git config --global user.email \"you@example.com\"\n"
-"  git config --global user.name \"Your Name\"\n"
-"\n"
-"to set your account's default identity.\n"
-"Omit --global to set the identity only in this repository.\n"
-"\n"
+#: diff.c:5438
+msgid "generate diff using the \"anchored diff\" algorithm"
+msgstr "genera diff usant l'algorisme «anchored diff»"
+
+#: diff.c:5440 diff.c:5449 diff.c:5452
+msgid "<mode>"
+msgstr "<mode>"
+
+#: diff.c:5441
+msgid "show word diff, using <mode> to delimit changed words"
 msgstr ""
-"\n"
-"*** Digueu-me qui sou.\n"
-"\n"
-"Executeu\n"
-"\n"
-"  git config --global user.email \"usuari@domini.com\"\n"
-"  git config --global user.name \"El vostre nom\"\n"
-"\n"
-"per a establir la identitat predeterminada del vostre compte.\n"
-"Ometeu --global per a establir la identitat només en aquest dipòsit.\n"
 
-#: ident.c:366
-msgid "no email was given and auto-detection is disabled"
+#: diff.c:5443 diff.c:5446 diff.c:5491
+msgid "<regex>"
+msgstr "<regex>"
+
+#: diff.c:5444
+msgid "use <regex> to decide what a word is"
 msgstr ""
-"no s'ha proporcionat cap adreça electrònica i la detecció automàtica està "
-"inhabilitada"
 
-#: ident.c:371
-#, c-format
-msgid "unable to auto-detect email address (got '%s')"
+#: diff.c:5447
+msgid "equivalent to --word-diff=color --word-diff-regex=<regex>"
+msgstr "equivalent a --word-diff=color --word-diff-regex=<regex>"
+
+#: diff.c:5450
+msgid "moved lines of code are colored differently"
+msgstr "les línies de codi que s'ha mogut s'acoloreixen diferent"
+
+#: diff.c:5453
+msgid "how white spaces are ignored in --color-moved"
+msgstr "com s'ignoren els espais en blanc a --color-moved"
+
+#: diff.c:5456
+msgid "Other diff options"
+msgstr "Altres opcions diff"
+
+#: diff.c:5458
+msgid "when run from subdir, exclude changes outside and show relative paths"
+msgstr "quan s'executa des d'un subdirectori, exclou els canvis de fora i mostra els camins relatius"
+
+#: diff.c:5462
+msgid "treat all files as text"
+msgstr "tracta tots els fitxers com a text"
+
+#: diff.c:5464
+msgid "swap two inputs, reverse the diff"
+msgstr "intercanvia els dues entrada, inverteix el diff"
+
+#: diff.c:5466
+msgid "exit with 1 if there were differences, 0 otherwise"
+msgstr "surt amb 1 si hi ha diferències, 0 en cas contrari"
+
+#: diff.c:5468
+msgid "disable all output of the program"
+msgstr "inhabilita totes les sortides del programa"
+
+#: diff.c:5470
+msgid "allow an external diff helper to be executed"
 msgstr ""
-"no s'ha pogut detectar automàticament una adreça electrònica vàlida (s'ha "
-"rebut «%s»)"
 
-#: ident.c:381
-msgid "no name was given and auto-detection is disabled"
+#: diff.c:5472
+msgid "run external text conversion filters when comparing binary files"
 msgstr ""
-"no s'ha proporcionat cap nom i la detecció automàtica està inhabilitada"
 
-#: ident.c:387
-#, c-format
-msgid "unable to auto-detect name (got '%s')"
-msgstr "no s'ha pogut detectar automàticament el nom (s'ha rebut «%s»)"
+#: diff.c:5474
+msgid "<when>"
+msgstr "<quan>"
 
-#: ident.c:395
-#, c-format
-msgid "empty ident name (for <%s>) not allowed"
-msgstr "nom d'identitat buit (per <%s>) no és permès"
+#: diff.c:5475
+msgid "ignore changes to submodules in the diff generation"
+msgstr "ignora els canvis als submòduls en la generació del diff"
 
-#: ident.c:401
-#, c-format
-msgid "name consists only of disallowed characters: %s"
-msgstr "el nom conté només caràcters no permesos: %s"
+#: diff.c:5478
+msgid "<format>"
+msgstr "<format>"
 
-#: ident.c:416 builtin/commit.c:582
-#, c-format
-msgid "invalid date format: %s"
-msgstr "format de data no vàlid: %s"
+#: diff.c:5479
+msgid "specify how differences in submodules are shown"
+msgstr "especifiqueu com es mostren els canvis als submòduls"
 
-#: list-objects-filter-options.c:36
-msgid "multiple filter-specs cannot be combined"
+#: diff.c:5483
+#, fuzzy
+msgid "hide 'git add -N' entries from the index"
+msgstr "usa .gitattributes només des de l'índex"
+
+#: diff.c:5486
+msgid "treat 'git add -N' entries as real in the index"
 msgstr ""
 
-#: list-objects-filter-options.c:126
-msgid "cannot change partial clone promisor remote"
+#: diff.c:5488
+msgid "<string>"
+msgstr "<cadena>"
+
+#: diff.c:5489
+msgid ""
+"look for differences that change the number of occurrences of the specified "
+"string"
 msgstr ""
 
-#: lockfile.c:151
-#, c-format
+#: diff.c:5492
 msgid ""
-"Unable to create '%s.lock': %s.\n"
-"\n"
-"Another git process seems to be running in this repository, e.g.\n"
-"an editor opened by 'git commit'. Please make sure all processes\n"
-"are terminated then try again. If it still fails, a git process\n"
-"may have crashed in this repository earlier:\n"
-"remove the file manually to continue."
+"look for differences that change the number of occurrences of the specified "
+"regex"
 msgstr ""
-"No s'ha pogut crear '%s.lock': %s.\n"
-"\n"
-"Sembla que un altre procés de git s'està executant en aquest\n"
-"dipòsit, per exemple, un editor obert per 'git commit'. \n"
-"Assegureu-vos que tots els processos s'hagin terminat i\n"
-"llavors proveu de nou. Si encara falla, pot ser que un procés de\n"
-"git ha tingut un error:\n"
-"elimineu el fitxer manualment per a continuar."
 
-#: lockfile.c:159
-#, c-format
-msgid "Unable to create '%s.lock': %s"
-msgstr "No s'ha pogut crear '%s.lock': %s"
+#: diff.c:5495
+msgid "show all changes in the changeset with -S or -G"
+msgstr "mostra tots els canvis amb el conjunt de canvis amb -S o -G"
 
-#: merge.c:74
-msgid "failed to read the cache"
-msgstr "s'ha produït un error en llegir la memòria cau"
+#: diff.c:5498
+msgid "treat <string> in -S as extended POSIX regular expression"
+msgstr "tracta <cadena> a -S com a expressió regular POSIX ampliada"
 
-#: merge.c:134 builtin/am.c:1946 builtin/am.c:1980 builtin/checkout.c:378
-#: builtin/checkout.c:599 builtin/clone.c:759
-msgid "unable to write new index file"
-msgstr "no s'ha pogut escriure un fitxer d'índex nou"
+#: diff.c:5501
+msgid "control the order in which files appear in the output"
+msgstr "controla l'ordre amb el qual els fitxers apareixen en la sortida"
 
-#: merge-recursive.c:235
-msgid "(bad commit)\n"
-msgstr "(comissió errònia)\n"
+#: diff.c:5502
+msgid "<object-id>"
+msgstr "<id de l'objecte>"
 
-#: merge-recursive.c:257 merge-recursive.c:265
-#, c-format
-msgid "addinfo_cache failed for path '%s'"
-msgstr "addinfo_cache ha fallat per al camí «%s»"
+#: diff.c:5503
+msgid ""
+"look for differences that change the number of occurrences of the specified "
+"object"
+msgstr ""
 
-#: merge-recursive.c:329
-msgid "error building trees"
-msgstr "error en construir arbres"
+#: diff.c:5505
+msgid "[(A|C|D|M|R|T|U|X|B)...[*]]"
+msgstr "[(A|C|D|M|R|T|U|X|B)...[*]]"
 
-#: merge-recursive.c:771
-#, c-format
-msgid "failed to create path '%s'%s"
-msgstr "s'ha produït un error en crear el camí «%s»%s"
+#: diff.c:5506
+msgid "select files by diff type"
+msgstr "seleccioneu els fitxers per tipus de diff"
 
-#: merge-recursive.c:782
-#, c-format
-msgid "Removing %s to make room for subdirectory\n"
-msgstr "S'està eliminant %s per a fer espai per al subdirectori\n"
+#: diff.c:5508
+msgid "<file>"
+msgstr "<fitxer>"
 
-#: merge-recursive.c:796 merge-recursive.c:815
-msgid ": perhaps a D/F conflict?"
-msgstr ": potser un conflicte D/F?"
+#: diff.c:5509
+msgid "Output to a specific file"
+msgstr "Sortida a un fitxer específic"
 
-#: merge-recursive.c:805
-#, c-format
-msgid "refusing to lose untracked file at '%s'"
-msgstr "s'està refusant perdre el fitxer no seguit a «%s»"
+#: diff.c:6164
+msgid "inexact rename detection was skipped due to too many files."
+msgstr ""
+"s'ha omès la detecció de canvi de nom inexacta a causa de massa fitxers."
+
+#: diff.c:6167
+msgid "only found copies from modified paths due to too many files."
+msgstr ""
+"només s'han trobat còpies des de camins modificats a causa de massa fitxers."
 
-#: merge-recursive.c:847 builtin/cat-file.c:37
+#: diff.c:6170
 #, c-format
-msgid "cannot read object %s '%s'"
-msgstr "no es pot llegir l'objecte %s «%s»"
+msgid ""
+"you may want to set your %s variable to at least %d and retry the command."
+msgstr ""
+"potser voleu establir la vostra variable %s a almenys %d i tornar a intentar "
+"l'ordre."
 
-#: merge-recursive.c:849
+#: dir.c:554
 #, c-format
-msgid "blob expected for %s '%s'"
-msgstr "blob esperat per a %s «%s»"
+msgid "pathspec '%s' did not match any file(s) known to git"
+msgstr ""
+"l'especificació de camí «%s» no ha coincidit amb cap fitxer que git conegui"
 
-#: merge-recursive.c:873
+#: dir.c:664
 #, c-format
-msgid "failed to open '%s': %s"
-msgstr "s'ha produït un error en obrir «%s»: %s"
+msgid "unrecognized pattern: '%s'"
+msgstr "patró no reconegut: «%s»"
 
-#: merge-recursive.c:884
+#: dir.c:682 dir.c:696
 #, c-format
-msgid "failed to symlink '%s': %s"
-msgstr "s'ha produït un error en fer l'enllaç simbòlic «%s»: %s"
+msgid "unrecognized negative pattern: '%s'"
+msgstr "patró negatiu no reconegut: «%s»"
 
-#: merge-recursive.c:889
+#: dir.c:714
 #, c-format
-msgid "do not know what to do with %06o %s '%s'"
-msgstr "no se sap què fer amb %06o %s «%s»"
+msgid "your sparse-checkout file may have issues: pattern '%s' is repeated"
+msgstr ""
 
-#: merge-recursive.c:1029
-msgid "Failed to execute internal merge"
-msgstr "S'ha produït un error en executar la fusió interna"
+#: dir.c:724
+msgid "disabling cone pattern matching"
+msgstr "inhabilita la coincidència de patrons «cone»"
 
-#: merge-recursive.c:1034
+#: dir.c:1101
 #, c-format
-msgid "Unable to add %s to database"
-msgstr "No s'ha pogut afegir %s a la base de dades"
+msgid "cannot use %s as an exclude file"
+msgstr "no es pot usar %s com a fitxer d'exclusió"
 
-#: merge-recursive.c:1146
+#: dir.c:2078
 #, c-format
-msgid ""
-"CONFLICT (%s/delete): %s deleted in %s and %s in %s. Version %s of %s left "
-"in tree."
+msgid "could not open directory '%s'"
+msgstr "no s'ha pogut obrir el directori «%s»"
+
+#: dir.c:2415
+msgid "failed to get kernel name and information"
+msgstr "s'ha produït un error en obtenir el nombre i la informació del nucli"
+
+#: dir.c:2539
+msgid "untracked cache is disabled on this system or location"
 msgstr ""
-"CONFLICTE: (%s/supressió): %s suprimit en %s i %s en %s. La versió %s de %s "
-"s'ha deixat en l'arbre."
+"la memòria cau no seguida està inhabilitada en aquest sistema o ubicació"
 
-#: merge-recursive.c:1151
+#: dir.c:3343
 #, c-format
-msgid ""
-"CONFLICT (%s/delete): %s deleted in %s and %s to %s in %s. Version %s of %s "
-"left in tree."
-msgstr ""
-"CONFLICTE: (%s/supressió): %s suprimit en %s i %s a %s en %s. La versió %s "
-"de %s s'ha deixat en l'arbre."
+msgid "index file corrupt in repo %s"
+msgstr "el fitxer d'índex al dipòsit %s és malmès"
 
-#: merge-recursive.c:1158
+#: dir.c:3388 dir.c:3393
 #, c-format
-msgid ""
-"CONFLICT (%s/delete): %s deleted in %s and %s in %s. Version %s of %s left "
-"in tree at %s."
-msgstr ""
-"CONFLICTE: (%s/supressió): %s suprimit en %s i %s en %s. La versió %s de %s "
-"s'ha deixat en l'arbre a %s."
+msgid "could not create directories for %s"
+msgstr "no s'han pogut crear directoris per %s"
 
-#: merge-recursive.c:1163
+#: dir.c:3422
 #, c-format
-msgid ""
-"CONFLICT (%s/delete): %s deleted in %s and %s to %s in %s. Version %s of %s "
-"left in tree at %s."
-msgstr ""
-"CONFLICTE: (%s/supressió): %s suprimit en %s i %s a %s en %s. La versió %s "
-"de %s s'ha deixat en l'arbre a %s."
+msgid "could not migrate git directory from '%s' to '%s'"
+msgstr "no s'ha pogut migrar el directori de «%s» a «%s»"
 
-#: merge-recursive.c:1197
-msgid "rename"
-msgstr "canvi de nom"
+#: editor.c:73
+#, c-format
+msgid "hint: Waiting for your editor to close the file...%c"
+msgstr ""
 
-#: merge-recursive.c:1197
-msgid "renamed"
-msgstr "canviat de nom"
+#: entry.c:178
+msgid "Filtering content"
+msgstr "S'està filtrant el contingut"
 
-#: merge-recursive.c:1254
+#: entry.c:476
 #, c-format
-msgid "%s is a directory in %s adding as %s instead"
-msgstr "%s és un directori en %s; s'està afegint com a %s en lloc d'això"
+msgid "could not stat file '%s'"
+msgstr "no s'ha pogut fer «stat» sobre el fitxer «%s»"
 
-#: merge-recursive.c:1279
+#: environment.c:149
 #, c-format
-msgid ""
-"CONFLICT (rename/rename): Rename \"%s\"->\"%s\" in branch \"%s\" rename \"%s"
-"\"->\"%s\" in \"%s\"%s"
+msgid "bad git namespace path \"%s\""
 msgstr ""
-"CONFLICTE (canvi de nom/canvi de nom): Canvi de nom \"%s\"->\"%s\" en la "
-"branca \"%s\" canvi de nom \"%s\"->\"%s\" en \"%s\"%s"
 
-#: merge-recursive.c:1284
-msgid " (left unresolved)"
-msgstr " (deixat sense resolució)"
+#: environment.c:331
+#, c-format
+msgid "could not set GIT_DIR to '%s'"
+msgstr "no s'ha pogut establir GIT_DIR a «%s»"
 
-#: merge-recursive.c:1346
+#: exec-cmd.c:363
 #, c-format
-msgid "CONFLICT (rename/rename): Rename %s->%s in %s. Rename %s->%s in %s"
-msgstr ""
-"CONFLICTE (canvi de nom/canvi de nom): Canvi de nom %s->%s en %s. Canvi de "
-"nom %s->%s en %s"
+msgid "too many args to run %s"
+msgstr "hi ha massa arguments per a executar %s"
+
+#: fetch-pack.c:150
+msgid "git fetch-pack: expected shallow list"
+msgstr "git fetch-pack: llista superficial esperada"
 
-#: merge-recursive.c:1379
+#: fetch-pack.c:153
+#, fuzzy
+msgid "git fetch-pack: expected a flush packet after shallow list"
+msgstr "git fetch-pack: llista superficial esperada"
+
+#: fetch-pack.c:164
+msgid "git fetch-pack: expected ACK/NAK, got a flush packet"
+msgstr "git fetch-pack: s'esperava ACK/NAK, s'ha rebut un paquet de neteja"
+
+#: fetch-pack.c:184
 #, c-format
-msgid "Renaming %s to %s and %s to %s instead"
-msgstr "S'està canviant el nom de %s a %s i %s a %s en lloc d'això"
+msgid "git fetch-pack: expected ACK/NAK, got '%s'"
+msgstr "git fetch-pack: s'esperava ACK/NAK, s'ha rebut «%s»"
 
-#: merge-recursive.c:1582
+#: fetch-pack.c:195
+msgid "unable to write to remote"
+msgstr "no s'ha pogut escriure al remot"
+
+#: fetch-pack.c:257
+msgid "--stateless-rpc requires multi_ack_detailed"
+msgstr "--stateless-rpc requereix multi_ack_detailed"
+
+#: fetch-pack.c:356 fetch-pack.c:1340
 #, c-format
-msgid "CONFLICT (rename/add): Rename %s->%s in %s. %s added in %s"
-msgstr ""
-"CONFLICTE (canvi de nom/afegiment): Canvi de nom %s->%s en %s. %s afegit en "
-"%s"
+msgid "invalid shallow line: %s"
+msgstr "línia de shallow no vàlida: %s"
 
-#: merge-recursive.c:1597
+#: fetch-pack.c:362 fetch-pack.c:1346
 #, c-format
-msgid "Adding merged %s"
-msgstr "S'està afegint %s fusionat"
+msgid "invalid unshallow line: %s"
+msgstr "línia d'unshallow no vàlida: %s"
 
-#: merge-recursive.c:1604 merge-recursive.c:1834
+#: fetch-pack.c:364 fetch-pack.c:1348
 #, c-format
-msgid "Adding as %s instead"
-msgstr "S'està afegint com a %s en lloc d'això"
+msgid "object not found: %s"
+msgstr "objecte no trobat: %s"
 
-#: merge-recursive.c:1661
+#: fetch-pack.c:367 fetch-pack.c:1351
 #, c-format
-msgid "cannot read object %s"
-msgstr "no es pot llegir l'objecte %s"
+msgid "error in object: %s"
+msgstr "error en objecte: %s"
 
-#: merge-recursive.c:1664
+#: fetch-pack.c:369 fetch-pack.c:1353
 #, c-format
-msgid "object %s is not a blob"
-msgstr "l'objecte %s no és un blob"
+msgid "no shallow found: %s"
+msgstr "no s'ha trobat cap shallow: %s"
 
-#: merge-recursive.c:1733
-msgid "modify"
-msgstr "modificació"
+#: fetch-pack.c:372 fetch-pack.c:1357
+#, c-format
+msgid "expected shallow/unshallow, got %s"
+msgstr "s'esperava shallow/unshallow, s'ha rebut %s"
 
-#: merge-recursive.c:1733
-msgid "modified"
-msgstr "modificat"
+#: fetch-pack.c:414
+#, c-format
+msgid "got %s %d %s"
+msgstr "s'ha rebut %s %d %s"
 
-#: merge-recursive.c:1743
-msgid "content"
-msgstr "contingut"
+#: fetch-pack.c:431
+#, c-format
+msgid "invalid commit %s"
+msgstr "comissió no vàlida %s"
 
-#: merge-recursive.c:1750
-msgid "add/add"
-msgstr "afegiment/afegiment"
+#: fetch-pack.c:462
+msgid "giving up"
+msgstr "s'abandona"
 
-#: merge-recursive.c:1786
-#, c-format
-msgid "Skipped %s (merged same as existing)"
-msgstr "S'ha omès %s (el fusionat és igual a l'existent)"
+#: fetch-pack.c:475 progress.c:323
+msgid "done"
+msgstr "fet"
 
-#: merge-recursive.c:1800
+#: fetch-pack.c:487
 #, c-format
-msgid "Auto-merging %s"
-msgstr "S'està autofusionant %s"
-
-#: merge-recursive.c:1804 git-submodule.sh:879
-msgid "submodule"
-msgstr "submòdul"
+msgid "got %s (%d) %s"
+msgstr "s'ha rebut %s (%d) %s"
 
-#: merge-recursive.c:1805
+#: fetch-pack.c:533
 #, c-format
-msgid "CONFLICT (%s): Merge conflict in %s"
-msgstr "CONFLICTE (%s): Conflicte de fusió en %s"
+msgid "Marking %s as complete"
+msgstr "S'està marcant %s com a complet"
 
-#: merge-recursive.c:1899
+#: fetch-pack.c:754
 #, c-format
-msgid "Removing %s"
-msgstr "S'està eliminant %s"
+msgid "already have %s (%s)"
+msgstr "ja es té %s (%s)"
 
-#: merge-recursive.c:1925
-msgid "file/directory"
-msgstr "fitxer/directori"
+#: fetch-pack.c:818
+msgid "fetch-pack: unable to fork off sideband demultiplexer"
+msgstr "fetch-pack: no s'ha pogut bifurcar del desmultiplexor de banda lateral"
 
-#: merge-recursive.c:1931
-msgid "directory/file"
-msgstr "directori/fitxer"
+#: fetch-pack.c:826
+msgid "protocol error: bad pack header"
+msgstr "error de protocol: capçalera de paquet errònia"
 
-#: merge-recursive.c:1938
+#: fetch-pack.c:900
 #, c-format
-msgid "CONFLICT (%s): There is a directory with name %s in %s. Adding %s as %s"
-msgstr ""
-"CONFLICTE (%s): Hi ha un directori amb nom %s en %s. S'està afegint %s com a "
-"%s"
+msgid "fetch-pack: unable to fork off %s"
+msgstr "fetch-pack: no es pot bifurcar de %s"
 
-#: merge-recursive.c:1947
+#: fetch-pack.c:916
 #, c-format
-msgid "Adding %s"
-msgstr "S'està afegint %s"
+msgid "%s failed"
+msgstr "%s ha fallat"
 
-#: merge-recursive.c:1987
-#, c-format
-msgid "Dirty index: cannot merge (dirty: %s)"
-msgstr "Índex brut: no es pot fusionar (bruts: %s)"
+#: fetch-pack.c:918
+msgid "error in sideband demultiplexer"
+msgstr "error en desmultiplexor de banda lateral"
 
-#: merge-recursive.c:1991
-msgid "Already up to date!"
-msgstr "Ja està al dia!"
+#: fetch-pack.c:965
+#, c-format
+msgid "Server version is %.*s"
+msgstr "La versió del servidor és %.*s"
 
-#: merge-recursive.c:2000
+#: fetch-pack.c:970 fetch-pack.c:976 fetch-pack.c:979 fetch-pack.c:985
+#: fetch-pack.c:989 fetch-pack.c:993 fetch-pack.c:997 fetch-pack.c:1001
+#: fetch-pack.c:1005 fetch-pack.c:1009 fetch-pack.c:1013 fetch-pack.c:1017
+#: fetch-pack.c:1023 fetch-pack.c:1029 fetch-pack.c:1034 fetch-pack.c:1039
 #, c-format
-msgid "merging of trees %s and %s failed"
-msgstr "la fusió dels arbres %s i %s ha fallat"
+msgid "Server supports %s"
+msgstr "El servidor accepta %s"
 
-#: merge-recursive.c:2097
-msgid "Merging:"
-msgstr "S'està fusionant:"
+#: fetch-pack.c:972
+msgid "Server does not support shallow clients"
+msgstr "El servidor no permet clients superficials"
 
-#: merge-recursive.c:2110
-#, c-format
-msgid "found %u common ancestor:"
-msgid_plural "found %u common ancestors:"
-msgstr[0] "s'ha trobat %u avantpassat en comú:"
-msgstr[1] "s'han trobat %u avantpassats en comú:"
+#: fetch-pack.c:1032
+msgid "Server does not support --shallow-since"
+msgstr "El servidor no admet --shallow-since"
 
-#: merge-recursive.c:2149
-msgid "merge returned no commit"
-msgstr "la fusió no ha retornat cap comissió"
+#: fetch-pack.c:1037
+msgid "Server does not support --shallow-exclude"
+msgstr "El servidor no admet --shallow-exclude"
 
-#: merge-recursive.c:2212
-#, c-format
-msgid "Could not parse object '%s'"
-msgstr "No s'ha pogut analitzar l'objecte «%s»"
+#: fetch-pack.c:1041
+msgid "Server does not support --deepen"
+msgstr "El servidor no admet --deepen"
 
-#: merge-recursive.c:2228 builtin/merge.c:657 builtin/merge.c:816
-msgid "Unable to write index."
-msgstr "No s'ha pogut escriure l'índex."
+#: fetch-pack.c:1058
+msgid "no common commits"
+msgstr "cap comissió en comú"
 
-#: notes-merge.c:272
-#, c-format
-msgid ""
-"You have not concluded your previous notes merge (%s exists).\n"
-"Please, use 'git notes merge --commit' or 'git notes merge --abort' to "
-"commit/abort the previous merge before you start a new notes merge."
-msgstr ""
-"No heu acabat la vostra fusió de notes prèvia (%s existeix).\n"
-"Useu «git notes merge --commit» o «git notes merge --abort» per a cometre/"
-"avortar la fusió prèvia abans de començar una fusió de notes nova."
+#: fetch-pack.c:1070 fetch-pack.c:1536
+msgid "git fetch-pack: fetch failed."
+msgstr "git fetch-pack: l'obtenció ha fallat."
 
-#: notes-merge.c:279
-#, c-format
-msgid "You have not concluded your notes merge (%s exists)."
-msgstr "No heu conclòs la vostra fusió de notes (%s existeix)."
+#: fetch-pack.c:1209
+msgid "Server does not support shallow requests"
+msgstr "El servidor no permet peticions superficials"
 
-#: notes-utils.c:43
-msgid "Cannot commit uninitialized/unreferenced notes tree"
-msgstr "No es pot cometre un arbre de notes no inicialitzat / no referenciat"
+#: fetch-pack.c:1216
+msgid "Server supports filter"
+msgstr "El servidor accepta filtratge"
 
-#: notes-utils.c:102
+#: fetch-pack.c:1239
+msgid "unable to write request to remote"
+msgstr "no s'ha pogut escriure la petició al remot"
+
+#: fetch-pack.c:1257
 #, c-format
-msgid "Bad notes.rewriteMode value: '%s'"
-msgstr "Valor de notes.rewriteMode erroni: «%s»"
+msgid "error reading section header '%s'"
+msgstr "error en llegir la capçalera de la secció «%s»"
 
-#: notes-utils.c:112
+#: fetch-pack.c:1263
 #, c-format
-msgid "Refusing to rewrite notes in %s (outside of refs/notes/)"
-msgstr "S'està refusant reescriure les notes en %s (fora de refs/notes/)"
+msgid "expected '%s', received '%s'"
+msgstr "s'esperava «%s», s'ha rebut «%s»"
 
-#. TRANSLATORS: The first %s is the name of
-#. the environment variable, the second %s is
-#. its value.
-#.
-#: notes-utils.c:142
+#: fetch-pack.c:1303
 #, c-format
-msgid "Bad %s value: '%s'"
-msgstr "Valor erroni de %s: «%s»"
+msgid "unexpected acknowledgment line: '%s'"
+msgstr "línia de confirmació inesperada: «%s»"
 
-#: object.c:239
+#: fetch-pack.c:1308
 #, c-format
-msgid "unable to parse object: %s"
-msgstr "no s'ha pogut analitzar l'objecte: %s"
+msgid "error processing acks: %d"
+msgstr "s'ha produït un error en processar els acks: %d"
 
-#: packfile.c:561
-msgid "offset before end of packfile (broken .idx?)"
-msgstr "desplaçament abans de la fi del fitxer de paquet (.idx trencat?)"
+#: fetch-pack.c:1318
+msgid "expected packfile to be sent after 'ready'"
+msgstr "s'espera l'enviament del fitxer de paquet després de «ready»"
 
-#: packfile.c:1694
-#, c-format
-msgid "offset before start of pack index for %s (corrupt index?)"
-msgstr ""
-"desplaçament abans d'inici d'índex de paquet per a %s (índex corromput?)"
+#: fetch-pack.c:1320
+msgid "expected no other sections to be sent after no 'ready'"
+msgstr "s'espera que cap altra seccions s'enviï després de no «ready»"
 
-#: packfile.c:1698
+#: fetch-pack.c:1362
 #, c-format
-msgid "offset beyond end of pack index for %s (truncated index?)"
-msgstr ""
-"desplaçament més enllà de la fi d'índex de paquet per a %s (índex truncat?)"
+msgid "error processing shallow info: %d"
+msgstr "s'ha produït un error en processar la informació superficial: %d"
 
-#: parse-options.c:619
-msgid "..."
-msgstr "..."
-
-#: parse-options.c:638
+#: fetch-pack.c:1409
 #, c-format
-msgid "usage: %s"
-msgstr "ús: %s"
+msgid "expected wanted-ref, got '%s'"
+msgstr "s'esperava wanted-ref, s'ha rebut «%s»"
 
-#. TRANSLATORS: the colon here should align with the
-#. one in "usage: %s" translation.
-#.
-#: parse-options.c:644
+#: fetch-pack.c:1414
 #, c-format
-msgid "   or: %s"
-msgstr " o: %s"
+msgid "unexpected wanted-ref: '%s'"
+msgstr "wanted-ref inesperat: «%s»"
 
-#: parse-options.c:647
+#: fetch-pack.c:1419
 #, c-format
-msgid "    %s"
-msgstr "    %s"
+msgid "error processing wanted refs: %d"
+msgstr "s'ha produït un error en processar les referències desitjades: %d"
 
-#: parse-options.c:686
-msgid "-NUM"
-msgstr "-NUM"
+#: fetch-pack.c:1762
+msgid "no matching remote head"
+msgstr "no hi ha cap HEAD remot coincident"
 
-#: parse-options-cb.c:108
+#: fetch-pack.c:1785 builtin/clone.c:688
+msgid "remote did not send all necessary objects"
+msgstr "el remot no ha enviat tots els objectes necessaris"
+
+#: fetch-pack.c:1812
 #, c-format
-msgid "malformed object name '%s'"
-msgstr "nom d'objecte mal format «%s»"
+msgid "no such remote ref %s"
+msgstr "no existeix la referència remota %s"
 
-#: path.c:891
+#: fetch-pack.c:1815
 #, c-format
-msgid "Could not make %s writable by group"
-msgstr "No s'ha pogut fer %s escrivible pel grup"
+msgid "Server does not allow request for unadvertised object %s"
+msgstr "El servidor no permet sol·licitar objectes no anunciats %s"
 
-#: pathspec.c:129
-msgid "Escape character '\\' not allowed as last character in attr value"
-msgstr ""
-"El caràcter d'escapament '\\' no està permès com a últim caràcter en un "
-"valor d'un atribut"
+#: gpg-interface.c:223
+msgid "could not create temporary file"
+msgstr "no s'ha pogut crear el fitxer temporal"
 
-#: pathspec.c:147
-msgid "Only one 'attr:' specification is allowed."
-msgstr "Només es permet una especificació 'attr:'."
+#: gpg-interface.c:226
+#, c-format
+msgid "failed writing detached signature to '%s'"
+msgstr "s'ha produït un error en escriure la signatura separada a «%s»"
 
-#: pathspec.c:150
-msgid "attr spec must not be empty"
-msgstr "una especificació d'atribut no pot estar buida"
+#: gpg-interface.c:390
+msgid "gpg failed to sign the data"
+msgstr "gpg ha fallat en signar les dades"
 
-#: pathspec.c:193
+#: graph.c:98
 #, c-format
-msgid "invalid attribute name %s"
-msgstr "nom d'atribut no vàlid %s"
+msgid "ignore invalid color '%.*s' in log.graphColors"
+msgstr "ignora el color no vàlid «%.*s» en log.graphColors"
 
-#: pathspec.c:258
-msgid "global 'glob' and 'noglob' pathspec settings are incompatible"
+#: grep.c:668
+msgid ""
+"given pattern contains NULL byte (via -f <file>). This is only supported "
+"with -P under PCRE v2"
 msgstr ""
-"els paràmetres d'especificació de camí 'glob' i 'noglob' globals són "
-"incompatibles"
 
-#: pathspec.c:265
-msgid ""
-"global 'literal' pathspec setting is incompatible with all other global "
-"pathspec settings"
-msgstr ""
-"el paràmetre d'especificació de camí 'literal' global és incompatible amb "
-"tots els altres paràmetres d'especificació de camí globals"
-
-#: pathspec.c:305
-msgid "invalid parameter for pathspec magic 'prefix'"
-msgstr "paràmetre no vàlid per a la màgia d'especificació de camí 'prefix'"
-
-#: pathspec.c:326
+#: grep.c:2124
 #, c-format
-msgid "Invalid pathspec magic '%.*s' in '%s'"
-msgstr "Màgia d'especificació de camí no vàlida '%.*s' en «%s»"
+msgid "'%s': unable to read %s"
+msgstr "«%s»: no s'ha pogut llegir %s"
 
-#: pathspec.c:331
+#: grep.c:2141 setup.c:165 builtin/clone.c:411 builtin/diff.c:82
+#: builtin/rm.c:135
 #, c-format
-msgid "Missing ')' at the end of pathspec magic in '%s'"
-msgstr "')' mancant al final de la màgia d'especificació de camí en «%s»"
+msgid "failed to stat '%s'"
+msgstr "s'ha produït un error en fer stat a «%s»"
 
-#: pathspec.c:369
+#: grep.c:2152
 #, c-format
-msgid "Unimplemented pathspec magic '%c' in '%s'"
-msgstr "Màgia d'especificació de camí no implementada '%c' en «%s»"
+msgid "'%s': short read"
+msgstr "«%s»: lectura curta"
 
-#: pathspec.c:428
-#, c-format
-msgid "%s: 'literal' and 'glob' are incompatible"
-msgstr "%s: 'literal' i 'glob' són incompatibles"
+#: help.c:23
+msgid "start a working area (see also: git help tutorial)"
+msgstr "començar una àrea de treball (vegeu també: git help tutorial)"
 
-#: pathspec.c:441
-#, c-format
-msgid "%s: '%s' is outside repository"
-msgstr "%s: «%s» és fora del dipòsit"
+#: help.c:24
+msgid "work on the current change (see also: git help everyday)"
+msgstr "treballar en el canvi actual (vegeu també: git help everyday)"
 
-#: pathspec.c:515
-#, c-format
-msgid "'%s' (mnemonic: '%c')"
-msgstr "«%s» (mnemònic: '%c')"
+#: help.c:25
+msgid "examine the history and state (see also: git help revisions)"
+msgstr "examinar la història i l'estat (vegeu també: git help revisions)"
 
-#: pathspec.c:525
-#, c-format
-msgid "%s: pathspec magic not supported by this command: %s"
-msgstr ""
-"%s: aquesta ordre no està admesa amb la màgia d'especificació de camí: %s"
+#: help.c:26
+msgid "grow, mark and tweak your common history"
+msgstr "fer créixer, marcar i ajustar la vostra història comuna"
 
-#: pathspec.c:592
-#, c-format
-msgid "pathspec '%s' is beyond a symbolic link"
-msgstr "l'especificació de camí «%s» és més enllà d'un enllaç simbòlic"
+#: help.c:27
+msgid "collaborate (see also: git help workflows)"
+msgstr "col·laborar (vegeu també: git help workflow)"
 
-#: pretty.c:962
-msgid "unable to parse --pretty format"
-msgstr "no s'ha pogut analitzar el format --pretty"
+#: help.c:31
+msgid "Main Porcelain Commands"
+msgstr ""
 
-#: read-cache.c:1473
-#, c-format
-msgid ""
-"index.version set, but the value is invalid.\n"
-"Using version %i"
+#: help.c:32
+msgid "Ancillary Commands / Manipulators"
 msgstr ""
-"index.version està establerta, però el valor no és vàlid.\n"
-"S'està usant la versió %i"
 
-#: read-cache.c:1483
-#, c-format
-msgid ""
-"GIT_INDEX_VERSION set, but the value is invalid.\n"
-"Using version %i"
+#: help.c:33
+msgid "Ancillary Commands / Interrogators"
 msgstr ""
-"GIT_INDEX_VERSION està establerta, però el valor no és vàlid.\n"
-"S'està usant la versió %i"
 
-#: read-cache.c:2375 sequencer.c:3248 wrapper.c:658 builtin/merge.c:1049
-#, c-format
-msgid "could not close '%s'"
-msgstr "no s'ha pogut tancar «%s»"
+#: help.c:34
+msgid "Interacting with Others"
+msgstr "Interaccionar amb altres"
 
-#: read-cache.c:2448 sequencer.c:1900 sequencer.c:2627
-#, c-format
-msgid "could not stat '%s'"
-msgstr "no s'ha pogut fer stat a «%s»"
+#: help.c:35
+msgid "Low-level Commands / Manipulators"
+msgstr "Ordres de baix nivell / Manipuladors"
 
-#: read-cache.c:2461
-#, c-format
-msgid "unable to open git dir: %s"
-msgstr "no s'ha pogut obrir el directori git: %s"
+#: help.c:36
+msgid "Low-level Commands / Interrogators"
+msgstr "Ordres de baix nivell / Interrogadors"
 
-#: read-cache.c:2473
-#, c-format
-msgid "unable to unlink: %s"
-msgstr "no s'ha pogut desenllaçar: %s"
+#: help.c:37
+msgid "Low-level Commands / Syncing Repositories"
+msgstr "Ordres de baix nivell / Sincronització de dipòsits"
+
+#: help.c:38
+msgid "Low-level Commands / Internal Helpers"
+msgstr "Ordres de baix nivell / Ajudants interns"
 
-#: refs.c:706
+#: help.c:298
 #, c-format
-msgid "Could not open '%s' for writing"
-msgstr "No s'ha pogut obrir «%s» per a escriptura"
+msgid "available git commands in '%s'"
+msgstr "ordres de git disponibles en «%s»"
 
-#: refs.c:1850
-msgid "ref updates forbidden inside quarantine environment"
-msgstr "no està permès actualitzar les referències en un entorn de quarantena"
+#: help.c:305
+msgid "git commands available from elsewhere on your $PATH"
+msgstr "ordres de git disponibles d'altres llocs en el vostre $PATH"
 
-#: refs/files-backend.c:1189
-#, c-format
-msgid "could not remove reference %s"
-msgstr "no s'ha pogut eliminar la referència %s"
+#: help.c:314
+msgid "These are common Git commands used in various situations:"
+msgstr ""
+"Aquestes són ordres del Git habitualment usades en diverses situacions:"
 
-#: refs/files-backend.c:1203 refs/packed-backend.c:1528
-#: refs/packed-backend.c:1538
+#: help.c:363 git.c:98
 #, c-format
-msgid "could not delete reference %s: %s"
-msgstr "no s'ha pogut suprimir la referència %s: %s"
+msgid "unsupported command listing type '%s'"
+msgstr "tipus de llistat de l'ordre no compatible «%s»"
 
-#: refs/files-backend.c:1206 refs/packed-backend.c:1541
-#, c-format
-msgid "could not delete references: %s"
-msgstr "no s'han pogut suprimir les referències: %s"
+#: help.c:403
+msgid "The common Git guides are:"
+msgstr "Les guies de Git comunes són:"
 
-#: ref-filter.c:35 wt-status.c:1842
-msgid "gone"
-msgstr "no hi és"
+#: help.c:512
+msgid "See 'git help <command>' to read about a specific subcommand"
+msgstr "Vegeu «git help <ordre>» per llegir sobre un subordre específic"
 
-#: ref-filter.c:36
-#, c-format
-msgid "ahead %d"
-msgstr "davant per %d"
+#: help.c:517
+msgid "External commands"
+msgstr "Ordres externes"
 
-#: ref-filter.c:37
-#, c-format
-msgid "behind %d"
-msgstr "darrere per %d"
+#: help.c:532
+msgid "Command aliases"
+msgstr "Àlies d'ordres"
 
-#: ref-filter.c:38
+#: help.c:596
 #, c-format
-msgid "ahead %d, behind %d"
-msgstr "davant per %d, darrere per %d"
+msgid ""
+"'%s' appears to be a git command, but we were not\n"
+"able to execute it. Maybe git-%s is broken?"
+msgstr ""
+"«%s» sembla un ordre de git, però no hem pogut\n"
+"executar-la. Pot ser que git-%s estigui malmès?"
 
-#: ref-filter.c:107
-#, c-format
-msgid "expected format: %%(color:<color>)"
-msgstr "format esperat: %%(color:<color>)"
+#: help.c:655
+msgid "Uh oh. Your system reports no Git commands at all."
+msgstr "Ai. El vostre sistema no informa de cap ordre de Git."
 
-#: ref-filter.c:109
+#: help.c:677
 #, c-format
-msgid "unrecognized color: %%(color:%s)"
-msgstr "color no reconegut: %%(color:%s)"
+msgid "WARNING: You called a Git command named '%s', which does not exist."
+msgstr ""
+"ADVERTÈNCIA: Heu invocat un ordre de Git amb nom «%s», la qual no existeix."
 
-#: ref-filter.c:129
+#: help.c:682
 #, c-format
-msgid "Integer value expected refname:lstrip=%s"
-msgstr "valor enter esperat pel nom de referència:lstrip=%s"
+msgid "Continuing under the assumption that you meant '%s'."
+msgstr "El procés continuarà, pressuposant que volíeu dir «%s»."
 
-#: ref-filter.c:133
+#: help.c:687
 #, c-format
-msgid "Integer value expected refname:rstrip=%s"
-msgstr "valor enter esperat pel nom de referència:rstrip=%s"
+msgid "Continuing in %0.1f seconds, assuming that you meant '%s'."
+msgstr ""
+"El procés continuarà en %0.1f segons, pressuposant que volíeu dir «%s»."
 
-#: ref-filter.c:135
+#: help.c:695
 #, c-format
-msgid "unrecognized %%(%s) argument: %s"
-msgstr "paràmetre %%(%s) desconegut: %s"
+msgid "git: '%s' is not a git command. See 'git --help'."
+msgstr "git: «%s» no és un ordre de git. Vegeu «git --help»."
 
-#: ref-filter.c:184
-#, c-format
-msgid "%%(body) does not take arguments"
-msgstr "%%(body) no accepta paràmetres"
+#: help.c:699
+msgid ""
+"\n"
+"The most similar command is"
+msgid_plural ""
+"\n"
+"The most similar commands are"
+msgstr[0] ""
+"\n"
+"L'ordre més similar és"
+msgstr[1] ""
+"\n"
+"Les ordres més similars són"
 
-#: ref-filter.c:191
-#, c-format
-msgid "%%(subject) does not take arguments"
-msgstr "%%(subject) no accepta paràmetres"
+#: help.c:714
+msgid "git version [<options>]"
+msgstr "git version [<opcions>]"
 
-#: ref-filter.c:209
+#: help.c:783
 #, c-format
-msgid "unknown %%(trailers) argument: %s"
-msgstr "paràmetre %%(trailers) desconegut: %s"
+msgid "%s: %s - %s"
+msgstr "%s: %s - %s"
 
-#: ref-filter.c:232
-#, c-format
-msgid "positive value expected contents:lines=%s"
-msgstr "valor positiu esperat conté:lines=%s"
+#: help.c:787
+msgid ""
+"\n"
+"Did you mean this?"
+msgid_plural ""
+"\n"
+"Did you mean one of these?"
+msgstr[0] ""
+"\n"
+"Volíeu dir això?"
+msgstr[1] ""
+"\n"
+"Volíeu dir un d'aquests?"
 
-#: ref-filter.c:234
-#, c-format
-msgid "unrecognized %%(contents) argument: %s"
-msgstr "paràmetre %%(contents) no reconegut: %s"
+#: ident.c:349
+msgid ""
+"\n"
+"*** Please tell me who you are.\n"
+"\n"
+"Run\n"
+"\n"
+"  git config --global user.email \"you@example.com\"\n"
+"  git config --global user.name \"Your Name\"\n"
+"\n"
+"to set your account's default identity.\n"
+"Omit --global to set the identity only in this repository.\n"
+"\n"
+msgstr ""
+"\n"
+"*** Digueu-me qui sou.\n"
+"\n"
+"Executeu\n"
+"\n"
+"  git config --global user.email \"usuari@domini.com\"\n"
+"  git config --global user.name \"El vostre nom\"\n"
+"\n"
+"per a establir la identitat predeterminada del vostre compte.\n"
+"Ometeu --global per a establir la identitat només en aquest dipòsit.\n"
 
-#: ref-filter.c:247
-#, c-format
-msgid "positive value expected objectname:short=%s"
-msgstr "valor positiu esperat nom d'objecte:curt=%s"
+#: ident.c:379
+msgid "no email was given and auto-detection is disabled"
+msgstr ""
+"no s'ha proporcionat cap adreça electrònica i la detecció automàtica està "
+"inhabilitada"
 
-#: ref-filter.c:251
+#: ident.c:384
 #, c-format
-msgid "unrecognized %%(objectname) argument: %s"
-msgstr "paràmetre %%(objectname) no reconegut: %s"
+msgid "unable to auto-detect email address (got '%s')"
+msgstr ""
+"no s'ha pogut detectar automàticament una adreça electrònica vàlida (s'ha "
+"rebut «%s»)"
 
-#: ref-filter.c:278
-#, c-format
-msgid "expected format: %%(align:<width>,<position>)"
-msgstr "format esperat: %%(align:<amplada>,<posició>)"
+#: ident.c:401
+msgid "no name was given and auto-detection is disabled"
+msgstr ""
+"no s'ha proporcionat cap nom i la detecció automàtica està inhabilitada"
 
-#: ref-filter.c:290
+#: ident.c:407
 #, c-format
-msgid "unrecognized position:%s"
-msgstr "posició no reconeguda:%s"
+msgid "unable to auto-detect name (got '%s')"
+msgstr "no s'ha pogut detectar automàticament el nom (s'ha rebut «%s»)"
 
-#: ref-filter.c:294
+#: ident.c:415
 #, c-format
-msgid "unrecognized width:%s"
-msgstr "amplada no reconeguda:%s"
+msgid "empty ident name (for <%s>) not allowed"
+msgstr "nom d'identitat buit (per <%s>) no és permès"
 
-#: ref-filter.c:300
+#: ident.c:421
 #, c-format
-msgid "unrecognized %%(align) argument: %s"
-msgstr "paràmetre %%(align) no reconegut: %s"
+msgid "name consists only of disallowed characters: %s"
+msgstr "el nom conté només caràcters no permesos: %s"
 
-#: ref-filter.c:304
+#: ident.c:436 builtin/commit.c:631
 #, c-format
-msgid "positive width expected with the %%(align) atom"
-msgstr "amplada positiva esperada amb l'àtom %%(align)"
+msgid "invalid date format: %s"
+msgstr "format de data no vàlid: %s"
 
-#: ref-filter.c:319
+#: list-objects.c:127
 #, c-format
-msgid "unrecognized %%(if) argument: %s"
-msgstr "paràmetre %%(if) no reconegut: %s"
+msgid "entry '%s' in tree %s has tree mode, but is not a tree"
+msgstr "l'entrada «%s» a l'arbre %s té mode d'arbre, però no és un arbre"
 
-#: ref-filter.c:409
+#: list-objects.c:140
 #, c-format
-msgid "malformed field name: %.*s"
-msgstr "nom de camp mal format: %.*s"
+msgid "entry '%s' in tree %s has blob mode, but is not a blob"
+msgstr "l'entrada «%s» a l'arbre %s té mode blob, però no és un blob"
 
-#: ref-filter.c:435
+#: list-objects.c:375
 #, c-format
-msgid "unknown field name: %.*s"
-msgstr "nom de camp desconegut: %.*s"
+msgid "unable to load root tree for commit %s"
+msgstr "no s'ha pogut carregar l'arrel de l'arbre per la comissió %s"
 
-#: ref-filter.c:547
-#, c-format
-msgid "format: %%(if) atom used without a %%(then) atom"
-msgstr "format: s'ha usat l'àtom %%(if) sense un àtom %%(then)"
+#: list-objects-filter.c:492
+#, fuzzy, c-format
+msgid "unable to access sparse blob in '%s'"
+msgstr "no s'ha pogut accedir a «%s»"
 
-#: ref-filter.c:607
-#, c-format
-msgid "format: %%(then) atom used without an %%(if) atom"
-msgstr "format: s'ha usat l'àtom %%(then) sense un àtom %%(if)"
+#: list-objects-filter.c:495
+#, fuzzy, c-format
+msgid "unable to parse sparse filter data in %s"
+msgstr "no s'ha pogut llegir %s"
 
-#: ref-filter.c:609
-#, c-format
-msgid "format: %%(then) atom used more than once"
-msgstr "format: s'ha usat l'àtom %%(then) més d'un cop"
+#: list-objects-filter-options.c:58
+msgid "expected 'tree:<depth>'"
+msgstr "s'esperava «tree:<profunditat>»"
 
-#: ref-filter.c:611
-#, c-format
-msgid "format: %%(then) atom used after %%(else)"
-msgstr "format: s'ha usat l'àtom %%(then) després de %%(else)"
+#: list-objects-filter-options.c:73
+msgid "sparse:path filters support has been dropped"
+msgstr ""
 
-#: ref-filter.c:637
+#: list-objects-filter-options.c:86
 #, c-format
-msgid "format: %%(else) atom used without an %%(if) atom"
-msgstr "format: s'ha usat l'àtom %%(else) sense un àtom %%(if)"
+msgid "invalid filter-spec '%s'"
+msgstr "filtre d'especificació no vàlid: «%s»"
 
-#: ref-filter.c:639
+#: list-objects-filter-options.c:102
 #, c-format
-msgid "format: %%(else) atom used without a %%(then) atom"
-msgstr "format: s'ha usat l'àtom %%(else) sense un àtom %%(then)"
+msgid "must escape char in sub-filter-spec: '%c'"
+msgstr ""
 
-#: ref-filter.c:641
-#, c-format
-msgid "format: %%(else) atom used more than once"
-msgstr "format: s'ha usat l'àtom %%(else) més d'un cop"
+#: list-objects-filter-options.c:144
+msgid "expected something after combine:"
+msgstr ""
 
-#: ref-filter.c:654
-#, c-format
-msgid "format: %%(end) atom used without corresponding atom"
-msgstr "format: s'ha usat l'àtom %%(end) sense l'àtom corresponent"
-
-#: ref-filter.c:709
-#, c-format
-msgid "malformed format string %s"
-msgstr "cadena de format mal format %s"
+#: list-objects-filter-options.c:226
+msgid "multiple filter-specs cannot be combined"
+msgstr "no es poden combinar múltiples especificacions de filtratge"
 
-#: ref-filter.c:1313
+#: lockfile.c:151
 #, c-format
-msgid "(no branch, rebasing %s)"
-msgstr "(cap branca, s'està fent «rebase» %s)"
+msgid ""
+"Unable to create '%s.lock': %s.\n"
+"\n"
+"Another git process seems to be running in this repository, e.g.\n"
+"an editor opened by 'git commit'. Please make sure all processes\n"
+"are terminated then try again. If it still fails, a git process\n"
+"may have crashed in this repository earlier:\n"
+"remove the file manually to continue."
+msgstr ""
+"No s'ha pogut crear '%s.lock': %s.\n"
+"\n"
+"Sembla que un altre procés de git s'està executant en aquest\n"
+"dipòsit, per exemple, un editor obert per «git commit». \n"
+"Assegureu-vos que tots els processos s'hagin acabat i\n"
+"llavors proveu de nou. Si encara falla, pot ser que un procés de\n"
+"git ha tingut un error:\n"
+"elimineu el fitxer manualment per a continuar."
 
-#: ref-filter.c:1316
+#: lockfile.c:159
 #, c-format
-msgid "(no branch, bisect started on %s)"
-msgstr "(cap branca, bisecció començada en %s)"
+msgid "Unable to create '%s.lock': %s"
+msgstr "No s'ha pogut crear «%s.lock»: %s"
 
-#. TRANSLATORS: make sure this matches "HEAD
-#. detached at " in wt-status.c
-#.
-#: ref-filter.c:1324
-#, c-format
-msgid "(HEAD detached at %s)"
-msgstr "(HEAD separat a %s)"
+#: merge.c:41
+msgid "failed to read the cache"
+msgstr "s'ha produït un error en llegir la memòria cau"
 
-#. TRANSLATORS: make sure this matches "HEAD
-#. detached from " in wt-status.c
-#.
-#: ref-filter.c:1331
-#, c-format
-msgid "(HEAD detached from %s)"
-msgstr "(HEAD separat de %s)"
+#: merge.c:107 rerere.c:720 builtin/am.c:1874 builtin/am.c:1908
+#: builtin/checkout.c:539 builtin/checkout.c:798 builtin/clone.c:809
+#: builtin/stash.c:264
+msgid "unable to write new index file"
+msgstr "no s'ha pogut escriure un fitxer d'índex nou"
 
-#: ref-filter.c:1335
-msgid "(no branch)"
-msgstr "(cap branca)"
+#: merge-recursive.c:367
+msgid "(bad commit)\n"
+msgstr "(comissió errònia)\n"
 
-#: ref-filter.c:1364
+#: merge-recursive.c:390
 #, c-format
-msgid "missing object %s for %s"
-msgstr "manca l'objecte %s per a %s"
+msgid "add_cacheinfo failed for path '%s'; merge aborting."
+msgstr "addinfo_cache ha fallat per al camí «%s»; interrompent la fusió."
 
-#: ref-filter.c:1367
+#: merge-recursive.c:399
 #, c-format
-msgid "parse_object_buffer failed on %s for %s"
-msgstr "parse_object_buffer ha fallat en %s per a %s"
+msgid "add_cacheinfo failed to refresh for path '%s'; merge aborting."
+msgstr ""
+"addinfo_cache ha fallat al refrescar el camí «%s»; interrompent la fusió."
 
-#: ref-filter.c:1819
+#: merge-recursive.c:885
 #, c-format
-msgid "malformed object at '%s'"
-msgstr "objecte mal format a «%s»"
+msgid "failed to create path '%s'%s"
+msgstr "s'ha produït un error en crear el camí «%s»%s"
 
-#: ref-filter.c:1886
+#: merge-recursive.c:896
 #, c-format
-msgid "ignoring ref with broken name %s"
-msgstr "s'està ignorant la referència amb nom malmès %s"
+msgid "Removing %s to make room for subdirectory\n"
+msgstr "S'està eliminant %s per a fer espai per al subdirectori\n"
 
-#: ref-filter.c:1891
-#, c-format
-msgid "ignoring broken ref %s"
-msgstr "s'està ignorant la referència trencada %s"
+#: merge-recursive.c:910 merge-recursive.c:929
+msgid ": perhaps a D/F conflict?"
+msgstr ": potser un conflicte D/F?"
 
-#: ref-filter.c:2152
+#: merge-recursive.c:919
 #, c-format
-msgid "format: %%(end) atom missing"
-msgstr "format: manca l'àtom %%(end)"
+msgid "refusing to lose untracked file at '%s'"
+msgstr "s'està refusant perdre el fitxer no seguit a «%s»"
 
-#: ref-filter.c:2246
+#: merge-recursive.c:960 builtin/cat-file.c:41
 #, c-format
-msgid "malformed object name %s"
-msgstr "nom d'objecte %s mal format"
+msgid "cannot read object %s '%s'"
+msgstr "no es pot llegir l'objecte %s «%s»"
 
-#: remote.c:795
+#: merge-recursive.c:965
 #, c-format
-msgid "Cannot fetch both %s and %s to %s"
-msgstr "No es poden obtenir ambdós %s i %s a %s"
+msgid "blob expected for %s '%s'"
+msgstr "blob esperat per a %s «%s»"
 
-#: remote.c:799
+#: merge-recursive.c:990
 #, c-format
-msgid "%s usually tracks %s, not %s"
-msgstr "%s generalment segueix %s, no %s"
+msgid "failed to open '%s': %s"
+msgstr "s'ha produït un error en obrir «%s»: %s"
 
-#: remote.c:803
+#: merge-recursive.c:1001
 #, c-format
-msgid "%s tracks both %s and %s"
-msgstr "%s segueix ambdós %s i %s"
+msgid "failed to symlink '%s': %s"
+msgstr "s'ha produït un error en fer l'enllaç simbòlic «%s»: %s"
 
-#: remote.c:811
-msgid "Internal error"
-msgstr "Error intern"
+#: merge-recursive.c:1006
+#, c-format
+msgid "do not know what to do with %06o %s '%s'"
+msgstr "no se sap què fer amb %06o %s «%s»"
 
-#: remote.c:1726 remote.c:1828
-msgid "HEAD does not point to a branch"
-msgstr "HEAD no assenyala cap branca"
+#: merge-recursive.c:1199
+#, c-format
+msgid "Failed to merge submodule %s (not checked out)"
+msgstr "S'ha produït un error en fusionar el submòdul %s (no està agafat)"
 
-#: remote.c:1735
+#: merge-recursive.c:1206
 #, c-format
-msgid "no such branch: '%s'"
-msgstr "no hi ha tal branca: «%s»"
+msgid "Failed to merge submodule %s (commits not present)"
+msgstr "S'ha produït un error en fusionar el submòdul %s (no hi ha comissions)"
 
-#: remote.c:1738
+#: merge-recursive.c:1213
 #, c-format
-msgid "no upstream configured for branch '%s'"
-msgstr "cap font configurada per a la branca «%s»"
+msgid "Failed to merge submodule %s (commits don't follow merge-base)"
+msgstr ""
+"S'ha produït un error en fusionar el submòdul %s (les comissions no "
+"segueixen merge-base)"
 
-#: remote.c:1744
+#: merge-recursive.c:1221 merge-recursive.c:1233
 #, c-format
-msgid "upstream branch '%s' not stored as a remote-tracking branch"
-msgstr "la branca font «%s» no s'emmagatzema com a branca amb seguiment remot"
+msgid "Fast-forwarding submodule %s to the following commit:"
+msgstr "Avançament ràpid del submòdul %s a la següent comissió:"
 
-#: remote.c:1759
+#: merge-recursive.c:1224 merge-recursive.c:1236
 #, c-format
-msgid "push destination '%s' on remote '%s' has no local tracking branch"
-msgstr ""
-"el destí de pujada «%s» en el remot «%s» no té cap branca amb seguiment remot"
+msgid "Fast-forwarding submodule %s"
+msgstr "Avançament ràpid al submòdul %s"
 
-#: remote.c:1771
+#: merge-recursive.c:1259
 #, c-format
-msgid "branch '%s' has no remote for pushing"
-msgstr "la branca «%s» no té cap remot al qual pujar"
+msgid "Failed to merge submodule %s (merge following commits not found)"
+msgstr ""
 
-#: remote.c:1782
+#: merge-recursive.c:1263
 #, c-format
-msgid "push refspecs for '%s' do not include '%s'"
-msgstr "les especificacions de referència de «%s» no inclouen «%s»"
+msgid "Failed to merge submodule %s (not fast-forward)"
+msgstr ""
+"S'ha produït un error en fusionar el submòdul %s (sense avançament ràpid)"
 
-#: remote.c:1795
-msgid "push has no destination (push.default is 'nothing')"
-msgstr "push no té destí (push.default és 'nothing')"
+#: merge-recursive.c:1264
+msgid "Found a possible merge resolution for the submodule:\n"
+msgstr "S'ha trobat una possible resolució de fusió pel submòdul:\n"
 
-#: remote.c:1817
-msgid "cannot resolve 'simple' push to a single destination"
-msgstr "no es pot resoldre una pujada 'simple' a un sol destí"
+#: merge-recursive.c:1267
+#, c-format
+msgid ""
+"If this is correct simply add it to the index for example\n"
+"by using:\n"
+"\n"
+"  git update-index --cacheinfo 160000 %s \"%s\"\n"
+"\n"
+"which will accept this suggestion.\n"
+msgstr ""
 
-#: remote.c:2132
+#: merge-recursive.c:1276
 #, c-format
-msgid "Your branch is based on '%s', but the upstream is gone.\n"
-msgstr "La vostra branca està basada en «%s», però la font no hi és.\n"
+msgid "Failed to merge submodule %s (multiple merges found)"
+msgstr ""
+"S'ha produït un error en fusionar el submòdul %s (s'han trobat múltiples "
+"fusions)"
 
-#: remote.c:2136
-msgid "  (use \"git branch --unset-upstream\" to fixup)\n"
-msgstr "  (useu \"git branch --unset-upstream\" per a arreglar)\n"
+#: merge-recursive.c:1349
+msgid "Failed to execute internal merge"
+msgstr "S'ha produït un error en executar la fusió interna"
 
-#: remote.c:2139
+#: merge-recursive.c:1354
 #, c-format
-msgid "Your branch is up to date with '%s'.\n"
-msgstr "La vostra branca està al dia amb «%s».\n"
+msgid "Unable to add %s to database"
+msgstr "No s'ha pogut afegir %s a la base de dades"
 
-#: remote.c:2143
+#: merge-recursive.c:1386
 #, c-format
-msgid "Your branch and '%s' refer to different commits.\n"
-msgstr "La vostra branca i «%s» es refereixen a diferents comissions.\n"
+msgid "Auto-merging %s"
+msgstr "S'està autofusionant %s"
 
-#: remote.c:2146
+#: merge-recursive.c:1410
 #, c-format
-msgid "  (use \"%s\" for details)\n"
+msgid "Error: Refusing to lose untracked file at %s; writing to %s instead."
 msgstr ""
+"Error: s'està refusant perdre el fitxer no seguit a %s; en comptes s'ha "
+"escrit a %s."
 
-#: remote.c:2150
+#: merge-recursive.c:1482
 #, c-format
-msgid "Your branch is ahead of '%s' by %d commit.\n"
-msgid_plural "Your branch is ahead of '%s' by %d commits.\n"
-msgstr[0] "La vostra branca està davant de «%s» per %d comissió.\n"
-msgstr[1] "La vostra branca està davant de «%s» per %d comissions.\n"
-
-#: remote.c:2156
-msgid "  (use \"git push\" to publish your local commits)\n"
-msgstr "  (useu \"git push\" per a publicar les vostres comissions locals)\n"
+msgid ""
+"CONFLICT (%s/delete): %s deleted in %s and %s in %s. Version %s of %s left "
+"in tree."
+msgstr ""
+"CONFLICTE: (%s/supressió): %s suprimit en %s i %s en %s. La versió %s de %s "
+"s'ha deixat en l'arbre."
 
-#: remote.c:2159
+#: merge-recursive.c:1487
 #, c-format
-msgid "Your branch is behind '%s' by %d commit, and can be fast-forwarded.\n"
-msgid_plural ""
-"Your branch is behind '%s' by %d commits, and can be fast-forwarded.\n"
-msgstr[0] ""
-"La vostra branca està darrere de «%s» per %d comissió, i pot avançar-se "
-"ràpidament.\n"
-msgstr[1] ""
-"La vostra branca està darrere de «%s» per %d comissions, i pot avançar-se "
-"ràpidament.\n"
+msgid ""
+"CONFLICT (%s/delete): %s deleted in %s and %s to %s in %s. Version %s of %s "
+"left in tree."
+msgstr ""
+"CONFLICTE: (%s/supressió): %s suprimit en %s i %s a %s en %s. La versió %s "
+"de %s s'ha deixat en l'arbre."
 
-#: remote.c:2167
-msgid "  (use \"git pull\" to update your local branch)\n"
-msgstr " (useu \"git pull\" per a actualitzar la vostra branca local)\n"
+#: merge-recursive.c:1494
+#, c-format
+msgid ""
+"CONFLICT (%s/delete): %s deleted in %s and %s in %s. Version %s of %s left "
+"in tree at %s."
+msgstr ""
+"CONFLICTE: (%s/supressió): %s suprimit en %s i %s en %s. La versió %s de %s "
+"s'ha deixat en l'arbre a %s."
 
-#: remote.c:2170
+#: merge-recursive.c:1499
 #, c-format
 msgid ""
-"Your branch and '%s' have diverged,\n"
-"and have %d and %d different commit each, respectively.\n"
-msgid_plural ""
-"Your branch and '%s' have diverged,\n"
-"and have %d and %d different commits each, respectively.\n"
-msgstr[0] ""
-"La vostra branca i «%s» han divergit,\n"
-"i tenen %d i %d comissió distinta cada una, respectivament.\n"
-msgstr[1] ""
-"La vostra branca i «%s» han divergit,\n"
-"i tenen %d i %d comissions distintes cada una, respectivament.\n"
+"CONFLICT (%s/delete): %s deleted in %s and %s to %s in %s. Version %s of %s "
+"left in tree at %s."
+msgstr ""
+"CONFLICTE: (%s/supressió): %s suprimit en %s i %s a %s en %s. La versió %s "
+"de %s s'ha deixat en l'arbre a %s."
 
-#: remote.c:2180
-msgid "  (use \"git pull\" to merge the remote branch into yours)\n"
-msgstr "  (useu \"git pull\" per a fusionar la branca remota a la vostra)\n"
+#: merge-recursive.c:1534
+msgid "rename"
+msgstr "canvi de nom"
 
-#: revision.c:2277
-msgid "your current branch appears to be broken"
-msgstr "la vostra branca actual sembla malmesa"
+#: merge-recursive.c:1534
+msgid "renamed"
+msgstr "canviat de nom"
 
-#: revision.c:2280
+#: merge-recursive.c:1614 merge-recursive.c:2530 merge-recursive.c:3175
 #, c-format
-msgid "your current branch '%s' does not have any commits yet"
-msgstr "la branca actual «%s» encara no té cap comissió"
-
-#: revision.c:2477
-msgid "--first-parent is incompatible with --bisect"
-msgstr "--first-parent és incompatible amb --bisect"
-
-#: run-command.c:731
-msgid "open /dev/null failed"
-msgstr "s'ha produït un error en obrir /dev/null"
+msgid "Refusing to lose dirty file at %s"
+msgstr "S'està refusant a perdre el fitxer brut a %s"
 
-#: run-command.c:1274
+#: merge-recursive.c:1624
 #, c-format
-msgid ""
-"The '%s' hook was ignored because it's not set as executable.\n"
-"You can disable this warning with `git config advice.ignoredHook false`."
+msgid "Refusing to lose untracked file at %s, even though it's in the way."
 msgstr ""
+"S'està refusant perdre el fitxer no seguit a «%s», malgrat que està en mig "
+"de l'operació."
 
-#: send-pack.c:141
-msgid "unexpected flush packet while reading remote unpack status"
+#: merge-recursive.c:1682
+#, c-format
+msgid "CONFLICT (rename/add): Rename %s->%s in %s.  Added %s in %s"
 msgstr ""
-"paquet de neteja no esperat quan estava llegint l'estat del desempaquetament "
-"remot"
+"CONFLICTE (canvi de nom/afegiment): Canvi de nom %s->%s a %s.  S'ha afegit "
+"%s a %s"
 
-#: send-pack.c:143
+#: merge-recursive.c:1713
 #, c-format
-msgid "unable to parse remote unpack status: %s"
-msgstr "no s'ha pogut analitzar l'estat del desempaquetament remot: %s"
+msgid "%s is a directory in %s adding as %s instead"
+msgstr "%s és un directori en %s; s'està afegint com a %s en lloc d'això"
 
-#: send-pack.c:145
+#: merge-recursive.c:1718
 #, c-format
-msgid "remote unpack failed: %s"
-msgstr "s'ha produït un error en el desempaquetament remot: %s"
-
-#: send-pack.c:308
-msgid "failed to sign the push certificate"
-msgstr "s'ha produït un error en signar el certificat de pujada"
-
-#: send-pack.c:421
-msgid "the receiving end does not support --signed push"
-msgstr "el destí receptor no admet pujar --signed"
+msgid "Refusing to lose untracked file at %s; adding as %s instead"
+msgstr ""
+"s'està refusant perdre el fitxer no seguit a %s; en comptes, s'està afegint "
+"com a %s"
 
-#: send-pack.c:423
+#: merge-recursive.c:1737
+#, c-format
 msgid ""
-"not sending a push certificate since the receiving end does not support --"
-"signed push"
+"CONFLICT (rename/rename): Rename \"%s\"->\"%s\" in branch \"%s\" rename \"%s"
+"\"->\"%s\" in \"%s\"%s"
 msgstr ""
-"no s'està enviant una certificació de pujada perquè el destí receptor no "
-"admet pujar --signed"
+"CONFLICTE (canvi de nom/canvi de nom): Canvi de nom «%s»->«%s» en la branca "
+"«%s» canvi de nom «%s»->«%s» en «%s»%s"
 
-#: send-pack.c:435
-msgid "the receiving end does not support --atomic push"
-msgstr "el destí receptor no admet pujar --atomic"
-
-#: send-pack.c:440
-msgid "the receiving end does not support push options"
-msgstr "el destí receptor no admet opcions de pujada"
+#: merge-recursive.c:1742
+msgid " (left unresolved)"
+msgstr " (deixat sense resolució)"
 
-#: sequencer.c:158
+#: merge-recursive.c:1851
 #, c-format
-msgid "invalid commit message cleanup mode '%s'"
-msgstr "mode de neteja «%s» no vàlid en la comissió del missatge"
-
-#: sequencer.c:267
-msgid "revert"
-msgstr "revertir"
-
-#: sequencer.c:269
-msgid "cherry-pick"
-msgstr "cherry-pick"
-
-#: sequencer.c:271
-msgid "rebase -i"
-msgstr "rebase -i"
+msgid "CONFLICT (rename/rename): Rename %s->%s in %s. Rename %s->%s in %s"
+msgstr ""
+"CONFLICTE (canvi de nom/canvi de nom): Canvi de nom %s->%s en %s. Canvi de "
+"nom %s->%s en %s"
 
-#: sequencer.c:273
+#: merge-recursive.c:2114
 #, c-format
-msgid "Unknown action: %d"
-msgstr "Acció desconeguda: %d"
-
-#: sequencer.c:330
 msgid ""
-"after resolving the conflicts, mark the corrected paths\n"
-"with 'git add <paths>' or 'git rm <paths>'"
+"CONFLICT (directory rename split): Unclear where to place %s because "
+"directory %s was renamed to multiple other directories, with no destination "
+"getting a majority of the files."
 msgstr ""
-"després de resoldre els conflictes, marqueu els camins\n"
-"corregits amb 'git add <camins>' o 'git rm <camins>'"
 
-#: sequencer.c:333
+#: merge-recursive.c:2146
+#, c-format
 msgid ""
-"after resolving the conflicts, mark the corrected paths\n"
-"with 'git add <paths>' or 'git rm <paths>'\n"
-"and commit the result with 'git commit'"
+"CONFLICT (implicit dir rename): Existing file/dir at %s in the way of "
+"implicit directory rename(s) putting the following path(s) there: %s."
 msgstr ""
-"després de resoldre els conflictes, marqueu els camins\n"
-"corregits amb 'git add <camins>' o 'git rm <camins>'\n"
-"i cometeu el resultat amb 'git commit'"
 
-#: sequencer.c:346 sequencer.c:2245
+#: merge-recursive.c:2156
 #, c-format
-msgid "could not lock '%s'"
-msgstr "no s'ha pogut bloquejar «%s»"
+msgid ""
+"CONFLICT (implicit dir rename): Cannot map more than one path to %s; "
+"implicit directory renames tried to put these paths there: %s"
+msgstr ""
 
-#: sequencer.c:349 sequencer.c:2124 sequencer.c:2250 sequencer.c:2264
-#: sequencer.c:3246 sequencer.c:3310 wrapper.c:656
+#: merge-recursive.c:2248
 #, c-format
-msgid "could not write to '%s'"
-msgstr "no s'ha pogut escriure a «%s»"
+msgid ""
+"CONFLICT (rename/rename): Rename directory %s->%s in %s. Rename directory %s-"
+">%s in %s"
+msgstr ""
+"CONFLICTE (canvi de nom/canvi de nom): canvi de nom %s->%s en %s. Canvi de "
+"nom de directori %s->%s en %s"
 
-#: sequencer.c:353
+#: merge-recursive.c:2493
 #, c-format
-msgid "could not write eol to '%s'"
-msgstr "no s'ha pogut escriure el terminador de línia a «%s»"
+msgid ""
+"WARNING: Avoiding applying %s -> %s rename to %s, because %s itself was "
+"renamed."
+msgstr ""
+"AVÍS: S'està evitant aplicar el canvi de nom %s -> %s a %s, perquè %s ell "
+"mateix ja havia canviat de nom."
 
-#: sequencer.c:356 sequencer.c:2128 sequencer.c:2252
+#: merge-recursive.c:3019
 #, c-format
-msgid "failed to finalize '%s'"
-msgstr "s'ha produït un error en finalitzar «%s»"
+msgid "cannot read object %s"
+msgstr "no es pot llegir l'objecte %s"
 
-#: sequencer.c:379 sequencer.c:1340 sequencer.c:2148 builtin/am.c:259
-#: builtin/commit.c:722 builtin/merge.c:1047
+#: merge-recursive.c:3022
 #, c-format
-msgid "could not read '%s'"
-msgstr "no s'ha pogut llegir «%s»"
+msgid "object %s is not a blob"
+msgstr "l'objecte %s no és un blob"
 
-#: sequencer.c:405
-#, c-format
-msgid "your local changes would be overwritten by %s."
-msgstr "els vostres canvis locals se sobreescriurien per %s."
+#: merge-recursive.c:3086
+msgid "modify"
+msgstr "modificació"
 
-#: sequencer.c:409
-msgid "commit your changes or stash them to proceed."
-msgstr "cometeu els vostres canvis o feu un «stash» per a procedir."
+#: merge-recursive.c:3086
+msgid "modified"
+msgstr "modificat"
 
-#: sequencer.c:438
-#, c-format
-msgid "%s: fast-forward"
-msgstr "%s: avanç ràpid"
+#: merge-recursive.c:3098
+msgid "content"
+msgstr "contingut"
 
-#. TRANSLATORS: %s will be "revert", "cherry-pick" or
-#. "rebase -i".
-#.
-#: sequencer.c:526
+#: merge-recursive.c:3102
+msgid "add/add"
+msgstr "afegiment/afegiment"
+
+#: merge-recursive.c:3125
 #, c-format
-msgid "%s: Unable to write new index file"
-msgstr "%s: No s'ha pogut escriure un fitxer d'índex nou"
+msgid "Skipped %s (merged same as existing)"
+msgstr "S'ha omès %s (el fusionat és igual a l'existent)"
 
-#: sequencer.c:542
-msgid "could not resolve HEAD commit"
-msgstr "no s'ha pogut resoldre la comissió HEAD"
+#: merge-recursive.c:3147 git-submodule.sh:993
+msgid "submodule"
+msgstr "submòdul"
 
-#: sequencer.c:562
-msgid "unable to update cache tree"
-msgstr "no s'ha pogut actualitzar l'arbre cau"
+#: merge-recursive.c:3148
+#, c-format
+msgid "CONFLICT (%s): Merge conflict in %s"
+msgstr "CONFLICTE (%s): Conflicte de fusió en %s"
 
-#: sequencer.c:658
+#: merge-recursive.c:3178
+#, c-format
+msgid "Adding as %s instead"
+msgstr "S'està afegint com a %s en lloc d'això"
+
+#: merge-recursive.c:3261
 #, c-format
 msgid ""
-"you have staged changes in your working tree\n"
-"If these changes are meant to be squashed into the previous commit, run:\n"
-"\n"
-"  git commit --amend %s\n"
-"\n"
-"If they are meant to go into a new commit, run:\n"
-"\n"
-"  git commit %s\n"
-"\n"
-"In both cases, once you're done, continue with:\n"
-"\n"
-"  git rebase --continue\n"
+"Path updated: %s added in %s inside a directory that was renamed in %s; "
+"moving it to %s."
 msgstr ""
-"teniu canvis «staged» en el vostre arbre de treball\n"
-"Si aquests canvis estan pensats per fer «squash» a la comissió prèvia, "
-"executeu:\n"
-"\n"
-"  git commit --amend %s\n"
-"\n"
-"Si són per a formar una comissió nova, executeu:\n"
-"\n"
-"  git commit %s\n"
-"\n"
-"En ambdós casos, quan hàgiu terminat, continueu amb:\n"
-"\n"
-"  git rebase --continue\n"
-
-#: sequencer.c:915
-msgid "'prepare-commit-msg' hook failed"
-msgstr "el lligam «prepare-commit-msg» ha fallat"
 
-#: sequencer.c:922
+#: merge-recursive.c:3264
+#, c-format
 msgid ""
-"Your name and email address were configured automatically based\n"
-"on your username and hostname. Please check that they are accurate.\n"
-"You can suppress this message by setting them explicitly. Run the\n"
-"following command and follow the instructions in your editor to edit\n"
-"your configuration file:\n"
-"\n"
-"    git config --global --edit\n"
-"\n"
-"After doing this, you may fix the identity used for this commit with:\n"
-"\n"
-"    git commit --amend --reset-author\n"
+"CONFLICT (file location): %s added in %s inside a directory that was renamed "
+"in %s, suggesting it should perhaps be moved to %s."
 msgstr ""
-"S'han configurat el vostre nom i adreça electrònica\n"
-"automàticament basats en el vostre nom d'usuari i nom de màquina. \n"
-"Comproveu que siguin correctes. Podeu suprimir aquest\n"
-"missatge establint-los explícitament. Executeu l'ordre següent i\n"
-"seguiu les instruccions en el vostre editor per editar el vostre\n"
-"fitxer de configuració:\n"
-"\n"
-"    git config --global --edit\n"
-"Després de fer això, podeu arreglar la identitat usada per a aquesta\n"
-"comissió amb:\n"
-"\n"
-"    git commit --amend --reset-author\n"
 
-#: sequencer.c:935
+#: merge-recursive.c:3268
+#, c-format
 msgid ""
-"Your name and email address were configured automatically based\n"
-"on your username and hostname. Please check that they are accurate.\n"
-"You can suppress this message by setting them explicitly:\n"
-"\n"
-"    git config --global user.name \"Your Name\"\n"
-"    git config --global user.email you@example.com\n"
-"\n"
-"After doing this, you may fix the identity used for this commit with:\n"
-"\n"
-"    git commit --amend --reset-author\n"
+"Path updated: %s renamed to %s in %s, inside a directory that was renamed in "
+"%s; moving it to %s."
 msgstr ""
-"S'han configurat el vostre nom i adreça electrònica\n"
-"automàticament basats en el vostre nom d'usuari i nom de màquina. \n"
-"Comproveu que siguin correctes. Podeu suprimir aquest\n"
-"missatge establint-los explícitament:\n"
-"\n"
-"    git config --global user.name \"El Vostre Nom\"\n"
-"    git config --global user.email tu@example.com\n"
-"\n"
-"Després de fer això, podeu arreglar la identitat usada per a aquesta\n"
-"comissió amb:\n"
-"\n"
-"    git commit --amend --reset-author\n"
 
-#: sequencer.c:975
-msgid "couldn't look up newly created commit"
-msgstr "no s'ha pogut trobar la comissió novament creada"
+#: merge-recursive.c:3271
+#, c-format
+msgid ""
+"CONFLICT (file location): %s renamed to %s in %s, inside a directory that "
+"was renamed in %s, suggesting it should perhaps be moved to %s."
+msgstr ""
 
-#: sequencer.c:977
-msgid "could not parse newly created commit"
-msgstr "no s'ha pogut analitzar la comissió novament creada"
+#: merge-recursive.c:3385
+#, c-format
+msgid "Removing %s"
+msgstr "S'està eliminant %s"
 
-#: sequencer.c:1023
-msgid "unable to resolve HEAD after creating commit"
-msgstr "no s'ha pogut resoldre HEAD després de crear la comissió"
+#: merge-recursive.c:3408
+msgid "file/directory"
+msgstr "fitxer/directori"
 
-#: sequencer.c:1025
-msgid "detached HEAD"
-msgstr "HEAD separat"
+#: merge-recursive.c:3413
+msgid "directory/file"
+msgstr "directori/fitxer"
 
-#: sequencer.c:1029
-msgid " (root-commit)"
-msgstr " (comissió d'arrel)"
+#: merge-recursive.c:3420
+#, c-format
+msgid "CONFLICT (%s): There is a directory with name %s in %s. Adding %s as %s"
+msgstr ""
+"CONFLICTE (%s): Hi ha un directori amb nom %s en %s. S'està afegint %s com a "
+"%s"
 
-#: sequencer.c:1050
-msgid "could not parse HEAD"
-msgstr "no s'ha pogut analitzar HEAD"
+#: merge-recursive.c:3429
+#, c-format
+msgid "Adding %s"
+msgstr "S'està afegint %s"
 
-#: sequencer.c:1052
+#: merge-recursive.c:3438
 #, c-format
-msgid "HEAD %s is not a commit!"
-msgstr "HEAD %s no és una comissió!"
+msgid "CONFLICT (add/add): Merge conflict in %s"
+msgstr "CONFLICTE (afegiment/afegiment): Conflicte de fusió en %s"
 
-#: sequencer.c:1056 builtin/commit.c:1491
-msgid "could not parse HEAD commit"
-msgstr "no s'ha pogut analitzar la comissió HEAD"
+#: merge-recursive.c:3482
+msgid "Already up to date!"
+msgstr "Ja està al dia!"
 
-#: sequencer.c:1107 sequencer.c:1673
-msgid "unable to parse commit author"
-msgstr "no s'ha pogut analitzar l'autor de la comissió"
+#: merge-recursive.c:3491
+#, c-format
+msgid "merging of trees %s and %s failed"
+msgstr "la fusió dels arbres %s i %s ha fallat"
 
-#: sequencer.c:1117 builtin/am.c:1630 builtin/merge.c:643
-msgid "git write-tree failed to write a tree"
-msgstr "git write-tree ha fallat en escriure un arbre"
+#: merge-recursive.c:3595
+msgid "Merging:"
+msgstr "S'està fusionant:"
 
-#: sequencer.c:1134 sequencer.c:1186
+#: merge-recursive.c:3608
 #, c-format
-msgid "unable to read commit message from '%s'"
-msgstr "no s'ha pogut llegir el missatge de comissió des de «%s»"
+msgid "found %u common ancestor:"
+msgid_plural "found %u common ancestors:"
+msgstr[0] "s'ha trobat %u avantpassat en comú:"
+msgstr[1] "s'han trobat %u avantpassats en comú:"
 
-#: sequencer.c:1154 builtin/am.c:1650 builtin/commit.c:1594 builtin/merge.c:826
-#: builtin/merge.c:851
-msgid "failed to write commit object"
-msgstr "s'ha produït un error en escriure l'objecte de comissió"
+#: merge-recursive.c:3658
+msgid "merge returned no commit"
+msgstr "la fusió no ha retornat cap comissió"
 
-#: sequencer.c:1213
+#: merge-recursive.c:3717
 #, c-format
-msgid "could not parse commit %s"
-msgstr "no s'ha pogut analitzar la comissió %s"
+msgid ""
+"Your local changes to the following files would be overwritten by merge:\n"
+"  %s"
+msgstr ""
+"Els canvis locals als fitxers següents se sobreescriuran per la fusió:\n"
+"  %s"
 
-#: sequencer.c:1218
+#: merge-recursive.c:3814
 #, c-format
-msgid "could not parse parent commit %s"
-msgstr "no s'ha pogut analitzar la comissió pare %s"
+msgid "Could not parse object '%s'"
+msgstr "No s'ha pogut analitzar l'objecte «%s»"
 
-#: sequencer.c:1347
+#: merge-recursive.c:3832 builtin/merge.c:694 builtin/merge.c:874
+msgid "Unable to write index."
+msgstr "No s'ha pogut escriure l'índex."
+
+#: midx.c:68
 #, c-format
-msgid ""
-"unexpected 1st line of squash message:\n"
-"\n"
-"\t%.*s"
+msgid "multi-pack-index file %s is too small"
 msgstr ""
-"Primera línia del missatge de «squash» no esperada:\n"
-"\n"
-"\t%.*s"
 
-#: sequencer.c:1353
+#: midx.c:84
 #, c-format
-msgid ""
-"invalid 1st line of squash message:\n"
-"\n"
-"\t%.*s"
+msgid "multi-pack-index signature 0x%08x does not match signature 0x%08x"
 msgstr ""
-"Primera línia del missatge de «squash» no vàlida:\n"
-"\n"
-"\t%.*s"
 
-#: sequencer.c:1359 sequencer.c:1384
+#: midx.c:89
 #, c-format
-msgid "This is a combination of %d commits."
-msgstr "Això és una combinació de %d comissions."
+msgid "multi-pack-index version %d not recognized"
+msgstr ""
 
-#: sequencer.c:1368 sequencer.c:3265
-msgid "need a HEAD to fixup"
-msgstr "cal un HEAD per reparar-ho"
+#: midx.c:94
+#, fuzzy, c-format
+msgid "hash version %u does not match"
+msgstr "el camí «%s» no té la seva versió"
 
-#: sequencer.c:1370
-msgid "could not read HEAD"
-msgstr "no s'ha pogut llegir HEAD"
+#: midx.c:108
+msgid "invalid chunk offset (too large)"
+msgstr ""
 
-#: sequencer.c:1372
-msgid "could not read HEAD's commit message"
-msgstr "no s'ha pogut llegir el missatge de comissió de HEAD"
+#: midx.c:132
+msgid "terminating multi-pack-index chunk id appears earlier than expected"
+msgstr ""
 
-#: sequencer.c:1378
-#, c-format
-msgid "cannot write '%s'"
-msgstr "no es pot escriure «%s»"
+#: midx.c:145
+msgid "multi-pack-index missing required pack-name chunk"
+msgstr ""
 
-#: sequencer.c:1387 git-rebase--interactive.sh:452
-msgid "This is the 1st commit message:"
-msgstr "Aquest és el 1r missatge de comissió:"
+#: midx.c:147
+msgid "multi-pack-index missing required OID fanout chunk"
+msgstr ""
 
-#: sequencer.c:1395
-#, c-format
-msgid "could not read commit message of %s"
-msgstr "no s'ha pogut llegir el missatge de comissió: %s"
+#: midx.c:149
+msgid "multi-pack-index missing required OID lookup chunk"
+msgstr ""
 
-#: sequencer.c:1402
-#, c-format
-msgid "This is the commit message #%d:"
-msgstr "Aquest és el missatge de comissió #%d:"
+#: midx.c:151
+msgid "multi-pack-index missing required object offsets chunk"
+msgstr ""
 
-#: sequencer.c:1407
+#: midx.c:165
 #, c-format
-msgid "The commit message #%d will be skipped:"
-msgstr "El missatge de comissió núm. #%d s'ometrà:"
+msgid "multi-pack-index pack names out of order: '%s' before '%s'"
+msgstr ""
 
-#: sequencer.c:1412
+#: midx.c:210
 #, c-format
-msgid "unknown command: %d"
-msgstr "ordre desconeguda: %d"
+msgid "bad pack-int-id: %u (%u total packs)"
+msgstr ""
 
-#: sequencer.c:1479
-msgid "your index file is unmerged."
-msgstr "el vostre fitxer d'índex està sense fusionar."
+#: midx.c:260
+msgid "multi-pack-index stores a 64-bit offset, but off_t is too small"
+msgstr ""
 
-#: sequencer.c:1498
-#, c-format
-msgid "commit %s is a merge but no -m option was given."
-msgstr "la comissió %s és una fusió però no s'ha donat cap opció -m."
+#: midx.c:288
+msgid "error preparing packfile from multi-pack-index"
+msgstr ""
 
-#: sequencer.c:1506
-#, c-format
-msgid "commit %s does not have parent %d"
-msgstr "la comissió %s no té pare %d"
+#: midx.c:472
+#, fuzzy, c-format
+msgid "failed to add packfile '%s'"
+msgstr "s'ha produït un error en llegir el fitxer d'ordres «%s»"
 
-#: sequencer.c:1510
-#, c-format
-msgid "mainline was specified but commit %s is not a merge."
-msgstr ""
-"s'ha especificat la línia principal però la comissió %s no és una fusió."
+#: midx.c:478
+#, fuzzy, c-format
+msgid "failed to open pack-index '%s'"
+msgstr "s'ha produït un error en obrir «%s»"
 
-#: sequencer.c:1516
-#, c-format
-msgid "cannot get commit message for %s"
-msgstr "no es pot obtenir el missatge de comissió de %s"
+#: midx.c:538
+#, fuzzy, c-format
+msgid "failed to locate object %d in packfile"
+msgstr "s'ha produït un error en llegir l'objecte «%s»."
 
-#. TRANSLATORS: The first %s will be a "todo" command like
-#. "revert" or "pick", the second %s a SHA1.
-#: sequencer.c:1535
-#, c-format
-msgid "%s: cannot parse parent commit %s"
-msgstr "%s: no es pot analitzar la comissió pare %s"
+#: midx.c:842
+#, fuzzy
+msgid "Adding packfiles to multi-pack-index"
+msgstr "s'ha produït un error en netejar l'índex"
 
-#: sequencer.c:1600 sequencer.c:2397
+#: midx.c:875
 #, c-format
-msgid "could not rename '%s' to '%s'"
-msgstr "no s'ha pogut canviar el nom «%s» a «%s»"
+msgid "did not see pack-file %s to drop"
+msgstr ""
 
-#: sequencer.c:1654
-#, c-format
-msgid "could not revert %s... %s"
-msgstr "no s'ha pogut revertir %s... %s"
+#: midx.c:973
+msgid "Writing chunks to multi-pack-index"
+msgstr ""
 
-#: sequencer.c:1655
-#, c-format
-msgid "could not apply %s... %s"
-msgstr "no s'ha pogut aplicar %s... %s"
+#: midx.c:1052
+#, fuzzy, c-format
+msgid "failed to clear multi-pack-index at %s"
+msgstr "s'ha produït un error en netejar l'índex"
 
-#: sequencer.c:1702
-msgid "empty commit set passed"
-msgstr "conjunt de comissions buit passat"
+#: midx.c:1108
+msgid "Looking for referenced packfiles"
+msgstr "S'estan cercant fitxers de paquets referenciats"
 
-#: sequencer.c:1712
+#: midx.c:1123
 #, c-format
-msgid "git %s: failed to read the index"
-msgstr "git %s: s'ha produït un error en llegir l'índex"
+msgid ""
+"oid fanout out of order: fanout[%d] = %<PRIx32> > %<PRIx32> = fanout[%d]"
+msgstr ""
 
-#: sequencer.c:1718
-#, c-format
-msgid "git %s: failed to refresh the index"
-msgstr "git %s: s'ha produït un error en actualitzar l'índex"
+#: midx.c:1128
+msgid "Verifying OID order in multi-pack-index"
+msgstr ""
 
-#: sequencer.c:1792
+#: midx.c:1137
 #, c-format
-msgid "%s does not accept arguments: '%s'"
-msgstr "%s no accepta paràmetres: «%s»"
+msgid "oid lookup out of order: oid[%d] = %s >= %s = oid[%d]"
+msgstr ""
 
-#: sequencer.c:1801
-#, c-format
-msgid "missing arguments for %s"
-msgstr "falten els arguments per %s"
+#: midx.c:1157
+msgid "Sorting objects by packfile"
+msgstr "S'estan ordenant els objectes per fitxer de paquet"
 
-#: sequencer.c:1844
-#, c-format
-msgid "invalid line %d: %.*s"
-msgstr "línia no vàlida %d: %.*s"
+#: midx.c:1164
+msgid "Verifying object offsets"
+msgstr "S'estan verificant els desplaçaments dels objectes"
 
-#: sequencer.c:1852
-#, c-format
-msgid "cannot '%s' without a previous commit"
-msgstr "No es pot «%s» sense una comissió prèvia"
+#: midx.c:1180
+#, fuzzy, c-format
+msgid "failed to load pack entry for oid[%d] = %s"
+msgstr "no s'ha pogut afegir una entrada de cau per a %s"
+
+#: midx.c:1186
+#, fuzzy, c-format
+msgid "failed to load pack-index for packfile %s"
+msgstr "s'ha produït un error en llegir el fitxer d'ordres «%s»"
 
-#: sequencer.c:1883 sequencer.c:3056 sequencer.c:3091
+#: midx.c:1195
 #, c-format
-msgid "could not read '%s'."
-msgstr "no s'ha pogut llegir «%s»."
+msgid "incorrect object offset for oid[%d] = %s: %<PRIx64> != %<PRIx64>"
+msgstr ""
 
-#: sequencer.c:1906
-msgid "please fix this using 'git rebase --edit-todo'."
-msgstr "corregiu-ho usant «git rebase --edit-todo»."
+#: midx.c:1220
+msgid "Counting referenced objects"
+msgstr "S'estan comptant els objectes referenciats"
 
-#: sequencer.c:1908
-#, c-format
-msgid "unusable instruction sheet: '%s'"
-msgstr "full d'instruccions inusable: «%s»"
+#: midx.c:1230
+msgid "Finding and deleting unreferenced packfiles"
+msgstr "S'estan cercant i suprimint els fitxers de paquets no referenciats"
 
-#: sequencer.c:1913
-msgid "no commits parsed."
-msgstr "no s'ha analitzat cap comissió."
+#: midx.c:1388
+msgid "could not start pack-objects"
+msgstr "no s'ha pogut executar el pack-objects"
 
-#: sequencer.c:1924
-msgid "cannot cherry-pick during a revert."
-msgstr "no es pot fer «cherry pick» durant una reversió."
+#: midx.c:1407
+msgid "could not finish pack-objects"
+msgstr "no s'ha pogut finalitzar el pack-objects"
 
-#: sequencer.c:1926
-msgid "cannot revert during a cherry-pick."
-msgstr "no es pot revertir durant un «cherry pick»."
+#: name-hash.c:537
+#, fuzzy, c-format
+msgid "unable to create lazy_dir thread: %s"
+msgstr "no s'ha pogut crear fil: %s"
 
-#: sequencer.c:1993
-#, c-format
-msgid "invalid key: %s"
-msgstr "clau no vàlida: %s"
+#: name-hash.c:559
+#, fuzzy, c-format
+msgid "unable to create lazy_name thread: %s"
+msgstr "no s'ha pogut crear fil: %s"
 
-#: sequencer.c:1996
-#, c-format
-msgid "invalid value for %s: %s"
-msgstr "valor no vàlid per a %s: %s"
+#: name-hash.c:565
+#, fuzzy, c-format
+msgid "unable to join lazy_name thread: %s"
+msgstr "no s'ha pogut crear fil: %s"
 
-#: sequencer.c:2062
+#: notes-merge.c:277
 #, c-format
-msgid "malformed options sheet: '%s'"
-msgstr "full d'opcions mal format: «%s»"
+msgid ""
+"You have not concluded your previous notes merge (%s exists).\n"
+"Please, use 'git notes merge --commit' or 'git notes merge --abort' to "
+"commit/abort the previous merge before you start a new notes merge."
+msgstr ""
+"No heu acabat la vostra fusió de notes prèvia (%s existeix).\n"
+"Useu «git notes merge --commit» o «git notes merge --abort» per a cometre/"
+"avortar la fusió prèvia abans de començar una fusió de notes nova."
 
-#: sequencer.c:2100
-msgid "a cherry-pick or revert is already in progress"
-msgstr "un «cherry pick» o una reversió ja està en curs"
+#: notes-merge.c:284
+#, c-format
+msgid "You have not concluded your notes merge (%s exists)."
+msgstr "No heu conclòs la vostra fusió de notes (%s existeix)."
 
-#: sequencer.c:2101
-msgid "try \"git cherry-pick (--continue | --quit | --abort)\""
-msgstr "intenteu \"git cherry-pick (--continue | --quit | --abort)\""
+#: notes-utils.c:46
+msgid "Cannot commit uninitialized/unreferenced notes tree"
+msgstr "No es pot cometre un arbre de notes no inicialitzat / no referenciat"
 
-#: sequencer.c:2104
+#: notes-utils.c:105
 #, c-format
-msgid "could not create sequencer directory '%s'"
-msgstr "no s'ha pogut crear el directori de seqüenciador «%s»"
-
-#: sequencer.c:2118
-msgid "could not lock HEAD"
-msgstr "no s'ha pogut bloquejar HEAD"
+msgid "Bad notes.rewriteMode value: '%s'"
+msgstr "Valor de notes.rewriteMode erroni: «%s»"
 
-#: sequencer.c:2173 sequencer.c:2761
-msgid "no cherry-pick or revert in progress"
-msgstr "ni hi ha cap «cherry pick» ni cap reversió en curs"
+#: notes-utils.c:115
+#, c-format
+msgid "Refusing to rewrite notes in %s (outside of refs/notes/)"
+msgstr "S'està refusant reescriure les notes en %s (fora de refs/notes/)"
 
-#: sequencer.c:2175
-msgid "cannot resolve HEAD"
-msgstr "no es pot resoldre HEAD"
+#. TRANSLATORS: The first %s is the name of
+#. the environment variable, the second %s is
+#. its value.
+#.
+#: notes-utils.c:145
+#, c-format
+msgid "Bad %s value: '%s'"
+msgstr "Valor erroni de %s: «%s»"
 
-#: sequencer.c:2177 sequencer.c:2212
-msgid "cannot abort from a branch yet to be born"
-msgstr "no es pot avortar des d'una branca que encara ha de nàixer"
+#: object.c:53
+#, c-format
+msgid "invalid object type \"%s\""
+msgstr "tipus d'objecte «%s» no vàlid"
 
-#: sequencer.c:2198 builtin/grep.c:720
+#: object.c:173
 #, c-format
-msgid "cannot open '%s'"
-msgstr "no es pot obrir «%s»"
+msgid "object %s is a %s, not a %s"
+msgstr "l'objecte %s és %s, no pas %s"
 
-#: sequencer.c:2200
+#: object.c:233
 #, c-format
-msgid "cannot read '%s': %s"
-msgstr "no es pot llegir «%s»: %s"
+msgid "object %s has unknown type id %d"
+msgstr "l'objecte %s té un identificador de tipus %d desconegut"
 
-#: sequencer.c:2201
-msgid "unexpected end of file"
-msgstr "final de fitxer inesperat"
+#: object.c:246
+#, c-format
+msgid "unable to parse object: %s"
+msgstr "no s'ha pogut analitzar l'objecte: %s"
 
-#: sequencer.c:2207
+#: object.c:266 object.c:277
 #, c-format
-msgid "stored pre-cherry-pick HEAD file '%s' is corrupt"
-msgstr "el fitxer HEAD emmagatzemat abans de fer «cherry pick» «%s» és malmès"
+msgid "hash mismatch %s"
+msgstr ""
 
-#: sequencer.c:2218
-msgid "You seem to have moved HEAD. Not rewinding, check your HEAD!"
-msgstr "Sembla que heu mogut HEAD sense rebobinar, comproveu-ho HEAD"
+#: packfile.c:641
+msgid "offset before end of packfile (broken .idx?)"
+msgstr "desplaçament abans de la fi del fitxer de paquet (.idx trencat?)"
 
-#: sequencer.c:2324 sequencer.c:2679
+#: packfile.c:1888
 #, c-format
-msgid "could not update %s"
-msgstr "no s'ha pogut actualitzar %s"
+msgid "offset before start of pack index for %s (corrupt index?)"
+msgstr ""
+"desplaçament abans d'inici d'índex de paquet per a %s (índex corromput?)"
 
-#: sequencer.c:2362 sequencer.c:2659
-msgid "cannot read HEAD"
-msgstr "No es pot llegir HEAD"
+#: packfile.c:1892
+#, c-format
+msgid "offset beyond end of pack index for %s (truncated index?)"
+msgstr ""
+"desplaçament més enllà de la fi d'índex de paquet per a %s (índex truncat?)"
 
-#: sequencer.c:2402 builtin/difftool.c:639
+#: parse-options.c:38
 #, c-format
-msgid "could not copy '%s' to '%s'"
-msgstr "no s'ha pogut copiar «%s» a «%s»"
+msgid "%s requires a value"
+msgstr "%s requereix un valor"
 
-#: sequencer.c:2421
-msgid "could not read index"
-msgstr "no s'ha pogut llegir l'índex"
+#: parse-options.c:73
+#, c-format
+msgid "%s is incompatible with %s"
+msgstr "%s és incompatible amb %s"
 
-#: sequencer.c:2426
+#: parse-options.c:78
 #, c-format
-msgid ""
-"execution failed: %s\n"
-"%sYou can fix the problem, and then run\n"
-"\n"
-"  git rebase --continue\n"
-"\n"
-msgstr ""
-"ha fallat: %s\n"
-"%sPodeu solucionar el problema, i llavors executar\n"
-"\n"
-" git rebase --continue\n"
-"\n"
+msgid "%s : incompatible with something else"
+msgstr "%s: és incompatible amb alguna altra cosa"
 
-#: sequencer.c:2432
-msgid "and made changes to the index and/or the working tree\n"
-msgstr "i ha fet canvis a l'índex i/o l'arbre de treball\n"
+#: parse-options.c:92 parse-options.c:96 parse-options.c:319
+#, c-format
+msgid "%s takes no value"
+msgstr "%s no accepta cap valor"
 
-#: sequencer.c:2438
+#: parse-options.c:94
 #, c-format
-msgid ""
-"execution succeeded: %s\n"
-"but left changes to the index and/or the working tree\n"
-"Commit or stash your changes, and then run\n"
-"\n"
-"  git rebase --continue\n"
-"\n"
-msgstr ""
-"l'execució ha tingut èxit: %s\n"
-"però ha deixat canvis a l'índex i/o l'arbre de treball\n"
-"Cometeu o feu «stash» dels vostres canvis, i llavors executeu\n"
-"\n"
-" git rebase --continue\n"
+msgid "%s isn't available"
+msgstr "%s no és disponible"
 
-#: sequencer.c:2497
+#: parse-options.c:219
 #, c-format
-msgid "Applied autostash.\n"
-msgstr "S'ha aplicat el «stash» automàticament.\n"
+msgid "%s expects a non-negative integer value with an optional k/m/g suffix"
+msgstr ""
 
-#: sequencer.c:2509
+#: parse-options.c:389
 #, c-format
-msgid "cannot store %s"
-msgstr "no es pot emmagatzemar %s"
+msgid "ambiguous option: %s (could be --%s%s or --%s%s)"
+msgstr ""
 
-#: sequencer.c:2512 git-rebase.sh:178
+#: parse-options.c:423 parse-options.c:431
 #, c-format
-msgid ""
-"Applying autostash resulted in conflicts.\n"
-"Your changes are safe in the stash.\n"
-"You can run \"git stash pop\" or \"git stash drop\" at any time.\n"
+msgid "did you mean `--%s` (with two dashes ?)"
 msgstr ""
-"L'aplicació del «stash» automàtic ha resultat en conflictes.\n"
-"Els vostres canvis estan segurs en el «stash».\n"
-"Podeu executar \"git stash pop\" o \"git stash drop\" en qualsevol moment.\n"
 
-#: sequencer.c:2595
+#: parse-options.c:860
 #, c-format
-msgid "Stopped at %s...  %.*s\n"
-msgstr "Aturat a %s...  %.*s\n"
+msgid "unknown option `%s'"
+msgstr "opció desconeguda «%s»"
 
-#: sequencer.c:2637
+#: parse-options.c:862
 #, c-format
-msgid "unknown command %d"
-msgstr "ordre %d desconeguda"
+msgid "unknown switch `%c'"
+msgstr "«switch» «%c» desconegut"
 
-#: sequencer.c:2667
-msgid "could not read orig-head"
-msgstr "No s'ha pogut llegir orig-head"
+#: parse-options.c:864
+#, c-format
+msgid "unknown non-ascii option in string: `%s'"
+msgstr "opció no ascii desconeguda en la cadena: «%s»"
 
-#: sequencer.c:2672 sequencer.c:3262
-msgid "could not read 'onto'"
-msgstr "no s'ha pogut llegir 'onto'"
+#: parse-options.c:888
+msgid "..."
+msgstr "..."
 
-#: sequencer.c:2686
+#: parse-options.c:907
 #, c-format
-msgid "could not update HEAD to %s"
-msgstr "no s'ha pogut actualitzar HEAD a %s"
+msgid "usage: %s"
+msgstr "ús: %s"
 
-#: sequencer.c:2770
-msgid "cannot rebase: You have unstaged changes."
-msgstr "No es pot fer «rebase»: teniu canvis «unstaged»."
+#. TRANSLATORS: the colon here should align with the
+#. one in "usage: %s" translation.
+#.
+#: parse-options.c:913
+#, c-format
+msgid "   or: %s"
+msgstr " o: %s"
 
-#: sequencer.c:2775
-msgid "could not remove CHERRY_PICK_HEAD"
-msgstr "No s'ha pogut eliminar CHERRY_PICK_HEAD"
+#: parse-options.c:916
+#, c-format
+msgid "    %s"
+msgstr "    %s"
 
-#: sequencer.c:2784
-msgid "cannot amend non-existing commit"
-msgstr "no es pot esmenar una comissió no existent"
+#: parse-options.c:955
+msgid "-NUM"
+msgstr "-NUM"
 
-#: sequencer.c:2786
+#: parse-options.c:969
 #, c-format
-msgid "invalid file: '%s'"
-msgstr "fitxer no vàlid: «%s»"
+msgid "alias of --%s"
+msgstr "àlies de --%s"
 
-#: sequencer.c:2788
+#: parse-options-cb.c:20 parse-options-cb.c:24
 #, c-format
-msgid "invalid contents: '%s'"
-msgstr "contingut no vàlid: «%s»"
+msgid "option `%s' expects a numerical value"
+msgstr "l'opció «%s» espera un valor numèric"
 
-#: sequencer.c:2791
-msgid ""
-"\n"
-"You have uncommitted changes in your working tree. Please, commit them\n"
-"first and then run 'git rebase --continue' again."
-msgstr ""
-"\n"
-"Teniu canvis no comesos en el vostre arbre de treball. \n"
-"Primer cometeu-los i després executeu 'git rebase --continue' de nou."
+#: parse-options-cb.c:41
+#, c-format
+msgid "malformed expiration date '%s'"
+msgstr "data de venciment «%s» mal formada"
 
-#: sequencer.c:2801
-msgid "could not commit staged changes."
-msgstr "No s'han pogut cometre els canvis «staged»."
+#: parse-options-cb.c:54
+#, c-format
+msgid "option `%s' expects \"always\", \"auto\", or \"never\""
+msgstr "l'opció «%s» espera «always», «auto» o «never»"
 
-#: sequencer.c:2881
+#: parse-options-cb.c:130 parse-options-cb.c:147
 #, c-format
-msgid "%s: can't cherry-pick a %s"
-msgstr "%s: no es pot fer «cherry pick» a %s"
+msgid "malformed object name '%s'"
+msgstr "nom d'objecte «%s» mal format"
 
-#: sequencer.c:2885
+#: path.c:915
 #, c-format
-msgid "%s: bad revision"
-msgstr "%s: revisió incorrecta"
+msgid "Could not make %s writable by group"
+msgstr "No s'ha pogut fer %s escrivible pel grup"
 
-#: sequencer.c:2918
-msgid "can't revert as initial commit"
-msgstr "no es pot revertir com a comissió inicial"
+#: pathspec.c:130
+msgid "Escape character '\\' not allowed as last character in attr value"
+msgstr ""
+"El caràcter d'escapament «\\» no està permès com a últim caràcter en un "
+"valor d'un atribut"
 
-#: sequencer.c:3023
-msgid "make_script: unhandled options"
-msgstr "make_script: opcions no gestionades"
+#: pathspec.c:148
+msgid "Only one 'attr:' specification is allowed."
+msgstr "Només es permet una especificació «attr:»."
 
-#: sequencer.c:3026
-msgid "make_script: error preparing revisions"
-msgstr "make_script: s'ha produït un error en preparar les revisions"
+#: pathspec.c:151
+msgid "attr spec must not be empty"
+msgstr "una especificació d'atribut no pot estar buida"
 
-#: sequencer.c:3060 sequencer.c:3095
+#: pathspec.c:194
 #, c-format
-msgid "unusable todo list: '%s'"
-msgstr "llista per a fer inestable: «%s»"
+msgid "invalid attribute name %s"
+msgstr "nom d'atribut no vàlid %s"
 
-#: sequencer.c:3146
-#, c-format
-msgid ""
-"unrecognized setting %s for option rebase.missingCommitsCheck. Ignoring."
+#: pathspec.c:259
+msgid "global 'glob' and 'noglob' pathspec settings are incompatible"
 msgstr ""
-"No s'ha reconegut el paràmetre %s per rebase.missingCommitsCheck. S'està "
-"ignorant."
+"els paràmetres d'especificació de camí «glob» i «noglob» globals són "
+"incompatibles"
 
-#: sequencer.c:3212
-#, c-format
+#: pathspec.c:266
 msgid ""
-"Warning: some commits may have been dropped accidentally.\n"
-"Dropped commits (newer to older):\n"
+"global 'literal' pathspec setting is incompatible with all other global "
+"pathspec settings"
 msgstr ""
-"Advertència: pot ser que algunes comissions s'hagin descartat "
-"accidentalment.\n"
-"Les comissions descartades (més nova a més vella):\n"
+"el paràmetre d'especificació de camí «literal» global és incompatible amb "
+"tots els altres paràmetres d'especificació de camí globals"
 
-#: sequencer.c:3219
-#, c-format
-msgid ""
-"To avoid this message, use \"drop\" to explicitly remove a commit.\n"
-"\n"
-"Use 'git config rebase.missingCommitsCheck' to change the level of "
-"warnings.\n"
-"The possible behaviours are: ignore, warn, error.\n"
-"\n"
-msgstr ""
-"Per a evitar aquest missatge, useu \"drop\" per a eliminar explícitament una "
-"comissió.\n"
-"\n"
-"Useu 'git config rebase.missingCommitsCheck' per a canviar el nivell "
-"d'advertències.\n"
-"Els comportaments possibles són: ignore, warn, error.\n"
+#: pathspec.c:306
+msgid "invalid parameter for pathspec magic 'prefix'"
+msgstr "paràmetre no vàlid per a la màgia d'especificació de camí «prefix»"
 
-#: sequencer.c:3231
+#: pathspec.c:327
 #, c-format
-msgid ""
-"You can fix this with 'git rebase --edit-todo' and then run 'git rebase --"
-"continue'.\n"
-"Or you can abort the rebase with 'git rebase --abort'.\n"
-msgstr ""
-"Podeu arreglar això amb 'git rebase --edit-todo' i després 'git rebase --"
-"continue'.\n"
+msgid "Invalid pathspec magic '%.*s' in '%s'"
+msgstr "Màgia d'especificació de camí no vàlida '%.*s' en «%s»"
 
-#: sequencer.c:3244 sequencer.c:3304 wrapper.c:225 wrapper.c:395
-#: builtin/am.c:779
+#: pathspec.c:332
 #, c-format
-msgid "could not open '%s' for writing"
-msgstr "no s'ha pogut obrir «%s» per a escriptura"
+msgid "Missing ')' at the end of pathspec magic in '%s'"
+msgstr "«)» mancant al final de la màgia d'especificació de camí en «%s»"
 
-#: sequencer.c:3285
+#: pathspec.c:370
 #, c-format
-msgid "could not parse commit '%s'"
-msgstr "no s'ha pogut analitzar la comissió «%s»"
+msgid "Unimplemented pathspec magic '%c' in '%s'"
+msgstr "Màgia d'especificació de camí no implementada «%c» en «%s»"
 
-#: sequencer.c:3401
-msgid "the script was already rearranged."
-msgstr "l'script ja estava endreçat."
+#: pathspec.c:429
+#, c-format
+msgid "%s: 'literal' and 'glob' are incompatible"
+msgstr "%s: «literal» i «glob» són incompatibles"
 
-#: setup.c:122
+#: pathspec.c:442
 #, c-format
-msgid "'%s' is outside repository"
-msgstr "«%s» és fora del dipòsit"
+msgid "%s: '%s' is outside repository"
+msgstr "%s: «%s» és fora del dipòsit"
 
-#: setup.c:171
+#: pathspec.c:516
 #, c-format
-msgid ""
-"%s: no such path in the working tree.\n"
-"Use 'git <command> -- <path>...' to specify paths that do not exist locally."
-msgstr ""
-"%s: no hi ha tal camí en l'arbre de treball.\n"
-"Useu 'git <ordre> -- <camí>...' per a especificar camins que no existeixin "
-"localment."
+msgid "'%s' (mnemonic: '%c')"
+msgstr "«%s» (mnemònic: «%c»)"
 
-#: setup.c:184
+#: pathspec.c:526
 #, c-format
-msgid ""
-"ambiguous argument '%s': unknown revision or path not in the working tree.\n"
-"Use '--' to separate paths from revisions, like this:\n"
-"'git <command> [<revision>...] -- [<file>...]'"
+msgid "%s: pathspec magic not supported by this command: %s"
 msgstr ""
-"paràmetre ambigu «%s»: revisió no coneguda o camí no en l'arbre de treball.\n"
-"Useu '--' per a separar els camins de les revisions, com això:\n"
-"'git <ordre> [<revisió>...] -- [<fitxer>...]'"
+"%s: aquesta ordre no està admesa amb la màgia d'especificació de camí: %s"
 
-#: setup.c:233
+#: pathspec.c:593
 #, c-format
-msgid "option '%s' must come before non-option arguments"
-msgstr "l'opció «%s» ha de venir abans dels arguments opcionals"
+msgid "pathspec '%s' is beyond a symbolic link"
+msgstr "l'especificació de camí «%s» és més enllà d'un enllaç simbòlic"
 
-#: setup.c:252
+#: pathspec.c:638
 #, c-format
-msgid ""
-"ambiguous argument '%s': both revision and filename\n"
-"Use '--' to separate paths from revisions, like this:\n"
-"'git <command> [<revision>...] -- [<file>...]'"
+msgid "line is badly quoted: %s"
 msgstr ""
-"paràmetre ambigu «%s»: ambdós una revisió i un nom de fitxer\n"
-"Useu '--' per a separar els camins de les revisions, com això:\n"
-"'git <ordre> [<revisió>...] -- [<fitxer>...]'"
 
-#: setup.c:388
-msgid "unable to set up work tree using invalid config"
+#: pkt-line.c:92
+msgid "unable to write flush packet"
+msgstr "no s'ha pogut escriure el paquet de buidatge"
+
+#: pkt-line.c:99
+msgid "unable to write delim packet"
+msgstr "no s'ha pogut escriure el paquet delim"
+
+#: pkt-line.c:106
+msgid "flush packet write failed"
+msgstr "s'ha produït un error en escriure el paquet de buidatge"
+
+#: pkt-line.c:146 pkt-line.c:232
+msgid "protocol error: impossibly long line"
+msgstr "error de protocol: longitud de línia impossible"
+
+#: pkt-line.c:162 pkt-line.c:164
+msgid "packet write with format failed"
+msgstr "ha fallat l'escriptura del paquet amb format"
+
+#: pkt-line.c:196
+msgid "packet write failed - data exceeds max packet size"
 msgstr ""
-"no s'ha configurar un arbre de treball utilitzant una configuració no vàlida"
+"no s'ha pogut escriure el paquet - les dades excedeixen la mida màxima del "
+"paquet"
 
-#: setup.c:395
-msgid "this operation must be run in a work tree"
-msgstr "aquesta operació s'ha d'executar en un arbre de treball"
+#: pkt-line.c:203 pkt-line.c:210
+msgid "packet write failed"
+msgstr "no s'ha pogut escriure el paquet"
 
-#: setup.c:506
-#, c-format
-msgid "Expected git repo version <= %d, found %d"
-msgstr "S'esperava una versió de dipòsit de git <= %d, s'ha trobat %d"
+#: pkt-line.c:295
+msgid "read error"
+msgstr "error de lectura"
 
-#: setup.c:514
-msgid "unknown repository extensions found:"
-msgstr "s'han trobat extensions de dipòsit desconegudes:"
+#: pkt-line.c:303
+msgid "the remote end hung up unexpectedly"
+msgstr "el remot ha penjat inesperadament"
 
-#: setup.c:533
+#: pkt-line.c:331
 #, c-format
-msgid "error opening '%s'"
-msgstr "s'ha produït un error en obrir «%s»"
+msgid "protocol error: bad line length character: %.4s"
+msgstr "error de protocol: caràcter de longitud de línia erroni: %.4s"
 
-#: setup.c:535
+#: pkt-line.c:341 pkt-line.c:346
 #, c-format
-msgid "too large to be a .git file: '%s'"
-msgstr "massa larg per a ser un fitxer .git: «%s»"
+msgid "protocol error: bad line length %d"
+msgstr "error de protocol: longitud de línia errònia %d"
 
-#: setup.c:537
+#: pkt-line.c:362
 #, c-format
-msgid "error reading %s"
-msgstr "error en llegir %s"
+msgid "remote error: %s"
+msgstr "error remot: %s"
 
-#: setup.c:539
+#: preload-index.c:119
+msgid "Refreshing index"
+msgstr "S'està actualitzant l'índex"
+
+#: preload-index.c:138
+#, fuzzy, c-format
+msgid "unable to create threaded lstat: %s"
+msgstr "no s'ha pogut crear fil: %s"
+
+#: pretty.c:981
+msgid "unable to parse --pretty format"
+msgstr "no s'ha pogut analitzar el format --pretty"
+
+#: promisor-remote.c:23
+msgid "Remote with no URL"
+msgstr "Remot sense URL"
+
+#: promisor-remote.c:58
 #, c-format
-msgid "invalid gitfile format: %s"
-msgstr "format gitfile no vàlid: %s"
+msgid "promisor remote name cannot begin with '/': %s"
+msgstr ""
 
-#: setup.c:541
+#: range-diff.c:75
+msgid "could not start `log`"
+msgstr "no s'ha pogut iniciar «log»"
+
+#: range-diff.c:77
+msgid "could not read `log` output"
+msgstr "no s'ha pogut llegir la sortida de «log»"
+
+#: range-diff.c:96 sequencer.c:5163
 #, c-format
-msgid "no path in gitfile: %s"
-msgstr "sense camí al gitfile: %s"
+msgid "could not parse commit '%s'"
+msgstr "no s'ha pogut analitzar la comissió «%s»"
 
-#: setup.c:543
+#: range-diff.c:122
 #, c-format
-msgid "not a git repository: %s"
-msgstr "no és un dipòsit de git: %s"
+msgid "could not parse git header '%.*s'"
+msgstr "no s'ha pogut llegir la capçalera de la gif «%.*s»"
 
-#: setup.c:642
+#: range-diff.c:285
+msgid "failed to generate diff"
+msgstr "s'ha produït un error en generar el diff"
+
+#: range-diff.c:518 range-diff.c:520
 #, c-format
-msgid "'$%s' too big"
-msgstr "«$%s» massa gran"
+msgid "could not parse log for '%s'"
+msgstr "no s'ha pogut llegir el fitxer de registre per «%s»"
 
-#: setup.c:656
+#: read-cache.c:680
 #, c-format
-msgid "not a git repository: '%s'"
-msgstr "no és un dipòsit de git: «%s»"
+msgid "will not add file alias '%s' ('%s' already exists in index)"
+msgstr "no s'afegirà l'àlies «%s»: («%s» ja existeix en l'índex)"
+
+#: read-cache.c:696
+msgid "cannot create an empty blob in the object database"
+msgstr "no es pot crear un blob buit a la base de dades d'objectes"
 
-#: setup.c:685 setup.c:687 setup.c:718
+#: read-cache.c:718
 #, c-format
-msgid "cannot chdir to '%s'"
-msgstr "no es pot canviar de directori a «%s»"
+msgid "%s: can only add regular files, symbolic links or git-directories"
+msgstr ""
+"%s: només pot afegir fitxers normals, enllaços simbòlics o directoris git"
 
-#: setup.c:690 setup.c:746 setup.c:756 setup.c:795 setup.c:803 setup.c:818
-msgid "cannot come back to cwd"
-msgstr "no es pot tornar al directori de treball actual"
+#: read-cache.c:723
+#, fuzzy, c-format
+msgid "'%s' does not have a commit checked out"
+msgstr "«%s» no assenyala una comissió"
 
-#: setup.c:816
+#: read-cache.c:775
 #, c-format
-msgid "not a git repository (or any of the parent directories): %s"
-msgstr "no és un dipòsit de git (ni cap dels directoris pares): %s"
+msgid "unable to index file '%s'"
+msgstr "no es pot llegir indexar el fitxer «%s»"
 
-#: setup.c:827
+#: read-cache.c:794
 #, c-format
-msgid "failed to stat '%*s%s%s'"
-msgstr "s'ha produït un error en fer stat a «%*s%s%s»"
+msgid "unable to add '%s' to index"
+msgstr "no s'ha pogut afegir «%s» a l'índex"
 
-#: setup.c:1057
-msgid "Unable to read current working directory"
-msgstr "No s'ha pogut llegir el directori de treball actual"
+#: read-cache.c:805
+#, c-format
+msgid "unable to stat '%s'"
+msgstr "no s'ha pogut fer «stat» a «%s»"
 
-#: setup.c:1069 setup.c:1075
+#: read-cache.c:1325
 #, c-format
-msgid "cannot change to '%s'"
-msgstr "no es pot canviar a «%s»"
+msgid "'%s' appears as both a file and as a directory"
+msgstr "«%s» apareix com a fitxer i com a directori"
 
-#: setup.c:1088
+#: read-cache.c:1531
+msgid "Refresh index"
+msgstr "Actualitza l'índex"
+
+#: read-cache.c:1646
 #, c-format
 msgid ""
-"not a git repository (or any parent up to mount point %s)\n"
-"Stopping at filesystem boundary (GIT_DISCOVERY_ACROSS_FILESYSTEM not set)."
+"index.version set, but the value is invalid.\n"
+"Using version %i"
 msgstr ""
-"no un dipòsit de git (ni cap pare fins al punt de muntatge %s)\n"
-"S'atura a la frontera de sistema de fitxers (GIT_DISCOVERY_ACROSS_FILESYSTEM "
-"no està establert)."
+"index.version està establerta, però el valor no és vàlid.\n"
+"S'està usant la versió %i"
 
-#: setup.c:1172
+#: read-cache.c:1656
 #, c-format
 msgid ""
-"problem with core.sharedRepository filemode value (0%.3o).\n"
-"The owner of files must always have read and write permissions."
+"GIT_INDEX_VERSION set, but the value is invalid.\n"
+"Using version %i"
 msgstr ""
-"hi ha un problema amb el valor de mode de fitxer core.sharedRepository "
-"(0%.3o).\n"
-"El propietari dels fitxers sempre ha de tenir permisos de lectura i "
-"escriptura."
-
-#: setup.c:1215
-msgid "open /dev/null or dup failed"
-msgstr "s'ha produït un error en obrir /dev/null o dup"
-
-#: setup.c:1230
-msgid "fork failed"
-msgstr "el «fork» ha fallat"
-
-#: setup.c:1235
-msgid "setsid failed"
-msgstr "l'«stash» ha fallat"
+"GIT_INDEX_VERSION està establerta, però el valor no és vàlid.\n"
+"S'està usant la versió %i"
 
-#: sha1_file.c:592
+#: read-cache.c:1712
 #, c-format
-msgid "path '%s' does not exist"
-msgstr "el camí «%s» no existeix"
+msgid "bad signature 0x%08x"
+msgstr "signatura malmesa 0x%08x"
 
-#: sha1_file.c:618
+#: read-cache.c:1715
 #, c-format
-msgid "reference repository '%s' as a linked checkout is not supported yet."
-msgstr ""
-"Encara no se suporta el dipòsit de referència «%s» com a agafament enllaçat."
+msgid "bad index version %d"
+msgstr "versió d'índex incorrecta %d"
 
-#: sha1_file.c:624
-#, c-format
-msgid "reference repository '%s' is not a local repository."
-msgstr "el dipòsit de referència «%s» no és un dipòsit local."
+#: read-cache.c:1724
+msgid "bad index file sha1 signature"
+msgstr "signatura sha1 malmesa al fitxer d'índex"
 
-#: sha1_file.c:630
+#: read-cache.c:1754
 #, c-format
-msgid "reference repository '%s' is shallow"
-msgstr "el dipòsit de referència «%s» és superficial"
+msgid "index uses %.4s extension, which we do not understand"
+msgstr "l'índex usa l'extensió %.4s, que no es pot entendre"
 
-#: sha1_file.c:638
+#: read-cache.c:1756
 #, c-format
-msgid "reference repository '%s' is grafted"
-msgstr "el dipòsit de referència «%s» és empeltat"
+msgid "ignoring %.4s extension"
+msgstr "s'està ignorant l'extensió %.4s"
 
-#: sha1_name.c:422
+#: read-cache.c:1793
 #, c-format
-msgid "short SHA1 %s is ambiguous"
-msgstr "l'SHA1 %s curt és ambigu"
+msgid "unknown index entry format 0x%08x"
+msgstr "Format d'entrada d'índex desconeguda «0x%08x»"
 
-#: sha1_name.c:433
-msgid "The candidates are:"
-msgstr "Els candidats són:"
+#: read-cache.c:1809
+#, c-format
+msgid "malformed name field in the index, near path '%s'"
+msgstr "camp del nom mal formatat l'index, camí a prop «%s»"
 
-#: sha1_name.c:693
-msgid ""
-"Git normally never creates a ref that ends with 40 hex characters\n"
-"because it will be ignored when you just specify 40-hex. These refs\n"
-"may be created by mistake. For example,\n"
-"\n"
-"  git checkout -b $br $(git rev-parse ...)\n"
-"\n"
-"where \"$br\" is somehow empty and a 40-hex ref is created. Please\n"
-"examine these refs and maybe delete them. Turn this message off by\n"
-"running \"git config advice.objectNameWarning false\""
+#: read-cache.c:1866
+msgid "unordered stage entries in index"
 msgstr ""
-"Git normalment mai crea una referència que acabi amb 40 caràcters\n"
-"hexadecimals perquè s'ignorarà quan només especifiqueu 40 caràcters\n"
-"hexadecimals. Aquestes referències es poden crear per error. Per\n"
-"exemple,\n"
-"\n"
-"  git checkout -b $br $(git rev-parse ...)\n"
-"\n"
-"on «$br» és d'alguna manera buida i una referència de 40 caràcters\n"
-"hexadecimals. Examineu aquestes referències i potser\n"
-"suprimiu-les. Desactiveu aquest missatge executant\n"
-"«git config advice.objectNameWarning false»"
 
-#: submodule.c:96 submodule.c:130
-msgid "Cannot change unmerged .gitmodules, resolve merge conflicts first"
-msgstr ""
-"No es pot canviar un .gitmodules no fusionat, primer resoleu els conflictes "
-"de fusió"
+#: read-cache.c:1869
+#, fuzzy, c-format
+msgid "multiple stage entries for merged file '%s'"
+msgstr "nom d'identitat buit (per <%s>) no és permès"
 
-#: submodule.c:100 submodule.c:134
-#, c-format
-msgid "Could not find section in .gitmodules where path=%s"
-msgstr "No s'ha pogut trobar la secció en .gitmodules on path=%s"
+#: read-cache.c:1872
+#, fuzzy, c-format
+msgid "unordered stage entries for '%s'"
+msgstr "no s'han pogut crear directoris per %s"
 
-#: submodule.c:108
-#, c-format
-msgid "Could not update .gitmodules entry %s"
-msgstr "No s'ha pogut actualitzar l'entrada de .gitmodules %s"
+#: read-cache.c:1978 read-cache.c:2266 rerere.c:565 rerere.c:599 rerere.c:1111
+#: builtin/add.c:499 builtin/check-ignore.c:178 builtin/checkout.c:470
+#: builtin/checkout.c:654 builtin/clean.c:967 builtin/commit.c:367
+#: builtin/diff-tree.c:120 builtin/grep.c:499 builtin/mv.c:145
+#: builtin/reset.c:246 builtin/rm.c:271 builtin/submodule--helper.c:332
+msgid "index file corrupt"
+msgstr "fitxer d'índex malmès"
 
-#: submodule.c:141
-#, c-format
-msgid "Could not remove .gitmodules entry for %s"
-msgstr "No s'ha pogut eliminar l'entrada de .gitmodules per a %s"
+#: read-cache.c:2119
+#, fuzzy, c-format
+msgid "unable to create load_cache_entries thread: %s"
+msgstr "no s'ha pogut crear fil: %s"
 
-#: submodule.c:152
-msgid "staging updated .gitmodules failed"
-msgstr "l'allistament del .gitmodules actualitzat ha fallat"
+#: read-cache.c:2132
+#, fuzzy, c-format
+msgid "unable to join load_cache_entries thread: %s"
+msgstr "no s'ha pogut crear fil: %s"
 
-#: submodule.c:312
-#, c-format
-msgid "in unpopulated submodule '%s'"
-msgstr "al submòdul no populat «%s»"
+#: read-cache.c:2165
+#, fuzzy, c-format
+msgid "%s: index file open failed"
+msgstr "%s: s'ha produït un error en actualitzar els fitxers"
+
+#: read-cache.c:2169
+#, fuzzy, c-format
+msgid "%s: cannot stat the open index"
+msgstr "no es pot llegir l'índex"
 
-#: submodule.c:343
+#: read-cache.c:2173
 #, c-format
-msgid "Pathspec '%s' is in submodule '%.*s'"
-msgstr "L'especificació «%s» és en el submòdul «%.*s»"
+msgid "%s: index file smaller than expected"
+msgstr "%s: fitxer d'índex més petit que s'esperava"
 
-#: submodule.c:833
+#: read-cache.c:2177
 #, c-format
-msgid "submodule entry '%s' (%s) is a %s, not a commit"
-msgstr "l'entrada del submòdul «%s» (%s) és a %s, no és una comissió"
+msgid "%s: unable to map index file"
+msgstr "%s: no es pot mapar el fitxer d'índex"
 
-#: submodule.c:1065 builtin/branch.c:648 builtin/submodule--helper.c:1724
-msgid "Failed to resolve HEAD as a valid ref."
-msgstr "S'ha produït un error en resoldre HEAD com a referència vàlida."
+#: read-cache.c:2219
+#, fuzzy, c-format
+msgid "unable to create load_index_extensions thread: %s"
+msgstr "no s'ha pogut crear fil: %s"
 
-#: submodule.c:1370
-#, c-format
-msgid "'%s' not recognized as a git repository"
-msgstr "«%s» no reconegut com un dipòsit git"
+#: read-cache.c:2246
+#, fuzzy, c-format
+msgid "unable to join load_index_extensions thread: %s"
+msgstr "no s'ha pogut crear fil: %s"
 
-#: submodule.c:1508
+#: read-cache.c:2278
 #, c-format
-msgid "could not start 'git status' in submodule '%s'"
-msgstr "no s'ha pogut iniciar «git status» al submòdul «%s»"
+msgid "could not freshen shared index '%s'"
+msgstr "no s'ha pogut refrescar l'índex compartit «%s»"
 
-#: submodule.c:1521
+#: read-cache.c:2325
 #, c-format
-msgid "could not run 'git status' in submodule '%s'"
-msgstr "no s'ha pogut executar 'git status' al submòdul «%s»"
+msgid "broken index, expect %s in %s, got %s"
+msgstr "índex malmès, s'esperava %s a %s, s'ha rebut %s"
 
-#: submodule.c:1614
+#: read-cache.c:3021 strbuf.c:1145 wrapper.c:622 builtin/merge.c:1119
 #, c-format
-msgid "submodule '%s' has dirty index"
-msgstr "el submòdul «%s» té l'índex brut"
+msgid "could not close '%s'"
+msgstr "no s'ha pogut tancar «%s»"
 
-#: submodule.c:1878
+#: read-cache.c:3124 sequencer.c:2429 sequencer.c:4069
 #, c-format
-msgid ""
-"relocate_gitdir for submodule '%s' with more than one worktree not supported"
-msgstr ""
-"no està admès relocate_gitdir per al submòdul «%s» amb més d'un arbre de "
-"treball"
+msgid "could not stat '%s'"
+msgstr "no s'ha pogut fer stat a «%s»"
 
-#: submodule.c:1890 submodule.c:1946
+#: read-cache.c:3137
 #, c-format
-msgid "could not lookup name for submodule '%s'"
-msgstr "no s'ha trobat el nom pel submòdul «%s»"
+msgid "unable to open git dir: %s"
+msgstr "no s'ha pogut obrir el directori git: %s"
 
-#: submodule.c:1894 builtin/submodule--helper.c:1246
-#: builtin/submodule--helper.c:1256
+#: read-cache.c:3149
 #, c-format
-msgid "could not create directory '%s'"
-msgstr "no s'ha pogut crear el directori «%s»"
+msgid "unable to unlink: %s"
+msgstr "no s'ha pogut desenllaçar: %s"
+
+#: read-cache.c:3174
+#, fuzzy, c-format
+msgid "cannot fix permission bits on '%s'"
+msgstr "no s'ha pogut resoldre la revisió: %s"
+
+#: read-cache.c:3323
+#, fuzzy, c-format
+msgid "%s: cannot drop to stage #0"
+msgstr "no es pot canviar de directori a %s"
 
-#: submodule.c:1897
+#: rebase-interactive.c:26
 #, c-format
 msgid ""
-"Migrating git directory of '%s%s' from\n"
-"'%s' to\n"
-"'%s'\n"
+"unrecognized setting %s for option rebase.missingCommitsCheck. Ignoring."
 msgstr ""
-"S'està migrant el directori de «%s%s» des de\n"
-"«%s» a\n"
-"«%s»\n"
+"No s'ha reconegut el paràmetre %s per rebase.missingCommitsCheck. S'està "
+"ignorant."
 
-#: submodule.c:1981
-#, c-format
-msgid "could not recurse into submodule '%s'"
-msgstr "s'ha produït un error en cercar recursivament al camí de submòdul «%s»"
+#: rebase-interactive.c:35
+#, fuzzy
+msgid ""
+"\n"
+"Commands:\n"
+"p, pick <commit> = use commit\n"
+"r, reword <commit> = use commit, but edit the commit message\n"
+"e, edit <commit> = use commit, but stop for amending\n"
+"s, squash <commit> = use commit, but meld into previous commit\n"
+"f, fixup <commit> = like \"squash\", but discard this commit's log message\n"
+"x, exec <command> = run command (the rest of the line) using shell\n"
+"b, break = stop here (continue rebase later with 'git rebase --continue')\n"
+"d, drop <commit> = remove commit\n"
+"l, label <label> = label current HEAD with a name\n"
+"t, reset <label> = reset HEAD to a label\n"
+"m, merge [-C <commit> | -c <commit>] <label> [# <oneline>]\n"
+".       create a merge commit using the original merge commit's\n"
+".       message (or the oneline, if no original merge commit was\n"
+".       specified). Use -c <commit> to reword the commit message.\n"
+"\n"
+"These lines can be re-ordered; they are executed from top to bottom.\n"
+msgstr ""
+"\n"
+"Ordres:\n"
+" p, pick = usa la comissió\n"
+" r, reword = usa la comissió, però edita el missatge de comissió\n"
+" e, edit = usa la comissió, però atura't per a esmenar\n"
+" s, squash = usa la comissió, però fusiona'l a la comissió prèvia\n"
+" f, fixup = com \"squash\", però descarta el missatge de registre d'aquesta "
+"comissió\n"
+" x, exec = executa l'ordre (la resta de la línia) usant l'intèrpret "
+"d'ordres\n"
+" d, drop = elimina la comissió\n"
+"\n"
+"Es pot canviar l'ordre d'aquestes línies; s'executen de dalt a baix.\n"
 
-#: submodule.c:2025
-msgid "could not start ls-files in .."
-msgstr "no s'ha pogut iniciar ls-files a .."
+#: rebase-interactive.c:56
+#, fuzzy, c-format
+msgid "Rebase %s onto %s (%d command)"
+msgid_plural "Rebase %s onto %s (%d commands)"
+msgstr[0] "Rebasa $shortrevisions sobre $shortonto ($todocount ordre)"
+msgstr[1] "Rebasa $shortrevisions sobre $shortonto ($todocount ordres)"
+
+#: rebase-interactive.c:65 git-rebase--preserve-merges.sh:228
+msgid ""
+"\n"
+"Do not remove any line. Use 'drop' explicitly to remove a commit.\n"
+msgstr ""
+"\n"
+"No elimineu cap línia. Useu «drop» explícitament per a eliminar una "
+"comissió.\n"
 
-#: submodule.c:2045
-msgid "BUG: returned path string doesn't match cwd?"
-msgstr "ERRADA: la cadena del camí retornada no coincideix amb cwd?"
+#: rebase-interactive.c:68 git-rebase--preserve-merges.sh:232
+msgid ""
+"\n"
+"If you remove a line here THAT COMMIT WILL BE LOST.\n"
+msgstr ""
+"\n"
+"Si elimineu una línia aquí, ES PERDRÀ AQUELLA COMISSIÓ.\n"
 
-#: submodule.c:2064
-#, c-format
-msgid "ls-tree returned unexpected return code %d"
-msgstr "ls-tree ha retornat un codi de retorn %d no esperat"
+#: rebase-interactive.c:74 git-rebase--preserve-merges.sh:871
+msgid ""
+"\n"
+"You are editing the todo file of an ongoing interactive rebase.\n"
+"To continue rebase after editing, run:\n"
+"    git rebase --continue\n"
+"\n"
+msgstr ""
+"\n"
+"Esteu editant el fitxer de coses a fer d'un «rebase» interactiu en marxa.\n"
+"Per a continuar el «rebase» després d'editar, executeu:\n"
+"    git rebase --continue\n"
+"\n"
 
-#: submodule-config.c:263
-msgid "negative values not allowed for submodule.fetchjobs"
-msgstr "no es permeten els valors negatius a submodule.fetchjobs"
+#: rebase-interactive.c:79 git-rebase--preserve-merges.sh:948
+msgid ""
+"\n"
+"However, if you remove everything, the rebase will be aborted.\n"
+"\n"
+msgstr ""
+"\n"
+"No obstant, si elimineu tot, s'avortarà el «rebase».\n"
+"\n"
 
-#: submodule-config.c:436
-#, c-format
-msgid "invalid value for %s"
-msgstr "valor no vàlid per a %s"
+#: rebase-interactive.c:85 git-rebase--preserve-merges.sh:955
+msgid "Note that empty commits are commented out"
+msgstr "Tingueu en compte que les comissions buides estan comentades"
 
-#: trailer.c:238
+#: rebase-interactive.c:105 rerere.c:485 rerere.c:692 sequencer.c:3536
+#: sequencer.c:3562 sequencer.c:5263 builtin/fsck.c:346 builtin/rebase.c:254
 #, c-format
-msgid "running trailer command '%s' failed"
-msgstr "l'execució de l'ordre de remolc «%s» ha fallat"
+msgid "could not write '%s'"
+msgstr "no s'ha pogut escriure «%s»"
 
-#: trailer.c:485 trailer.c:490 trailer.c:495 trailer.c:549 trailer.c:553
-#: trailer.c:557
+#: rebase-interactive.c:108
 #, c-format
-msgid "unknown value '%s' for key '%s'"
-msgstr "valor desconegut «%s» per a la clau «%s»"
+msgid "could not copy '%s' to '%s'."
+msgstr "no s'ha pogut copiar «%s» a «%s»."
 
-#: trailer.c:539 trailer.c:544 builtin/remote.c:290
+#: rebase-interactive.c:173
 #, c-format
-msgid "more than one %s"
-msgstr "més d'un %s"
+msgid ""
+"Warning: some commits may have been dropped accidentally.\n"
+"Dropped commits (newer to older):\n"
+msgstr ""
+"Advertència: pot ser que algunes comissions s'hagin descartat "
+"accidentalment.\n"
+"Les comissions descartades (més nova a més vella):\n"
 
-#: trailer.c:730
+#: rebase-interactive.c:180
 #, c-format
-msgid "empty trailer token in trailer '%.*s'"
-msgstr "testimoni de remolc buit en el remolc '%.*s'"
+msgid ""
+"To avoid this message, use \"drop\" to explicitly remove a commit.\n"
+"\n"
+"Use 'git config rebase.missingCommitsCheck' to change the level of "
+"warnings.\n"
+"The possible behaviours are: ignore, warn, error.\n"
+"\n"
+msgstr ""
+"Per a evitar aquest missatge, useu \"drop\" per a eliminar explícitament una "
+"comissió.\n"
+"\n"
+"Useu 'git config rebase.missingCommitsCheck' per a canviar el nivell "
+"d'advertències.\n"
+"Els comportaments possibles són: ignore, warn, error.\n"
 
-#: trailer.c:750
+#: refs.c:262
 #, c-format
-msgid "could not read input file '%s'"
-msgstr "no s'ha pogut llegir el fitxer d'entrada «%s»"
+msgid "%s does not point to a valid object!"
+msgstr "%s no apunta a un objecte vàlid"
 
-#: trailer.c:753
-msgid "could not read from stdin"
-msgstr "no s'ha pogut llegir des de stdin"
+#: refs.c:667
+#, fuzzy, c-format
+msgid "ignoring dangling symref %s"
+msgstr "s'està ignorant la referència trencada %s"
 
-#: trailer.c:1008 builtin/am.c:46
+#: refs.c:669 ref-filter.c:2098
 #, c-format
-msgid "could not stat %s"
-msgstr "no s'ha pogut fer stat a %s"
+msgid "ignoring broken ref %s"
+msgstr "s'està ignorant la referència trencada %s"
 
-#: trailer.c:1010
+#: refs.c:804
 #, c-format
-msgid "file %s is not a regular file"
-msgstr "el fitxer %s no és un fitxer regular"
+msgid "could not open '%s' for writing: %s"
+msgstr "no s'ha pogut obrir «%s» per a escriptura: %s"
 
-#: trailer.c:1012
+#: refs.c:814 refs.c:865
 #, c-format
-msgid "file %s is not writable by user"
-msgstr "el fitxer %s no és gravable per l'usuari"
+msgid "could not read ref '%s'"
+msgstr "no s'ha pogut llegir la referència «%s»"
 
-#: trailer.c:1024
-msgid "could not open temporary file"
-msgstr "no s'ha pogut obrir el fitxer temporal"
+#: refs.c:820
+#, c-format
+msgid "ref '%s' already exists"
+msgstr "la referència «%s» ja existeix"
 
-#: trailer.c:1064
+#: refs.c:825
 #, c-format
-msgid "could not rename temporary file to %s"
-msgstr "no s'ha pogut canviar el nom del fitxer temporal a %s"
+msgid "unexpected object ID when writing '%s'"
+msgstr "ID d'objecte no esperat en escriure «%s»"
 
-#: transport.c:63
+#: refs.c:833 sequencer.c:405 sequencer.c:2793 sequencer.c:2997
+#: sequencer.c:3011 sequencer.c:3269 sequencer.c:5179 strbuf.c:1142
+#: wrapper.c:620
 #, c-format
-msgid "Would set upstream of '%s' to '%s' of '%s'\n"
-msgstr "Canviaria la font de «%s» a «%s» de «%s»\n"
+msgid "could not write to '%s'"
+msgstr "no s'ha pogut escriure a «%s»"
 
-#: transport.c:152
+#: refs.c:860 strbuf.c:1140 wrapper.c:188 wrapper.c:358 builtin/am.c:714
+#: builtin/rebase.c:1031
 #, c-format
-msgid "transport: invalid depth option '%s'"
-msgstr "transport: opció de profunditat no vàlida «%s»"
+msgid "could not open '%s' for writing"
+msgstr "no s'ha pogut obrir «%s» per a escriptura"
 
-#: transport.c:916
+#: refs.c:867
 #, c-format
-msgid ""
-"The following submodule paths contain changes that can\n"
-"not be found on any remote:\n"
+msgid "unexpected object ID when deleting '%s'"
+msgstr "ID d'objecte no esperat en suprimir «%s»"
+
+#: refs.c:998
+#, c-format
+msgid "log for ref %s has gap after %s"
 msgstr ""
-"Els camins de submòdul següents contenen canvis que no\n"
-"es poden trobar en cap remot:\n"
 
-#: transport.c:920
+#: refs.c:1004
 #, c-format
-msgid ""
-"\n"
-"Please try\n"
-"\n"
-"\tgit push --recurse-submodules=on-demand\n"
-"\n"
-"or cd to the path and use\n"
-"\n"
-"\tgit push\n"
-"\n"
-"to push them to a remote.\n"
-"\n"
+msgid "log for ref %s unexpectedly ended on %s"
 msgstr ""
-"\n"
-"Intenteu\n"
-"\n"
-"\tgit push --recurse-submodules=on-demand\n"
-"\n"
-"o canviar de directori al camí i useu\n"
-"\n"
-"\tgit push\n"
-"\n"
-"per a pujar-los a un remot.\n"
 
-#: transport.c:928
-msgid "Aborting."
-msgstr "S'està avortant."
+#: refs.c:1063
+#, c-format
+msgid "log for %s is empty"
+msgstr ""
 
-#: transport-helper.c:1079
+#: refs.c:1155
 #, c-format
-msgid "Could not read ref %s"
-msgstr "No s'ha pogut llegir la referència %s"
+msgid "refusing to update ref with bad name '%s'"
+msgstr "s'està refusant la referència amb nom malmès «%s»"
 
-#: tree-walk.c:31
-msgid "too-short tree object"
-msgstr "objecte d'arbre massa curt"
+#: refs.c:1231
+#, fuzzy, c-format
+msgid "update_ref failed for ref '%s': %s"
+msgstr "s'ha produït un error en obrir «%s»: %s"
 
-#: tree-walk.c:37
-msgid "malformed mode in tree entry"
-msgstr "mode mal format en entrada d'arbre"
+#: refs.c:2023
+#, fuzzy, c-format
+msgid "multiple updates for ref '%s' not allowed"
+msgstr "nom d'identitat buit (per <%s>) no és permès"
 
-#: tree-walk.c:41
-msgid "empty filename in tree entry"
-msgstr "nom de fitxer buit en una entrada d'arbre"
+#: refs.c:2055
+msgid "ref updates forbidden inside quarantine environment"
+msgstr "no està permès actualitzar les referències en un entorn de quarantena"
 
-#: tree-walk.c:114
-msgid "too-short tree file"
-msgstr "fitxer d'arbre massa curt"
+#: refs.c:2151 refs.c:2181
+#, c-format
+msgid "'%s' exists; cannot create '%s'"
+msgstr "«%s» existeix; no es pot crear «%s»"
 
-#: unpack-trees.c:108
+#: refs.c:2157 refs.c:2192
 #, c-format
-msgid ""
-"Your local changes to the following files would be overwritten by checkout:\n"
-"%%sPlease commit your changes or stash them before you switch branches."
-msgstr ""
-"Els vostres canvis locals als fitxers següents se sobreescriurien per "
-"agafar:\n"
-"%%sCometeu els vostres canvis o feu «stash» abans de canviar de branca."
+msgid "cannot process '%s' and '%s' at the same time"
+msgstr "no es poden processar «%s» i «%s» a la vegada"
 
-#: unpack-trees.c:110
+#: refs/files-backend.c:1234
 #, c-format
-msgid ""
-"Your local changes to the following files would be overwritten by checkout:\n"
-"%%s"
-msgstr ""
-"Els vostres canvis locals als fitxers següents se sobreescriurien per "
-"agafar:\n"
-"%%s"
+msgid "could not remove reference %s"
+msgstr "no s'ha pogut eliminar la referència %s"
 
-#: unpack-trees.c:113
+#: refs/files-backend.c:1248 refs/packed-backend.c:1541
+#: refs/packed-backend.c:1551
 #, c-format
-msgid ""
-"Your local changes to the following files would be overwritten by merge:\n"
-"%%sPlease commit your changes or stash them before you merge."
-msgstr ""
-"Els vostres canvis locals als fitxers següents se sobreescriurien per "
-"fusionar:\n"
-"%%sCometeu els vostres canvis o feu «stash» abans de fusionar."
+msgid "could not delete reference %s: %s"
+msgstr "no s'ha pogut suprimir la referència %s: %s"
 
-#: unpack-trees.c:115
+#: refs/files-backend.c:1251 refs/packed-backend.c:1554
 #, c-format
-msgid ""
-"Your local changes to the following files would be overwritten by merge:\n"
-"%%s"
-msgstr ""
-"Els vostres canvis locals als fitxers següents se sobreescriurien per "
-"fusionar:\n"
-"%%s"
+msgid "could not delete references: %s"
+msgstr "no s'han pogut suprimir les referències: %s"
 
-#: unpack-trees.c:118
+#: refspec.c:137
 #, c-format
-msgid ""
-"Your local changes to the following files would be overwritten by %s:\n"
-"%%sPlease commit your changes or stash them before you %s."
-msgstr ""
-"Els vostres canvis locals als fitxers següents se sobreescriurien per %s:\n"
-"%%sCometeu els vostres canvis o feu «stash» abans de %s."
+msgid "invalid refspec '%s'"
+msgstr "refspec no vàlida: «%s»"
 
-#: unpack-trees.c:120
-#, c-format
-msgid ""
-"Your local changes to the following files would be overwritten by %s:\n"
-"%%s"
-msgstr ""
-"Els vostres canvis locals als fitxers següents se sobreescriurien per %s:\n"
-"%%s"
+#: ref-filter.c:42 wt-status.c:1938
+msgid "gone"
+msgstr "no hi és"
 
-#: unpack-trees.c:125
+#: ref-filter.c:43
 #, c-format
-msgid ""
-"Updating the following directories would lose untracked files in them:\n"
-"%s"
-msgstr ""
-"En actualitzar els directoris següents perdria fitxers no seguits en el:\n"
-"%s"
+msgid "ahead %d"
+msgstr "davant per %d"
 
-#: unpack-trees.c:129
+#: ref-filter.c:44
 #, c-format
-msgid ""
-"The following untracked working tree files would be removed by checkout:\n"
-"%%sPlease move or remove them before you switch branches."
-msgstr ""
-"Els següents fitxers no seguits en l'arbre de treball s'eliminarien per "
-"agafar:\n"
-"%%sMoveu-los o elimineu-los abans de canviar de branca."
+msgid "behind %d"
+msgstr "darrere per %d"
 
-#: unpack-trees.c:131
+#: ref-filter.c:45
 #, c-format
-msgid ""
-"The following untracked working tree files would be removed by checkout:\n"
-"%%s"
-msgstr ""
-"Els següents fitxers no seguits en l'arbre de treball s'eliminarien per "
-"agafar:\n"
-"%%s"
+msgid "ahead %d, behind %d"
+msgstr "davant per %d, darrere per %d"
 
-#: unpack-trees.c:134
+#: ref-filter.c:165
 #, c-format
-msgid ""
-"The following untracked working tree files would be removed by merge:\n"
-"%%sPlease move or remove them before you merge."
-msgstr ""
-"Els següents fitxers no seguits en l'arbre de treball s'eliminarien per "
-"fusionar:\n"
-"%%sMoveu-los o elimineu-los abans de fusionar."
+msgid "expected format: %%(color:<color>)"
+msgstr "format esperat: %%(color:<color>)"
 
-#: unpack-trees.c:136
+#: ref-filter.c:167
 #, c-format
-msgid ""
-"The following untracked working tree files would be removed by merge:\n"
-"%%s"
-msgstr ""
-"Els següents fitxers no seguits en l'arbre de treball s'eliminarien per "
-"fusionar:\n"
-"%%s"
+msgid "unrecognized color: %%(color:%s)"
+msgstr "color no reconegut: %%(color:%s)"
 
-#: unpack-trees.c:139
+#: ref-filter.c:189
 #, c-format
-msgid ""
-"The following untracked working tree files would be removed by %s:\n"
-"%%sPlease move or remove them before you %s."
-msgstr ""
-"Els següents fitxers no seguits en l'arbre de treball s'eliminarien per %s:\n"
-"%%sMoveu-los o elimineu-los abans de %s."
+msgid "Integer value expected refname:lstrip=%s"
+msgstr "valor enter esperat pel nom de referència:lstrip=%s"
 
-#: unpack-trees.c:141
+#: ref-filter.c:193
 #, c-format
-msgid ""
-"The following untracked working tree files would be removed by %s:\n"
-"%%s"
-msgstr ""
-"Els següents fitxers no seguits en l'arbre de treball s'eliminarien per %s:\n"
-"%%s"
+msgid "Integer value expected refname:rstrip=%s"
+msgstr "valor enter esperat pel nom de referència:rstrip=%s"
 
-#: unpack-trees.c:146
+#: ref-filter.c:195
 #, c-format
-msgid ""
-"The following untracked working tree files would be overwritten by "
-"checkout:\n"
-"%%sPlease move or remove them before you switch branches."
-msgstr ""
-"Els següents fitxers no seguits en l'arbre de treball se sobreescriurien per "
-"agafar:\n"
-"%%sMoveu-los o elimineu-los abans de canviar de branca."
+msgid "unrecognized %%(%s) argument: %s"
+msgstr "paràmetre %%(%s) desconegut: %s"
 
-#: unpack-trees.c:148
+#: ref-filter.c:250
 #, c-format
-msgid ""
-"The following untracked working tree files would be overwritten by "
-"checkout:\n"
-"%%s"
-msgstr ""
-"Els següents fitxers no seguits en l'arbre de treball se sobreescriurien per "
-"agafar:\n"
-"%%s"
+msgid "%%(objecttype) does not take arguments"
+msgstr "%%(subject) no accepta paràmetres"
 
-#: unpack-trees.c:151
+#: ref-filter.c:272
 #, c-format
-msgid ""
-"The following untracked working tree files would be overwritten by merge:\n"
-"%%sPlease move or remove them before you merge."
-msgstr ""
-"Els següents fitxers no seguits en l'arbre de treball se sobreescriurien per "
-"fusionar:\n"
-"%%sMoveu-los o elimineu-los abans de fusionar."
+msgid "unrecognized %%(objectsize) argument: %s"
+msgstr "paràmetre %%(objectsize) no reconegut: %s"
 
-#: unpack-trees.c:153
+#: ref-filter.c:280
 #, c-format
-msgid ""
-"The following untracked working tree files would be overwritten by merge:\n"
-"%%s"
-msgstr ""
-"Els següents fitxers no seguits en l'arbre de treball se sobreescriurien per "
-"fusionar:\n"
-"%%s"
+msgid "%%(deltabase) does not take arguments"
+msgstr "%%(deltabase) no accepta paràmetres"
 
-#: unpack-trees.c:156
+#: ref-filter.c:292
 #, c-format
-msgid ""
-"The following untracked working tree files would be overwritten by %s:\n"
-"%%sPlease move or remove them before you %s."
-msgstr ""
-"Els següents fitxers no seguits en l'arbre de treball se sobreescriurien per "
-"%s:\n"
-"%%sMoveu-los o elimineu-los abans de %s."
+msgid "%%(body) does not take arguments"
+msgstr "%%(body) no accepta paràmetres"
 
-#: unpack-trees.c:158
+#: ref-filter.c:301
 #, c-format
-msgid ""
-"The following untracked working tree files would be overwritten by %s:\n"
-"%%s"
-msgstr ""
-"Els següents fitxers no seguits en l'arbre de treball se sobreescriurien per "
-"%s:\n"
-"%%s"
+msgid "%%(subject) does not take arguments"
+msgstr "%%(subject) no accepta paràmetres"
 
-#: unpack-trees.c:165
+#: ref-filter.c:323
 #, c-format
-msgid "Entry '%s' overlaps with '%s'.  Cannot bind."
-msgstr "L'entrada «%s» encavalca amb «%s».  No es pot vincular."
+msgid "unknown %%(trailers) argument: %s"
+msgstr "paràmetre %%(trailers) desconegut: %s"
 
-#: unpack-trees.c:168
+#: ref-filter.c:352
 #, c-format
-msgid ""
-"Cannot update sparse checkout: the following entries are not up to date:\n"
-"%s"
-msgstr ""
-"No es pot actualitzar l'agafament parcial: les entrades següents no estan al "
-"dia:\n"
-"%s"
+msgid "positive value expected contents:lines=%s"
+msgstr "valor positiu esperat conté:lines=%s"
 
-#: unpack-trees.c:170
+#: ref-filter.c:354
 #, c-format
-msgid ""
-"The following working tree files would be overwritten by sparse checkout "
-"update:\n"
-"%s"
-msgstr ""
-"Els fitxers següents en l'arbre de treball se sobreescriurien per "
-"actualitzar l'agafament parcial:\n"
-"%s"
+msgid "unrecognized %%(contents) argument: %s"
+msgstr "paràmetre %%(contents) no reconegut: %s"
 
-#: unpack-trees.c:172
+#: ref-filter.c:369
 #, c-format
-msgid ""
-"The following working tree files would be removed by sparse checkout "
-"update:\n"
-"%s"
-msgstr ""
-"Els fitxers següents en l'arbre de treball s'eliminarien per actualitzar "
-"l'agafament parcial:\n"
-"%s"
+msgid "positive value expected objectname:short=%s"
+msgstr "valor positiu esperat nom d'objecte:curt=%s"
 
-#: unpack-trees.c:174
+#: ref-filter.c:373
 #, c-format
-msgid ""
-"Cannot update submodule:\n"
-"%s"
-msgstr ""
-"No es pot actualitzar el submòdul:\n"
-"%s"
+msgid "unrecognized %%(objectname) argument: %s"
+msgstr "paràmetre %%(objectname) no reconegut: %s"
 
-#: unpack-trees.c:251
+#: ref-filter.c:403
 #, c-format
-msgid "Aborting\n"
-msgstr "S'està avortant\n"
-
-#: unpack-trees.c:333
-msgid "Checking out files"
-msgstr "S'estan agafant fitxers"
-
-#: urlmatch.c:163
-msgid "invalid URL scheme name or missing '://' suffix"
-msgstr "l'esquema d'URL no és vàlid o li manca el sufix '://'"
+msgid "expected format: %%(align:<width>,<position>)"
+msgstr "format esperat: %%(align:<amplada>,<posició>)"
 
-#: urlmatch.c:187 urlmatch.c:346 urlmatch.c:405
+#: ref-filter.c:415
 #, c-format
-msgid "invalid %XX escape sequence"
-msgstr "seqüència d'escapament %XX no vàlida"
-
-#: urlmatch.c:215
-msgid "missing host and scheme is not 'file:'"
-msgstr "manca la màquina i l'esquema no és 'file:'"
+msgid "unrecognized position:%s"
+msgstr "posició no reconeguda:%s"
 
-#: urlmatch.c:232
-msgid "a 'file:' URL may not have a port number"
-msgstr "un URL 'file:' no pot tenir número de port"
+#: ref-filter.c:422
+#, c-format
+msgid "unrecognized width:%s"
+msgstr "amplada no reconeguda:%s"
 
-#: urlmatch.c:247
-msgid "invalid characters in host name"
-msgstr "hi ha caràcters no vàlids en el nom de màquina"
+#: ref-filter.c:431
+#, c-format
+msgid "unrecognized %%(align) argument: %s"
+msgstr "paràmetre %%(align) no reconegut: %s"
 
-#: urlmatch.c:292 urlmatch.c:303
-msgid "invalid port number"
-msgstr "número de port no vàlid"
+#: ref-filter.c:439
+#, c-format
+msgid "positive width expected with the %%(align) atom"
+msgstr "amplada positiva esperada amb l'àtom %%(align)"
 
-#: urlmatch.c:371
-msgid "invalid '..' path segment"
-msgstr "segment de camí '..' no vàlid"
+#: ref-filter.c:457
+#, c-format
+msgid "unrecognized %%(if) argument: %s"
+msgstr "paràmetre %%(if) no reconegut: %s"
 
-#: worktree.c:245 builtin/am.c:2147
+#: ref-filter.c:559
 #, c-format
-msgid "failed to read '%s'"
-msgstr "s'ha produït un error en llegir «%s»"
+msgid "malformed field name: %.*s"
+msgstr "nom de camp mal format: %.*s"
 
-#: worktree.c:291
+#: ref-filter.c:586
 #, c-format
-msgid "'%s' at main working tree is not the repository directory"
-msgstr ""
+msgid "unknown field name: %.*s"
+msgstr "nom de camp desconegut: %.*s"
 
-#: worktree.c:302
+#: ref-filter.c:590
 #, c-format
-msgid "'%s' file does not contain absolute path to the working tree location"
+msgid ""
+"not a git repository, but the field '%.*s' requires access to object data"
 msgstr ""
 
-#: worktree.c:314
+#: ref-filter.c:714
 #, c-format
-msgid "'%s' does not exist"
-msgstr "«%s» no existeix"
+msgid "format: %%(if) atom used without a %%(then) atom"
+msgstr "format: s'ha usat l'àtom %%(if) sense un àtom %%(then)"
 
-#: worktree.c:320
+#: ref-filter.c:777
 #, c-format
-msgid "'%s' is not a .git file, error code %d"
-msgstr "«%s» no és un fitxer .git, codi d'error %d"
+msgid "format: %%(then) atom used without an %%(if) atom"
+msgstr "format: s'ha usat l'àtom %%(then) sense un àtom %%(if)"
 
-#: worktree.c:328
+#: ref-filter.c:779
 #, c-format
-msgid "'%s' does not point back to '%s'"
-msgstr "«%s» no assenyala de tornada a «%s»"
+msgid "format: %%(then) atom used more than once"
+msgstr "format: s'ha usat l'àtom %%(then) més d'un cop"
 
-#: wrapper.c:223 wrapper.c:393
+#: ref-filter.c:781
 #, c-format
-msgid "could not open '%s' for reading and writing"
-msgstr "no s'ha pogut obrir «%s» per a lectura i escriptura"
+msgid "format: %%(then) atom used after %%(else)"
+msgstr "format: s'ha usat l'àtom %%(then) després de %%(else)"
 
-#: wrapper.c:227 wrapper.c:397 builtin/am.c:320 builtin/am.c:770
-#: builtin/am.c:862 builtin/merge.c:1044
+#: ref-filter.c:809
 #, c-format
-msgid "could not open '%s' for reading"
-msgstr "no s'ha pogut obrir «%s» per a lectura"
+msgid "format: %%(else) atom used without an %%(if) atom"
+msgstr "format: s'ha usat l'àtom %%(else) sense un àtom %%(if)"
 
-#: wrapper.c:424 wrapper.c:624
+#: ref-filter.c:811
 #, c-format
-msgid "unable to access '%s'"
-msgstr "no s'ha pogut accedir a «%s»"
+msgid "format: %%(else) atom used without a %%(then) atom"
+msgstr "format: s'ha usat l'àtom %%(else) sense un àtom %%(then)"
 
-#: wrapper.c:632
-msgid "unable to get current working directory"
-msgstr "no s'ha pogut obtenir el directori de treball actual"
+#: ref-filter.c:813
+#, c-format
+msgid "format: %%(else) atom used more than once"
+msgstr "format: s'ha usat l'àtom %%(else) més d'un cop"
 
-#: wt-status.c:151
-msgid "Unmerged paths:"
-msgstr "Camins sense fusionar:"
+#: ref-filter.c:828
+#, c-format
+msgid "format: %%(end) atom used without corresponding atom"
+msgstr "format: s'ha usat l'àtom %%(end) sense l'àtom corresponent"
 
-#: wt-status.c:178 wt-status.c:205
+#: ref-filter.c:885
 #, c-format
-msgid "  (use \"git reset %s <file>...\" to unstage)"
-msgstr "  (useu \"git reset %s <fitxer>...\" per a fer «unstage»)"
-
-#: wt-status.c:180 wt-status.c:207
-msgid "  (use \"git rm --cached <file>...\" to unstage)"
-msgstr "  (useu \"git rm --cached <fitxer>...\" per a fer «unstage»)"
-
-#: wt-status.c:184
-msgid "  (use \"git add <file>...\" to mark resolution)"
-msgstr "  (useu \"git add <fitxer>...\" per a senyalar resolució)"
-
-#: wt-status.c:186 wt-status.c:190
-msgid "  (use \"git add/rm <file>...\" as appropriate to mark resolution)"
-msgstr ""
-"  (useu \"git add/rm <fitxer>...\" segons sigui apropiat per a senyalar "
-"resolució)"
-
-#: wt-status.c:188
-msgid "  (use \"git rm <file>...\" to mark resolution)"
-msgstr "  (useu \"git rm <fitxer>...\" per a senyalar resolució)"
-
-#: wt-status.c:199 wt-status.c:1007
-msgid "Changes to be committed:"
-msgstr "Canvis a cometre:"
+msgid "malformed format string %s"
+msgstr "cadena de format mal format %s"
 
-#: wt-status.c:217 wt-status.c:1016
-msgid "Changes not staged for commit:"
-msgstr "Canvis no «staged» per a cometre:"
+#: ref-filter.c:1488
+#, c-format
+msgid "no branch, rebasing %s"
+msgstr "sense branca, s'està fent «rebase» %s"
 
-#: wt-status.c:221
-msgid "  (use \"git add <file>...\" to update what will be committed)"
-msgstr "  (useu \"git add <fitxer>...\" per a actualitzar què es cometrà)"
+#: ref-filter.c:1491
+#, c-format
+msgid "no branch, rebasing detached HEAD %s"
+msgstr "sense branca, s'està fent «rebase» d'un «HEAD» %s no adjuntat"
 
-#: wt-status.c:223
-msgid "  (use \"git add/rm <file>...\" to update what will be committed)"
-msgstr "  (useu \"git add/rm <fitxer>...\" per a actualitzar què es cometrà)"
+#: ref-filter.c:1494
+#, c-format
+msgid "no branch, bisect started on %s"
+msgstr "(sense branca, bisecció començada en %s)"
 
-#: wt-status.c:224
-msgid ""
-"  (use \"git checkout -- <file>...\" to discard changes in working directory)"
-msgstr ""
-"  (useu \"git checkout -- <fitxer>...\" per a descartar els canvis en el "
-"directori de treball)"
+#: ref-filter.c:1504
+msgid "no branch"
+msgstr "sense branca"
 
-#: wt-status.c:226
-msgid "  (commit or discard the untracked or modified content in submodules)"
-msgstr ""
-"  (cometeu o descarteu el contingut modificat o no seguit en els submòduls)"
+#: ref-filter.c:1540 ref-filter.c:1749
+#, c-format
+msgid "missing object %s for %s"
+msgstr "manca l'objecte %s per a %s"
 
-#: wt-status.c:238
+#: ref-filter.c:1550
 #, c-format
-msgid "  (use \"git %s <file>...\" to include in what will be committed)"
-msgstr ""
-"  (useu \"git %s <fitxer>...\" per a incloure-ho en el qual es cometrà)"
+msgid "parse_object_buffer failed on %s for %s"
+msgstr "parse_object_buffer ha fallat en %s per a %s"
 
-#: wt-status.c:253
-msgid "both deleted:"
-msgstr "suprimit per ambdós:"
+#: ref-filter.c:2004
+#, c-format
+msgid "malformed object at '%s'"
+msgstr "objecte mal format a «%s»"
 
-#: wt-status.c:255
-msgid "added by us:"
-msgstr "afegit per nosaltres:"
+#: ref-filter.c:2093
+#, c-format
+msgid "ignoring ref with broken name %s"
+msgstr "s'està ignorant la referència amb nom malmès %s"
 
-#: wt-status.c:257
-msgid "deleted by them:"
-msgstr "suprimit per ells:"
+#: ref-filter.c:2389
+#, c-format
+msgid "format: %%(end) atom missing"
+msgstr "format: manca l'àtom %%(end)"
 
-#: wt-status.c:259
-msgid "added by them:"
-msgstr "afegit per ells:"
+#: ref-filter.c:2489
+#, c-format
+msgid "option `%s' is incompatible with --merged"
+msgstr "l'opció «%s» és incompatible amb --merged"
 
-#: wt-status.c:261
-msgid "deleted by us:"
-msgstr "suprimit per nosaltres:"
+#: ref-filter.c:2492
+#, c-format
+msgid "option `%s' is incompatible with --no-merged"
+msgstr "l'opció «%s» és incompatible amb --no-merged"
 
-#: wt-status.c:263
-msgid "both added:"
-msgstr "afegit per ambdós:"
+#: ref-filter.c:2502
+#, c-format
+msgid "malformed object name %s"
+msgstr "nom d'objecte %s mal format"
 
-#: wt-status.c:265
-msgid "both modified:"
-msgstr "modificat per ambdós:"
+#: ref-filter.c:2507
+#, c-format
+msgid "option `%s' must point to a commit"
+msgstr "l'opció «%s» ha d'apuntar a una comissió"
 
-#: wt-status.c:275
-msgid "new file:"
-msgstr "fitxer nou:"
+#: remote.c:366
+#, c-format
+msgid "config remote shorthand cannot begin with '/': %s"
+msgstr ""
 
-#: wt-status.c:277
-msgid "copied:"
-msgstr "copiat:"
+#: remote.c:413
+msgid "more than one receivepack given, using the first"
+msgstr ""
 
-#: wt-status.c:279
-msgid "deleted:"
-msgstr "suprimit:"
+#: remote.c:421
+msgid "more than one uploadpack given, using the first"
+msgstr ""
 
-#: wt-status.c:281
-msgid "modified:"
-msgstr "modificat:"
+#: remote.c:611
+#, c-format
+msgid "Cannot fetch both %s and %s to %s"
+msgstr "No es poden obtenir ambdós %s i %s a %s"
 
-#: wt-status.c:283
-msgid "renamed:"
-msgstr "canviat de nom:"
+#: remote.c:615
+#, c-format
+msgid "%s usually tracks %s, not %s"
+msgstr "%s generalment segueix %s, no %s"
 
-#: wt-status.c:285
-msgid "typechange:"
-msgstr "canviat de tipus:"
+#: remote.c:619
+#, c-format
+msgid "%s tracks both %s and %s"
+msgstr "%s segueix ambdós %s i %s"
 
-#: wt-status.c:287
-msgid "unknown:"
-msgstr "desconegut:"
+#: remote.c:687
+#, c-format
+msgid "key '%s' of pattern had no '*'"
+msgstr ""
 
-#: wt-status.c:289
-msgid "unmerged:"
-msgstr "sense fusionar:"
+#: remote.c:697
+#, c-format
+msgid "value '%s' of pattern has no '*'"
+msgstr ""
 
-#: wt-status.c:369
-msgid "new commits, "
-msgstr "comissions noves, "
+#: remote.c:1003
+#, fuzzy, c-format
+msgid "src refspec %s does not match any"
+msgstr "%s: no coincideix amb l'índex"
 
-#: wt-status.c:371
-msgid "modified content, "
-msgstr "contingut modificat, "
+#: remote.c:1008
+#, c-format
+msgid "src refspec %s matches more than one"
+msgstr ""
 
-#: wt-status.c:373
-msgid "untracked content, "
-msgstr "contingut no seguit, "
+#. TRANSLATORS: "matches '%s'%" is the <dst> part of "git push
+#. <remote> <src>:<dst>" push, and "being pushed ('%s')" is
+#. the <src>.
+#.
+#: remote.c:1023
+#, c-format
+msgid ""
+"The destination you provided is not a full refname (i.e.,\n"
+"starting with \"refs/\"). We tried to guess what you meant by:\n"
+"\n"
+"- Looking for a ref that matches '%s' on the remote side.\n"
+"- Checking if the <src> being pushed ('%s')\n"
+"  is a ref in \"refs/{heads,tags}/\". If so we add a corresponding\n"
+"  refs/{heads,tags}/ prefix on the remote side.\n"
+"\n"
+"Neither worked, so we gave up. You must fully qualify the ref."
+msgstr ""
 
-#: wt-status.c:847
+#: remote.c:1043
 #, c-format
-msgid "Your stash currently has %d entry"
-msgid_plural "Your stash currently has %d entries"
-msgstr[0] "L'«stash» té actualment %d entrada"
-msgstr[1] "L'«stash» té actualment %d entrades"
+msgid ""
+"The <src> part of the refspec is a commit object.\n"
+"Did you mean to create a new branch by pushing to\n"
+"'%s:refs/heads/%s'?"
+msgstr ""
 
-#: wt-status.c:879
-msgid "Submodules changed but not updated:"
-msgstr "Submòduls canviats però no actualitzats:"
+#: remote.c:1048
+#, c-format
+msgid ""
+"The <src> part of the refspec is a tag object.\n"
+"Did you mean to create a new tag by pushing to\n"
+"'%s:refs/tags/%s'?"
+msgstr ""
 
-#: wt-status.c:881
-msgid "Submodule changes to be committed:"
-msgstr "Canvis de submòdul a cometre:"
+#: remote.c:1053
+#, c-format
+msgid ""
+"The <src> part of the refspec is a tree object.\n"
+"Did you mean to tag a new tree by pushing to\n"
+"'%s:refs/tags/%s'?"
+msgstr ""
 
-#: wt-status.c:963
+#: remote.c:1058
+#, c-format
 msgid ""
-"Do not modify or remove the line above.\n"
-"Everything below it will be ignored."
+"The <src> part of the refspec is a blob object.\n"
+"Did you mean to tag a new blob by pushing to\n"
+"'%s:refs/tags/%s'?"
 msgstr ""
-"No modifiqueu o suprimiu la línia de dalt.\n"
-"Tot el que hi ha a sota s'ignorarà."
 
-#: wt-status.c:1076
-msgid "You have unmerged paths."
-msgstr "Teniu camins sense fusionar."
+#: remote.c:1094
+#, c-format
+msgid "%s cannot be resolved to branch"
+msgstr "«%s» no es pot resoldre a una branca"
 
-#: wt-status.c:1079
-msgid "  (fix conflicts and run \"git commit\")"
-msgstr "  (arregleu els conflictes i executeu \"git commit\")"
+#: remote.c:1105
+#, c-format
+msgid "unable to delete '%s': remote ref does not exist"
+msgstr "no s'ha pogut suprimir «%s»: la referència remota no existeix"
 
-#: wt-status.c:1081
-msgid "  (use \"git merge --abort\" to abort the merge)"
-msgstr "  (useu \"git merge --abort\" per a avortar la fusió)"
+#: remote.c:1117
+#, c-format
+msgid "dst refspec %s matches more than one"
+msgstr ""
 
-#: wt-status.c:1086
-msgid "All conflicts fixed but you are still merging."
-msgstr "Tots els conflictes estan arreglats però encara esteu fusionant."
+#: remote.c:1124
+#, c-format
+msgid "dst ref %s receives from more than one src"
+msgstr ""
 
-#: wt-status.c:1089
-msgid "  (use \"git commit\" to conclude merge)"
-msgstr "  (useu \"git commit\" per a concloure la fusió)"
+#: remote.c:1627 remote.c:1728
+msgid "HEAD does not point to a branch"
+msgstr "HEAD no assenyala cap branca"
 
-#: wt-status.c:1099
-msgid "You are in the middle of an am session."
-msgstr "Esteu enmig d'una sessió am."
+#: remote.c:1636
+#, c-format
+msgid "no such branch: '%s'"
+msgstr "no existeix la branca: «%s»"
 
-#: wt-status.c:1102
-msgid "The current patch is empty."
-msgstr "El pedaç actual està buit."
+#: remote.c:1639
+#, c-format
+msgid "no upstream configured for branch '%s'"
+msgstr "cap font configurada per a la branca «%s»"
 
-#: wt-status.c:1106
-msgid "  (fix conflicts and then run \"git am --continue\")"
-msgstr "  (arregleu els conflictes i després executeu \"git am --continue\")"
+#: remote.c:1645
+#, c-format
+msgid "upstream branch '%s' not stored as a remote-tracking branch"
+msgstr "la branca font «%s» no s'emmagatzema com a branca amb seguiment remot"
 
-#: wt-status.c:1108
-msgid "  (use \"git am --skip\" to skip this patch)"
-msgstr "  (useu \"git am --skip\" per a ometre aquest pedaç)"
+#: remote.c:1660
+#, c-format
+msgid "push destination '%s' on remote '%s' has no local tracking branch"
+msgstr ""
+"el destí de pujada «%s» en el remot «%s» no té cap branca amb seguiment remot"
 
-#: wt-status.c:1110
-msgid "  (use \"git am --abort\" to restore the original branch)"
-msgstr "  (useu \"git am --abort\" per a restaurar la branca original)"
+#: remote.c:1672
+#, c-format
+msgid "branch '%s' has no remote for pushing"
+msgstr "la branca «%s» no té cap remot al qual pujar"
 
-#: wt-status.c:1242
-msgid "git-rebase-todo is missing."
-msgstr "Manca git-rebase-todo."
+#: remote.c:1682
+#, c-format
+msgid "push refspecs for '%s' do not include '%s'"
+msgstr "les especificacions de referència de «%s» no inclouen «%s»"
 
-#: wt-status.c:1244
-msgid "No commands done."
-msgstr "No s'ha fet cap ordre."
+#: remote.c:1695
+msgid "push has no destination (push.default is 'nothing')"
+msgstr "push no té destí (push.default és «nothing)"
 
-#: wt-status.c:1247
-#, c-format
-msgid "Last command done (%d command done):"
-msgid_plural "Last commands done (%d commands done):"
-msgstr[0] "Última ordre feta (%d ordre feta):"
-msgstr[1] "Últimes ordres fetes (%d ordres fetes):"
+#: remote.c:1717
+msgid "cannot resolve 'simple' push to a single destination"
+msgstr "no es pot resoldre una pujada 'simple' a un sol destí"
 
-#: wt-status.c:1258
+#: remote.c:1843
 #, c-format
-msgid "  (see more in file %s)"
-msgstr "  (vegeu més en el fitxer %s)"
+msgid "couldn't find remote ref %s"
+msgstr "no s'ha pogut trobar la referència remota %s"
 
-#: wt-status.c:1263
-msgid "No commands remaining."
-msgstr "No manca cap ordre."
+#: remote.c:1856
+#, c-format
+msgid "* Ignoring funny ref '%s' locally"
+msgstr ""
 
-#: wt-status.c:1266
+#: remote.c:2019
 #, c-format
-msgid "Next command to do (%d remaining command):"
-msgid_plural "Next commands to do (%d remaining commands):"
-msgstr[0] "Ordre següent a fer (manca %d ordre):"
-msgstr[1] "Ordres següents a fer (manquen %d ordres):"
+msgid "Your branch is based on '%s', but the upstream is gone.\n"
+msgstr "La vostra branca està basada en «%s», però la font no hi és.\n"
 
-#: wt-status.c:1274
-msgid "  (use \"git rebase --edit-todo\" to view and edit)"
-msgstr "  (useu \"git rebase --edit-todo\" per a veure i editar)"
+#: remote.c:2023
+msgid "  (use \"git branch --unset-upstream\" to fixup)\n"
+msgstr "  (useu \"git branch --unset-upstream\" per a arreglar)\n"
 
-#: wt-status.c:1287
+#: remote.c:2026
 #, c-format
-msgid "You are currently rebasing branch '%s' on '%s'."
-msgstr "Actualment esteu fent «rebase» de la branca «%s» en «%s»."
+msgid "Your branch is up to date with '%s'.\n"
+msgstr "La vostra branca està al dia amb «%s».\n"
 
-#: wt-status.c:1292
-msgid "You are currently rebasing."
-msgstr "Actualment esteu fent «rebase»."
+#: remote.c:2030
+#, c-format
+msgid "Your branch and '%s' refer to different commits.\n"
+msgstr "La vostra branca i «%s» es refereixen a diferents comissions.\n"
 
-#: wt-status.c:1306
-msgid "  (fix conflicts and then run \"git rebase --continue\")"
+#: remote.c:2033
+#, c-format
+msgid "  (use \"%s\" for details)\n"
 msgstr ""
-"  (arregleu els conflictes i després executeu \"git rebase --continue\")"
 
-#: wt-status.c:1308
-msgid "  (use \"git rebase --skip\" to skip this patch)"
-msgstr "  (useu \"git rebase --skip\" per a ometre aquest pedaç)"
+#: remote.c:2037
+#, c-format
+msgid "Your branch is ahead of '%s' by %d commit.\n"
+msgid_plural "Your branch is ahead of '%s' by %d commits.\n"
+msgstr[0] "La vostra branca està %2$d comissió per davant de «%1$s».\n"
+msgstr[1] "La vostra branca està %2$d comissions per davant de «%1$s».\n"
 
-#: wt-status.c:1310
-msgid "  (use \"git rebase --abort\" to check out the original branch)"
-msgstr "  (useu \"git rebase --abort\" per a agafar la branca original)"
+#: remote.c:2043
+msgid "  (use \"git push\" to publish your local commits)\n"
+msgstr "  (useu \"git push\" per a publicar les vostres comissions locals)\n"
 
-#: wt-status.c:1316
-msgid "  (all conflicts fixed: run \"git rebase --continue\")"
-msgstr ""
-"  (tots els conflictes estan arreglats: executeu \"git rebase --continue\")"
+#: remote.c:2046
+#, c-format
+msgid "Your branch is behind '%s' by %d commit, and can be fast-forwarded.\n"
+msgid_plural ""
+"Your branch is behind '%s' by %d commits, and can be fast-forwarded.\n"
+msgstr[0] ""
+"La vostra branca està %2$d comissió per darrere de «%1$s», i pot avançar-se "
+"ràpidament.\n"
+msgstr[1] ""
+"La vostra branca està %2$d comissions per darrere de «%1$s», i pot avançar-"
+"se ràpidament.\n"
+
+#: remote.c:2054
+msgid "  (use \"git pull\" to update your local branch)\n"
+msgstr "  (useu «git pull» per a actualitzar la vostra branca local)\n"
 
-#: wt-status.c:1320
+#: remote.c:2057
 #, c-format
 msgid ""
-"You are currently splitting a commit while rebasing branch '%s' on '%s'."
-msgstr ""
-"Actualment esteu dividint una comissió mentre es fa «rebase» de la branca "
-"«%s» en «%s»."
-
-#: wt-status.c:1325
-msgid "You are currently splitting a commit during a rebase."
-msgstr "Actualment esteu dividint una comissió durant un «rebase»."
+"Your branch and '%s' have diverged,\n"
+"and have %d and %d different commit each, respectively.\n"
+msgid_plural ""
+"Your branch and '%s' have diverged,\n"
+"and have %d and %d different commits each, respectively.\n"
+msgstr[0] ""
+"La vostra branca i «%s» han divergit,\n"
+"i tenen %d i %d comissió distinta cada una, respectivament.\n"
+msgstr[1] ""
+"La vostra branca i «%s» han divergit,\n"
+"i tenen %d i %d comissions distintes cada una, respectivament.\n"
 
-#: wt-status.c:1328
-msgid "  (Once your working directory is clean, run \"git rebase --continue\")"
-msgstr ""
-"  (Una vegada que el vostre directori de treball sigui net, executeu \"git "
-"rebase --continue\")"
+#: remote.c:2067
+msgid "  (use \"git pull\" to merge the remote branch into yours)\n"
+msgstr "  (useu «git pull» per a fusionar la branca remota a la vostra)\n"
 
-#: wt-status.c:1332
+#: remote.c:2250
 #, c-format
-msgid "You are currently editing a commit while rebasing branch '%s' on '%s'."
-msgstr ""
-"Actualment esteu editant una comissió mentre es fa «rebase» de la branca "
-"«%s» en «%s»."
-
-#: wt-status.c:1337
-msgid "You are currently editing a commit during a rebase."
-msgstr "Actualment esteu editant una comissió durant un «rebase»."
+msgid "cannot parse expected object name '%s'"
+msgstr "no es pot analitzar el nom de l'objecte esperat «%s»"
 
-#: wt-status.c:1340
-msgid "  (use \"git commit --amend\" to amend the current commit)"
-msgstr "  (useu \"git commit --amend\" per a esmenar la comissió actual)"
+#: replace-object.c:21
+#, c-format
+msgid "bad replace ref name: %s"
+msgstr "nom de la referència reemplaçada incorrecte: %s"
 
-#: wt-status.c:1342
-msgid ""
-"  (use \"git rebase --continue\" once you are satisfied with your changes)"
-msgstr ""
-"  (useu \"git rebase --continue\" una vegada que estigueu satisfet amb els "
-"vostres canvis)"
+#: replace-object.c:30
+#, fuzzy, c-format
+msgid "duplicate replace ref: %s"
+msgstr "suprimeix les referències reemplaçades"
 
-#: wt-status.c:1352
+#: replace-object.c:73
 #, c-format
-msgid "You are currently cherry-picking commit %s."
-msgstr "Actualment esteu fent «cherry pick» a la comissió %s."
+msgid "replace depth too high for object %s"
+msgstr "la profunditat de reemplaçament és massa alta per l'objecte %s"
 
-#: wt-status.c:1357
-msgid "  (fix conflicts and run \"git cherry-pick --continue\")"
-msgstr "  (arregleu els conflictes i executeu \"git cherry-pick --continue\")"
+#: rerere.c:217 rerere.c:226 rerere.c:229
+msgid "corrupt MERGE_RR"
+msgstr "MERGE_RR corrupte"
 
-#: wt-status.c:1360
-msgid "  (all conflicts fixed: run \"git cherry-pick --continue\")"
-msgstr ""
-"  (tots els conflictes estan arreglats: executeu \"git cherry-pick --continue"
-"\")"
+#: rerere.c:264 rerere.c:269
+msgid "unable to write rerere record"
+msgstr "no s'ha pogut escriure el registre «rerere»"
 
-#: wt-status.c:1362
-msgid "  (use \"git cherry-pick --abort\" to cancel the cherry-pick operation)"
-msgstr ""
-"  (useu \"git cherry-pick --abort\" per a cancel·lar l'operació de «cherry "
-"pick»)"
+#: rerere.c:495
+#, c-format
+msgid "there were errors while writing '%s' (%s)"
+msgstr "s'han produït errors en escriure «%s» (%s)"
 
-#: wt-status.c:1371
+#: rerere.c:498
+#, fuzzy, c-format
+msgid "failed to flush '%s'"
+msgstr "s'ha produït un error en fer stat a «%s»"
+
+#: rerere.c:503 rerere.c:1039
+#,  c-format
+msgid "could not parse conflict hunks in '%s'"
+msgstr "no s'han pogut analitzar els pedaços en conflicte a «%s»"
+
+#: rerere.c:684
 #, c-format
-msgid "You are currently reverting commit %s."
-msgstr "Actualment esteu revertint la comissió %s."
+msgid "failed utime() on '%s'"
+msgstr "s'ha produït un error en fer «failed utime()» a «%s»"
 
-#: wt-status.c:1376
-msgid "  (fix conflicts and run \"git revert --continue\")"
-msgstr "  (arregleu els conflictes i executeu \"git revert --continue\")"
+#: rerere.c:694
+#, fuzzy, c-format
+msgid "writing '%s' failed"
+msgstr "la creació de «%s» ha fallat"
 
-#: wt-status.c:1379
-msgid "  (all conflicts fixed: run \"git revert --continue\")"
+#: rerere.c:714
+#, c-format
+msgid "Staged '%s' using previous resolution."
 msgstr ""
-"  (tots els conflictes estan arreglats: executeu \"git revert --continue\")"
 
-#: wt-status.c:1381
-msgid "  (use \"git revert --abort\" to cancel the revert operation)"
+#: rerere.c:753
+#, c-format
+msgid "Recorded resolution for '%s'."
 msgstr ""
-"  (useu \"git revert --abort\" per a cancel·lar l'operació de reversió)"
 
-#: wt-status.c:1392
+#: rerere.c:788
 #, c-format
-msgid "You are currently bisecting, started from branch '%s'."
-msgstr "Actualment esteu bisecant, heu començat des de la branca «%s»."
+msgid "Resolved '%s' using previous resolution."
+msgstr ""
 
-#: wt-status.c:1396
-msgid "You are currently bisecting."
-msgstr "Actualment esteu bisecant."
+#: rerere.c:803
+#, fuzzy, c-format
+msgid "cannot unlink stray '%s'"
+msgstr "no es pot fer symlink en «%s» «%s»"
 
-#: wt-status.c:1399
-msgid "  (use \"git bisect reset\" to get back to the original branch)"
-msgstr "  (useu \"git bisect reset\" per a tornar a la branca original)"
+#: rerere.c:807
+#, fuzzy, c-format
+msgid "Recorded preimage for '%s'"
+msgstr "no s'ha pogut llegir el fitxer de registre «%s»"
 
-#: wt-status.c:1596
-msgid "On branch "
-msgstr "En la branca "
+#: rerere.c:881 submodule.c:2067 builtin/log.c:1871
+#: builtin/submodule--helper.c:1436 builtin/submodule--helper.c:1448
+#, c-format
+msgid "could not create directory '%s'"
+msgstr "no s'ha pogut crear el directori «%s»"
 
-#: wt-status.c:1602
-msgid "interactive rebase in progress; onto "
-msgstr "«rebase» interactiu en curs; sobre "
+#: rerere.c:1057
+#, fuzzy, c-format
+msgid "failed to update conflicted state in '%s'"
+msgstr "no s'ha pogut escriure a «%s»"
 
-#: wt-status.c:1604
-msgid "rebase in progress; onto "
-msgstr "«rebase» en curs; sobre "
+#: rerere.c:1068 rerere.c:1075
+#, fuzzy, c-format
+msgid "no remembered resolution for '%s'"
+msgstr "No s'ha pogut afegir el resultat de fusió per a «%s»"
 
-#: wt-status.c:1609
-msgid "HEAD detached at "
-msgstr "HEAD separat a "
+#: rerere.c:1077
+#, fuzzy, c-format
+msgid "cannot unlink '%s'"
+msgstr "no es pot fer readlink en «%s»"
 
-#: wt-status.c:1611
-msgid "HEAD detached from "
-msgstr "HEAD separat de "
+#: rerere.c:1087
+#, fuzzy, c-format
+msgid "Updated preimage for '%s'"
+msgstr "suprimeix les referències reemplaçades"
 
-#: wt-status.c:1614
-msgid "Not currently on any branch."
-msgstr "Actualment no s'és en cap branca."
+#: rerere.c:1096
+#, fuzzy, c-format
+msgid "Forgot resolution for '%s'\n"
+msgstr "no s'ha pogut llegir el fitxer de registre «%s»"
 
-#: wt-status.c:1634
-msgid "Initial commit"
-msgstr "Comissió inicial"
+#: rerere.c:1199
+#, fuzzy
+msgid "unable to open rr-cache directory"
+msgstr "no s'ha pogut actualitzar l'arbre cau"
 
-#: wt-status.c:1635
-msgid "No commits yet"
-msgstr "No s'ha fet cap comissió encara."
+#: revision.c:2497
+msgid "your current branch appears to be broken"
+msgstr "la vostra branca actual sembla malmesa"
 
-#: wt-status.c:1649
-msgid "Untracked files"
-msgstr "Fitxers no seguits"
+#: revision.c:2500
+#, c-format
+msgid "your current branch '%s' does not have any commits yet"
+msgstr "la branca actual «%s» encara no té cap comissió"
 
-#: wt-status.c:1651
-msgid "Ignored files"
-msgstr "Fitxers ignorats"
+#: revision.c:2708
+msgid "--first-parent is incompatible with --bisect"
+msgstr "--first-parent és incompatible amb --bisect"
 
-#: wt-status.c:1655
-#, c-format
-msgid ""
-"It took %.2f seconds to enumerate untracked files. 'status -uno'\n"
-"may speed it up, but you have to be careful not to forget to add\n"
-"new files yourself (see 'git help status')."
+#: revision.c:2712
+msgid "-L does not yet support diff formats besides -p and -s"
 msgstr ""
-"Ha trigat %.2f segons enumerar els fitxers no seguits.\n"
-"'status -uno' pot accelerar-ho, però heu d'anar amb compte de no\n"
-"oblidar-vos d'afegir fitxers nous vosaltres mateixos (vegeu\n"
-"'git help status')."
-
-#: wt-status.c:1661
-#, c-format
-msgid "Untracked files not listed%s"
-msgstr "Els fitxers no seguits no estan llistats%s"
 
-#: wt-status.c:1663
-msgid " (use -u option to show untracked files)"
-msgstr " (useu l'opció -u per a mostrar els fitxers no seguits)"
+#: run-command.c:762
+msgid "open /dev/null failed"
+msgstr "s'ha produït un error en obrir /dev/null"
 
-#: wt-status.c:1669
-msgid "No changes"
-msgstr "Sense canvis"
+#: run-command.c:1268
+#, fuzzy, c-format
+msgid "cannot create async thread: %s"
+msgstr "no s'ha pogut crear fil: %s"
 
-#: wt-status.c:1674
+#: run-command.c:1332
 #, c-format
-msgid "no changes added to commit (use \"git add\" and/or \"git commit -a\")\n"
+msgid ""
+"The '%s' hook was ignored because it's not set as executable.\n"
+"You can disable this warning with `git config advice.ignoredHook false`."
 msgstr ""
-"no hi ha canvis afegits a cometre (useu \"git add\" o \"git commit -a\")\n"
 
-#: wt-status.c:1677
+#: send-pack.c:144
+msgid "unexpected flush packet while reading remote unpack status"
+msgstr ""
+"paquet de neteja no esperat quan estava llegint l'estat del desempaquetament "
+"remot"
+
+#: send-pack.c:146
 #, c-format
-msgid "no changes added to commit\n"
-msgstr "no hi ha canvis afegits a cometre\n"
+msgid "unable to parse remote unpack status: %s"
+msgstr "no s'ha pogut analitzar l'estat del desempaquetament remot: %s"
 
-#: wt-status.c:1680
+#: send-pack.c:148
 #, c-format
+msgid "remote unpack failed: %s"
+msgstr "s'ha produït un error en el desempaquetament remot: %s"
+
+#: send-pack.c:309
+msgid "failed to sign the push certificate"
+msgstr "s'ha produït un error en signar el certificat de pujada"
+
+#: send-pack.c:423
+msgid "the receiving end does not support --signed push"
+msgstr "el destí receptor no admet pujar --signed"
+
+#: send-pack.c:425
 msgid ""
-"nothing added to commit but untracked files present (use \"git add\" to "
-"track)\n"
+"not sending a push certificate since the receiving end does not support --"
+"signed push"
 msgstr ""
-"no hi ha res afegit a cometre però hi ha fitxers no seguits (useu \"git add"
-"\" per a seguir-los)\n"
+"no s'està enviant una certificació de pujada perquè el destí receptor no "
+"admet pujar --signed"
 
-#: wt-status.c:1683
-#, c-format
-msgid "nothing added to commit but untracked files present\n"
-msgstr "no hi ha res afegit a cometre però hi ha fitxers no seguits\n"
+#: send-pack.c:437
+msgid "the receiving end does not support --atomic push"
+msgstr "el destí receptor no admet pujar --atomic"
 
-#: wt-status.c:1686
-#, c-format
-msgid "nothing to commit (create/copy files and use \"git add\" to track)\n"
-msgstr ""
-"no hi ha res a cometre (creeu/copieu fitxers i useu \"git add\" per a seguir-"
-"los)\n"
+#: send-pack.c:442
+msgid "the receiving end does not support push options"
+msgstr "el destí receptor no admet opcions de pujada"
 
-#: wt-status.c:1689 wt-status.c:1694
+#: sequencer.c:189
 #, c-format
-msgid "nothing to commit\n"
-msgstr "no hi ha res a cometre\n"
+msgid "invalid commit message cleanup mode '%s'"
+msgstr "mode de neteja «%s» no vàlid en la comissió del missatge"
 
-#: wt-status.c:1692
-#, c-format
-msgid "nothing to commit (use -u to show untracked files)\n"
-msgstr ""
-"no hi ha res a cometre (useu -u per a mostrar els fitxers no seguits)\n"
+#: sequencer.c:294
+#, fuzzy, c-format
+msgid "could not delete '%s'"
+msgstr "No s'ha pogut suprimir %s"
 
-#: wt-status.c:1696
+#: sequencer.c:313 builtin/rebase.c:781 builtin/rebase.c:1706 builtin/rm.c:369
 #, c-format
-msgid "nothing to commit, working tree clean\n"
-msgstr "no hi ha res a cometre, l'arbre de treball està net\n"
-
-#: wt-status.c:1809
-msgid "No commits yet on "
-msgstr "No s'ha fet cap comissió encara a "
+msgid "could not remove '%s'"
+msgstr "no s'ha pogut suprimir «%s»"
 
-#: wt-status.c:1813
-msgid "HEAD (no branch)"
-msgstr "HEAD (sense branca)"
+#: sequencer.c:323
+msgid "revert"
+msgstr "revertir"
 
-#: wt-status.c:1844
-msgid "different"
-msgstr "diferent"
+#: sequencer.c:325
+msgid "cherry-pick"
+msgstr "cherry-pick"
 
-#: wt-status.c:1846 wt-status.c:1854
-msgid "behind "
-msgstr "darrere "
+#: sequencer.c:327
+msgid "rebase -i"
+msgstr "rebase -i"
 
-#: wt-status.c:1849 wt-status.c:1852
-msgid "ahead "
-msgstr "davant per "
+#: sequencer.c:329
+#, fuzzy, c-format
+msgid "unknown action: %d"
+msgstr "Acció desconeguda: %d"
 
-#. TRANSLATORS: the action is e.g. "pull with rebase"
-#: wt-status.c:2358
-#, c-format
-msgid "cannot %s: You have unstaged changes."
-msgstr "no es pot %s: Teniu canvis «unstaged»."
+#: sequencer.c:387
+msgid ""
+"after resolving the conflicts, mark the corrected paths\n"
+"with 'git add <paths>' or 'git rm <paths>'"
+msgstr ""
+"després de resoldre els conflictes, marqueu els camins\n"
+"corregits amb 'git add <camins>' o 'git rm <camins>'"
 
-#: wt-status.c:2364
-msgid "additionally, your index contains uncommitted changes."
-msgstr "addicionalment, el vostre índex conté canvis sense cometre."
+#: sequencer.c:390
+msgid ""
+"after resolving the conflicts, mark the corrected paths\n"
+"with 'git add <paths>' or 'git rm <paths>'\n"
+"and commit the result with 'git commit'"
+msgstr ""
+"després de resoldre els conflictes, marqueu els camins\n"
+"corregits amb 'git add <camins>' o 'git rm <camins>'\n"
+"i cometeu el resultat amb 'git commit'"
 
-#: wt-status.c:2366
+#: sequencer.c:403 sequencer.c:2993
 #, c-format
-msgid "cannot %s: Your index contains uncommitted changes."
-msgstr "no es pot %s: El vostre índex conté canvis sense cometre."
+msgid "could not lock '%s'"
+msgstr "no s'ha pogut bloquejar «%s»"
 
-#: compat/precompose_utf8.c:58 builtin/clone.c:440
+#: sequencer.c:410
 #, c-format
-msgid "failed to unlink '%s'"
-msgstr "s'ha produït un error en desenllaçar «%s»"
-
-#: builtin/add.c:24
-msgid "git add [<options>] [--] <pathspec>..."
-msgstr "git add [<opcions>] [--] <especificació-de-camí>..."
+msgid "could not write eol to '%s'"
+msgstr "no s'ha pogut escriure el terminador de línia a «%s»"
 
-#: builtin/add.c:83
+#: sequencer.c:415 sequencer.c:2798 sequencer.c:2999 sequencer.c:3013
+#: sequencer.c:3277
 #, c-format
-msgid "unexpected diff status %c"
-msgstr "estat de diff inesperat %c"
+msgid "failed to finalize '%s'"
+msgstr "s'ha produït un error en finalitzar «%s»"
 
-#: builtin/add.c:88 builtin/commit.c:257
-msgid "updating files failed"
-msgstr "s'ha produït un error en actualitzar els fitxers"
+#: sequencer.c:438 sequencer.c:1707 sequencer.c:2818 sequencer.c:3259
+#: sequencer.c:3368 builtin/am.c:244 builtin/commit.c:783 builtin/merge.c:1117
+#: builtin/rebase.c:589
+#, c-format
+msgid "could not read '%s'"
+msgstr "no s'ha pogut llegir «%s»"
 
-#: builtin/add.c:98
+#: sequencer.c:464
 #, c-format
-msgid "remove '%s'\n"
-msgstr "elimina «%s»\n"
-
-#: builtin/add.c:173
-msgid "Unstaged changes after refreshing the index:"
-msgstr "Canvis «unstaged» després d'actualitzar l'índex:"
+msgid "your local changes would be overwritten by %s."
+msgstr "els vostres canvis locals se sobreescriurien per %s."
 
-#: builtin/add.c:233 builtin/rev-parse.c:888
-msgid "Could not read the index"
-msgstr "No s'ha pogut llegir l'índex"
+#: sequencer.c:468
+msgid "commit your changes or stash them to proceed."
+msgstr "cometeu els vostres canvis o feu un «stash» per a procedir."
 
-#: builtin/add.c:244
+#: sequencer.c:500
 #, c-format
-msgid "Could not open '%s' for writing."
-msgstr "No s'ha pogut obrir «%s» per a escriptura."
-
-#: builtin/add.c:248
-msgid "Could not write patch"
-msgstr "No s'ha pogut escriure el pedaç"
-
-#: builtin/add.c:251
-msgid "editing patch failed"
-msgstr "l'edició del pedaç ha fallat"
+msgid "%s: fast-forward"
+msgstr "%s: avanç ràpid"
 
-#: builtin/add.c:254
+#: sequencer.c:539 builtin/tag.c:565
 #, c-format
-msgid "Could not stat '%s'"
-msgstr "No s'ha pogut fer stat a «%s»"
-
-#: builtin/add.c:256
-msgid "Empty patch. Aborted."
-msgstr "El pedaç és buit. S'ha avortat."
+msgid "Invalid cleanup mode %s"
+msgstr "Mode de neteja no vàlid %s"
 
-#: builtin/add.c:261
+#. TRANSLATORS: %s will be "revert", "cherry-pick" or
+#. "rebase -i".
+#.
+#: sequencer.c:633
 #, c-format
-msgid "Could not apply '%s'"
-msgstr "No s'ha pogut aplicar «%s»"
+msgid "%s: Unable to write new index file"
+msgstr "%s: No s'ha pogut escriure un fitxer d'índex nou"
 
-#: builtin/add.c:271
-msgid "The following paths are ignored by one of your .gitignore files:\n"
-msgstr ""
-"Els camins següents s'ignoren per un dels vostres fitxers .gitignore:\n"
+#: sequencer.c:650
+msgid "unable to update cache tree"
+msgstr "no s'ha pogut actualitzar l'arbre cau"
 
-#: builtin/add.c:291 builtin/clean.c:911 builtin/fetch.c:146 builtin/mv.c:124
-#: builtin/prune-packed.c:55 builtin/pull.c:207 builtin/push.c:541
-#: builtin/remote.c:1333 builtin/rm.c:242 builtin/send-pack.c:164
-msgid "dry run"
-msgstr "marxa en sec"
+#: sequencer.c:664
+msgid "could not resolve HEAD commit"
+msgstr "no s'ha pogut resoldre la comissió HEAD"
 
-#: builtin/add.c:294
-msgid "interactive picking"
-msgstr "recull interactiu"
+#: sequencer.c:744
+#, fuzzy, c-format
+msgid "no key present in '%.*s'"
+msgstr "no s'ha pogut analitzar «%.*s»"
 
-#: builtin/add.c:295 builtin/checkout.c:1128 builtin/reset.c:302
-msgid "select hunks interactively"
-msgstr "selecciona els trossos interactivament"
+#: sequencer.c:755
+#, fuzzy, c-format
+msgid "unable to dequote value of '%s'"
+msgstr "No s'ha pogut afegir el resultat de fusió per a «%s»"
 
-#: builtin/add.c:296
-msgid "edit current diff and apply"
-msgstr "edita la diferència actual i aplica-la"
+#: sequencer.c:792 wrapper.c:190 wrapper.c:360 builtin/am.c:705
+#: builtin/am.c:797 builtin/merge.c:1114 builtin/rebase.c:1074
+#, c-format
+msgid "could not open '%s' for reading"
+msgstr "no s'ha pogut obrir «%s» per a lectura"
 
-#: builtin/add.c:297
-msgid "allow adding otherwise ignored files"
-msgstr "permet afegir fitxers que d'altra manera s'ignoren"
+#: sequencer.c:802
+msgid "'GIT_AUTHOR_NAME' already given"
+msgstr "Ja s'ha donat «GIT_AUTHOR_NAME»"
 
-#: builtin/add.c:298
-msgid "update tracked files"
-msgstr "actualitza els fitxers seguits"
+#: sequencer.c:807
+msgid "'GIT_AUTHOR_EMAIL' already given"
+msgstr "Ja s'ha donat «GIT_AUTHOR_EMAIL»"
 
-#: builtin/add.c:299
-msgid "renormalize EOL of tracked files (implies -u)"
-msgstr ""
+#: sequencer.c:812
+msgid "'GIT_AUTHOR_DATE' already given"
+msgstr "Ja s'ha donat «GIT_AUTHOR_DATE»"
 
-#: builtin/add.c:300
-msgid "record only the fact that the path will be added later"
-msgstr "registra només el fet que el camí s'afegirà més tard"
+#: sequencer.c:816
+#, c-format
+msgid "unknown variable '%s'"
+msgstr "variable  «%s» desconeguda"
 
-#: builtin/add.c:301
-msgid "add changes from all tracked and untracked files"
-msgstr "afegeix els canvis de tots els fitxers seguits i no seguits"
+#: sequencer.c:821
+msgid "missing 'GIT_AUTHOR_NAME'"
+msgstr "falta «GIT_AUTHOR_NAME»"
 
-#: builtin/add.c:304
-msgid "ignore paths removed in the working tree (same as --no-all)"
-msgstr ""
-"ignora els camins eliminats en l'arbre de treball (el mateix que --no-all)"
+#: sequencer.c:823
+msgid "missing 'GIT_AUTHOR_EMAIL'"
+msgstr "falta «GIT_AUTHOR_EMAIL»"
 
-#: builtin/add.c:306
-msgid "don't add, only refresh the index"
-msgstr "no afegeixis, només actualitza l'índex"
+#: sequencer.c:825
+msgid "missing 'GIT_AUTHOR_DATE'"
+msgstr "falta «GIT_AUTHOR_DATE»"
 
-#: builtin/add.c:307
-msgid "just skip files which cannot be added because of errors"
-msgstr "només omet els fitxers que no es poden afegir a causa d'errors"
+#: sequencer.c:902 sequencer.c:1427
+#, fuzzy
+msgid "malformed ident line"
+msgstr "línia d'entrada mal formada: «%s»."
 
-#: builtin/add.c:308
-msgid "check if - even missing - files are ignored in dry run"
+#: sequencer.c:925
+#, c-format
+msgid ""
+"you have staged changes in your working tree\n"
+"If these changes are meant to be squashed into the previous commit, run:\n"
+"\n"
+"  git commit --amend %s\n"
+"\n"
+"If they are meant to go into a new commit, run:\n"
+"\n"
+"  git commit %s\n"
+"\n"
+"In both cases, once you're done, continue with:\n"
+"\n"
+"  git rebase --continue\n"
 msgstr ""
-"comproveu si els fitxers - fins i tot els absents - s'ignoren en marxa en sec"
-
-#: builtin/add.c:309 builtin/update-index.c:964
-msgid "(+/-)x"
-msgstr "(+/-)x"
-
-#: builtin/add.c:309 builtin/update-index.c:965
-msgid "override the executable bit of the listed files"
-msgstr "passa per alt el bit executable dels fitxers llistats"
+"teniu canvis «staged» en el vostre arbre de treball\n"
+"Si aquests canvis estan pensats per fer «squash» a la comissió prèvia, "
+"executeu:\n"
+"\n"
+"  git commit --amend %s\n"
+"\n"
+"Si són per a formar una comissió nova, executeu:\n"
+"\n"
+"  git commit %s\n"
+"\n"
+"En ambdós casos, quan hàgiu terminat, continueu amb:\n"
+"\n"
+"  git rebase --continue\n"
 
-#: builtin/add.c:311
-msgid "warn when adding an embedded repository"
-msgstr "avisa'm quan s'afegeixi un dipòsit incrustat"
+#: sequencer.c:1218
+msgid "'prepare-commit-msg' hook failed"
+msgstr "el lligam «prepare-commit-msg» ha fallat"
 
-#: builtin/add.c:326
-#, c-format
+#: sequencer.c:1224
 msgid ""
-"You've added another git repository inside your current repository.\n"
-"Clones of the outer repository will not contain the contents of\n"
-"the embedded repository and will not know how to obtain it.\n"
-"If you meant to add a submodule, use:\n"
-"\n"
-"\tgit submodule add <url> %s\n"
+"Your name and email address were configured automatically based\n"
+"on your username and hostname. Please check that they are accurate.\n"
+"You can suppress this message by setting them explicitly. Run the\n"
+"following command and follow the instructions in your editor to edit\n"
+"your configuration file:\n"
 "\n"
-"If you added this path by mistake, you can remove it from the\n"
-"index with:\n"
+"    git config --global --edit\n"
 "\n"
-"\tgit rm --cached %s\n"
+"After doing this, you may fix the identity used for this commit with:\n"
 "\n"
-"See \"git help submodule\" for more information."
+"    git commit --amend --reset-author\n"
 msgstr ""
-"Heu afegit un altre dipòsit git dins del dipòsit actual.\n"
-"Els clons de dipòsits externs no contindran els continguts de\n"
-"del dipòsit incrustat i no saben com obtenir-ho.\n"
-"Si volíeu afegir un submòdul, useu:\n"
+"S'han configurat el vostre nom i adreça electrònica\n"
+"automàticament basant-se en el vostre nom d'usuari i nom de màquina. \n"
+"Comproveu que siguin correctes. Podeu suprimir aquest\n"
+"missatge establint-los explícitament. Executeu l'ordre següent i\n"
+"seguiu les instruccions en el vostre editor per editar el vostre\n"
+"fitxer de configuració:\n"
 "\n"
-"\tgit submodule add <url> %s\n"
+"    git config --global --edit\n"
+"Després de fer això, podeu esmenar la identitat usada per a aquesta\n"
+"comissió amb:\n"
 "\n"
-"Si heu afegit aquest camí per error, podeu suprimir-lo de\n"
-" l'índex amb:\n"
+"    git commit --amend --reset-author\n"
+
+#: sequencer.c:1237
+msgid ""
+"Your name and email address were configured automatically based\n"
+"on your username and hostname. Please check that they are accurate.\n"
+"You can suppress this message by setting them explicitly:\n"
 "\n"
-"\tgit rm --cached %s\n"
+"    git config --global user.name \"Your Name\"\n"
+"    git config --global user.email you@example.com\n"
 "\n"
-"Vegeu \"git help submodule\" per a més informació."
+"After doing this, you may fix the identity used for this commit with:\n"
+"\n"
+"    git commit --amend --reset-author\n"
+msgstr ""
+"S'han configurat el vostre nom i adreça electrònica\n"
+"automàticament basats en el vostre nom d'usuari i nom de màquina. \n"
+"Comproveu que siguin correctes. Podeu suprimir aquest\n"
+"missatge establint-los explícitament:\n"
+"\n"
+"    git config --global user.name \"El Vostre Nom\"\n"
+"    git config --global user.email tu@example.com\n"
+"\n"
+"Després de fer això, podeu arreglar la identitat usada per a aquesta\n"
+"comissió amb:\n"
+"\n"
+"    git commit --amend --reset-author\n"
 
-#: builtin/add.c:354
-#, c-format
-msgid "adding embedded git repository: %s"
-msgstr "s'està afegint un dipòsit incrustat: %s"
+#: sequencer.c:1279
+msgid "couldn't look up newly created commit"
+msgstr "no s'ha pogut trobar la comissió novament creada"
 
-#: builtin/add.c:372
-#, c-format
-msgid "Use -f if you really want to add them.\n"
-msgstr "Useu -f si realment els voleu afegir.\n"
+#: sequencer.c:1281
+msgid "could not parse newly created commit"
+msgstr "no s'ha pogut analitzar la comissió novament creada"
 
-#: builtin/add.c:380
-msgid "adding files failed"
-msgstr "l'afegiment de fitxers ha fallat"
+#: sequencer.c:1327
+msgid "unable to resolve HEAD after creating commit"
+msgstr "no s'ha pogut resoldre HEAD després de crear la comissió"
 
-#: builtin/add.c:417
-msgid "-A and -u are mutually incompatible"
-msgstr "-A i -u són mútuament incompatibles"
+#: sequencer.c:1329
+msgid "detached HEAD"
+msgstr "HEAD separat"
 
-#: builtin/add.c:424
-msgid "Option --ignore-missing can only be used together with --dry-run"
-msgstr "L'opció --ignore-missing només es pot usar juntament amb --dry-run"
+#: sequencer.c:1333
+msgid " (root-commit)"
+msgstr " (comissió d'arrel)"
 
-#: builtin/add.c:428
-#, c-format
-msgid "--chmod param '%s' must be either -x or +x"
-msgstr "el paràmetre --chmod «%s» ha de ser o -x o +x"
+#: sequencer.c:1354
+msgid "could not parse HEAD"
+msgstr "no s'ha pogut analitzar HEAD"
 
-#: builtin/add.c:443
+#: sequencer.c:1356
 #, c-format
-msgid "Nothing specified, nothing added.\n"
-msgstr "No s'ha especificat res, no s'ha afegit res.\n"
+msgid "HEAD %s is not a commit!"
+msgstr "HEAD %s no és una comissió!"
 
-#: builtin/add.c:444
-#, c-format
-msgid "Maybe you wanted to say 'git add .'?\n"
-msgstr "Potser volíeu dir «git add .»?\n"
+#: sequencer.c:1360 sequencer.c:1458 builtin/commit.c:1569
+msgid "could not parse HEAD commit"
+msgstr "no s'ha pogut analitzar la comissió HEAD"
 
-#: builtin/add.c:449 builtin/check-ignore.c:177 builtin/checkout.c:280
-#: builtin/checkout.c:483 builtin/clean.c:958 builtin/commit.c:316
-#: builtin/diff-tree.c:114 builtin/mv.c:144 builtin/reset.c:241
-#: builtin/rm.c:271 builtin/submodule--helper.c:326
-msgid "index file corrupt"
-msgstr "fitxer d'índex malmès"
+#: sequencer.c:1411 sequencer.c:2055
+msgid "unable to parse commit author"
+msgstr "no s'ha pogut analitzar l'autor de la comissió"
 
-#: builtin/am.c:414
-msgid "could not parse author script"
-msgstr "no s'ha pogut analitzar l'script d'autor"
+#: sequencer.c:1431
+#, fuzzy
+msgid "corrupted author without date information"
+msgstr "actualitza la informació d'estadístiques"
 
-#: builtin/am.c:498
+#: sequencer.c:1447 builtin/am.c:1561 builtin/merge.c:684
+msgid "git write-tree failed to write a tree"
+msgstr "git write-tree ha fallat en escriure un arbre"
+
+#: sequencer.c:1480 sequencer.c:1550
 #, c-format
-msgid "'%s' was deleted by the applypatch-msg hook"
-msgstr "s'ha suprimit «%s» pel lligam applypatch-msg"
+msgid "unable to read commit message from '%s'"
+msgstr "no s'ha pogut llegir el missatge de comissió des de «%s»"
+
+#: sequencer.c:1516 builtin/am.c:1583 builtin/commit.c:1668 builtin/merge.c:883
+#: builtin/merge.c:908
+msgid "failed to write commit object"
+msgstr "s'ha produït un error en escriure l'objecte de comissió"
 
-#: builtin/am.c:539
+#: sequencer.c:1577
 #, c-format
-msgid "Malformed input line: '%s'."
-msgstr "Línia d'entrada mal formada: «%s»."
+msgid "could not parse commit %s"
+msgstr "no s'ha pogut analitzar la comissió %s"
 
-#: builtin/am.c:576
+#: sequencer.c:1582
 #, c-format
-msgid "Failed to copy notes from '%s' to '%s'"
-msgstr "S'ha produït un error en copiar les notes de «%s» a «%s»"
+msgid "could not parse parent commit %s"
+msgstr "no s'ha pogut analitzar la comissió pare %s"
 
-#: builtin/am.c:602
-msgid "fseek failed"
-msgstr "fseek ha fallat"
+#: sequencer.c:1656 sequencer.c:1767
+#, c-format
+msgid "unknown command: %d"
+msgstr "ordre desconeguda: %d"
 
-#: builtin/am.c:790
+#: sequencer.c:1714 sequencer.c:1739
 #, c-format
-msgid "could not parse patch '%s'"
-msgstr "no s'ha pogut analitzar el pedaç «%s»"
+msgid "This is a combination of %d commits."
+msgstr "Això és una combinació de %d comissions."
 
-#: builtin/am.c:855
-msgid "Only one StGIT patch series can be applied at once"
-msgstr "Només una sèrie de pedaços StGIT es pot aplicar a la vegada"
+#: sequencer.c:1724
+msgid "need a HEAD to fixup"
+msgstr "cal un HEAD per reparar-ho"
 
-#: builtin/am.c:903
-msgid "invalid timestamp"
-msgstr "marca de temps no vàlida"
+#: sequencer.c:1726 sequencer.c:3304
+msgid "could not read HEAD"
+msgstr "no s'ha pogut llegir HEAD"
 
-#: builtin/am.c:908 builtin/am.c:920
-msgid "invalid Date line"
-msgstr "línia Date no vàlida"
+#: sequencer.c:1728
+msgid "could not read HEAD's commit message"
+msgstr "no s'ha pogut llegir el missatge de comissió de HEAD"
 
-#: builtin/am.c:915
-msgid "invalid timezone offset"
-msgstr "desplaçament de zona de temps no vàlid"
-
-#: builtin/am.c:1008
-msgid "Patch format detection failed."
-msgstr "La detecció de format de pedaç ha fallat."
-
-#: builtin/am.c:1013 builtin/clone.c:405
+#: sequencer.c:1734
 #, c-format
-msgid "failed to create directory '%s'"
-msgstr "s'ha produït un error en crear el directori «%s»"
-
-#: builtin/am.c:1018
-msgid "Failed to split patches."
-msgstr "S'ha produït un error en dividir els pedaços."
+msgid "cannot write '%s'"
+msgstr "no es pot escriure «%s»"
 
-#: builtin/am.c:1148 builtin/commit.c:342
-msgid "unable to write index file"
-msgstr "no s'ha pogut escriure el fitxer d'índex"
+#: sequencer.c:1741 git-rebase--preserve-merges.sh:496
+msgid "This is the 1st commit message:"
+msgstr "Aquest és el 1r missatge de comissió:"
 
-#: builtin/am.c:1162
+#: sequencer.c:1749
 #, c-format
-msgid "When you have resolved this problem, run \"%s --continue\"."
-msgstr "Quan hàgiu resolt aquest problema, executeu \"%s --continue\"."
+msgid "could not read commit message of %s"
+msgstr "no s'ha pogut llegir el missatge de comissió: %s"
 
-#: builtin/am.c:1163
+#: sequencer.c:1756
 #, c-format
-msgid "If you prefer to skip this patch, run \"%s --skip\" instead."
-msgstr ""
-"Si preferiu ometre aquest pedaç, executeu \"%s --skip\" en lloc d'això."
+msgid "This is the commit message #%d:"
+msgstr "Aquest és el missatge de comissió #%d:"
 
-#: builtin/am.c:1164
+#: sequencer.c:1762
 #, c-format
-msgid "To restore the original branch and stop patching, run \"%s --abort\"."
-msgstr ""
-"Per a restaurar la branca original i deixar d'apedaçar, executeu \"%s --abort"
-"\"."
+msgid "The commit message #%d will be skipped:"
+msgstr "El missatge de comissió núm. #%d s'ometrà:"
 
-#: builtin/am.c:1271
-msgid "Patch is empty."
-msgstr "El pedaç està buit."
+#: sequencer.c:1850
+msgid "your index file is unmerged."
+msgstr "el vostre fitxer d'índex està sense fusionar."
 
-#: builtin/am.c:1337
+#: sequencer.c:1857
+#, fuzzy
+msgid "cannot fixup root commit"
+msgstr "no es pot trobar la comissió %s (%s)"
+
+#: sequencer.c:1876
 #, c-format
-msgid "invalid ident line: %.*s"
-msgstr "línia d'identitat no vàlida: %.*s"
+msgid "commit %s is a merge but no -m option was given."
+msgstr "la comissió %s és una fusió però no s'ha donat cap opció -m."
 
-#: builtin/am.c:1359
+#: sequencer.c:1884 sequencer.c:1892
 #, c-format
-msgid "unable to parse commit %s"
-msgstr "no s'ha pogut analitzar la comissió %s"
+msgid "commit %s does not have parent %d"
+msgstr "la comissió %s no té pare %d"
 
-#: builtin/am.c:1554
-msgid "Repository lacks necessary blobs to fall back on 3-way merge."
-msgstr ""
-"Al dipòsit li manquen els blobs necessaris per a retrocedir a una fusió de 3 "
-"vies."
+#: sequencer.c:1898
+#, c-format
+msgid "cannot get commit message for %s"
+msgstr "no es pot obtenir el missatge de comissió de %s"
 
-#: builtin/am.c:1556
-msgid "Using index info to reconstruct a base tree..."
-msgstr "S'està usant la informació d'índex per a reconstruir un arbre base..."
+#. TRANSLATORS: The first %s will be a "todo" command like
+#. "revert" or "pick", the second %s a SHA1.
+#: sequencer.c:1917
+#, c-format
+msgid "%s: cannot parse parent commit %s"
+msgstr "%s: no es pot analitzar la comissió pare %s"
 
-#: builtin/am.c:1575
-msgid ""
-"Did you hand edit your patch?\n"
-"It does not apply to blobs recorded in its index."
-msgstr ""
-"Heu editat el vostre pedaç a mà?\n"
-"No s'aplica als blobs recordats en el seu índex."
+#: sequencer.c:1982
+#, c-format
+msgid "could not rename '%s' to '%s'"
+msgstr "no s'ha pogut canviar el nom «%s» a «%s»"
 
-#: builtin/am.c:1581
-msgid "Falling back to patching base and 3-way merge..."
-msgstr "S'està retrocedint a apedaçar la base i una fusió de 3 vies..."
+#: sequencer.c:2037
+#, c-format
+msgid "could not revert %s... %s"
+msgstr "no s'ha pogut revertir %s... %s"
 
-#: builtin/am.c:1606
-msgid "Failed to merge in the changes."
-msgstr "S'ha produït un error en fusionar els canvis."
+#: sequencer.c:2038
+#, c-format
+msgid "could not apply %s... %s"
+msgstr "no s'ha pogut aplicar %s... %s"
 
-#: builtin/am.c:1637
-msgid "applying to an empty history"
-msgstr "s'està aplicant a una història buida"
+#: sequencer.c:2105
+#, c-format
+msgid "git %s: failed to read the index"
+msgstr "git %s: s'ha produït un error en llegir l'índex"
 
-#: builtin/am.c:1683 builtin/am.c:1687
+#: sequencer.c:2112
 #, c-format
-msgid "cannot resume: %s does not exist."
-msgstr "no es pot reprendre: %s no existeix."
+msgid "git %s: failed to refresh the index"
+msgstr "git %s: s'ha produït un error en actualitzar l'índex"
 
-#: builtin/am.c:1703
-msgid "cannot be interactive without stdin connected to a terminal."
-msgstr ""
-"no es pot ser interactiu sense que stdin estigui connectada a un terminal."
+#: sequencer.c:2189
+#, c-format
+msgid "%s does not accept arguments: '%s'"
+msgstr "%s no accepta paràmetres: «%s»"
 
-#: builtin/am.c:1708
-msgid "Commit Body is:"
-msgstr "El cos de la comissió és:"
+#: sequencer.c:2198
+#, c-format
+msgid "missing arguments for %s"
+msgstr "falten els arguments per %s"
 
-#. TRANSLATORS: Make sure to include [y], [n], [e], [v] and [a]
-#. in your translation. The program will only accept English
-#. input at this point.
-#.
-#: builtin/am.c:1718
-msgid "Apply? [y]es/[n]o/[e]dit/[v]iew patch/[a]ccept all: "
-msgstr ""
-"Voleu aplicar-lo? [y]es/[n]o/[e]dita/[v]isualitza el pedaç/[a]ccepta'ls "
-"tots: "
+#: sequencer.c:2235
+#, fuzzy, c-format
+msgid "could not parse '%.*s'"
+msgstr "no s'ha pogut analitzar «%s»"
 
-#: builtin/am.c:1768
+#: sequencer.c:2289
 #, c-format
-msgid "Dirty index: cannot apply patches (dirty: %s)"
-msgstr "Índex brut: no es poden aplicar pedaços (bruts: %s)"
+msgid "invalid line %d: %.*s"
+msgstr "línia no vàlida %d: %.*s"
 
-#: builtin/am.c:1808 builtin/am.c:1879
+#: sequencer.c:2300
 #, c-format
-msgid "Applying: %.*s"
-msgstr "S'està aplicant: %.*s"
-
-#: builtin/am.c:1824
-msgid "No changes -- Patch already applied."
-msgstr "Sense canvis -- El pedaç ja s'ha aplicat."
+msgid "cannot '%s' without a previous commit"
+msgstr "No es pot «%s» sense una comissió prèvia"
 
-#: builtin/am.c:1832
+#: sequencer.c:2348 builtin/rebase.c:172 builtin/rebase.c:197
+#: builtin/rebase.c:223 builtin/rebase.c:248
 #, c-format
-msgid "Patch failed at %s %.*s"
-msgstr "El pedaç ha fallat a %s %.*s"
+msgid "could not read '%s'."
+msgstr "no s'ha pogut llegir «%s»."
 
-#: builtin/am.c:1838
-msgid "Use 'git am --show-current-patch' to see the failed patch"
-msgstr ""
+#: sequencer.c:2384
+#, fuzzy
+msgid "cancelling a cherry picking in progress"
+msgstr "ni hi ha cap «cherry pick» ni cap reversió en curs"
 
-#: builtin/am.c:1882
-msgid ""
-"No changes - did you forget to use 'git add'?\n"
-"If there is nothing left to stage, chances are that something else\n"
-"already introduced the same changes; you might want to skip this patch."
-msgstr ""
-"Cap canvi - heu oblidat d'usar 'git add'?\n"
-"Si no hi ha res per fer «stage», probablement alguna altra cosa ja ha\n"
-"introduït els mateixos canvis; potser voleu ometre aquest pedaç."
+#: sequencer.c:2391
+#, fuzzy
+msgid "cancelling a revert in progress"
+msgstr "ni hi ha cap «cherry pick» ni cap reversió en curs"
 
-#: builtin/am.c:1889
-msgid ""
-"You still have unmerged paths in your index.\n"
-"You should 'git add' each file with resolved conflicts to mark them as "
-"such.\n"
-"You might run `git rm` on a file to accept \"deleted by them\" for it."
-msgstr ""
-"Encara teniu camins sense fusionar a l'índex.\n"
-"Heu de fer 'git add' a cada fitxer amb conflictes resolts per marcar-los com "
-"a tal.\n"
-"Podeu executar `git rm` en un fitxer per acceptar \"suprimit per ells\" pel "
-"fitxer."
+#: sequencer.c:2435
+msgid "please fix this using 'git rebase --edit-todo'."
+msgstr "corregiu-ho usant «git rebase --edit-todo»."
 
-#: builtin/am.c:1996 builtin/am.c:2000 builtin/am.c:2012 builtin/reset.c:324
-#: builtin/reset.c:332
+#: sequencer.c:2437
 #, c-format
-msgid "Could not parse object '%s'."
-msgstr "No s'ha pogut analitzar l'objecte «%s»."
+msgid "unusable instruction sheet: '%s'"
+msgstr "full d'instruccions inusable: «%s»"
 
-#: builtin/am.c:2048
-msgid "failed to clean index"
-msgstr "s'ha produït un error en netejar l'índex"
+#: sequencer.c:2442
+msgid "no commits parsed."
+msgstr "no s'ha analitzat cap comissió."
 
-#: builtin/am.c:2083
-msgid ""
-"You seem to have moved HEAD since the last 'am' failure.\n"
-"Not rewinding to ORIG_HEAD"
-msgstr ""
-"Sembla que heu mogut HEAD després de l'última fallada de 'am'.\n"
-"No s'està rebobinant a ORIG_HEAD"
+#: sequencer.c:2453
+msgid "cannot cherry-pick during a revert."
+msgstr "no es pot fer «cherry pick» durant una reversió."
 
-#: builtin/am.c:2174
+#: sequencer.c:2455
+msgid "cannot revert during a cherry-pick."
+msgstr "no es pot revertir durant un «cherry pick»."
+
+#: sequencer.c:2533
 #, c-format
-msgid "Invalid value for --patch-format: %s"
-msgstr "Valor no vàlid per a --patch-format: %s"
+msgid "invalid value for %s: %s"
+msgstr "valor no vàlid per a %s: %s"
 
-#: builtin/am.c:2210
-msgid "git am [<options>] [(<mbox> | <Maildir>)...]"
-msgstr "git am [<opcions>] [(<bústia> | <directori-de-correu>)...]"
+#: sequencer.c:2630
+msgid "unusable squash-onto"
+msgstr ""
 
-#: builtin/am.c:2211
-msgid "git am [<options>] (--continue | --skip | --abort)"
-msgstr "git am [<opcions>] (--continue | --skip | --abort)"
+#: sequencer.c:2646
+#, c-format
+msgid "malformed options sheet: '%s'"
+msgstr "full d'opcions mal format: «%s»"
 
-#: builtin/am.c:2217
-msgid "run interactively"
-msgstr "executa interactivament"
+#: sequencer.c:2736 sequencer.c:4463
+msgid "empty commit set passed"
+msgstr "conjunt de comissions buit passat"
 
-#: builtin/am.c:2219
-msgid "historical option -- no-op"
-msgstr "opció històrica -- no-op"
+#: sequencer.c:2752
+#, fuzzy
+msgid "revert is already in progress"
+msgstr "un «cherry pick» o una reversió ja està en curs"
 
-#: builtin/am.c:2221
-msgid "allow fall back on 3way merging if needed"
-msgstr "permet retrocedir a una fusió de 3 vies si és necessari"
+#: sequencer.c:2754
+#, fuzzy, c-format
+msgid "try \"git revert (--continue | %s--abort | --quit)\""
+msgstr "intenteu \"git cherry-pick (--continue | --quit | --abort)\""
 
-#: builtin/am.c:2222 builtin/init-db.c:484 builtin/prune-packed.c:57
-#: builtin/repack.c:182
-msgid "be quiet"
-msgstr "silenciós"
+#: sequencer.c:2757
+#, fuzzy
+msgid "cherry-pick is already in progress"
+msgstr "un «cherry pick» o una reversió ja està en curs"
 
-#: builtin/am.c:2224
-msgid "add a Signed-off-by line to the commit message"
-msgstr "afegeix una línia «Signed-off-by» al missatge de comissió"
+#: sequencer.c:2759
+#, fuzzy, c-format
+msgid "try \"git cherry-pick (--continue | %s--abort | --quit)\""
+msgstr "intenteu \"git cherry-pick (--continue | --quit | --abort)\""
 
-#: builtin/am.c:2227
-msgid "recode into utf8 (default)"
-msgstr "recodifica en utf8 (per defecte)"
+#: sequencer.c:2773
+#, c-format
+msgid "could not create sequencer directory '%s'"
+msgstr "no s'ha pogut crear el directori de seqüenciador «%s»"
 
-#: builtin/am.c:2229
-msgid "pass -k flag to git-mailinfo"
-msgstr "passa l'indicador -k a git-mailinfo"
+#: sequencer.c:2788
+msgid "could not lock HEAD"
+msgstr "no s'ha pogut bloquejar HEAD"
 
-#: builtin/am.c:2231
-msgid "pass -b flag to git-mailinfo"
-msgstr "passa l'indicador -b a git-mailinfo"
+#: sequencer.c:2848 sequencer.c:4209
+msgid "no cherry-pick or revert in progress"
+msgstr "ni hi ha cap «cherry pick» ni cap reversió en curs"
 
-#: builtin/am.c:2233
-msgid "pass -m flag to git-mailinfo"
-msgstr "passa l'indicador -m a git-mailinfo"
+#: sequencer.c:2850 sequencer.c:2861
+msgid "cannot resolve HEAD"
+msgstr "no es pot resoldre HEAD"
 
-#: builtin/am.c:2235
-msgid "pass --keep-cr flag to git-mailsplit for mbox format"
-msgstr "passa l'indicador --keep-cr a git-mailsplit per al format mbox"
+#: sequencer.c:2852 sequencer.c:2896
+msgid "cannot abort from a branch yet to be born"
+msgstr "no es pot avortar des d'una branca que encara ha de nàixer"
 
-#: builtin/am.c:2238
-msgid "do not pass --keep-cr flag to git-mailsplit independent of am.keepcr"
-msgstr ""
-"no passis l'indicador --keep-cr a git-mailsplit independent d'am.keepcr"
+#: sequencer.c:2882 builtin/grep.c:736
+#, c-format
+msgid "cannot open '%s'"
+msgstr "no es pot obrir «%s»"
 
-#: builtin/am.c:2241
-msgid "strip everything before a scissors line"
-msgstr "elimina tot abans d'una línia de tisores"
+#: sequencer.c:2884
+#, c-format
+msgid "cannot read '%s': %s"
+msgstr "no es pot llegir «%s»: %s"
 
-#: builtin/am.c:2243 builtin/am.c:2246 builtin/am.c:2249 builtin/am.c:2252
-#: builtin/am.c:2255 builtin/am.c:2258 builtin/am.c:2261 builtin/am.c:2264
-#: builtin/am.c:2270
-msgid "pass it through git-apply"
-msgstr "passa-ho a través de git-apply"
+#: sequencer.c:2885
+msgid "unexpected end of file"
+msgstr "final de fitxer inesperat"
 
-#: builtin/am.c:2260 builtin/fmt-merge-msg.c:665 builtin/fmt-merge-msg.c:668
-#: builtin/grep.c:853 builtin/merge.c:206 builtin/pull.c:145 builtin/pull.c:203
-#: builtin/repack.c:191 builtin/repack.c:195 builtin/repack.c:197
-#: builtin/show-branch.c:631 builtin/show-ref.c:169 builtin/tag.c:382
-#: parse-options.h:144 parse-options.h:146 parse-options.h:257
-msgid "n"
-msgstr "n"
+#: sequencer.c:2891
+#, c-format
+msgid "stored pre-cherry-pick HEAD file '%s' is corrupt"
+msgstr "el fitxer HEAD emmagatzemat abans de fer «cherry pick» «%s» és malmès"
 
-#: builtin/am.c:2266 builtin/branch.c:629 builtin/for-each-ref.c:38
-#: builtin/replace.c:445 builtin/tag.c:418 builtin/verify-tag.c:39
-msgid "format"
-msgstr "format"
+#: sequencer.c:2902
+msgid "You seem to have moved HEAD. Not rewinding, check your HEAD!"
+msgstr "Sembla que heu mogut HEAD sense rebobinar, comproveu-ho HEAD"
 
-#: builtin/am.c:2267
-msgid "format the patch(es) are in"
-msgstr "el format en el qual estan els pedaços"
-
-#: builtin/am.c:2273
-msgid "override error message when patch failure occurs"
-msgstr "passa per alt el missatge d'error si falla l'aplicació del pedaç"
-
-#: builtin/am.c:2275
-msgid "continue applying patches after resolving a conflict"
-msgstr "segueix aplicant pedaços després de resoldre un conflicte"
-
-#: builtin/am.c:2278
-msgid "synonyms for --continue"
-msgstr "sinònims de --continue"
+#: sequencer.c:2943
+#, fuzzy
+msgid "no revert in progress"
+msgstr "No hi ha un «rebase» en curs?"
 
-#: builtin/am.c:2281
-msgid "skip the current patch"
-msgstr "omet el pedaç actual"
+#: sequencer.c:2951
+#, fuzzy
+msgid "no cherry-pick in progress"
+msgstr "ni hi ha cap «cherry pick» ni cap reversió en curs"
 
-#: builtin/am.c:2284
-msgid "restore the original branch and abort the patching operation."
-msgstr "restaura la branca original i avorta l'operació d'apedaçament."
+#: sequencer.c:2961
+#, fuzzy
+msgid "failed to skip the commit"
+msgstr "s'ha produït un error en escriure l'objecte de comissió"
 
-#: builtin/am.c:2287
-msgid "abort the patching operation but keep HEAD where it is."
+#: sequencer.c:2968
+msgid "there is nothing to skip"
 msgstr ""
 
-#: builtin/am.c:2290
-msgid "show the patch being applied."
-msgstr "mostra el pedaç que s'està aplicant."
-
-#: builtin/am.c:2294
-msgid "lie about committer date"
-msgstr "menteix sobre la data del comitent"
-
-#: builtin/am.c:2296
-msgid "use current timestamp for author date"
-msgstr "usa el marc de temps actual per la data d'autor"
+#: sequencer.c:2971
+#, c-format
+msgid ""
+"have you committed already?\n"
+"try \"git %s --continue\""
+msgstr ""
 
-#: builtin/am.c:2298 builtin/commit.c:1431 builtin/merge.c:237
-#: builtin/pull.c:178 builtin/revert.c:112 builtin/tag.c:398
-msgid "key-id"
-msgstr "ID de clau"
+#: sequencer.c:3095 sequencer.c:4121
+#, c-format
+msgid "could not update %s"
+msgstr "no s'ha pogut actualitzar %s"
 
-#: builtin/am.c:2299
-msgid "GPG-sign commits"
-msgstr "signa les comissions amb GPG"
+#: sequencer.c:3134 sequencer.c:4101
+msgid "cannot read HEAD"
+msgstr "No es pot llegir HEAD"
 
-#: builtin/am.c:2302
-msgid "(internal use for git-rebase)"
-msgstr "(ús intern per a git-rebase)"
+#: sequencer.c:3151
+#, c-format
+msgid "unable to copy '%s' to '%s'"
+msgstr "no s'ha pogut copiar «%s» a «%s»"
 
-#: builtin/am.c:2320
+#: sequencer.c:3159
+#, fuzzy, c-format
 msgid ""
-"The -b/--binary option has been a no-op for long time, and\n"
-"it will be removed. Please do not use it anymore."
+"You can amend the commit now, with\n"
+"\n"
+"  git commit --amend %s\n"
+"\n"
+"Once you are satisfied with your changes, run\n"
+"\n"
+"  git rebase --continue\n"
 msgstr ""
-"Fa molt que l'opció -b/--binary no ha fet res, i\n"
-"s'eliminarà. No l'useu més."
+"Podeu esmenar la comissió ara, amb\n"
+"\n"
+"\tgit commit --amend $gpg_sign_opt_quoted\n"
+"\n"
+"Una vegada que estigueu satisfet amb els vostres canvis, executeu\n"
+"\n"
+"\tgit rebase --continue"
 
-#: builtin/am.c:2327
-msgid "failed to read the index"
-msgstr "S'ha produït un error en llegir l'índex"
+#: sequencer.c:3169
+#, c-format
+msgid "Could not apply %s... %.*s"
+msgstr "No s'ha pogut aplicar %s... %.*s"
 
-#: builtin/am.c:2342
+#: sequencer.c:3176
 #, c-format
-msgid "previous rebase directory %s still exists but mbox given."
-msgstr ""
-"un directori de «rebase» anterior %s encara existeix però s'ha donat una "
-"bústia."
+msgid "Could not merge %.*s"
+msgstr "No s'ha pogut fusionar %.*s"
+
+#: sequencer.c:3190 sequencer.c:3194 builtin/difftool.c:641
+#, c-format
+msgid "could not copy '%s' to '%s'"
+msgstr "no s'ha pogut copiar «%s» a «%s»"
 
-#: builtin/am.c:2366
+#: sequencer.c:3221
 #, c-format
 msgid ""
-"Stray %s directory found.\n"
-"Use \"git am --abort\" to remove it."
+"execution failed: %s\n"
+"%sYou can fix the problem, and then run\n"
+"\n"
+"  git rebase --continue\n"
+"\n"
 msgstr ""
-"S'ha trobat un directori %s extraviat.\n"
-"Useu \"git am --abort\" per a eliminar-lo."
+"ha fallat: %s\n"
+"%sPodeu solucionar el problema, i llavors executar\n"
+"\n"
+" git rebase --continue\n"
+"\n"
 
-#: builtin/am.c:2372
-msgid "Resolve operation not in progress, we are not resuming."
-msgstr "Una operació de resolució no està en curs; no reprenem."
+#: sequencer.c:3227
+msgid "and made changes to the index and/or the working tree\n"
+msgstr "i ha fet canvis a l'índex i/o l'arbre de treball\n"
 
-#: builtin/apply.c:8
-msgid "git apply [<options>] [<patch>...]"
-msgstr "git apply [<opcions>] [<pedaç>...]"
+#: sequencer.c:3233
+#, c-format
+msgid ""
+"execution succeeded: %s\n"
+"but left changes to the index and/or the working tree\n"
+"Commit or stash your changes, and then run\n"
+"\n"
+"  git rebase --continue\n"
+"\n"
+msgstr ""
+"l'execució ha tingut èxit: %s\n"
+"però ha deixat canvis a l'índex i/o l'arbre de treball\n"
+"Cometeu o feu «stash» dels vostres canvis, i llavors executeu\n"
+"\n"
+" git rebase --continue\n"
 
-#: builtin/archive.c:17
+#: sequencer.c:3294
 #, c-format
-msgid "could not create archive file '%s'"
-msgstr "no s'ha pogut crear el fitxer d'arxiu «%s»"
+msgid "illegal label name: '%.*s'"
+msgstr "nom d'etiqueta no permès: «%.*s»"
 
-#: builtin/archive.c:20
-msgid "could not redirect output"
-msgstr "no s'ha pogut redirigir la sortida"
+#: sequencer.c:3348
+#, fuzzy
+msgid "writing fake root commit"
+msgstr "no hi ha res a cometre\n"
 
-#: builtin/archive.c:37
-msgid "git archive: Remote with no URL"
-msgstr "git archive: Remot sense URL"
+#: sequencer.c:3353
+msgid "writing squash-onto"
+msgstr ""
 
-#: builtin/archive.c:58
-msgid "git archive: expected ACK/NAK, got a flush packet"
-msgstr "git archive: s'esperava ACK/NAK, s'ha rebut un paquet de neteja"
+#: sequencer.c:3391 builtin/rebase.c:876 builtin/rebase.c:882
+#, fuzzy, c-format
+msgid "failed to find tree of %s"
+msgstr "S'ha produït un error en cercar l'arbre de %s."
 
-#: builtin/archive.c:61
+#: sequencer.c:3436
 #, c-format
-msgid "git archive: NACK %s"
-msgstr "git archive: %s NACK"
+msgid "could not resolve '%s'"
+msgstr "no s'ha pogut resoldre «%s»"
 
-#: builtin/archive.c:64
-msgid "git archive: protocol error"
-msgstr "git archive: error de protocol"
+#: sequencer.c:3467
+#, fuzzy
+msgid "cannot merge without a current revision"
+msgstr "No es pot «%s» sense una comissió prèvia"
 
-#: builtin/archive.c:68
-msgid "git archive: expected a flush"
-msgstr "git archive: s'esperava una neteja"
+#: sequencer.c:3489
+#, c-format
+msgid "unable to parse '%.*s'"
+msgstr "no s'ha pogut analitzar «%.*s»"
 
-#: builtin/bisect--helper.c:12
-msgid "git bisect--helper --next-all [--no-checkout]"
-msgstr "git bisect--helper --next-all [--no-checkout]"
+#: sequencer.c:3498
+#, c-format
+msgid "nothing to merge: '%.*s'"
+msgstr "no hi ha res per fusionar «%.*s»"
 
-#: builtin/bisect--helper.c:13
-msgid "git bisect--helper --write-terms <bad_term> <good_term>"
-msgstr "git bisect--helper --write-terms <mal_terme> <bon_terme>"
+#: sequencer.c:3510
+msgid "octopus merge cannot be executed on top of a [new root]"
+msgstr ""
 
-#: builtin/bisect--helper.c:14
-msgid "git bisect--helper --bisect-clean-state"
-msgstr "git bisect--helper --bisect-clean-state"
+#: sequencer.c:3526
+#, fuzzy, c-format
+msgid "could not get commit message of '%s'"
+msgstr "no s'ha pogut llegir el missatge de comissió: %s"
 
-#: builtin/bisect--helper.c:46
+#: sequencer.c:3688
 #, c-format
-msgid "'%s' is not a valid term"
-msgstr "«%s» no és una terme vàlid"
+msgid "could not even attempt to merge '%.*s'"
+msgstr "no s'ha pogut fusionar «%.*s»"
 
-#: builtin/bisect--helper.c:50
+#: sequencer.c:3704
+#, fuzzy
+msgid "merge: Unable to write new index file"
+msgstr "%s: No s'ha pogut escriure un fitxer d'índex nou"
+
+#: sequencer.c:3773 builtin/rebase.c:733
 #, c-format
-msgid "can't use the builtin command '%s' as a term"
-msgstr "no es pot usar l'ordre interna «%s» com a terme"
+msgid "Applied autostash.\n"
+msgstr "S'ha aplicat el «stash» automàticament.\n"
 
-#: builtin/bisect--helper.c:60
+#: sequencer.c:3785
 #, c-format
-msgid "can't change the meaning of the term '%s'"
-msgstr "no es pot canviar el significat del terme «%s»"
+msgid "cannot store %s"
+msgstr "no es pot emmagatzemar %s"
 
-#: builtin/bisect--helper.c:71
-msgid "please use two different terms"
-msgstr "useu dos termes distintes"
+#: sequencer.c:3788 builtin/rebase.c:749 git-rebase--preserve-merges.sh:113
+#, c-format
+msgid ""
+"Applying autostash resulted in conflicts.\n"
+"Your changes are safe in the stash.\n"
+"You can run \"git stash pop\" or \"git stash drop\" at any time.\n"
+msgstr ""
+"L'aplicació del «stash» automàtic ha resultat en conflictes.\n"
+"Els vostres canvis estan segurs en el «stash».\n"
+"Podeu executar \"git stash pop\" o \"git stash drop\" en qualsevol moment.\n"
 
-#: builtin/bisect--helper.c:78
-msgid "could not open the file BISECT_TERMS"
-msgstr "no s'ha pogut obrir el BISECT_TERMS"
+#: sequencer.c:3849
+#, fuzzy, c-format
+msgid "could not checkout %s"
+msgstr "no es pot agafar %s"
 
-#: builtin/bisect--helper.c:120
-msgid "perform 'git bisect next'"
-msgstr "realitza 'git bisect next'"
+#: sequencer.c:3863
+#, fuzzy, c-format
+msgid "%s: not a valid OID"
+msgstr "«%s» no és un terme vàlid"
 
-#: builtin/bisect--helper.c:122
-msgid "write the terms to .git/BISECT_TERMS"
-msgstr "escriu els termes a .git/BISECT_TERMS"
+#: sequencer.c:3868 git-rebase--preserve-merges.sh:779
+msgid "could not detach HEAD"
+msgstr "no s'ha pogut separar HEAD"
 
-#: builtin/bisect--helper.c:124
-msgid "cleanup the bisection state"
-msgstr "neteja l'estat de la bisecció"
+#: sequencer.c:3883
+#, fuzzy, c-format
+msgid "Stopped at HEAD\n"
+msgstr "Aturat a %s...  %.*s\n"
 
-#: builtin/bisect--helper.c:126
-msgid "check for expected revs"
-msgstr "comprova les revisions esperades"
+#: sequencer.c:3885
+#, fuzzy, c-format
+msgid "Stopped at %s\n"
+msgstr "Aturat a %s...  %.*s\n"
 
-#: builtin/bisect--helper.c:128
-msgid "update BISECT_HEAD instead of checking out the current commit"
-msgstr "actualitza BISECT_HEAD en lloc d'agafar la comissió actual"
+#: sequencer.c:3893
+#, c-format
+msgid ""
+"Could not execute the todo command\n"
+"\n"
+"    %.*s\n"
+"It has been rescheduled; To edit the command before continuing, please\n"
+"edit the todo list first:\n"
+"\n"
+"    git rebase --edit-todo\n"
+"    git rebase --continue\n"
+msgstr ""
 
-#: builtin/bisect--helper.c:143
-msgid "--write-terms requires two arguments"
-msgstr "--write-terms requereix dos paràmetres"
+#: sequencer.c:3979
+#, c-format
+msgid "Stopped at %s...  %.*s\n"
+msgstr "Aturat a %s...  %.*s\n"
 
-#: builtin/bisect--helper.c:147
-msgid "--bisect-clean-state requires no arguments"
-msgstr "--bisect-clean-state no accepta paràmetres"
+#: sequencer.c:4050
+#, c-format
+msgid "unknown command %d"
+msgstr "ordre %d desconeguda"
 
-#: builtin/blame.c:27
-msgid "git blame [<options>] [<rev-opts>] [<rev>] [--] <file>"
-msgstr "git blame [<opcions>] [<opcions-de-revisió>] [<revisió>] [--] fitxer"
+#: sequencer.c:4109
+msgid "could not read orig-head"
+msgstr "No s'ha pogut llegir orig-head"
 
-#: builtin/blame.c:32
-msgid "<rev-opts> are documented in git-rev-list(1)"
-msgstr "es documenten les <opcions-de-revisió> en git-rev-list(1)"
+#: sequencer.c:4114
+msgid "could not read 'onto'"
+msgstr "no s'ha pogut llegir 'onto'"
 
-#: builtin/blame.c:677
-msgid "Show blame entries as we find them, incrementally"
-msgstr "Mostra les entrades «blame» mentre les trobem, incrementalment"
+#: sequencer.c:4128
+#, c-format
+msgid "could not update HEAD to %s"
+msgstr "no s'ha pogut actualitzar HEAD a %s"
 
-#: builtin/blame.c:678
-msgid "Show blank SHA-1 for boundary commits (Default: off)"
-msgstr ""
-"Mostra un SHA-1 en blanc per les comissions de frontera (Per defecte: "
-"desactivat)"
+#: sequencer.c:4221
+msgid "cannot rebase: You have unstaged changes."
+msgstr "No es pot fer «rebase»: teniu canvis «unstaged»."
 
-#: builtin/blame.c:679
-msgid "Do not treat root commits as boundaries (Default: off)"
-msgstr ""
-"No tractis les comissions d'arrel com a límits (Per defecte: desactivat)"
+#: sequencer.c:4230
+msgid "cannot amend non-existing commit"
+msgstr "no es pot esmenar una comissió no existent"
 
-#: builtin/blame.c:680
-msgid "Show work cost statistics"
-msgstr "Mostra les estadístiques de preu de treball"
+#: sequencer.c:4232
+#, c-format
+msgid "invalid file: '%s'"
+msgstr "fitxer no vàlid: «%s»"
 
-#: builtin/blame.c:681
-msgid "Force progress reporting"
-msgstr "Força l'informe de progrés"
+#: sequencer.c:4234
+#, c-format
+msgid "invalid contents: '%s'"
+msgstr "contingut no vàlid: «%s»"
 
-#: builtin/blame.c:682
-msgid "Show output score for blame entries"
-msgstr "Mostra la puntuació de sortida de les entrades «blame»"
+#: sequencer.c:4237
+msgid ""
+"\n"
+"You have uncommitted changes in your working tree. Please, commit them\n"
+"first and then run 'git rebase --continue' again."
+msgstr ""
+"\n"
+"Teniu canvis no comesos en el vostre arbre de treball. \n"
+"Primer cometeu-los i després executeu 'git rebase --continue' de nou."
 
-#: builtin/blame.c:683
-msgid "Show original filename (Default: auto)"
-msgstr "Mostra el nom de fitxer original (Per defecte: automàtic)"
+#: sequencer.c:4273 sequencer.c:4312
+#, fuzzy, c-format
+msgid "could not write file: '%s'"
+msgstr "no s'ha pogut crear el fitxer «%s»"
 
-#: builtin/blame.c:684
-msgid "Show original linenumber (Default: off)"
-msgstr "Mostra el número de línia original (Per defecte: desactivat)"
+#: sequencer.c:4327
+msgid "could not remove CHERRY_PICK_HEAD"
+msgstr "No s'ha pogut eliminar CHERRY_PICK_HEAD"
 
-#: builtin/blame.c:685
-msgid "Show in a format designed for machine consumption"
-msgstr "Presenta en un format dissenyat per consumpció per màquina"
+#: sequencer.c:4334
+msgid "could not commit staged changes."
+msgstr "No s'han pogut cometre els canvis «staged»."
 
-#: builtin/blame.c:686
-msgid "Show porcelain format with per-line commit information"
-msgstr "Mostra el format de porcellana amb informació de comissió per línia"
+#: sequencer.c:4440
+#, c-format
+msgid "%s: can't cherry-pick a %s"
+msgstr "%s: no es pot fer «cherry pick» a %s"
 
-#: builtin/blame.c:687
-msgid "Use the same output mode as git-annotate (Default: off)"
-msgstr ""
-"Usa el mateix mode de sortida que git-annotate (Per defecte: desactivat)"
+#: sequencer.c:4444
+#, c-format
+msgid "%s: bad revision"
+msgstr "%s: revisió incorrecta"
 
-#: builtin/blame.c:688
-msgid "Show raw timestamp (Default: off)"
-msgstr "Mostra la marca de temps crua (Per defecte: desactivat)"
+#: sequencer.c:4479
+msgid "can't revert as initial commit"
+msgstr "no es pot revertir com a comissió inicial"
 
-#: builtin/blame.c:689
-msgid "Show long commit SHA1 (Default: off)"
-msgstr "Mostra l'SHA1 de comissió llarg (Per defecte: desactivat)"
+#: sequencer.c:4952
+msgid "make_script: unhandled options"
+msgstr "make_script: opcions no gestionades"
 
-#: builtin/blame.c:690
-msgid "Suppress author name and timestamp (Default: off)"
-msgstr "Omet el nom d'autor i la marca de temps (Per defecte: desactivat)"
+#: sequencer.c:4955
+msgid "make_script: error preparing revisions"
+msgstr "make_script: s'ha produït un error en preparar les revisions"
 
-#: builtin/blame.c:691
-msgid "Show author email instead of name (Default: off)"
+#: sequencer.c:5113
+msgid ""
+"You can fix this with 'git rebase --edit-todo' and then run 'git rebase --"
+"continue'.\n"
+"Or you can abort the rebase with 'git rebase --abort'.\n"
 msgstr ""
-"Mostra l'adreça electrònica de l'autor en lloc del nom (Per defecte: "
-"desactivat)"
-
-#: builtin/blame.c:692
-msgid "Ignore whitespace differences"
-msgstr "Ignora les diferències d'espai en blanc"
-
-#: builtin/blame.c:699
-msgid "Use an experimental heuristic to improve diffs"
-msgstr "Usa un heurístic experimental per a millorar les diferències"
-
-#: builtin/blame.c:701
-msgid "Spend extra cycles to find better match"
-msgstr "Gasta cicles extres per a trobar una coincidència millor"
-
-#: builtin/blame.c:702
-msgid "Use revisions from <file> instead of calling git-rev-list"
-msgstr "Usa les revisions de <fitxer> en lloc d'invocar git-rev-list"
-
-#: builtin/blame.c:703
-msgid "Use <file>'s contents as the final image"
-msgstr "Usa els continguts de <fitxer> com a la imatge final"
-
-#: builtin/blame.c:704 builtin/blame.c:705
-msgid "score"
-msgstr "puntuació"
-
-#: builtin/blame.c:704
-msgid "Find line copies within and across files"
-msgstr "Troba còpies de línia dins i a través dels fitxers"
-
-#: builtin/blame.c:705
-msgid "Find line movements within and across files"
-msgstr "Troba moviments de línia dins i a través dels fitxers"
-
-#: builtin/blame.c:706
-msgid "n,m"
-msgstr "n,m"
-
-#: builtin/blame.c:706
-msgid "Process only line range n,m, counting from 1"
-msgstr "Processa només el rang de línies n,m, comptant des d'1"
+"Podeu arreglar això amb 'git rebase --edit-todo' i després 'git rebase --"
+"continue'.\n"
 
-#: builtin/blame.c:753
-msgid "--progress can't be used with --incremental or porcelain formats"
-msgstr ""
-"no es pot usar --progress amb els formats --incremental o de porcellana"
+#: sequencer.c:5226 sequencer.c:5243
+msgid "nothing to do"
+msgstr "res a fer"
+
+#: sequencer.c:5257
+msgid "could not skip unnecessary pick commands"
+msgstr "no s'han pogut ometre les ordres «picks» no necessàries"
 
-#. TRANSLATORS: This string is used to tell us the
-#. maximum display width for a relative timestamp in
-#. "git blame" output.  For C locale, "4 years, 11
-#. months ago", which takes 22 places, is the longest
-#. among various forms of relative timestamps, but
-#. your language may need more or fewer display
-#. columns.
-#.
-#: builtin/blame.c:804
-msgid "4 years, 11 months ago"
-msgstr "fa 4 anys i 11 mesos"
+#: sequencer.c:5351
+msgid "the script was already rearranged."
+msgstr "l'script ja estava endreçat."
 
-#: builtin/blame.c:890
+#: setup.c:124
 #, c-format
-msgid "file %s has only %lu line"
-msgid_plural "file %s has only %lu lines"
-msgstr[0] "el fitxer %s té només %lu línia"
-msgstr[1] "el fitxer %s té només %lu línies"
-
-#: builtin/blame.c:936
-msgid "Blaming lines"
-msgstr "S'està fent un «blame»"
-
-#: builtin/branch.c:27
-msgid "git branch [<options>] [-r | -a] [--merged | --no-merged]"
-msgstr "git branch [<opcions>] [-r | -a] [--merged | --no-merged]"
-
-#: builtin/branch.c:28
-msgid "git branch [<options>] [-l] [-f] <branch-name> [<start-point>]"
-msgstr "git branch [<opcions>] [-l] [-f] <nom-de-branca> [<punt-inicial>]"
-
-#: builtin/branch.c:29
-msgid "git branch [<options>] [-r] (-d | -D) <branch-name>..."
-msgstr "git branch [<opcions>] [-r] (-d | -D) <nom-de-branca>..."
-
-#: builtin/branch.c:30
-msgid "git branch [<options>] (-m | -M) [<old-branch>] <new-branch>"
-msgstr "git branch [<opcions>] (-m | -M) [<branca-antiga>] <branca-nova>"
-
-#: builtin/branch.c:31
-msgid "git branch [<options>] (-c | -C) [<old-branch>] <new-branch>"
-msgstr "git branch [<opcions>] (-c | -C) [<branca-antiga>] <branca-nova>"
-
-#: builtin/branch.c:32
-msgid "git branch [<options>] [-r | -a] [--points-at]"
-msgstr "git branch [<opcions>] [-r | -a] [--points-at]"
-
-#: builtin/branch.c:33
-msgid "git branch [<options>] [-r | -a] [--format]"
-msgstr "git branch [<opcions>] [-r | -a] [--format]"
+msgid "'%s' is outside repository"
+msgstr "«%s» és fora del dipòsit"
 
-#: builtin/branch.c:146
+#: setup.c:174
 #, c-format
 msgid ""
-"deleting branch '%s' that has been merged to\n"
-"         '%s', but not yet merged to HEAD."
+"%s: no such path in the working tree.\n"
+"Use 'git <command> -- <path>...' to specify paths that do not exist locally."
 msgstr ""
-"s'està suprimint la branca «%s» que s'ha\n"
-"         fusionat a «%s», però encara no\n"
-"         s'ha fusionat a HEAD."
+"%s: no hi ha tal camí en l'arbre de treball.\n"
+"Useu «git <ordre> -- <camí>...» per a especificar camins que no existeixin "
+"localment."
 
-#: builtin/branch.c:150
+#: setup.c:187
 #, c-format
 msgid ""
-"not deleting branch '%s' that is not yet merged to\n"
-"         '%s', even though it is merged to HEAD."
+"ambiguous argument '%s': unknown revision or path not in the working tree.\n"
+"Use '--' to separate paths from revisions, like this:\n"
+"'git <command> [<revision>...] -- [<file>...]'"
 msgstr ""
-"no s'està suprimint la branca «%s» que encara no\n"
-"         s'ha fusionat a «%s», encara que està\n"
-"         fusionada a HEAD."
+"paràmetre ambigu «%s»: revisió no coneguda o el camí no és en l'arbre de "
+"treball.\n"
+"Useu «--» per a separar els camins de les revisions:\n"
+"'git <ordre> [<revisió>...] -- [<fitxer>...]'"
 
-#: builtin/branch.c:164
+#: setup.c:236
 #, c-format
-msgid "Couldn't look up commit object for '%s'"
-msgstr "No s'ha pogut trobar l'objecte de comissió de «%s»"
+msgid "option '%s' must come before non-option arguments"
+msgstr "l'opció «%s» ha de venir abans dels arguments opcionals"
 
-#: builtin/branch.c:168
+#: setup.c:255
 #, c-format
 msgid ""
-"The branch '%s' is not fully merged.\n"
-"If you are sure you want to delete it, run 'git branch -D %s'."
+"ambiguous argument '%s': both revision and filename\n"
+"Use '--' to separate paths from revisions, like this:\n"
+"'git <command> [<revision>...] -- [<file>...]'"
 msgstr ""
-"La branca «%s» no està totalment fusionada.\n"
-"Si esteu segur que la voleu suprimir, executeu 'git branch -D %s'."
-
-#: builtin/branch.c:181
-msgid "Update of config-file failed"
-msgstr "L'actualització del fitxer de configuració ha fallat"
+"paràmetre ambigu «%s»: ambdós una revisió i un nom de fitxer\n"
+"Useu '--' per a separar els camins de les revisions:\n"
+"'git <ordre> [<revisió>...] -- [<fitxer>...]'"
 
-#: builtin/branch.c:212
-msgid "cannot use -a with -d"
-msgstr "no es pot usar -a amb -d"
+#: setup.c:391
+msgid "unable to set up work tree using invalid config"
+msgstr ""
+"no s'ha pogut configurar un arbre de treball utilitzant una configuració no "
+"vàlida"
 
-#: builtin/branch.c:218
-msgid "Couldn't look up commit object for HEAD"
-msgstr "No s'ha pogut trobar l'objecte de comissió de HEAD"
+#: setup.c:395
+msgid "this operation must be run in a work tree"
+msgstr "aquesta operació s'ha d'executar en un arbre de treball"
 
-#: builtin/branch.c:232
+#: setup.c:541
 #, c-format
-msgid "Cannot delete branch '%s' checked out at '%s'"
-msgstr "No es pot suprimir la branca «%s» agafada a «%s»"
+msgid "Expected git repo version <= %d, found %d"
+msgstr "S'esperava una versió de dipòsit de git <= %d, s'ha trobat %d"
 
-#: builtin/branch.c:247
-#, c-format
-msgid "remote-tracking branch '%s' not found."
-msgstr "no s'ha trobat la branca amb seguiment remot «%s»."
+#: setup.c:549
+msgid "unknown repository extensions found:"
+msgstr "s'han trobat extensions de dipòsit desconegudes:"
 
-#: builtin/branch.c:248
+#: setup.c:568
 #, c-format
-msgid "branch '%s' not found."
-msgstr "no s'ha trobat la branca «%s»."
+msgid "error opening '%s'"
+msgstr "s'ha produït un error en obrir «%s»"
 
-#: builtin/branch.c:263
+#: setup.c:570
 #, c-format
-msgid "Error deleting remote-tracking branch '%s'"
-msgstr "Error en suprimir la branca amb seguiment remot «%s»"
+msgid "too large to be a .git file: '%s'"
+msgstr "massa larg per a ser un fitxer .git: «%s»"
 
-#: builtin/branch.c:264
+#: setup.c:572
 #, c-format
-msgid "Error deleting branch '%s'"
-msgstr "Error en suprimir la branca «%s»"
+msgid "error reading %s"
+msgstr "error en llegir %s"
 
-#: builtin/branch.c:271
+#: setup.c:574
 #, c-format
-msgid "Deleted remote-tracking branch %s (was %s).\n"
-msgstr "S'ha suprimit la branca amb seguiment remot %s (era %s).\n"
+msgid "invalid gitfile format: %s"
+msgstr "format gitfile no vàlid: %s"
 
-#: builtin/branch.c:272
+#: setup.c:576
 #, c-format
-msgid "Deleted branch %s (was %s).\n"
-msgstr "S'ha suprimit la branca %s (era %s).\n"
+msgid "no path in gitfile: %s"
+msgstr "sense camí al gitfile: %s"
 
-#: builtin/branch.c:417 builtin/tag.c:58
-msgid "unable to parse format string"
-msgstr "no s'ha pogut analitzar la cadena de format"
+#: setup.c:578
+#, c-format
+msgid "not a git repository: %s"
+msgstr "no és un dipòsit de git: %s"
 
-#: builtin/branch.c:450
+#: setup.c:677
 #, c-format
-msgid "Branch %s is being rebased at %s"
-msgstr "S'està fent «rebase» en la branca %s a %s"
+msgid "'$%s' too big"
+msgstr "«$%s» massa gran"
 
-#: builtin/branch.c:454
+#: setup.c:691
 #, c-format
-msgid "Branch %s is being bisected at %s"
-msgstr "La branca %s s'està bisecant a %s"
+msgid "not a git repository: '%s'"
+msgstr "no és un dipòsit de git: «%s»"
 
-#: builtin/branch.c:471
-msgid "cannot copy the current branch while not on any."
-msgstr "no es pot copiar branca actual mentre no s'és a cap."
+#: setup.c:720 setup.c:722 setup.c:753
+#, c-format
+msgid "cannot chdir to '%s'"
+msgstr "no es pot canviar de directori a «%s»"
 
-#: builtin/branch.c:473
-msgid "cannot rename the current branch while not on any."
-msgstr "no es pot canviar el nom de la branca actual mentre no s'és a cap."
+#: setup.c:725 setup.c:781 setup.c:791 setup.c:830 setup.c:838
+msgid "cannot come back to cwd"
+msgstr "no es pot tornar al directori de treball actual"
 
-#: builtin/branch.c:484
+#: setup.c:852
 #, c-format
-msgid "Invalid branch name: '%s'"
-msgstr "Nom de branca no vàlid: «%s»"
-
-#: builtin/branch.c:511
-msgid "Branch rename failed"
-msgstr "El canvi de nom de branca ha fallat"
+msgid "failed to stat '%*s%s%s'"
+msgstr "s'ha produït un error en fer stat a «%*s%s%s»"
 
-#: builtin/branch.c:513
-msgid "Branch copy failed"
-msgstr "La còpia de la branca ha fallat"
+#: setup.c:1090
+msgid "Unable to read current working directory"
+msgstr "No s'ha pogut llegir el directori de treball actual"
 
-#: builtin/branch.c:517
+#: setup.c:1099 setup.c:1105
 #, c-format
-msgid "Created a copy of a misnamed branch '%s'"
-msgstr "S'ha creat una còpia d'una branca mal anomenada «%s»"
+msgid "cannot change to '%s'"
+msgstr "no es pot canviar a «%s»"
 
-#: builtin/branch.c:520
+#: setup.c:1110
 #, c-format
-msgid "Renamed a misnamed branch '%s' away"
-msgstr "S'ha canviat el nom de la branca mal anomenada «%s»"
+msgid "not a git repository (or any of the parent directories): %s"
+msgstr "no és un dipòsit de git (ni cap dels directoris pares): %s"
 
-#: builtin/branch.c:526
+#: setup.c:1116
 #, c-format
-msgid "Branch renamed to %s, but HEAD is not updated!"
-msgstr "S'ha canviat el nom de la branca a %s, però HEAD no està actualitzat!"
-
-#: builtin/branch.c:535
-msgid "Branch is renamed, but update of config-file failed"
-msgstr ""
-"La branca està canviada de nom, però l'actualització del fitxer de "
-"configuració ha fallat"
-
-#: builtin/branch.c:537
-msgid "Branch is copied, but update of config-file failed"
+msgid ""
+"not a git repository (or any parent up to mount point %s)\n"
+"Stopping at filesystem boundary (GIT_DISCOVERY_ACROSS_FILESYSTEM not set)."
 msgstr ""
-"La branca està copiada, però l'actualització del fitxer de configuració ha "
-"fallat"
+"no un dipòsit de git (ni cap pare fins al punt de muntatge %s)\n"
+"S'atura a la frontera de sistema de fitxers (GIT_DISCOVERY_ACROSS_FILESYSTEM "
+"no està establert)."
 
-#: builtin/branch.c:553
+#: setup.c:1227
 #, c-format
 msgid ""
-"Please edit the description for the branch\n"
-"  %s\n"
-"Lines starting with '%c' will be stripped.\n"
+"problem with core.sharedRepository filemode value (0%.3o).\n"
+"The owner of files must always have read and write permissions."
 msgstr ""
-"Editeu la descripció de la branca\n"
-"  %s\n"
-"S'eliminaran les línies que comencin amb '%c'.\n"
-
-#: builtin/branch.c:586
-msgid "Generic options"
-msgstr "Opcions genèriques"
-
-#: builtin/branch.c:588
-msgid "show hash and subject, give twice for upstream branch"
-msgstr "mostra el hash i l'assumpte, doneu dues vegades per la branca font"
-
-#: builtin/branch.c:589
-msgid "suppress informational messages"
-msgstr "omet els missatges informatius"
-
-#: builtin/branch.c:590
-msgid "set up tracking mode (see git-pull(1))"
-msgstr "configura el mode de seguiment (vegeu git-pull(1))"
+"hi ha un problema amb el valor de mode de fitxer core.sharedRepository "
+"(0%.3o).\n"
+"El propietari dels fitxers sempre ha de tenir permisos de lectura i "
+"escriptura."
 
-#: builtin/branch.c:592
-msgid "do not use"
-msgstr "no usar"
+#: setup.c:1271
+msgid "open /dev/null or dup failed"
+msgstr "s'ha produït un error en obrir /dev/null o dup"
 
-#: builtin/branch.c:594
-msgid "upstream"
-msgstr "font"
+#: setup.c:1286
+msgid "fork failed"
+msgstr "el «fork» ha fallat"
 
-#: builtin/branch.c:594
-msgid "change the upstream info"
-msgstr "canvia la informació de font"
+#: setup.c:1291
+msgid "setsid failed"
+msgstr "l'«stash» ha fallat"
 
-#: builtin/branch.c:595
-msgid "Unset the upstream info"
-msgstr "Desassigna la informació de font"
+#: sha1-file.c:452
+#, c-format
+msgid "object directory %s does not exist; check .git/objects/info/alternates"
+msgstr ""
 
-#: builtin/branch.c:596
-msgid "use colored output"
-msgstr "usa sortida colorada"
+#: sha1-file.c:503
+#, fuzzy, c-format
+msgid "unable to normalize alternate object path: %s"
+msgstr "no s'ha pogut analitzar l'objecte: %s"
 
-#: builtin/branch.c:597
-msgid "act on remote-tracking branches"
-msgstr "actua en branques amb seguiment remot"
+#: sha1-file.c:575
+#, c-format
+msgid "%s: ignoring alternate object stores, nesting too deep"
+msgstr ""
 
-#: builtin/branch.c:599 builtin/branch.c:601
-msgid "print only branches that contain the commit"
-msgstr "imprimeix només les branques que continguin la comissió"
+#: sha1-file.c:582
+#, fuzzy, c-format
+msgid "unable to normalize object directory: %s"
+msgstr "no s'ha pogut analitzar l'objecte: %s"
 
-#: builtin/branch.c:600 builtin/branch.c:602
-msgid "print only branches that don't contain the commit"
-msgstr "imprimeix només les branques que no continguin la comissió"
+#: sha1-file.c:625
+#, fuzzy
+msgid "unable to fdopen alternates lockfile"
+msgstr "no s'han pogut escriure els paràmetres al fitxer de configuració"
 
-#: builtin/branch.c:605
-msgid "Specific git-branch actions:"
-msgstr "Accions de git-branch específiques:"
+#: sha1-file.c:643
+#, fuzzy
+msgid "unable to read alternates file"
+msgstr "no es pot llegir el fitxer d'índex"
 
-#: builtin/branch.c:606
-msgid "list both remote-tracking and local branches"
-msgstr "llista les branques amb seguiment remot i les locals"
+#: sha1-file.c:650
+#, fuzzy
+msgid "unable to move new alternates file into place"
+msgstr "no s'ha pogut escriure un fitxer d'índex nou"
 
-#: builtin/branch.c:608
-msgid "delete fully merged branch"
-msgstr "suprimeix la branca si està completament fusionada"
+#: sha1-file.c:685
+#, c-format
+msgid "path '%s' does not exist"
+msgstr "el camí «%s» no existeix"
 
-#: builtin/branch.c:609
-msgid "delete branch (even if not merged)"
-msgstr "suprimeix la branca (encara que no estigui fusionada)"
+#: sha1-file.c:711
+#, c-format
+msgid "reference repository '%s' as a linked checkout is not supported yet."
+msgstr ""
+"Encara no se suporta el dipòsit de referència «%s» com a agafament enllaçat."
 
-#: builtin/branch.c:610
-msgid "move/rename a branch and its reflog"
-msgstr "mou/canvia de nom una branca i el seu registre de referència"
+#: sha1-file.c:717
+#, c-format
+msgid "reference repository '%s' is not a local repository."
+msgstr "el dipòsit de referència «%s» no és un dipòsit local."
 
-#: builtin/branch.c:611
-msgid "move/rename a branch, even if target exists"
-msgstr "mou/canvia de nom una branca, encara que el destí existeixi"
+#: sha1-file.c:723
+#, c-format
+msgid "reference repository '%s' is shallow"
+msgstr "el dipòsit de referència «%s» és superficial"
 
-#: builtin/branch.c:612
-msgid "copy a branch and its reflog"
-msgstr "copia una branca i el seu registre de referència"
+#: sha1-file.c:731
+#, c-format
+msgid "reference repository '%s' is grafted"
+msgstr "el dipòsit de referència «%s» és empeltat"
 
-#: builtin/branch.c:613
-msgid "copy a branch, even if target exists"
-msgstr "copia una branca, encara que el destí existeixi"
+#: sha1-file.c:791
+#, c-format
+msgid "invalid line while parsing alternate refs: %s"
+msgstr ""
 
-#: builtin/branch.c:614
-msgid "list branch names"
-msgstr "llista els noms de branca"
+#: sha1-file.c:943
+#, c-format
+msgid "attempting to mmap %<PRIuMAX> over limit %<PRIuMAX>"
+msgstr ""
 
-#: builtin/branch.c:615
-msgid "create the branch's reflog"
-msgstr "crea el registre de referència de la branca"
+#: sha1-file.c:964
+msgid "mmap failed"
+msgstr "mmap ha fallat"
 
-#: builtin/branch.c:617
-msgid "edit the description for the branch"
-msgstr "edita la descripció de la branca"
+#: sha1-file.c:1128
+#, c-format
+msgid "object file %s is empty"
+msgstr "el tipus d'objecte %s és buit"
 
-#: builtin/branch.c:618
-msgid "force creation, move/rename, deletion"
-msgstr "força creació, moviment/canvi de nom, supressió"
+#: sha1-file.c:1252 sha1-file.c:2392
+#, fuzzy, c-format
+msgid "corrupt loose object '%s'"
+msgstr "no s'ha pogut analitzar l'objecte «%s»"
 
-#: builtin/branch.c:619
-msgid "print only branches that are merged"
-msgstr "imprimeix només les branques que s'han fusionat"
+#: sha1-file.c:1254 sha1-file.c:2396
+#, fuzzy, c-format
+msgid "garbage at end of loose object '%s'"
+msgstr "no s'ha pogut analitzar l'objecte: %s"
 
-#: builtin/branch.c:620
-msgid "print only branches that are not merged"
-msgstr "imprimeix només les branques que no s'han fusionat"
+#: sha1-file.c:1296
+#, fuzzy
+msgid "invalid object type"
+msgstr "el tipus d'objecte és incorrecte."
 
-#: builtin/branch.c:621
-msgid "list branches in columns"
-msgstr "llista les branques en columnes"
+#: sha1-file.c:1380
+#, c-format
+msgid "unable to unpack %s header with --allow-unknown-type"
+msgstr ""
 
-#: builtin/branch.c:622 builtin/for-each-ref.c:40 builtin/tag.c:411
-msgid "key"
-msgstr "clau"
+#: sha1-file.c:1383
+#, fuzzy, c-format
+msgid "unable to unpack %s header"
+msgstr "no s'ha pogut actualitzar %s"
 
-#: builtin/branch.c:623 builtin/for-each-ref.c:41 builtin/tag.c:412
-msgid "field name to sort on"
-msgstr "nom del camp en el qual ordenar"
+#: sha1-file.c:1389
+#, c-format
+msgid "unable to parse %s header with --allow-unknown-type"
+msgstr ""
 
-#: builtin/branch.c:625 builtin/for-each-ref.c:43 builtin/notes.c:408
-#: builtin/notes.c:411 builtin/notes.c:571 builtin/notes.c:574
-#: builtin/tag.c:414
-msgid "object"
-msgstr "objecte"
+#: sha1-file.c:1392
+#, fuzzy, c-format
+msgid "unable to parse %s header"
+msgstr "no s'ha pogut actualitzar %s"
 
-#: builtin/branch.c:626
-msgid "print only branches of the object"
-msgstr "imprimeix només les branques de l'objecte"
+#: sha1-file.c:1584
+#, fuzzy, c-format
+msgid "failed to read object %s"
+msgstr "s'ha produït un error en llegir l'objecte «%s»."
 
-#: builtin/branch.c:628 builtin/for-each-ref.c:49 builtin/tag.c:421
-msgid "sorting and filtering are case insensitive"
-msgstr "l'ordenació i el filtratge distingeixen entre majúscules i minúscules"
+#: sha1-file.c:1588
+#, fuzzy, c-format
+msgid "replacement %s not found for %s"
+msgstr "no s'han trobat les plantilles %s"
 
-#: builtin/branch.c:629 builtin/for-each-ref.c:38 builtin/tag.c:419
-#: builtin/verify-tag.c:39
-msgid "format to use for the output"
-msgstr "format a usar en la sortida"
+#: sha1-file.c:1592
+#, fuzzy, c-format
+msgid "loose object %s (stored in %s) is corrupt"
+msgstr "l'objecte local %s és malmès"
 
-#: builtin/branch.c:652 builtin/clone.c:735
-msgid "HEAD not found below refs/heads!"
-msgstr "HEAD no trobat sota refs/heads!"
+#: sha1-file.c:1596
+#, fuzzy, c-format
+msgid "packed object %s (stored in %s) is corrupt"
+msgstr "l'objecte local %s és malmès"
 
-#: builtin/branch.c:675
-msgid "--column and --verbose are incompatible"
-msgstr "--column i --verbose són incompatibles"
+#: sha1-file.c:1699
+#, fuzzy, c-format
+msgid "unable to write file %s"
+msgstr "no s'ha pogut escriure %s"
 
-#: builtin/branch.c:690 builtin/branch.c:742 builtin/branch.c:751
-msgid "branch name required"
-msgstr "cal el nom de branca"
+#: sha1-file.c:1706
+#, fuzzy, c-format
+msgid "unable to set permission to '%s'"
+msgstr "no s'ha pogut resoldre la revisió: %s"
 
-#: builtin/branch.c:718
-msgid "Cannot give description to detached HEAD"
-msgstr "No es pot donar descripció a un HEAD separat"
+#: sha1-file.c:1713
+#, fuzzy
+msgid "file write error"
+msgstr "escriptura fallada al rev-list"
 
-#: builtin/branch.c:723
-msgid "cannot edit description of more than one branch"
-msgstr "no es pot editar la descripció de més d'una branca"
+#: sha1-file.c:1732
+#, fuzzy
+msgid "error when closing loose object file"
+msgstr "error en tancar el fitxer de paquet"
 
-#: builtin/branch.c:730
+#: sha1-file.c:1797
 #, c-format
-msgid "No commit on branch '%s' yet."
-msgstr "Encara no hi ha cap comissió en la branca «%s»."
+msgid "insufficient permission for adding an object to repository database %s"
+msgstr ""
 
-#: builtin/branch.c:733
-#, c-format
-msgid "No branch named '%s'."
-msgstr "No hi ha cap branca amb nom «%s»."
+#: sha1-file.c:1799
+#, fuzzy
+msgid "unable to create temporary file"
+msgstr "no s'ha pogut crear un índex temporal"
 
-#: builtin/branch.c:748
-msgid "too many branches for a copy operation"
-msgstr "hi ha massa branques per a una operació de còpia"
+#: sha1-file.c:1823
+#, fuzzy
+msgid "unable to write loose object file"
+msgstr "no s'ha pogut escriure l'objecte de nota"
 
-#: builtin/branch.c:757
-msgid "too many arguments for a rename operation"
-msgstr "hi ha massa arguments per a una operació remota"
+#: sha1-file.c:1829
+#, fuzzy, c-format
+msgid "unable to deflate new object %s (%d)"
+msgstr "no s'ha pogut desinflar l'objecte annexat (%d)"
 
-#: builtin/branch.c:762
-msgid "too many arguments to set new upstream"
-msgstr "hi ha massa arguments per a establir una nova font"
+#: sha1-file.c:1833
+#, fuzzy, c-format
+msgid "deflateEnd on object %s failed (%d)"
+msgstr "ha fallat fstat a %s"
 
-#: builtin/branch.c:766
+#: sha1-file.c:1837
 #, c-format
-msgid ""
-"could not set upstream of HEAD to %s when it does not point to any branch."
+msgid "confused by unstable object source data for %s"
 msgstr ""
-"no s'ha pogut establir la font de HEAD com a %s quan no assenyala cap branca."
 
-#: builtin/branch.c:769 builtin/branch.c:791 builtin/branch.c:807
-#, c-format
-msgid "no such branch '%s'"
-msgstr "no hi ha tal branca «%s»"
+#: sha1-file.c:1847 builtin/pack-objects.c:925
+#, fuzzy, c-format
+msgid "failed utime() on %s"
+msgstr "s'ha produït un error en obrir «%s»"
 
-#: builtin/branch.c:773
-#, c-format
-msgid "branch '%s' does not exist"
-msgstr "la branca «%s» no existeix"
+#: sha1-file.c:1922
+#, fuzzy, c-format
+msgid "cannot read object for %s"
+msgstr "no es pot llegir l'objecte %s"
 
-#: builtin/branch.c:785
-msgid "too many arguments to unset upstream"
-msgstr "hi ha massa arguments per a desassignar la font"
+#: sha1-file.c:1962
+#, fuzzy
+msgid "corrupt commit"
+msgstr "autor corregit de la comissió"
 
-#: builtin/branch.c:789
-msgid "could not unset upstream of HEAD when it does not point to any branch."
-msgstr ""
-"no s'ha pogut desassignar la font de HEAD perquè no assenyala cap branca."
+#: sha1-file.c:1970
+#, fuzzy
+msgid "corrupt tag"
+msgstr "informa de les etiquetes"
 
-#: builtin/branch.c:795
-#, c-format
-msgid "Branch '%s' has no upstream information"
-msgstr "La branca «%s» no té informació de font"
+#: sha1-file.c:2069
+#, fuzzy, c-format
+msgid "read error while indexing %s"
+msgstr "error en llegir %s"
 
-#: builtin/branch.c:810
-msgid "-a and -r options to 'git branch' do not make sense with a branch name"
-msgstr ""
-"les opcions -a i -r a 'git branch' no tenen sentit amb un nom de branca"
+#: sha1-file.c:2072
+#, fuzzy, c-format
+msgid "short read while indexing %s"
+msgstr "no es pot llegir l'índex"
 
-#: builtin/branch.c:813
-msgid ""
-"the '--set-upstream' option is no longer supported. Please use '--track' or "
-"'--set-upstream-to' instead."
-msgstr ""
-"L'opció --set-upstream ja no està suportada. Useu en comptes --track o --set-"
-"upstream-to."
+#: sha1-file.c:2145 sha1-file.c:2154
+#, fuzzy, c-format
+msgid "%s: failed to insert into database"
+msgstr "gpg ha fallat en signar les dades"
 
-#: builtin/bundle.c:45
-#, c-format
-msgid "%s is okay\n"
-msgstr "%s està bé\n"
+#: sha1-file.c:2160
+#, fuzzy, c-format
+msgid "%s: unsupported file type"
+msgstr "versió d'índex no compatible %s"
 
-#: builtin/bundle.c:58
-msgid "Need a repository to create a bundle."
-msgstr "Cal un dipòsit per a fer un farcell."
+#: sha1-file.c:2184
+#, fuzzy, c-format
+msgid "%s is not a valid object"
+msgstr "«%s» no és una terme vàlid"
 
-#: builtin/bundle.c:62
-msgid "Need a repository to unbundle."
-msgstr "Cal un dipòsit per a desfer un farcell."
+#: sha1-file.c:2186
+#, fuzzy, c-format
+msgid "%s is not a valid '%s' object"
+msgstr "%s no és un objecte de «%s» vàlid"
 
-#: builtin/cat-file.c:523
-msgid ""
-"git cat-file (-t [--allow-unknown-type] | -s [--allow-unknown-type] | -e | -"
-"p | <type> | --textconv | --filters) [--path=<path>] <object>"
-msgstr ""
-"git cat-file (-t [--allow-unknown-type] | -s [--allow-unknown-type] | -e | -"
-"p | <tipus> | --textconv | --filters [--path=<camí>]) <objecte>"
+#: sha1-file.c:2213 builtin/index-pack.c:155
+#, c-format
+msgid "unable to open %s"
+msgstr "no s'ha pogut obrir %s"
 
-#: builtin/cat-file.c:524
-msgid ""
-"git cat-file (--batch | --batch-check) [--follow-symlinks] [--textconv | --"
-"filters]"
+#: sha1-file.c:2403 sha1-file.c:2455
+#, c-format
+msgid "hash mismatch for %s (expected %s)"
 msgstr ""
-"git cat-file (--batch | --batch-check) [--follow-symlinks] [--textconv | --"
-"filters]"
 
-#: builtin/cat-file.c:561
-msgid "<type> can be one of: blob, tree, commit, tag"
-msgstr "<tipus> pot ser un de: blob, tree, commit, tag"
+#: sha1-file.c:2427
+#, fuzzy, c-format
+msgid "unable to mmap %s"
+msgstr "no s'ha pogut obrir %s"
 
-#: builtin/cat-file.c:562
-msgid "show object type"
-msgstr "mostra el tipus de l'objecte"
+#: sha1-file.c:2432
+#, fuzzy, c-format
+msgid "unable to unpack header of %s"
+msgstr "no s'ha pogut actualitzar %s"
 
-#: builtin/cat-file.c:563
-msgid "show object size"
-msgstr "mostra la mida de l'objecte"
+#: sha1-file.c:2438
+#, fuzzy, c-format
+msgid "unable to parse header of %s"
+msgstr "no s'ha pogut llegir %s"
 
-#: builtin/cat-file.c:565
-msgid "exit with zero when there's no error"
-msgstr "surt amb zero quan no hi ha error"
+#: sha1-file.c:2449
+#, fuzzy, c-format
+msgid "unable to unpack contents of %s"
+msgstr "no s'ha pogut analitzar el contacte: %s"
 
-#: builtin/cat-file.c:566
-msgid "pretty-print object's content"
-msgstr "imprimeix bellament el contingut de l'objecte"
+#: sha1-name.c:487
+#, c-format
+msgid "short SHA1 %s is ambiguous"
+msgstr "l'SHA1 %s curt és ambigu"
 
-#: builtin/cat-file.c:568
-msgid "for blob objects, run textconv on object's content"
-msgstr "en els objectes de blob, executa textconv en el contingut de l'objecte"
+#: sha1-name.c:498
+msgid "The candidates are:"
+msgstr "Els candidats són:"
 
-#: builtin/cat-file.c:570
-msgid "for blob objects, run filters on object's content"
+#: sha1-name.c:797
+#, fuzzy
+msgid ""
+"Git normally never creates a ref that ends with 40 hex characters\n"
+"because it will be ignored when you just specify 40-hex. These refs\n"
+"may be created by mistake. For example,\n"
+"\n"
+"  git switch -c $br $(git rev-parse ...)\n"
+"\n"
+"where \"$br\" is somehow empty and a 40-hex ref is created. Please\n"
+"examine these refs and maybe delete them. Turn this message off by\n"
+"running \"git config advice.objectNameWarning false\""
 msgstr ""
-"en els objectes de blob, executa els filtres en el contingut de l'objecte"
-
-#: builtin/cat-file.c:571 git-submodule.sh:878
-msgid "blob"
-msgstr "blob"
-
-#: builtin/cat-file.c:572
-msgid "use a specific path for --textconv/--filters"
-msgstr "usa un camí específic per a --textconv/--filters"
-
-#: builtin/cat-file.c:574
-msgid "allow -s and -t to work with broken/corrupt objects"
-msgstr "permet que -s i -t funcionin amb objectes trencats/malmesos"
-
-#: builtin/cat-file.c:575
-msgid "buffer --batch output"
-msgstr "posa la sortida de --batch en memòria intermèdia"
+"Git normalment mai crea una referència que acabi amb 40 caràcters\n"
+"hexadecimals perquè s'ignorarà quan només especifiqueu 40 caràcters\n"
+"hexadecimals. Aquestes referències es poden crear per error. Per\n"
+"exemple,\n"
+"\n"
+"  git checkout -b $br $(git rev-parse ...)\n"
+"\n"
+"on «$br» és d'alguna manera buida i una referència de 40 caràcters\n"
+"hexadecimals. Examineu aquestes referències i potser\n"
+"suprimiu-les. Desactiveu aquest missatge executant\n"
+"«git config advice.objectNameWarning false»"
 
-#: builtin/cat-file.c:577
-msgid "show info and content of objects fed from the standard input"
+#. TRANSLATORS: IEC 80000-13:2008 gibibyte
+#: strbuf.c:822
+#, c-format
+msgid "%u.%2.2u GiB"
 msgstr ""
-"mostra la informació i contingut dels objectes rebuts de l'entrada estàndard"
-
-#: builtin/cat-file.c:580
-msgid "show info about objects fed from the standard input"
-msgstr "mostra informació sobre els objectes rebuts de l'entrada estàndard"
 
-#: builtin/cat-file.c:583
-msgid "follow in-tree symlinks (used with --batch or --batch-check)"
+#. TRANSLATORS: IEC 80000-13:2008 gibibyte/second
+#: strbuf.c:824
+#, c-format
+msgid "%u.%2.2u GiB/s"
 msgstr ""
-"segueix els enllaços simbòlics en l'arbre (s'usa amb --batch o --batch-check)"
-
-#: builtin/cat-file.c:585
-msgid "show all objects with --batch or --batch-check"
-msgstr "mostra tots els objectes amb --batch o --batch-check"
 
-#: builtin/check-attr.c:12
-msgid "git check-attr [-a | --all | <attr>...] [--] <pathname>..."
-msgstr "git check-attr [-a | --all | <atribut>...] [--] <nom-de-camí>..."
-
-#: builtin/check-attr.c:13
-msgid "git check-attr --stdin [-z] [-a | --all | <attr>...]"
-msgstr "git check-attr --stdin [-z] [-a | --all | <atribut>...]"
+#. TRANSLATORS: IEC 80000-13:2008 mebibyte
+#: strbuf.c:832
+#, c-format
+msgid "%u.%2.2u MiB"
+msgstr ""
 
-#: builtin/check-attr.c:20
-msgid "report all attributes set on file"
-msgstr "informa de tots els atributs establerts en el fitxer"
+#. TRANSLATORS: IEC 80000-13:2008 mebibyte/second
+#: strbuf.c:834
+#, c-format
+msgid "%u.%2.2u MiB/s"
+msgstr ""
 
-#: builtin/check-attr.c:21
-msgid "use .gitattributes only from the index"
-msgstr "usa .gitattributes només des de l'índex"
+#. TRANSLATORS: IEC 80000-13:2008 kibibyte
+#: strbuf.c:841
+#, c-format
+msgid "%u.%2.2u KiB"
+msgstr ""
 
-#: builtin/check-attr.c:22 builtin/check-ignore.c:24 builtin/hash-object.c:100
-msgid "read file names from stdin"
-msgstr "llegeix els noms de fitxer de stdin"
+#. TRANSLATORS: IEC 80000-13:2008 kibibyte/second
+#: strbuf.c:843
+#, c-format
+msgid "%u.%2.2u KiB/s"
+msgstr ""
 
-#: builtin/check-attr.c:24 builtin/check-ignore.c:26
-msgid "terminate input and output records by a NUL character"
-msgstr "acaba els registres d'entrada i de sortida amb un caràcter NUL"
+#. TRANSLATORS: IEC 80000-13:2008 byte
+#: strbuf.c:849
+#, fuzzy, c-format
+msgid "%u byte"
+msgid_plural "%u bytes"
+msgstr[0] "%u byte"
+msgstr[1] "%u bytes"
 
-#: builtin/check-ignore.c:20 builtin/checkout.c:1106 builtin/gc.c:358
-msgid "suppress progress reporting"
-msgstr "omet els informes de progrés"
+#. TRANSLATORS: IEC 80000-13:2008 byte/second
+#: strbuf.c:851
+#, fuzzy, c-format
+msgid "%u byte/s"
+msgid_plural "%u bytes/s"
+msgstr[0] "octets"
+msgstr[1] "octets"
 
-#: builtin/check-ignore.c:28
-msgid "show non-matching input paths"
-msgstr "mostra els camins d'entrada que no coincideixin"
+#: strbuf.c:1149
+#, fuzzy, c-format
+msgid "could not edit '%s'"
+msgstr "no s'ha pogut llegir «%s»"
 
-#: builtin/check-ignore.c:30
-msgid "ignore index when checking"
-msgstr "ignora l'índex en comprovar"
+#: submodule.c:114 submodule.c:143
+msgid "Cannot change unmerged .gitmodules, resolve merge conflicts first"
+msgstr ""
+"No es pot canviar un .gitmodules no fusionat, primer resoleu els conflictes "
+"de fusió"
 
-#: builtin/check-ignore.c:159
-msgid "cannot specify pathnames with --stdin"
-msgstr "no es poden especificar noms de camí amb --stdin"
+#: submodule.c:118 submodule.c:147
+#, c-format
+msgid "Could not find section in .gitmodules where path=%s"
+msgstr "No s'ha pogut trobar la secció en .gitmodules on path=%s"
 
-#: builtin/check-ignore.c:162
-msgid "-z only makes sense with --stdin"
-msgstr "-z només té sentit amb --stdin"
+#: submodule.c:154
+#, c-format
+msgid "Could not remove .gitmodules entry for %s"
+msgstr "No s'ha pogut eliminar l'entrada de .gitmodules per a %s"
 
-#: builtin/check-ignore.c:164
-msgid "no path specified"
-msgstr "cap camí especificat"
+#: submodule.c:165
+msgid "staging updated .gitmodules failed"
+msgstr "l'allistament del .gitmodules actualitzat ha fallat"
 
-#: builtin/check-ignore.c:168
-msgid "--quiet is only valid with a single pathname"
-msgstr "--quiet només és vàlid amb un sol nom de camí"
+#: submodule.c:327
+#, c-format
+msgid "in unpopulated submodule '%s'"
+msgstr "al submòdul sense popular «%s»"
 
-#: builtin/check-ignore.c:170
-msgid "cannot have both --quiet and --verbose"
-msgstr "no es poden especificar --quiet i --verbose alhora"
+#: submodule.c:358
+#, c-format
+msgid "Pathspec '%s' is in submodule '%.*s'"
+msgstr "L'especificació «%s» és en el submòdul «%.*s»"
 
-#: builtin/check-ignore.c:173
-msgid "--non-matching is only valid with --verbose"
-msgstr "--non-matching és vàlid només amb --verbose"
+#: submodule.c:910
+#, c-format
+msgid "submodule entry '%s' (%s) is a %s, not a commit"
+msgstr "l'entrada del submòdul «%s» (%s) és a %s, no és una comissió"
 
-#: builtin/check-mailmap.c:9
-msgid "git check-mailmap [<options>] <contact>..."
-msgstr "git check-mailmap [<opcions>] <contacte>..."
+#: submodule.c:1147 builtin/branch.c:680 builtin/submodule--helper.c:2016
+msgid "Failed to resolve HEAD as a valid ref."
+msgstr "S'ha produït un error en resoldre HEAD com a referència vàlida."
 
-#: builtin/check-mailmap.c:14
-msgid "also read contacts from stdin"
-msgstr "també llegeix els contactes des de stdin"
+#: submodule.c:1481
+#, fuzzy, c-format
+msgid "Could not access submodule '%s'"
+msgstr "s'ha produït un error en cercar recursivament al camí de submòdul «%s»"
 
-#: builtin/check-mailmap.c:25
+#: submodule.c:1651
 #, c-format
-msgid "unable to parse contact: %s"
-msgstr "no s'ha pogut analitzar el contacte: %s"
+msgid "'%s' not recognized as a git repository"
+msgstr "«%s» no reconegut com un dipòsit git"
 
-#: builtin/check-mailmap.c:48
-msgid "no contacts specified"
-msgstr "no hi ha contactes especificats"
+#: submodule.c:1789
+#, c-format
+msgid "could not start 'git status' in submodule '%s'"
+msgstr "no s'ha pogut iniciar «git status» al submòdul «%s»"
 
-#: builtin/checkout-index.c:128
-msgid "git checkout-index [<options>] [--] [<file>...]"
-msgstr "git checkout-index [<opcions>] [--] [<fitxer>...]"
+#: submodule.c:1802
+#, c-format
+msgid "could not run 'git status' in submodule '%s'"
+msgstr "no s'ha pogut executar 'git status' al submòdul «%s»"
 
-#: builtin/checkout-index.c:143
-msgid "stage should be between 1 and 3 or all"
-msgstr "«stage» ha de ser entre 1 i 3 o all"
+#: submodule.c:1817
+#, fuzzy, c-format
+msgid "Could not unset core.worktree setting in submodule '%s'"
+msgstr "no s'ha pogut executar 'git status' al submòdul «%s»"
 
-#: builtin/checkout-index.c:159
-msgid "check out all files in the index"
-msgstr "agafa tots els fitxers en l'índex"
+#: submodule.c:1907
+#, c-format
+msgid "submodule '%s' has dirty index"
+msgstr "el submòdul «%s» té l'índex brut"
 
-#: builtin/checkout-index.c:160
-msgid "force overwrite of existing files"
-msgstr "força la sobreescriptura de fitxers existents"
+#: submodule.c:1959
+#, fuzzy, c-format
+msgid "Submodule '%s' could not be updated."
+msgstr "Submòduls canviats però no actualitzats:"
 
-#: builtin/checkout-index.c:162
-msgid "no warning for existing files and files not in index"
+#: submodule.c:2027
+#, c-format
+msgid "submodule git dir '%s' is inside git dir '%.*s'"
 msgstr ""
-"cap advertència per a fitxers existents i fitxers que no siguin a l'índex"
 
-#: builtin/checkout-index.c:164
-msgid "don't checkout new files"
-msgstr "no agafis fitxers nous"
+#: submodule.c:2048
+#, c-format
+msgid ""
+"relocate_gitdir for submodule '%s' with more than one worktree not supported"
+msgstr ""
+"no està admès relocate_gitdir per al submòdul «%s» amb més d'un arbre de "
+"treball"
 
-#: builtin/checkout-index.c:166
-msgid "update stat information in the index file"
-msgstr "actualitza la informació d'estadístiques en el fitxer d'índex"
+#: submodule.c:2060 submodule.c:2119
+#, c-format
+msgid "could not lookup name for submodule '%s'"
+msgstr "no s'ha trobat el nom pel submòdul «%s»"
 
-#: builtin/checkout-index.c:170
-msgid "read list of paths from the standard input"
-msgstr "llegeix la llista de camins des de l'entrada estàndard"
+#: submodule.c:2064
+#, c-format
+msgid "refusing to move '%s' into an existing git dir"
+msgstr ""
 
-#: builtin/checkout-index.c:172
-msgid "write the content to temporary files"
-msgstr "escriu el contingut a fitxers temporals"
+#: submodule.c:2071
+#, c-format
+msgid ""
+"Migrating git directory of '%s%s' from\n"
+"'%s' to\n"
+"'%s'\n"
+msgstr ""
+"S'està migrant el directori de «%s%s» des de\n"
+"«%s» a\n"
+"«%s»\n"
 
-#: builtin/checkout-index.c:173 builtin/column.c:31
-#: builtin/submodule--helper.c:1203 builtin/submodule--helper.c:1206
-#: builtin/submodule--helper.c:1212 builtin/submodule--helper.c:1574
-#: builtin/worktree.c:570
-msgid "string"
-msgstr "cadena"
+#: submodule.c:2154
+#, c-format
+msgid "could not recurse into submodule '%s'"
+msgstr "s'ha produït un error en cercar recursivament al camí de submòdul «%s»"
 
-#: builtin/checkout-index.c:174
-msgid "when creating files, prepend <string>"
-msgstr "en crear fitxers, anteposa <cadena>"
+#: submodule.c:2198
+msgid "could not start ls-files in .."
+msgstr "no s'ha pogut iniciar ls-files a .."
 
-#: builtin/checkout-index.c:176
-msgid "copy out the files from named stage"
-msgstr "copia els fitxers des de «stage» amb nom"
+#: submodule.c:2237
+#, c-format
+msgid "ls-tree returned unexpected return code %d"
+msgstr "ls-tree ha retornat un codi de retorn %d no esperat"
 
-#: builtin/checkout.c:27
-msgid "git checkout [<options>] <branch>"
-msgstr "git checkout [<opcions>] <branca>"
+#: submodule-config.c:236
+#, fuzzy, c-format
+msgid "ignoring suspicious submodule name: %s"
+msgstr "s'està ignorant la referència amb nom malmès %s"
 
-#: builtin/checkout.c:28
-msgid "git checkout [<options>] [<branch>] -- <file>..."
-msgstr "git checkout [<opcions>] [<branca>] -- <fitxer>..."
+#: submodule-config.c:303
+msgid "negative values not allowed for submodule.fetchjobs"
+msgstr "no es permeten els valors negatius a submodule.fetchjobs"
 
-#: builtin/checkout.c:136 builtin/checkout.c:169
+#: submodule-config.c:401
 #, c-format
-msgid "path '%s' does not have our version"
-msgstr "el camí «%s» no té la nostra versió"
+msgid "ignoring '%s' which may be interpreted as a command-line option: %s"
+msgstr ""
 
-#: builtin/checkout.c:138 builtin/checkout.c:171
+#: submodule-config.c:498
 #, c-format
-msgid "path '%s' does not have their version"
-msgstr "el camí «%s» no té la seva versió"
+msgid "invalid value for %s"
+msgstr "valor no vàlid per a %s"
 
-#: builtin/checkout.c:154
+#: submodule-config.c:769
 #, c-format
-msgid "path '%s' does not have all necessary versions"
-msgstr "el camí «%s» no té totes les versions necessàries"
+msgid "Could not update .gitmodules entry %s"
+msgstr "No s'ha pogut actualitzar l'entrada de .gitmodules %s"
 
-#: builtin/checkout.c:198
+#: trailer.c:238
 #, c-format
-msgid "path '%s' does not have necessary versions"
-msgstr "el camí «%s» no té les versions necessàries"
+msgid "running trailer command '%s' failed"
+msgstr "l'execució de l'ordre de remolc «%s» ha fallat"
 
-#: builtin/checkout.c:215
+#: trailer.c:485 trailer.c:490 trailer.c:495 trailer.c:549 trailer.c:553
+#: trailer.c:557
 #, c-format
-msgid "path '%s': cannot merge"
-msgstr "camí «%s»: no es pot fusionar"
+msgid "unknown value '%s' for key '%s'"
+msgstr "valor desconegut «%s» per a la clau «%s»"
 
-#: builtin/checkout.c:231
+#: trailer.c:539 trailer.c:544 builtin/remote.c:295
 #, c-format
-msgid "Unable to add merge result for '%s'"
-msgstr "No s'ha pogut afegir el resultat de fusió per a «%s»"
+msgid "more than one %s"
+msgstr "més d'un %s"
 
-#: builtin/checkout.c:253 builtin/checkout.c:256 builtin/checkout.c:259
-#: builtin/checkout.c:262
+#: trailer.c:730
 #, c-format
-msgid "'%s' cannot be used with updating paths"
-msgstr "«%s» no es pot usar amb actualització de camins"
+msgid "empty trailer token in trailer '%.*s'"
+msgstr "testimoni de remolc buit en el remolc '%.*s'"
 
-#: builtin/checkout.c:265 builtin/checkout.c:268
+#: trailer.c:750
 #, c-format
-msgid "'%s' cannot be used with %s"
-msgstr "«%s» no es pot usar amb %s"
+msgid "could not read input file '%s'"
+msgstr "no s'ha pogut llegir el fitxer d'entrada «%s»"
 
-#: builtin/checkout.c:271
-#, c-format
-msgid "Cannot update paths and switch to branch '%s' at the same time."
-msgstr ""
-"No es poden actualitzar els camins i canviar a la branca «%s» a la vegada."
+#: trailer.c:753
+msgid "could not read from stdin"
+msgstr "no s'ha pogut llegir des de stdin"
 
-#: builtin/checkout.c:340 builtin/checkout.c:347
+#: trailer.c:1011 wrapper.c:665
 #, c-format
-msgid "path '%s' is unmerged"
-msgstr "el camí «%s» està sense fusionar"
-
-#: builtin/checkout.c:505
-msgid "you need to resolve your current index first"
-msgstr "heu de primer resoldre el vostre índex actual"
+msgid "could not stat %s"
+msgstr "no s'ha pogut fer stat a %s"
 
-#: builtin/checkout.c:636
+#: trailer.c:1013
 #, c-format
-msgid "Can not do reflog for '%s': %s\n"
-msgstr "No es pot fer reflog per a «%s»: %s\n"
+msgid "file %s is not a regular file"
+msgstr "el fitxer %s no és un fitxer regular"
 
-#: builtin/checkout.c:677
-msgid "HEAD is now at"
-msgstr "HEAD ara és a"
+#: trailer.c:1015
+#, c-format
+msgid "file %s is not writable by user"
+msgstr "el fitxer %s no és gravable per l'usuari"
 
-#: builtin/checkout.c:681 builtin/clone.c:689
-msgid "unable to update HEAD"
-msgstr "no s'ha pogut actualitzar HEAD"
+#: trailer.c:1027
+msgid "could not open temporary file"
+msgstr "no s'ha pogut obrir el fitxer temporal"
 
-#: builtin/checkout.c:685
+#: trailer.c:1067
 #, c-format
-msgid "Reset branch '%s'\n"
-msgstr "Restableix la branca «%s»\n"
+msgid "could not rename temporary file to %s"
+msgstr "no s'ha pogut canviar el nom del fitxer temporal a %s"
 
-#: builtin/checkout.c:688
+#: transport.c:116
 #, c-format
-msgid "Already on '%s'\n"
-msgstr "Ja en «%s»\n"
+msgid "Would set upstream of '%s' to '%s' of '%s'\n"
+msgstr "Canviaria la font de «%s» a «%s» de «%s»\n"
 
-#: builtin/checkout.c:692
-#, c-format
-msgid "Switched to and reset branch '%s'\n"
-msgstr "S'ha canviat i restablert a la branca «%s»\n"
+#: transport.c:145
+#, fuzzy, c-format
+msgid "could not read bundle '%s'"
+msgstr "no s'ha pogut llegir el fitxer «%s»"
 
-#: builtin/checkout.c:694 builtin/checkout.c:1039
+#: transport.c:214
 #, c-format
-msgid "Switched to a new branch '%s'\n"
-msgstr "S'ha canviat a la branca nova «%s»\n"
+msgid "transport: invalid depth option '%s'"
+msgstr "transport: opció de profunditat no vàlida «%s»"
 
-#: builtin/checkout.c:696
-#, c-format
-msgid "Switched to branch '%s'\n"
-msgstr "S'ha canviat a la branca «%s»\n"
+#: transport.c:266
+msgid "see protocol.version in 'git help config' for more details"
+msgstr ""
+
+#: transport.c:267
+msgid "server options require protocol version 2 or later"
+msgstr ""
+
+#: transport.c:632
+#, fuzzy
+msgid "could not parse transport.color.* config"
+msgstr "no s'ha pogut analitzar l'script d'autor"
+
+#: transport.c:705
+msgid "support for protocol v2 not implemented yet"
+msgstr ""
+
+#: transport.c:831
+#, fuzzy, c-format
+msgid "unknown value for config '%s': %s"
+msgstr "valor desconegut «%s» per a la clau «%s»"
+
+#: transport.c:897
+#, fuzzy, c-format
+msgid "transport '%s' not allowed"
+msgstr "no s'ha trobat la branca «%s»."
 
-#: builtin/checkout.c:747
+#: transport.c:949
+msgid "git-over-rsync is no longer supported"
+msgstr ""
+
+#: transport.c:1044
 #, c-format
-msgid " ... and %d more.\n"
-msgstr " ... i %d més.\n"
+msgid ""
+"The following submodule paths contain changes that can\n"
+"not be found on any remote:\n"
+msgstr ""
+"Els camins de submòdul següents contenen canvis que no\n"
+"es poden trobar en cap remot:\n"
 
-#: builtin/checkout.c:753
+#: transport.c:1048
 #, c-format
 msgid ""
-"Warning: you are leaving %d commit behind, not connected to\n"
-"any of your branches:\n"
 "\n"
-"%s\n"
-msgid_plural ""
-"Warning: you are leaving %d commits behind, not connected to\n"
-"any of your branches:\n"
-"\n"
-"%s\n"
-msgstr[0] ""
-"Advertència: esteu deixant enrere %d comissió, no\n"
-"connectada a cap de les vostres branques:\n"
+"Please try\n"
 "\n"
-"%s\n"
-msgstr[1] ""
-"Advertència: esteu deixant enrere %d comissions, no\n"
-"connectades a cap de les vostres branques:\n"
+"\tgit push --recurse-submodules=on-demand\n"
 "\n"
-"%s\n"
-
-#: builtin/checkout.c:772
-#, c-format
-msgid ""
-"If you want to keep it by creating a new branch, this may be a good time\n"
-"to do so with:\n"
+"or cd to the path and use\n"
 "\n"
-" git branch <new-branch-name> %s\n"
+"\tgit push\n"
 "\n"
-msgid_plural ""
-"If you want to keep them by creating a new branch, this may be a good time\n"
-"to do so with:\n"
+"to push them to a remote.\n"
 "\n"
-" git branch <new-branch-name> %s\n"
+msgstr ""
 "\n"
-msgstr[0] ""
-"Si la voleu mantenir creant una branca nova, ara pot ser un bon moment\n"
-"per a fer-ho amb:\n"
+"Intenteu\n"
 "\n"
-" git branch <nom-de-branca-nova> %s\n"
+"\tgit push --recurse-submodules=on-demand\n"
 "\n"
-msgstr[1] ""
-"Si les voleu mantenir creant una branca nova, ara pot ser un bon moment\n"
-"per a fer-ho amb:\n"
+"o canviar de directori al camí i useu\n"
 "\n"
-" git branch <nom-de-branca-nova> %s\n"
+"\tgit push\n"
 "\n"
+"per a pujar-los a un remot.\n"
 
-#: builtin/checkout.c:804
-msgid "internal error in revision walk"
-msgstr "error intern en el passeig per revisions"
+#: transport.c:1056
+msgid "Aborting."
+msgstr "S'està avortant."
 
-#: builtin/checkout.c:808
-msgid "Previous HEAD position was"
-msgstr "La posició de HEAD anterior era"
+#: transport.c:1201
+#, fuzzy
+msgid "failed to push all needed submodules"
+msgstr "s'ha produït un error en cercar recursivament al submòdul «%s»"
 
-#: builtin/checkout.c:836 builtin/checkout.c:1034
-msgid "You are on a branch yet to be born"
-msgstr "Sou en una branca que encara ha de néixer"
+#: transport.c:1345 transport-helper.c:656
+#, fuzzy
+msgid "operation not supported by protocol"
+msgstr "opció no admesa amb --recurse-submodules."
 
-#: builtin/checkout.c:940
-#, c-format
-msgid "only one reference expected, %d given."
-msgstr "s'esperava només una referència, s'han donat %d."
+#: transport-helper.c:61 transport-helper.c:90
+#, fuzzy
+msgid "full write to remote helper failed"
+msgstr "imprimeix l'estat des de l'ajudant remot"
 
-#: builtin/checkout.c:980 builtin/worktree.c:249
-#, c-format
-msgid "invalid reference: %s"
-msgstr "referència no vàlida: %s"
+#: transport-helper.c:144
+#, fuzzy, c-format
+msgid "unable to find remote helper for '%s'"
+msgstr "No s'ha pogut afegir el resultat de fusió per a «%s»"
+
+#: transport-helper.c:160 transport-helper.c:570
+msgid "can't dup helper output fd"
+msgstr ""
 
-#: builtin/checkout.c:1009
+#: transport-helper.c:211
 #, c-format
-msgid "reference is not a tree: %s"
-msgstr "la referència no és un arbre: %s"
+msgid ""
+"unknown mandatory capability %s; this remote helper probably needs newer "
+"version of Git"
+msgstr ""
 
-#: builtin/checkout.c:1048
-msgid "paths cannot be used with switching branches"
-msgstr "els camins no es poden usar amb canvi de branca"
+#: transport-helper.c:217
+msgid "this remote helper should implement refspec capability"
+msgstr ""
 
-#: builtin/checkout.c:1051 builtin/checkout.c:1055
-#, c-format
-msgid "'%s' cannot be used with switching branches"
-msgstr "«%s» no es pot usar amb canvi de branca"
+#: transport-helper.c:284 transport-helper.c:424
+#, fuzzy, c-format
+msgid "%s unexpectedly said: '%s'"
+msgstr "blob esperat per a %s «%s»"
 
-#: builtin/checkout.c:1059 builtin/checkout.c:1062 builtin/checkout.c:1067
-#: builtin/checkout.c:1070
+#: transport-helper.c:413
 #, c-format
-msgid "'%s' cannot be used with '%s'"
-msgstr "«%s» no es pot usar amb «%s»"
+msgid "%s also locked %s"
+msgstr "%s també ha bloquejat %s"
 
-#: builtin/checkout.c:1075
-#, c-format
-msgid "Cannot switch branch to a non-commit '%s'"
-msgstr "No es pot canviar la branca a la no comissió «%s»"
+#: transport-helper.c:492
+#, fuzzy
+msgid "couldn't run fast-import"
+msgstr "no s'ha pogut executar «stash»."
 
-#: builtin/checkout.c:1107 builtin/checkout.c:1109 builtin/clone.c:116
-#: builtin/remote.c:166 builtin/remote.c:168 builtin/worktree.c:387
-#: builtin/worktree.c:389
-msgid "branch"
-msgstr "branca"
+#: transport-helper.c:515
+#, fuzzy
+msgid "error while running fast-import"
+msgstr "error en tancar el fitxer de paquet"
 
-#: builtin/checkout.c:1108
-msgid "create and checkout a new branch"
-msgstr "crea i agafa una branca nova"
+#: transport-helper.c:544 transport-helper.c:1133
+#, fuzzy, c-format
+msgid "could not read ref %s"
+msgstr "No s'ha pogut llegir la referència %s"
 
-#: builtin/checkout.c:1110
-msgid "create/reset and checkout a branch"
-msgstr "crea/restableix i agafa una branca"
+#: transport-helper.c:589
+#, fuzzy, c-format
+msgid "unknown response to connect: %s"
+msgstr "opció desconeguda: %s\n"
 
-#: builtin/checkout.c:1111
-msgid "create reflog for new branch"
-msgstr "crea un registre de referència per a la branca nova"
+#: transport-helper.c:611
+msgid "setting remote service path not supported by protocol"
+msgstr ""
 
-#: builtin/checkout.c:1112 builtin/worktree.c:391
-msgid "detach HEAD at named commit"
-msgstr "separa HEAD a la comissió anomenada"
+#: transport-helper.c:613
+#, fuzzy
+msgid "invalid remote service path"
+msgstr "referència no vàlida: %s"
 
-#: builtin/checkout.c:1113
-msgid "set upstream info for new branch"
-msgstr "estableix la informació de font de la branca nova"
+#: transport-helper.c:659
+#, c-format
+msgid "can't connect to subservice %s"
+msgstr ""
 
-#: builtin/checkout.c:1115
-msgid "new-branch"
-msgstr "branca-nova"
+#: transport-helper.c:735
+#, fuzzy, c-format
+msgid "expected ok/error, helper said '%s'"
+msgstr "blob esperat per a %s «%s»"
 
-#: builtin/checkout.c:1115
-msgid "new unparented branch"
-msgstr "branca òrfena nova"
+#: transport-helper.c:788
+#, fuzzy, c-format
+msgid "helper reported unexpected status of %s"
+msgstr "ls-tree ha retornat un codi de retorn %d no esperat"
 
-#: builtin/checkout.c:1116
-msgid "checkout our version for unmerged files"
-msgstr "agafa la versió nostra dels fitxers sense fusionar"
+#: transport-helper.c:849
+#, fuzzy, c-format
+msgid "helper %s does not support dry-run"
+msgstr "El servidor no admet --deepen"
 
-#: builtin/checkout.c:1118
-msgid "checkout their version for unmerged files"
-msgstr "agafa la versió seva dels fitxers sense fusionar"
+#: transport-helper.c:852
+#, fuzzy, c-format
+msgid "helper %s does not support --signed"
+msgstr "El servidor no admet --shallow-since"
 
-#: builtin/checkout.c:1120
-msgid "force checkout (throw away local modifications)"
-msgstr "agafa a la força (descarta qualsevol modificació local)"
+#: transport-helper.c:855
+#, fuzzy, c-format
+msgid "helper %s does not support --signed=if-asked"
+msgstr "el destí receptor no admet pujar --signed"
 
-#: builtin/checkout.c:1122
-msgid "perform a 3-way merge with the new branch"
-msgstr "realitza una fusió de 3 vies amb la branca nova"
+#: transport-helper.c:860
+#, fuzzy, c-format
+msgid "helper %s does not support --atomic"
+msgstr "El servidor no admet --shallow-since"
 
-#: builtin/checkout.c:1124 builtin/merge.c:239
-msgid "update ignored files (default)"
-msgstr "actualitza els fitxers ignorats (per defecte)"
+#: transport-helper.c:866
+#, fuzzy, c-format
+msgid "helper %s does not support 'push-option'"
+msgstr "el destí receptor no admet opcions de pujada"
 
-#: builtin/checkout.c:1126 builtin/log.c:1499 parse-options.h:263
-msgid "style"
-msgstr "estil"
+#: transport-helper.c:964
+msgid "remote-helper doesn't support push; refspec needed"
+msgstr ""
 
-#: builtin/checkout.c:1127
-msgid "conflict style (merge or diff3)"
-msgstr "estil de conflicte (fusió o diff3)"
+#: transport-helper.c:969
+#, fuzzy, c-format
+msgid "helper %s does not support 'force'"
+msgstr "El servidor no admet --deepen"
 
-#: builtin/checkout.c:1130
-msgid "do not limit pathspecs to sparse entries only"
-msgstr "no limitis les especificacions de camí només a entrades disperses"
+#: transport-helper.c:1016
+#, fuzzy
+msgid "couldn't run fast-export"
+msgstr "no s'ha pogut executar «stash»."
 
-#: builtin/checkout.c:1132
-msgid "second guess 'git checkout <no-such-branch>'"
-msgstr "dubta 'git checkout <cap-branca-així>'"
+#: transport-helper.c:1021
+#, fuzzy
+msgid "error while running fast-export"
+msgstr "error en tancar el fitxer de paquet"
 
-#: builtin/checkout.c:1134
-msgid "do not check if another worktree is holding the given ref"
-msgstr "no comprovis si altre arbre de treball té la referència donada"
+#: transport-helper.c:1046
+#, c-format
+msgid ""
+"No refs in common and none specified; doing nothing.\n"
+"Perhaps you should specify a branch such as 'master'.\n"
+msgstr ""
 
-#: builtin/checkout.c:1138 builtin/clone.c:83 builtin/fetch.c:150
-#: builtin/merge.c:236 builtin/pull.c:123 builtin/push.c:556
-#: builtin/send-pack.c:173
-msgid "force progress reporting"
-msgstr "força l'informe de progrés"
+#: transport-helper.c:1119
+#, fuzzy, c-format
+msgid "malformed response in ref list: %s"
+msgstr "full d'opcions mal format: «%s»"
 
-#: builtin/checkout.c:1168
-msgid "-b, -B and --orphan are mutually exclusive"
-msgstr "-b, -B i --orphan són mútuament excloents"
+#: transport-helper.c:1271
+#, fuzzy, c-format
+msgid "read(%s) failed"
+msgstr "%s ha fallat"
 
-#: builtin/checkout.c:1185
-msgid "--track needs a branch name"
-msgstr "--track necessita un nom de branca"
+#: transport-helper.c:1298
+#, fuzzy, c-format
+msgid "write(%s) failed"
+msgstr "%s ha fallat"
 
-#: builtin/checkout.c:1190
-msgid "Missing branch name; try -b"
-msgstr "Manca el nom de branca; proveu -b"
+#: transport-helper.c:1347
+#, fuzzy, c-format
+msgid "%s thread failed"
+msgstr "%s ha fallat"
 
-#: builtin/checkout.c:1226
-msgid "invalid path specification"
-msgstr "especificació de camí no vàlida"
+#: transport-helper.c:1351
+#, fuzzy, c-format
+msgid "%s thread failed to join: %s"
+msgstr "s'ha produït un error en obrir «%s»"
 
-#: builtin/checkout.c:1233
+#: transport-helper.c:1370 transport-helper.c:1374
 #, c-format
-msgid "'%s' is not a commit and a branch '%s' cannot be created from it"
+msgid "can't start thread for copying data: %s"
 msgstr ""
-"«%s» no és una comissió i la branca «%s» no es pot crear a partir d'aquesta "
-"comissió"
 
-#: builtin/checkout.c:1237
+#: transport-helper.c:1411
 #, c-format
-msgid "git checkout: --detach does not take a path argument '%s'"
-msgstr "git checkout: --detach no accepta un paràmetre de camí «%s»"
-
-#: builtin/checkout.c:1241
-msgid ""
-"git checkout: --ours/--theirs, --force and --merge are incompatible when\n"
-"checking out of the index."
+msgid "%s process failed to wait"
 msgstr ""
-"git checkout: --ours/--theirs, --force i --merge són incompatibles en\n"
-"agafar de l'índex."
 
-#: builtin/clean.c:26
-msgid ""
-"git clean [-d] [-f] [-i] [-n] [-q] [-e <pattern>] [-x | -X] [--] <paths>..."
+#: transport-helper.c:1415
+#, fuzzy, c-format
+msgid "%s process failed"
+msgstr "%s ha fallat"
+
+#: transport-helper.c:1433 transport-helper.c:1442
+msgid "can't start thread for copying data"
 msgstr ""
-"git clean [-d] [-f] [-i] [-n] [-q] [-e <patró>] [-x | -X] [--] <camins>..."
 
-#: builtin/clean.c:30
-#, c-format
-msgid "Removing %s\n"
-msgstr "S'està eliminant %s\n"
+#: tree-walk.c:33
+msgid "too-short tree object"
+msgstr "objecte d'arbre massa curt"
 
-#: builtin/clean.c:31
-#, c-format
-msgid "Would remove %s\n"
-msgstr "Eliminaria %s\n"
+#: tree-walk.c:39
+msgid "malformed mode in tree entry"
+msgstr "mode mal format en entrada d'arbre"
 
-#: builtin/clean.c:32
-#, c-format
-msgid "Skipping repository %s\n"
-msgstr "S'està ometent el dipòsit %s\n"
+#: tree-walk.c:43
+msgid "empty filename in tree entry"
+msgstr "nom de fitxer buit en una entrada d'arbre"
 
-#: builtin/clean.c:33
+#: tree-walk.c:48
 #, c-format
-msgid "Would skip repository %s\n"
-msgstr "Ometria el dipòsit %s\n"
+msgid "filename in tree entry contains backslash: '%s'"
+msgstr ""
 
-#: builtin/clean.c:34
-#, c-format
-msgid "failed to remove %s"
-msgstr "s'ha produït un error en eliminar %s"
+#: tree-walk.c:124
+msgid "too-short tree file"
+msgstr "fitxer d'arbre massa curt"
 
-#: builtin/clean.c:302 git-add--interactive.perl:572
+#: unpack-trees.c:110
 #, c-format
 msgid ""
-"Prompt help:\n"
-"1          - select a numbered item\n"
-"foo        - select item based on unique prefix\n"
-"           - (empty) select nothing\n"
+"Your local changes to the following files would be overwritten by checkout:\n"
+"%%sPlease commit your changes or stash them before you switch branches."
 msgstr ""
-"Ajuda:\n"
-"1          - selecciona un ítem numerat\n"
-"foo        - selecciona un ítem basat en un prefix únic\n"
-"           - (buit) no seleccionis res\n"
+"Els vostres canvis locals als fitxers següents se sobreescriurien per "
+"agafar:\n"
+"%%sCometeu els vostres canvis o feu «stash» abans de canviar de branca."
 
-#: builtin/clean.c:306 git-add--interactive.perl:581
+#: unpack-trees.c:112
 #, c-format
 msgid ""
-"Prompt help:\n"
-"1          - select a single item\n"
-"3-5        - select a range of items\n"
-"2-3,6-9    - select multiple ranges\n"
-"foo        - select item based on unique prefix\n"
-"-...       - unselect specified items\n"
-"*          - choose all items\n"
-"           - (empty) finish selecting\n"
+"Your local changes to the following files would be overwritten by checkout:\n"
+"%%s"
 msgstr ""
-"Ajuda:\n"
-"1          - selecciona un sol ítem\n"
-"3-5        - selecciona un rang d'ítems\n"
-"2-3,6-9    - selecciona múltiples rangs\n"
-"foo        - selecciona un ítem basat en un prefix únic\n"
-"-...       - desselecciona els ítems seleccionats\n"
-"*          - tria tots els ítems\n"
-"           - (buit) finalitza la selecció\n"
-
-#: builtin/clean.c:522 git-add--interactive.perl:547
-#: git-add--interactive.perl:552
-#, c-format, perl-format
-msgid "Huh (%s)?\n"
-msgstr "Perdó (%s)?\n"
+"Els vostres canvis locals als fitxers següents se sobreescriurien per "
+"agafar:\n"
+"%%s"
 
-#: builtin/clean.c:664
+#: unpack-trees.c:115
 #, c-format
-msgid "Input ignore patterns>> "
-msgstr "Introduïu els patrons a ignorar>> "
+msgid ""
+"Your local changes to the following files would be overwritten by merge:\n"
+"%%sPlease commit your changes or stash them before you merge."
+msgstr ""
+"Els vostres canvis locals als fitxers següents se sobreescriurien per "
+"fusionar:\n"
+"%%sCometeu els vostres canvis o feu «stash» abans de fusionar."
 
-#: builtin/clean.c:701
+#: unpack-trees.c:117
 #, c-format
-msgid "WARNING: Cannot find items matched by: %s"
-msgstr "ADVERTÈNCIA: No es poden trobar ítems que coincideixin amb: %s"
-
-#: builtin/clean.c:722
-msgid "Select items to delete"
-msgstr "Selecciona els ítems a suprimir"
+msgid ""
+"Your local changes to the following files would be overwritten by merge:\n"
+"%%s"
+msgstr ""
+"Els vostres canvis locals als fitxers següents se sobreescriurien per "
+"fusionar:\n"
+"%%s"
 
-#. TRANSLATORS: Make sure to keep [y/N] as is
-#: builtin/clean.c:763
+#: unpack-trees.c:120
 #, c-format
-msgid "Remove %s [y/N]? "
-msgstr "Voleu eliminar %s [y/N]? "
+msgid ""
+"Your local changes to the following files would be overwritten by %s:\n"
+"%%sPlease commit your changes or stash them before you %s."
+msgstr ""
+"Els vostres canvis locals als fitxers següents se sobreescriurien per %s:\n"
+"%%sCometeu els vostres canvis o feu «stash» abans de %s."
 
-#: builtin/clean.c:788 git-add--interactive.perl:1710
+#: unpack-trees.c:122
 #, c-format
-msgid "Bye.\n"
-msgstr "Adeu.\n"
-
-#: builtin/clean.c:796
 msgid ""
-"clean               - start cleaning\n"
-"filter by pattern   - exclude items from deletion\n"
-"select by numbers   - select items to be deleted by numbers\n"
-"ask each            - confirm each deletion (like \"rm -i\")\n"
-"quit                - stop cleaning\n"
-"help                - this screen\n"
-"?                   - help for prompt selection"
+"Your local changes to the following files would be overwritten by %s:\n"
+"%%s"
 msgstr ""
-"clean               - comença a netejar\n"
-"filter by pattern   - exclou ítems de supressió\n"
-"select by numbers   - selecciona ítems a suprimir per números\n"
-"ask each            - confirma cada supressió (com \"rm -i\")\n"
-"quit                - deixa de netejar\n"
-"help                - aquesta pantalla\n"
-"?                   - ajuda de selecció de l'avís"
-
-#: builtin/clean.c:823 git-add--interactive.perl:1786
-msgid "*** Commands ***"
-msgstr "*** Ordres ***"
-
-#: builtin/clean.c:824 git-add--interactive.perl:1783
-msgid "What now"
-msgstr "I ara què"
-
-#: builtin/clean.c:832
-msgid "Would remove the following item:"
-msgid_plural "Would remove the following items:"
-msgstr[0] "Eliminaria l'ítem següent:"
-msgstr[1] "Eliminaria els ítems següents:"
-
-#: builtin/clean.c:848
-msgid "No more files to clean, exiting."
-msgstr "No hi ha més fitxers a netejar; s'està sortint."
-
-#: builtin/clean.c:910
-msgid "do not print names of files removed"
-msgstr "no imprimeixis els noms dels fitxers eliminats"
+"Els vostres canvis locals als fitxers següents se sobreescriurien per %s:\n"
+"%%s"
 
-#: builtin/clean.c:912
-msgid "force"
-msgstr "força"
+#: unpack-trees.c:127
+#, c-format
+msgid ""
+"Updating the following directories would lose untracked files in them:\n"
+"%s"
+msgstr ""
+"En actualitzar els directoris següents perdria fitxers no seguits en el:\n"
+"%s"
 
-#: builtin/clean.c:913
-msgid "interactive cleaning"
-msgstr "neteja interactiva"
+#: unpack-trees.c:131
+#, c-format
+msgid ""
+"The following untracked working tree files would be removed by checkout:\n"
+"%%sPlease move or remove them before you switch branches."
+msgstr ""
+"Els següents fitxers no seguits en l'arbre de treball s'eliminarien per "
+"agafar:\n"
+"%%sMoveu-los o elimineu-los abans de canviar de branca."
 
-#: builtin/clean.c:915
-msgid "remove whole directories"
-msgstr "elimina directoris sencers"
+#: unpack-trees.c:133
+#, c-format
+msgid ""
+"The following untracked working tree files would be removed by checkout:\n"
+"%%s"
+msgstr ""
+"Els següents fitxers no seguits en l'arbre de treball s'eliminarien per "
+"agafar:\n"
+"%%s"
 
-#: builtin/clean.c:916 builtin/describe.c:533 builtin/describe.c:535
-#: builtin/grep.c:871 builtin/log.c:157 builtin/log.c:159
-#: builtin/ls-files.c:548 builtin/name-rev.c:397 builtin/name-rev.c:399
-#: builtin/show-ref.c:176
-msgid "pattern"
-msgstr "patró"
+#: unpack-trees.c:136
+#, c-format
+msgid ""
+"The following untracked working tree files would be removed by merge:\n"
+"%%sPlease move or remove them before you merge."
+msgstr ""
+"Els següents fitxers no seguits en l'arbre de treball s'eliminarien per "
+"fusionar:\n"
+"%%sMoveu-los o elimineu-los abans de fusionar."
 
-#: builtin/clean.c:917
-msgid "add <pattern> to ignore rules"
-msgstr "afegiu <patró> per a ignorar les regles"
+#: unpack-trees.c:138
+#, c-format
+msgid ""
+"The following untracked working tree files would be removed by merge:\n"
+"%%s"
+msgstr ""
+"Els següents fitxers no seguits en l'arbre de treball s'eliminarien per "
+"fusionar:\n"
+"%%s"
 
-#: builtin/clean.c:918
-msgid "remove ignored files, too"
-msgstr "elimina els fitxers ignorats, també"
+#: unpack-trees.c:141
+#, c-format
+msgid ""
+"The following untracked working tree files would be removed by %s:\n"
+"%%sPlease move or remove them before you %s."
+msgstr ""
+"Els següents fitxers no seguits en l'arbre de treball s'eliminarien per %s:\n"
+"%%sMoveu-los o elimineu-los abans de %s."
 
-#: builtin/clean.c:920
-msgid "remove only ignored files"
-msgstr "elimina només els fitxers ignorats"
+#: unpack-trees.c:143
+#, c-format
+msgid ""
+"The following untracked working tree files would be removed by %s:\n"
+"%%s"
+msgstr ""
+"Els següents fitxers no seguits en l'arbre de treball s'eliminarien per %s:\n"
+"%%s"
 
-#: builtin/clean.c:938
-msgid "-x and -X cannot be used together"
-msgstr "-x i -X no es poden usar junts"
+#: unpack-trees.c:149
+#, c-format
+msgid ""
+"The following untracked working tree files would be overwritten by "
+"checkout:\n"
+"%%sPlease move or remove them before you switch branches."
+msgstr ""
+"Els següents fitxers no seguits en l'arbre de treball se sobreescriurien per "
+"agafar:\n"
+"%%sMoveu-los o elimineu-los abans de canviar de branca."
 
-#: builtin/clean.c:942
+#: unpack-trees.c:151
+#, c-format
 msgid ""
-"clean.requireForce set to true and neither -i, -n, nor -f given; refusing to "
-"clean"
+"The following untracked working tree files would be overwritten by "
+"checkout:\n"
+"%%s"
 msgstr ""
-"clean.requireForce està establerta en cert i ni -i, -n ni -f s'han indicat; "
-"refusant netejar"
+"Els següents fitxers no seguits en l'arbre de treball se sobreescriurien per "
+"agafar:\n"
+"%%s"
 
-#: builtin/clean.c:945
+#: unpack-trees.c:154
+#, c-format
 msgid ""
-"clean.requireForce defaults to true and neither -i, -n, nor -f given; "
-"refusing to clean"
+"The following untracked working tree files would be overwritten by merge:\n"
+"%%sPlease move or remove them before you merge."
 msgstr ""
-"clean.requireForce és per defecte cert i ni -i, -n ni -f s'han indicat; "
-"refusant netejar"
+"Els següents fitxers no seguits en l'arbre de treball se sobreescriurien per "
+"fusionar:\n"
+"%%sMoveu-los o elimineu-los abans de fusionar."
 
-#: builtin/clone.c:40
-msgid "git clone [<options>] [--] <repo> [<dir>]"
-msgstr "git clone [<opcions>] [--] <dipòsit> [<directori>]"
+#: unpack-trees.c:156
+#, c-format
+msgid ""
+"The following untracked working tree files would be overwritten by merge:\n"
+"%%s"
+msgstr ""
+"Els següents fitxers no seguits en l'arbre de treball se sobreescriurien per "
+"fusionar:\n"
+"%%s"
 
-#: builtin/clone.c:85
-msgid "don't create a checkout"
-msgstr "no facis cap agafament"
-
-#: builtin/clone.c:86 builtin/clone.c:88 builtin/init-db.c:479
-msgid "create a bare repository"
-msgstr "crea un dipòsit nu"
-
-#: builtin/clone.c:90
-msgid "create a mirror repository (implies bare)"
-msgstr "crea un dipòsit mirall (implica bare)"
-
-#: builtin/clone.c:92
-msgid "to clone from a local repository"
-msgstr "per a clonar des d'un dipòsit local"
-
-#: builtin/clone.c:94
-msgid "don't use local hardlinks, always copy"
-msgstr "no usis enllaços durs locals, sempre copia"
-
-#: builtin/clone.c:96
-msgid "setup as shared repository"
-msgstr "configura com a dipòsit compartit"
-
-#: builtin/clone.c:98 builtin/clone.c:102
-msgid "pathspec"
-msgstr "especificació de camí"
-
-#: builtin/clone.c:98 builtin/clone.c:102
-msgid "initialize submodules in the clone"
-msgstr "inicialitza els submòduls en el clon"
-
-#: builtin/clone.c:105
-msgid "number of submodules cloned in parallel"
-msgstr "nombre de submòduls clonats en paral·lel"
-
-#: builtin/clone.c:106 builtin/init-db.c:476
-msgid "template-directory"
-msgstr "directori-de-plantilla"
-
-#: builtin/clone.c:107 builtin/init-db.c:477
-msgid "directory from which templates will be used"
-msgstr "directori des del qual s'usaran les plantilles"
-
-#: builtin/clone.c:109 builtin/clone.c:111 builtin/submodule--helper.c:1210
-#: builtin/submodule--helper.c:1577
-msgid "reference repository"
-msgstr "dipòsit de referència"
-
-#: builtin/clone.c:113
-msgid "use --reference only while cloning"
-msgstr "usa --reference només en clonar"
-
-#: builtin/clone.c:114 builtin/column.c:27 builtin/merge-file.c:44
-msgid "name"
-msgstr "nom"
-
-#: builtin/clone.c:115
-msgid "use <name> instead of 'origin' to track upstream"
-msgstr "usa <nom> en lloc de 'origin' per a seguir la font"
-
-#: builtin/clone.c:117
-msgid "checkout <branch> instead of the remote's HEAD"
-msgstr "agafa <branca> en lloc de la HEAD del remot"
-
-#: builtin/clone.c:119
-msgid "path to git-upload-pack on the remote"
-msgstr "camí a git-upload-pack en el remot"
-
-#: builtin/clone.c:120 builtin/fetch.c:151 builtin/grep.c:813
-#: builtin/pull.c:211
-msgid "depth"
-msgstr "profunditat"
-
-#: builtin/clone.c:121
-msgid "create a shallow clone of that depth"
-msgstr "crea un clon superficial de tal profunditat"
-
-#: builtin/clone.c:122 builtin/fetch.c:153 builtin/pack-objects.c:3017
-#: parse-options.h:154
-msgid "time"
-msgstr "hora"
-
-#: builtin/clone.c:123
-msgid "create a shallow clone since a specific time"
-msgstr "crea un clon superficial des d'una hora específica"
-
-#: builtin/clone.c:124 builtin/fetch.c:155
-msgid "revision"
-msgstr "revisió"
-
-#: builtin/clone.c:125 builtin/fetch.c:156
-msgid "deepen history of shallow clone, excluding rev"
-msgstr "aprofundeix la història d'un clon superficial, excloent una revisió"
-
-#: builtin/clone.c:127
-msgid "clone only one branch, HEAD or --branch"
-msgstr "clona només una branca, HEAD o --branch"
-
-#: builtin/clone.c:129
-msgid "don't clone any tags, and make later fetches not to follow them"
+#: unpack-trees.c:159
+#, c-format
+msgid ""
+"The following untracked working tree files would be overwritten by %s:\n"
+"%%sPlease move or remove them before you %s."
 msgstr ""
-"no cloneu cap etiqueta, i feu que els «fetch» següents no els segueixen"
-
-#: builtin/clone.c:131
-msgid "any cloned submodules will be shallow"
-msgstr "qualsevol submòdul clonat serà superficial"
-
-#: builtin/clone.c:132 builtin/init-db.c:485
-msgid "gitdir"
-msgstr "directori de git"
-
-#: builtin/clone.c:133 builtin/init-db.c:486
-msgid "separate git dir from working tree"
-msgstr "separa el directori de git de l'arbre de treball"
-
-#: builtin/clone.c:134
-msgid "key=value"
-msgstr "clau=valor"
-
-#: builtin/clone.c:135
-msgid "set config inside the new repository"
-msgstr "estableix la configuració dins del dipòsit nou"
-
-#: builtin/clone.c:136 builtin/fetch.c:173 builtin/pull.c:224
-#: builtin/push.c:567
-msgid "use IPv4 addresses only"
-msgstr "usa només adreces IPv4"
-
-#: builtin/clone.c:138 builtin/fetch.c:175 builtin/pull.c:227
-#: builtin/push.c:569
-msgid "use IPv6 addresses only"
-msgstr "usa només adreces IPv6"
+"Els següents fitxers no seguits en l'arbre de treball se sobreescriurien per "
+"%s:\n"
+"%%sMoveu-los o elimineu-los abans de %s."
 
-#: builtin/clone.c:276
+#: unpack-trees.c:161
+#, c-format
 msgid ""
-"No directory name could be guessed.\n"
-"Please specify a directory on the command line"
+"The following untracked working tree files would be overwritten by %s:\n"
+"%%s"
 msgstr ""
-"No s'ha pogut endevinar cap nom de directori.\n"
-"Especifiqueu un directori en la línia d'ordres"
+"Els següents fitxers no seguits en l'arbre de treball se sobreescriurien per "
+"%s:\n"
+"%%s"
 
-#: builtin/clone.c:329
+#: unpack-trees.c:169
 #, c-format
-msgid "info: Could not add alternate for '%s': %s\n"
-msgstr "info: No s'ha pogut afegir un alternatiu per a «%s»: %s\n"
+msgid "Entry '%s' overlaps with '%s'.  Cannot bind."
+msgstr "L'entrada «%s» encavalca amb «%s».  No es pot vincular."
 
-#: builtin/clone.c:401
+#: unpack-trees.c:172
 #, c-format
-msgid "failed to open '%s'"
-msgstr "s'ha produït un error en obrir «%s»"
+msgid ""
+"Cannot update sparse checkout: the following entries are not up to date:\n"
+"%s"
+msgstr ""
+"No es pot actualitzar l'agafament parcial: les entrades següents no estan al "
+"dia:\n"
+"%s"
 
-#: builtin/clone.c:409
+#: unpack-trees.c:174
 #, c-format
-msgid "%s exists and is not a directory"
-msgstr "%s existeix i no és directori"
+msgid ""
+"The following working tree files would be overwritten by sparse checkout "
+"update:\n"
+"%s"
+msgstr ""
+"Els fitxers següents en l'arbre de treball se sobreescriurien per "
+"actualitzar l'agafament parcial:\n"
+"%s"
 
-#: builtin/clone.c:423
+#: unpack-trees.c:176
 #, c-format
-msgid "failed to stat %s\n"
-msgstr "s'ha produït un error en fer stat a '%s'\n"
+msgid ""
+"The following working tree files would be removed by sparse checkout "
+"update:\n"
+"%s"
+msgstr ""
+"Els fitxers següents en l'arbre de treball s'eliminarien per actualitzar "
+"l'agafament parcial:\n"
+"%s"
 
-#: builtin/clone.c:445
+#: unpack-trees.c:178
 #, c-format
-msgid "failed to create link '%s'"
-msgstr "s'ha produït un error en crear l'enllaç «%s»"
+msgid ""
+"Cannot update submodule:\n"
+"%s"
+msgstr ""
+"No es pot actualitzar el submòdul:\n"
+"%s"
 
-#: builtin/clone.c:449
+#: unpack-trees.c:255
 #, c-format
-msgid "failed to copy file to '%s'"
-msgstr "s'ha produït un error en copiar el fitxer a «%s»"
+msgid "Aborting\n"
+msgstr "S'està avortant\n"
 
-#: builtin/clone.c:475
-#, c-format
-msgid "done.\n"
-msgstr "fet.\n"
+#: unpack-trees.c:317
+msgid "Updating files"
+msgstr "S'estan actualitzant els fitxers"
 
-#: builtin/clone.c:489
+#: unpack-trees.c:349
 msgid ""
-"Clone succeeded, but checkout failed.\n"
-"You can inspect what was checked out with 'git status'\n"
-"and retry the checkout with 'git checkout -f HEAD'\n"
+"the following paths have collided (e.g. case-sensitive paths\n"
+"on a case-insensitive filesystem) and only one from the same\n"
+"colliding group is in the working tree:\n"
 msgstr ""
-"El clonatge ha tingut èxit, però l'agafament ha\n"
-"fallat. Podeu inspeccionar què s'ha agafat amb\n"
-"'git status' i tornar a intentar l'agafament amb\n"
-"'git checkout -f HEAD'\n"
 
-#: builtin/clone.c:566
-#, c-format
-msgid "Could not find remote branch %s to clone."
-msgstr "No s'ha pogut trobar la branca remota %s per a clonar."
+#: unpack-trees.c:1441
+#, fuzzy
+msgid "Updating index flags"
+msgstr "S'estan actualitzant els fitxers"
 
-#: builtin/clone.c:661
-msgid "remote did not send all necessary objects"
-msgstr "el remot no ha enviat tots els objectes necessaris"
+#: urlmatch.c:163
+msgid "invalid URL scheme name or missing '://' suffix"
+msgstr "l'esquema d'URL no és vàlid o li manca el sufix '://'"
 
-#: builtin/clone.c:677
+#: urlmatch.c:187 urlmatch.c:346 urlmatch.c:405
 #, c-format
-msgid "unable to update %s"
-msgstr "no s'ha pogut actualitzar %s"
-
-#: builtin/clone.c:726
-msgid "remote HEAD refers to nonexistent ref, unable to checkout.\n"
-msgstr ""
-"la HEAD remot es refereix a una referència que no existeix; no s'ha pogut "
-"agafar.\n"
-
-#: builtin/clone.c:756
-msgid "unable to checkout working tree"
-msgstr "no s'ha pogut agafar l'arbre de treball"
+msgid "invalid %XX escape sequence"
+msgstr "seqüència d'escapament %XX no vàlida"
 
-#: builtin/clone.c:801
-msgid "unable to write parameters to config file"
-msgstr "no s'han pogut escriure els paràmetres al fitxer de configuració"
+#: urlmatch.c:215
+msgid "missing host and scheme is not 'file:'"
+msgstr "manca la màquina i l'esquema no és 'file:'"
 
-#: builtin/clone.c:864
-msgid "cannot repack to clean up"
-msgstr "no es pot reempaquetar per a netejar"
+#: urlmatch.c:232
+msgid "a 'file:' URL may not have a port number"
+msgstr "un URL 'file:' no pot tenir número de port"
 
-#: builtin/clone.c:866
-msgid "cannot unlink temporary alternates file"
-msgstr "no es pot desenllaçar el fitxer d'alternatives temporal"
+#: urlmatch.c:247
+msgid "invalid characters in host name"
+msgstr "hi ha caràcters no vàlids en el nom de màquina"
 
-#: builtin/clone.c:906 builtin/receive-pack.c:1946
-msgid "Too many arguments."
-msgstr "Hi ha massa paràmetres."
+#: urlmatch.c:292 urlmatch.c:303
+msgid "invalid port number"
+msgstr "número de port no vàlid"
 
-#: builtin/clone.c:910
-msgid "You must specify a repository to clone."
-msgstr "Heu d'especificar un dipòsit per a clonar."
+#: urlmatch.c:371
+msgid "invalid '..' path segment"
+msgstr "segment de camí '..' no vàlid"
 
-#: builtin/clone.c:923
+#: worktree.c:258 builtin/am.c:2084
 #, c-format
-msgid "--bare and --origin %s options are incompatible."
-msgstr "les opcions --bare i --origin %s són incompatibles."
-
-#: builtin/clone.c:926
-msgid "--bare and --separate-git-dir are incompatible."
-msgstr "--bare i --separate-git-dir són incompatibles."
+msgid "failed to read '%s'"
+msgstr "s'ha produït un error en llegir «%s»"
 
-#: builtin/clone.c:939
+#: worktree.c:304
 #, c-format
-msgid "repository '%s' does not exist"
-msgstr "el dipòsit «%s» no existeix"
+msgid "'%s' at main working tree is not the repository directory"
+msgstr ""
 
-#: builtin/clone.c:945 builtin/fetch.c:1455
+#: worktree.c:315
 #, c-format
-msgid "depth %s is not a positive number"
-msgstr "la profunditat %s no és nombre positiu"
+msgid "'%s' file does not contain absolute path to the working tree location"
+msgstr ""
 
-#: builtin/clone.c:955
+#: worktree.c:327
 #, c-format
-msgid "destination path '%s' already exists and is not an empty directory."
-msgstr "el camí destí «%s» ja existeix i no és un directori buit."
+msgid "'%s' does not exist"
+msgstr "«%s» no existeix"
 
-#: builtin/clone.c:965
+#: worktree.c:333
 #, c-format
-msgid "working tree '%s' already exists."
-msgstr "l'arbre de treball «%s» ja existeix."
+msgid "'%s' is not a .git file, error code %d"
+msgstr "«%s» no és un fitxer .git, codi d'error %d"
 
-#: builtin/clone.c:980 builtin/clone.c:1001 builtin/difftool.c:270
-#: builtin/worktree.c:255 builtin/worktree.c:285
+#: worktree.c:341
 #, c-format
-msgid "could not create leading directories of '%s'"
-msgstr "no s'han pogut crear els directoris inicials de «%s»"
+msgid "'%s' does not point back to '%s'"
+msgstr "«%s» no assenyala de tornada a «%s»"
 
-#: builtin/clone.c:985
+#: wrapper.c:186 wrapper.c:356
 #, c-format
-msgid "could not create work tree dir '%s'"
-msgstr "no s'ha pogut crear el directori d'arbre de treball «%s»"
+msgid "could not open '%s' for reading and writing"
+msgstr "no s'ha pogut obrir «%s» per a lectura i escriptura"
 
-#: builtin/clone.c:1005
+#: wrapper.c:387 wrapper.c:588
 #, c-format
-msgid "Cloning into bare repository '%s'...\n"
-msgstr "S'està clonant al dipòsit nu «%s»...\n"
+msgid "unable to access '%s'"
+msgstr "no s'ha pogut accedir a «%s»"
 
-#: builtin/clone.c:1007
-#, c-format
-msgid "Cloning into '%s'...\n"
-msgstr "S'està clonant a «%s»...\n"
+#: wrapper.c:596
+msgid "unable to get current working directory"
+msgstr "no s'ha pogut obtenir el directori de treball actual"
 
-#: builtin/clone.c:1031
-msgid ""
-"clone --recursive is not compatible with both --reference and --reference-if-"
-"able"
+#: wt-status.c:158
+msgid "Unmerged paths:"
+msgstr "Camins sense fusionar:"
+
+#: wt-status.c:187 wt-status.c:219
+#, fuzzy
+msgid "  (use \"git restore --staged <file>...\" to unstage)"
+msgstr "  (useu \"git reset %s <fitxer>...\" per a fer «unstage»)"
+
+#: wt-status.c:190 wt-status.c:222
+#, fuzzy, c-format
+msgid "  (use \"git restore --source=%s --staged <file>...\" to unstage)"
+msgstr "  (useu \"git reset %s <fitxer>...\" per a fer «unstage»)"
+
+#: wt-status.c:193 wt-status.c:225
+msgid "  (use \"git rm --cached <file>...\" to unstage)"
+msgstr "  (useu \"git rm --cached <fitxer>...\" per a fer «unstage»)"
+
+#: wt-status.c:197
+msgid "  (use \"git add <file>...\" to mark resolution)"
+msgstr "  (useu \"git add <fitxer>...\" per a senyalar resolució)"
+
+#: wt-status.c:199 wt-status.c:203
+msgid "  (use \"git add/rm <file>...\" as appropriate to mark resolution)"
 msgstr ""
-"clone --recursive no és compatible amb ambdós --reference i --reference-if-"
-"able"
+"  (useu \"git add/rm <fitxer>...\" segons sigui apropiat per a senyalar "
+"resolució)"
 
-#: builtin/clone.c:1093
-msgid "--depth is ignored in local clones; use file:// instead."
-msgstr "--depth s'ignora en els clons locals; useu file:// en lloc d'això."
+#: wt-status.c:201
+msgid "  (use \"git rm <file>...\" to mark resolution)"
+msgstr "  (useu \"git rm <fitxer>...\" per a senyalar resolució)"
 
-#: builtin/clone.c:1095
-msgid "--shallow-since is ignored in local clones; use file:// instead."
+#: wt-status.c:211 wt-status.c:1074
+msgid "Changes to be committed:"
+msgstr "Canvis a cometre:"
+
+#: wt-status.c:234 wt-status.c:1083
+msgid "Changes not staged for commit:"
+msgstr "Canvis no «staged» per a cometre:"
+
+#: wt-status.c:238
+msgid "  (use \"git add <file>...\" to update what will be committed)"
+msgstr "  (useu \"git add <fitxer>...\" per a actualitzar què es cometrà)"
+
+#: wt-status.c:240
+msgid "  (use \"git add/rm <file>...\" to update what will be committed)"
+msgstr "  (useu \"git add/rm <fitxer>...\" per a actualitzar què es cometrà)"
+
+#: wt-status.c:241
+#, fuzzy
+msgid ""
+"  (use \"git restore <file>...\" to discard changes in working directory)"
 msgstr ""
-"--shallow-since s'ignora en els clons locals; useu file:// en lloc d'això."
+"  (useu \"git checkout -- <fitxer>...\" per a descartar els canvis en el "
+"directori de treball)"
 
-#: builtin/clone.c:1097
-msgid "--shallow-exclude is ignored in local clones; use file:// instead."
+#: wt-status.c:243
+msgid "  (commit or discard the untracked or modified content in submodules)"
 msgstr ""
-"--shallow-exclude s'ignora en els clons locals; useu file:// en lloc d'això."
+"  (cometeu o descarteu el contingut modificat o no seguit en els submòduls)"
 
-#: builtin/clone.c:1099
-msgid "--filter is ignored in local clones; use file:// instead."
-msgstr "--filter s'ignora en els clons locals; useu file:// en lloc d'això."
+#: wt-status.c:254
+#, c-format
+msgid "  (use \"git %s <file>...\" to include in what will be committed)"
+msgstr "  (useu \"git %s <fitxer>...\" per a incloure-ho en el que es cometrà)"
 
-#: builtin/clone.c:1102
-msgid "source repository is shallow, ignoring --local"
-msgstr "el dipòsit font és superficial, s'està ignorant --local"
+#: wt-status.c:268
+msgid "both deleted:"
+msgstr "suprimit per ambdós:"
 
-#: builtin/clone.c:1107
-msgid "--local is ignored"
-msgstr "--local s'ignora"
+#: wt-status.c:270
+msgid "added by us:"
+msgstr "afegit per nosaltres:"
 
-#: builtin/clone.c:1169 builtin/clone.c:1177
-#, c-format
-msgid "Remote branch %s not found in upstream %s"
-msgstr "La branca remota %s no es troba en la font %s"
+#: wt-status.c:272
+msgid "deleted by them:"
+msgstr "suprimit per ells:"
 
-#: builtin/clone.c:1180
-msgid "You appear to have cloned an empty repository."
-msgstr "Sembla que heu clonat un dipòsit buit."
+#: wt-status.c:274
+msgid "added by them:"
+msgstr "afegit per ells:"
 
-#: builtin/column.c:10
-msgid "git column [<options>]"
-msgstr "git column [<opcions>]"
+#: wt-status.c:276
+msgid "deleted by us:"
+msgstr "suprimit per nosaltres:"
 
-#: builtin/column.c:27
-msgid "lookup config vars"
-msgstr "cerca les variables de configuració"
+#: wt-status.c:278
+msgid "both added:"
+msgstr "afegit per ambdós:"
 
-#: builtin/column.c:28 builtin/column.c:29
-msgid "layout to use"
-msgstr "disposició a usar"
+#: wt-status.c:280
+msgid "both modified:"
+msgstr "modificat per ambdós:"
 
-#: builtin/column.c:30
-msgid "Maximum width"
-msgstr "Amplada màxima"
+#: wt-status.c:290
+msgid "new file:"
+msgstr "fitxer nou:"
 
-#: builtin/column.c:31
-msgid "Padding space on left border"
-msgstr "Espai d'encoixinada en el marge esquerre"
+#: wt-status.c:292
+msgid "copied:"
+msgstr "copiat:"
 
-#: builtin/column.c:32
-msgid "Padding space on right border"
-msgstr "Espai d'encoixinada en el marge dret"
+#: wt-status.c:294
+msgid "deleted:"
+msgstr "suprimit:"
 
-#: builtin/column.c:33
-msgid "Padding space between columns"
-msgstr "Espai d'encoixinada entre columnes"
+#: wt-status.c:296
+msgid "modified:"
+msgstr "modificat:"
 
-#: builtin/column.c:52
-msgid "--command must be the first argument"
-msgstr "--command ha de ser el primer paràmetre"
+#: wt-status.c:298
+msgid "renamed:"
+msgstr "canviat de nom:"
 
-#: builtin/commit.c:37
-msgid "git commit [<options>] [--] <pathspec>..."
-msgstr "git commit [<opcions>] [--] <especificació-de-camí>..."
+#: wt-status.c:300
+msgid "typechange:"
+msgstr "canviat de tipus:"
 
-#: builtin/commit.c:42
-msgid "git status [<options>] [--] <pathspec>..."
-msgstr "git status [<opcions>] [--] <especificació-de-camí>..."
+#: wt-status.c:302
+msgid "unknown:"
+msgstr "desconegut:"
+
+#: wt-status.c:304
+msgid "unmerged:"
+msgstr "sense fusionar:"
+
+#: wt-status.c:384
+msgid "new commits, "
+msgstr "comissions noves, "
+
+#: wt-status.c:386
+msgid "modified content, "
+msgstr "contingut modificat, "
+
+#: wt-status.c:388
+msgid "untracked content, "
+msgstr "contingut no seguit, "
+
+#: wt-status.c:906
+#, c-format
+msgid "Your stash currently has %d entry"
+msgid_plural "Your stash currently has %d entries"
+msgstr[0] "L'«stash» té actualment %d entrada"
+msgstr[1] "L'«stash» té actualment %d entrades"
+
+#: wt-status.c:938
+msgid "Submodules changed but not updated:"
+msgstr "Submòduls canviats però no actualitzats:"
+
+#: wt-status.c:940
+msgid "Submodule changes to be committed:"
+msgstr "Canvis de submòdul a cometre:"
 
-#: builtin/commit.c:47
+#: wt-status.c:1022
 msgid ""
-"You asked to amend the most recent commit, but doing so would make\n"
-"it empty. You can repeat your command with --allow-empty, or you can\n"
-"remove the commit entirely with \"git reset HEAD^\".\n"
+"Do not modify or remove the line above.\n"
+"Everything below it will be ignored."
 msgstr ""
-"Heu demanat esmenar la comissió més recent, però fer això la\n"
-"deixaria buida. Podeu repetir la vostra ordre amb --allow-empty, o\n"
-"podeu eliminar la comissió per complet amb \"git reset HEAD^\".\n"
+"No modifiqueu o suprimiu la línia de dalt.\n"
+"Tot el que hi ha a sota s'ignorarà."
 
-#: builtin/commit.c:52
+#: wt-status.c:1114
+#, c-format
 msgid ""
-"The previous cherry-pick is now empty, possibly due to conflict resolution.\n"
-"If you wish to commit it anyway, use:\n"
-"\n"
-"    git commit --allow-empty\n"
 "\n"
+"It took %.2f seconds to compute the branch ahead/behind values.\n"
+"You can use '--no-ahead-behind' to avoid this.\n"
 msgstr ""
-"El «cherry pick» previ ja està buit, possiblement a causa de resolució de "
-"conflicte.\n"
-"Si el voleu cometre de totes maneres, useu:\n"
-"\n"
-"    git commit --allow-empty\n"
-"\n"
 
-#: builtin/commit.c:59
-msgid "Otherwise, please use 'git reset'\n"
-msgstr "D'altra manera, useu «git reset»\n"
+#: wt-status.c:1144
+msgid "You have unmerged paths."
+msgstr "Teniu camins sense fusionar."
 
-#: builtin/commit.c:62
-msgid ""
-"If you wish to skip this commit, use:\n"
-"\n"
-"    git reset\n"
-"\n"
-"Then \"git cherry-pick --continue\" will resume cherry-picking\n"
-"the remaining commits.\n"
-msgstr ""
-"Si voleu ometre aquesta comissió, useu:\n"
-"\n"
-"    git reset\n"
-"\n"
-"Llavors \"git cherry-pick --continue\" reprendrà\n"
-"com a «cherry pick» les comissions restants.\n"
+#: wt-status.c:1147
+msgid "  (fix conflicts and run \"git commit\")"
+msgstr "  (arregleu els conflictes i executeu \"git commit\")"
 
-#: builtin/commit.c:284
-msgid "failed to unpack HEAD tree object"
-msgstr "s'ha produït un error en desempaquetar l'objecte d'arbre HEAD"
+#: wt-status.c:1149
+msgid "  (use \"git merge --abort\" to abort the merge)"
+msgstr "  (useu \"git merge --abort\" per a avortar la fusió)"
 
-#: builtin/commit.c:325
-msgid "unable to create temporary index"
-msgstr "no s'ha pogut crear un índex temporal"
+#: wt-status.c:1153
+msgid "All conflicts fixed but you are still merging."
+msgstr "Tots els conflictes estan arreglats però encara esteu fusionant."
 
-#: builtin/commit.c:331
-msgid "interactive add failed"
-msgstr "l'afegiment interactiu ha fallat"
+#: wt-status.c:1156
+msgid "  (use \"git commit\" to conclude merge)"
+msgstr "  (useu \"git commit\" per a concloure la fusió)"
 
-#: builtin/commit.c:344
-msgid "unable to update temporary index"
-msgstr "no s'ha pogut actualitzar l'índex temporal"
+#: wt-status.c:1165
+msgid "You are in the middle of an am session."
+msgstr "Esteu enmig d'una sessió am."
 
-#: builtin/commit.c:346
-msgid "Failed to update main cache tree"
-msgstr "S'ha produït un error en actualitzar l'arbre principal de memòria cau"
+#: wt-status.c:1168
+msgid "The current patch is empty."
+msgstr "El pedaç actual està buit."
 
-#: builtin/commit.c:371 builtin/commit.c:395 builtin/commit.c:444
-msgid "unable to write new_index file"
-msgstr "no s'ha pogut escriure el fitxer new_index"
+#: wt-status.c:1172
+msgid "  (fix conflicts and then run \"git am --continue\")"
+msgstr "  (arregleu els conflictes i després executeu \"git am --continue\")"
 
-#: builtin/commit.c:427
-msgid "cannot do a partial commit during a merge."
-msgstr "no es pot fer una comissió parcial durant una fusió."
+#: wt-status.c:1174
+msgid "  (use \"git am --skip\" to skip this patch)"
+msgstr "  (useu \"git am --skip\" per a ometre aquest pedaç)"
 
-#: builtin/commit.c:429
-msgid "cannot do a partial commit during a cherry-pick."
-msgstr "no es pot fer una comissió parcial durant un «cherry pick»."
+#: wt-status.c:1176
+msgid "  (use \"git am --abort\" to restore the original branch)"
+msgstr "  (useu \"git am --abort\" per a restaurar la branca original)"
 
-#: builtin/commit.c:437
-msgid "cannot read the index"
-msgstr "no es pot llegir l'índex"
+#: wt-status.c:1309
+msgid "git-rebase-todo is missing."
+msgstr "Manca git-rebase-todo."
 
-#: builtin/commit.c:456
-msgid "unable to write temporary index file"
-msgstr "no s'ha pogut escriure un fitxer d'índex temporal"
+#: wt-status.c:1311
+msgid "No commands done."
+msgstr "No s'ha fet cap ordre."
 
-#: builtin/commit.c:553
+#: wt-status.c:1314
 #, c-format
-msgid "commit '%s' lacks author header"
-msgstr "a la comissió «%s» li manca la capçalera d'autor"
+msgid "Last command done (%d command done):"
+msgid_plural "Last commands done (%d commands done):"
+msgstr[0] "Última ordre feta (%d ordre feta):"
+msgstr[1] "Últimes ordres fetes (%d ordres fetes):"
 
-#: builtin/commit.c:555
+#: wt-status.c:1325
 #, c-format
-msgid "commit '%s' has malformed author line"
-msgstr "la comissió «%s» té una línia d'autor mal formada"
-
-#: builtin/commit.c:574
-msgid "malformed --author parameter"
-msgstr "paràmetre --author mal format"
-
-#: builtin/commit.c:626
-msgid ""
-"unable to select a comment character that is not used\n"
-"in the current commit message"
-msgstr ""
-"no es pot seleccionar un caràcter de comentari que\n"
-"no sigui usat en el missatge de comissió actual"
+msgid "  (see more in file %s)"
+msgstr "  (vegeu més en el fitxer %s)"
 
-#: builtin/commit.c:663 builtin/commit.c:696 builtin/commit.c:1024
-#, c-format
-msgid "could not lookup commit %s"
-msgstr "no s'ha pogut trobar la comissió %s"
+#: wt-status.c:1330
+msgid "No commands remaining."
+msgstr "No manca cap ordre."
 
-#: builtin/commit.c:675 builtin/shortlog.c:309
+#: wt-status.c:1333
 #, c-format
-msgid "(reading log message from standard input)\n"
-msgstr "(s'està llegint el missatge de registre des de l'entrada estàndard)\n"
+msgid "Next command to do (%d remaining command):"
+msgid_plural "Next commands to do (%d remaining commands):"
+msgstr[0] "Ordre següent a fer (manca %d ordre):"
+msgstr[1] "Ordres següents a fer (manquen %d ordres):"
 
-#: builtin/commit.c:677
-msgid "could not read log from standard input"
-msgstr "no s'ha pogut llegir el registre des de l'entrada estàndard"
+#: wt-status.c:1341
+msgid "  (use \"git rebase --edit-todo\" to view and edit)"
+msgstr "  (useu \"git rebase --edit-todo\" per a veure i editar)"
 
-#: builtin/commit.c:681
+#: wt-status.c:1353
 #, c-format
-msgid "could not read log file '%s'"
-msgstr "no s'ha pogut llegir el fitxer de registre «%s»"
+msgid "You are currently rebasing branch '%s' on '%s'."
+msgstr "Actualment esteu fent «rebase» de la branca «%s» en «%s»."
 
-#: builtin/commit.c:710 builtin/commit.c:718
-msgid "could not read SQUASH_MSG"
-msgstr "no s'ha pogut llegir SQUASH_MSG"
+#: wt-status.c:1358
+msgid "You are currently rebasing."
+msgstr "Actualment esteu fent «rebase»."
 
-#: builtin/commit.c:715
-msgid "could not read MERGE_MSG"
-msgstr "no s'ha pogut llegir MERGE_MSG"
+#: wt-status.c:1371
+msgid "  (fix conflicts and then run \"git rebase --continue\")"
+msgstr ""
+"  (arregleu els conflictes i després executeu \"git rebase --continue\")"
 
-#: builtin/commit.c:769
-msgid "could not write commit template"
-msgstr "no s'ha pogut escriure la plantilla de comissió"
+#: wt-status.c:1373
+msgid "  (use \"git rebase --skip\" to skip this patch)"
+msgstr "  (useu \"git rebase --skip\" per a ometre aquest pedaç)"
 
-#: builtin/commit.c:787
-#, c-format
-msgid ""
-"\n"
-"It looks like you may be committing a merge.\n"
-"If this is not correct, please remove the file\n"
-"\t%s\n"
-"and try again.\n"
+#: wt-status.c:1375
+msgid "  (use \"git rebase --abort\" to check out the original branch)"
+msgstr "  (useu \"git rebase --abort\" per a agafar la branca original)"
+
+#: wt-status.c:1382
+msgid "  (all conflicts fixed: run \"git rebase --continue\")"
 msgstr ""
-"\n"
-"Sembla que podeu estar cometent una fusió.\n"
-"Si això no és correcte, elimineu el fitxer\n"
-"\t%s\n"
-"i intenteu-ho de nou.\n"
+"  (tots els conflictes estan arreglats: executeu \"git rebase --continue\")"
 
-#: builtin/commit.c:792
+#: wt-status.c:1386
 #, c-format
 msgid ""
-"\n"
-"It looks like you may be committing a cherry-pick.\n"
-"If this is not correct, please remove the file\n"
-"\t%s\n"
-"and try again.\n"
+"You are currently splitting a commit while rebasing branch '%s' on '%s'."
 msgstr ""
-"\n"
-"Sembla que podeu estar cometent un «cherry pick».\n"
-"Si això no és correcte, elimineu el fitxer\n"
-"\t%s\n"
-"i intenteu-ho de nou.\n"
+"Actualment esteu dividint una comissió mentre es fa «rebase» de la branca "
+"«%s» en «%s»."
 
-#: builtin/commit.c:805
-#, c-format
-msgid ""
-"Please enter the commit message for your changes. Lines starting\n"
-"with '%c' will be ignored, and an empty message aborts the commit.\n"
+#: wt-status.c:1391
+msgid "You are currently splitting a commit during a rebase."
+msgstr "Actualment esteu dividint una comissió durant un «rebase»."
+
+#: wt-status.c:1394
+msgid "  (Once your working directory is clean, run \"git rebase --continue\")"
 msgstr ""
-"Introduïu el missatge de comissió dels vostres canvis.\n"
-"S'ignoraran les línies començant amb '%c', i un missatge de\n"
-"comissió buit avorta la comissió.\n"
+"  (Una vegada que el vostre directori de treball sigui net, executeu \"git "
+"rebase --continue\")"
 
-#: builtin/commit.c:813
+#: wt-status.c:1398
 #, c-format
+msgid "You are currently editing a commit while rebasing branch '%s' on '%s'."
+msgstr ""
+"Actualment esteu editant una comissió mentre es fa «rebase» de la branca "
+"«%s» en «%s»."
+
+#: wt-status.c:1403
+msgid "You are currently editing a commit during a rebase."
+msgstr "Actualment esteu editant una comissió durant un «rebase»."
+
+#: wt-status.c:1406
+msgid "  (use \"git commit --amend\" to amend the current commit)"
+msgstr "  (useu \"git commit --amend\" per a esmenar la comissió actual)"
+
+#: wt-status.c:1408
 msgid ""
-"Please enter the commit message for your changes. Lines starting\n"
-"with '%c' will be kept; you may remove them yourself if you want to.\n"
-"An empty message aborts the commit.\n"
+"  (use \"git rebase --continue\" once you are satisfied with your changes)"
 msgstr ""
-"Introduïu el missatge de comissió dels vostres canvis.\n"
-"Es mantindran les línies que comencin amb '%c'; podeu eliminar-les "
-"vosaltres\n"
-"mateixos si voleu. Un missatge buit avorta la comissió.\n"
+"  (useu \"git rebase --continue\" una vegada que estigueu satisfet amb els "
+"vostres canvis)"
 
-#: builtin/commit.c:830
-#, c-format
-msgid "%sAuthor:    %.*s <%.*s>"
-msgstr "%sAutor:    %.*s <%.*s>"
+#: wt-status.c:1419
+#, fuzzy
+msgid "Cherry-pick currently in progress."
+msgstr "ni hi ha cap «cherry pick» ni cap reversió en curs"
 
-#: builtin/commit.c:838
+#: wt-status.c:1422
 #, c-format
-msgid "%sDate:      %s"
-msgstr "%sData:      %s"
+msgid "You are currently cherry-picking commit %s."
+msgstr "Actualment esteu fent «cherry pick» a la comissió %s."
 
-#: builtin/commit.c:845
-#, c-format
-msgid "%sCommitter: %.*s <%.*s>"
-msgstr "%sComitent: %.*s <%.*s>"
+#: wt-status.c:1429
+msgid "  (fix conflicts and run \"git cherry-pick --continue\")"
+msgstr "  (arregleu els conflictes i executeu \"git cherry-pick --continue\")"
 
-#: builtin/commit.c:862
-msgid "Cannot read index"
-msgstr "No es pot llegir l'índex"
+#: wt-status.c:1432
+#, fuzzy
+msgid "  (run \"git cherry-pick --continue\" to continue)"
+msgstr "  (arregleu els conflictes i executeu \"git cherry-pick --continue\")"
 
-#: builtin/commit.c:928
-msgid "Error building trees"
-msgstr "Error en construir arbres"
+#: wt-status.c:1435
+msgid "  (all conflicts fixed: run \"git cherry-pick --continue\")"
+msgstr ""
+"  (tots els conflictes estan arreglats: executeu \"git cherry-pick --continue"
+"\")"
 
-#: builtin/commit.c:942 builtin/tag.c:256
-#, c-format
-msgid "Please supply the message using either -m or -F option.\n"
-msgstr "Especifiqueu el missatge usant l'opció -m o l'opció -F.\n"
+#: wt-status.c:1437
+#, fuzzy
+msgid "  (use \"git cherry-pick --skip\" to skip this patch)"
+msgstr "  (useu \"git am --skip\" per a ometre aquest pedaç)"
 
-#: builtin/commit.c:986
-#, c-format
-msgid "--author '%s' is not 'Name <email>' and matches no existing author"
+#: wt-status.c:1439
+msgid "  (use \"git cherry-pick --abort\" to cancel the cherry-pick operation)"
 msgstr ""
-"--author «%s» no és «Nom <adreça-electrònica>» i no coincideix amb\n"
-"cap autor existent"
+"  (useu \"git cherry-pick --abort\" per a cancel·lar l'operació de «cherry "
+"pick»)"
 
-#: builtin/commit.c:1000
-#, c-format
-msgid "Invalid ignored mode '%s'"
-msgstr "mode ignorat no vàlid «%s»"
+#: wt-status.c:1449
+#, fuzzy
+msgid "Revert currently in progress."
+msgstr "avorta la fusió en curs actual"
 
-#: builtin/commit.c:1014 builtin/commit.c:1264
+#: wt-status.c:1452
 #, c-format
-msgid "Invalid untracked files mode '%s'"
-msgstr "Mode de fitxers no seguits no vàlid «%s»"
+msgid "You are currently reverting commit %s."
+msgstr "Actualment esteu revertint la comissió %s."
 
-#: builtin/commit.c:1052
-msgid "--long and -z are incompatible"
-msgstr "--long i -z són incompatibles"
+#: wt-status.c:1458
+msgid "  (fix conflicts and run \"git revert --continue\")"
+msgstr "  (arregleu els conflictes i executeu \"git revert --continue\")"
 
-#: builtin/commit.c:1085
-msgid "Using both --reset-author and --author does not make sense"
-msgstr "Usar ambdós --reset-author i --author no té sentit"
+#: wt-status.c:1461
+#, fuzzy
+msgid "  (run \"git revert --continue\" to continue)"
+msgstr "  (arregleu els conflictes i executeu \"git revert --continue\")"
 
-#: builtin/commit.c:1094
-msgid "You have nothing to amend."
-msgstr "No teniu res a esmenar."
+#: wt-status.c:1464
+msgid "  (all conflicts fixed: run \"git revert --continue\")"
+msgstr ""
+"  (tots els conflictes estan arreglats: executeu \"git revert --continue\")"
 
-#: builtin/commit.c:1097
-msgid "You are in the middle of a merge -- cannot amend."
-msgstr "Esteu enmig d'una fusió -- no es pot esmenar."
+#: wt-status.c:1466
+#, fuzzy
+msgid "  (use \"git revert --skip\" to skip this patch)"
+msgstr "  (useu \"git rebase --skip\" per a ometre aquest pedaç)"
 
-#: builtin/commit.c:1099
-msgid "You are in the middle of a cherry-pick -- cannot amend."
-msgstr "Esteu enmig d'un «cherry pick» -- no es pot esmenar."
+#: wt-status.c:1468
+msgid "  (use \"git revert --abort\" to cancel the revert operation)"
+msgstr ""
+"  (useu \"git revert --abort\" per a cancel·lar l'operació de reversió)"
 
-#: builtin/commit.c:1102
-msgid "Options --squash and --fixup cannot be used together"
-msgstr "Les opcions --squash i --fixup no es poden usar juntes"
+#: wt-status.c:1478
+#, c-format
+msgid "You are currently bisecting, started from branch '%s'."
+msgstr "Actualment esteu bisecant, heu començat des de la branca «%s»."
 
-#: builtin/commit.c:1112
-msgid "Only one of -c/-C/-F/--fixup can be used."
-msgstr "Només un de -c/-C/-F/--fixup es pot usar."
+#: wt-status.c:1482
+msgid "You are currently bisecting."
+msgstr "Actualment esteu bisecant."
 
-#: builtin/commit.c:1114
-msgid "Option -m cannot be combined with -c/-C/-F."
-msgstr "L'opció -m no es pot combinar amb -c/-C/-F/."
+#: wt-status.c:1485
+msgid "  (use \"git bisect reset\" to get back to the original branch)"
+msgstr "  (useu \"git bisect reset\" per a tornar a la branca original)"
 
-#: builtin/commit.c:1122
-msgid "--reset-author can be used only with -C, -c or --amend."
-msgstr "--reset-author només es pot usar amb -C, -c o --amend."
+#: wt-status.c:1694
+msgid "On branch "
+msgstr "En la branca "
 
-#: builtin/commit.c:1139
-msgid "Only one of --include/--only/--all/--interactive/--patch can be used."
-msgstr "Només un de --include/--only/--all/--interactive/--patch es pot usar."
+#: wt-status.c:1701
+msgid "interactive rebase in progress; onto "
+msgstr "«rebase» interactiu en curs; sobre "
 
-#: builtin/commit.c:1141
-msgid "No paths with --include/--only does not make sense."
-msgstr "--include/--only no té sentit sense camí."
+#: wt-status.c:1703
+msgid "rebase in progress; onto "
+msgstr "«rebase» en curs; sobre "
 
-#: builtin/commit.c:1155 builtin/tag.c:542
-#, c-format
-msgid "Invalid cleanup mode %s"
-msgstr "Mode de neteja no vàlid %s"
+#: wt-status.c:1713
+msgid "Not currently on any branch."
+msgstr "Actualment no s'és en cap branca."
 
-#: builtin/commit.c:1160
-msgid "Paths with -a does not make sense."
-msgstr "-a no té sentit amb camins."
+#: wt-status.c:1730
+msgid "Initial commit"
+msgstr "Comissió inicial"
 
-#: builtin/commit.c:1278 builtin/commit.c:1443
-msgid "show status concisely"
-msgstr "mostra l'estat concisament"
+#: wt-status.c:1731
+msgid "No commits yet"
+msgstr "No s'ha fet cap comissió encara"
 
-#: builtin/commit.c:1280 builtin/commit.c:1445
-msgid "show branch information"
-msgstr "mostra la informació de branca"
+#: wt-status.c:1745
+msgid "Untracked files"
+msgstr "Fitxers no seguits"
 
-#: builtin/commit.c:1282
-msgid "show stash information"
-msgstr "mostra la informació de «stash»"
+#: wt-status.c:1747
+msgid "Ignored files"
+msgstr "Fitxers ignorats"
 
-#: builtin/commit.c:1284 builtin/commit.c:1447
-msgid "compute full ahead/behind values"
+#: wt-status.c:1751
+#, c-format
+msgid ""
+"It took %.2f seconds to enumerate untracked files. 'status -uno'\n"
+"may speed it up, but you have to be careful not to forget to add\n"
+"new files yourself (see 'git help status')."
 msgstr ""
+"Ha trigat %.2f segons enumerar els fitxers no seguits.\n"
+"'status -uno' pot accelerar-ho, però heu d'anar amb compte de no\n"
+"oblidar-vos d'afegir fitxers nous vosaltres mateixos (vegeu\n"
+"'git help status')."
 
-#: builtin/commit.c:1286
-msgid "version"
-msgstr "versió"
-
-#: builtin/commit.c:1286 builtin/commit.c:1449 builtin/push.c:542
-#: builtin/worktree.c:541
-msgid "machine-readable output"
-msgstr "sortida llegible per màquina"
-
-#: builtin/commit.c:1289 builtin/commit.c:1451
-msgid "show status in long format (default)"
-msgstr "mostra l'estat en format llarg (per defecte)"
-
-#: builtin/commit.c:1292 builtin/commit.c:1454
-msgid "terminate entries with NUL"
-msgstr "acaba les entrades amb NUL"
+#: wt-status.c:1757
+#, c-format
+msgid "Untracked files not listed%s"
+msgstr "Els fitxers no seguits no estan llistats%s"
 
-#: builtin/commit.c:1294 builtin/commit.c:1298 builtin/commit.c:1457
-#: builtin/fast-export.c:999 builtin/fast-export.c:1002 builtin/tag.c:396
-msgid "mode"
-msgstr "mode"
+#: wt-status.c:1759
+msgid " (use -u option to show untracked files)"
+msgstr " (useu l'opció -u per a mostrar els fitxers no seguits)"
 
-#: builtin/commit.c:1295 builtin/commit.c:1457
-msgid "show untracked files, optional modes: all, normal, no. (Default: all)"
-msgstr ""
-"mostra els fitxers no seguits, modes opcionals: all, normal, no. (Per "
-"defecte: all)"
+#: wt-status.c:1765
+msgid "No changes"
+msgstr "Sense canvis"
 
-#: builtin/commit.c:1299
-msgid ""
-"show ignored files, optional modes: traditional, matching, no. (Default: "
-"traditional)"
+#: wt-status.c:1770
+#, c-format
+msgid "no changes added to commit (use \"git add\" and/or \"git commit -a\")\n"
 msgstr ""
-"mostra els fitxers ignorats, modes opcionals: traditional, matching, no. "
-"(Per defecte: traditional, matching, no.)"
+"no hi ha canvis afegits a cometre (useu \"git add\" o \"git commit -a\")\n"
 
-#: builtin/commit.c:1301 parse-options.h:167
-msgid "when"
-msgstr "quan"
+#: wt-status.c:1773
+#, c-format
+msgid "no changes added to commit\n"
+msgstr "no hi ha canvis afegits a cometre\n"
 
-#: builtin/commit.c:1302
+#: wt-status.c:1776
+#, c-format
 msgid ""
-"ignore changes to submodules, optional when: all, dirty, untracked. "
-"(Default: all)"
+"nothing added to commit but untracked files present (use \"git add\" to "
+"track)\n"
 msgstr ""
-"ignora els canvis als submòduls, opcional quan: all, dirty, untracked. (Per "
-"defecte: all)"
+"no hi ha res afegit a cometre però hi ha fitxers no seguits (useu \"git add"
+"\" per a seguir-los)\n"
 
-#: builtin/commit.c:1304
-msgid "list untracked files in columns"
-msgstr "mostra els fitxers no seguits en columnes"
+#: wt-status.c:1779
+#, c-format
+msgid "nothing added to commit but untracked files present\n"
+msgstr "no hi ha res afegit a cometre però hi ha fitxers no seguits\n"
 
-#: builtin/commit.c:1323
-msgid "Unsupported combination of ignored and untracked-files arguments"
+#: wt-status.c:1782
+#, c-format
+msgid "nothing to commit (create/copy files and use \"git add\" to track)\n"
 msgstr ""
+"no hi ha res a cometre (creeu/copieu fitxers i useu \"git add\" per a seguir-"
+"los)\n"
 
-#: builtin/commit.c:1413
-msgid "suppress summary after successful commit"
-msgstr "omet el resum després d'una comissió reeixida"
-
-#: builtin/commit.c:1414
-msgid "show diff in commit message template"
-msgstr "mostra la diferència en la plantilla de missatge de comissió"
+#: wt-status.c:1785 wt-status.c:1790
+#, c-format
+msgid "nothing to commit\n"
+msgstr "no hi ha res a cometre\n"
 
-#: builtin/commit.c:1416
-msgid "Commit message options"
-msgstr "Opcions de missatge de comissió"
+#: wt-status.c:1788
+#, c-format
+msgid "nothing to commit (use -u to show untracked files)\n"
+msgstr ""
+"no hi ha res a cometre (useu -u per a mostrar els fitxers no seguits)\n"
 
-#: builtin/commit.c:1417 builtin/tag.c:393
-msgid "read message from file"
-msgstr "llegiu el missatge des d'un fitxer"
+#: wt-status.c:1792
+#, c-format
+msgid "nothing to commit, working tree clean\n"
+msgstr "no hi ha res a cometre, l'arbre de treball està net\n"
 
-#: builtin/commit.c:1418
-msgid "author"
-msgstr "autor"
+#: wt-status.c:1905
+msgid "No commits yet on "
+msgstr "No s'ha fet cap comissió encara a "
 
-#: builtin/commit.c:1418
-msgid "override author for commit"
-msgstr "autor corregit de la comissió"
+#: wt-status.c:1909
+msgid "HEAD (no branch)"
+msgstr "HEAD (sense branca)"
 
-#: builtin/commit.c:1419 builtin/gc.c:359
-msgid "date"
-msgstr "data"
+#: wt-status.c:1940
+msgid "different"
+msgstr "diferent"
 
-#: builtin/commit.c:1419
-msgid "override date for commit"
-msgstr "data corregida de la comissió"
+#: wt-status.c:1942 wt-status.c:1950
+msgid "behind "
+msgstr "darrere "
 
-#: builtin/commit.c:1420 builtin/merge.c:226 builtin/notes.c:402
-#: builtin/notes.c:565 builtin/tag.c:391
-msgid "message"
-msgstr "missatge"
+#: wt-status.c:1945 wt-status.c:1948
+msgid "ahead "
+msgstr "davant per "
 
-#: builtin/commit.c:1420
-msgid "commit message"
-msgstr "missatge de comissió"
+#. TRANSLATORS: the action is e.g. "pull with rebase"
+#: wt-status.c:2470
+#, c-format
+msgid "cannot %s: You have unstaged changes."
+msgstr "no es pot %s: Teniu canvis «unstaged»."
 
-#: builtin/commit.c:1421 builtin/commit.c:1422 builtin/commit.c:1423
-#: builtin/commit.c:1424 parse-options.h:269 ref-filter.h:92
-msgid "commit"
-msgstr "comissió"
+#: wt-status.c:2476
+msgid "additionally, your index contains uncommitted changes."
+msgstr "addicionalment, el vostre índex conté canvis sense cometre."
 
-#: builtin/commit.c:1421
-msgid "reuse and edit message from specified commit"
-msgstr "reusa i edita el missatge de la comissió especificada"
+#: wt-status.c:2478
+#, c-format
+msgid "cannot %s: Your index contains uncommitted changes."
+msgstr "no es pot %s: El vostre índex conté canvis sense cometre."
 
-#: builtin/commit.c:1422
-msgid "reuse message from specified commit"
-msgstr "reusa el missatge de la comissió especificada"
+#: compat/precompose_utf8.c:58 builtin/clone.c:455
+#, c-format
+msgid "failed to unlink '%s'"
+msgstr "s'ha produït un error en desenllaçar «%s»"
 
-#: builtin/commit.c:1423
-msgid "use autosquash formatted message to fixup specified commit"
-msgstr ""
-"usa el missatge formatat de «squash» automàtic per a corregir la comissió "
-"especificada"
+#: builtin/add.c:26
+msgid "git add [<options>] [--] <pathspec>..."
+msgstr "git add [<opcions>] [--] <especificació-de-camí>..."
 
-#: builtin/commit.c:1424
-msgid "use autosquash formatted message to squash specified commit"
-msgstr ""
-"usa el missatge formatat de «squash» automàtic per a «squash» a la comissió "
-"especificada"
+#: builtin/add.c:87
+#, c-format
+msgid "unexpected diff status %c"
+msgstr "estat de diff inesperat %c"
 
-#: builtin/commit.c:1425
-msgid "the commit is authored by me now (used with -C/-c/--amend)"
-msgstr "l'autor de la comissió ja soc jo (s'usa amb -C/-c/--amend)"
+#: builtin/add.c:92 builtin/commit.c:288
+msgid "updating files failed"
+msgstr "s'ha produït un error en actualitzar els fitxers"
 
-#: builtin/commit.c:1426 builtin/log.c:1446 builtin/merge.c:240
-#: builtin/pull.c:149 builtin/revert.c:105
-msgid "add Signed-off-by:"
-msgstr "afegeix Signed-off-by:"
+#: builtin/add.c:102
+#, c-format
+msgid "remove '%s'\n"
+msgstr "elimina «%s»\n"
 
-#: builtin/commit.c:1427
-msgid "use specified template file"
-msgstr "usa el fitxer de plantilla especificat"
+#: builtin/add.c:177
+msgid "Unstaged changes after refreshing the index:"
+msgstr "Canvis «unstaged» després d'actualitzar l'índex:"
 
-#: builtin/commit.c:1428
-msgid "force edit of commit"
-msgstr "força l'edició de la comissió"
+#: builtin/add.c:252 builtin/rev-parse.c:899
+msgid "Could not read the index"
+msgstr "No s'ha pogut llegir l'índex"
 
-#: builtin/commit.c:1429
-msgid "default"
-msgstr "per defecte"
+#: builtin/add.c:263
+#, c-format
+msgid "Could not open '%s' for writing."
+msgstr "No s'ha pogut obrir «%s» per a escriptura."
 
-#: builtin/commit.c:1429 builtin/tag.c:397
-msgid "how to strip spaces and #comments from message"
-msgstr "com suprimir els espais i #comentaris del missatge"
+#: builtin/add.c:267
+msgid "Could not write patch"
+msgstr "No s'ha pogut escriure el pedaç"
 
-#: builtin/commit.c:1430
-msgid "include status in commit message template"
-msgstr "inclou l'estat en la plantilla de missatge de comissió"
+#: builtin/add.c:270
+msgid "editing patch failed"
+msgstr "l'edició del pedaç ha fallat"
 
-#: builtin/commit.c:1432 builtin/merge.c:238 builtin/pull.c:179
-#: builtin/revert.c:113
-msgid "GPG sign commit"
-msgstr "signa la comissió amb GPG"
+#: builtin/add.c:273
+#, c-format
+msgid "Could not stat '%s'"
+msgstr "No s'ha pogut fer stat a «%s»"
 
-#: builtin/commit.c:1435
-msgid "Commit contents options"
-msgstr "Opcions dels continguts de les comissions"
+#: builtin/add.c:275
+msgid "Empty patch. Aborted."
+msgstr "El pedaç és buit. S'ha avortat."
 
-#: builtin/commit.c:1436
-msgid "commit all changed files"
-msgstr "comet tots els fitxers canviats"
+#: builtin/add.c:280
+#, c-format
+msgid "Could not apply '%s'"
+msgstr "No s'ha pogut aplicar «%s»"
 
-#: builtin/commit.c:1437
-msgid "add specified files to index for commit"
-msgstr "afegeix els fitxers especificats a l'índex per a cometre"
+#: builtin/add.c:288
+msgid "The following paths are ignored by one of your .gitignore files:\n"
+msgstr ""
+"Els camins següents s'ignoren per un dels vostres fitxers .gitignore:\n"
 
-#: builtin/commit.c:1438
-msgid "interactively add files"
-msgstr "afegeix els fitxers interactivament"
+#: builtin/add.c:308 builtin/clean.c:910 builtin/fetch.c:163 builtin/mv.c:124
+#: builtin/prune-packed.c:56 builtin/pull.c:223 builtin/push.c:548
+#: builtin/remote.c:1344 builtin/rm.c:241 builtin/send-pack.c:165
+msgid "dry run"
+msgstr "marxa en sec"
 
-#: builtin/commit.c:1439
-msgid "interactively add changes"
-msgstr "afegeix els canvis interactivament"
+#: builtin/add.c:311
+msgid "interactive picking"
+msgstr "recull interactiu"
 
-#: builtin/commit.c:1440
-msgid "commit only specified files"
-msgstr "comet només els fitxers especificats"
+#: builtin/add.c:312 builtin/checkout.c:1482 builtin/reset.c:307
+msgid "select hunks interactively"
+msgstr "selecciona els trossos interactivament"
 
-#: builtin/commit.c:1441
-msgid "bypass pre-commit and commit-msg hooks"
-msgstr "evita els lligams de precomissió i missatge de comissió"
+#: builtin/add.c:313
+msgid "edit current diff and apply"
+msgstr "edita la diferència actual i aplica-la"
 
-#: builtin/commit.c:1442
-msgid "show what would be committed"
-msgstr "mostra què es cometria"
+#: builtin/add.c:314
+msgid "allow adding otherwise ignored files"
+msgstr "permet afegir fitxers que d'altra manera s'ignoren"
 
-#: builtin/commit.c:1455
-msgid "amend previous commit"
-msgstr "esmena la comissió anterior"
+#: builtin/add.c:315
+msgid "update tracked files"
+msgstr "actualitza els fitxers seguits"
 
-#: builtin/commit.c:1456
-msgid "bypass post-rewrite hook"
-msgstr "evita el lligam de post escriptura"
+#: builtin/add.c:316
+msgid "renormalize EOL of tracked files (implies -u)"
+msgstr ""
 
-#: builtin/commit.c:1461
-msgid "ok to record an empty change"
-msgstr "està bé registrar un canvi buit"
+#: builtin/add.c:317
+msgid "record only the fact that the path will be added later"
+msgstr "registra només el fet que el camí s'afegirà més tard"
 
-#: builtin/commit.c:1463
-msgid "ok to record a change with an empty message"
-msgstr "està bé registrar un canvi amb missatge buit"
+#: builtin/add.c:318
+msgid "add changes from all tracked and untracked files"
+msgstr "afegeix els canvis de tots els fitxers seguits i no seguits"
 
-#: builtin/commit.c:1536
-#, c-format
-msgid "Corrupt MERGE_HEAD file (%s)"
-msgstr "Fitxer MERGE_HEAD malmès (%s)"
+#: builtin/add.c:321
+msgid "ignore paths removed in the working tree (same as --no-all)"
+msgstr ""
+"ignora els camins eliminats en l'arbre de treball (el mateix que --no-all)"
 
-#: builtin/commit.c:1543
-msgid "could not read MERGE_MODE"
-msgstr "no s'ha pogut llegir MERGE_MODE"
+#: builtin/add.c:323
+msgid "don't add, only refresh the index"
+msgstr "no afegeixis, només actualitza l'índex"
 
-#: builtin/commit.c:1562
-#, c-format
-msgid "could not read commit message: %s"
-msgstr "no s'ha pogut llegir el missatge de comissió: %s"
+#: builtin/add.c:324
+msgid "just skip files which cannot be added because of errors"
+msgstr "només omet els fitxers que no es poden afegir a causa d'errors"
 
-#: builtin/commit.c:1573
-#, c-format
-msgid "Aborting commit due to empty commit message.\n"
-msgstr "S'està avortant la comissió a causa d'un missatge de comissió buit.\n"
+#: builtin/add.c:325
+msgid "check if - even missing - files are ignored in dry run"
+msgstr ""
+"comproveu si els fitxers - fins i tot els absents - s'ignoren en marxa en sec"
 
-#: builtin/commit.c:1578
-#, c-format
-msgid "Aborting commit; you did not edit the message.\n"
-msgstr "S'està avortant la comissió; no heu editat el missatge.\n"
+#: builtin/add.c:327 builtin/update-index.c:1004
+msgid "override the executable bit of the listed files"
+msgstr "passa per alt el bit executable dels fitxers llistats"
+
+#: builtin/add.c:329
+msgid "warn when adding an embedded repository"
+msgstr "avisa'm quan s'afegeixi un dipòsit incrustat"
 
-#: builtin/commit.c:1613
+#: builtin/add.c:347
+#, c-format
 msgid ""
-"Repository has been updated, but unable to write\n"
-"new_index file. Check that disk is not full and quota is\n"
-"not exceeded, and then \"git reset HEAD\" to recover."
+"You've added another git repository inside your current repository.\n"
+"Clones of the outer repository will not contain the contents of\n"
+"the embedded repository and will not know how to obtain it.\n"
+"If you meant to add a submodule, use:\n"
+"\n"
+"\tgit submodule add <url> %s\n"
+"\n"
+"If you added this path by mistake, you can remove it from the\n"
+"index with:\n"
+"\n"
+"\tgit rm --cached %s\n"
+"\n"
+"See \"git help submodule\" for more information."
 msgstr ""
-"S'ha actualitzat el dipòsit, però no es pot escriure el\n"
-"fitxer new_index. Comproveu que el disc no estigui ple i\n"
-"que la quota no estigui excedida, i després\n"
-"«git reset HEAD» per a recuperar."
+"Heu afegit un altre dipòsit git dins del dipòsit actual.\n"
+"Els clons de dipòsits externs no contindran els continguts de\n"
+"del dipòsit incrustat i no sabran com obtenir-ho.\n"
+"Si volíeu afegir un submòdul, useu:\n"
+"\n"
+"\tgit submodule add <url> %s\n"
+"\n"
+"Si heu afegit aquest camí per error, podeu suprimir-lo de\n"
+"l'índex amb:\n"
+"\n"
+"\tgit rm --cached %s\n"
+"\n"
+"Vegeu \"git help submodule\" per a més informació."
 
-#: builtin/config.c:10
-msgid "git config [<options>]"
-msgstr "git config [<opcions>]"
+#: builtin/add.c:375
+#, c-format
+msgid "adding embedded git repository: %s"
+msgstr "s'està afegint un dipòsit incrustat: %s"
 
-#: builtin/config.c:58
-msgid "Config file location"
-msgstr "Ubicació del fitxer de configuració"
+#: builtin/add.c:393
+#, c-format
+msgid "Use -f if you really want to add them.\n"
+msgstr "Useu -f si realment els voleu afegir.\n"
 
-#: builtin/config.c:59
-msgid "use global config file"
-msgstr "usa el fitxer de configuració global"
+#: builtin/add.c:400
+msgid "adding files failed"
+msgstr "l'afegiment de fitxers ha fallat"
 
-#: builtin/config.c:60
-msgid "use system config file"
-msgstr "usa el fitxer de configuració del sistema"
+#: builtin/add.c:428 builtin/commit.c:348
+#, fuzzy
+msgid "--pathspec-from-file is incompatible with --interactive/--patch"
+msgstr "--first-parent és incompatible amb --bisect"
 
-#: builtin/config.c:61
-msgid "use repository config file"
-msgstr "usa el fitxer de configuració del dipòsit"
+#: builtin/add.c:434
+#, fuzzy
+msgid "--pathspec-from-file is incompatible with --edit"
+msgstr "--first-parent és incompatible amb --bisect"
 
-#: builtin/config.c:62
-msgid "use given config file"
-msgstr "usa el fitxer de configuració donat"
+#: builtin/add.c:446
+msgid "-A and -u are mutually incompatible"
+msgstr "-A i -u són mútuament incompatibles"
 
-#: builtin/config.c:63
-msgid "blob-id"
-msgstr "ID de blob"
+#: builtin/add.c:449
+msgid "Option --ignore-missing can only be used together with --dry-run"
+msgstr "L'opció --ignore-missing només es pot usar juntament amb --dry-run"
 
-#: builtin/config.c:63
-msgid "read config from given blob object"
-msgstr "llegeix la configuració de l'objecte de blob donat"
+#: builtin/add.c:453
+#, c-format
+msgid "--chmod param '%s' must be either -x or +x"
+msgstr "el paràmetre --chmod «%s» ha de ser o -x o +x"
 
-#: builtin/config.c:64
-msgid "Action"
-msgstr "Acció"
+#: builtin/add.c:471 builtin/checkout.c:1648 builtin/commit.c:354
+#: builtin/reset.c:327
+#, fuzzy
+msgid "--pathspec-from-file is incompatible with pathspec arguments"
+msgstr "--patch és incompatible amb --{hard,mixed,soft}"
 
-#: builtin/config.c:65
-msgid "get value: name [value-regex]"
-msgstr "obtén valor: nom [regex-de-valors]"
+#: builtin/add.c:478 builtin/checkout.c:1660 builtin/commit.c:360
+#: builtin/reset.c:333
+msgid "--pathspec-file-nul requires --pathspec-from-file"
+msgstr ""
 
-#: builtin/config.c:66
-msgid "get all values: key [value-regex]"
-msgstr "obtén tots els valors: clau [regex-de-valors]"
+#: builtin/add.c:482
+#, c-format
+msgid "Nothing specified, nothing added.\n"
+msgstr "No s'ha especificat res, no s'ha afegit res.\n"
 
-#: builtin/config.c:67
-msgid "get values for regexp: name-regex [value-regex]"
-msgstr "obtén valors de regexp: regex-de-noms [regex-de-valors]"
-
-#: builtin/config.c:68
-msgid "get value specific for the URL: section[.var] URL"
-msgstr "obtén el valor específic per a l'URL: secció[.variable] URL"
-
-#: builtin/config.c:69
-msgid "replace all matching variables: name value [value_regex]"
-msgstr ""
-"reemplaça totes les variables que coincideixen: nom valor [regex_de_valors]"
-
-#: builtin/config.c:70
-msgid "add a new variable: name value"
-msgstr "afegeix una variable nova: nom valor"
-
-#: builtin/config.c:71
-msgid "remove a variable: name [value-regex]"
-msgstr "elimina una variable: nom [regex-de-valors]"
-
-#: builtin/config.c:72
-msgid "remove all matches: name [value-regex]"
-msgstr "elimina totes les coincidències: nom [regex-de-valors]"
+#: builtin/add.c:483
+#, c-format
+msgid "Maybe you wanted to say 'git add .'?\n"
+msgstr "Potser volíeu dir «git add .»?\n"
 
-#: builtin/config.c:73
-msgid "rename section: old-name new-name"
-msgstr "canvia el nom de secció: nom-antic nom-nou"
+#: builtin/am.c:347
+msgid "could not parse author script"
+msgstr "no s'ha pogut analitzar l'script d'autor"
 
-#: builtin/config.c:74
-msgid "remove a section: name"
-msgstr "elimina una secció: nom"
+#: builtin/am.c:431
+#, c-format
+msgid "'%s' was deleted by the applypatch-msg hook"
+msgstr "s'ha suprimit «%s» pel lligam applypatch-msg"
 
-#: builtin/config.c:75
-msgid "list all"
-msgstr "llista tots"
+#: builtin/am.c:473
+#, c-format
+msgid "Malformed input line: '%s'."
+msgstr "Línia d'entrada mal formada: «%s»."
 
-#: builtin/config.c:76
-msgid "open an editor"
-msgstr "obre un editor"
+#: builtin/am.c:511
+#, c-format
+msgid "Failed to copy notes from '%s' to '%s'"
+msgstr "S'ha produït un error en copiar les notes de «%s» a «%s»"
 
-#: builtin/config.c:77
-msgid "find the color configured: slot [default]"
-msgstr "troba el color configurat: ranura [per defecte]"
+#: builtin/am.c:537
+msgid "fseek failed"
+msgstr "fseek ha fallat"
 
-#: builtin/config.c:78
-msgid "find the color setting: slot [stdout-is-tty]"
-msgstr "troba el paràmetre de color: ranura [stdout-és-tty]"
+#: builtin/am.c:725
+#, c-format
+msgid "could not parse patch '%s'"
+msgstr "no s'ha pogut analitzar el pedaç «%s»"
 
-#: builtin/config.c:79
-msgid "Type"
-msgstr "Tipus"
+#: builtin/am.c:790
+msgid "Only one StGIT patch series can be applied at once"
+msgstr "Només una sèrie de pedaços StGIT es pot aplicar a la vegada"
 
-#: builtin/config.c:80
-msgid "value is \"true\" or \"false\""
-msgstr "el valor és \"true\" o \"false\""
+#: builtin/am.c:838
+msgid "invalid timestamp"
+msgstr "marca de temps no vàlida"
 
-#: builtin/config.c:81
-msgid "value is decimal number"
-msgstr "el valor és un nombre decimal"
+#: builtin/am.c:843 builtin/am.c:855
+msgid "invalid Date line"
+msgstr "línia Date no vàlida"
 
-#: builtin/config.c:82
-msgid "value is --bool or --int"
-msgstr "el valor és --bool o --int"
+#: builtin/am.c:850
+msgid "invalid timezone offset"
+msgstr "desplaçament de zona de temps no vàlid"
 
-#: builtin/config.c:83
-msgid "value is a path (file or directory name)"
-msgstr "el valor és un camí (nom de fitxer o directori)"
+#: builtin/am.c:943
+msgid "Patch format detection failed."
+msgstr "La detecció de format de pedaç ha fallat."
 
-#: builtin/config.c:84
-msgid "value is an expiry date"
-msgstr "el valor és una data de venciment"
+#: builtin/am.c:948 builtin/clone.c:409
+#, c-format
+msgid "failed to create directory '%s'"
+msgstr "s'ha produït un error en crear el directori «%s»"
 
-#: builtin/config.c:85
-msgid "Other"
-msgstr "Altre"
+#: builtin/am.c:953
+msgid "Failed to split patches."
+msgstr "S'ha produït un error en dividir els pedaços."
 
-#: builtin/config.c:86
-msgid "terminate values with NUL byte"
-msgstr "acaba els valors amb un octet NUL"
+#: builtin/am.c:1084
+#, c-format
+msgid "When you have resolved this problem, run \"%s --continue\"."
+msgstr "Quan hàgiu resolt aquest problema, executeu \"%s --continue\"."
 
-#: builtin/config.c:87
-msgid "show variable names only"
-msgstr "mostra només els noms de variable"
+#: builtin/am.c:1085
+#, c-format
+msgid "If you prefer to skip this patch, run \"%s --skip\" instead."
+msgstr ""
+"Si preferiu ometre aquest pedaç, executeu \"%s --skip\" en lloc d'això."
 
-#: builtin/config.c:88
-msgid "respect include directives on lookup"
-msgstr "respecta les directives d'inclusió en cercar"
+#: builtin/am.c:1086
+#, c-format
+msgid "To restore the original branch and stop patching, run \"%s --abort\"."
+msgstr ""
+"Per a restaurar la branca original i deixar d'apedaçar, executeu \"%s --abort"
+"\"."
 
-#: builtin/config.c:89
-msgid "show origin of config (file, standard input, blob, command line)"
+#: builtin/am.c:1169
+msgid "Patch sent with format=flowed; space at the end of lines might be lost."
 msgstr ""
-"mostra l'origen de la configuració (fitxer, entrada estàndard, blob, línia "
-"d'ordres)"
 
-#: builtin/config.c:335
-msgid "unable to parse default color value"
-msgstr "no s'ha pogut analitzar el valor de color per defecte"
+#: builtin/am.c:1197
+msgid "Patch is empty."
+msgstr "El pedaç està buit."
+
+#: builtin/am.c:1262
+#, fuzzy, c-format
+msgid "missing author line in commit %s"
+msgstr "Manca el nom de branca; proveu -b"
 
-#: builtin/config.c:479
+#: builtin/am.c:1265
 #, c-format
-msgid ""
-"# This is Git's per-user configuration file.\n"
-"[user]\n"
-"# Please adapt and uncomment the following lines:\n"
-"#\tname = %s\n"
-"#\temail = %s\n"
-msgstr ""
-"# Això és el fitxer de configuració del Git de l'usuari.\n"
-"[user]\n"
-"# Adapteu i descomenteu les línies següents:\n"
-"#\tname = %s\n"
-"#\temail = %s\n"
+msgid "invalid ident line: %.*s"
+msgstr "línia d'identitat no vàlida: %.*s"
 
-#: builtin/config.c:507
-msgid "--local can only be used inside a git repository"
-msgstr "--local només es pot usar dins d'un dipòsit git"
+#: builtin/am.c:1484
+msgid "Repository lacks necessary blobs to fall back on 3-way merge."
+msgstr ""
+"Al dipòsit li manquen els blobs necessaris per a retrocedir a una fusió de 3 "
+"vies."
 
-#: builtin/config.c:632
-#, c-format
-msgid "cannot create configuration file %s"
-msgstr "no es pot crear el fitxer de configuració %s"
+#: builtin/am.c:1486
+msgid "Using index info to reconstruct a base tree..."
+msgstr "S'està usant la informació d'índex per a reconstruir un arbre base..."
 
-#: builtin/config.c:645
-#, c-format
+#: builtin/am.c:1505
 msgid ""
-"cannot overwrite multiple values with a single value\n"
-"       Use a regexp, --add or --replace-all to change %s."
+"Did you hand edit your patch?\n"
+"It does not apply to blobs recorded in its index."
 msgstr ""
-"no es poden sobreescriure múltiples valors amb un sol valor\n"
-"       Useu una expressió regular, --add o --replace-all per a canviar %s."
+"Heu editat el vostre pedaç a mà?\n"
+"No s'aplica als blobs recordats en el seu índex."
 
-#: builtin/count-objects.c:88
-msgid "git count-objects [-v] [-H | --human-readable]"
-msgstr "git count-objects [-v] [-H | --human-readable]"
+#: builtin/am.c:1511
+msgid "Falling back to patching base and 3-way merge..."
+msgstr "S'està retrocedint a apedaçar la base i una fusió de 3 vies..."
 
-#: builtin/count-objects.c:98
-msgid "print sizes in human readable format"
-msgstr "imprimeix les mides en un format llegible pels humans"
+#: builtin/am.c:1537
+msgid "Failed to merge in the changes."
+msgstr "S'ha produït un error en fusionar els canvis."
 
-#: builtin/describe.c:22
-msgid "git describe [<options>] [<commit-ish>...]"
-msgstr "git describe [<opcions>] [<comissió>...]"
+#: builtin/am.c:1569
+msgid "applying to an empty history"
+msgstr "s'està aplicant a una història buida"
 
-#: builtin/describe.c:23
-msgid "git describe [<options>] --dirty"
-msgstr "git describe [<opcions>] --dirty"
+#: builtin/am.c:1616 builtin/am.c:1620
+#, c-format
+msgid "cannot resume: %s does not exist."
+msgstr "no es pot reprendre: %s no existeix."
 
-#: builtin/describe.c:57
-msgid "head"
-msgstr "davant per"
+#: builtin/am.c:1638
+msgid "Commit Body is:"
+msgstr "El cos de la comissió és:"
 
-#: builtin/describe.c:57
-msgid "lightweight"
-msgstr "lleuger"
+#. TRANSLATORS: Make sure to include [y], [n], [e], [v] and [a]
+#. in your translation. The program will only accept English
+#. input at this point.
+#.
+#: builtin/am.c:1648
+#, c-format
+msgid "Apply? [y]es/[n]o/[e]dit/[v]iew patch/[a]ccept all: "
+msgstr ""
+"Voleu aplicar-lo? [y]es/[n]o/[e]dita/[v]isualitza el pedaç/[a]ccepta'ls "
+"tots: "
 
-#: builtin/describe.c:57
-msgid "annotated"
-msgstr "anotat"
+#: builtin/am.c:1695 builtin/commit.c:394
+msgid "unable to write index file"
+msgstr "no s'ha pogut escriure el fitxer d'índex"
 
-#: builtin/describe.c:267
+#: builtin/am.c:1699
 #, c-format
-msgid "annotated tag %s not available"
-msgstr "l'etiqueta anotada %s no és disponible"
+msgid "Dirty index: cannot apply patches (dirty: %s)"
+msgstr "Índex brut: no es poden aplicar pedaços (bruts: %s)"
 
-#: builtin/describe.c:271
+#: builtin/am.c:1739 builtin/am.c:1807
 #, c-format
-msgid "annotated tag %s has no embedded name"
-msgstr "l'etiqueta anotada %s no té nom incrustat"
+msgid "Applying: %.*s"
+msgstr "S'està aplicant: %.*s"
 
-#: builtin/describe.c:273
-#, c-format
-msgid "tag '%s' is really '%s' here"
-msgstr "l'etiqueta «%s» realment és «%s» aquí"
+#: builtin/am.c:1756
+msgid "No changes -- Patch already applied."
+msgstr "Sense canvis -- El pedaç ja s'ha aplicat."
 
-#: builtin/describe.c:317
+#: builtin/am.c:1762
 #, c-format
-msgid "no tag exactly matches '%s'"
-msgstr "cap etiqueta coincideix exactament amb «%s»"
+msgid "Patch failed at %s %.*s"
+msgstr "El pedaç ha fallat a %s %.*s"
 
-#: builtin/describe.c:319
-#, c-format
-msgid "No exact match on refs or tags, searching to describe\n"
+#: builtin/am.c:1766
+msgid "Use 'git am --show-current-patch' to see the failed patch"
 msgstr ""
 
-#: builtin/describe.c:366
-#, c-format
-msgid "finished search at %s\n"
-msgstr "s'ha finalitzat la cerca a %s\n"
-
-#: builtin/describe.c:392
-#, c-format
+#: builtin/am.c:1810
 msgid ""
-"No annotated tags can describe '%s'.\n"
-"However, there were unannotated tags: try --tags."
+"No changes - did you forget to use 'git add'?\n"
+"If there is nothing left to stage, chances are that something else\n"
+"already introduced the same changes; you might want to skip this patch."
 msgstr ""
-"Cap etiqueta anotada pot descriure «%s».\n"
-"No obstant, hi havia etiquetes no anotades: proveu --tags."
+"Cap canvi - heu oblidat d'usar 'git add'?\n"
+"Si no hi ha res per fer «stage», probablement alguna altra cosa ja ha\n"
+"introduït els mateixos canvis; potser voleu ometre aquest pedaç."
 
-#: builtin/describe.c:396
-#, c-format
+#: builtin/am.c:1817
 msgid ""
-"No tags can describe '%s'.\n"
-"Try --always, or create some tags."
+"You still have unmerged paths in your index.\n"
+"You should 'git add' each file with resolved conflicts to mark them as "
+"such.\n"
+"You might run `git rm` on a file to accept \"deleted by them\" for it."
 msgstr ""
-"Cap etiqueta pot descriure «%s».\n"
-"Proveu --always, o creeu algunes etiquetes."
+"Encara teniu camins sense fusionar a l'índex.\n"
+"Heu de fer 'git add' a cada fitxer amb conflictes resolts per marcar-los com "
+"a tal.\n"
+"Podeu executar `git rm` en un fitxer per acceptar \"suprimit per ells\" pel "
+"fitxer."
 
-#: builtin/describe.c:426
+#: builtin/am.c:1924 builtin/am.c:1928 builtin/am.c:1940 builtin/reset.c:346
+#: builtin/reset.c:354
 #, c-format
-msgid "traversed %lu commits\n"
-msgstr "%lu comissions travessades\n"
+msgid "Could not parse object '%s'."
+msgstr "No s'ha pogut analitzar l'objecte «%s»."
 
-#: builtin/describe.c:429
-#, c-format
+#: builtin/am.c:1976
+msgid "failed to clean index"
+msgstr "s'ha produït un error en netejar l'índex"
+
+#: builtin/am.c:2020
 msgid ""
-"more than %i tags found; listed %i most recent\n"
-"gave up search at %s\n"
+"You seem to have moved HEAD since the last 'am' failure.\n"
+"Not rewinding to ORIG_HEAD"
 msgstr ""
-"s'han trobat més de %i etiquetes: s'han llistat les %i més recents\n"
-"s'ha renunciat la cerca a %s\n"
+"Sembla que heu mogut HEAD després de l'última fallada de 'am'.\n"
+"No s'està rebobinant a ORIG_HEAD"
 
-#: builtin/describe.c:497
+#: builtin/am.c:2117
 #, c-format
-msgid "describe %s\n"
-msgstr "descriu %s\n"
+msgid "Invalid value for --patch-format: %s"
+msgstr "Valor no vàlid per a --patch-format: %s"
 
-#: builtin/describe.c:500 builtin/log.c:502
-#, c-format
-msgid "Not a valid object name %s"
-msgstr "%s no és un nom d'objecte vàlid"
+#: builtin/am.c:2153
+msgid "git am [<options>] [(<mbox> | <Maildir>)...]"
+msgstr "git am [<opcions>] [(<bústia> | <directori-de-correu>)...]"
 
-#: builtin/describe.c:508
-#, c-format
-msgid "%s is neither a commit nor blob"
-msgstr "%s no és una comissió o un blob"
+#: builtin/am.c:2154
+msgid "git am [<options>] (--continue | --skip | --abort)"
+msgstr "git am [<opcions>] (--continue | --skip | --abort)"
 
-#: builtin/describe.c:522
-msgid "find the tag that comes after the commit"
-msgstr "troba l'etiqueta que vingui després de la comissió"
+#: builtin/am.c:2160
+msgid "run interactively"
+msgstr "executa interactivament"
 
-#: builtin/describe.c:523
-msgid "debug search strategy on stderr"
-msgstr "estratègia de cerca de depuració en stderr"
+#: builtin/am.c:2162
+msgid "historical option -- no-op"
+msgstr "opció històrica -- no-op"
 
-#: builtin/describe.c:524
-msgid "use any ref"
-msgstr "usa qualsevol referència"
+#: builtin/am.c:2164
+msgid "allow fall back on 3way merging if needed"
+msgstr "permet retrocedir a una fusió de 3 vies si és necessari"
 
-#: builtin/describe.c:525
-msgid "use any tag, even unannotated"
-msgstr "usa qualsevol etiqueta, fins i tot aquelles sense anotar"
+#: builtin/am.c:2165 builtin/init-db.c:494 builtin/prune-packed.c:58
+#: builtin/repack.c:304 builtin/stash.c:811
+msgid "be quiet"
+msgstr "silenciós"
 
-#: builtin/describe.c:526
-msgid "always use long format"
-msgstr "sempre usa el format llarg"
+#: builtin/am.c:2167
+msgid "add a Signed-off-by line to the commit message"
+msgstr "afegeix una línia «Signed-off-by» al missatge de comissió"
 
-#: builtin/describe.c:527
-msgid "only follow first parent"
-msgstr "només segueix la primera mare"
+#: builtin/am.c:2170
+msgid "recode into utf8 (default)"
+msgstr "recodifica en utf8 (per defecte)"
 
-#: builtin/describe.c:530
-msgid "only output exact matches"
-msgstr "emet només coincidències exactes"
+#: builtin/am.c:2172
+msgid "pass -k flag to git-mailinfo"
+msgstr "passa l'indicador -k a git-mailinfo"
 
-#: builtin/describe.c:532
-msgid "consider <n> most recent tags (default: 10)"
-msgstr "considera les <n> etiquetes més recents (per defecte: 10)"
+#: builtin/am.c:2174
+msgid "pass -b flag to git-mailinfo"
+msgstr "passa l'indicador -b a git-mailinfo"
 
-#: builtin/describe.c:534
-msgid "only consider tags matching <pattern>"
-msgstr "només considera les etiquetes que coincideixen amb <patró>"
+#: builtin/am.c:2176
+msgid "pass -m flag to git-mailinfo"
+msgstr "passa l'indicador -m a git-mailinfo"
 
-#: builtin/describe.c:536
-msgid "do not consider tags matching <pattern>"
-msgstr "no consideris les etiquetes que no coincideixen amb <patró>"
+#: builtin/am.c:2178
+msgid "pass --keep-cr flag to git-mailsplit for mbox format"
+msgstr "passa l'indicador --keep-cr a git-mailsplit per al format mbox"
 
-#: builtin/describe.c:538 builtin/name-rev.c:406
-msgid "show abbreviated commit object as fallback"
-msgstr "mostra l'objecte de comissió abreviat com a sistema alternatiu"
+#: builtin/am.c:2181
+msgid "do not pass --keep-cr flag to git-mailsplit independent of am.keepcr"
+msgstr ""
+"no passis l'indicador --keep-cr a git-mailsplit independent d'am.keepcr"
 
-#: builtin/describe.c:539 builtin/describe.c:542
-msgid "mark"
-msgstr "marca"
+#: builtin/am.c:2184
+msgid "strip everything before a scissors line"
+msgstr "elimina tot abans d'una línia de tisores"
 
-#: builtin/describe.c:540
-msgid "append <mark> on dirty working tree (default: \"-dirty\")"
-msgstr "annexa <marca> en l'arbre de treball brut (per defecte: \"-dirty\")"
+#: builtin/am.c:2186 builtin/am.c:2189 builtin/am.c:2192 builtin/am.c:2195
+#: builtin/am.c:2198 builtin/am.c:2201 builtin/am.c:2204 builtin/am.c:2207
+#: builtin/am.c:2213
+msgid "pass it through git-apply"
+msgstr "passa-ho a través de git-apply"
 
-#: builtin/describe.c:543
-msgid "append <mark> on broken working tree (default: \"-broken\")"
-msgstr "annexa <marca> en l'arbre de treball brut (per defecte: \"-broken\")"
+#: builtin/am.c:2203 builtin/commit.c:1386 builtin/fmt-merge-msg.c:673
+#: builtin/fmt-merge-msg.c:676 builtin/grep.c:883 builtin/merge.c:249
+#: builtin/pull.c:160 builtin/pull.c:219 builtin/rebase.c:1469
+#: builtin/repack.c:315 builtin/repack.c:319 builtin/repack.c:321
+#: builtin/show-branch.c:650 builtin/show-ref.c:172 builtin/tag.c:403
+#: parse-options.h:154 parse-options.h:175 parse-options.h:316
+msgid "n"
+msgstr "n"
 
-#: builtin/describe.c:561
-msgid "--long is incompatible with --abbrev=0"
-msgstr "--long és incompatible amb --abbrev=0"
+#: builtin/am.c:2209 builtin/branch.c:661 builtin/for-each-ref.c:38
+#: builtin/replace.c:555 builtin/tag.c:437 builtin/verify-tag.c:38
+msgid "format"
+msgstr "format"
 
-#: builtin/describe.c:590
-msgid "No names found, cannot describe anything."
-msgstr "No s'ha trobat cap nom, no es pot descriure res."
+#: builtin/am.c:2210
+msgid "format the patch(es) are in"
+msgstr "el format en el qual estan els pedaços"
 
-#: builtin/describe.c:640
-msgid "--dirty is incompatible with commit-ishes"
-msgstr "--dirty és incompatible amb les comissions"
+#: builtin/am.c:2216
+msgid "override error message when patch failure occurs"
+msgstr "passa per alt el missatge d'error si falla l'aplicació del pedaç"
 
-#: builtin/describe.c:642
-msgid "--broken is incompatible with commit-ishes"
-msgstr "--broken és incompatible amb les comissions"
+#: builtin/am.c:2218
+msgid "continue applying patches after resolving a conflict"
+msgstr "segueix aplicant pedaços després de resoldre un conflicte"
 
-#: builtin/diff.c:83
-#, c-format
-msgid "'%s': not a regular file or symlink"
-msgstr "«%s»: no és ni fitxer regular ni enllaç simbòlic"
+#: builtin/am.c:2221
+msgid "synonyms for --continue"
+msgstr "sinònims de --continue"
 
-#: builtin/diff.c:234
-#, c-format
-msgid "invalid option: %s"
-msgstr "opció no vàlida: %s"
+#: builtin/am.c:2224
+msgid "skip the current patch"
+msgstr "omet el pedaç actual"
 
-#: builtin/diff.c:356
-msgid "Not a git repository"
-msgstr "No és un dipòsit de git"
+#: builtin/am.c:2227
+msgid "restore the original branch and abort the patching operation."
+msgstr "restaura la branca original i avorta l'operació d'apedaçament."
 
-#: builtin/diff.c:399
-#, c-format
-msgid "invalid object '%s' given."
-msgstr "s'ha donat un objecte no vàlid «%s»."
+#: builtin/am.c:2230
+msgid "abort the patching operation but keep HEAD where it is."
+msgstr ""
 
-#: builtin/diff.c:408
-#, c-format
-msgid "more than two blobs given: '%s'"
-msgstr "s'ha donat més de dos blobs: «%s»"
+#: builtin/am.c:2233
+msgid "show the patch being applied."
+msgstr "mostra el pedaç que s'està aplicant."
 
-#: builtin/diff.c:413
-#, c-format
-msgid "unhandled object '%s' given."
-msgstr "s'ha donat l'objecte no gestionat «%s»."
+#: builtin/am.c:2237
+msgid "lie about committer date"
+msgstr "menteix sobre la data del comitent"
 
-#: builtin/difftool.c:29
-msgid "git difftool [<options>] [<commit> [<commit>]] [--] [<path>...]"
-msgstr "git difftool [<opcions>] [<commit> [<commit>]] [--] [<camí>...]"
+#: builtin/am.c:2239
+msgid "use current timestamp for author date"
+msgstr "usa el marc de temps actual per la data d'autor"
 
-#: builtin/difftool.c:259
-#, c-format
-msgid "failed: %d"
-msgstr "ha fallat: %d"
+#: builtin/am.c:2241 builtin/commit-tree.c:120 builtin/commit.c:1507
+#: builtin/merge.c:286 builtin/pull.c:194 builtin/rebase.c:509
+#: builtin/rebase.c:1513 builtin/revert.c:117 builtin/tag.c:418
+msgid "key-id"
+msgstr "ID de clau"
 
-#: builtin/difftool.c:301
-#, c-format
-msgid "could not read symlink %s"
-msgstr "no s'ha pogut llegir l'enllaç simbòlic %s"
+#: builtin/am.c:2242 builtin/rebase.c:510 builtin/rebase.c:1514
+msgid "GPG-sign commits"
+msgstr "signa les comissions amb GPG"
 
-#: builtin/difftool.c:303
-#, c-format
-msgid "could not read symlink file %s"
-msgstr "no s'ha pogut llegir el fitxer d'enllaç simbòlic %s"
+#: builtin/am.c:2245
+msgid "(internal use for git-rebase)"
+msgstr "(ús intern per a git-rebase)"
+
+#: builtin/am.c:2263
+msgid ""
+"The -b/--binary option has been a no-op for long time, and\n"
+"it will be removed. Please do not use it anymore."
+msgstr ""
+"Fa molt que l'opció -b/--binary no ha fet res, i\n"
+"s'eliminarà. No l'useu més."
 
-#: builtin/difftool.c:311
+#: builtin/am.c:2270
+msgid "failed to read the index"
+msgstr "S'ha produït un error en llegir l'índex"
+
+#: builtin/am.c:2285
 #, c-format
-msgid "could not read object %s for symlink %s"
-msgstr "No es pot llegir l'objecte %s per l'enllaç simbòlic %s"
+msgid "previous rebase directory %s still exists but mbox given."
+msgstr ""
+"un directori de «rebase» anterior %s encara existeix però s'ha donat una "
+"bústia."
 
-#: builtin/difftool.c:412
+#: builtin/am.c:2309
+#, c-format
 msgid ""
-"combined diff formats('-c' and '--cc') are not supported in\n"
-"directory diff mode('-d' and '--dir-diff')."
+"Stray %s directory found.\n"
+"Use \"git am --abort\" to remove it."
+msgstr ""
+"S'ha trobat un directori %s extraviat.\n"
+"Useu \"git am --abort\" per a eliminar-lo."
+
+#: builtin/am.c:2315
+msgid "Resolve operation not in progress, we are not resuming."
+msgstr "Una operació de resolució no està en curs; no reprenem."
+
+#: builtin/am.c:2325
+msgid "interactive mode requires patches on the command line"
 msgstr ""
-"els formats de diff combinats ('-c' and '--cc') no són admesos \n"
-"en el mode diff per directoris ('-d' and '--dir-diff')."
 
-#: builtin/difftool.c:632
+#: builtin/apply.c:8
+msgid "git apply [<options>] [<patch>...]"
+msgstr "git apply [<opcions>] [<pedaç>...]"
+
+#: builtin/archive.c:17
 #, c-format
-msgid "both files modified: '%s' and '%s'."
-msgstr "s'han modificat ambdós fitxers: «%s» i «%s»."
+msgid "could not create archive file '%s'"
+msgstr "no s'ha pogut crear el fitxer d'arxiu «%s»"
 
-#: builtin/difftool.c:634
-msgid "working tree file has been left."
-msgstr "s'ha deixat un fitxer de l'arbre de treball."
+#: builtin/archive.c:20
+msgid "could not redirect output"
+msgstr "no s'ha pogut redirigir la sortida"
+
+#: builtin/archive.c:37
+msgid "git archive: Remote with no URL"
+msgstr "git archive: Remot sense URL"
+
+#: builtin/archive.c:61
+msgid "git archive: expected ACK/NAK, got a flush packet"
+msgstr "git archive: s'esperava ACK/NAK, s'ha rebut un paquet de neteja"
 
-#: builtin/difftool.c:645
+#: builtin/archive.c:64
 #, c-format
-msgid "temporary files exist in '%s'."
-msgstr "existeix un fitxer temporal a %s'."
+msgid "git archive: NACK %s"
+msgstr "git archive: %s NACK"
 
-#: builtin/difftool.c:646
-msgid "you may want to cleanup or recover these."
-msgstr "podeu netejar o recuperar-los."
+#: builtin/archive.c:65
+msgid "git archive: protocol error"
+msgstr "git archive: error de protocol"
 
-#: builtin/difftool.c:695
-msgid "use `diff.guitool` instead of `diff.tool`"
-msgstr "utilitza `diff.guitool` en comptes de `diff.tool`"
+#: builtin/archive.c:69
+msgid "git archive: expected a flush"
+msgstr "git archive: s'esperava una neteja"
 
-#: builtin/difftool.c:697
-msgid "perform a full-directory diff"
-msgstr "fes un diff de tot el directori"
+#: builtin/bisect--helper.c:22
+msgid "git bisect--helper --next-all [--no-checkout]"
+msgstr "git bisect--helper --next-all [--no-checkout]"
 
-#: builtin/difftool.c:699
-msgid "do not prompt before launching a diff tool"
-msgstr "no preguntis abans d'executar l'eina diff"
+#: builtin/bisect--helper.c:23
+msgid "git bisect--helper --write-terms <bad_term> <good_term>"
+msgstr "git bisect--helper --write-terms <mal_terme> <bon_terme>"
 
-#: builtin/difftool.c:705
-msgid "use symlinks in dir-diff mode"
-msgstr "utilitza enllaços simbòlics en mode dir-diff"
+#: builtin/bisect--helper.c:24
+msgid "git bisect--helper --bisect-clean-state"
+msgstr "git bisect--helper --bisect-clean-state"
 
-#: builtin/difftool.c:706
-msgid "<tool>"
-msgstr "<tool>"
+#: builtin/bisect--helper.c:25
+#, fuzzy
+msgid "git bisect--helper --bisect-reset [<commit>]"
+msgstr "git bisect--helper --bisect-clean-state"
 
-#: builtin/difftool.c:707
-msgid "use the specified diff tool"
-msgstr "utilitza l'eina de diff especificada"
+#: builtin/bisect--helper.c:26
+#, fuzzy
+msgid ""
+"git bisect--helper --bisect-write [--no-log] <state> <revision> <good_term> "
+"<bad_term>"
+msgstr "git bisect--helper --write-terms <mal_terme> <bon_terme>"
 
-#: builtin/difftool.c:709
-msgid "print a list of diff tools that may be used with `--tool`"
+#: builtin/bisect--helper.c:27
+#, fuzzy
+msgid ""
+"git bisect--helper --bisect-check-and-set-terms <command> <good_term> "
+"<bad_term>"
+msgstr "git bisect--helper --write-terms <mal_terme> <bon_terme>"
+
+#: builtin/bisect--helper.c:28
+#, fuzzy
+msgid "git bisect--helper --bisect-next-check <good_term> <bad_term> [<term>]"
+msgstr "git bisect--helper --write-terms <mal_terme> <bon_terme>"
+
+#: builtin/bisect--helper.c:29
+#, fuzzy
+msgid ""
+"git bisect--helper --bisect-terms [--term-good | --term-old | --term-bad | --"
+"term-new]"
 msgstr ""
-"imprimeix una llista de totes les eines diff que podeu usar amb `--tool`"
+"paràmetre no vàlid $arg per a 'git bisect terms'.\n"
+"Les opcions admeses són: --term-good|--term-old i --term-bad|--term-new."
 
-#: builtin/difftool.c:712
+#: builtin/bisect--helper.c:30
 msgid ""
-"make 'git-difftool' exit when an invoked diff tool returns a non - zero exit "
-"code"
+"git bisect--helper --bisect-start [--term-{old,good}=<term> --term-{new,bad}"
+"=<term>][--no-checkout] [<bad> [<good>...]] [--] [<paths>...]"
 msgstr ""
-"fes que 'git-difftool' surti quan l'eina de diff invocada torna un codi de "
-"sortida diferent de zero"
 
-#: builtin/difftool.c:714
-msgid "<command>"
-msgstr "<command>"
+#: builtin/bisect--helper.c:86
+#, c-format
+msgid "'%s' is not a valid term"
+msgstr "«%s» no és un terme vàlid"
 
-#: builtin/difftool.c:715
-msgid "specify a custom command for viewing diffs"
-msgstr "especifiqueu una ordre personalitzada per veure diffs"
+#: builtin/bisect--helper.c:90
+#, c-format
+msgid "can't use the builtin command '%s' as a term"
+msgstr "no es pot usar l'ordre interna «%s» com a terme"
 
-#: builtin/difftool.c:739
-msgid "no <tool> given for --tool=<tool>"
-msgstr "no s'ha proporcionat <tool> per --tool=<tool>"
+#: builtin/bisect--helper.c:100
+#, c-format
+msgid "can't change the meaning of the term '%s'"
+msgstr "no es pot canviar el significat del terme «%s»"
 
-#: builtin/difftool.c:746
-msgid "no <cmd> given for --extcmd=<cmd>"
-msgstr "no s'ha proporcionat <cmd> per --extcmd=<cmd>"
+#: builtin/bisect--helper.c:111
+msgid "please use two different terms"
+msgstr "useu dos termes distintes"
 
-#: builtin/fast-export.c:26
-msgid "git fast-export [rev-list-opts]"
-msgstr "git fast-export [opcions-de-llista-de-revisions]"
+#: builtin/bisect--helper.c:118
+msgid "could not open the file BISECT_TERMS"
+msgstr "no s'ha pogut obrir el BISECT_TERMS"
 
-#: builtin/fast-export.c:998
-msgid "show progress after <n> objects"
-msgstr "mostra el progrés després de <n> objectes"
+#: builtin/bisect--helper.c:155
+#, fuzzy, c-format
+msgid "We are not bisecting.\n"
+msgstr "No estem bisecant."
 
-#: builtin/fast-export.c:1000
-msgid "select handling of signed tags"
-msgstr "selecciona la gestió de les etiquetes signades"
+#: builtin/bisect--helper.c:163
+#, fuzzy, c-format
+msgid "'%s' is not a valid commit"
+msgstr "«%s» no és un terme vàlid"
 
-#: builtin/fast-export.c:1003
-msgid "select handling of tags that tag filtered objects"
-msgstr "selecciona la gestió de les etiquetes que etiquetin objectes filtrats"
+#: builtin/bisect--helper.c:172
+#, fuzzy, c-format
+msgid ""
+"could not check out original HEAD '%s'. Try 'git bisect reset <commit>'."
+msgstr ""
+"No s'ha pogut agafar la HEAD original '$branch'.\n"
+"Proveu 'git bisect reset <comissió>'."
 
-#: builtin/fast-export.c:1006
-msgid "Dump marks to this file"
-msgstr "Bolca les marques a aquest fitxer"
+#: builtin/bisect--helper.c:216
+#, fuzzy, c-format
+msgid "Bad bisect_write argument: %s"
+msgstr "Paràmetre bisect_write incorrecte: $state"
 
-#: builtin/fast-export.c:1008
-msgid "Import marks from this file"
-msgstr "Importa les marques d'aquest fitxer"
+#: builtin/bisect--helper.c:221
+#, fuzzy, c-format
+msgid "couldn't get the oid of the rev '%s'"
+msgstr "no es pot canviar el significat del terme «%s»"
 
-#: builtin/fast-export.c:1010
-msgid "Fake a tagger when tags lack one"
-msgstr "Fingeix un etiquetador quan els en manca un a les etiquetes"
+#: builtin/bisect--helper.c:233
+#, fuzzy, c-format
+msgid "couldn't open the file '%s'"
+msgstr "no s'ha pogut crear el fitxer «%s»"
 
-#: builtin/fast-export.c:1012
-msgid "Output full tree for each commit"
-msgstr "Imprimeix l'arbre complet de cada comissió"
+#: builtin/bisect--helper.c:259
+#, fuzzy, c-format
+msgid "Invalid command: you're currently in a %s/%s bisect"
+msgstr ""
+"Ordre no vàlida: actualment esteu en una bisecció $TERM_BAD/$TERM_GOOD."
 
-#: builtin/fast-export.c:1014
-msgid "Use the done feature to terminate the stream"
-msgstr "Usa la característica done per a acabar el corrent"
+#: builtin/bisect--helper.c:286
+#, fuzzy, c-format
+msgid ""
+"You need to give me at least one %s and %s revision.\n"
+"You can use \"git bisect %s\" and \"git bisect %s\" for that."
+msgstr ""
+"Cal donar-me almenys una revisió $bad_syn i una $good_syn.\n"
+"(Podeu usar \"git bisect $bad_syn\" i \"git bisect $good_syn\" per això.)"
 
-#: builtin/fast-export.c:1015
-msgid "Skip output of blob data"
-msgstr "Omet l'emissió de dades de blob"
+#: builtin/bisect--helper.c:290
+#, fuzzy, c-format
+msgid ""
+"You need to start by \"git bisect start\".\n"
+"You then need to give me at least one %s and %s revision.\n"
+"You can use \"git bisect %s\" and \"git bisect %s\" for that."
+msgstr ""
+"Cal començar amb \"git bisect start\".\n"
+"Després cal donar-me almenys una revisió $good_syn i una $bad_syn.\n"
+"(Podeu usar \"git bisect $bad_syn\" i \"git bisect $good_syn\" per això.)"
 
-#: builtin/fast-export.c:1016
-msgid "refspec"
-msgstr "especificació de referència"
+#: builtin/bisect--helper.c:322
+#, fuzzy, c-format
+msgid "bisecting only with a %s commit"
+msgstr "Advertència: bisecant amb només comissió $TERM_BAD."
 
-#: builtin/fast-export.c:1017
-msgid "Apply refspec to exported refs"
-msgstr "Aplica l'especificació de referència a les referències exportades"
+#. TRANSLATORS: Make sure to include [Y] and [n] in your
+#. translation. The program will only accept English input
+#. at this point.
+#.
+#: builtin/bisect--helper.c:330
+msgid "Are you sure [Y/n]? "
+msgstr "N'esteu segur [Y/n]? "
 
-#: builtin/fast-export.c:1018
-msgid "anonymize output"
-msgstr "anonimitza la sortida"
+#: builtin/bisect--helper.c:377
+msgid "no terms defined"
+msgstr "cap terme definit"
 
-#: builtin/fetch.c:25
-msgid "git fetch [<options>] [<repository> [<refspec>...]]"
-msgstr "git fetch [<opcions>] [<dipòsit> [<especificació-de-referència>...]]"
+#: builtin/bisect--helper.c:380
+#, c-format
+msgid ""
+"Your current terms are %s for the old state\n"
+"and %s for the new state.\n"
+msgstr ""
 
-#: builtin/fetch.c:26
-msgid "git fetch [<options>] <group>"
-msgstr "git fetch [<opcions>] <grup>"
+#: builtin/bisect--helper.c:390
+#, fuzzy, c-format
+msgid ""
+"invalid argument %s for 'git bisect terms'.\n"
+"Supported options are: --term-good|--term-old and --term-bad|--term-new."
+msgstr ""
+"paràmetre no vàlid $arg per a 'git bisect terms'.\n"
+"Les opcions admeses són: --term-good|--term-old i --term-bad|--term-new."
 
-#: builtin/fetch.c:27
-msgid "git fetch --multiple [<options>] [(<repository> | <group>)...]"
-msgstr "git fetch --multiple [<opcions>] [(<dipòsit> | <grup>)...]"
+#: builtin/bisect--helper.c:476
+#, fuzzy, c-format
+msgid "unrecognized option: '%s'"
+msgstr "posició no reconeguda:%s"
 
-#: builtin/fetch.c:28
-msgid "git fetch --all [<options>]"
-msgstr "git fetch --all [<opcions>]"
+#: builtin/bisect--helper.c:480
+#, fuzzy, c-format
+msgid "'%s' does not appear to be a valid revision"
+msgstr "'$arg' no sembla una revisió vàlida"
 
-#: builtin/fetch.c:124 builtin/pull.c:188
-msgid "fetch from all remotes"
-msgstr "obtén de tots els remots"
+#: builtin/bisect--helper.c:512
+#, fuzzy
+msgid "bad HEAD - I need a HEAD"
+msgstr "HEAD incorrecte - Cal un HEAD"
 
-#: builtin/fetch.c:126 builtin/pull.c:191
-msgid "append to .git/FETCH_HEAD instead of overwriting"
-msgstr "annexa a .git/FETCH_HEAD en lloc de sobreescriure"
+#: builtin/bisect--helper.c:527
+#, fuzzy, c-format
+msgid "checking out '%s' failed. Try 'git bisect start <valid-branch>'."
+msgstr ""
+"L'agafament de '$start_head' ha fallat. Proveu 'git bisect reset <branca-"
+"vàlida>'."
 
-#: builtin/fetch.c:128 builtin/pull.c:194
-msgid "path to upload pack on remote end"
-msgstr "camí al qual pujar el paquet al costat remot"
+#: builtin/bisect--helper.c:548
+msgid "won't bisect on cg-seek'ed tree"
+msgstr "no es bisecarà en un arbre en el qual s'ha fet cg-seek"
 
-#: builtin/fetch.c:129 builtin/pull.c:196
-msgid "force overwrite of local branch"
-msgstr "força la sobreescriptura de la branca local"
+#: builtin/bisect--helper.c:551
+#, fuzzy
+msgid "bad HEAD - strange symbolic ref"
+msgstr "HEAD incorrecte - referència simbòlica estranya"
 
-#: builtin/fetch.c:131
-msgid "fetch from multiple remotes"
-msgstr "obtén de múltiples remots"
+#: builtin/bisect--helper.c:575
+#, fuzzy, c-format
+msgid "invalid ref: '%s'"
+msgstr "fitxer no vàlid: «%s»"
 
-#: builtin/fetch.c:133 builtin/pull.c:198
-msgid "fetch all tags and associated objects"
-msgstr "obtén totes les etiquetes i tots els objectes associats"
+#: builtin/bisect--helper.c:631
+msgid "perform 'git bisect next'"
+msgstr "realitza 'git bisect next'"
 
-#: builtin/fetch.c:135
-msgid "do not fetch all tags (--no-tags)"
-msgstr "no obtinguis les etiquetes (--no-tags)"
+#: builtin/bisect--helper.c:633
+msgid "write the terms to .git/BISECT_TERMS"
+msgstr "escriu els termes a .git/BISECT_TERMS"
 
-#: builtin/fetch.c:137
-msgid "number of submodules fetched in parallel"
-msgstr "nombre de submòduls obtinguts en paral·lel"
+#: builtin/bisect--helper.c:635
+msgid "cleanup the bisection state"
+msgstr "neteja l'estat de la bisecció"
 
-#: builtin/fetch.c:139 builtin/pull.c:201
-msgid "prune remote-tracking branches no longer on remote"
-msgstr "poda les branques amb seguiment remot que ja no estiguin en el remot"
+#: builtin/bisect--helper.c:637
+msgid "check for expected revs"
+msgstr "comprova les revisions esperades"
 
-#: builtin/fetch.c:141
-msgid "prune local tags no longer on remote and clobber changed tags"
-msgstr ""
+#: builtin/bisect--helper.c:639
+#, fuzzy
+msgid "reset the bisection state"
+msgstr "neteja l'estat de la bisecció"
 
-#: builtin/fetch.c:142 builtin/fetch.c:165 builtin/pull.c:126
-msgid "on-demand"
-msgstr "sota demanda"
+#: builtin/bisect--helper.c:641
+#, fuzzy
+msgid "write out the bisection state in BISECT_LOG"
+msgstr "neteja l'estat de la bisecció"
 
-#: builtin/fetch.c:143
-msgid "control recursive fetching of submodules"
-msgstr "controla l'obtenció recursiva de submòduls"
+#: builtin/bisect--helper.c:643
+#, fuzzy
+msgid "check and set terms in a bisection state"
+msgstr "neteja l'estat de la bisecció"
 
-#: builtin/fetch.c:147 builtin/pull.c:209
-msgid "keep downloaded pack"
-msgstr "retén el paquet baixat"
+#: builtin/bisect--helper.c:645
+msgid "check whether bad or good terms exist"
+msgstr ""
 
-#: builtin/fetch.c:149
-msgid "allow updating of HEAD ref"
-msgstr "permet l'actualització de la referència HEAD"
+#: builtin/bisect--helper.c:647
+#, fuzzy
+msgid "print out the bisect terms"
+msgstr "imprimeix només les etiquetes de l'objecte"
 
-#: builtin/fetch.c:152 builtin/fetch.c:158 builtin/pull.c:212
-msgid "deepen history of shallow clone"
-msgstr "aprofundeix la història d'un clon superficial"
+#: builtin/bisect--helper.c:649
+msgid "start the bisect session"
+msgstr ""
 
-#: builtin/fetch.c:154
-msgid "deepen history of shallow repository based on time"
-msgstr "aprofundeix la història d'un clon superficial basat en temps"
+#: builtin/bisect--helper.c:651
+msgid "update BISECT_HEAD instead of checking out the current commit"
+msgstr "actualitza BISECT_HEAD en lloc d'agafar la comissió actual"
 
-#: builtin/fetch.c:160 builtin/pull.c:215
-msgid "convert to a complete repository"
-msgstr "converteix en un dipòsit complet"
+#: builtin/bisect--helper.c:653
+msgid "no log for BISECT_WRITE"
+msgstr ""
 
-#: builtin/fetch.c:162 builtin/log.c:1466
-msgid "dir"
-msgstr "directori"
+#: builtin/bisect--helper.c:670
+msgid "--write-terms requires two arguments"
+msgstr "--write-terms requereix dos paràmetres"
 
-#: builtin/fetch.c:163
-msgid "prepend this to submodule path output"
-msgstr "anteposa això a la sortida de camí del submòdul"
+#: builtin/bisect--helper.c:674
+msgid "--bisect-clean-state requires no arguments"
+msgstr "--bisect-clean-state no accepta paràmetres"
 
-#: builtin/fetch.c:166
-msgid ""
-"default for recursive fetching of submodules (lower priority than config "
-"files)"
-msgstr ""
-"per defecte per a l'obtenció recursiva de submòduls (prioritat més baixa que "
-"els fitxers de configuració)"
+#: builtin/bisect--helper.c:681
+#, fuzzy
+msgid "--bisect-reset requires either no argument or a commit"
+msgstr "--bisect-clean-state no accepta paràmetres"
 
-#: builtin/fetch.c:170 builtin/pull.c:218
-msgid "accept refs that update .git/shallow"
-msgstr "accepta les referències que actualitzin .git/shallow"
+#: builtin/bisect--helper.c:685
+#, fuzzy
+msgid "--bisect-write requires either 4 or 5 arguments"
+msgstr "--bisect-clean-state no accepta paràmetres"
 
-#: builtin/fetch.c:171 builtin/pull.c:220
-msgid "refmap"
-msgstr "mapa de referències"
+#: builtin/bisect--helper.c:691
+#, fuzzy
+msgid "--check-and-set-terms requires 3 arguments"
+msgstr "--bisect-clean-state no accepta paràmetres"
 
-#: builtin/fetch.c:172 builtin/pull.c:221
-msgid "specify fetch refmap"
-msgstr "mostra el mapa de referències d'obtenció"
+#: builtin/bisect--helper.c:697
+#, fuzzy
+msgid "--bisect-next-check requires 2 or 3 arguments"
+msgstr "--bisect-clean-state no accepta paràmetres"
 
-#: builtin/fetch.c:431
-msgid "Couldn't find remote ref HEAD"
-msgstr "No s'ha pogut trobar la referència HEAD remota"
+#: builtin/bisect--helper.c:703
+#, fuzzy
+msgid "--bisect-terms requires 0 or 1 argument"
+msgstr "--write-terms requereix dos paràmetres"
 
-#: builtin/fetch.c:549
-#, c-format
-msgid "configuration fetch.output contains invalid value %s"
-msgstr "la configuració fetch.output conté un valor no vàlid %s"
+#: builtin/blame.c:31
+msgid "git blame [<options>] [<rev-opts>] [<rev>] [--] <file>"
+msgstr "git blame [<opcions>] [<opcions-de-revisió>] [<revisió>] [--] fitxer"
 
-#: builtin/fetch.c:642
-#, c-format
-msgid "object %s not found"
-msgstr "objecte %s no trobat"
+#: builtin/blame.c:36
+msgid "<rev-opts> are documented in git-rev-list(1)"
+msgstr "es documenten les <opcions-de-revisió> en git-rev-list(1)"
 
-#: builtin/fetch.c:646
-msgid "[up to date]"
-msgstr "[al dia]"
+#: builtin/blame.c:409
+#, fuzzy, c-format
+msgid "expecting a color: %s"
+msgstr "respecta els colors del format"
 
-#: builtin/fetch.c:659 builtin/fetch.c:739
-msgid "[rejected]"
-msgstr "[rebutjat]"
+#: builtin/blame.c:416
+msgid "must end with a color"
+msgstr ""
 
-#: builtin/fetch.c:660
-msgid "can't fetch in current branch"
-msgstr "no es pot obtenir en la branca actual"
+#: builtin/blame.c:729
+#, fuzzy, c-format
+msgid "invalid color '%s' in color.blame.repeatedLines"
+msgstr "ignora el color no vàlid «%.*s» en log.graphColors"
 
-#: builtin/fetch.c:669
-msgid "[tag update]"
-msgstr "[actualització d'etiqueta]"
+#: builtin/blame.c:747
+#, fuzzy
+msgid "invalid value for blame.coloring"
+msgstr "valor no vàlid per a --missing"
 
-#: builtin/fetch.c:670 builtin/fetch.c:703 builtin/fetch.c:719
-#: builtin/fetch.c:734
-msgid "unable to update local ref"
-msgstr "no s'ha pogut actualitzar la referència local"
+#: builtin/blame.c:822
+#, fuzzy, c-format
+msgid "cannot find revision %s to ignore"
+msgstr "no s'ha pogut resoldre la revisió: %s"
 
-#: builtin/fetch.c:689
-msgid "[new tag]"
-msgstr "[etiqueta nova]"
+#: builtin/blame.c:844
+msgid "Show blame entries as we find them, incrementally"
+msgstr "Mostra les entrades «blame» mentre les trobem, incrementalment"
 
-#: builtin/fetch.c:692
-msgid "[new branch]"
-msgstr "[branca nova]"
+#: builtin/blame.c:845
+msgid "Show blank SHA-1 for boundary commits (Default: off)"
+msgstr ""
+"Mostra un SHA-1 en blanc per les comissions de frontera (Per defecte: "
+"desactivat)"
 
-#: builtin/fetch.c:695
-msgid "[new ref]"
-msgstr "[referència nova]"
+#: builtin/blame.c:846
+msgid "Do not treat root commits as boundaries (Default: off)"
+msgstr ""
+"No tractis les comissions d'arrel com a límits (Per defecte: desactivat)"
 
-#: builtin/fetch.c:734
-msgid "forced update"
-msgstr "actualització forçada"
+#: builtin/blame.c:847
+msgid "Show work cost statistics"
+msgstr "Mostra les estadístiques de preu de treball"
 
-#: builtin/fetch.c:739
-msgid "non-fast-forward"
-msgstr "sense avanç ràpid"
+#: builtin/blame.c:848
+msgid "Force progress reporting"
+msgstr "Força l'informe de progrés"
 
-#: builtin/fetch.c:784
-#, c-format
-msgid "%s did not send all necessary objects\n"
-msgstr "%s no ha enviat tots els objectes necessaris\n"
+#: builtin/blame.c:849
+msgid "Show output score for blame entries"
+msgstr "Mostra la puntuació de sortida de les entrades «blame»"
 
-#: builtin/fetch.c:804
-#, c-format
-msgid "reject %s because shallow roots are not allowed to be updated"
-msgstr ""
-"rebutja %s perquè no es permet que les arrels superficials s'actualitzin"
+#: builtin/blame.c:850
+msgid "Show original filename (Default: auto)"
+msgstr "Mostra el nom de fitxer original (Per defecte: automàtic)"
 
-#: builtin/fetch.c:892 builtin/fetch.c:988
-#, c-format
-msgid "From %.*s\n"
-msgstr "De %.*s\n"
+#: builtin/blame.c:851
+msgid "Show original linenumber (Default: off)"
+msgstr "Mostra el número de línia original (Per defecte: desactivat)"
 
-#: builtin/fetch.c:903
-#, c-format
-msgid ""
-"some local refs could not be updated; try running\n"
-" 'git remote prune %s' to remove any old, conflicting branches"
-msgstr ""
-"algunes referències locals no s'han pogut actualitzar;\n"
-" intenteu executar 'git remote prune %s' per a eliminar\n"
-" qualsevol branca antiga o conflictiva"
+#: builtin/blame.c:852
+msgid "Show in a format designed for machine consumption"
+msgstr "Presenta en un format dissenyat per consumpció per màquina"
 
-#: builtin/fetch.c:958
-#, c-format
-msgid "   (%s will become dangling)"
-msgstr "   (%s es tornarà penjant)"
+#: builtin/blame.c:853
+msgid "Show porcelain format with per-line commit information"
+msgstr "Mostra el format de porcellana amb informació de comissió per línia"
 
-#: builtin/fetch.c:959
-#, c-format
-msgid "   (%s has become dangling)"
-msgstr "   (%s s'ha tornat penjant)"
+#: builtin/blame.c:854
+msgid "Use the same output mode as git-annotate (Default: off)"
+msgstr ""
+"Usa el mateix mode de sortida que git-annotate (Per defecte: desactivat)"
 
-#: builtin/fetch.c:991
-msgid "[deleted]"
-msgstr "[suprimit]"
+#: builtin/blame.c:855
+msgid "Show raw timestamp (Default: off)"
+msgstr "Mostra la marca de temps crua (Per defecte: desactivat)"
 
-#: builtin/fetch.c:992 builtin/remote.c:1024
-msgid "(none)"
-msgstr "(cap)"
+#: builtin/blame.c:856
+msgid "Show long commit SHA1 (Default: off)"
+msgstr "Mostra l'SHA1 de comissió llarg (Per defecte: desactivat)"
 
-#: builtin/fetch.c:1015
-#, c-format
-msgid "Refusing to fetch into current branch %s of non-bare repository"
-msgstr "S'està refusant obtenir en la branca actual %s d'un dipòsit no nu"
+#: builtin/blame.c:857
+msgid "Suppress author name and timestamp (Default: off)"
+msgstr "Omet el nom d'autor i la marca de temps (Per defecte: desactivat)"
 
-#: builtin/fetch.c:1034
-#, c-format
-msgid "Option \"%s\" value \"%s\" is not valid for %s"
-msgstr "L'opció \"%s\" amb valor \"%s\" no és vàlida per a %s"
+#: builtin/blame.c:858
+msgid "Show author email instead of name (Default: off)"
+msgstr ""
+"Mostra l'adreça electrònica de l'autor en lloc del nom (Per defecte: "
+"desactivat)"
 
-#: builtin/fetch.c:1037
-#, c-format
-msgid "Option \"%s\" is ignored for %s\n"
-msgstr "S'ignora l'opció \"%s\" per a %s\n"
+#: builtin/blame.c:859
+msgid "Ignore whitespace differences"
+msgstr "Ignora les diferències d'espai en blanc"
 
-#: builtin/fetch.c:1277
-#, c-format
-msgid "Fetching %s\n"
-msgstr "S'està obtenint %s\n"
+#: builtin/blame.c:860 builtin/log.c:1702
+msgid "rev"
+msgstr "rev"
 
-#: builtin/fetch.c:1279 builtin/remote.c:97
-#, c-format
-msgid "Could not fetch %s"
-msgstr "No s'ha pogut obtenir %s"
+#: builtin/blame.c:860
+#, fuzzy
+msgid "Ignore <rev> when blaming"
+msgstr "ignora l'índex en comprovar"
 
-#: builtin/fetch.c:1325 builtin/fetch.c:1498
-msgid ""
-"--filter can only be used with the remote configured in core.partialClone"
-msgstr ""
+#: builtin/blame.c:861
+#, fuzzy
+msgid "Ignore revisions from <file>"
+msgstr "llegiu el missatge des d'un fitxer"
 
-#: builtin/fetch.c:1350
-msgid ""
-"No remote repository specified.  Please, specify either a URL or a\n"
-"remote name from which new revisions should be fetched."
+#: builtin/blame.c:862
+msgid "color redundant metadata from previous line differently"
 msgstr ""
-"Cap dipòsit remot especificat. Especifiqueu un URL o\n"
-"un nom remot del qual es deuen obtenir les revisions noves."
 
-#: builtin/fetch.c:1394
-msgid "You need to specify a tag name."
-msgstr "Necessiteu especificar un nom d'etiqueta."
+#: builtin/blame.c:863
+msgid "color lines by age"
+msgstr ""
 
-#: builtin/fetch.c:1439
-msgid "Negative depth in --deepen is not supported"
-msgstr "No s'admet una profunditat negativa en --deepen"
+#: builtin/blame.c:864
+msgid "Spend extra cycles to find better match"
+msgstr "Gasta cicles extres per a trobar una coincidència millor"
 
-#: builtin/fetch.c:1441
-msgid "--deepen and --depth are mutually exclusive"
-msgstr "--deepen i --depth són mútuament excloents"
+#: builtin/blame.c:865
+msgid "Use revisions from <file> instead of calling git-rev-list"
+msgstr "Usa les revisions de <fitxer> en lloc d'invocar git-rev-list"
 
-#: builtin/fetch.c:1446
-msgid "--depth and --unshallow cannot be used together"
-msgstr "--depth i --unshallow no es poden usar junts"
+#: builtin/blame.c:866
+msgid "Use <file>'s contents as the final image"
+msgstr "Usa els continguts de <fitxer> com a la imatge final"
 
-#: builtin/fetch.c:1448
-msgid "--unshallow on a complete repository does not make sense"
-msgstr "--unshallow en un dipòsit complet no té sentit"
+#: builtin/blame.c:867 builtin/blame.c:868
+msgid "score"
+msgstr "puntuació"
 
-#: builtin/fetch.c:1464
-msgid "fetch --all does not take a repository argument"
-msgstr "fetch --all no accepta un paràmetre de dipòsit"
+#: builtin/blame.c:867
+msgid "Find line copies within and across files"
+msgstr "Troba còpies de línia dins i a través dels fitxers"
 
-#: builtin/fetch.c:1466
-msgid "fetch --all does not make sense with refspecs"
-msgstr "fetch --all no té sentit amb especificacions de referència"
+#: builtin/blame.c:868
+msgid "Find line movements within and across files"
+msgstr "Troba moviments de línia dins i a través dels fitxers"
 
-#: builtin/fetch.c:1475
-#, c-format
-msgid "No such remote or remote group: %s"
-msgstr "No hi ha tal remot ni tal grup remot: %s"
+#: builtin/blame.c:869
+msgid "n,m"
+msgstr "n,m"
 
-#: builtin/fetch.c:1482
-msgid "Fetching a group and specifying refspecs does not make sense"
-msgstr "Obtenir un grup i especificar referències no té sentit"
+#: builtin/blame.c:869
+msgid "Process only line range n,m, counting from 1"
+msgstr "Processa només el rang de línies n,m, comptant des d'1"
 
-#: builtin/fmt-merge-msg.c:15
-msgid ""
-"git fmt-merge-msg [-m <message>] [--log[=<n>] | --no-log] [--file <file>]"
+#: builtin/blame.c:921
+msgid "--progress can't be used with --incremental or porcelain formats"
 msgstr ""
-"git fmt-merge-msg [-m <missatge>] [--log[=<n>] | --no-log] [--file <fitxer>]"
+"no es pot usar --progress amb els formats --incremental o de porcellana"
 
-#: builtin/fmt-merge-msg.c:666
-msgid "populate log with at most <n> entries from shortlog"
-msgstr "emplena el registre amb <n> entrades del registre curt com a màxim"
+#. TRANSLATORS: This string is used to tell us the
+#. maximum display width for a relative timestamp in
+#. "git blame" output.  For C locale, "4 years, 11
+#. months ago", which takes 22 places, is the longest
+#. among various forms of relative timestamps, but
+#. your language may need more or fewer display
+#. columns.
+#.
+#: builtin/blame.c:972
+msgid "4 years, 11 months ago"
+msgstr "fa 4 anys i 11 mesos"
 
-#: builtin/fmt-merge-msg.c:669
-msgid "alias for --log (deprecated)"
-msgstr "àlies per --log (en desús)"
+#: builtin/blame.c:1079
+#, c-format
+msgid "file %s has only %lu line"
+msgid_plural "file %s has only %lu lines"
+msgstr[0] "el fitxer %s té només %lu línia"
+msgstr[1] "el fitxer %s té només %lu línies"
 
-#: builtin/fmt-merge-msg.c:672
-msgid "text"
-msgstr "text"
+#: builtin/blame.c:1125
+msgid "Blaming lines"
+msgstr "S'està fent un «blame»"
 
-#: builtin/fmt-merge-msg.c:673
-msgid "use <text> as start of message"
-msgstr "usa <text> com a inici de missatge"
+#: builtin/branch.c:29
+msgid "git branch [<options>] [-r | -a] [--merged | --no-merged]"
+msgstr "git branch [<opcions>] [-r | -a] [--merged | --no-merged]"
 
-#: builtin/fmt-merge-msg.c:674
-msgid "file to read from"
-msgstr "fitxer del qual llegir"
+#: builtin/branch.c:30
+msgid "git branch [<options>] [-l] [-f] <branch-name> [<start-point>]"
+msgstr "git branch [<opcions>] [-l] [-f] <nom-de-branca> [<punt-inicial>]"
 
-#: builtin/for-each-ref.c:10
-msgid "git for-each-ref [<options>] [<pattern>]"
-msgstr "git for-each-ref [<opcions>] [<patró>]"
+#: builtin/branch.c:31
+msgid "git branch [<options>] [-r] (-d | -D) <branch-name>..."
+msgstr "git branch [<opcions>] [-r] (-d | -D) <nom-de-branca>..."
 
-#: builtin/for-each-ref.c:11
-msgid "git for-each-ref [--points-at <object>]"
-msgstr "git for-each-ref [--points-at <objecte>]"
+#: builtin/branch.c:32
+msgid "git branch [<options>] (-m | -M) [<old-branch>] <new-branch>"
+msgstr "git branch [<opcions>] (-m | -M) [<branca-antiga>] <branca-nova>"
 
-#: builtin/for-each-ref.c:12
-msgid "git for-each-ref [(--merged | --no-merged) [<commit>]]"
-msgstr "git for-each-ref [(--merged | --no-merged) [<comissió>]]"
+#: builtin/branch.c:33
+msgid "git branch [<options>] (-c | -C) [<old-branch>] <new-branch>"
+msgstr "git branch [<opcions>] (-c | -C) [<branca-antiga>] <branca-nova>"
 
-#: builtin/for-each-ref.c:13
-msgid "git for-each-ref [--contains [<commit>]] [--no-contains [<commit>]]"
+#: builtin/branch.c:34
+msgid "git branch [<options>] [-r | -a] [--points-at]"
+msgstr "git branch [<opcions>] [-r | -a] [--points-at]"
+
+#: builtin/branch.c:35
+msgid "git branch [<options>] [-r | -a] [--format]"
+msgstr "git branch [<opcions>] [-r | -a] [--format]"
+
+#: builtin/branch.c:154
+#, c-format
+msgid ""
+"deleting branch '%s' that has been merged to\n"
+"         '%s', but not yet merged to HEAD."
 msgstr ""
-"git for-each-ref [--contains [<comissió>]] [--no-contains [<comissió>]]"
+"s'està suprimint la branca «%s» que s'ha\n"
+"         fusionat a «%s», però encara no\n"
+"         s'ha fusionat a HEAD."
 
-#: builtin/for-each-ref.c:28
-msgid "quote placeholders suitably for shells"
+#: builtin/branch.c:158
+#, c-format
+msgid ""
+"not deleting branch '%s' that is not yet merged to\n"
+"         '%s', even though it is merged to HEAD."
 msgstr ""
-"posa els marcadors de posició de forma adequada per a intèrprets d'ordres"
+"no s'està suprimint la branca «%s» que encara no\n"
+"         s'ha fusionat a «%s», encara que està\n"
+"         fusionada a HEAD."
 
-#: builtin/for-each-ref.c:30
-msgid "quote placeholders suitably for perl"
-msgstr "posa els marcadors de posició entre cometes adequades per al perl"
+#: builtin/branch.c:172
+#, c-format
+msgid "Couldn't look up commit object for '%s'"
+msgstr "No s'ha pogut trobar l'objecte de comissió de «%s»"
 
-#: builtin/for-each-ref.c:32
-msgid "quote placeholders suitably for python"
-msgstr "posa els marcadors de posició entre cometes adequades per al python"
+#: builtin/branch.c:176
+#, c-format
+msgid ""
+"The branch '%s' is not fully merged.\n"
+"If you are sure you want to delete it, run 'git branch -D %s'."
+msgstr ""
+"La branca «%s» no està totalment fusionada.\n"
+"Si esteu segur que la voleu suprimir, executeu 'git branch -D %s'."
 
-#: builtin/for-each-ref.c:34
-msgid "quote placeholders suitably for Tcl"
-msgstr "posa els marcadors de posició entre cometes adequades per al Tcl"
+#: builtin/branch.c:189
+msgid "Update of config-file failed"
+msgstr "L'actualització del fitxer de configuració ha fallat"
 
-#: builtin/for-each-ref.c:37
-msgid "show only <n> matched refs"
-msgstr "mostra només <n> referències coincidents"
+#: builtin/branch.c:220
+msgid "cannot use -a with -d"
+msgstr "no es pot usar -a amb -d"
 
-#: builtin/for-each-ref.c:39 builtin/tag.c:420
-msgid "respect format colors"
-msgstr "respecta els colors del format"
+#: builtin/branch.c:226
+msgid "Couldn't look up commit object for HEAD"
+msgstr "No s'ha pogut trobar l'objecte de comissió de HEAD"
 
-#: builtin/for-each-ref.c:43
-msgid "print only refs which points at the given object"
-msgstr "imprimeix només les referències que assenyalin l'objecte donat"
+#: builtin/branch.c:240
+#, c-format
+msgid "Cannot delete branch '%s' checked out at '%s'"
+msgstr "No es pot suprimir la branca «%s» agafada a «%s»"
 
-#: builtin/for-each-ref.c:45
-msgid "print only refs that are merged"
-msgstr "imprimeix només les referències que s'han fusionat"
+#: builtin/branch.c:255
+#, c-format
+msgid "remote-tracking branch '%s' not found."
+msgstr "no s'ha trobat la branca amb seguiment remot «%s»."
 
-#: builtin/for-each-ref.c:46
-msgid "print only refs that are not merged"
-msgstr "imprimeix només les referències que no s'han fusionat"
+#: builtin/branch.c:256
+#, c-format
+msgid "branch '%s' not found."
+msgstr "no s'ha trobat la branca «%s»."
 
-#: builtin/for-each-ref.c:47
-msgid "print only refs which contain the commit"
-msgstr "imprimeix només les referències que continguin la comissió"
+#: builtin/branch.c:271
+#, c-format
+msgid "Error deleting remote-tracking branch '%s'"
+msgstr "Error en suprimir la branca amb seguiment remot «%s»"
 
-#: builtin/for-each-ref.c:48
-msgid "print only refs which don't contain the commit"
-msgstr "imprimeix només les referències que no continguin la comissió"
+#: builtin/branch.c:272
+#, c-format
+msgid "Error deleting branch '%s'"
+msgstr "Error en suprimir la branca «%s»"
 
-#: builtin/fsck.c:568
-msgid "Checking object directories"
-msgstr "S'estan comprovant els directoris d'objecte"
+#: builtin/branch.c:279
+#, c-format
+msgid "Deleted remote-tracking branch %s (was %s).\n"
+msgstr "S'ha suprimit la branca amb seguiment remot %s (era %s).\n"
 
-#: builtin/fsck.c:660
-msgid "git fsck [<options>] [<object>...]"
-msgstr "git fsck [<opcions>] [<objecte>...]"
+#: builtin/branch.c:280
+#, c-format
+msgid "Deleted branch %s (was %s).\n"
+msgstr "S'ha suprimit la branca %s (era %s).\n"
 
-#: builtin/fsck.c:666
-msgid "show unreachable objects"
-msgstr "mostra els objectes inabastables"
+#: builtin/branch.c:429 builtin/tag.c:61
+msgid "unable to parse format string"
+msgstr "no s'ha pogut analitzar la cadena de format"
 
-#: builtin/fsck.c:667
-msgid "show dangling objects"
-msgstr "mostra els objectes penjants"
+#: builtin/branch.c:460
+#, fuzzy
+msgid "could not resolve HEAD"
+msgstr "no s'ha pogut resoldre la comissió HEAD"
 
-#: builtin/fsck.c:668
-msgid "report tags"
-msgstr "informa de les etiquetes"
-
-#: builtin/fsck.c:669
-msgid "report root nodes"
-msgstr "informa dels nodes d'arrel"
-
-#: builtin/fsck.c:670
-msgid "make index objects head nodes"
-msgstr "fes els objectes d'índex nodes de cap"
-
-#: builtin/fsck.c:671
-msgid "make reflogs head nodes (default)"
-msgstr "fes que els registres de referències siguin nodes de cap (per defecte)"
-
-#: builtin/fsck.c:672
-msgid "also consider packs and alternate objects"
-msgstr "també considera els paquets i els objectes alternatius"
-
-#: builtin/fsck.c:673
-msgid "check only connectivity"
-msgstr "comprova només la connectivitat"
-
-#: builtin/fsck.c:674
-msgid "enable more strict checking"
-msgstr "habilita la comprovació més estricta"
-
-#: builtin/fsck.c:676
-msgid "write dangling objects in .git/lost-found"
-msgstr "escriu objectes penjants a .git/lost-found"
-
-#: builtin/fsck.c:677 builtin/prune.c:108
-msgid "show progress"
-msgstr "mostra el progrés"
-
-#: builtin/fsck.c:678
-msgid "show verbose names for reachable objects"
-msgstr "mostra els noms detallats dels objectes abastables"
-
-#: builtin/fsck.c:742
-msgid "Checking objects"
-msgstr "S'estan comprovant els objectes"
-
-#: builtin/gc.c:27
-msgid "git gc [<options>]"
-msgstr "git gc [<opcions>]"
+#: builtin/branch.c:466
+#, fuzzy, c-format
+msgid "HEAD (%s) points outside of refs/heads/"
+msgstr "HEAD no trobat sota refs/heads!"
 
-#: builtin/gc.c:80
+#: builtin/branch.c:481
 #, c-format
-msgid "Failed to fstat %s: %s"
-msgstr "S'ha produït un error en fer fstat %s: %s"
+msgid "Branch %s is being rebased at %s"
+msgstr "S'està fent «rebase» en la branca %s a %s"
 
-#: builtin/gc.c:312
+#: builtin/branch.c:485
 #, c-format
-msgid "Can't stat %s"
-msgstr "No es pot fer stat en %s"
+msgid "Branch %s is being bisected at %s"
+msgstr "La branca %s s'està bisecant a %s"
 
-#: builtin/gc.c:321
-#, c-format
-msgid ""
-"The last gc run reported the following. Please correct the root cause\n"
-"and remove %s.\n"
-"Automatic cleanup will not be performed until the file is removed.\n"
-"\n"
-"%s"
-msgstr ""
-"L'última execució de gc ha informat el següent. Corregiu\n"
-"la causa primordial i elimineu %s.\n"
-"No es realitzarà la neteja automàtica fins que s'elimini el fitxer.\n"
-"\n"
-"%s"
+#: builtin/branch.c:502
+msgid "cannot copy the current branch while not on any."
+msgstr "no es pot copiar branca actual mentre no s'és a cap."
 
-#: builtin/gc.c:360
-msgid "prune unreferenced objects"
-msgstr "poda objectes sense referència"
+#: builtin/branch.c:504
+msgid "cannot rename the current branch while not on any."
+msgstr "no es pot canviar el nom de la branca actual mentre no s'és a cap."
 
-#: builtin/gc.c:362
-msgid "be more thorough (increased runtime)"
-msgstr "sigues més exhaustiu (el temps d'execució augmenta)"
+#: builtin/branch.c:515
+#, c-format
+msgid "Invalid branch name: '%s'"
+msgstr "Nom de branca no vàlid: «%s»"
 
-#: builtin/gc.c:363
-msgid "enable auto-gc mode"
-msgstr "habilita el mode de recollida d'escombraries automàtica"
+#: builtin/branch.c:542
+msgid "Branch rename failed"
+msgstr "El canvi de nom de branca ha fallat"
 
-#: builtin/gc.c:366
-msgid "force running gc even if there may be another gc running"
-msgstr "força l'execució de gc encara que hi pugui haver un altre gc executant"
+#: builtin/branch.c:544
+msgid "Branch copy failed"
+msgstr "La còpia de la branca ha fallat"
 
-#: builtin/gc.c:384
+#: builtin/branch.c:548
 #, c-format
-msgid "Failed to parse gc.logexpiry value %s"
-msgstr "No s'ha pogut analitzar el valor gc.logexpiry %s"
+msgid "Created a copy of a misnamed branch '%s'"
+msgstr "S'ha creat una còpia d'una branca mal anomenada «%s»"
 
-#: builtin/gc.c:412
+#: builtin/branch.c:551
 #, c-format
-msgid "Auto packing the repository in background for optimum performance.\n"
-msgstr ""
-"S'està empaquetant el dipòsit automàticament en el fons per rendiment "
-"òptim.\n"
+msgid "Renamed a misnamed branch '%s' away"
+msgstr "S'ha canviat el nom de la branca mal anomenada «%s»"
 
-#: builtin/gc.c:414
+#: builtin/branch.c:557
 #, c-format
-msgid "Auto packing the repository for optimum performance.\n"
-msgstr "S'està empaquetant automàticament el dipòsit per rendiment òptim.\n"
+msgid "Branch renamed to %s, but HEAD is not updated!"
+msgstr "S'ha canviat el nom de la branca a %s, però HEAD no està actualitzat!"
 
-#: builtin/gc.c:415
-#, c-format
-msgid "See \"git help gc\" for manual housekeeping.\n"
-msgstr "Vegeu \"git help gc\" per neteja manual.\n"
+#: builtin/branch.c:566
+msgid "Branch is renamed, but update of config-file failed"
+msgstr ""
+"La branca està canviada de nom, però l'actualització del fitxer de "
+"configuració ha fallat"
 
-#: builtin/gc.c:440
-#, c-format
-msgid ""
-"gc is already running on machine '%s' pid %<PRIuMAX> (use --force if not)"
+#: builtin/branch.c:568
+msgid "Branch is copied, but update of config-file failed"
 msgstr ""
-"gc ja s'està executant en la màquina «%s» pid %<PRIuMAX> (useu --force si no)"
+"La branca està copiada, però l'actualització del fitxer de configuració ha "
+"fallat"
 
-#: builtin/gc.c:487
+#: builtin/branch.c:584
+#, c-format
 msgid ""
-"There are too many unreachable loose objects; run 'git prune' to remove them."
+"Please edit the description for the branch\n"
+"  %s\n"
+"Lines starting with '%c' will be stripped.\n"
 msgstr ""
-"Hi ha massa objectes solts inabastables; executeu 'git prune' per a eliminar-"
-"los."
+"Editeu la descripció de la branca\n"
+"  %s\n"
+"S'eliminaran les línies que comencin amb «%c».\n"
 
-#: builtin/grep.c:27
-msgid "git grep [<options>] [-e] <pattern> [<rev>...] [[--] <path>...]"
-msgstr "git grep [<opcions>] [-e] <patró> [<revisió>...] [[--] <camí>...]"
+#: builtin/branch.c:618
+msgid "Generic options"
+msgstr "Opcions genèriques"
 
-#: builtin/grep.c:225
-#, c-format
-msgid "grep: failed to create thread: %s"
-msgstr "grep: s'ha produït un error en crear fil: %s"
+#: builtin/branch.c:620
+msgid "show hash and subject, give twice for upstream branch"
+msgstr "mostra el hash i l'assumpte, doneu dues vegades per la branca font"
 
-#: builtin/grep.c:283
-#, c-format
-msgid "invalid number of threads specified (%d) for %s"
-msgstr "s'ha especificat un nombre de fils no vàlid (%d) per a %s"
+#: builtin/branch.c:621
+msgid "suppress informational messages"
+msgstr "omet els missatges informatius"
 
-#. TRANSLATORS: %s is the configuration
-#. variable for tweaking threads, currently
-#. grep.threads
-#.
-#: builtin/grep.c:292 builtin/index-pack.c:1523 builtin/index-pack.c:1712
-#, c-format
-msgid "no threads support, ignoring %s"
-msgstr "no hi ha suport de fils, s'està ignorant %s"
+#: builtin/branch.c:622
+msgid "set up tracking mode (see git-pull(1))"
+msgstr "configura el mode de seguiment (vegeu git-pull(1))"
 
-#: builtin/grep.c:460 builtin/grep.c:580 builtin/grep.c:622
-#, c-format
-msgid "unable to read tree (%s)"
-msgstr "no s'ha pogut llegir l'arbre (%s)"
+#: builtin/branch.c:624
+msgid "do not use"
+msgstr "no usar"
 
-#: builtin/grep.c:637
-#, c-format
-msgid "unable to grep from object of type %s"
-msgstr "no es pot fer grep des d'un objecte de tipus %s"
+#: builtin/branch.c:626 builtin/rebase.c:505
+msgid "upstream"
+msgstr "font"
 
-#: builtin/grep.c:703
-#, c-format
-msgid "switch `%c' expects a numerical value"
-msgstr "l'opció «%c» espera un valor numèric"
+#: builtin/branch.c:626
+msgid "change the upstream info"
+msgstr "canvia la informació de font"
 
-#: builtin/grep.c:790
-msgid "search in index instead of in the work tree"
-msgstr "cerca en l'índex en lloc de l'arbre de treball"
+#: builtin/branch.c:627
+#, fuzzy
+msgid "unset the upstream info"
+msgstr "Desassigna la informació de font"
 
-#: builtin/grep.c:792
-msgid "find in contents not managed by git"
-msgstr "cerca en continguts no gestionats per git"
+#: builtin/branch.c:628
+msgid "use colored output"
+msgstr "usa sortida colorada"
 
-#: builtin/grep.c:794
-msgid "search in both tracked and untracked files"
-msgstr "cerca tant en fitxers seguits com en no seguits"
+#: builtin/branch.c:629
+msgid "act on remote-tracking branches"
+msgstr "actua en branques amb seguiment remot"
 
-#: builtin/grep.c:796
-msgid "ignore files specified via '.gitignore'"
-msgstr "ignora els fitxers especificats mitjançant '.gitignore'"
+#: builtin/branch.c:631 builtin/branch.c:633
+msgid "print only branches that contain the commit"
+msgstr "imprimeix només les branques que continguin la comissió"
 
-#: builtin/grep.c:798
-msgid "recursively search in each submodule"
-msgstr "cerca recursivament a cada submòdul"
+#: builtin/branch.c:632 builtin/branch.c:634
+msgid "print only branches that don't contain the commit"
+msgstr "imprimeix només les branques que no continguin la comissió"
 
-#: builtin/grep.c:801
-msgid "show non-matching lines"
-msgstr "mostra les línies no coincidents"
+#: builtin/branch.c:637
+msgid "Specific git-branch actions:"
+msgstr "Accions de git-branch específiques:"
 
-#: builtin/grep.c:803
-msgid "case insensitive matching"
-msgstr "coincidència insensible a majúscula i minúscula"
+#: builtin/branch.c:638
+msgid "list both remote-tracking and local branches"
+msgstr "llista les branques amb seguiment remot i les locals"
 
-#: builtin/grep.c:805
-msgid "match patterns only at word boundaries"
-msgstr "coincideix amb els patrons només als límits de paraula"
+#: builtin/branch.c:640
+msgid "delete fully merged branch"
+msgstr "suprimeix la branca si està completament fusionada"
 
-#: builtin/grep.c:807
-msgid "process binary files as text"
-msgstr "processa els fitxers binaris com a text"
+#: builtin/branch.c:641
+msgid "delete branch (even if not merged)"
+msgstr "suprimeix la branca (encara que no estigui fusionada)"
 
-#: builtin/grep.c:809
-msgid "don't match patterns in binary files"
-msgstr "no coincideixis amb els patrons en els fitxers binaris"
+#: builtin/branch.c:642
+msgid "move/rename a branch and its reflog"
+msgstr "mou/canvia de nom una branca i el seu registre de referència"
 
-#: builtin/grep.c:812
-msgid "process binary files with textconv filters"
-msgstr "processa els fitxers binaris amb filtres de textconv"
+#: builtin/branch.c:643
+msgid "move/rename a branch, even if target exists"
+msgstr "mou/canvia de nom una branca, encara que el destí existeixi"
 
-#: builtin/grep.c:814
-msgid "descend at most <depth> levels"
-msgstr "descendeix com a màxim <profunditat> nivells"
+#: builtin/branch.c:644
+msgid "copy a branch and its reflog"
+msgstr "copia una branca i el seu registre de referència"
 
-#: builtin/grep.c:818
-msgid "use extended POSIX regular expressions"
-msgstr "usa les expressions regulars POSIX ampliades"
+#: builtin/branch.c:645
+msgid "copy a branch, even if target exists"
+msgstr "copia una branca, encara que el destí existeixi"
 
-#: builtin/grep.c:821
-msgid "use basic POSIX regular expressions (default)"
-msgstr "usa les expressions regulars POSIX bàsiques (per defecte)"
+#: builtin/branch.c:646
+msgid "list branch names"
+msgstr "llista els noms de branca"
 
-#: builtin/grep.c:824
-msgid "interpret patterns as fixed strings"
-msgstr "interpreta els patrons com a cadenes fixes"
+#: builtin/branch.c:647
+#, fuzzy
+msgid "show current branch name"
+msgstr "No hi ha cap branca actual."
 
-#: builtin/grep.c:827
-msgid "use Perl-compatible regular expressions"
-msgstr "usa les expressions regulars compatibles amb Perl"
+#: builtin/branch.c:648
+msgid "create the branch's reflog"
+msgstr "crea el registre de referència de la branca"
 
-#: builtin/grep.c:830
-msgid "show line numbers"
-msgstr "mostra els números de línia"
+#: builtin/branch.c:650
+msgid "edit the description for the branch"
+msgstr "edita la descripció de la branca"
 
-#: builtin/grep.c:831
-msgid "don't show filenames"
-msgstr "no mostris els noms de fitxer"
+#: builtin/branch.c:651
+msgid "force creation, move/rename, deletion"
+msgstr "força creació, moviment/canvi de nom, supressió"
 
-#: builtin/grep.c:832
-msgid "show filenames"
-msgstr "mostra els noms de fitxer"
+#: builtin/branch.c:652
+msgid "print only branches that are merged"
+msgstr "imprimeix només les branques que s'han fusionat"
 
-#: builtin/grep.c:834
-msgid "show filenames relative to top directory"
-msgstr "mostra els noms de fitxer relatius al directori superior"
+#: builtin/branch.c:653
+msgid "print only branches that are not merged"
+msgstr "imprimeix només les branques que no s'han fusionat"
 
-#: builtin/grep.c:836
-msgid "show only filenames instead of matching lines"
-msgstr "mostra només els noms de fitxer en lloc de les línies coincidents"
+#: builtin/branch.c:654
+msgid "list branches in columns"
+msgstr "llista les branques en columnes"
 
-#: builtin/grep.c:838
-msgid "synonym for --files-with-matches"
-msgstr "sinònim de --files-with-matches"
+#: builtin/branch.c:657 builtin/for-each-ref.c:42 builtin/notes.c:415
+#: builtin/notes.c:418 builtin/notes.c:581 builtin/notes.c:584
+#: builtin/tag.c:433
+msgid "object"
+msgstr "objecte"
 
-#: builtin/grep.c:841
-msgid "show only the names of files without match"
-msgstr "mostra només els noms dels fitxers sense coincidència"
+#: builtin/branch.c:658
+msgid "print only branches of the object"
+msgstr "imprimeix només les branques de l'objecte"
 
-#: builtin/grep.c:843
-msgid "print NUL after filenames"
-msgstr "imprimeix NUL després dels noms de fitxer"
+#: builtin/branch.c:660 builtin/for-each-ref.c:48 builtin/tag.c:440
+msgid "sorting and filtering are case insensitive"
+msgstr "l'ordenació i el filtratge distingeixen entre majúscules i minúscules"
 
-#: builtin/grep.c:846
-msgid "show the number of matches instead of matching lines"
-msgstr "mostra el nombre de coincidències en lloc de les línies coincidents"
+#: builtin/branch.c:661 builtin/for-each-ref.c:38 builtin/tag.c:438
+#: builtin/verify-tag.c:38
+msgid "format to use for the output"
+msgstr "format a usar en la sortida"
 
-#: builtin/grep.c:847
-msgid "highlight matches"
-msgstr "ressalta les coincidències"
-
-#: builtin/grep.c:849
-msgid "print empty line between matches from different files"
-msgstr "imprimeix una línia buida entre coincidències de fitxers distints"
-
-#: builtin/grep.c:851
-msgid "show filename only once above matches from same file"
-msgstr ""
-"mostra el nom de fitxer només una vegada a dalt de les coincidències del "
-"mateix fitxer"
-
-#: builtin/grep.c:854
-msgid "show <n> context lines before and after matches"
-msgstr "mostra <n> línies de context abans i després d'una coincidència"
-
-#: builtin/grep.c:857
-msgid "show <n> context lines before matches"
-msgstr "mostra <n> línies de context abans d'una coincidència"
+#: builtin/branch.c:684 builtin/clone.c:784
+msgid "HEAD not found below refs/heads!"
+msgstr "HEAD no trobat sota refs/heads!"
 
-#: builtin/grep.c:859
-msgid "show <n> context lines after matches"
-msgstr "mostra <n> línies de context després d'una coincidència"
+#: builtin/branch.c:708
+msgid "--column and --verbose are incompatible"
+msgstr "--column i --verbose són incompatibles"
 
-#: builtin/grep.c:861
-msgid "use <n> worker threads"
-msgstr "usa <n> fils de treball"
+#: builtin/branch.c:723 builtin/branch.c:777 builtin/branch.c:786
+msgid "branch name required"
+msgstr "cal el nom de branca"
 
-#: builtin/grep.c:862
-msgid "shortcut for -C NUM"
-msgstr "drecera per -C NUM"
+#: builtin/branch.c:753
+msgid "Cannot give description to detached HEAD"
+msgstr "No es pot donar descripció a un HEAD separat"
 
-#: builtin/grep.c:865
-msgid "show a line with the function name before matches"
-msgstr "mostra una línia amb el nom de funció abans de les coincidències"
+#: builtin/branch.c:758
+msgid "cannot edit description of more than one branch"
+msgstr "no es pot editar la descripció de més d'una branca"
 
-#: builtin/grep.c:867
-msgid "show the surrounding function"
-msgstr "mostra la funció circumdant"
+#: builtin/branch.c:765
+#, c-format
+msgid "No commit on branch '%s' yet."
+msgstr "Encara no hi ha cap comissió en la branca «%s»."
 
-#: builtin/grep.c:870
-msgid "read patterns from file"
-msgstr "llegeix els patrons des d'un fitxer"
+#: builtin/branch.c:768
+#, c-format
+msgid "No branch named '%s'."
+msgstr "No hi ha cap branca amb nom «%s»."
 
-#: builtin/grep.c:872
-msgid "match <pattern>"
-msgstr "coincideix amb <patró>"
+#: builtin/branch.c:783
+msgid "too many branches for a copy operation"
+msgstr "hi ha massa branques per a una operació de còpia"
 
-#: builtin/grep.c:874
-msgid "combine patterns specified with -e"
-msgstr "combina els patrons especificats amb -e"
+#: builtin/branch.c:792
+msgid "too many arguments for a rename operation"
+msgstr "hi ha massa arguments per a una operació remota"
 
-#: builtin/grep.c:886
-msgid "indicate hit with exit status without output"
-msgstr "indica coincidència amb estat de sortida sense sortida textual"
+#: builtin/branch.c:797
+msgid "too many arguments to set new upstream"
+msgstr "hi ha massa arguments per a establir una nova font"
 
-#: builtin/grep.c:888
-msgid "show only matches from files that match all patterns"
+#: builtin/branch.c:801
+#, c-format
+msgid ""
+"could not set upstream of HEAD to %s when it does not point to any branch."
 msgstr ""
-"mostra només les coincidències dels fitxers que coincideixin amb tots els "
-"patrons"
-
-#: builtin/grep.c:890
-msgid "show parse tree for grep expression"
-msgstr "mostra l'arbre d'anàlisi de l'expressió grep"
-
-#: builtin/grep.c:894
-msgid "pager"
-msgstr "paginador"
-
-#: builtin/grep.c:894
-msgid "show matching files in the pager"
-msgstr "mostra els fitxers coincidents en el paginador"
-
-#: builtin/grep.c:898
-msgid "allow calling of grep(1) (ignored by this build)"
-msgstr "permet la invocació de grep(1) (ignorat per aquesta compilació)"
-
-#: builtin/grep.c:962
-msgid "no pattern given."
-msgstr "cap patró donat."
-
-#: builtin/grep.c:994
-msgid "--no-index or --untracked cannot be used with revs"
-msgstr "--no-index o --untracked no es pot usar amb revisions"
+"no s'ha pogut establir la font de HEAD com a %s quan no assenyala cap branca."
 
-#: builtin/grep.c:1001
+#: builtin/branch.c:804 builtin/branch.c:827
 #, c-format
-msgid "unable to resolve revision: %s"
-msgstr "no s'ha pogut resoldre la revisió: %s"
+msgid "no such branch '%s'"
+msgstr "no existeix la branca «%s»"
 
-#: builtin/grep.c:1036 builtin/index-pack.c:1519
+#: builtin/branch.c:808
 #, c-format
-msgid "invalid number of threads specified (%d)"
-msgstr "s'ha especificat un nombre de fils no vàlid (%d)"
-
-#: builtin/grep.c:1041
-msgid "no threads support, ignoring --threads"
-msgstr "no hi ha suport de fils, s'està ignorant --threads"
-
-#: builtin/grep.c:1065
-msgid "--open-files-in-pager only works on the worktree"
-msgstr "--open-files-in-pager només funciona en l'arbre de treball"
-
-#: builtin/grep.c:1088
-msgid "option not supported with --recurse-submodules."
-msgstr "opció no admesa amb --recurse-submodules."
+msgid "branch '%s' does not exist"
+msgstr "la branca «%s» no existeix"
 
-#: builtin/grep.c:1094
-msgid "--cached or --untracked cannot be used with --no-index."
-msgstr "--cached o --untracked no es pot usar amb --no-index."
+#: builtin/branch.c:821
+msgid "too many arguments to unset upstream"
+msgstr "hi ha massa arguments per a desassignar la font"
 
-#: builtin/grep.c:1100
-msgid "--[no-]exclude-standard cannot be used for tracked contents."
-msgstr "--[no-]exclude-standard no es pot usar per als continguts seguits."
+#: builtin/branch.c:825
+msgid "could not unset upstream of HEAD when it does not point to any branch."
+msgstr ""
+"no s'ha pogut desassignar la font de HEAD perquè no assenyala cap branca."
 
-#: builtin/grep.c:1108
-msgid "both --cached and trees are given."
-msgstr "s'han donat ambdós --caches i arbres."
+#: builtin/branch.c:831
+#, c-format
+msgid "Branch '%s' has no upstream information"
+msgstr "La branca «%s» no té informació de font"
 
-#: builtin/hash-object.c:83
+#: builtin/branch.c:841
+#, fuzzy
 msgid ""
-"git hash-object [-t <type>] [-w] [--path=<file> | --no-filters] [--stdin] "
-"[--] <file>..."
+"The -a, and -r, options to 'git branch' do not take a branch name.\n"
+"Did you mean to use: -a|-r --list <pattern>?"
 msgstr ""
-"git hash-object [-t <tipus>] [-w] [--path=<fitxer> | --no-filters] [--stdin] "
-"[--] <fitxer>..."
-
-#: builtin/hash-object.c:84
-msgid "git hash-object  --stdin-paths"
-msgstr "git hash-object  --stdin-paths"
-
-#: builtin/hash-object.c:96
-msgid "type"
-msgstr "tipus"
-
-#: builtin/hash-object.c:96
-msgid "object type"
-msgstr "tipus d'objecte"
+"les opcions -a i -r a 'git branch' no tenen sentit amb un nom de branca"
 
-#: builtin/hash-object.c:97
-msgid "write the object into the object database"
-msgstr "escriu l'objecte a la base de dades d'objectes"
+#: builtin/branch.c:845
+msgid ""
+"the '--set-upstream' option is no longer supported. Please use '--track' or "
+"'--set-upstream-to' instead."
+msgstr ""
+"L'opció --set-upstream ja no està suportada. Useu en comptes --track o --set-"
+"upstream-to."
 
-#: builtin/hash-object.c:99
-msgid "read the object from stdin"
-msgstr "llegeix l'objecte des de stdin"
+#: builtin/bundle.c:15 builtin/bundle.c:23
+#, fuzzy
+msgid "git bundle create [<options>] <file> <git-rev-list args>"
+msgstr "git remote add [<opcions>] <nom> <url>"
 
-#: builtin/hash-object.c:101
-msgid "store file as is without filters"
-msgstr "emmagatzema el fitxer tal com és sense filtres"
+#: builtin/bundle.c:16 builtin/bundle.c:28
+#, fuzzy
+msgid "git bundle verify [<options>] <file>"
+msgstr "git rm [<opcions>] [--] <fitxer>..."
 
-#: builtin/hash-object.c:102
-msgid ""
-"just hash any random garbage to create corrupt objects for debugging Git"
+#: builtin/bundle.c:17 builtin/bundle.c:33
+msgid "git bundle list-heads <file> [<refname>...]"
 msgstr ""
-"només suma qualsevol brossa aleatòria per a crear objectes malmesos per a "
-"depurar al Git"
-
-#: builtin/hash-object.c:103
-msgid "process file as it were from this path"
-msgstr "processa el fitxer com si fos d'aquest camí"
 
-#: builtin/help.c:43
-msgid "print all available commands"
-msgstr "imprimeix totes les ordres disponibles"
+#: builtin/bundle.c:18 builtin/bundle.c:38
+msgid "git bundle unbundle <file> [<refname>...]"
+msgstr ""
 
-#: builtin/help.c:44
-msgid "exclude guides"
-msgstr "exclou guies"
+#: builtin/bundle.c:66 builtin/pack-objects.c:3228
+msgid "do not show progress meter"
+msgstr "no mostris l'indicador de progrés"
 
-#: builtin/help.c:45
-msgid "print list of useful guides"
-msgstr "imprimeix la llista de guies útils"
+#: builtin/bundle.c:68 builtin/pack-objects.c:3230
+msgid "show progress meter"
+msgstr "mostra l'indicador de progrés"
 
-#: builtin/help.c:46
-msgid "show man page"
-msgstr "mostra la pàgina de manual"
+#: builtin/bundle.c:70 builtin/pack-objects.c:3232
+msgid "show progress meter during object writing phase"
+msgstr "mostra l'indicador de progrés durant la fase d'escriptura d'objectes"
 
-#: builtin/help.c:47
-msgid "show manual in web browser"
-msgstr "mostra la pàgina de manual en el navegador web"
+#: builtin/bundle.c:73 builtin/pack-objects.c:3235
+msgid "similar to --all-progress when progress meter is shown"
+msgstr "similar a --all-progress quan l'indicador de progrés es mostra"
 
-#: builtin/help.c:49
-msgid "show info page"
-msgstr "mostra la pàgina d'informació"
+#: builtin/bundle.c:93
+msgid "Need a repository to create a bundle."
+msgstr "Cal un dipòsit per a fer un farcell."
 
-#: builtin/help.c:55
-msgid "git help [--all] [--guides] [--man | --web | --info] [<command>]"
-msgstr "git help [--all] [--guides] [--man | --web | --info] [<ordre>]"
+#: builtin/bundle.c:104
+#, fuzzy
+msgid "do not show bundle details"
+msgstr "no mostris les etiquetes pelades"
 
-#: builtin/help.c:67
+#: builtin/bundle.c:119
 #, c-format
-msgid "unrecognized help format '%s'"
-msgstr "format d'ajuda no reconegut «%s»"
-
-#: builtin/help.c:94
-msgid "Failed to start emacsclient."
-msgstr "S'ha produït un error'ha produït un error en iniciar emacsclient."
+msgid "%s is okay\n"
+msgstr "%s està bé\n"
 
-#: builtin/help.c:107
-msgid "Failed to parse emacsclient version."
-msgstr "S'ha produït un error en analitzar la versió d'emacsclient."
+#: builtin/bundle.c:160
+msgid "Need a repository to unbundle."
+msgstr "Cal un dipòsit per a desfer un farcell."
 
-#: builtin/help.c:115
-#, c-format
-msgid "emacsclient version '%d' too old (< 22)."
-msgstr "la versió d'emacsclient «%d» és massa vella (< 22)."
+#: builtin/bundle.c:168 builtin/remote.c:1609
+msgid "be verbose; must be placed before a subcommand"
+msgstr "sigues detallat; s'ha de col·locar abans d'un subordre"
 
-#: builtin/help.c:133 builtin/help.c:155 builtin/help.c:165 builtin/help.c:173
+#: builtin/bundle.c:190 builtin/remote.c:1640
 #, c-format
-msgid "failed to exec '%s'"
-msgstr "s'ha produït un error en executar «%s»"
+msgid "Unknown subcommand: %s"
+msgstr "Subordre desconeguda: %s"
 
-#: builtin/help.c:211
-#, c-format
+#: builtin/cat-file.c:595
 msgid ""
-"'%s': path for unsupported man viewer.\n"
-"Please consider using 'man.<tool>.cmd' instead."
+"git cat-file (-t [--allow-unknown-type] | -s [--allow-unknown-type] | -e | -"
+"p | <type> | --textconv | --filters) [--path=<path>] <object>"
 msgstr ""
-"«%s»: camí a un visualitzador de manuals no compatible.\n"
-"Considereu usar 'man.<eina>.cmd' en lloc d'això."
+"git cat-file (-t [--allow-unknown-type] | -s [--allow-unknown-type] | -e | -"
+"p | <tipus> | --textconv | --filters [--path=<camí>]) <objecte>"
 
-#: builtin/help.c:223
-#, c-format
+#: builtin/cat-file.c:596
 msgid ""
-"'%s': cmd for supported man viewer.\n"
-"Please consider using 'man.<tool>.path' instead."
+"git cat-file (--batch | --batch-check) [--follow-symlinks] [--textconv | --"
+"filters]"
 msgstr ""
-"«%s»: ordre per a un visualitzador de manuals compatible.\n"
-"Considereu usar 'man.<eina>.path' en lloc d'això."
+"git cat-file (--batch | --batch-check) [--follow-symlinks] [--textconv | --"
+"filters]"
 
-#: builtin/help.c:340
-#, c-format
-msgid "'%s': unknown man viewer."
-msgstr "«%s»: visualitzador de manuals desconegut."
+#: builtin/cat-file.c:617
+#, fuzzy
+msgid "only one batch option may be specified"
+msgstr "Cap nom de branca especificat"
 
-#: builtin/help.c:357
-msgid "no man viewer handled the request"
-msgstr "cap visualitzador de manuals ha gestionat la sol·licitud"
+#: builtin/cat-file.c:635
+msgid "<type> can be one of: blob, tree, commit, tag"
+msgstr "<tipus> pot ser un de: blob, tree, commit, tag"
 
-#: builtin/help.c:365
-msgid "no info viewer handled the request"
-msgstr "cap visualitzador d'informació ha gestionat la sol·licitud"
+#: builtin/cat-file.c:636
+msgid "show object type"
+msgstr "mostra el tipus de l'objecte"
 
-#: builtin/help.c:407
-msgid "Defining attributes per path"
-msgstr "La definició d'atributs per camí"
+#: builtin/cat-file.c:637
+msgid "show object size"
+msgstr "mostra la mida de l'objecte"
 
-#: builtin/help.c:408
-msgid "Everyday Git With 20 Commands Or So"
-msgstr "Git quotidià amb més o menys 20 ordres"
+#: builtin/cat-file.c:639
+msgid "exit with zero when there's no error"
+msgstr "surt amb zero quan no hi ha error"
 
-#: builtin/help.c:409
-msgid "A Git glossary"
-msgstr "Un glossari de Git"
+#: builtin/cat-file.c:640
+msgid "pretty-print object's content"
+msgstr "imprimeix bellament el contingut de l'objecte"
 
-#: builtin/help.c:410
-msgid "Specifies intentionally untracked files to ignore"
-msgstr "Especifica els fitxers intencionalment no seguits a ignorar"
+#: builtin/cat-file.c:642
+msgid "for blob objects, run textconv on object's content"
+msgstr "en els objectes de blob, executa textconv en el contingut de l'objecte"
 
-#: builtin/help.c:411
-msgid "Defining submodule properties"
-msgstr "La definició de les propietats de submòduls"
+#: builtin/cat-file.c:644
+msgid "for blob objects, run filters on object's content"
+msgstr ""
+"en els objectes de blob, executa els filtres en el contingut de l'objecte"
 
-#: builtin/help.c:412
-msgid "Specifying revisions and ranges for Git"
-msgstr "L'especificació de revisions i rangs per al Git"
+#: builtin/cat-file.c:645 git-submodule.sh:992
+msgid "blob"
+msgstr "blob"
 
-#: builtin/help.c:413
-msgid "A tutorial introduction to Git (for version 1.5.1 or newer)"
-msgstr "Una introducció tutorial al Git (per a la versió 1.5.1 o més nova)"
+#: builtin/cat-file.c:646
+msgid "use a specific path for --textconv/--filters"
+msgstr "usa un camí específic per a --textconv/--filters"
 
-#: builtin/help.c:414
-msgid "An overview of recommended workflows with Git"
-msgstr "Una visió de conjunt de fluxos de treball recomanats amb Git"
-
-#: builtin/help.c:426
-msgid "The common Git guides are:\n"
-msgstr "Les guies de Git comunes són:\n"
-
-#: builtin/help.c:444
-#, c-format
-msgid "'%s' is aliased to '%s'"
-msgstr "«%s» és un àlies de «%s»"
-
-#: builtin/help.c:466 builtin/help.c:483
-#, c-format
-msgid "usage: %s%s"
-msgstr "ús: %s%s"
+#: builtin/cat-file.c:648
+msgid "allow -s and -t to work with broken/corrupt objects"
+msgstr "permet que -s i -t funcionin amb objectes trencats/malmesos"
 
-#: builtin/index-pack.c:157
-#, c-format
-msgid "unable to open %s"
-msgstr "no s'ha pogut obrir %s"
+#: builtin/cat-file.c:649
+msgid "buffer --batch output"
+msgstr "posa la sortida de --batch en memòria intermèdia"
 
-#: builtin/index-pack.c:207
-#, c-format
-msgid "object type mismatch at %s"
-msgstr "hi ha una discordança de tipus d'objecte a %s"
+#: builtin/cat-file.c:651
+msgid "show info and content of objects fed from the standard input"
+msgstr ""
+"mostra la informació i contingut dels objectes rebuts de l'entrada estàndard"
 
-#: builtin/index-pack.c:227
-#, c-format
-msgid "did not receive expected object %s"
-msgstr "no s'ha rebut l'objecte esperat %s"
+#: builtin/cat-file.c:655
+msgid "show info about objects fed from the standard input"
+msgstr "mostra informació sobre els objectes rebuts de l'entrada estàndard"
 
-#: builtin/index-pack.c:230
-#, c-format
-msgid "object %s: expected type %s, found %s"
-msgstr "objecte %s: s'esperava el tipus %s, s'ha trobat %s"
+#: builtin/cat-file.c:659
+msgid "follow in-tree symlinks (used with --batch or --batch-check)"
+msgstr ""
+"segueix els enllaços simbòlics en l'arbre (s'usa amb --batch o --batch-check)"
 
-#: builtin/index-pack.c:272
-#, c-format
-msgid "cannot fill %d byte"
-msgid_plural "cannot fill %d bytes"
-msgstr[0] "no es pot omplir %d octet"
-msgstr[1] "no es pot omplir %d octets"
+#: builtin/cat-file.c:661
+msgid "show all objects with --batch or --batch-check"
+msgstr "mostra tots els objectes amb --batch o --batch-check"
 
-#: builtin/index-pack.c:282
-msgid "early EOF"
-msgstr "EOF prematur"
+#: builtin/cat-file.c:663
+msgid "do not order --batch-all-objects output"
+msgstr ""
 
-#: builtin/index-pack.c:283
-msgid "read error on input"
-msgstr "error de lectura d'entrada"
+#: builtin/check-attr.c:13
+msgid "git check-attr [-a | --all | <attr>...] [--] <pathname>..."
+msgstr "git check-attr [-a | --all | <atribut>...] [--] <nom-de-camí>..."
 
-#: builtin/index-pack.c:295
-msgid "used more bytes than were available"
-msgstr "s'han usat més octets que hi havia disponibles"
+#: builtin/check-attr.c:14
+msgid "git check-attr --stdin [-z] [-a | --all | <attr>...]"
+msgstr "git check-attr --stdin [-z] [-a | --all | <atribut>...]"
 
-#: builtin/index-pack.c:302
-msgid "pack too large for current definition of off_t"
-msgstr "paquet massa gran per a la definició actual d'off_t"
+#: builtin/check-attr.c:21
+msgid "report all attributes set on file"
+msgstr "informa de tots els atributs establerts en el fitxer"
 
-#: builtin/index-pack.c:305 builtin/unpack-objects.c:93
-msgid "pack exceeds maximum allowed size"
-msgstr "el paquet supera la mida màxima permesa"
+#: builtin/check-attr.c:22
+msgid "use .gitattributes only from the index"
+msgstr "usa .gitattributes només des de l'índex"
 
-#: builtin/index-pack.c:320
-#, c-format
-msgid "unable to create '%s'"
-msgstr "no s'ha pogut crear «%s»"
+#: builtin/check-attr.c:23 builtin/check-ignore.c:25 builtin/hash-object.c:102
+msgid "read file names from stdin"
+msgstr "llegeix els noms de fitxer de stdin"
 
-#: builtin/index-pack.c:326
-#, c-format
-msgid "cannot open packfile '%s'"
-msgstr "no es pot obrir el fitxer de paquet «%s»"
+#: builtin/check-attr.c:25 builtin/check-ignore.c:27
+msgid "terminate input and output records by a NUL character"
+msgstr "acaba els registres d'entrada i de sortida amb un caràcter NUL"
 
-#: builtin/index-pack.c:340
-msgid "pack signature mismatch"
-msgstr "hi ha una discordança de signatura de paquet"
+#: builtin/check-ignore.c:21 builtin/checkout.c:1435 builtin/gc.c:537
+#: builtin/worktree.c:506
+msgid "suppress progress reporting"
+msgstr "omet els informes de progrés"
 
-#: builtin/index-pack.c:342
-#, c-format
-msgid "pack version %<PRIu32> unsupported"
-msgstr "la versió de paquet %<PRIu32> no és compatible"
+#: builtin/check-ignore.c:29
+msgid "show non-matching input paths"
+msgstr "mostra els camins d'entrada que no coincideixin"
 
-#: builtin/index-pack.c:360
-#, c-format
-msgid "pack has bad object at offset %<PRIuMAX>: %s"
-msgstr "el paquet té un objecte incorrecte a la posició %<PRIuMAX>: %s"
+#: builtin/check-ignore.c:31
+msgid "ignore index when checking"
+msgstr "ignora l'índex en comprovar"
 
-#: builtin/index-pack.c:481
-#, c-format
-msgid "inflate returned %d"
-msgstr "la inflació ha retornat %d"
+#: builtin/check-ignore.c:160
+msgid "cannot specify pathnames with --stdin"
+msgstr "no es poden especificar noms de camí amb --stdin"
 
-#: builtin/index-pack.c:530
-msgid "offset value overflow for delta base object"
-msgstr ""
-"desbordament de valor de desplaçament per a l'objecte base de diferències"
+#: builtin/check-ignore.c:163
+msgid "-z only makes sense with --stdin"
+msgstr "-z només té sentit amb --stdin"
 
-#: builtin/index-pack.c:538
-msgid "delta base offset is out of bound"
-msgstr "el desplaçament de base de diferències està fora de límits"
+#: builtin/check-ignore.c:165
+msgid "no path specified"
+msgstr "cap camí especificat"
 
-#: builtin/index-pack.c:546
-#, c-format
-msgid "unknown object type %d"
-msgstr "tipus d'objecte desconegut %d"
+#: builtin/check-ignore.c:169
+msgid "--quiet is only valid with a single pathname"
+msgstr "--quiet només és vàlid amb un sol nom de camí"
 
-#: builtin/index-pack.c:577
-msgid "cannot pread pack file"
-msgstr "no es pot fer pread en el fitxer de paquet"
+#: builtin/check-ignore.c:171
+msgid "cannot have both --quiet and --verbose"
+msgstr "no es poden especificar --quiet i --verbose alhora"
 
-#: builtin/index-pack.c:579
-#, c-format
-msgid "premature end of pack file, %<PRIuMAX> byte missing"
-msgid_plural "premature end of pack file, %<PRIuMAX> bytes missing"
-msgstr[0] "el final del fitxer de paquet és prematur, manca %<PRIuMAX> octet"
-msgstr[1] ""
-"el final del fitxer de paquet és prematur, manquen %<PRIuMAX> octets"
+#: builtin/check-ignore.c:174
+msgid "--non-matching is only valid with --verbose"
+msgstr "--non-matching és vàlid només amb --verbose"
 
-#: builtin/index-pack.c:605
-msgid "serious inflate inconsistency"
-msgstr "hi ha una inconsistència seriosa d'inflació"
+#: builtin/check-mailmap.c:9
+msgid "git check-mailmap [<options>] <contact>..."
+msgstr "git check-mailmap [<opcions>] <contacte>..."
 
-#: builtin/index-pack.c:750 builtin/index-pack.c:756 builtin/index-pack.c:779
-#: builtin/index-pack.c:818 builtin/index-pack.c:827
-#, c-format
-msgid "SHA1 COLLISION FOUND WITH %s !"
-msgstr "S'HA TROBAT UNA COL·LISIÓ SHA1 AMB %s !"
+#: builtin/check-mailmap.c:14
+msgid "also read contacts from stdin"
+msgstr "també llegeix els contactes des de stdin"
 
-#: builtin/index-pack.c:753 builtin/pack-objects.c:182
-#: builtin/pack-objects.c:276
+#: builtin/check-mailmap.c:25
 #, c-format
-msgid "unable to read %s"
-msgstr "no s'ha pogut llegir %s"
+msgid "unable to parse contact: %s"
+msgstr "no s'ha pogut analitzar el contacte: %s"
 
-#: builtin/index-pack.c:816
-#, c-format
-msgid "cannot read existing object info %s"
-msgstr "no es pot llegir la informació d'objecte existent %s"
+#: builtin/check-mailmap.c:48
+msgid "no contacts specified"
+msgstr "no hi ha contactes especificats"
 
-#: builtin/index-pack.c:824
-#, c-format
-msgid "cannot read existing object %s"
-msgstr "no es pot llegir l'objecte existent %s"
+#: builtin/checkout-index.c:131
+msgid "git checkout-index [<options>] [--] [<file>...]"
+msgstr "git checkout-index [<opcions>] [--] [<fitxer>...]"
 
-#: builtin/index-pack.c:838
-#, c-format
-msgid "invalid blob object %s"
-msgstr "objecte de blob no vàlid %s"
+#: builtin/checkout-index.c:148
+msgid "stage should be between 1 and 3 or all"
+msgstr "«stage» ha de ser entre 1 i 3 o all"
 
-#: builtin/index-pack.c:853
-#, c-format
-msgid "invalid %s"
-msgstr "%s no vàlid"
+#: builtin/checkout-index.c:164
+msgid "check out all files in the index"
+msgstr "agafa tots els fitxers en l'índex"
 
-#: builtin/index-pack.c:856
-msgid "Error in object"
-msgstr "Error en objecte"
+#: builtin/checkout-index.c:165
+msgid "force overwrite of existing files"
+msgstr "força la sobreescriptura de fitxers existents"
 
-#: builtin/index-pack.c:858
-#, c-format
-msgid "Not all child objects of %s are reachable"
-msgstr "No tots els objectes fills de %s són abastables"
+#: builtin/checkout-index.c:167
+msgid "no warning for existing files and files not in index"
+msgstr ""
+"cap advertència per a fitxers existents i fitxers que no siguin a l'índex"
 
-#: builtin/index-pack.c:930 builtin/index-pack.c:961
-msgid "failed to apply delta"
-msgstr "s'ha produït un error en aplicar la diferència"
+#: builtin/checkout-index.c:169
+msgid "don't checkout new files"
+msgstr "no agafis fitxers nous"
 
-#: builtin/index-pack.c:1131
-msgid "Receiving objects"
-msgstr "S'estan rebent objectes"
+#: builtin/checkout-index.c:171
+msgid "update stat information in the index file"
+msgstr "actualitza la informació d'estadístiques en el fitxer d'índex"
 
-#: builtin/index-pack.c:1131
-msgid "Indexing objects"
-msgstr "S'estan indexant objectes"
+#: builtin/checkout-index.c:175
+msgid "read list of paths from the standard input"
+msgstr "llegeix la llista de camins des de l'entrada estàndard"
 
-#: builtin/index-pack.c:1165
-msgid "pack is corrupted (SHA1 mismatch)"
-msgstr "el paquet és malmès (discordança SHA1)"
+#: builtin/checkout-index.c:177
+msgid "write the content to temporary files"
+msgstr "escriu el contingut a fitxers temporals"
 
-#: builtin/index-pack.c:1170
-msgid "cannot fstat packfile"
-msgstr "no es pot fer fstat en el fitxer de paquet"
+#: builtin/checkout-index.c:178 builtin/column.c:31
+#: builtin/submodule--helper.c:1385 builtin/submodule--helper.c:1388
+#: builtin/submodule--helper.c:1396 builtin/submodule--helper.c:1882
+#: builtin/worktree.c:679
+msgid "string"
+msgstr "cadena"
 
-#: builtin/index-pack.c:1173
-msgid "pack has junk at the end"
-msgstr "el paquet té brossa al seu final"
+#: builtin/checkout-index.c:179
+msgid "when creating files, prepend <string>"
+msgstr "en crear fitxers, anteposa <cadena>"
 
-#: builtin/index-pack.c:1185
-msgid "confusion beyond insanity in parse_pack_objects()"
-msgstr "confusió més enllà de la bogeria en parse_pack_objects()"
+#: builtin/checkout-index.c:181
+msgid "copy out the files from named stage"
+msgstr "copia els fitxers des de «stage» amb nom"
 
-#: builtin/index-pack.c:1208
-msgid "Resolving deltas"
-msgstr "S'estan resolent les diferències"
+#: builtin/checkout.c:31
+msgid "git checkout [<options>] <branch>"
+msgstr "git checkout [<opcions>] <branca>"
 
-#: builtin/index-pack.c:1219
-#, c-format
-msgid "unable to create thread: %s"
-msgstr "no s'ha pogut crear fil: %s"
+#: builtin/checkout.c:32
+msgid "git checkout [<options>] [<branch>] -- <file>..."
+msgstr "git checkout [<opcions>] [<branca>] -- <fitxer>..."
 
-#: builtin/index-pack.c:1261
-msgid "confusion beyond insanity"
-msgstr "confusió més enllà de la bogeria"
+#: builtin/checkout.c:37
+#, fuzzy
+msgid "git switch [<options>] [<branch>]"
+msgstr "git checkout [<opcions>] <branca>"
 
-#: builtin/index-pack.c:1267
-#, c-format
-msgid "completed with %d local object"
-msgid_plural "completed with %d local objects"
-msgstr[0] "s'ha completat amb %d objecte local"
-msgstr[1] "s'ha completat amb %d objectes locals"
+#: builtin/checkout.c:42
+#, fuzzy
+msgid "git restore [<options>] [--source=<branch>] <file>..."
+msgstr "git checkout [<opcions>] [<branca>] -- <fitxer>..."
 
-#: builtin/index-pack.c:1279
+#: builtin/checkout.c:175 builtin/checkout.c:214
 #, c-format
-msgid "Unexpected tail checksum for %s (disk corruption?)"
-msgstr "Suma de verificació final no esperada per a %s (corrupció de disc?)"
+msgid "path '%s' does not have our version"
+msgstr "el camí «%s» no té la nostra versió"
 
-#: builtin/index-pack.c:1283
+#: builtin/checkout.c:177 builtin/checkout.c:216
 #, c-format
-msgid "pack has %d unresolved delta"
-msgid_plural "pack has %d unresolved deltas"
-msgstr[0] "El paquet té %d diferència no resolta"
-msgstr[1] "El paquet té %d diferències no resoltes"
+msgid "path '%s' does not have their version"
+msgstr "el camí «%s» no té la seva versió"
 
-#: builtin/index-pack.c:1307
+#: builtin/checkout.c:193
 #, c-format
-msgid "unable to deflate appended object (%d)"
-msgstr "no s'ha pogut desinflar l'objecte annexat (%d)"
+msgid "path '%s' does not have all necessary versions"
+msgstr "el camí «%s» no té totes les versions necessàries"
 
-#: builtin/index-pack.c:1383
+#: builtin/checkout.c:243
 #, c-format
-msgid "local object %s is corrupt"
-msgstr "l'objecte local %s és malmès"
+msgid "path '%s' does not have necessary versions"
+msgstr "el camí «%s» no té les versions necessàries"
 
-#: builtin/index-pack.c:1397
+#: builtin/checkout.c:261
 #, c-format
-msgid "packfile name '%s' does not end with '.pack'"
-msgstr "el nom del fitxer de paquet «%s» no acaba amb '.pack'"
+msgid "path '%s': cannot merge"
+msgstr "camí «%s»: no es pot fusionar"
 
-#: builtin/index-pack.c:1422
+#: builtin/checkout.c:277
 #, c-format
-msgid "cannot write %s file '%s'"
-msgstr "no es pot escriure «%s» al fitxer «%s»"
+msgid "Unable to add merge result for '%s'"
+msgstr "No s'ha pogut afegir el resultat de fusió per a «%s»"
 
-#: builtin/index-pack.c:1430
+#: builtin/checkout.c:377
 #, fuzzy, c-format
-msgid "cannot close written %s file '%s'"
-msgstr "no es pot tancar el fitxer escrit a mantenir «%s»"
-
-#: builtin/index-pack.c:1454
-msgid "error while closing pack file"
-msgstr "error en tancar el fitxer de paquet"
+msgid "Recreated %d merge conflict"
+msgid_plural "Recreated %d merge conflicts"
+msgstr[0] "etiqueta de fusió incorrecta en la comissió «%s»"
+msgstr[1] "etiqueta de fusió incorrecta en la comissió «%s»"
 
-#: builtin/index-pack.c:1468
-msgid "cannot store pack file"
-msgstr "no es pot emmagatzemar el fitxer de paquet"
-
-#: builtin/index-pack.c:1476
-msgid "cannot store index file"
-msgstr "no es pot emmagatzemar el fitxer d'índex"
+#: builtin/checkout.c:382
+#, fuzzy, c-format
+msgid "Updated %d path from %s"
+msgid_plural "Updated %d paths from %s"
+msgstr[0] "actualitzat %d camí\n"
+msgstr[1] "actualitzats %d camins\n"
 
-#: builtin/index-pack.c:1513
+#: builtin/checkout.c:389
 #, c-format
-msgid "bad pack.indexversion=%<PRIu32>"
-msgstr "pack.indexversion=%<PRIu32> incorrecte"
+msgid "Updated %d path from the index"
+msgid_plural "Updated %d paths from the index"
+msgstr[0] "S'ha actualitzat un camí des de l'índex"
+msgstr[1] "S'ha actualitzat %d camins des de l'índex"
 
-#: builtin/index-pack.c:1581
+#: builtin/checkout.c:412 builtin/checkout.c:415 builtin/checkout.c:418
+#: builtin/checkout.c:422
 #, c-format
-msgid "Cannot open existing pack file '%s'"
-msgstr "No es pot obrir el fitxer de paquet existent «%s»"
+msgid "'%s' cannot be used with updating paths"
+msgstr "«%s» no es pot usar amb actualització de camins"
 
-#: builtin/index-pack.c:1583
+#: builtin/checkout.c:425 builtin/checkout.c:428
 #, c-format
-msgid "Cannot open existing pack idx file for '%s'"
-msgstr "No es pot obrir el fitxer d'índex de paquets existent de «%s»"
+msgid "'%s' cannot be used with %s"
+msgstr "«%s» no es pot usar amb %s"
 
-#: builtin/index-pack.c:1631
+#: builtin/checkout.c:432
 #, c-format
-msgid "non delta: %d object"
-msgid_plural "non delta: %d objects"
-msgstr[0] "sense diferències: %d objecte"
-msgstr[1] "sense diferències: %d objectes"
+msgid "Cannot update paths and switch to branch '%s' at the same time."
+msgstr ""
+"No es poden actualitzar els camins i canviar a la branca «%s» a la vegada."
 
-#: builtin/index-pack.c:1638
+#: builtin/checkout.c:436
 #, c-format
-msgid "chain length = %d: %lu object"
-msgid_plural "chain length = %d: %lu objects"
-msgstr[0] "longitud de cadena = %d: %lu objecte"
-msgstr[1] "longitud de cadena = %d: %lu objectes"
-
-#: builtin/index-pack.c:1675
-msgid "Cannot come back to cwd"
-msgstr "No es pot tornar al directori de treball actual"
+msgid "neither '%s' or '%s' is specified"
+msgstr ""
 
-#: builtin/index-pack.c:1724 builtin/index-pack.c:1727
-#: builtin/index-pack.c:1743 builtin/index-pack.c:1747
-#, c-format
-msgid "bad %s"
-msgstr "%s incorrecte"
+#: builtin/checkout.c:440
+#, fuzzy, c-format
+msgid "'%s' must be used when '%s' is not specified"
+msgstr "«%s» no es pot usar amb «%s»"
 
-#: builtin/index-pack.c:1763
-msgid "--fix-thin cannot be used without --stdin"
-msgstr "--fix-thin no es pot usar sense --stdin"
+#: builtin/checkout.c:445 builtin/checkout.c:450
+#, fuzzy, c-format
+msgid "'%s' or '%s' cannot be used with %s"
+msgstr "%s: %s no es pot usar amb %s"
 
-#: builtin/index-pack.c:1765
-msgid "--stdin requires a git repository"
-msgstr "--stdin requereix un dipòsit git"
+#: builtin/checkout.c:509 builtin/checkout.c:516
+#, c-format
+msgid "path '%s' is unmerged"
+msgstr "el camí «%s» està sense fusionar"
 
-#: builtin/index-pack.c:1771
-msgid "--verify with no packfile name given"
-msgstr "s'ha donat --verify sense nom de fitxer de paquet"
+#: builtin/checkout.c:682 builtin/sparse-checkout.c:82
+msgid "you need to resolve your current index first"
+msgstr "heu de primer resoldre el vostre índex actual"
 
-#: builtin/init-db.c:55
+#: builtin/checkout.c:732
 #, c-format
-msgid "cannot stat '%s'"
-msgstr "no es pot fer stat en «%s»"
+msgid ""
+"cannot continue with staged changes in the following files:\n"
+"%s"
+msgstr ""
 
-#: builtin/init-db.c:61
+#: builtin/checkout.c:835
 #, c-format
-msgid "cannot stat template '%s'"
-msgstr "no es pot fer stat en la plantilla «%s»"
+msgid "Can not do reflog for '%s': %s\n"
+msgstr "No es pot fer reflog per a «%s»: %s\n"
 
-#: builtin/init-db.c:66
-#, c-format
-msgid "cannot opendir '%s'"
-msgstr "no es pot fer opendir en el directori «%s»"
+#: builtin/checkout.c:877
+msgid "HEAD is now at"
+msgstr "HEAD ara és a"
 
-#: builtin/init-db.c:77
-#, c-format
-msgid "cannot readlink '%s'"
-msgstr "no es pot fer readlink en «%s»"
+#: builtin/checkout.c:881 builtin/clone.c:716
+msgid "unable to update HEAD"
+msgstr "no s'ha pogut actualitzar HEAD"
 
-#: builtin/init-db.c:79
+#: builtin/checkout.c:885
 #, c-format
-msgid "cannot symlink '%s' '%s'"
-msgstr "no es pot fer symlink en «%s» «%s»"
+msgid "Reset branch '%s'\n"
+msgstr "Restableix la branca «%s»\n"
 
-#: builtin/init-db.c:85
+#: builtin/checkout.c:888
 #, c-format
-msgid "cannot copy '%s' to '%s'"
-msgstr "no es pot copiar «%s» a «%s»"
+msgid "Already on '%s'\n"
+msgstr "Ja en «%s»\n"
 
-#: builtin/init-db.c:89
+#: builtin/checkout.c:892
 #, c-format
-msgid "ignoring template %s"
-msgstr "s'està ignorant la plantilla %s"
+msgid "Switched to and reset branch '%s'\n"
+msgstr "S'ha canviat i restablert a la branca «%s»\n"
 
-#: builtin/init-db.c:120
+#: builtin/checkout.c:894 builtin/checkout.c:1291
 #, c-format
-msgid "templates not found %s"
-msgstr "no s'han trobat les plantilles %s"
+msgid "Switched to a new branch '%s'\n"
+msgstr "S'ha canviat a la branca nova «%s»\n"
 
-#: builtin/init-db.c:135
+#: builtin/checkout.c:896
 #, c-format
-msgid "not copying templates from '%s': %s"
-msgstr "no s'estan copiant plantilles de «%s»: %s"
+msgid "Switched to branch '%s'\n"
+msgstr "S'ha canviat a la branca «%s»\n"
 
-#: builtin/init-db.c:328
+#: builtin/checkout.c:947
 #, c-format
-msgid "unable to handle file type %d"
-msgstr "no s'ha pogut gestionar el tipus de fitxer %d"
+msgid " ... and %d more.\n"
+msgstr " ... i %d més.\n"
 
-#: builtin/init-db.c:331
+#: builtin/checkout.c:953
 #, c-format
-msgid "unable to move %s to %s"
-msgstr "no s'ha pogut moure %s a %s"
+msgid ""
+"Warning: you are leaving %d commit behind, not connected to\n"
+"any of your branches:\n"
+"\n"
+"%s\n"
+msgid_plural ""
+"Warning: you are leaving %d commits behind, not connected to\n"
+"any of your branches:\n"
+"\n"
+"%s\n"
+msgstr[0] ""
+"Advertència: esteu deixant enrere %d comissió, no\n"
+"vinculada a cap de les vostres branques:\n"
+"\n"
+"%s\n"
+msgstr[1] ""
+"Advertència: esteu deixant enrere %d comissions, no\n"
+"vinculades a cap de les vostres branques:\n"
+"\n"
+"%s\n"
 
-#: builtin/init-db.c:348 builtin/init-db.c:351
+#: builtin/checkout.c:972
 #, c-format
-msgid "%s already exists"
-msgstr "%s ja existeix"
+msgid ""
+"If you want to keep it by creating a new branch, this may be a good time\n"
+"to do so with:\n"
+"\n"
+" git branch <new-branch-name> %s\n"
+"\n"
+msgid_plural ""
+"If you want to keep them by creating a new branch, this may be a good time\n"
+"to do so with:\n"
+"\n"
+" git branch <new-branch-name> %s\n"
+"\n"
+msgstr[0] ""
+"Si la voleu mantenir creant una branca nova, ara pot ser un bon moment\n"
+"per a fer-ho amb:\n"
+"\n"
+" git branch <nom-de-branca-nova> %s\n"
+"\n"
+msgstr[1] ""
+"Si les voleu mantenir creant una branca nova, ara pot ser un bon moment\n"
+"per a fer-ho amb:\n"
+"\n"
+" git branch <nom-de-branca-nova> %s\n"
+"\n"
+
+#: builtin/checkout.c:1007
+msgid "internal error in revision walk"
+msgstr "error intern en el passeig per revisions"
+
+#: builtin/checkout.c:1011
+msgid "Previous HEAD position was"
+msgstr "La posició de HEAD anterior era"
+
+#: builtin/checkout.c:1051 builtin/checkout.c:1286
+msgid "You are on a branch yet to be born"
+msgstr "Sou en una branca que encara ha de néixer"
 
-#: builtin/init-db.c:404
+#: builtin/checkout.c:1178
+#, fuzzy
+msgid "only one reference expected"
+msgstr "s'esperava només una referència, s'han donat %d."
+
+#: builtin/checkout.c:1195
 #, c-format
-msgid "Reinitialized existing shared Git repository in %s%s\n"
-msgstr "S'ha reinicialitzat el dipòsit compartit existent del Git en %s%s\n"
+msgid "only one reference expected, %d given."
+msgstr "s'esperava només una referència, s'han donat %d."
 
-#: builtin/init-db.c:405
+#: builtin/checkout.c:1232
 #, c-format
-msgid "Reinitialized existing Git repository in %s%s\n"
-msgstr "S'ha reinicialitzat el dipòsit existent del Git en %s%s\n"
+msgid ""
+"'%s' could be both a local file and a tracking branch.\n"
+"Please use -- (and optionally --no-guess) to disambiguate"
+msgstr ""
 
-#: builtin/init-db.c:409
+#: builtin/checkout.c:1245 builtin/worktree.c:290 builtin/worktree.c:455
 #, c-format
-msgid "Initialized empty shared Git repository in %s%s\n"
-msgstr "S'ha inicialitzat un dipòsit compartit buit del Git en %s%s\n"
+msgid "invalid reference: %s"
+msgstr "referència no vàlida: %s"
 
-#: builtin/init-db.c:410
+#: builtin/checkout.c:1258 builtin/checkout.c:1622
 #, c-format
-msgid "Initialized empty Git repository in %s%s\n"
-msgstr "S'ha inicialitzat un dipòsit buit del Git en %s%s\n"
+msgid "reference is not a tree: %s"
+msgstr "la referència no és un arbre: %s"
 
-#: builtin/init-db.c:458
-msgid ""
-"git init [-q | --quiet] [--bare] [--template=<template-directory>] [--"
-"shared[=<permissions>]] [<directory>]"
-msgstr ""
-"git init [-q | --quiet] [--bare] [--template=<directori-de-plantilla>] [--"
-"shared[=<permisos>]] [<directori>]"
+#: builtin/checkout.c:1305
+#, fuzzy, c-format
+msgid "a branch is expected, got tag '%s'"
+msgstr "no es pot llegir l'objecte %s «%s»"
 
-#: builtin/init-db.c:481
-msgid "permissions"
-msgstr "permisos"
+#: builtin/checkout.c:1307
+#, fuzzy, c-format
+msgid "a branch is expected, got remote branch '%s'"
+msgstr ""
+"La branca «%s» està configurada per a seguir la branca remota «%s» de «%s»."
 
-#: builtin/init-db.c:482
-msgid "specify that the git repository is to be shared amongst several users"
-msgstr "especifica que el dipòsit de git es compartirà entre diversos usuaris"
+#: builtin/checkout.c:1308 builtin/checkout.c:1316
+#, fuzzy, c-format
+msgid "a branch is expected, got '%s'"
+msgstr "s'esperava shallow/unshallow, s'ha rebut %s"
 
-#: builtin/init-db.c:516 builtin/init-db.c:521
-#, c-format
-msgid "cannot mkdir %s"
-msgstr "no es pot mkdir %s"
+#: builtin/checkout.c:1311
+#, fuzzy, c-format
+msgid "a branch is expected, got commit '%s'"
+msgstr "La vostra branca està al dia amb «%s».\n"
 
-#: builtin/init-db.c:525
-#, c-format
-msgid "cannot chdir to %s"
-msgstr "no es pot canviar de directori a %s"
+#: builtin/checkout.c:1327
+msgid ""
+"cannot switch branch while merging\n"
+"Consider \"git merge --quit\" or \"git worktree add\"."
+msgstr ""
 
-#: builtin/init-db.c:546
-#, c-format
+#: builtin/checkout.c:1331
 msgid ""
-"%s (or --work-tree=<directory>) not allowed without specifying %s (or --git-"
-"dir=<directory>)"
+"cannot switch branch in the middle of an am session\n"
+"Consider \"git am --quit\" or \"git worktree add\"."
 msgstr ""
-"no es permet %s (o --work-tree=<directori>) sense especificar %s (o --git-"
-"dir=<directori>)"
 
-#: builtin/init-db.c:574
-#, c-format
-msgid "Cannot access work tree '%s'"
-msgstr "No es pot accedir a l'arbre de treball «%s»"
+#: builtin/checkout.c:1335
+msgid ""
+"cannot switch branch while rebasing\n"
+"Consider \"git rebase --quit\" or \"git worktree add\"."
+msgstr ""
 
-#: builtin/interpret-trailers.c:15
+#: builtin/checkout.c:1339
 msgid ""
-"git interpret-trailers [--in-place] [--trim-empty] [(--trailer "
-"<token>[(=|:)<value>])...] [<file>...]"
+"cannot switch branch while cherry-picking\n"
+"Consider \"git cherry-pick --quit\" or \"git worktree add\"."
 msgstr ""
-"git interpret-trailers [--in-place] [--trim-empty] [(--trailer "
-"<testimoni>[(=|:)<valor>])...] [<fitxer>...]"
 
-#: builtin/interpret-trailers.c:92
-msgid "edit files in place"
-msgstr "edita els fitxers in situ"
+#: builtin/checkout.c:1343
+msgid ""
+"cannot switch branch while reverting\n"
+"Consider \"git revert --quit\" or \"git worktree add\"."
+msgstr ""
 
-#: builtin/interpret-trailers.c:93
-msgid "trim empty trailers"
-msgstr "escurça els remolcs buits"
+#: builtin/checkout.c:1347
+#, fuzzy
+msgid "you are switching branch while bisecting"
+msgstr "Actualment esteu bisecant."
 
-#: builtin/interpret-trailers.c:96
-msgid "where to place the new trailer"
-msgstr "on ubica"
+#: builtin/checkout.c:1354
+msgid "paths cannot be used with switching branches"
+msgstr "els camins no es poden usar amb canvi de branca"
 
-#: builtin/interpret-trailers.c:98
-msgid "action if trailer already exists"
-msgstr "acció si el «trailer» ja existeix"
+#: builtin/checkout.c:1357 builtin/checkout.c:1361 builtin/checkout.c:1365
+#, c-format
+msgid "'%s' cannot be used with switching branches"
+msgstr "«%s» no es pot usar amb canvi de branca"
 
-#: builtin/interpret-trailers.c:100
-msgid "action if trailer is missing"
-msgstr "acció si el «trailer» falta"
+#: builtin/checkout.c:1369 builtin/checkout.c:1372 builtin/checkout.c:1375
+#: builtin/checkout.c:1380 builtin/checkout.c:1385
+#, c-format
+msgid "'%s' cannot be used with '%s'"
+msgstr "«%s» no es pot usar amb «%s»"
 
-#: builtin/interpret-trailers.c:102
-msgid "output only the trailers"
-msgstr "mostra només els «trailer»"
+#: builtin/checkout.c:1382
+#, fuzzy, c-format
+msgid "'%s' cannot take <start-point>"
+msgstr "«%s» no es pot usar amb actualització de camins"
 
-#: builtin/interpret-trailers.c:103
-msgid "do not apply config rules"
-msgstr "no apliquis les regles de configuració"
+#: builtin/checkout.c:1390
+#, c-format
+msgid "Cannot switch branch to a non-commit '%s'"
+msgstr "No es pot canviar la branca a la no comissió «%s»"
 
-#: builtin/interpret-trailers.c:104
-msgid "join whitespace-continued values"
-msgstr "uneix els valors continus amb espais en blanc"
+#: builtin/checkout.c:1397
+#, fuzzy
+msgid "missing branch or commit argument"
+msgstr "Manca el nom de branca; proveu -b"
 
-#: builtin/interpret-trailers.c:105
-msgid "set parsing options"
-msgstr "estableix les opcions d'anàlisi"
+#: builtin/checkout.c:1439 builtin/clone.c:91 builtin/commit-graph.c:52
+#: builtin/commit-graph.c:113 builtin/fetch.c:167 builtin/merge.c:285
+#: builtin/multi-pack-index.c:27 builtin/pull.c:138 builtin/push.c:563
+#: builtin/send-pack.c:174
+msgid "force progress reporting"
+msgstr "força l'informe de progrés"
 
-#: builtin/interpret-trailers.c:107
-msgid "trailer"
-msgstr "remolc"
+#: builtin/checkout.c:1440
+msgid "perform a 3-way merge with the new branch"
+msgstr "realitza una fusió de 3 vies amb la branca nova"
 
-#: builtin/interpret-trailers.c:108
-msgid "trailer(s) to add"
-msgstr "remolcs a afegir"
+#: builtin/checkout.c:1441 builtin/log.c:1690 parse-options.h:322
+msgid "style"
+msgstr "estil"
 
-#: builtin/interpret-trailers.c:117
-msgid "--trailer with --only-input does not make sense"
-msgstr "--trailer amb --only-input no té sentit"
+#: builtin/checkout.c:1442
+msgid "conflict style (merge or diff3)"
+msgstr "estil de conflicte (fusió o diff3)"
 
-#: builtin/interpret-trailers.c:127
-msgid "no input file given for in-place editing"
-msgstr "no s'ha donat cap fitxer d'entrada per a edició in situ"
+#: builtin/checkout.c:1454 builtin/worktree.c:503
+msgid "detach HEAD at named commit"
+msgstr "separa HEAD a la comissió anomenada"
 
-#: builtin/log.c:48
-msgid "git log [<options>] [<revision-range>] [[--] <path>...]"
-msgstr "git log [<opcions>] [<rang-de-revisions>] [[--] <camí>...]"
+#: builtin/checkout.c:1455
+msgid "set upstream info for new branch"
+msgstr "estableix la informació de font de la branca nova"
 
-#: builtin/log.c:49
-msgid "git show [<options>] <object>..."
-msgstr "git show [<opcions>] <objecte>..."
-
-#: builtin/log.c:93
-#, c-format
-msgid "invalid --decorate option: %s"
-msgstr "opció --decorate no vàlida: %s"
+#: builtin/checkout.c:1457
+msgid "force checkout (throw away local modifications)"
+msgstr "agafa a la força (descarta qualsevol modificació local)"
 
-#: builtin/log.c:153
-msgid "suppress diff output"
-msgstr "omet la sortida de diferències"
+#: builtin/checkout.c:1459
+msgid "new-branch"
+msgstr "branca-nova"
 
-#: builtin/log.c:154
-msgid "show source"
-msgstr "mostra la font"
+#: builtin/checkout.c:1459
+msgid "new unparented branch"
+msgstr "branca òrfena nova"
 
-#: builtin/log.c:155
-msgid "Use mail map file"
-msgstr "Usa el fitxer de mapa de correu"
+#: builtin/checkout.c:1461 builtin/merge.c:288
+msgid "update ignored files (default)"
+msgstr "actualitza els fitxers ignorats (per defecte)"
 
-#: builtin/log.c:157
-msgid "only decorate refs that match <pattern>"
-msgstr "només decora les referències que coincideixin amb <patró>"
+#: builtin/checkout.c:1464
+msgid "do not check if another worktree is holding the given ref"
+msgstr "no comprovis si altre arbre de treball té la referència donada"
 
-#: builtin/log.c:159
-msgid "do not decorate refs that match <pattern>"
-msgstr "no decoris les referències que coincideixen amb <patró>"
+#: builtin/checkout.c:1477
+msgid "checkout our version for unmerged files"
+msgstr "agafa la versió nostra dels fitxers sense fusionar"
 
-#: builtin/log.c:160
-msgid "decorate options"
-msgstr "opcions de decoració"
+#: builtin/checkout.c:1480
+msgid "checkout their version for unmerged files"
+msgstr "agafa la versió seva dels fitxers sense fusionar"
 
-#: builtin/log.c:163
-msgid "Process line range n,m in file, counting from 1"
-msgstr "Processa el rang de línies n,m en el fitxer, comptant des d'1"
+#: builtin/checkout.c:1484
+msgid "do not limit pathspecs to sparse entries only"
+msgstr "no limitis les especificacions de camí només a entrades disperses"
 
-#: builtin/log.c:259
-#, c-format
-msgid "Final output: %d %s\n"
-msgstr "Sortida final: %d %s\n"
+#: builtin/checkout.c:1537
+msgid "-b, -B and --orphan are mutually exclusive"
+msgstr "-b, -B i --orphan són mútuament excloents"
 
-#: builtin/log.c:510
-#, c-format
-msgid "git show %s: bad file"
-msgstr "git show %s: fitxer incorrecte"
+#: builtin/checkout.c:1540
+#, fuzzy
+msgid "-p and --overlay are mutually exclusive"
+msgstr "-n i -k són mútuament excloents."
 
-#: builtin/log.c:525 builtin/log.c:619
-#, c-format
-msgid "Could not read object %s"
-msgstr "No es pot llegir l'objecte %s"
+#: builtin/checkout.c:1577
+msgid "--track needs a branch name"
+msgstr "--track necessita un nom de branca"
 
-#: builtin/log.c:643
-#, c-format
-msgid "Unknown type: %d"
-msgstr "Tipus desconegut: %d"
+#: builtin/checkout.c:1582
+#, fuzzy
+msgid "missing branch name; try -b"
+msgstr "Manca el nom de branca; proveu -b"
 
-#: builtin/log.c:764
-msgid "format.headers without value"
-msgstr "format.headers sense valor"
+#: builtin/checkout.c:1615
+#, fuzzy, c-format
+msgid "could not resolve %s"
+msgstr "no s'ha pogut resoldre «%s»"
 
-#: builtin/log.c:865
-msgid "name of output directory is too long"
-msgstr "el nom del directori de sortida és massa llarg"
+#: builtin/checkout.c:1631
+msgid "invalid path specification"
+msgstr "especificació de camí no vàlida"
 
-#: builtin/log.c:881
+#: builtin/checkout.c:1638
 #, c-format
-msgid "Cannot open patch file %s"
-msgstr "No es pot obrir el fitxer de pedaç %s"
-
-#: builtin/log.c:898
-msgid "Need exactly one range."
-msgstr "Cal exactament un rang."
+msgid "'%s' is not a commit and a branch '%s' cannot be created from it"
+msgstr ""
+"«%s» no és una comissió i la branca «%s» no es pot crear a partir d'aquesta "
+"comissió"
 
-#: builtin/log.c:908
-msgid "Not a range."
-msgstr "No és un rang."
+#: builtin/checkout.c:1642
+#, c-format
+msgid "git checkout: --detach does not take a path argument '%s'"
+msgstr "git checkout: --detach no accepta un paràmetre de camí «%s»"
 
-#: builtin/log.c:1014
-msgid "Cover letter needs email format"
-msgstr "La carta de presentació necessita el format de correu electrònic"
+#: builtin/checkout.c:1651
+#, fuzzy
+msgid "--pathspec-from-file is incompatible with --detach"
+msgstr "--first-parent és incompatible amb --bisect"
 
-#: builtin/log.c:1095
-#, c-format
-msgid "insane in-reply-to: %s"
-msgstr "in-reply-to boig: %s"
+#: builtin/checkout.c:1654 builtin/reset.c:324
+#, fuzzy
+msgid "--pathspec-from-file is incompatible with --patch"
+msgstr "--first-parent és incompatible amb --bisect"
 
-#: builtin/log.c:1122
-msgid "git format-patch [<options>] [<since> | <revision-range>]"
-msgstr "git format-patch [<opcions>] [<des-de> | <rang-de-revisions>]"
+#: builtin/checkout.c:1665
+msgid ""
+"git checkout: --ours/--theirs, --force and --merge are incompatible when\n"
+"checking out of the index."
+msgstr ""
+"git checkout: --ours/--theirs, --force i --merge són incompatibles en\n"
+"agafar de l'índex."
 
-#: builtin/log.c:1172
-msgid "Two output directories?"
-msgstr "Hi ha dos directoris de sortida?"
+#: builtin/checkout.c:1670
+#, fuzzy
+msgid "you must specify path(s) to restore"
+msgstr "Heu d'especificar un directori."
 
-#: builtin/log.c:1279 builtin/log.c:1932 builtin/log.c:1934 builtin/log.c:1946
+#: builtin/checkout.c:1689
 #, c-format
-msgid "Unknown commit %s"
-msgstr "Comissió desconeguda %s"
+msgid ""
+"'%s' matched more than one remote tracking branch.\n"
+"We found %d remotes with a reference that matched. So we fell back\n"
+"on trying to resolve the argument as a path, but failed there too!\n"
+"\n"
+"If you meant to check out a remote tracking branch on, e.g. 'origin',\n"
+"you can do so by fully qualifying the name with the --track option:\n"
+"\n"
+"    git checkout --track origin/<name>\n"
+"\n"
+"If you'd like to always have checkouts of an ambiguous <name> prefer\n"
+"one remote, e.g. the 'origin' remote, consider setting\n"
+"checkout.defaultRemote=origin in your config."
+msgstr ""
 
-#: builtin/log.c:1289 builtin/notes.c:887 builtin/tag.c:522
-#, c-format
-msgid "Failed to resolve '%s' as a valid ref."
-msgstr "S'ha produït un error en resoldre «%s» com a referència vàlida."
+#: builtin/checkout.c:1714 builtin/checkout.c:1716 builtin/checkout.c:1765
+#: builtin/checkout.c:1767 builtin/clone.c:121 builtin/remote.c:169
+#: builtin/remote.c:171 builtin/worktree.c:499 builtin/worktree.c:501
+msgid "branch"
+msgstr "branca"
 
-#: builtin/log.c:1294
-msgid "Could not find exact merge base."
-msgstr "No s'ha pogut trobar la base exacta de fusió."
+#: builtin/checkout.c:1715
+msgid "create and checkout a new branch"
+msgstr "crea i agafa una branca nova"
 
-#: builtin/log.c:1298
-msgid ""
-"Failed to get upstream, if you want to record base commit automatically,\n"
-"please use git branch --set-upstream-to to track a remote branch.\n"
-"Or you could specify base commit by --base=<base-commit-id> manually."
-msgstr ""
-"S'ha produït un error en obtenir la font. Si voleu registrar la comissió "
-"base\n"
-"automàticament, useu git branch --set-upstream-to per a\n"
-"seguir una branca remota. O podeu especificar la comissió base manualment\n"
-"amb --base=<id-de-comissió-base>."
+#: builtin/checkout.c:1717
+msgid "create/reset and checkout a branch"
+msgstr "crea/restableix i agafa una branca"
 
-#: builtin/log.c:1318
-msgid "Failed to find exact merge base"
-msgstr "S'ha produït un error en trobar la base exacta de fusió."
+#: builtin/checkout.c:1718
+msgid "create reflog for new branch"
+msgstr "crea un registre de referència per a la branca nova"
 
-#: builtin/log.c:1329
-msgid "base commit should be the ancestor of revision list"
-msgstr "la comissió base ha de ser l'avantpassat de la llista de revisions"
+#: builtin/checkout.c:1720
+#, fuzzy
+msgid "second guess 'git checkout <no-such-branch>' (default)"
+msgstr "dubta 'git checkout <cap-branca-així>'"
 
-#: builtin/log.c:1333
-msgid "base commit shouldn't be in revision list"
-msgstr "la comissió base no ha de ser en la llista de revisions"
+#: builtin/checkout.c:1721
+#, fuzzy
+msgid "use overlay mode (default)"
+msgstr "poda les referències soltes (per defecte)"
 
-#: builtin/log.c:1382
-msgid "cannot get patch id"
-msgstr "no es pot obtenir l'id del pedaç"
+#: builtin/checkout.c:1766
+#, fuzzy
+msgid "create and switch to a new branch"
+msgstr "crea i agafa una branca nova"
 
-#: builtin/log.c:1441
-msgid "use [PATCH n/m] even with a single patch"
-msgstr "usa [PATCH n/m] fins i tot amb un sol pedaç"
+#: builtin/checkout.c:1768
+#, fuzzy
+msgid "create/reset and switch to a branch"
+msgstr "crea/restableix i agafa una branca"
 
-#: builtin/log.c:1444
-msgid "use [PATCH] even with multiple patches"
-msgstr "usa [PATCH] fins i tot amb múltiples pedaços"
+#: builtin/checkout.c:1770
+#, fuzzy
+msgid "second guess 'git switch <no-such-branch>'"
+msgstr "dubta 'git checkout <cap-branca-així>'"
 
-#: builtin/log.c:1448
-msgid "print patches to standard out"
-msgstr "imprimeix els pedaços a la sortida estàndard"
+#: builtin/checkout.c:1772
+#, fuzzy
+msgid "throw away local modifications"
+msgstr "agafa a la força (descarta qualsevol modificació local)"
 
-#: builtin/log.c:1450
-msgid "generate a cover letter"
-msgstr "genera una carta de presentació"
+#: builtin/checkout.c:1804
+#, fuzzy
+msgid "which tree-ish to checkout from"
+msgstr "llegeix l'objecte des de stdin"
 
-#: builtin/log.c:1452
-msgid "use simple number sequence for output file names"
-msgstr "usa una seqüència de números per als noms dels fitxers de sortida"
+#: builtin/checkout.c:1806
+#, fuzzy
+msgid "restore the index"
+msgstr "S'ha produït un error en llegir l'índex"
 
-#: builtin/log.c:1453
-msgid "sfx"
-msgstr "sufix"
+#: builtin/checkout.c:1808
+#, fuzzy
+msgid "restore the working tree (default)"
+msgstr "Mostra l'estat de l'arbre de treball"
 
-#: builtin/log.c:1454
-msgid "use <sfx> instead of '.patch'"
-msgstr "usa <sufix> en lloc de '.patch'"
+#: builtin/checkout.c:1810
+#, fuzzy
+msgid "ignore unmerged entries"
+msgstr "s'està ignorant %s no fusionat\n"
 
-#: builtin/log.c:1456
-msgid "start numbering patches at <n> instead of 1"
-msgstr "comença numerant els pedaços a <n> en lloc d'1"
+#: builtin/checkout.c:1811
+msgid "use overlay mode"
+msgstr ""
 
-#: builtin/log.c:1458
-msgid "mark the series as Nth re-roll"
-msgstr "marca la sèrie com a l'enèsima llançada"
+#: builtin/clean.c:28
+msgid ""
+"git clean [-d] [-f] [-i] [-n] [-q] [-e <pattern>] [-x | -X] [--] <paths>..."
+msgstr ""
+"git clean [-d] [-f] [-i] [-n] [-q] [-e <patró>] [-x | -X] [--] <camins>..."
 
-#: builtin/log.c:1460
-msgid "Use [RFC PATCH] instead of [PATCH]"
-msgstr "Usa [RFC PATCH] en lloc de [PATCH]"
+#: builtin/clean.c:32
+#, c-format
+msgid "Removing %s\n"
+msgstr "S'està eliminant %s\n"
 
-#: builtin/log.c:1463
-msgid "Use [<prefix>] instead of [PATCH]"
-msgstr "Usa [<prefix>] en lloc de [PATCH]"
+#: builtin/clean.c:33
+#, c-format
+msgid "Would remove %s\n"
+msgstr "Eliminaria %s\n"
 
-#: builtin/log.c:1466
-msgid "store resulting files in <dir>"
-msgstr "emmagatzema els fitxers resultants a <directori>"
+#: builtin/clean.c:34
+#, c-format
+msgid "Skipping repository %s\n"
+msgstr "S'està ometent el dipòsit %s\n"
 
-#: builtin/log.c:1469
-msgid "don't strip/add [PATCH]"
-msgstr "no despullis/afegeixis [PATCH]"
+#: builtin/clean.c:35
+#, c-format
+msgid "Would skip repository %s\n"
+msgstr "Ometria el dipòsit %s\n"
 
-#: builtin/log.c:1472
-msgid "don't output binary diffs"
-msgstr "no emetis diferències binàries"
+#: builtin/clean.c:36
+#, c-format
+msgid "failed to remove %s"
+msgstr "s'ha produït un error en eliminar %s"
 
-#: builtin/log.c:1474
-msgid "output all-zero hash in From header"
-msgstr "emet un hash de tots zeros en la capçalera From"
+#: builtin/clean.c:37
+#, fuzzy, c-format
+msgid "could not lstat %s\n"
+msgstr "no s'ha pogut fer stat a %s"
 
-#: builtin/log.c:1476
-msgid "don't include a patch matching a commit upstream"
-msgstr "no incloguis pedaços que coincideixin amb comissions a la font"
+#: builtin/clean.c:301 git-add--interactive.perl:595
+#, c-format
+msgid ""
+"Prompt help:\n"
+"1          - select a numbered item\n"
+"foo        - select item based on unique prefix\n"
+"           - (empty) select nothing\n"
+msgstr ""
+"Ajuda:\n"
+"1          - selecciona un ítem numerat\n"
+"foo        - selecciona un ítem basat en un prefix únic\n"
+"           - (buit) no seleccionis res\n"
 
-#: builtin/log.c:1478
-msgid "show patch format instead of default (patch + stat)"
+#: builtin/clean.c:305 git-add--interactive.perl:604
+#, c-format
+msgid ""
+"Prompt help:\n"
+"1          - select a single item\n"
+"3-5        - select a range of items\n"
+"2-3,6-9    - select multiple ranges\n"
+"foo        - select item based on unique prefix\n"
+"-...       - unselect specified items\n"
+"*          - choose all items\n"
+"           - (empty) finish selecting\n"
 msgstr ""
-"mostra el format de pedaç en lloc del per defecte (pedaç + estadístiques)"
+"Ajuda:\n"
+"1          - selecciona un sol ítem\n"
+"3-5        - selecciona un rang d'ítems\n"
+"2-3,6-9    - selecciona múltiples rangs\n"
+"foo        - selecciona un ítem basat en un prefix únic\n"
+"-...       - desselecciona els ítems seleccionats\n"
+"*          - tria tots els ítems\n"
+"           - (buit) finalitza la selecció\n"
 
-#: builtin/log.c:1480
-msgid "Messaging"
-msgstr "Missatgeria"
+#: builtin/clean.c:521 git-add--interactive.perl:570
+#: git-add--interactive.perl:575
+#, c-format, perl-format
+msgid "Huh (%s)?\n"
+msgstr "Perdó (%s)?\n"
 
-#: builtin/log.c:1481
-msgid "header"
-msgstr "capçalera"
+#: builtin/clean.c:663
+#, c-format
+msgid "Input ignore patterns>> "
+msgstr "Introduïu els patrons a ignorar>> "
 
-#: builtin/log.c:1482
-msgid "add email header"
-msgstr "afegeix una capçalera de correu electrònic"
+#: builtin/clean.c:700
+#, c-format
+msgid "WARNING: Cannot find items matched by: %s"
+msgstr "ADVERTÈNCIA: No es poden trobar ítems que coincideixin amb: %s"
 
-#: builtin/log.c:1483 builtin/log.c:1485
-msgid "email"
-msgstr "correu electrònic"
+#: builtin/clean.c:721
+msgid "Select items to delete"
+msgstr "Selecciona els ítems a suprimir"
 
-#: builtin/log.c:1483
-msgid "add To: header"
-msgstr "afegeix la capçalera To:"
-
-#: builtin/log.c:1485
-msgid "add Cc: header"
-msgstr "afegeix la capçalera Cc:"
-
-#: builtin/log.c:1487
-msgid "ident"
-msgstr "identitat"
+#. TRANSLATORS: Make sure to keep [y/N] as is
+#: builtin/clean.c:762
+#, c-format
+msgid "Remove %s [y/N]? "
+msgstr "Voleu eliminar %s [y/N]? "
 
-#: builtin/log.c:1488
-msgid "set From address to <ident> (or committer ident if absent)"
+#: builtin/clean.c:795
+msgid ""
+"clean               - start cleaning\n"
+"filter by pattern   - exclude items from deletion\n"
+"select by numbers   - select items to be deleted by numbers\n"
+"ask each            - confirm each deletion (like \"rm -i\")\n"
+"quit                - stop cleaning\n"
+"help                - this screen\n"
+"?                   - help for prompt selection"
 msgstr ""
-"estableix l'adreça From a <identitat> (o la identitat del comitent si manca)"
-
-#: builtin/log.c:1490
-msgid "message-id"
-msgstr "ID de missatge"
+"clean               - comença a netejar\n"
+"filter by pattern   - exclou ítems de supressió\n"
+"select by numbers   - selecciona ítems a suprimir per números\n"
+"ask each            - confirma cada supressió (com \"rm -i\")\n"
+"quit                - deixa de netejar\n"
+"help                - aquesta pantalla\n"
+"?                   - ajuda de selecció de l'avís"
 
-#: builtin/log.c:1491
-msgid "make first mail a reply to <message-id>"
-msgstr "fes que el primer missatge sigui una resposta a <ID de missatge>"
+#: builtin/clean.c:831
+msgid "Would remove the following item:"
+msgid_plural "Would remove the following items:"
+msgstr[0] "Eliminaria l'ítem següent:"
+msgstr[1] "Eliminaria els ítems següents:"
 
-#: builtin/log.c:1492 builtin/log.c:1495
-msgid "boundary"
-msgstr "límit"
+#: builtin/clean.c:847
+msgid "No more files to clean, exiting."
+msgstr "No hi ha més fitxers a netejar; s'està sortint."
 
-#: builtin/log.c:1493
-msgid "attach the patch"
-msgstr "adjunta el pedaç"
+#: builtin/clean.c:909
+msgid "do not print names of files removed"
+msgstr "no imprimeixis els noms dels fitxers eliminats"
 
-#: builtin/log.c:1496
-msgid "inline the patch"
-msgstr "posa el pedaç en el cos"
+#: builtin/clean.c:911
+msgid "force"
+msgstr "força"
 
-#: builtin/log.c:1500
-msgid "enable message threading, styles: shallow, deep"
-msgstr "habilita l'enfilada de missatges, estils: shallow, deep"
+#: builtin/clean.c:912
+msgid "interactive cleaning"
+msgstr "neteja interactiva"
 
-#: builtin/log.c:1502
-msgid "signature"
-msgstr "signatura"
+#: builtin/clean.c:914
+msgid "remove whole directories"
+msgstr "elimina directoris sencers"
 
-#: builtin/log.c:1503
-msgid "add a signature"
-msgstr "afegeix una signatura"
+#: builtin/clean.c:915 builtin/describe.c:548 builtin/describe.c:550
+#: builtin/grep.c:901 builtin/log.c:177 builtin/log.c:179
+#: builtin/ls-files.c:557 builtin/name-rev.c:464 builtin/name-rev.c:466
+#: builtin/show-ref.c:179
+msgid "pattern"
+msgstr "patró"
 
-#: builtin/log.c:1504
-msgid "base-commit"
-msgstr "comissió base"
+#: builtin/clean.c:916
+msgid "add <pattern> to ignore rules"
+msgstr "afegiu <patró> per a ignorar les regles"
 
-#: builtin/log.c:1505
-msgid "add prerequisite tree info to the patch series"
-msgstr "afegeix la informació d'arbre prerequerida a la sèrie de pedaços"
+#: builtin/clean.c:917
+msgid "remove ignored files, too"
+msgstr "elimina els fitxers ignorats, també"
 
-#: builtin/log.c:1507
-msgid "add a signature from a file"
-msgstr "afegeix una signatura des d'un fitxer"
+#: builtin/clean.c:919
+msgid "remove only ignored files"
+msgstr "elimina només els fitxers ignorats"
 
-#: builtin/log.c:1508
-msgid "don't print the patch filenames"
-msgstr "no imprimeixis els noms de fitxer del pedaç"
+#: builtin/clean.c:937
+msgid "-x and -X cannot be used together"
+msgstr "-x i -X no es poden usar junts"
 
-#: builtin/log.c:1510
-msgid "show progress while generating patches"
-msgstr "mostra el progrés durant la generació de pedaços"
+#: builtin/clean.c:941
+msgid ""
+"clean.requireForce set to true and neither -i, -n, nor -f given; refusing to "
+"clean"
+msgstr ""
+"clean.requireForce està establerta en cert i ni -i, -n ni -f s'han indicat; "
+"refusant netejar"
 
-#: builtin/log.c:1585
-#, c-format
-msgid "invalid ident line: %s"
-msgstr "línia d'identitat no vàlida: %s"
+#: builtin/clean.c:944
+msgid ""
+"clean.requireForce defaults to true and neither -i, -n, nor -f given; "
+"refusing to clean"
+msgstr ""
+"clean.requireForce és per defecte cert i ni -i, -n ni -f s'han indicat; "
+"refusant netejar"
 
-#: builtin/log.c:1600
-msgid "-n and -k are mutually exclusive."
-msgstr "-n i -k són mútuament excloents."
+#: builtin/clone.c:45
+msgid "git clone [<options>] [--] <repo> [<dir>]"
+msgstr "git clone [<opcions>] [--] <dipòsit> [<directori>]"
 
-#: builtin/log.c:1602
-msgid "--subject-prefix/--rfc and -k are mutually exclusive."
-msgstr "--subject-prefix/--rfc i -k són mútuament excloents."
+#: builtin/clone.c:93
+msgid "don't create a checkout"
+msgstr "no facis cap agafament"
 
-#: builtin/log.c:1610
-msgid "--name-only does not make sense"
-msgstr "--name-only no té sentit"
+#: builtin/clone.c:94 builtin/clone.c:96 builtin/init-db.c:489
+msgid "create a bare repository"
+msgstr "crea un dipòsit nu"
 
-#: builtin/log.c:1612
-msgid "--name-status does not make sense"
-msgstr "--name-status no té sentit"
+#: builtin/clone.c:98
+msgid "create a mirror repository (implies bare)"
+msgstr "crea un dipòsit mirall (implica bare)"
 
-#: builtin/log.c:1614
-msgid "--check does not make sense"
-msgstr "--check no té sentit"
+#: builtin/clone.c:100
+msgid "to clone from a local repository"
+msgstr "per a clonar des d'un dipòsit local"
 
-#: builtin/log.c:1646
-msgid "standard output, or directory, which one?"
-msgstr "sortida estàndard o directori, quin dels dos?"
+#: builtin/clone.c:102
+msgid "don't use local hardlinks, always copy"
+msgstr "no usis enllaços durs locals, sempre copia"
 
-#: builtin/log.c:1648
-#, c-format
-msgid "Could not create directory '%s'"
-msgstr "No s'ha pogut crear el directori «%s»"
+#: builtin/clone.c:104
+msgid "setup as shared repository"
+msgstr "configura com a dipòsit compartit"
 
-#: builtin/log.c:1741
-#, c-format
-msgid "unable to read signature file '%s'"
-msgstr "no s'ha pogut llegir el fitxer de signatura «%s»"
+#: builtin/clone.c:107
+msgid "pathspec"
+msgstr "especificació de camí"
 
-#: builtin/log.c:1773
-msgid "Generating patches"
-msgstr "S'estan generant els pedaços"
+#: builtin/clone.c:107
+msgid "initialize submodules in the clone"
+msgstr "inicialitza els submòduls en el clon"
 
-#: builtin/log.c:1817
-msgid "Failed to create output files"
-msgstr "S'ha produït un error en crear els fitxers de sortida"
+#: builtin/clone.c:110
+msgid "number of submodules cloned in parallel"
+msgstr "nombre de submòduls clonats en paral·lel"
 
-#: builtin/log.c:1867
-msgid "git cherry [-v] [<upstream> [<head> [<limit>]]]"
-msgstr "git cherry [-v] [<font> [<cap> [<límit>]]]"
+#: builtin/clone.c:111 builtin/init-db.c:486
+msgid "template-directory"
+msgstr "directori-de-plantilla"
 
-#: builtin/log.c:1921
-#, c-format
-msgid ""
-"Could not find a tracked remote branch, please specify <upstream> manually.\n"
-msgstr ""
-"No s'ha pogut trobar una branca remota seguida. Especifiqueu <font> "
-"manualment.\n"
+#: builtin/clone.c:112 builtin/init-db.c:487
+msgid "directory from which templates will be used"
+msgstr "directori des del qual s'usaran les plantilles"
 
-#: builtin/ls-files.c:468
-msgid "git ls-files [<options>] [<file>...]"
-msgstr "git ls-files [<opcions>] [<fitxer>...]"
+#: builtin/clone.c:114 builtin/clone.c:116 builtin/submodule--helper.c:1392
+#: builtin/submodule--helper.c:1885
+msgid "reference repository"
+msgstr "dipòsit de referència"
 
-#: builtin/ls-files.c:517
-msgid "identify the file status with tags"
-msgstr "identifica l'estat de fitxer amb etiquetes"
+#: builtin/clone.c:118 builtin/submodule--helper.c:1394
+#: builtin/submodule--helper.c:1887
+msgid "use --reference only while cloning"
+msgstr "usa --reference només en clonar"
 
-#: builtin/ls-files.c:519
-msgid "use lowercase letters for 'assume unchanged' files"
-msgstr "usa lletres minúscules per als fitxers 'assume unchanged'"
+#: builtin/clone.c:119 builtin/column.c:27 builtin/merge-file.c:46
+#: builtin/pack-objects.c:3294 builtin/repack.c:327
+msgid "name"
+msgstr "nom"
 
-#: builtin/ls-files.c:521
-msgid "use lowercase letters for 'fsmonitor clean' files"
-msgstr "usa lletres minúscules per als fitxers 'fsmonitor clean'"
+#: builtin/clone.c:120
+msgid "use <name> instead of 'origin' to track upstream"
+msgstr "usa <nom> en lloc de 'origin' per a seguir la font"
 
-#: builtin/ls-files.c:523
-msgid "show cached files in the output (default)"
-msgstr ""
-"mostra en la sortida els fitxers desats en la memòria cau (per defecte)"
+#: builtin/clone.c:122
+msgid "checkout <branch> instead of the remote's HEAD"
+msgstr "agafa <branca> en lloc de la HEAD del remot"
 
-#: builtin/ls-files.c:525
-msgid "show deleted files in the output"
-msgstr "mostra en la sortida els fitxers suprimits"
+#: builtin/clone.c:124
+msgid "path to git-upload-pack on the remote"
+msgstr "camí a git-upload-pack en el remot"
 
-#: builtin/ls-files.c:527
-msgid "show modified files in the output"
-msgstr "mostra en la sortida els fitxers modificats"
+#: builtin/clone.c:125 builtin/fetch.c:168 builtin/grep.c:840
+#: builtin/pull.c:227
+msgid "depth"
+msgstr "profunditat"
 
-#: builtin/ls-files.c:529
-msgid "show other files in the output"
-msgstr "mostra en la sortida els altres fitxers"
+#: builtin/clone.c:126
+msgid "create a shallow clone of that depth"
+msgstr "crea un clon superficial de tal profunditat"
 
-#: builtin/ls-files.c:531
-msgid "show ignored files in the output"
-msgstr "mostra en la sortida els fitxers ignorats"
+#: builtin/clone.c:127 builtin/fetch.c:170 builtin/pack-objects.c:3283
+msgid "time"
+msgstr "hora"
 
-#: builtin/ls-files.c:534
-msgid "show staged contents' object name in the output"
-msgstr "mostra en la sortida el nom d'objecte dels continguts «stage»"
+#: builtin/clone.c:128
+msgid "create a shallow clone since a specific time"
+msgstr "crea un clon superficial des d'una hora específica"
 
-#: builtin/ls-files.c:536
-msgid "show files on the filesystem that need to be removed"
-msgstr "mostra els fitxers en el sistema de fitxers que s'han d'eliminar"
+#: builtin/clone.c:129 builtin/fetch.c:172 builtin/fetch.c:195
+#: builtin/rebase.c:1445
+msgid "revision"
+msgstr "revisió"
 
-#: builtin/ls-files.c:538
-msgid "show 'other' directories' names only"
-msgstr "mostra només els noms dels directoris 'other'"
+#: builtin/clone.c:130 builtin/fetch.c:173
+msgid "deepen history of shallow clone, excluding rev"
+msgstr "aprofundeix la història d'un clon superficial, excloent una revisió"
 
-#: builtin/ls-files.c:540
-msgid "show line endings of files"
-msgstr "mostra els terminadors de línia dels fitxers"
+#: builtin/clone.c:132
+msgid "clone only one branch, HEAD or --branch"
+msgstr "clona només una branca, HEAD o --branch"
 
-#: builtin/ls-files.c:542
-msgid "don't show empty directories"
-msgstr "no mostris els directoris buits"
+#: builtin/clone.c:134
+msgid "don't clone any tags, and make later fetches not to follow them"
+msgstr ""
+"no cloneu cap etiqueta, i feu que els «fetch» següents no els segueixen"
 
-#: builtin/ls-files.c:545
-msgid "show unmerged files in the output"
-msgstr "mostra en la sortida els fitxers sense fusionar"
+#: builtin/clone.c:136
+msgid "any cloned submodules will be shallow"
+msgstr "qualsevol submòdul clonat serà superficial"
 
-#: builtin/ls-files.c:547
-msgid "show resolve-undo information"
-msgstr "mostra la informació de resolució de desfet"
+#: builtin/clone.c:137 builtin/init-db.c:495
+msgid "gitdir"
+msgstr "directori de git"
 
-#: builtin/ls-files.c:549
-msgid "skip files matching pattern"
-msgstr "omet els fitxers coincidents amb el patró"
+#: builtin/clone.c:138 builtin/init-db.c:496
+msgid "separate git dir from working tree"
+msgstr "separa el directori de git de l'arbre de treball"
 
-#: builtin/ls-files.c:552
-msgid "exclude patterns are read from <file>"
-msgstr "els patrons d'exclusió es llegeixen de <fitxer>"
+#: builtin/clone.c:139
+msgid "key=value"
+msgstr "clau=valor"
 
-#: builtin/ls-files.c:555
-msgid "read additional per-directory exclude patterns in <file>"
-msgstr "llegeix els patrons addicionals d'exclusió per directori en <fitxer>"
+#: builtin/clone.c:140
+msgid "set config inside the new repository"
+msgstr "estableix la configuració dins del dipòsit nou"
 
-#: builtin/ls-files.c:557
-msgid "add the standard git exclusions"
-msgstr "afegeix les exclusions estàndards de git"
+#: builtin/clone.c:142 builtin/fetch.c:190 builtin/ls-remote.c:76
+#: builtin/push.c:573 builtin/send-pack.c:172
+msgid "server-specific"
+msgstr "específic al servidor"
 
-#: builtin/ls-files.c:560
-msgid "make the output relative to the project top directory"
-msgstr "fes que la sortida sigui relativa al directori superior del projecte"
+#: builtin/clone.c:142 builtin/fetch.c:190 builtin/ls-remote.c:76
+#: builtin/push.c:573 builtin/send-pack.c:173
+msgid "option to transmit"
+msgstr "opció a transmetre"
 
-#: builtin/ls-files.c:563
-msgid "recurse through submodules"
-msgstr "inclou recursivament als submòduls"
+#: builtin/clone.c:143 builtin/fetch.c:191 builtin/pull.c:240
+#: builtin/push.c:574
+msgid "use IPv4 addresses only"
+msgstr "usa només adreces IPv4"
 
-#: builtin/ls-files.c:565
-msgid "if any <file> is not in the index, treat this as an error"
-msgstr "si qualsevol <fitxer> no és en l'índex, tracta-ho com a error"
+#: builtin/clone.c:145 builtin/fetch.c:193 builtin/pull.c:243
+#: builtin/push.c:576
+msgid "use IPv6 addresses only"
+msgstr "usa només adreces IPv6"
 
-#: builtin/ls-files.c:566
-msgid "tree-ish"
-msgstr "arbre"
+#: builtin/clone.c:149
+#, fuzzy
+msgid "any cloned submodules will use their remote-tracking branch"
+msgstr "qualsevol submòdul clonat serà superficial"
 
-#: builtin/ls-files.c:567
-msgid "pretend that paths removed since <tree-ish> are still present"
+#: builtin/clone.c:151
+msgid "initialize sparse-checkout file to include only files at root"
 msgstr ""
-"pretén que els camins eliminats després de <arbre> encara siguin presents"
 
-#: builtin/ls-files.c:569
-msgid "show debugging data"
-msgstr "mostra les dades de depuració"
+#: builtin/clone.c:287
+msgid ""
+"No directory name could be guessed.\n"
+"Please specify a directory on the command line"
+msgstr ""
+"No s'ha pogut endevinar cap nom de directori.\n"
+"Especifiqueu un directori en la línia d'ordres"
+
+#: builtin/clone.c:340
+#, c-format
+msgid "info: Could not add alternate for '%s': %s\n"
+msgstr "info: No s'ha pogut afegir un alternatiu per a «%s»: %s\n"
+
+#: builtin/clone.c:413
+#, c-format
+msgid "%s exists and is not a directory"
+msgstr "%s existeix i no és directori"
+
+#: builtin/clone.c:430
+#, fuzzy, c-format
+msgid "failed to start iterator over '%s'"
+msgstr "no s'ha pogut escriure a «%s»"
+
+#: builtin/clone.c:460
+#, c-format
+msgid "failed to create link '%s'"
+msgstr "s'ha produït un error en crear l'enllaç «%s»"
+
+#: builtin/clone.c:464
+#, c-format
+msgid "failed to copy file to '%s'"
+msgstr "s'ha produït un error en copiar el fitxer a «%s»"
+
+#: builtin/clone.c:469
+#, fuzzy, c-format
+msgid "failed to iterate over '%s'"
+msgstr "s'ha produït un error en eliminar «%s»"
+
+#: builtin/clone.c:494
+#, c-format
+msgid "done.\n"
+msgstr "fet.\n"
 
-#: builtin/ls-remote.c:7
+#: builtin/clone.c:508
+#, fuzzy
 msgid ""
-"git ls-remote [--heads] [--tags] [--refs] [--upload-pack=<exec>]\n"
-"                     [-q | --quiet] [--exit-code] [--get-url]\n"
-"                     [--symref] [<repository> [<refs>...]]"
+"Clone succeeded, but checkout failed.\n"
+"You can inspect what was checked out with 'git status'\n"
+"and retry with 'git restore --source=HEAD :/'\n"
 msgstr ""
-"git ls-remote [--heads] [--tags] [--refs]\n"
-"                     [--upload-pack=<executable>] [-q | --quiet]\n"
-"                     [--exit-code] [--get-url] [--symref]\n"
-"                     [<dipòsit> [<referències>...]]"
+"El clonatge ha tingut èxit, però l'agafament ha\n"
+"fallat. Podeu inspeccionar què s'ha agafat amb\n"
+"'git status' i tornar a intentar l'agafament amb\n"
+"'git checkout -f HEAD'\n"
 
-#: builtin/ls-remote.c:52
-msgid "do not print remote URL"
-msgstr "no imprimeixis l'URL remot"
+#: builtin/clone.c:585
+#, c-format
+msgid "Could not find remote branch %s to clone."
+msgstr "No s'ha pogut trobar la branca remota %s per a clonar."
 
-#: builtin/ls-remote.c:53 builtin/ls-remote.c:55
-msgid "exec"
-msgstr "executable"
+#: builtin/clone.c:704
+#, c-format
+msgid "unable to update %s"
+msgstr "no s'ha pogut actualitzar %s"
 
-#: builtin/ls-remote.c:54 builtin/ls-remote.c:56
-msgid "path of git-upload-pack on the remote host"
-msgstr "camí a git-upload-pack en la màquina remota"
+#: builtin/clone.c:752
+#, fuzzy
+msgid "failed to initialize sparse-checkout"
+msgstr "s'ha produït un error en finalitzar «%s»"
 
-#: builtin/ls-remote.c:58
-msgid "limit to tags"
-msgstr "limita a etiquetes"
+#: builtin/clone.c:775
+msgid "remote HEAD refers to nonexistent ref, unable to checkout.\n"
+msgstr ""
+"la HEAD remot es refereix a una referència que no existeix; no s'ha pogut "
+"agafar.\n"
 
-#: builtin/ls-remote.c:59
-msgid "limit to heads"
-msgstr "limita a caps"
+#: builtin/clone.c:806
+msgid "unable to checkout working tree"
+msgstr "no s'ha pogut agafar l'arbre de treball"
 
-#: builtin/ls-remote.c:60
-msgid "do not show peeled tags"
-msgstr "no mostris les etiquetes pelades"
+#: builtin/clone.c:856
+msgid "unable to write parameters to config file"
+msgstr "no s'han pogut escriure els paràmetres al fitxer de configuració"
 
-#: builtin/ls-remote.c:62
-msgid "take url.<base>.insteadOf into account"
-msgstr "tingues en compte url.<base>.insteadOf"
+#: builtin/clone.c:919
+msgid "cannot repack to clean up"
+msgstr "no es pot reempaquetar per a netejar"
 
-#: builtin/ls-remote.c:64
-msgid "exit with exit code 2 if no matching refs are found"
-msgstr "surt amb codi de sortida 2 si no es troba cap referència coincident"
+#: builtin/clone.c:921
+msgid "cannot unlink temporary alternates file"
+msgstr "no es pot desenllaçar el fitxer d'alternatives temporal"
 
-#: builtin/ls-remote.c:67
-msgid "show underlying ref in addition to the object pointed by it"
-msgstr "mostra la referència subjacent a més de l'objecte que senyali"
+#: builtin/clone.c:959 builtin/receive-pack.c:1948
+msgid "Too many arguments."
+msgstr "Hi ha massa paràmetres."
 
-#: builtin/ls-tree.c:29
-msgid "git ls-tree [<options>] <tree-ish> [<path>...]"
-msgstr "git ls-tree [<opcions>] <arbre> [<camí>...]"
+#: builtin/clone.c:963
+msgid "You must specify a repository to clone."
+msgstr "Heu d'especificar un dipòsit per a clonar."
 
-#: builtin/ls-tree.c:127
-msgid "only show trees"
-msgstr "mostra només els arbres"
+#: builtin/clone.c:976
+#, c-format
+msgid "--bare and --origin %s options are incompatible."
+msgstr "les opcions --bare i --origin %s són incompatibles."
 
-#: builtin/ls-tree.c:129
-msgid "recurse into subtrees"
-msgstr "inclou recursivament als subarbres"
+#: builtin/clone.c:979
+msgid "--bare and --separate-git-dir are incompatible."
+msgstr "--bare i --separate-git-dir són incompatibles."
 
-#: builtin/ls-tree.c:131
-msgid "show trees when recursing"
-msgstr "mostra els arbres quan es treballa recursivament"
+#: builtin/clone.c:992
+#, c-format
+msgid "repository '%s' does not exist"
+msgstr "el dipòsit «%s» no existeix"
 
-#: builtin/ls-tree.c:134
-msgid "terminate entries with NUL byte"
-msgstr "acaba les entrades amb un octet NUL"
+#: builtin/clone.c:998 builtin/fetch.c:1787
+#, c-format
+msgid "depth %s is not a positive number"
+msgstr "la profunditat %s no és nombre positiu"
 
-#: builtin/ls-tree.c:135
-msgid "include object size"
-msgstr "mida de l'objecte d'inclusió"
+#: builtin/clone.c:1008
+#, c-format
+msgid "destination path '%s' already exists and is not an empty directory."
+msgstr "el camí destí «%s» ja existeix i no és un directori buit."
 
-#: builtin/ls-tree.c:137 builtin/ls-tree.c:139
-msgid "list only filenames"
-msgstr "llista només els noms de fitxer"
+#: builtin/clone.c:1018
+#, c-format
+msgid "working tree '%s' already exists."
+msgstr "l'arbre de treball «%s» ja existeix."
 
-#: builtin/ls-tree.c:142
-msgid "use full path names"
-msgstr "usa els noms de camí complets"
+#: builtin/clone.c:1033 builtin/clone.c:1054 builtin/difftool.c:271
+#: builtin/log.c:1866 builtin/worktree.c:302 builtin/worktree.c:334
+#, c-format
+msgid "could not create leading directories of '%s'"
+msgstr "no s'han pogut crear els directoris inicials de «%s»"
 
-#: builtin/ls-tree.c:144
-msgid "list entire tree; not just current directory (implies --full-name)"
+#: builtin/clone.c:1038
+#, c-format
+msgid "could not create work tree dir '%s'"
+msgstr "no s'ha pogut crear el directori d'arbre de treball «%s»"
+
+#: builtin/clone.c:1058
+#, c-format
+msgid "Cloning into bare repository '%s'...\n"
+msgstr "S'està clonant al dipòsit nu «%s»...\n"
+
+#: builtin/clone.c:1060
+#, c-format
+msgid "Cloning into '%s'...\n"
+msgstr "S'està clonant a «%s»...\n"
+
+#: builtin/clone.c:1084
+msgid ""
+"clone --recursive is not compatible with both --reference and --reference-if-"
+"able"
 msgstr ""
-"llista l'arbre sencer; no només el directori actual (implica --full-name)"
+"clone --recursive no és compatible amb ambdós --reference i --reference-if-"
+"able"
 
-#: builtin/mailsplit.c:241
+#: builtin/clone.c:1148
+msgid "--depth is ignored in local clones; use file:// instead."
+msgstr "--depth s'ignora en els clons locals; useu file:// en lloc d'això."
+
+#: builtin/clone.c:1150
+msgid "--shallow-since is ignored in local clones; use file:// instead."
+msgstr ""
+"--shallow-since s'ignora en els clons locals; useu file:// en lloc d'això."
+
+#: builtin/clone.c:1152
+msgid "--shallow-exclude is ignored in local clones; use file:// instead."
+msgstr ""
+"--shallow-exclude s'ignora en els clons locals; useu file:// en lloc d'això."
+
+#: builtin/clone.c:1154
+msgid "--filter is ignored in local clones; use file:// instead."
+msgstr "--filter s'ignora en els clons locals; useu file:// en lloc d'això."
+
+#: builtin/clone.c:1157
+msgid "source repository is shallow, ignoring --local"
+msgstr "el dipòsit font és superficial, s'està ignorant --local"
+
+#: builtin/clone.c:1162
+msgid "--local is ignored"
+msgstr "--local s'ignora"
+
+#: builtin/clone.c:1237 builtin/clone.c:1245
 #, c-format
-msgid "empty mbox: '%s'"
-msgstr "mbox buit: «%s»"
+msgid "Remote branch %s not found in upstream %s"
+msgstr "La branca remota %s no es troba en la font %s"
+
+#: builtin/clone.c:1248
+msgid "You appear to have cloned an empty repository."
+msgstr "Sembla que heu clonat un dipòsit buit."
+
+#: builtin/column.c:10
+msgid "git column [<options>]"
+msgstr "git column [<opcions>]"
+
+#: builtin/column.c:27
+msgid "lookup config vars"
+msgstr "cerca les variables de configuració"
+
+#: builtin/column.c:28 builtin/column.c:29
+msgid "layout to use"
+msgstr "disposició a usar"
+
+#: builtin/column.c:30
+msgid "Maximum width"
+msgstr "Amplada màxima"
+
+#: builtin/column.c:31
+msgid "Padding space on left border"
+msgstr "Espai d'encoixinada en el marge esquerre"
+
+#: builtin/column.c:32
+msgid "Padding space on right border"
+msgstr "Espai d'encoixinada en el marge dret"
+
+#: builtin/column.c:33
+msgid "Padding space between columns"
+msgstr "Espai d'encoixinada entre columnes"
+
+#: builtin/column.c:51
+msgid "--command must be the first argument"
+msgstr "--command ha de ser el primer paràmetre"
+
+#: builtin/commit-tree.c:18
+msgid ""
+"git commit-tree [(-p <parent>)...] [-S[<keyid>]] [(-m <message>)...] [(-F "
+"<file>)...] <tree>"
+msgstr ""
+
+#: builtin/commit-tree.c:31
+#, fuzzy, c-format
+msgid "duplicate parent %s ignored"
+msgstr "suprimeix les referències reemplaçades"
+
+#: builtin/commit-tree.c:56 builtin/commit-tree.c:136 builtin/log.c:526
+#, fuzzy, c-format
+msgid "not a valid object name %s"
+msgstr "no és un nom d'objecte vàlid: %s"
+
+#: builtin/commit-tree.c:93
+#, fuzzy, c-format
+msgid "git commit-tree: failed to open '%s'"
+msgstr "s'ha produït un error en obrir «%s»"
+
+#: builtin/commit-tree.c:96
+#, fuzzy, c-format
+msgid "git commit-tree: failed to read '%s'"
+msgstr "git write-tree ha fallat en escriure un arbre"
+
+#: builtin/commit-tree.c:98
+#, fuzzy, c-format
+msgid "git commit-tree: failed to close '%s'"
+msgstr "git write-tree ha fallat en escriure un arbre"
+
+#: builtin/commit-tree.c:111
+#, fuzzy
+msgid "parent"
+msgstr "pare"
+
+#: builtin/commit-tree.c:112
+#, fuzzy
+msgid "id of a parent commit object"
+msgstr "s'ha produït un error en escriure l'objecte de comissió"
+
+#: builtin/commit-tree.c:114 builtin/commit.c:1496 builtin/merge.c:270
+#: builtin/notes.c:409 builtin/notes.c:575 builtin/stash.c:1469
+#: builtin/tag.c:412
+msgid "message"
+msgstr "missatge"
+
+#: builtin/commit-tree.c:115 builtin/commit.c:1496
+msgid "commit message"
+msgstr "missatge de comissió"
+
+#: builtin/commit-tree.c:118
+#, fuzzy
+msgid "read commit log message from file"
+msgstr "llegiu el missatge des d'un fitxer"
+
+#: builtin/commit-tree.c:121 builtin/commit.c:1508 builtin/merge.c:287
+#: builtin/pull.c:195 builtin/revert.c:118
+msgid "GPG sign commit"
+msgstr "signa la comissió amb GPG"
+
+#: builtin/commit-tree.c:133
+#, fuzzy
+msgid "must give exactly one tree"
+msgstr "Cal exactament un rang."
+
+#: builtin/commit-tree.c:140
+#, fuzzy
+msgid "git commit-tree: failed to read"
+msgstr "git write-tree ha fallat en escriure un arbre"
+
+#: builtin/commit.c:41
+msgid "git commit [<options>] [--] <pathspec>..."
+msgstr "git commit [<opcions>] [--] <especificació-de-camí>..."
+
+#: builtin/commit.c:46
+msgid "git status [<options>] [--] <pathspec>..."
+msgstr "git status [<opcions>] [--] <especificació-de-camí>..."
+
+#: builtin/commit.c:51
+msgid ""
+"You asked to amend the most recent commit, but doing so would make\n"
+"it empty. You can repeat your command with --allow-empty, or you can\n"
+"remove the commit entirely with \"git reset HEAD^\".\n"
+msgstr ""
+"Heu demanat esmenar la comissió més recent, però fer això la\n"
+"deixaria buida. Podeu repetir la vostra ordre amb --allow-empty, o\n"
+"podeu eliminar la comissió per complet amb \"git reset HEAD^\".\n"
+
+#: builtin/commit.c:56
+msgid ""
+"The previous cherry-pick is now empty, possibly due to conflict resolution.\n"
+"If you wish to commit it anyway, use:\n"
+"\n"
+"    git commit --allow-empty\n"
+"\n"
+msgstr ""
+"El «cherry pick» previ ja està buit, possiblement a causa de resolució de "
+"conflicte.\n"
+"Si el voleu cometre de totes maneres, useu:\n"
+"\n"
+"    git commit --allow-empty\n"
+"\n"
+
+#: builtin/commit.c:63
+#, fuzzy
+msgid "Otherwise, please use 'git cherry-pick --skip'\n"
+msgstr "D'altra manera, useu «git reset»\n"
+
+#: builtin/commit.c:66
+msgid ""
+"and then use:\n"
+"\n"
+"    git cherry-pick --continue\n"
+"\n"
+"to resume cherry-picking the remaining commits.\n"
+"If you wish to skip this commit, use:\n"
+"\n"
+"    git cherry-pick --skip\n"
+"\n"
+msgstr ""
+
+#: builtin/commit.c:315
+msgid "failed to unpack HEAD tree object"
+msgstr "s'ha produït un error en desempaquetar l'objecte d'arbre HEAD"
+
+#: builtin/commit.c:351
+#, fuzzy
+msgid "--pathspec-from-file with -a does not make sense"
+msgstr "-a no té sentit amb camins."
+
+#: builtin/commit.c:364
+msgid "No paths with --include/--only does not make sense."
+msgstr "--include/--only no té sentit sense camí."
+
+#: builtin/commit.c:376
+msgid "unable to create temporary index"
+msgstr "no s'ha pogut crear un índex temporal"
+
+#: builtin/commit.c:382
+msgid "interactive add failed"
+msgstr "l'afegiment interactiu ha fallat"
+
+#: builtin/commit.c:396
+msgid "unable to update temporary index"
+msgstr "no s'ha pogut actualitzar l'índex temporal"
+
+#: builtin/commit.c:398
+msgid "Failed to update main cache tree"
+msgstr "S'ha produït un error en actualitzar l'arbre principal de memòria cau"
+
+#: builtin/commit.c:423 builtin/commit.c:446 builtin/commit.c:492
+msgid "unable to write new_index file"
+msgstr "no s'ha pogut escriure el fitxer new_index"
+
+#: builtin/commit.c:475
+msgid "cannot do a partial commit during a merge."
+msgstr "no es pot fer una comissió parcial durant una fusió."
+
+#: builtin/commit.c:477
+msgid "cannot do a partial commit during a cherry-pick."
+msgstr "no es pot fer una comissió parcial durant un «cherry pick»."
+
+#: builtin/commit.c:485
+msgid "cannot read the index"
+msgstr "no es pot llegir l'índex"
+
+#: builtin/commit.c:504
+msgid "unable to write temporary index file"
+msgstr "no s'ha pogut escriure un fitxer d'índex temporal"
+
+#: builtin/commit.c:602
+#, c-format
+msgid "commit '%s' lacks author header"
+msgstr "a la comissió «%s» li manca la capçalera d'autor"
+
+#: builtin/commit.c:604
+#, c-format
+msgid "commit '%s' has malformed author line"
+msgstr "la comissió «%s» té una línia d'autor mal formada"
+
+#: builtin/commit.c:623
+msgid "malformed --author parameter"
+msgstr "paràmetre --author mal format"
+
+#: builtin/commit.c:676
+msgid ""
+"unable to select a comment character that is not used\n"
+"in the current commit message"
+msgstr ""
+"no es pot seleccionar un caràcter de comentari que\n"
+"no sigui usat en el missatge de comissió actual"
+
+#: builtin/commit.c:714 builtin/commit.c:747 builtin/commit.c:1092
+#, c-format
+msgid "could not lookup commit %s"
+msgstr "no s'ha pogut trobar la comissió %s"
+
+#: builtin/commit.c:726 builtin/shortlog.c:319
+#, c-format
+msgid "(reading log message from standard input)\n"
+msgstr "(s'està llegint el missatge de registre des de l'entrada estàndard)\n"
+
+#: builtin/commit.c:728
+msgid "could not read log from standard input"
+msgstr "no s'ha pogut llegir el registre des de l'entrada estàndard"
+
+#: builtin/commit.c:732
+#, c-format
+msgid "could not read log file '%s'"
+msgstr "no s'ha pogut llegir el fitxer de registre «%s»"
+
+#: builtin/commit.c:763 builtin/commit.c:779
+msgid "could not read SQUASH_MSG"
+msgstr "no s'ha pogut llegir SQUASH_MSG"
+
+#: builtin/commit.c:770
+msgid "could not read MERGE_MSG"
+msgstr "no s'ha pogut llegir MERGE_MSG"
+
+#: builtin/commit.c:830
+msgid "could not write commit template"
+msgstr "no s'ha pogut escriure la plantilla de comissió"
+
+#: builtin/commit.c:849
+#, c-format
+msgid ""
+"\n"
+"It looks like you may be committing a merge.\n"
+"If this is not correct, please remove the file\n"
+"\t%s\n"
+"and try again.\n"
+msgstr ""
+"\n"
+"Sembla que podeu estar cometent una fusió.\n"
+"Si això no és correcte, elimineu el fitxer\n"
+"\t%s\n"
+"i intenteu-ho de nou.\n"
+
+#: builtin/commit.c:854
+#, c-format
+msgid ""
+"\n"
+"It looks like you may be committing a cherry-pick.\n"
+"If this is not correct, please remove the file\n"
+"\t%s\n"
+"and try again.\n"
+msgstr ""
+"\n"
+"Sembla que podeu estar cometent un «cherry pick».\n"
+"Si això no és correcte, elimineu el fitxer\n"
+"\t%s\n"
+"i intenteu-ho de nou.\n"
+
+#: builtin/commit.c:867
+#, c-format
+msgid ""
+"Please enter the commit message for your changes. Lines starting\n"
+"with '%c' will be ignored, and an empty message aborts the commit.\n"
+msgstr ""
+"Introduïu el missatge de comissió dels vostres canvis.\n"
+"S'ignoraran les línies que comencin amb «%c», i un missatge de\n"
+"comissió buit avorta la comissió.\n"
+
+#: builtin/commit.c:875
+#, c-format
+msgid ""
+"Please enter the commit message for your changes. Lines starting\n"
+"with '%c' will be kept; you may remove them yourself if you want to.\n"
+"An empty message aborts the commit.\n"
+msgstr ""
+"Introduïu el missatge de comissió dels vostres canvis.\n"
+"Es mantindran les línies que comencin amb «%c»; podeu eliminar-les "
+"vosaltres\n"
+"mateixos si voleu. Un missatge buit avorta la comissió.\n"
+
+#: builtin/commit.c:892
+#, c-format
+msgid "%sAuthor:    %.*s <%.*s>"
+msgstr "%sAutor:    %.*s <%.*s>"
+
+#: builtin/commit.c:900
+#, c-format
+msgid "%sDate:      %s"
+msgstr "%sData:      %s"
+
+#: builtin/commit.c:907
+#, c-format
+msgid "%sCommitter: %.*s <%.*s>"
+msgstr "%sComitent: %.*s <%.*s>"
+
+#: builtin/commit.c:925
+msgid "Cannot read index"
+msgstr "No es pot llegir l'índex"
+
+#: builtin/commit.c:992
+msgid "Error building trees"
+msgstr "Error en construir arbres"
+
+#: builtin/commit.c:1006 builtin/tag.c:275
+#, c-format
+msgid "Please supply the message using either -m or -F option.\n"
+msgstr "Especifiqueu el missatge usant l'opció -m o l'opció -F.\n"
+
+#: builtin/commit.c:1050
+#, c-format
+msgid "--author '%s' is not 'Name <email>' and matches no existing author"
+msgstr ""
+"--author «%s» no és «Nom <adreça-electrònica>» i no coincideix amb\n"
+"cap autor existent"
+
+#: builtin/commit.c:1064
+#, c-format
+msgid "Invalid ignored mode '%s'"
+msgstr "mode ignorat no vàlid «%s»"
+
+#: builtin/commit.c:1082 builtin/commit.c:1322
+#, c-format
+msgid "Invalid untracked files mode '%s'"
+msgstr "Mode de fitxers no seguits no vàlid «%s»"
+
+#: builtin/commit.c:1122
+msgid "--long and -z are incompatible"
+msgstr "--long i -z són incompatibles"
+
+#: builtin/commit.c:1166
+msgid "Using both --reset-author and --author does not make sense"
+msgstr "Usar ambdós --reset-author i --author no té sentit"
+
+#: builtin/commit.c:1175
+msgid "You have nothing to amend."
+msgstr "No teniu res a esmenar."
+
+#: builtin/commit.c:1178
+msgid "You are in the middle of a merge -- cannot amend."
+msgstr "Esteu enmig d'una fusió -- no es pot esmenar."
+
+#: builtin/commit.c:1180
+msgid "You are in the middle of a cherry-pick -- cannot amend."
+msgstr "Esteu enmig d'un «cherry pick» -- no es pot esmenar."
+
+#: builtin/commit.c:1183
+msgid "Options --squash and --fixup cannot be used together"
+msgstr "Les opcions --squash i --fixup no es poden usar juntes"
+
+#: builtin/commit.c:1193
+msgid "Only one of -c/-C/-F/--fixup can be used."
+msgstr "Només un de -c/-C/-F/--fixup es pot usar."
+
+#: builtin/commit.c:1195
+msgid "Option -m cannot be combined with -c/-C/-F."
+msgstr "L'opció -m no es pot combinar amb -c/-C/-F/."
+
+#: builtin/commit.c:1203
+msgid "--reset-author can be used only with -C, -c or --amend."
+msgstr "--reset-author només es pot usar amb -C, -c o --amend."
+
+#: builtin/commit.c:1220
+msgid "Only one of --include/--only/--all/--interactive/--patch can be used."
+msgstr "Només un de --include/--only/--all/--interactive/--patch es pot usar."
+
+#: builtin/commit.c:1226
+#, fuzzy, c-format
+msgid "paths '%s ...' with -a does not make sense"
+msgstr "-a no té sentit amb camins."
+
+#: builtin/commit.c:1357 builtin/commit.c:1519
+msgid "show status concisely"
+msgstr "mostra l'estat concisament"
+
+#: builtin/commit.c:1359 builtin/commit.c:1521
+msgid "show branch information"
+msgstr "mostra la informació de branca"
+
+#: builtin/commit.c:1361
+msgid "show stash information"
+msgstr "mostra la informació de «stash»"
+
+#: builtin/commit.c:1363 builtin/commit.c:1523
+msgid "compute full ahead/behind values"
+msgstr ""
+
+#: builtin/commit.c:1365
+msgid "version"
+msgstr "versió"
+
+#: builtin/commit.c:1365 builtin/commit.c:1525 builtin/push.c:549
+#: builtin/worktree.c:650
+msgid "machine-readable output"
+msgstr "sortida llegible per màquina"
+
+#: builtin/commit.c:1368 builtin/commit.c:1527
+msgid "show status in long format (default)"
+msgstr "mostra l'estat en format llarg (per defecte)"
+
+#: builtin/commit.c:1371 builtin/commit.c:1530
+msgid "terminate entries with NUL"
+msgstr "acaba les entrades amb NUL"
+
+#: builtin/commit.c:1373 builtin/commit.c:1377 builtin/commit.c:1533
+#: builtin/fast-export.c:1153 builtin/fast-export.c:1156
+#: builtin/fast-export.c:1159 builtin/rebase.c:1525 parse-options.h:336
+msgid "mode"
+msgstr "mode"
+
+#: builtin/commit.c:1374 builtin/commit.c:1533
+msgid "show untracked files, optional modes: all, normal, no. (Default: all)"
+msgstr ""
+"mostra els fitxers no seguits, modes opcionals: all, normal, no. (Per "
+"defecte: all)"
+
+#: builtin/commit.c:1378
+msgid ""
+"show ignored files, optional modes: traditional, matching, no. (Default: "
+"traditional)"
+msgstr ""
+"mostra els fitxers ignorats, modes opcionals: traditional, matching, no. "
+"(Per defecte: traditional, matching, no.)"
+
+#: builtin/commit.c:1380 parse-options.h:192
+msgid "when"
+msgstr "quan"
+
+#: builtin/commit.c:1381
+msgid ""
+"ignore changes to submodules, optional when: all, dirty, untracked. "
+"(Default: all)"
+msgstr ""
+"ignora els canvis als submòduls, opcional quan: all, dirty, untracked. (Per "
+"defecte: all)"
+
+#: builtin/commit.c:1383
+msgid "list untracked files in columns"
+msgstr "mostra els fitxers no seguits en columnes"
+
+#: builtin/commit.c:1384
+msgid "do not detect renames"
+msgstr "no detectis canvis de noms"
+
+#: builtin/commit.c:1386
+msgid "detect renames, optionally set similarity index"
+msgstr "detecta canvis de noms, i opcionalment estableix un índex de semblança"
+
+#: builtin/commit.c:1406
+msgid "Unsupported combination of ignored and untracked-files arguments"
+msgstr ""
+
+#: builtin/commit.c:1489
+msgid "suppress summary after successful commit"
+msgstr "omet el resum després d'una comissió reeixida"
+
+#: builtin/commit.c:1490
+msgid "show diff in commit message template"
+msgstr "mostra la diferència en la plantilla de missatge de comissió"
+
+#: builtin/commit.c:1492
+msgid "Commit message options"
+msgstr "Opcions de missatge de comissió"
+
+#: builtin/commit.c:1493 builtin/merge.c:274 builtin/tag.c:414
+msgid "read message from file"
+msgstr "llegiu el missatge des d'un fitxer"
+
+#: builtin/commit.c:1494
+msgid "author"
+msgstr "autor"
+
+#: builtin/commit.c:1494
+msgid "override author for commit"
+msgstr "autor corregit de la comissió"
+
+#: builtin/commit.c:1495 builtin/gc.c:538
+msgid "date"
+msgstr "data"
+
+#: builtin/commit.c:1495
+msgid "override date for commit"
+msgstr "data corregida de la comissió"
+
+#: builtin/commit.c:1497 builtin/commit.c:1498 builtin/commit.c:1499
+#: builtin/commit.c:1500 parse-options.h:328 ref-filter.h:92
+msgid "commit"
+msgstr "comissió"
+
+#: builtin/commit.c:1497
+msgid "reuse and edit message from specified commit"
+msgstr "reusa i edita el missatge de la comissió especificada"
+
+#: builtin/commit.c:1498
+msgid "reuse message from specified commit"
+msgstr "reusa el missatge de la comissió especificada"
+
+#: builtin/commit.c:1499
+msgid "use autosquash formatted message to fixup specified commit"
+msgstr ""
+"usa el missatge formatat de «squash» automàtic per a corregir la comissió "
+"especificada"
+
+#: builtin/commit.c:1500
+msgid "use autosquash formatted message to squash specified commit"
+msgstr ""
+"usa el missatge formatat de «squash» automàtic per a «squash» a la comissió "
+"especificada"
+
+#: builtin/commit.c:1501
+msgid "the commit is authored by me now (used with -C/-c/--amend)"
+msgstr "l'autor de la comissió ja sóc jo (s'usa amb -C/-c/--amend)"
+
+#: builtin/commit.c:1502 builtin/log.c:1634 builtin/merge.c:289
+#: builtin/pull.c:164 builtin/revert.c:110
+msgid "add Signed-off-by:"
+msgstr "afegeix Signed-off-by:"
+
+#: builtin/commit.c:1503
+msgid "use specified template file"
+msgstr "usa el fitxer de plantilla especificat"
+
+#: builtin/commit.c:1504
+msgid "force edit of commit"
+msgstr "força l'edició de la comissió"
+
+#: builtin/commit.c:1506
+msgid "include status in commit message template"
+msgstr "inclou l'estat en la plantilla de missatge de comissió"
+
+#: builtin/commit.c:1511
+msgid "Commit contents options"
+msgstr "Opcions dels continguts de les comissions"
+
+#: builtin/commit.c:1512
+msgid "commit all changed files"
+msgstr "comet tots els fitxers canviats"
+
+#: builtin/commit.c:1513
+msgid "add specified files to index for commit"
+msgstr "afegeix els fitxers especificats a l'índex per a cometre"
+
+#: builtin/commit.c:1514
+msgid "interactively add files"
+msgstr "afegeix els fitxers interactivament"
+
+#: builtin/commit.c:1515
+msgid "interactively add changes"
+msgstr "afegeix els canvis interactivament"
+
+#: builtin/commit.c:1516
+msgid "commit only specified files"
+msgstr "comet només els fitxers especificats"
+
+#: builtin/commit.c:1517
+msgid "bypass pre-commit and commit-msg hooks"
+msgstr "evita els lligams de precomissió i missatge de comissió"
+
+#: builtin/commit.c:1518
+msgid "show what would be committed"
+msgstr "mostra què es cometria"
+
+#: builtin/commit.c:1531
+msgid "amend previous commit"
+msgstr "esmena la comissió anterior"
+
+#: builtin/commit.c:1532
+msgid "bypass post-rewrite hook"
+msgstr "evita el lligam de post escriptura"
+
+#: builtin/commit.c:1539
+msgid "ok to record an empty change"
+msgstr "està bé registrar un canvi buit"
+
+#: builtin/commit.c:1541
+msgid "ok to record a change with an empty message"
+msgstr "està bé registrar un canvi amb missatge buit"
+
+#: builtin/commit.c:1614
+#, c-format
+msgid "Corrupt MERGE_HEAD file (%s)"
+msgstr "Fitxer MERGE_HEAD malmès (%s)"
+
+#: builtin/commit.c:1621
+msgid "could not read MERGE_MODE"
+msgstr "no s'ha pogut llegir MERGE_MODE"
+
+#: builtin/commit.c:1640
+#, c-format
+msgid "could not read commit message: %s"
+msgstr "no s'ha pogut llegir el missatge de comissió: %s"
+
+#: builtin/commit.c:1647
+#, c-format
+msgid "Aborting commit due to empty commit message.\n"
+msgstr "S'està avortant la comissió a causa d'un missatge de comissió buit.\n"
+
+#: builtin/commit.c:1652
+#, c-format
+msgid "Aborting commit; you did not edit the message.\n"
+msgstr "S'està avortant la comissió; no heu editat el missatge.\n"
+
+#: builtin/commit.c:1686
+#, fuzzy
+msgid ""
+"repository has been updated, but unable to write\n"
+"new_index file. Check that disk is not full and quota is\n"
+"not exceeded, and then \"git restore --staged :/\" to recover."
+msgstr ""
+"s'ha actualitzat el dipòsit, però no es pot escriure el\n"
+"fitxer new_index. Comproveu que el disc no estigui ple i\n"
+"que no s'hagi excedit la quota, i després feu \n"
+"«git reset HEAD» per a recuperar-ho."
+
+#: builtin/commit-graph.c:11 builtin/commit-graph.c:17
+msgid ""
+"git commit-graph verify [--object-dir <objdir>] [--shallow] [--[no-]progress]"
+msgstr ""
+
+#: builtin/commit-graph.c:12 builtin/commit-graph.c:22
+msgid ""
+"git commit-graph write [--object-dir <objdir>] [--append|--split] [--"
+"reachable|--stdin-packs|--stdin-commits] [--[no-]progress] <split options>"
+msgstr ""
+
+#: builtin/commit-graph.c:48 builtin/commit-graph.c:103
+#: builtin/commit-graph.c:187 builtin/fetch.c:179 builtin/log.c:1657
+msgid "dir"
+msgstr "directori"
+
+#: builtin/commit-graph.c:49 builtin/commit-graph.c:104
+#: builtin/commit-graph.c:188
+msgid "The object directory to store the graph"
+msgstr ""
+
+#: builtin/commit-graph.c:51
+msgid "if the commit-graph is split, only verify the tip file"
+msgstr ""
+
+#: builtin/commit-graph.c:73 t/helper/test-read-graph.c:23
+#, fuzzy, c-format
+msgid "Could not open commit-graph '%s'"
+msgstr "no s'ha pogut analitzar la comissió «%s»"
+
+#: builtin/commit-graph.c:106
+msgid "start walk at all refs"
+msgstr ""
+
+#: builtin/commit-graph.c:108
+msgid "scan pack-indexes listed by stdin for commits"
+msgstr ""
+
+#: builtin/commit-graph.c:110
+msgid "start walk at commits listed by stdin"
+msgstr ""
+
+#: builtin/commit-graph.c:112
+msgid "include all commits already in the commit-graph file"
+msgstr ""
+
+#: builtin/commit-graph.c:115
+#, fuzzy
+msgid "allow writing an incremental commit-graph file"
+msgstr "Escriu i verifica els fitxers commit-graph de Git"
+
+#: builtin/commit-graph.c:117 builtin/commit-graph.c:121
+msgid "maximum number of commits in a non-base split commit-graph"
+msgstr ""
+
+#: builtin/commit-graph.c:119
+msgid "maximum ratio between two levels of a split commit-graph"
+msgstr ""
+
+#: builtin/commit-graph.c:137
+msgid "use at most one of --reachable, --stdin-commits, or --stdin-packs"
+msgstr ""
+
+#: builtin/config.c:11
+msgid "git config [<options>]"
+msgstr "git config [<opcions>]"
+
+#: builtin/config.c:103 builtin/env--helper.c:23
+#, c-format
+msgid "unrecognized --type argument, %s"
+msgstr "paràmetre --type no reconegut, %s"
+
+#: builtin/config.c:115
+msgid "only one type at a time"
+msgstr "només un tipus cada cop"
+
+#: builtin/config.c:124
+msgid "Config file location"
+msgstr "Ubicació del fitxer de configuració"
+
+#: builtin/config.c:125
+msgid "use global config file"
+msgstr "usa el fitxer de configuració global"
+
+#: builtin/config.c:126
+msgid "use system config file"
+msgstr "usa el fitxer de configuració del sistema"
+
+#: builtin/config.c:127
+msgid "use repository config file"
+msgstr "usa el fitxer de configuració del dipòsit"
+
+#: builtin/config.c:128
+msgid "use per-worktree config file"
+msgstr "usa un fitxer de configuració per dipòsit"
+
+#: builtin/config.c:129
+msgid "use given config file"
+msgstr "usa el fitxer de configuració donat"
+
+#: builtin/config.c:130
+msgid "blob-id"
+msgstr "ID de blob"
+
+#: builtin/config.c:130
+msgid "read config from given blob object"
+msgstr "llegeix la configuració de l'objecte de blob donat"
+
+#: builtin/config.c:131
+msgid "Action"
+msgstr "Acció"
+
+#: builtin/config.c:132
+msgid "get value: name [value-regex]"
+msgstr "obtén valor: nom [regex-de-valors]"
+
+#: builtin/config.c:133
+msgid "get all values: key [value-regex]"
+msgstr "obtén tots els valors: clau [regex-de-valors]"
+
+#: builtin/config.c:134
+msgid "get values for regexp: name-regex [value-regex]"
+msgstr "obtén valors de regexp: regex-de-noms [regex-de-valors]"
+
+#: builtin/config.c:135
+msgid "get value specific for the URL: section[.var] URL"
+msgstr "obtén el valor específic per a l'URL: secció[.variable] URL"
+
+#: builtin/config.c:136
+msgid "replace all matching variables: name value [value_regex]"
+msgstr ""
+"reemplaça totes les variables que coincideixen: nom valor [regex_de_valors]"
+
+#: builtin/config.c:137
+msgid "add a new variable: name value"
+msgstr "afegeix una variable nova: nom valor"
+
+#: builtin/config.c:138
+msgid "remove a variable: name [value-regex]"
+msgstr "elimina una variable: nom [regex-de-valors]"
+
+#: builtin/config.c:139
+msgid "remove all matches: name [value-regex]"
+msgstr "elimina totes les coincidències: nom [regex-de-valors]"
+
+#: builtin/config.c:140
+msgid "rename section: old-name new-name"
+msgstr "canvia el nom de secció: nom-antic nom-nou"
+
+#: builtin/config.c:141
+msgid "remove a section: name"
+msgstr "elimina una secció: nom"
+
+#: builtin/config.c:142
+msgid "list all"
+msgstr "llista tots"
+
+#: builtin/config.c:143
+msgid "open an editor"
+msgstr "obre un editor"
+
+#: builtin/config.c:144
+msgid "find the color configured: slot [default]"
+msgstr "troba el color configurat: ranura [per defecte]"
+
+#: builtin/config.c:145
+msgid "find the color setting: slot [stdout-is-tty]"
+msgstr "troba el paràmetre de color: ranura [stdout-és-tty]"
+
+#: builtin/config.c:146
+msgid "Type"
+msgstr "Tipus"
+
+#: builtin/config.c:147 builtin/env--helper.c:38
+msgid "value is given this type"
+msgstr "el valor té donat aquest tipus"
+
+#: builtin/config.c:148
+msgid "value is \"true\" or \"false\""
+msgstr "el valor és \"true\" o \"false\""
+
+#: builtin/config.c:149
+msgid "value is decimal number"
+msgstr "el valor és un nombre decimal"
+
+#: builtin/config.c:150
+msgid "value is --bool or --int"
+msgstr "el valor és --bool o --int"
+
+#: builtin/config.c:151
+msgid "value is a path (file or directory name)"
+msgstr "el valor és un camí (nom de fitxer o directori)"
+
+#: builtin/config.c:152
+msgid "value is an expiry date"
+msgstr "el valor és una data de venciment"
+
+#: builtin/config.c:153
+msgid "Other"
+msgstr "Altre"
+
+#: builtin/config.c:154
+msgid "terminate values with NUL byte"
+msgstr "acaba els valors amb un octet NUL"
+
+#: builtin/config.c:155
+msgid "show variable names only"
+msgstr "mostra només els noms de variable"
+
+#: builtin/config.c:156
+msgid "respect include directives on lookup"
+msgstr "respecta les directives d'inclusió en cercar"
+
+#: builtin/config.c:157
+msgid "show origin of config (file, standard input, blob, command line)"
+msgstr ""
+"mostra l'origen de la configuració (fitxer, entrada estàndard, blob, línia "
+"d'ordres)"
+
+#: builtin/config.c:158 builtin/env--helper.c:40
+msgid "value"
+msgstr "valor"
+
+#: builtin/config.c:158
+msgid "with --get, use default value when missing entry"
+msgstr ""
+
+#: builtin/config.c:172
+#, c-format
+msgid "wrong number of arguments, should be %d"
+msgstr ""
+
+#: builtin/config.c:174
+#, c-format
+msgid "wrong number of arguments, should be from %d to %d"
+msgstr ""
+
+#: builtin/config.c:308
+#, c-format
+msgid "invalid key pattern: %s"
+msgstr "patró de la clau no vàlid: %s"
+
+#: builtin/config.c:344
+#, c-format
+msgid "failed to format default config value: %s"
+msgstr ""
+"s'ha produït un error en formatar el valor per defecte de la configuració: %s"
+
+#: builtin/config.c:401
+#, c-format
+msgid "cannot parse color '%s'"
+msgstr "no es pot analitzar el color «%s»"
+
+#: builtin/config.c:443
+msgid "unable to parse default color value"
+msgstr "no s'ha pogut analitzar el valor de color per defecte"
+
+#: builtin/config.c:496 builtin/config.c:742
+msgid "not in a git directory"
+msgstr "no és en un directori git"
+
+#: builtin/config.c:499
+msgid "writing to stdin is not supported"
+msgstr "no s'admet escriure a stdin"
+
+#: builtin/config.c:502
+#, fuzzy
+msgid "writing config blobs is not supported"
+msgstr "avís: el sobrenom de sendmail amb cometes no està suportat: %s\n"
+
+#: builtin/config.c:587
+#, c-format
+msgid ""
+"# This is Git's per-user configuration file.\n"
+"[user]\n"
+"# Please adapt and uncomment the following lines:\n"
+"#\tname = %s\n"
+"#\temail = %s\n"
+msgstr ""
+"# Això és el fitxer de configuració del Git de l'usuari.\n"
+"[user]\n"
+"# Adapteu i descomenteu les línies següents:\n"
+"#\tname = %s\n"
+"#\temail = %s\n"
+
+#: builtin/config.c:611
+msgid "only one config file at a time"
+msgstr "només un fitxer de configuració cada cop"
+
+#: builtin/config.c:616
+msgid "--local can only be used inside a git repository"
+msgstr "--local només es pot usar dins d'un dipòsit git"
+
+#: builtin/config.c:619
+msgid "--blob can only be used inside a git repository"
+msgstr "--blob només es pot usar dins d'un dipòsit git"
+
+#: builtin/config.c:638
+msgid "$HOME not set"
+msgstr "$HOME no està establerta"
+
+#: builtin/config.c:658
+msgid ""
+"--worktree cannot be used with multiple working trees unless the config\n"
+"extension worktreeConfig is enabled. Please read \"CONFIGURATION FILE\"\n"
+"section in \"git help worktree\" for details"
+msgstr ""
+
+#: builtin/config.c:688
+msgid "--get-color and variable type are incoherent"
+msgstr "--get-color i el tipus de variable són incoherents"
+
+#: builtin/config.c:693
+msgid "only one action at a time"
+msgstr "només una acció cada cop"
+
+#: builtin/config.c:706
+msgid "--name-only is only applicable to --list or --get-regexp"
+msgstr "--name-only només és aplicable a --list o --get-regexp"
+
+#: builtin/config.c:712
+msgid ""
+"--show-origin is only applicable to --get, --get-all, --get-regexp, and --"
+"list"
+msgstr ""
+"--show-origin només és aplicable a --get, --get-all, --get-regexp, i --list"
+
+#: builtin/config.c:718
+msgid "--default is only applicable to --get"
+msgstr "--default només és aplicable a --get"
+
+#: builtin/config.c:731
+#, c-format
+msgid "unable to read config file '%s'"
+msgstr "no s'ha pogut llegir el fitxer de configuració «%s»"
+
+#: builtin/config.c:734
+msgid "error processing config file(s)"
+msgstr "s'ha produït un error processant els fitxers de configuració"
+
+#: builtin/config.c:744
+msgid "editing stdin is not supported"
+msgstr "no hi ha compatibilitat per a l'edició a stdin"
+
+#: builtin/config.c:746
+msgid "editing blobs is not supported"
+msgstr "no hi ha compatibilitat per l'edició de blobs"
+
+#: builtin/config.c:760
+#, c-format
+msgid "cannot create configuration file %s"
+msgstr "no es pot crear el fitxer de configuració %s"
+
+#: builtin/config.c:773
+#, c-format
+msgid ""
+"cannot overwrite multiple values with a single value\n"
+"       Use a regexp, --add or --replace-all to change %s."
+msgstr ""
+"no es poden sobreescriure múltiples valors amb un sol valor\n"
+"       Useu una expressió regular, --add o --replace-all per a canviar %s."
+
+#: builtin/config.c:847 builtin/config.c:858
+#, c-format
+msgid "no such section: %s"
+msgstr "no existeix la secció: %s"
+
+#: builtin/count-objects.c:90
+msgid "git count-objects [-v] [-H | --human-readable]"
+msgstr "git count-objects [-v] [-H | --human-readable]"
+
+#: builtin/count-objects.c:100
+msgid "print sizes in human readable format"
+msgstr "imprimeix les mides en un format llegible pels humans"
+
+#: builtin/describe.c:26
+msgid "git describe [<options>] [<commit-ish>...]"
+msgstr "git describe [<opcions>] [<comissió>...]"
+
+#: builtin/describe.c:27
+msgid "git describe [<options>] --dirty"
+msgstr "git describe [<opcions>] --dirty"
+
+#: builtin/describe.c:62
+msgid "head"
+msgstr "davant per"
+
+#: builtin/describe.c:62
+msgid "lightweight"
+msgstr "lleuger"
+
+#: builtin/describe.c:62
+msgid "annotated"
+msgstr "anotat"
+
+#: builtin/describe.c:275
+#, c-format
+msgid "annotated tag %s not available"
+msgstr "l'etiqueta anotada %s no és disponible"
+
+#: builtin/describe.c:279
+#, c-format
+msgid "annotated tag %s has no embedded name"
+msgstr "l'etiqueta anotada %s no té nom incrustat"
+
+#: builtin/describe.c:281
+#, c-format
+msgid "tag '%s' is really '%s' here"
+msgstr "l'etiqueta «%s» realment és «%s» aquí"
+
+#: builtin/describe.c:325
+#, c-format
+msgid "no tag exactly matches '%s'"
+msgstr "cap etiqueta coincideix exactament amb «%s»"
+
+#: builtin/describe.c:327
+#, c-format
+msgid "No exact match on refs or tags, searching to describe\n"
+msgstr ""
+
+#: builtin/describe.c:381
+#, c-format
+msgid "finished search at %s\n"
+msgstr "s'ha finalitzat la cerca a %s\n"
+
+#: builtin/describe.c:407
+#, c-format
+msgid ""
+"No annotated tags can describe '%s'.\n"
+"However, there were unannotated tags: try --tags."
+msgstr ""
+"Cap etiqueta anotada pot descriure «%s».\n"
+"No obstant, hi havia etiquetes no anotades: proveu --tags."
+
+#: builtin/describe.c:411
+#, c-format
+msgid ""
+"No tags can describe '%s'.\n"
+"Try --always, or create some tags."
+msgstr ""
+"Cap etiqueta pot descriure «%s».\n"
+"Proveu --always, o creeu algunes etiquetes."
+
+#: builtin/describe.c:441
+#, c-format
+msgid "traversed %lu commits\n"
+msgstr "%lu comissions travessades\n"
+
+#: builtin/describe.c:444
+#, c-format
+msgid ""
+"more than %i tags found; listed %i most recent\n"
+"gave up search at %s\n"
+msgstr ""
+"s'han trobat més de %i etiquetes: s'han llistat les %i més recents\n"
+"s'ha renunciat la cerca a %s\n"
+
+#: builtin/describe.c:512
+#, c-format
+msgid "describe %s\n"
+msgstr "descriu %s\n"
+
+#: builtin/describe.c:515
+#, c-format
+msgid "Not a valid object name %s"
+msgstr "%s no és un nom d'objecte vàlid"
+
+#: builtin/describe.c:523
+#, c-format
+msgid "%s is neither a commit nor blob"
+msgstr "%s no és una comissió o un blob"
+
+#: builtin/describe.c:537
+msgid "find the tag that comes after the commit"
+msgstr "troba l'etiqueta que vingui després de la comissió"
+
+#: builtin/describe.c:538
+msgid "debug search strategy on stderr"
+msgstr "estratègia de cerca de depuració en stderr"
+
+#: builtin/describe.c:539
+msgid "use any ref"
+msgstr "usa qualsevol referència"
+
+#: builtin/describe.c:540
+msgid "use any tag, even unannotated"
+msgstr "usa qualsevol etiqueta, fins i tot aquelles sense anotar"
+
+#: builtin/describe.c:541
+msgid "always use long format"
+msgstr "sempre usa el format llarg"
+
+#: builtin/describe.c:542
+msgid "only follow first parent"
+msgstr "només segueix la primera mare"
+
+#: builtin/describe.c:545
+msgid "only output exact matches"
+msgstr "emet només coincidències exactes"
+
+#: builtin/describe.c:547
+msgid "consider <n> most recent tags (default: 10)"
+msgstr "considera les <n> etiquetes més recents (per defecte: 10)"
+
+#: builtin/describe.c:549
+msgid "only consider tags matching <pattern>"
+msgstr "només considera les etiquetes que coincideixen amb <patró>"
+
+#: builtin/describe.c:551
+msgid "do not consider tags matching <pattern>"
+msgstr "no consideris les etiquetes que no coincideixen amb <patró>"
+
+#: builtin/describe.c:553 builtin/name-rev.c:473
+msgid "show abbreviated commit object as fallback"
+msgstr "mostra l'objecte de comissió abreviat com a sistema alternatiu"
+
+#: builtin/describe.c:554 builtin/describe.c:557
+msgid "mark"
+msgstr "marca"
+
+#: builtin/describe.c:555
+msgid "append <mark> on dirty working tree (default: \"-dirty\")"
+msgstr "annexa <marca> en l'arbre de treball brut (per defecte: \"-dirty\")"
+
+#: builtin/describe.c:558
+msgid "append <mark> on broken working tree (default: \"-broken\")"
+msgstr "annexa <marca> en l'arbre de treball brut (per defecte: \"-broken\")"
+
+#: builtin/describe.c:576
+msgid "--long is incompatible with --abbrev=0"
+msgstr "--long és incompatible amb --abbrev=0"
+
+#: builtin/describe.c:605
+msgid "No names found, cannot describe anything."
+msgstr "No s'ha trobat cap nom, no es pot descriure res."
+
+#: builtin/describe.c:656
+msgid "--dirty is incompatible with commit-ishes"
+msgstr "--dirty és incompatible amb les comissions"
+
+#: builtin/describe.c:658
+msgid "--broken is incompatible with commit-ishes"
+msgstr "--broken és incompatible amb les comissions"
+
+#: builtin/diff.c:84
+#, c-format
+msgid "'%s': not a regular file or symlink"
+msgstr "«%s»: no és ni fitxer regular ni enllaç simbòlic"
+
+#: builtin/diff.c:235
+#, c-format
+msgid "invalid option: %s"
+msgstr "opció no vàlida: %s"
+
+#: builtin/diff.c:350
+msgid "Not a git repository"
+msgstr "No és un dipòsit de git"
+
+#: builtin/diff.c:394
+#, c-format
+msgid "invalid object '%s' given."
+msgstr "s'ha donat un objecte no vàlid «%s»."
+
+#: builtin/diff.c:403
+#, c-format
+msgid "more than two blobs given: '%s'"
+msgstr "s'ha donat més de dos blobs: «%s»"
+
+#: builtin/diff.c:408
+#, c-format
+msgid "unhandled object '%s' given."
+msgstr "s'ha donat l'objecte no gestionat «%s»."
+
+#: builtin/difftool.c:30
+msgid "git difftool [<options>] [<commit> [<commit>]] [--] [<path>...]"
+msgstr "git difftool [<opcions>] [<commit> [<commit>]] [--] [<camí>...]"
+
+#: builtin/difftool.c:260
+#, c-format
+msgid "failed: %d"
+msgstr "ha fallat: %d"
+
+#: builtin/difftool.c:302
+#, c-format
+msgid "could not read symlink %s"
+msgstr "no s'ha pogut llegir l'enllaç simbòlic %s"
+
+#: builtin/difftool.c:304
+#, c-format
+msgid "could not read symlink file %s"
+msgstr "no s'ha pogut llegir el fitxer d'enllaç simbòlic %s"
+
+#: builtin/difftool.c:312
+#, c-format
+msgid "could not read object %s for symlink %s"
+msgstr "No es pot llegir l'objecte %s per l'enllaç simbòlic %s"
+
+#: builtin/difftool.c:413
+msgid ""
+"combined diff formats('-c' and '--cc') are not supported in\n"
+"directory diff mode('-d' and '--dir-diff')."
+msgstr ""
+"els formats de diff combinats ('-c' and '--cc') no són admesos \n"
+"en el mode diff per directoris ('-d' and '--dir-diff')."
+
+#: builtin/difftool.c:634
+#, c-format
+msgid "both files modified: '%s' and '%s'."
+msgstr "s'han modificat ambdós fitxers: «%s» i «%s»."
+
+#: builtin/difftool.c:636
+msgid "working tree file has been left."
+msgstr "s'ha deixat un fitxer de l'arbre de treball."
+
+#: builtin/difftool.c:647
+#, c-format
+msgid "temporary files exist in '%s'."
+msgstr "existeix un fitxer temporal a «%s»."
+
+#: builtin/difftool.c:648
+msgid "you may want to cleanup or recover these."
+msgstr "podeu netejar o recuperar-los."
+
+#: builtin/difftool.c:697
+msgid "use `diff.guitool` instead of `diff.tool`"
+msgstr "utilitza `diff.guitool` en comptes de `diff.tool`"
+
+#: builtin/difftool.c:699
+msgid "perform a full-directory diff"
+msgstr "fes un diff de tot el directori"
+
+#: builtin/difftool.c:701
+msgid "do not prompt before launching a diff tool"
+msgstr "no preguntis abans d'executar l'eina diff"
+
+#: builtin/difftool.c:706
+msgid "use symlinks in dir-diff mode"
+msgstr "utilitza enllaços simbòlics en mode dir-diff"
+
+#: builtin/difftool.c:707
+msgid "tool"
+msgstr "eina"
+
+#: builtin/difftool.c:708
+msgid "use the specified diff tool"
+msgstr "utilitza l'eina de diff especificada"
+
+#: builtin/difftool.c:710
+msgid "print a list of diff tools that may be used with `--tool`"
+msgstr ""
+"imprimeix una llista de totes les eines diff que podeu usar amb `--tool`"
+
+#: builtin/difftool.c:713
+msgid ""
+"make 'git-difftool' exit when an invoked diff tool returns a non - zero exit "
+"code"
+msgstr ""
+"fes que 'git-difftool' surti quan l'eina de diff invocada torna un codi de "
+"sortida diferent de zero"
+
+#: builtin/difftool.c:716
+msgid "specify a custom command for viewing diffs"
+msgstr "especifiqueu un ordre personalitzat per veure diffs"
+
+#: builtin/difftool.c:717
+msgid "passed to `diff`"
+msgstr "passa-ho a «diff»"
+
+#: builtin/difftool.c:732
+msgid "difftool requires worktree or --no-index"
+msgstr "difftool requereix worktree o --no-index"
+
+#: builtin/difftool.c:739
+msgid "--dir-diff is incompatible with --no-index"
+msgstr "--dir-diff és incompatible amb --no-index"
+
+#: builtin/difftool.c:742
+msgid "--gui, --tool and --extcmd are mutually exclusive"
+msgstr "--gui, --tool and --extcmd són mútuament excloents"
+
+#: builtin/difftool.c:750
+msgid "no <tool> given for --tool=<tool>"
+msgstr "no s'ha proporcionat <tool> per --tool=<tool>"
+
+#: builtin/difftool.c:757
+msgid "no <cmd> given for --extcmd=<cmd>"
+msgstr "no s'ha proporcionat <cmd> per --extcmd=<cmd>"
+
+#: builtin/env--helper.c:6
+msgid "git env--helper --type=[bool|ulong] <options> <env-var>"
+msgstr "git env--helper --type=[bool|ulong] <opcions> <env-var>"
+
+#: builtin/env--helper.c:37 builtin/hash-object.c:98
+msgid "type"
+msgstr "tipus"
+
+#: builtin/env--helper.c:41
+msgid "default for git_env_*(...) to fall back on"
+msgstr ""
+
+#: builtin/env--helper.c:43
+msgid "be quiet only use git_env_*() value as exit code"
+msgstr ""
+
+#: builtin/env--helper.c:62
+#, c-format
+msgid "option `--default' expects a boolean value with `--type=bool`, not `%s`"
+msgstr ""
+
+#: builtin/env--helper.c:77
+#, c-format
+msgid ""
+"option `--default' expects an unsigned long value with `--type=ulong`, not `"
+"%s`"
+msgstr ""
+
+#: builtin/fast-export.c:29
+msgid "git fast-export [rev-list-opts]"
+msgstr "git fast-export [opcions-de-llista-de-revisions]"
+
+#: builtin/fast-export.c:852
+msgid "Error: Cannot export nested tags unless --mark-tags is specified."
+msgstr ""
+
+#: builtin/fast-export.c:1152
+msgid "show progress after <n> objects"
+msgstr "mostra el progrés després de <n> objectes"
+
+#: builtin/fast-export.c:1154
+msgid "select handling of signed tags"
+msgstr "selecciona la gestió de les etiquetes signades"
+
+#: builtin/fast-export.c:1157
+msgid "select handling of tags that tag filtered objects"
+msgstr "selecciona la gestió de les etiquetes que etiquetin objectes filtrats"
+
+#: builtin/fast-export.c:1160
+#, fuzzy
+msgid "select handling of commit messages in an alternate encoding"
+msgstr "selecciona la gestió de les etiquetes que etiquetin objectes filtrats"
+
+#: builtin/fast-export.c:1163
+msgid "Dump marks to this file"
+msgstr "Bolca les marques a aquest fitxer"
+
+#: builtin/fast-export.c:1165
+msgid "Import marks from this file"
+msgstr "Importa les marques d'aquest fitxer"
+
+#: builtin/fast-export.c:1169
+#, fuzzy
+msgid "Import marks from this file if it exists"
+msgstr "Importa les marques d'aquest fitxer"
+
+#: builtin/fast-export.c:1171
+msgid "Fake a tagger when tags lack one"
+msgstr "Fingeix un etiquetador quan els en manca un a les etiquetes"
+
+#: builtin/fast-export.c:1173
+msgid "Output full tree for each commit"
+msgstr "Imprimeix l'arbre complet de cada comissió"
+
+#: builtin/fast-export.c:1175
+msgid "Use the done feature to terminate the stream"
+msgstr "Usa la característica done per a acabar el corrent"
+
+#: builtin/fast-export.c:1176
+msgid "Skip output of blob data"
+msgstr "Omet l'emissió de dades de blob"
+
+#: builtin/fast-export.c:1177 builtin/log.c:1705
+msgid "refspec"
+msgstr "especificació de referència"
+
+#: builtin/fast-export.c:1178
+msgid "Apply refspec to exported refs"
+msgstr "Aplica l'especificació de referència a les referències exportades"
+
+#: builtin/fast-export.c:1179
+msgid "anonymize output"
+msgstr "anonimitza la sortida"
+
+#: builtin/fast-export.c:1181
+msgid "Reference parents which are not in fast-export stream by object id"
+msgstr ""
+
+#: builtin/fast-export.c:1183
+msgid "Show original object ids of blobs/commits"
+msgstr ""
+
+#: builtin/fast-export.c:1185
+msgid "Label tags with mark ids"
+msgstr ""
+
+#: builtin/fast-export.c:1220
+msgid "Cannot pass both --import-marks and --import-marks-if-exists"
+msgstr ""
+
+#: builtin/fetch.c:34
+msgid "git fetch [<options>] [<repository> [<refspec>...]]"
+msgstr "git fetch [<opcions>] [<dipòsit> [<especificació-de-referència>...]]"
+
+#: builtin/fetch.c:35
+msgid "git fetch [<options>] <group>"
+msgstr "git fetch [<opcions>] <grup>"
+
+#: builtin/fetch.c:36
+msgid "git fetch --multiple [<options>] [(<repository> | <group>)...]"
+msgstr "git fetch --multiple [<opcions>] [(<dipòsit> | <grup>)...]"
+
+#: builtin/fetch.c:37
+msgid "git fetch --all [<options>]"
+msgstr "git fetch --all [<opcions>]"
+
+#: builtin/fetch.c:116
+msgid "fetch.parallel cannot be negative"
+msgstr ""
+
+#: builtin/fetch.c:139 builtin/pull.c:204
+msgid "fetch from all remotes"
+msgstr "obtén de tots els remots"
+
+#: builtin/fetch.c:141 builtin/pull.c:248
+#, fuzzy
+msgid "set upstream for git pull/fetch"
+msgstr "estableix la font per a git pull/status"
+
+#: builtin/fetch.c:143 builtin/pull.c:207
+msgid "append to .git/FETCH_HEAD instead of overwriting"
+msgstr "annexa a .git/FETCH_HEAD en lloc de sobreescriure"
+
+#: builtin/fetch.c:145 builtin/pull.c:210
+msgid "path to upload pack on remote end"
+msgstr "camí al qual pujar el paquet al costat remot"
+
+#: builtin/fetch.c:146
+msgid "force overwrite of local reference"
+msgstr "força la sobreescriptura de la referència local"
+
+#: builtin/fetch.c:148
+msgid "fetch from multiple remotes"
+msgstr "obtén de múltiples remots"
+
+#: builtin/fetch.c:150 builtin/pull.c:214
+msgid "fetch all tags and associated objects"
+msgstr "obtén totes les etiquetes i tots els objectes associats"
+
+#: builtin/fetch.c:152
+msgid "do not fetch all tags (--no-tags)"
+msgstr "no obtinguis les etiquetes (--no-tags)"
+
+#: builtin/fetch.c:154
+msgid "number of submodules fetched in parallel"
+msgstr "nombre de submòduls obtinguts en paral·lel"
+
+#: builtin/fetch.c:156 builtin/pull.c:217
+msgid "prune remote-tracking branches no longer on remote"
+msgstr "poda les branques amb seguiment remot que ja no estiguin en el remot"
+
+#: builtin/fetch.c:158
+msgid "prune local tags no longer on remote and clobber changed tags"
+msgstr ""
+
+#: builtin/fetch.c:159 builtin/fetch.c:182 builtin/pull.c:141
+msgid "on-demand"
+msgstr "sota demanda"
+
+#: builtin/fetch.c:160
+msgid "control recursive fetching of submodules"
+msgstr "controla l'obtenció recursiva de submòduls"
+
+#: builtin/fetch.c:164 builtin/pull.c:225
+msgid "keep downloaded pack"
+msgstr "retén el paquet baixat"
+
+#: builtin/fetch.c:166
+msgid "allow updating of HEAD ref"
+msgstr "permet l'actualització de la referència HEAD"
+
+#: builtin/fetch.c:169 builtin/fetch.c:175 builtin/pull.c:228
+msgid "deepen history of shallow clone"
+msgstr "aprofundeix la història d'un clon superficial"
+
+#: builtin/fetch.c:171
+msgid "deepen history of shallow repository based on time"
+msgstr "aprofundeix la història d'un clon superficial basat en temps"
+
+#: builtin/fetch.c:177 builtin/pull.c:231
+msgid "convert to a complete repository"
+msgstr "converteix en un dipòsit complet"
+
+#: builtin/fetch.c:180
+msgid "prepend this to submodule path output"
+msgstr "anteposa això a la sortida de camí del submòdul"
+
+#: builtin/fetch.c:183
+msgid ""
+"default for recursive fetching of submodules (lower priority than config "
+"files)"
+msgstr ""
+"per defecte per a l'obtenció recursiva de submòduls (prioritat més baixa que "
+"els fitxers de configuració)"
+
+#: builtin/fetch.c:187 builtin/pull.c:234
+msgid "accept refs that update .git/shallow"
+msgstr "accepta les referències que actualitzin .git/shallow"
+
+#: builtin/fetch.c:188 builtin/pull.c:236
+msgid "refmap"
+msgstr "mapa de referències"
+
+#: builtin/fetch.c:189 builtin/pull.c:237
+msgid "specify fetch refmap"
+msgstr "mostra el mapa de referències d'obtenció"
+
+#: builtin/fetch.c:196
+msgid "report that we have only objects reachable from this object"
+msgstr ""
+
+#: builtin/fetch.c:199
+#, fuzzy
+msgid "run 'gc --auto' after fetching"
+msgstr "poda els remots després d'obtenir-los"
+
+#: builtin/fetch.c:201 builtin/pull.c:246
+msgid "check for forced-updates on all updated branches"
+msgstr ""
+
+#: builtin/fetch.c:203
+#, fuzzy
+msgid "write the commit-graph after fetching"
+msgstr "poda els remots després d'obtenir-los"
+
+#: builtin/fetch.c:513
+msgid "Couldn't find remote ref HEAD"
+msgstr "No s'ha pogut trobar la referència HEAD remota"
+
+#: builtin/fetch.c:653
+#, c-format
+msgid "configuration fetch.output contains invalid value %s"
+msgstr "la configuració fetch.output conté un valor no vàlid %s"
+
+#: builtin/fetch.c:751
+#, c-format
+msgid "object %s not found"
+msgstr "objecte %s no trobat"
+
+#: builtin/fetch.c:755
+msgid "[up to date]"
+msgstr "[al dia]"
+
+#: builtin/fetch.c:768 builtin/fetch.c:784 builtin/fetch.c:856
+msgid "[rejected]"
+msgstr "[rebutjat]"
+
+#: builtin/fetch.c:769
+msgid "can't fetch in current branch"
+msgstr "no es pot obtenir en la branca actual"
+
+#: builtin/fetch.c:779
+msgid "[tag update]"
+msgstr "[actualització d'etiqueta]"
+
+#: builtin/fetch.c:780 builtin/fetch.c:817 builtin/fetch.c:839
+#: builtin/fetch.c:851
+msgid "unable to update local ref"
+msgstr "no s'ha pogut actualitzar la referència local"
+
+#: builtin/fetch.c:784
+msgid "would clobber existing tag"
+msgstr ""
+
+#: builtin/fetch.c:806
+msgid "[new tag]"
+msgstr "[etiqueta nova]"
+
+#: builtin/fetch.c:809
+msgid "[new branch]"
+msgstr "[branca nova]"
+
+#: builtin/fetch.c:812
+msgid "[new ref]"
+msgstr "[referència nova]"
+
+#: builtin/fetch.c:851
+msgid "forced update"
+msgstr "actualització forçada"
+
+#: builtin/fetch.c:856
+msgid "non-fast-forward"
+msgstr "sense avanç ràpid"
+
+#: builtin/fetch.c:877
+msgid ""
+"Fetch normally indicates which branches had a forced update,\n"
+"but that check has been disabled. To re-enable, use '--show-forced-updates'\n"
+"flag or run 'git config fetch.showForcedUpdates true'."
+msgstr ""
+
+#: builtin/fetch.c:881
+#, c-format
+msgid ""
+"It took %.2f seconds to check forced updates. You can use\n"
+"'--no-show-forced-updates' or run 'git config fetch.showForcedUpdates "
+"false'\n"
+" to avoid this check.\n"
+msgstr ""
+
+#: builtin/fetch.c:911
+#, c-format
+msgid "%s did not send all necessary objects\n"
+msgstr "%s no ha enviat tots els objectes necessaris\n"
+
+#: builtin/fetch.c:932
+#, c-format
+msgid "reject %s because shallow roots are not allowed to be updated"
+msgstr ""
+"rebutja %s perquè no es permet que les arrels superficials s'actualitzin"
+
+#: builtin/fetch.c:1017 builtin/fetch.c:1155
+#, c-format
+msgid "From %.*s\n"
+msgstr "De %.*s\n"
+
+#: builtin/fetch.c:1028
+#, c-format
+msgid ""
+"some local refs could not be updated; try running\n"
+" 'git remote prune %s' to remove any old, conflicting branches"
+msgstr ""
+"algunes referències locals no s'han pogut actualitzar;\n"
+" intenteu executar 'git remote prune %s' per a eliminar\n"
+" qualsevol branca antiga o conflictiva"
+
+#: builtin/fetch.c:1125
+#, c-format
+msgid "   (%s will become dangling)"
+msgstr "   (%s es tornarà penjant)"
+
+#: builtin/fetch.c:1126
+#, c-format
+msgid "   (%s has become dangling)"
+msgstr "   (%s s'ha tornat penjant)"
+
+#: builtin/fetch.c:1158
+msgid "[deleted]"
+msgstr "[suprimit]"
+
+#: builtin/fetch.c:1159 builtin/remote.c:1035
+msgid "(none)"
+msgstr "(cap)"
+
+#: builtin/fetch.c:1182
+#, c-format
+msgid "Refusing to fetch into current branch %s of non-bare repository"
+msgstr "S'està refusant obtenir en la branca actual %s d'un dipòsit no nu"
+
+#: builtin/fetch.c:1201
+#, c-format
+msgid "Option \"%s\" value \"%s\" is not valid for %s"
+msgstr "L'opció «%s» amb valor «%s» no és vàlida per a %s"
+
+#: builtin/fetch.c:1204
+#, c-format
+msgid "Option \"%s\" is ignored for %s\n"
+msgstr "S'ignora l'opció «%s» per a %s\n"
+
+#: builtin/fetch.c:1412
+msgid "multiple branches detected, incompatible with --set-upstream"
+msgstr ""
+
+#: builtin/fetch.c:1427
+#, fuzzy
+msgid "not setting upstream for a remote remote-tracking branch"
+msgstr "la branca font «%s» no s'emmagatzema com a branca amb seguiment remot"
+
+#: builtin/fetch.c:1429
+#, fuzzy
+msgid "not setting upstream for a remote tag"
+msgstr "estableix la font per a git pull/status"
+
+#: builtin/fetch.c:1431
+#, fuzzy
+msgid "unknown branch type"
+msgstr "tipus d'objecte desconegut %d"
+
+#: builtin/fetch.c:1433
+msgid ""
+"no source branch found.\n"
+"you need to specify exactly one branch with the --set-upstream option."
+msgstr ""
+
+#: builtin/fetch.c:1559 builtin/fetch.c:1622
+#, c-format
+msgid "Fetching %s\n"
+msgstr "S'està obtenint %s\n"
+
+#: builtin/fetch.c:1569 builtin/fetch.c:1624 builtin/remote.c:100
+#, c-format
+msgid "Could not fetch %s"
+msgstr "No s'ha pogut obtenir %s"
+
+#: builtin/fetch.c:1581
+#, fuzzy, c-format
+msgid "could not fetch '%s' (exit code: %d)\n"
+msgstr "no s'ha pogut establir «%s» a «%s»"
+
+#: builtin/fetch.c:1684
+msgid ""
+"No remote repository specified.  Please, specify either a URL or a\n"
+"remote name from which new revisions should be fetched."
+msgstr ""
+"Cap dipòsit remot especificat. Especifiqueu un URL o\n"
+"un nom remot del qual es deuen obtenir les revisions noves."
+
+#: builtin/fetch.c:1721
+msgid "You need to specify a tag name."
+msgstr "Necessiteu especificar un nom d'etiqueta."
+
+#: builtin/fetch.c:1771
+msgid "Negative depth in --deepen is not supported"
+msgstr "No s'admet una profunditat negativa en --deepen"
+
+#: builtin/fetch.c:1773
+msgid "--deepen and --depth are mutually exclusive"
+msgstr "--deepen i --depth són mútuament excloents"
+
+#: builtin/fetch.c:1778
+msgid "--depth and --unshallow cannot be used together"
+msgstr "--depth i --unshallow no es poden usar junts"
+
+#: builtin/fetch.c:1780
+msgid "--unshallow on a complete repository does not make sense"
+msgstr "--unshallow en un dipòsit complet no té sentit"
+
+#: builtin/fetch.c:1796
+msgid "fetch --all does not take a repository argument"
+msgstr "fetch --all no accepta un paràmetre de dipòsit"
+
+#: builtin/fetch.c:1798
+msgid "fetch --all does not make sense with refspecs"
+msgstr "fetch --all no té sentit amb especificacions de referència"
+
+#: builtin/fetch.c:1807
+#, c-format
+msgid "No such remote or remote group: %s"
+msgstr "No existeix un remot ni un grup remot: %s"
+
+#: builtin/fetch.c:1814
+msgid "Fetching a group and specifying refspecs does not make sense"
+msgstr "Obtenir un grup i especificar referències no té sentit"
+
+#: builtin/fetch.c:1832
+msgid ""
+"--filter can only be used with the remote configured in extensions."
+"partialclone"
+msgstr ""
+
+#: builtin/fmt-merge-msg.c:18
+msgid ""
+"git fmt-merge-msg [-m <message>] [--log[=<n>] | --no-log] [--file <file>]"
+msgstr ""
+"git fmt-merge-msg [-m <missatge>] [--log[=<n>] | --no-log] [--file <fitxer>]"
+
+#: builtin/fmt-merge-msg.c:674
+msgid "populate log with at most <n> entries from shortlog"
+msgstr "emplena el registre amb <n> entrades del registre curt com a màxim"
+
+#: builtin/fmt-merge-msg.c:677
+msgid "alias for --log (deprecated)"
+msgstr "àlies per --log (en desús)"
+
+#: builtin/fmt-merge-msg.c:680
+msgid "text"
+msgstr "text"
+
+#: builtin/fmt-merge-msg.c:681
+msgid "use <text> as start of message"
+msgstr "usa <text> com a inici de missatge"
+
+#: builtin/fmt-merge-msg.c:682
+msgid "file to read from"
+msgstr "fitxer del qual llegir"
+
+#: builtin/for-each-ref.c:10
+msgid "git for-each-ref [<options>] [<pattern>]"
+msgstr "git for-each-ref [<opcions>] [<patró>]"
+
+#: builtin/for-each-ref.c:11
+msgid "git for-each-ref [--points-at <object>]"
+msgstr "git for-each-ref [--points-at <objecte>]"
+
+#: builtin/for-each-ref.c:12
+msgid "git for-each-ref [(--merged | --no-merged) [<commit>]]"
+msgstr "git for-each-ref [(--merged | --no-merged) [<comissió>]]"
+
+#: builtin/for-each-ref.c:13
+msgid "git for-each-ref [--contains [<commit>]] [--no-contains [<commit>]]"
+msgstr ""
+"git for-each-ref [--contains [<comissió>]] [--no-contains [<comissió>]]"
+
+#: builtin/for-each-ref.c:28
+msgid "quote placeholders suitably for shells"
+msgstr ""
+"posa els marcadors de posició de forma adequada per a intèrprets d'ordres"
+
+#: builtin/for-each-ref.c:30
+msgid "quote placeholders suitably for perl"
+msgstr "posa els marcadors de posició entre cometes adequades per al perl"
+
+#: builtin/for-each-ref.c:32
+msgid "quote placeholders suitably for python"
+msgstr "posa els marcadors de posició entre cometes adequades per al python"
+
+#: builtin/for-each-ref.c:34
+msgid "quote placeholders suitably for Tcl"
+msgstr "posa els marcadors de posició entre cometes adequades per al Tcl"
+
+#: builtin/for-each-ref.c:37
+msgid "show only <n> matched refs"
+msgstr "mostra només <n> referències coincidents"
+
+#: builtin/for-each-ref.c:39 builtin/tag.c:439
+msgid "respect format colors"
+msgstr "respecta els colors del format"
+
+#: builtin/for-each-ref.c:42
+msgid "print only refs which points at the given object"
+msgstr "imprimeix només les referències que assenyalin l'objecte donat"
+
+#: builtin/for-each-ref.c:44
+msgid "print only refs that are merged"
+msgstr "imprimeix només les referències que s'han fusionat"
+
+#: builtin/for-each-ref.c:45
+msgid "print only refs that are not merged"
+msgstr "imprimeix només les referències que no s'han fusionat"
+
+#: builtin/for-each-ref.c:46
+msgid "print only refs which contain the commit"
+msgstr "imprimeix només les referències que continguin la comissió"
+
+#: builtin/for-each-ref.c:47
+msgid "print only refs which don't contain the commit"
+msgstr "imprimeix només les referències que no continguin la comissió"
+
+#: builtin/fsck.c:68 builtin/fsck.c:147 builtin/fsck.c:148
+msgid "unknown"
+msgstr "desconegut"
+
+#. TRANSLATORS: e.g. error in tree 01bfda: <more explanation>
+#: builtin/fsck.c:100 builtin/fsck.c:120
+#, c-format
+msgid "error in %s %s: %s"
+msgstr "error en %s %s: %s"
+
+#. TRANSLATORS: e.g. warning in tree 01bfda: <more explanation>
+#: builtin/fsck.c:114
+#, c-format
+msgid "warning in %s %s: %s"
+msgstr ""
+
+#: builtin/fsck.c:143 builtin/fsck.c:146
+#, c-format
+msgid "broken link from %7s %s"
+msgstr ""
+
+#: builtin/fsck.c:155
+msgid "wrong object type in link"
+msgstr "tipus d'objecte incorrecte en l'enllaç"
+
+#: builtin/fsck.c:171
+#, c-format
+msgid ""
+"broken link from %7s %s\n"
+"              to %7s %s"
+msgstr ""
+
+#: builtin/fsck.c:282
+#, c-format
+msgid "missing %s %s"
+msgstr "manca %s %s"
+
+#: builtin/fsck.c:309
+#, c-format
+msgid "unreachable %s %s"
+msgstr "inabastable %s %s"
+
+#: builtin/fsck.c:329
+#, fuzzy, c-format
+msgid "dangling %s %s"
+msgstr "S'estan actualitzant %s..%s\n"
+
+#: builtin/fsck.c:339
+#, fuzzy
+msgid "could not create lost-found"
+msgstr "no s'ha pogut crear el fitxer «%s»"
+
+#: builtin/fsck.c:350
+#, c-format
+msgid "could not finish '%s'"
+msgstr "no s'ha pogut finalitzar «%s»"
+
+#: builtin/fsck.c:367
+#, c-format
+msgid "Checking %s"
+msgstr "S'està comprovant %s"
+
+#: builtin/fsck.c:405
+#, c-format
+msgid "Checking connectivity (%d objects)"
+msgstr "S'està comprovant la connectivitat (%d objectes)"
+
+#: builtin/fsck.c:424
+#, c-format
+msgid "Checking %s %s"
+msgstr "S'està comprovant %s %s"
+
+#: builtin/fsck.c:429
+msgid "broken links"
+msgstr "enllaços trencats"
+
+#: builtin/fsck.c:438
+#, c-format
+msgid "root %s"
+msgstr "arrel %s"
+
+#: builtin/fsck.c:446
+#, c-format
+msgid "tagged %s %s (%s) in %s"
+msgstr ""
+
+#: builtin/fsck.c:475
+#, c-format
+msgid "%s: object corrupt or missing"
+msgstr "%s: objecte corrupte o no trobat"
+
+#: builtin/fsck.c:500
+#, c-format
+msgid "%s: invalid reflog entry %s"
+msgstr " %s: entrada de referència no vàlida %s"
+
+#: builtin/fsck.c:514
+#, fuzzy, c-format
+msgid "Checking reflog %s->%s"
+msgstr "S'està comprovant el canvi de nom de «%s» a «%s»\n"
+
+#: builtin/fsck.c:548
+#, c-format
+msgid "%s: invalid sha1 pointer %s"
+msgstr "%s: punter sha1 no vàlid: %s"
+
+#: builtin/fsck.c:555
+#, c-format
+msgid "%s: not a commit"
+msgstr "%s: no és una comissió"
+
+#: builtin/fsck.c:609
+msgid "notice: No default references"
+msgstr "avís: no hi ha referències per defecte"
+
+#: builtin/fsck.c:624
+#, c-format
+msgid "%s: object corrupt or missing: %s"
+msgstr "%s: objecte corrupte o no trobat: %s"
+
+#: builtin/fsck.c:637
+#, c-format
+msgid "%s: object could not be parsed: %s"
+msgstr "%s: no s'ha pogut analitzar l'objecte: %s"
+
+#: builtin/fsck.c:657
+#, c-format
+msgid "bad sha1 file: %s"
+msgstr "fitxer sha1 malmès: %s"
+
+#: builtin/fsck.c:672
+msgid "Checking object directory"
+msgstr "S'està comprovant el directori d'objecte"
+
+#: builtin/fsck.c:675
+msgid "Checking object directories"
+msgstr "S'estan comprovant els directoris d'objecte"
+
+#: builtin/fsck.c:690
+#, c-format
+msgid "Checking %s link"
+msgstr "S'està comprovant l'enllaç %s"
+
+#: builtin/fsck.c:695 builtin/index-pack.c:842
+#, c-format
+msgid "invalid %s"
+msgstr "%s no vàlid"
+
+#: builtin/fsck.c:702
+#, fuzzy, c-format
+msgid "%s points to something strange (%s)"
+msgstr "%s - no és una cosa que puguem fusionar"
+
+#: builtin/fsck.c:708
+#, c-format
+msgid "%s: detached HEAD points at nothing"
+msgstr ""
+
+#: builtin/fsck.c:712
+#, c-format
+msgid "notice: %s points to an unborn branch (%s)"
+msgstr ""
+
+#: builtin/fsck.c:724
+msgid "Checking cache tree"
+msgstr "S'està comprovant l'arbre de la memòria cau"
+
+#: builtin/fsck.c:729
+#, fuzzy, c-format
+msgid "%s: invalid sha1 pointer in cache-tree"
+msgstr "S'ha produït un error en actualitzar l'arbre principal de memòria cau"
+
+#: builtin/fsck.c:738
+msgid "non-tree in cache-tree"
+msgstr ""
+
+#: builtin/fsck.c:769
+msgid "git fsck [<options>] [<object>...]"
+msgstr "git fsck [<opcions>] [<objecte>...]"
+
+#: builtin/fsck.c:775
+msgid "show unreachable objects"
+msgstr "mostra els objectes inabastables"
+
+#: builtin/fsck.c:776
+msgid "show dangling objects"
+msgstr "mostra els objectes penjants"
+
+#: builtin/fsck.c:777
+msgid "report tags"
+msgstr "informa de les etiquetes"
+
+#: builtin/fsck.c:778
+msgid "report root nodes"
+msgstr "informa dels nodes d'arrel"
+
+#: builtin/fsck.c:779
+msgid "make index objects head nodes"
+msgstr "fes els objectes d'índex nodes de cap"
+
+#: builtin/fsck.c:780
+msgid "make reflogs head nodes (default)"
+msgstr "fes que els registres de referències siguin nodes de cap (per defecte)"
+
+#: builtin/fsck.c:781
+msgid "also consider packs and alternate objects"
+msgstr "també considera els paquets i els objectes alternatius"
+
+#: builtin/fsck.c:782
+msgid "check only connectivity"
+msgstr "comprova només la connectivitat"
+
+#: builtin/fsck.c:783
+msgid "enable more strict checking"
+msgstr "habilita la comprovació més estricta"
+
+#: builtin/fsck.c:785
+msgid "write dangling objects in .git/lost-found"
+msgstr "escriu objectes penjants a .git/lost-found"
+
+#: builtin/fsck.c:786 builtin/prune.c:132
+msgid "show progress"
+msgstr "mostra el progrés"
+
+#: builtin/fsck.c:787
+msgid "show verbose names for reachable objects"
+msgstr "mostra els noms detallats dels objectes abastables"
+
+#: builtin/fsck.c:846 builtin/index-pack.c:225
+msgid "Checking objects"
+msgstr "S'estan comprovant els objectes"
+
+#: builtin/fsck.c:874
+#, fuzzy, c-format
+msgid "%s: object missing"
+msgstr "mostra la mida de l'objecte"
+
+#: builtin/fsck.c:885
+#, fuzzy, c-format
+msgid "invalid parameter: expected sha1, got '%s'"
+msgstr "s'esperava shallow/unshallow, s'ha rebut %s"
+
+#: builtin/gc.c:35
+msgid "git gc [<options>]"
+msgstr "git gc [<opcions>]"
+
+#: builtin/gc.c:90
+#, c-format
+msgid "Failed to fstat %s: %s"
+msgstr "S'ha produït un error en fer fstat %s: %s"
+
+#: builtin/gc.c:126
+#, fuzzy, c-format
+msgid "failed to parse '%s' value '%s'"
+msgstr "s'ha produït un error en moure «%s» a «%s»"
+
+#: builtin/gc.c:475 builtin/init-db.c:55
+#, c-format
+msgid "cannot stat '%s'"
+msgstr "no es pot fer stat en «%s»"
+
+#: builtin/gc.c:484 builtin/notes.c:240 builtin/tag.c:529
+#, c-format
+msgid "cannot read '%s'"
+msgstr "no es pot llegir «%s»"
+
+#: builtin/gc.c:491
+#, c-format
+msgid ""
+"The last gc run reported the following. Please correct the root cause\n"
+"and remove %s.\n"
+"Automatic cleanup will not be performed until the file is removed.\n"
+"\n"
+"%s"
+msgstr ""
+"L'última execució de gc ha informat el següent. Corregiu\n"
+"la causa primordial i elimineu %s.\n"
+"No es realitzarà la neteja automàtica fins que s'elimini el fitxer.\n"
+"\n"
+"%s"
+
+#: builtin/gc.c:539
+msgid "prune unreferenced objects"
+msgstr "poda objectes sense referència"
+
+#: builtin/gc.c:541
+msgid "be more thorough (increased runtime)"
+msgstr "sigues més exhaustiu (el temps d'execució augmenta)"
+
+#: builtin/gc.c:542
+msgid "enable auto-gc mode"
+msgstr "habilita el mode de recollida d'escombraries automàtica"
+
+#: builtin/gc.c:545
+msgid "force running gc even if there may be another gc running"
+msgstr "força l'execució de gc encara que hi pugui haver un altre gc executant"
+
+#: builtin/gc.c:548
+msgid "repack all other packs except the largest pack"
+msgstr ""
+
+#: builtin/gc.c:565
+#, fuzzy, c-format
+msgid "failed to parse gc.logexpiry value %s"
+msgstr "No s'ha pogut analitzar el valor gc.logexpiry %s"
+
+#: builtin/gc.c:576
+#, fuzzy, c-format
+msgid "failed to parse prune expiry value %s"
+msgstr "No s'ha pogut analitzar el valor gc.logexpiry %s"
+
+#: builtin/gc.c:596
+#, c-format
+msgid "Auto packing the repository in background for optimum performance.\n"
+msgstr ""
+"S'està empaquetant el dipòsit automàticament en el rerefons per a un "
+"rendiment òptim.\n"
+
+#: builtin/gc.c:598
+#, c-format
+msgid "Auto packing the repository for optimum performance.\n"
+msgstr ""
+"S'està empaquetant automàticament el dipòsit per a un rendiment òptim.\n"
+
+#: builtin/gc.c:599
+#, c-format
+msgid "See \"git help gc\" for manual housekeeping.\n"
+msgstr "Vegeu «git help gc» per a neteja manual.\n"
+
+#: builtin/gc.c:639
+#, c-format
+msgid ""
+"gc is already running on machine '%s' pid %<PRIuMAX> (use --force if not)"
+msgstr ""
+"gc ja s'està executant en la màquina «%s» pid %<PRIuMAX> (useu --force si no)"
+
+#: builtin/gc.c:694
+msgid ""
+"There are too many unreachable loose objects; run 'git prune' to remove them."
+msgstr ""
+"Hi ha massa objectes solts inabastables; executeu 'git prune' per a eliminar-"
+"los."
+
+#: builtin/grep.c:29
+msgid "git grep [<options>] [-e] <pattern> [<rev>...] [[--] <path>...]"
+msgstr "git grep [<opcions>] [-e] <patró> [<revisió>...] [[--] <camí>...]"
+
+#: builtin/grep.c:225
+#, c-format
+msgid "grep: failed to create thread: %s"
+msgstr "grep: s'ha produït un error en crear fil: %s"
+
+#: builtin/grep.c:279
+#, c-format
+msgid "invalid number of threads specified (%d) for %s"
+msgstr "s'ha especificat un nombre de fils no vàlid (%d) per a %s"
+
+#. TRANSLATORS: %s is the configuration
+#. variable for tweaking threads, currently
+#. grep.threads
+#.
+#: builtin/grep.c:287 builtin/index-pack.c:1534 builtin/index-pack.c:1727
+#: builtin/pack-objects.c:2708
+#, c-format
+msgid "no threads support, ignoring %s"
+msgstr "no hi ha suport de fils, s'està ignorant %s"
+
+#: builtin/grep.c:467 builtin/grep.c:592 builtin/grep.c:635
+#, c-format
+msgid "unable to read tree (%s)"
+msgstr "no s'ha pogut llegir l'arbre (%s)"
+
+#: builtin/grep.c:650
+#, c-format
+msgid "unable to grep from object of type %s"
+msgstr "no es pot fer grep des d'un objecte de tipus %s"
+
+#: builtin/grep.c:716
+#, c-format
+msgid "switch `%c' expects a numerical value"
+msgstr "l'opció «%c» espera un valor numèric"
+
+#: builtin/grep.c:815
+msgid "search in index instead of in the work tree"
+msgstr "cerca en l'índex en lloc de l'arbre de treball"
+
+#: builtin/grep.c:817
+msgid "find in contents not managed by git"
+msgstr "cerca en continguts no gestionats per git"
+
+#: builtin/grep.c:819
+msgid "search in both tracked and untracked files"
+msgstr "cerca tant en fitxers seguits com en no seguits"
+
+#: builtin/grep.c:821
+msgid "ignore files specified via '.gitignore'"
+msgstr "ignora els fitxers especificats mitjançant '.gitignore'"
+
+#: builtin/grep.c:823
+msgid "recursively search in each submodule"
+msgstr "cerca recursivament a cada submòdul"
+
+#: builtin/grep.c:826
+msgid "show non-matching lines"
+msgstr "mostra les línies no coincidents"
+
+#: builtin/grep.c:828
+msgid "case insensitive matching"
+msgstr "coincidència insensible a majúscula i minúscula"
+
+#: builtin/grep.c:830
+msgid "match patterns only at word boundaries"
+msgstr "coincideix amb els patrons només als límits de paraula"
+
+#: builtin/grep.c:832
+msgid "process binary files as text"
+msgstr "processa els fitxers binaris com a text"
+
+#: builtin/grep.c:834
+msgid "don't match patterns in binary files"
+msgstr "no coincideixis amb els patrons en els fitxers binaris"
+
+#: builtin/grep.c:837
+msgid "process binary files with textconv filters"
+msgstr "processa els fitxers binaris amb filtres de textconv"
+
+#: builtin/grep.c:839
+msgid "search in subdirectories (default)"
+msgstr "cerca als subdirectories (per defecte)"
+
+#: builtin/grep.c:841
+msgid "descend at most <depth> levels"
+msgstr "descendeix com a màxim <profunditat> nivells"
+
+#: builtin/grep.c:845
+msgid "use extended POSIX regular expressions"
+msgstr "usa les expressions regulars POSIX ampliades"
+
+#: builtin/grep.c:848
+msgid "use basic POSIX regular expressions (default)"
+msgstr "usa les expressions regulars POSIX bàsiques (per defecte)"
+
+#: builtin/grep.c:851
+msgid "interpret patterns as fixed strings"
+msgstr "interpreta els patrons com a cadenes fixes"
+
+#: builtin/grep.c:854
+msgid "use Perl-compatible regular expressions"
+msgstr "usa les expressions regulars compatibles amb Perl"
+
+#: builtin/grep.c:857
+msgid "show line numbers"
+msgstr "mostra els números de línia"
+
+#: builtin/grep.c:858
+msgid "show column number of first match"
+msgstr "mostra el nombre de columna de la primera coincidència"
+
+#: builtin/grep.c:859
+msgid "don't show filenames"
+msgstr "no mostris els noms de fitxer"
+
+#: builtin/grep.c:860
+msgid "show filenames"
+msgstr "mostra els noms de fitxer"
+
+#: builtin/grep.c:862
+msgid "show filenames relative to top directory"
+msgstr "mostra els noms de fitxer relatius al directori superior"
+
+#: builtin/grep.c:864
+msgid "show only filenames instead of matching lines"
+msgstr "mostra només els noms de fitxer en lloc de les línies coincidents"
+
+#: builtin/grep.c:866
+msgid "synonym for --files-with-matches"
+msgstr "sinònim de --files-with-matches"
+
+#: builtin/grep.c:869
+msgid "show only the names of files without match"
+msgstr "mostra només els noms dels fitxers sense coincidència"
+
+#: builtin/grep.c:871
+msgid "print NUL after filenames"
+msgstr "imprimeix NUL després dels noms de fitxer"
+
+#: builtin/grep.c:874
+msgid "show only matching parts of a line"
+msgstr "mostra només les parts de coincidents de la línia"
+
+#: builtin/grep.c:876
+msgid "show the number of matches instead of matching lines"
+msgstr "mostra el nombre de coincidències en lloc de les línies coincidents"
+
+#: builtin/grep.c:877
+msgid "highlight matches"
+msgstr "ressalta les coincidències"
+
+#: builtin/grep.c:879
+msgid "print empty line between matches from different files"
+msgstr "imprimeix una línia buida entre coincidències de fitxers distints"
+
+#: builtin/grep.c:881
+msgid "show filename only once above matches from same file"
+msgstr ""
+"mostra el nom de fitxer només una vegada a dalt de les coincidències del "
+"mateix fitxer"
+
+#: builtin/grep.c:884
+msgid "show <n> context lines before and after matches"
+msgstr "mostra <n> línies de context abans i després d'una coincidència"
+
+#: builtin/grep.c:887
+msgid "show <n> context lines before matches"
+msgstr "mostra <n> línies de context abans d'una coincidència"
+
+#: builtin/grep.c:889
+msgid "show <n> context lines after matches"
+msgstr "mostra <n> línies de context després d'una coincidència"
+
+#: builtin/grep.c:891
+msgid "use <n> worker threads"
+msgstr "usa <n> fils de treball"
+
+#: builtin/grep.c:892
+msgid "shortcut for -C NUM"
+msgstr "drecera per -C NUM"
+
+#: builtin/grep.c:895
+msgid "show a line with the function name before matches"
+msgstr "mostra una línia amb el nom de funció abans de les coincidències"
+
+#: builtin/grep.c:897
+msgid "show the surrounding function"
+msgstr "mostra la funció circumdant"
+
+#: builtin/grep.c:900
+msgid "read patterns from file"
+msgstr "llegeix els patrons des d'un fitxer"
+
+#: builtin/grep.c:902
+msgid "match <pattern>"
+msgstr "coincideix amb <patró>"
+
+#: builtin/grep.c:904
+msgid "combine patterns specified with -e"
+msgstr "combina els patrons especificats amb -e"
+
+#: builtin/grep.c:916
+msgid "indicate hit with exit status without output"
+msgstr "indica coincidència amb estat de sortida sense sortida textual"
+
+#: builtin/grep.c:918
+msgid "show only matches from files that match all patterns"
+msgstr ""
+"mostra només les coincidències dels fitxers que coincideixin amb tots els "
+"patrons"
+
+#: builtin/grep.c:920
+msgid "show parse tree for grep expression"
+msgstr "mostra l'arbre d'anàlisi de l'expressió grep"
+
+#: builtin/grep.c:924
+msgid "pager"
+msgstr "paginador"
+
+#: builtin/grep.c:924
+msgid "show matching files in the pager"
+msgstr "mostra els fitxers coincidents en el paginador"
+
+#: builtin/grep.c:928
+msgid "allow calling of grep(1) (ignored by this build)"
+msgstr "permet la invocació de grep(1) (ignorat per aquesta compilació)"
+
+#: builtin/grep.c:992
+msgid "no pattern given"
+msgstr "no s'ha donat cap patró"
+
+#: builtin/grep.c:1028
+msgid "--no-index or --untracked cannot be used with revs"
+msgstr "--no-index o --untracked no es pot usar amb revisions"
+
+#: builtin/grep.c:1036
+#, c-format
+msgid "unable to resolve revision: %s"
+msgstr "no s'ha pogut resoldre la revisió: %s"
+
+#: builtin/grep.c:1067
+msgid "invalid option combination, ignoring --threads"
+msgstr "combinació d'opcions no vàlida, s'està ignorant --threads"
+
+#: builtin/grep.c:1070 builtin/pack-objects.c:3400
+msgid "no threads support, ignoring --threads"
+msgstr "no hi ha suport de fils, s'està ignorant --threads"
+
+#: builtin/grep.c:1073 builtin/index-pack.c:1531 builtin/pack-objects.c:2705
+#, c-format
+msgid "invalid number of threads specified (%d)"
+msgstr "s'ha especificat un nombre de fils no vàlid (%d)"
+
+#: builtin/grep.c:1096
+msgid "--open-files-in-pager only works on the worktree"
+msgstr "--open-files-in-pager només funciona en l'arbre de treball"
+
+#: builtin/grep.c:1119
+msgid "option not supported with --recurse-submodules"
+msgstr "opció no admesa amb --recurse-submodules."
+
+#: builtin/grep.c:1125
+msgid "--cached or --untracked cannot be used with --no-index"
+msgstr "--cached o --untracked no es pot usar amb --no-index."
+
+#: builtin/grep.c:1131
+#, fuzzy
+msgid "--[no-]exclude-standard cannot be used for tracked contents"
+msgstr "--[no-]exclude-standard no es pot usar per als continguts seguits."
+
+#: builtin/grep.c:1139
+#, fuzzy
+msgid "both --cached and trees are given"
+msgstr "s'han donat ambdós --caches i arbres."
+
+#: builtin/hash-object.c:85
+msgid ""
+"git hash-object [-t <type>] [-w] [--path=<file> | --no-filters] [--stdin] "
+"[--] <file>..."
+msgstr ""
+"git hash-object [-t <tipus>] [-w] [--path=<fitxer> | --no-filters] [--stdin] "
+"[--] <fitxer>..."
+
+#: builtin/hash-object.c:86
+msgid "git hash-object  --stdin-paths"
+msgstr "git hash-object  --stdin-paths"
+
+#: builtin/hash-object.c:98
+msgid "object type"
+msgstr "tipus d'objecte"
+
+#: builtin/hash-object.c:99
+msgid "write the object into the object database"
+msgstr "escriu l'objecte a la base de dades d'objectes"
+
+#: builtin/hash-object.c:101
+msgid "read the object from stdin"
+msgstr "llegeix l'objecte des de stdin"
+
+#: builtin/hash-object.c:103
+msgid "store file as is without filters"
+msgstr "emmagatzema el fitxer tal com és sense filtres"
+
+#: builtin/hash-object.c:104
+msgid ""
+"just hash any random garbage to create corrupt objects for debugging Git"
+msgstr ""
+"només suma qualsevol brossa aleatòria per a crear objectes malmesos per a "
+"depurar al Git"
+
+#: builtin/hash-object.c:105
+msgid "process file as it were from this path"
+msgstr "processa el fitxer com si fos d'aquest camí"
+
+#: builtin/help.c:46
+msgid "print all available commands"
+msgstr "imprimeix totes les ordres disponibles"
+
+#: builtin/help.c:47
+msgid "exclude guides"
+msgstr "exclou guies"
+
+#: builtin/help.c:48
+msgid "print list of useful guides"
+msgstr "imprimeix la llista de guies útils"
+
+#: builtin/help.c:49
+#, fuzzy
+msgid "print all configuration variable names"
+msgstr "no es pot crear el fitxer de configuració %s"
+
+#: builtin/help.c:51
+msgid "show man page"
+msgstr "mostra la pàgina de manual"
+
+#: builtin/help.c:52
+msgid "show manual in web browser"
+msgstr "mostra la pàgina de manual en el navegador web"
+
+#: builtin/help.c:54
+msgid "show info page"
+msgstr "mostra la pàgina d'informació"
+
+#: builtin/help.c:56
+#, fuzzy
+msgid "print command description"
+msgstr "imprimeix els continguts de la comissió"
+
+#: builtin/help.c:61
+msgid "git help [--all] [--guides] [--man | --web | --info] [<command>]"
+msgstr "git help [--all] [--guides] [--man | --web | --info] [<ordre>]"
+
+#: builtin/help.c:77
+#, c-format
+msgid "unrecognized help format '%s'"
+msgstr "format d'ajuda no reconegut «%s»"
+
+#: builtin/help.c:104
+msgid "Failed to start emacsclient."
+msgstr "S'ha produït un error'ha produït un error en iniciar emacsclient."
+
+#: builtin/help.c:117
+msgid "Failed to parse emacsclient version."
+msgstr "S'ha produït un error en analitzar la versió d'emacsclient."
+
+#: builtin/help.c:125
+#, c-format
+msgid "emacsclient version '%d' too old (< 22)."
+msgstr "la versió d'emacsclient «%d» és massa vella (< 22)."
+
+#: builtin/help.c:143 builtin/help.c:165 builtin/help.c:175 builtin/help.c:183
+#, c-format
+msgid "failed to exec '%s'"
+msgstr "s'ha produït un error en executar «%s»"
+
+#: builtin/help.c:221
+#, c-format
+msgid ""
+"'%s': path for unsupported man viewer.\n"
+"Please consider using 'man.<tool>.cmd' instead."
+msgstr ""
+"«%s»: camí a un visualitzador de manuals no compatible.\n"
+"Considereu usar 'man.<eina>.cmd' en lloc d'això."
+
+#: builtin/help.c:233
+#, c-format
+msgid ""
+"'%s': cmd for supported man viewer.\n"
+"Please consider using 'man.<tool>.path' instead."
+msgstr ""
+"«%s»: ordre per a un visualitzador de manuals compatible.\n"
+"Considereu usar 'man.<eina>.path' en lloc d'això."
+
+#: builtin/help.c:350
+#, c-format
+msgid "'%s': unknown man viewer."
+msgstr "«%s»: visualitzador de manuals desconegut."
+
+#: builtin/help.c:367
+msgid "no man viewer handled the request"
+msgstr "cap visualitzador de manuals ha gestionat la sol·licitud"
+
+#: builtin/help.c:375
+msgid "no info viewer handled the request"
+msgstr "cap visualitzador d'informació ha gestionat la sol·licitud"
+
+#: builtin/help.c:434 builtin/help.c:445 git.c:336
+#, c-format
+msgid "'%s' is aliased to '%s'"
+msgstr "«%s» és un àlies de «%s»"
+
+#: builtin/help.c:448 git.c:365
+#, fuzzy, c-format
+msgid "bad alias.%s string: %s"
+msgstr "Cadena branch.%s.mergeoptions incorrecta: %s"
+
+#: builtin/help.c:477 builtin/help.c:507
+#, c-format
+msgid "usage: %s%s"
+msgstr "ús: %s%s"
+
+#: builtin/help.c:491
+msgid "'git help config' for more information"
+msgstr ""
+
+#: builtin/index-pack.c:185
+#, c-format
+msgid "object type mismatch at %s"
+msgstr "hi ha una discordança de tipus d'objecte a %s"
+
+#: builtin/index-pack.c:205
+#, c-format
+msgid "did not receive expected object %s"
+msgstr "no s'ha rebut l'objecte esperat %s"
+
+#: builtin/index-pack.c:208
+#, c-format
+msgid "object %s: expected type %s, found %s"
+msgstr "objecte %s: s'esperava el tipus %s, s'ha trobat %s"
+
+#: builtin/index-pack.c:258
+#, c-format
+msgid "cannot fill %d byte"
+msgid_plural "cannot fill %d bytes"
+msgstr[0] "no es pot omplir %d octet"
+msgstr[1] "no es pot omplir %d octets"
+
+#: builtin/index-pack.c:268
+msgid "early EOF"
+msgstr "EOF prematur"
+
+#: builtin/index-pack.c:269
+msgid "read error on input"
+msgstr "error de lectura d'entrada"
+
+#: builtin/index-pack.c:281
+msgid "used more bytes than were available"
+msgstr "s'han usat més octets que hi havia disponibles"
+
+#: builtin/index-pack.c:288 builtin/pack-objects.c:604
+msgid "pack too large for current definition of off_t"
+msgstr "paquet massa gran per a la definició actual d'off_t"
+
+#: builtin/index-pack.c:291 builtin/unpack-objects.c:95
+msgid "pack exceeds maximum allowed size"
+msgstr "el paquet supera la mida màxima permesa"
+
+#: builtin/index-pack.c:312
+#, c-format
+msgid "cannot open packfile '%s'"
+msgstr "no es pot obrir el fitxer de paquet «%s»"
+
+#: builtin/index-pack.c:326
+msgid "pack signature mismatch"
+msgstr "hi ha una discordança de signatura de paquet"
+
+#: builtin/index-pack.c:328
+#, c-format
+msgid "pack version %<PRIu32> unsupported"
+msgstr "la versió de paquet %<PRIu32> no és compatible"
+
+#: builtin/index-pack.c:346
+#, c-format
+msgid "pack has bad object at offset %<PRIuMAX>: %s"
+msgstr "el paquet té un objecte incorrecte a la posició %<PRIuMAX>: %s"
+
+#: builtin/index-pack.c:466
+#, c-format
+msgid "inflate returned %d"
+msgstr "la inflació ha retornat %d"
+
+#: builtin/index-pack.c:515
+msgid "offset value overflow for delta base object"
+msgstr ""
+"desbordament de valor de desplaçament per a l'objecte base de diferències"
+
+#: builtin/index-pack.c:523
+msgid "delta base offset is out of bound"
+msgstr "el desplaçament de base de diferències està fora de límits"
+
+#: builtin/index-pack.c:531
+#, c-format
+msgid "unknown object type %d"
+msgstr "tipus d'objecte desconegut %d"
+
+#: builtin/index-pack.c:562
+msgid "cannot pread pack file"
+msgstr "no es pot fer pread en el fitxer empaquetat"
+
+#: builtin/index-pack.c:564
+#, c-format
+msgid "premature end of pack file, %<PRIuMAX> byte missing"
+msgid_plural "premature end of pack file, %<PRIuMAX> bytes missing"
+msgstr[0] "el final del fitxer empaquetat és prematur, manca %<PRIuMAX> octet"
+msgstr[1] ""
+"el final del fitxer empaquetat és prematur, manquen %<PRIuMAX> octets"
+
+#: builtin/index-pack.c:590
+msgid "serious inflate inconsistency"
+msgstr "hi ha una inconsistència seriosa d'inflació"
+
+#: builtin/index-pack.c:735 builtin/index-pack.c:741 builtin/index-pack.c:764
+#: builtin/index-pack.c:803 builtin/index-pack.c:812
+#, c-format
+msgid "SHA1 COLLISION FOUND WITH %s !"
+msgstr "S'HA TROBAT UNA COL·LISIÓ SHA1 AMB %s !"
+
+#: builtin/index-pack.c:738 builtin/pack-objects.c:157
+#: builtin/pack-objects.c:217 builtin/pack-objects.c:311
+#, c-format
+msgid "unable to read %s"
+msgstr "no s'ha pogut llegir %s"
+
+#: builtin/index-pack.c:801
+#, c-format
+msgid "cannot read existing object info %s"
+msgstr "no es pot llegir la informació d'objecte existent %s"
+
+#: builtin/index-pack.c:809
+#, c-format
+msgid "cannot read existing object %s"
+msgstr "no es pot llegir l'objecte existent %s"
+
+#: builtin/index-pack.c:823
+#, c-format
+msgid "invalid blob object %s"
+msgstr "objecte de blob no vàlid %s"
+
+#: builtin/index-pack.c:826 builtin/index-pack.c:845
+#, fuzzy
+msgid "fsck error in packed object"
+msgstr "ignora els objectes empaquetats"
+
+#: builtin/index-pack.c:847
+#, c-format
+msgid "Not all child objects of %s are reachable"
+msgstr "No tots els objectes fills de %s són abastables"
+
+#: builtin/index-pack.c:919 builtin/index-pack.c:950
+msgid "failed to apply delta"
+msgstr "s'ha produït un error en aplicar la diferència"
+
+#: builtin/index-pack.c:1118
+msgid "Receiving objects"
+msgstr "S'estan rebent objectes"
+
+#: builtin/index-pack.c:1118
+msgid "Indexing objects"
+msgstr "S'estan indexant objectes"
+
+#: builtin/index-pack.c:1152
+msgid "pack is corrupted (SHA1 mismatch)"
+msgstr "el paquet és malmès (discordança SHA1)"
+
+#: builtin/index-pack.c:1157
+msgid "cannot fstat packfile"
+msgstr "no es pot fer fstat en el fitxer de paquet"
+
+#: builtin/index-pack.c:1160
+msgid "pack has junk at the end"
+msgstr "el paquet té brossa al seu final"
+
+#: builtin/index-pack.c:1172
+msgid "confusion beyond insanity in parse_pack_objects()"
+msgstr "confusió més enllà de la bogeria en parse_pack_objects()"
+
+#: builtin/index-pack.c:1195
+msgid "Resolving deltas"
+msgstr "S'estan resolent les diferències"
+
+#: builtin/index-pack.c:1205 builtin/pack-objects.c:2481
+#, c-format
+msgid "unable to create thread: %s"
+msgstr "no s'ha pogut crear fil: %s"
+
+#: builtin/index-pack.c:1246
+msgid "confusion beyond insanity"
+msgstr "confusió més enllà de la bogeria"
+
+#: builtin/index-pack.c:1252
+#, c-format
+msgid "completed with %d local object"
+msgid_plural "completed with %d local objects"
+msgstr[0] "s'ha completat amb %d objecte local"
+msgstr[1] "s'ha completat amb %d objectes locals"
+
+#: builtin/index-pack.c:1264
+#, c-format
+msgid "Unexpected tail checksum for %s (disk corruption?)"
+msgstr "Suma de verificació final no esperada per a %s (corrupció de disc?)"
+
+#: builtin/index-pack.c:1268
+#, c-format
+msgid "pack has %d unresolved delta"
+msgid_plural "pack has %d unresolved deltas"
+msgstr[0] "El paquet té %d diferència no resolta"
+msgstr[1] "El paquet té %d diferències no resoltes"
+
+#: builtin/index-pack.c:1292
+#, c-format
+msgid "unable to deflate appended object (%d)"
+msgstr "no s'ha pogut desinflar l'objecte annexat (%d)"
+
+#: builtin/index-pack.c:1388
+#, c-format
+msgid "local object %s is corrupt"
+msgstr "l'objecte local %s és malmès"
+
+#: builtin/index-pack.c:1402
+#, c-format
+msgid "packfile name '%s' does not end with '.pack'"
+msgstr "el nom del fitxer de paquet «%s» no acaba amb '.pack'"
+
+#: builtin/index-pack.c:1427
+#, c-format
+msgid "cannot write %s file '%s'"
+msgstr "no es pot escriure «%s» al fitxer «%s»"
+
+#: builtin/index-pack.c:1435
+#, fuzzy, c-format
+msgid "cannot close written %s file '%s'"
+msgstr "no es pot tancar el fitxer escrit a mantenir «%s»"
+
+#: builtin/index-pack.c:1459
+msgid "error while closing pack file"
+msgstr "error en tancar el fitxer empaquetat"
+
+#: builtin/index-pack.c:1473
+msgid "cannot store pack file"
+msgstr "no es pot emmagatzemar el fitxer empaquetat"
+
+#: builtin/index-pack.c:1481
+msgid "cannot store index file"
+msgstr "no es pot emmagatzemar el fitxer d'índex"
+
+#: builtin/index-pack.c:1525 builtin/pack-objects.c:2716
+#, c-format
+msgid "bad pack.indexversion=%<PRIu32>"
+msgstr "pack.indexversion=%<PRIu32> incorrecte"
+
+#: builtin/index-pack.c:1593
+#, c-format
+msgid "Cannot open existing pack file '%s'"
+msgstr "No es pot obrir el fitxer empaquetat existent «%s»"
+
+#: builtin/index-pack.c:1595
+#, c-format
+msgid "Cannot open existing pack idx file for '%s'"
+msgstr "No es pot obrir el fitxer d'índex de paquets existent de «%s»"
+
+#: builtin/index-pack.c:1643
+#, c-format
+msgid "non delta: %d object"
+msgid_plural "non delta: %d objects"
+msgstr[0] "sense diferències: %d objecte"
+msgstr[1] "sense diferències: %d objectes"
+
+#: builtin/index-pack.c:1650
+#, c-format
+msgid "chain length = %d: %lu object"
+msgid_plural "chain length = %d: %lu objects"
+msgstr[0] "longitud de cadena = %d: %lu objecte"
+msgstr[1] "longitud de cadena = %d: %lu objectes"
+
+#: builtin/index-pack.c:1689
+msgid "Cannot come back to cwd"
+msgstr "No es pot tornar al directori de treball actual"
+
+#: builtin/index-pack.c:1738 builtin/index-pack.c:1741
+#: builtin/index-pack.c:1757 builtin/index-pack.c:1761
+#, c-format
+msgid "bad %s"
+msgstr "%s incorrecte"
+
+#: builtin/index-pack.c:1777
+msgid "--fix-thin cannot be used without --stdin"
+msgstr "--fix-thin no es pot usar sense --stdin"
+
+#: builtin/index-pack.c:1779
+msgid "--stdin requires a git repository"
+msgstr "--stdin requereix un dipòsit git"
+
+#: builtin/index-pack.c:1785
+msgid "--verify with no packfile name given"
+msgstr "s'ha donat --verify sense nom de fitxer de paquet"
+
+#: builtin/index-pack.c:1833 builtin/unpack-objects.c:581
+#, fuzzy
+msgid "fsck error in pack objects"
+msgstr "error en objecte: %s"
+
+#: builtin/init-db.c:61
+#, c-format
+msgid "cannot stat template '%s'"
+msgstr "no es pot fer stat en la plantilla «%s»"
+
+#: builtin/init-db.c:66
+#, c-format
+msgid "cannot opendir '%s'"
+msgstr "no es pot fer opendir en el directori «%s»"
+
+#: builtin/init-db.c:78
+#, c-format
+msgid "cannot readlink '%s'"
+msgstr "no es pot fer readlink en «%s»"
+
+#: builtin/init-db.c:80
+#, c-format
+msgid "cannot symlink '%s' '%s'"
+msgstr "no es pot fer symlink en «%s» «%s»"
+
+#: builtin/init-db.c:86
+#, c-format
+msgid "cannot copy '%s' to '%s'"
+msgstr "no es pot copiar «%s» a «%s»"
+
+#: builtin/init-db.c:90
+#, c-format
+msgid "ignoring template %s"
+msgstr "s'està ignorant la plantilla %s"
+
+#: builtin/init-db.c:121
+#, fuzzy, c-format
+msgid "templates not found in %s"
+msgstr "no s'han trobat les plantilles %s"
+
+#: builtin/init-db.c:136
+#, c-format
+msgid "not copying templates from '%s': %s"
+msgstr "no s'estan copiant plantilles de «%s»: %s"
+
+#: builtin/init-db.c:334
+#, c-format
+msgid "unable to handle file type %d"
+msgstr "no s'ha pogut gestionar el tipus de fitxer %d"
+
+#: builtin/init-db.c:337
+#, c-format
+msgid "unable to move %s to %s"
+msgstr "no s'ha pogut moure %s a %s"
+
+#: builtin/init-db.c:354 builtin/init-db.c:357
+#, c-format
+msgid "%s already exists"
+msgstr "%s ja existeix"
+
+#: builtin/init-db.c:413
+#, c-format
+msgid "Reinitialized existing shared Git repository in %s%s\n"
+msgstr "S'ha reinicialitzat el dipòsit compartit existent del Git en %s%s\n"
+
+#: builtin/init-db.c:414
+#, c-format
+msgid "Reinitialized existing Git repository in %s%s\n"
+msgstr "S'ha reinicialitzat el dipòsit existent del Git en %s%s\n"
+
+#: builtin/init-db.c:418
+#, c-format
+msgid "Initialized empty shared Git repository in %s%s\n"
+msgstr "S'ha inicialitzat un dipòsit compartit buit del Git en %s%s\n"
+
+#: builtin/init-db.c:419
+#, c-format
+msgid "Initialized empty Git repository in %s%s\n"
+msgstr "S'ha inicialitzat un dipòsit buit del Git en %s%s\n"
+
+#: builtin/init-db.c:468
+msgid ""
+"git init [-q | --quiet] [--bare] [--template=<template-directory>] [--"
+"shared[=<permissions>]] [<directory>]"
+msgstr ""
+"git init [-q | --quiet] [--bare] [--template=<directori-de-plantilla>] [--"
+"shared[=<permisos>]] [<directori>]"
+
+#: builtin/init-db.c:491
+msgid "permissions"
+msgstr "permisos"
+
+#: builtin/init-db.c:492
+msgid "specify that the git repository is to be shared amongst several users"
+msgstr "especifica que el dipòsit de git es compartirà entre diversos usuaris"
+
+#: builtin/init-db.c:529 builtin/init-db.c:534
+#, c-format
+msgid "cannot mkdir %s"
+msgstr "no es pot mkdir %s"
+
+#: builtin/init-db.c:538
+#, c-format
+msgid "cannot chdir to %s"
+msgstr "no es pot canviar de directori a %s"
+
+#: builtin/init-db.c:559
+#, c-format
+msgid ""
+"%s (or --work-tree=<directory>) not allowed without specifying %s (or --git-"
+"dir=<directory>)"
+msgstr ""
+"no es permet %s (o --work-tree=<directori>) sense especificar %s (o --git-"
+"dir=<directori>)"
+
+#: builtin/init-db.c:587
+#, c-format
+msgid "Cannot access work tree '%s'"
+msgstr "No es pot accedir a l'arbre de treball «%s»"
+
+#: builtin/interpret-trailers.c:16
+msgid ""
+"git interpret-trailers [--in-place] [--trim-empty] [(--trailer "
+"<token>[(=|:)<value>])...] [<file>...]"
+msgstr ""
+"git interpret-trailers [--in-place] [--trim-empty] [(--trailer "
+"<testimoni>[(=|:)<valor>])...] [<fitxer>...]"
+
+#: builtin/interpret-trailers.c:95
+msgid "edit files in place"
+msgstr "edita els fitxers in situ"
+
+#: builtin/interpret-trailers.c:96
+msgid "trim empty trailers"
+msgstr "escurça els remolcs buits"
+
+#: builtin/interpret-trailers.c:99
+msgid "where to place the new trailer"
+msgstr "on ubica"
+
+#: builtin/interpret-trailers.c:101
+msgid "action if trailer already exists"
+msgstr "acció si el «trailer» ja existeix"
+
+#: builtin/interpret-trailers.c:103
+msgid "action if trailer is missing"
+msgstr "acció si el «trailer» falta"
+
+#: builtin/interpret-trailers.c:105
+msgid "output only the trailers"
+msgstr "mostra només els «trailer»"
+
+#: builtin/interpret-trailers.c:106
+msgid "do not apply config rules"
+msgstr "no apliquis les regles de configuració"
+
+#: builtin/interpret-trailers.c:107
+msgid "join whitespace-continued values"
+msgstr "uneix els valors continus amb espais en blanc"
+
+#: builtin/interpret-trailers.c:108
+msgid "set parsing options"
+msgstr "estableix les opcions d'anàlisi"
+
+#: builtin/interpret-trailers.c:110
+msgid "do not treat --- specially"
+msgstr ""
+
+#: builtin/interpret-trailers.c:111
+msgid "trailer"
+msgstr "remolc"
+
+#: builtin/interpret-trailers.c:112
+msgid "trailer(s) to add"
+msgstr "remolcs a afegir"
+
+#: builtin/interpret-trailers.c:123
+msgid "--trailer with --only-input does not make sense"
+msgstr "--trailer amb --only-input no té sentit"
+
+#: builtin/interpret-trailers.c:133
+msgid "no input file given for in-place editing"
+msgstr "no s'ha donat cap fitxer d'entrada per a edició in situ"
+
+#: builtin/log.c:56
+msgid "git log [<options>] [<revision-range>] [[--] <path>...]"
+msgstr "git log [<opcions>] [<rang-de-revisions>] [[--] <camí>...]"
+
+#: builtin/log.c:57
+msgid "git show [<options>] <object>..."
+msgstr "git show [<opcions>] <objecte>..."
+
+#: builtin/log.c:110
+#, c-format
+msgid "invalid --decorate option: %s"
+msgstr "opció --decorate no vàlida: %s"
+
+#: builtin/log.c:174
+msgid "show source"
+msgstr "mostra la font"
+
+#: builtin/log.c:175
+msgid "Use mail map file"
+msgstr "Usa el fitxer de mapa de correu"
+
+#: builtin/log.c:177
+msgid "only decorate refs that match <pattern>"
+msgstr "només decora les referències que coincideixin amb <patró>"
+
+#: builtin/log.c:179
+msgid "do not decorate refs that match <pattern>"
+msgstr "no decoris les referències que coincideixen amb <patró>"
+
+#: builtin/log.c:180
+msgid "decorate options"
+msgstr "opcions de decoració"
+
+#: builtin/log.c:183
+msgid "Process line range n,m in file, counting from 1"
+msgstr "Processa el rang de línies n,m en el fitxer, comptant des d'1"
+
+#: builtin/log.c:281
+#, c-format
+msgid "Final output: %d %s\n"
+msgstr "Sortida final: %d %s\n"
+
+#: builtin/log.c:535
+#, c-format
+msgid "git show %s: bad file"
+msgstr "git show %s: fitxer incorrecte"
+
+#: builtin/log.c:550 builtin/log.c:645
+#, fuzzy, c-format
+msgid "could not read object %s"
+msgstr "No es pot llegir l'objecte %s"
+
+#: builtin/log.c:670
+#, fuzzy, c-format
+msgid "unknown type: %d"
+msgstr "Tipus desconegut: %d"
+
+#: builtin/log.c:814
+#, c-format
+msgid "%s: invalid cover from description mode"
+msgstr ""
+
+#: builtin/log.c:821
+msgid "format.headers without value"
+msgstr "format.headers sense valor"
+
+#: builtin/log.c:936
+msgid "name of output directory is too long"
+msgstr "el nom del directori de sortida és massa llarg"
+
+#: builtin/log.c:952
+#, fuzzy, c-format
+msgid "cannot open patch file %s"
+msgstr "No es pot obrir el fitxer de pedaç %s"
+
+#: builtin/log.c:969
+#, fuzzy
+msgid "need exactly one range"
+msgstr "Cal exactament un rang."
+
+#: builtin/log.c:979
+#, fuzzy
+msgid "not a range"
+msgstr "No és un rang."
+
+#: builtin/log.c:1143
+#, fuzzy
+msgid "cover letter needs email format"
+msgstr "La carta de presentació necessita el format de correu electrònic"
+
+#: builtin/log.c:1149
+#, fuzzy
+msgid "failed to create cover-letter file"
+msgstr "S'ha produït un error en crear els fitxers de sortida"
+
+#: builtin/log.c:1228
+#, c-format
+msgid "insane in-reply-to: %s"
+msgstr "in-reply-to boig: %s"
+
+#: builtin/log.c:1255
+msgid "git format-patch [<options>] [<since> | <revision-range>]"
+msgstr "git format-patch [<opcions>] [<des-de> | <rang-de-revisions>]"
+
+#: builtin/log.c:1313
+#, fuzzy
+msgid "two output directories?"
+msgstr "Hi ha dos directoris de sortida?"
+
+#: builtin/log.c:1424 builtin/log.c:2197 builtin/log.c:2199 builtin/log.c:2211
+#, fuzzy, c-format
+msgid "unknown commit %s"
+msgstr "Comissió desconeguda %s"
+
+#: builtin/log.c:1434 builtin/replace.c:58 builtin/replace.c:207
+#: builtin/replace.c:210
+#, c-format
+msgid "failed to resolve '%s' as a valid ref"
+msgstr "s'ha produït un error en resoldre «%s» com a referència vàlida"
+
+#: builtin/log.c:1439
+#, fuzzy
+msgid "could not find exact merge base"
+msgstr "No s'ha pogut trobar la base exacta de fusió."
+
+#: builtin/log.c:1443
+#, fuzzy
+msgid ""
+"failed to get upstream, if you want to record base commit automatically,\n"
+"please use git branch --set-upstream-to to track a remote branch.\n"
+"Or you could specify base commit by --base=<base-commit-id> manually"
+msgstr ""
+"S'ha produït un error en obtenir la font. Si voleu registrar la comissió "
+"base\n"
+"automàticament, useu git branch --set-upstream-to per a\n"
+"seguir una branca remota. O podeu especificar la comissió base manualment\n"
+"amb --base=<id-de-comissió-base>."
+
+#: builtin/log.c:1463
+#, fuzzy
+msgid "failed to find exact merge base"
+msgstr "S'ha produït un error en trobar la base exacta de fusió."
+
+#: builtin/log.c:1474
+msgid "base commit should be the ancestor of revision list"
+msgstr "la comissió base ha de ser l'avantpassat de la llista de revisions"
+
+#: builtin/log.c:1478
+msgid "base commit shouldn't be in revision list"
+msgstr "la comissió base no ha de ser en la llista de revisions"
+
+#: builtin/log.c:1531
+msgid "cannot get patch id"
+msgstr "no es pot obtenir l'id del pedaç"
+
+#: builtin/log.c:1583
+#, fuzzy
+msgid "failed to infer range-diff ranges"
+msgstr "s'ha produït un error en executar «%s»"
+
+#: builtin/log.c:1629
+msgid "use [PATCH n/m] even with a single patch"
+msgstr "usa [PATCH n/m] fins i tot amb un sol pedaç"
+
+#: builtin/log.c:1632
+msgid "use [PATCH] even with multiple patches"
+msgstr "usa [PATCH] fins i tot amb múltiples pedaços"
+
+#: builtin/log.c:1636
+msgid "print patches to standard out"
+msgstr "imprimeix els pedaços a la sortida estàndard"
+
+#: builtin/log.c:1638
+msgid "generate a cover letter"
+msgstr "genera una carta de presentació"
+
+#: builtin/log.c:1640
+msgid "use simple number sequence for output file names"
+msgstr "usa una seqüència de números per als noms dels fitxers de sortida"
+
+#: builtin/log.c:1641
+msgid "sfx"
+msgstr "sufix"
+
+#: builtin/log.c:1642
+msgid "use <sfx> instead of '.patch'"
+msgstr "usa <sufix> en lloc de '.patch'"
+
+#: builtin/log.c:1644
+msgid "start numbering patches at <n> instead of 1"
+msgstr "comença numerant els pedaços a <n> en lloc d'1"
+
+#: builtin/log.c:1646
+msgid "mark the series as Nth re-roll"
+msgstr "marca la sèrie com a l'enèsima llançada"
+
+#: builtin/log.c:1648
+msgid "Use [RFC PATCH] instead of [PATCH]"
+msgstr "Usa [RFC PATCH] en lloc de [PATCH]"
+
+#: builtin/log.c:1651
+msgid "cover-from-description-mode"
+msgstr ""
+
+#: builtin/log.c:1652
+msgid "generate parts of a cover letter based on a branch's description"
+msgstr ""
+
+#: builtin/log.c:1654
+msgid "Use [<prefix>] instead of [PATCH]"
+msgstr "Usa [<prefix>] en lloc de [PATCH]"
+
+#: builtin/log.c:1657
+msgid "store resulting files in <dir>"
+msgstr "emmagatzema els fitxers resultants a <directori>"
+
+#: builtin/log.c:1660
+msgid "don't strip/add [PATCH]"
+msgstr "no despullis/afegeixis [PATCH]"
+
+#: builtin/log.c:1663
+msgid "don't output binary diffs"
+msgstr "no emetis diferències binàries"
+
+#: builtin/log.c:1665
+msgid "output all-zero hash in From header"
+msgstr "emet un hash de tots zeros en la capçalera From"
+
+#: builtin/log.c:1667
+msgid "don't include a patch matching a commit upstream"
+msgstr "no incloguis pedaços que coincideixin amb comissions a la font"
+
+#: builtin/log.c:1669
+msgid "show patch format instead of default (patch + stat)"
+msgstr ""
+"mostra el format de pedaç en lloc del per defecte (pedaç + estadístiques)"
+
+#: builtin/log.c:1671
+msgid "Messaging"
+msgstr "Missatgeria"
+
+#: builtin/log.c:1672
+msgid "header"
+msgstr "capçalera"
+
+#: builtin/log.c:1673
+msgid "add email header"
+msgstr "afegeix una capçalera de correu electrònic"
+
+#: builtin/log.c:1674 builtin/log.c:1676
+msgid "email"
+msgstr "correu electrònic"
+
+#: builtin/log.c:1674
+msgid "add To: header"
+msgstr "afegeix la capçalera To:"
+
+#: builtin/log.c:1676
+msgid "add Cc: header"
+msgstr "afegeix la capçalera Cc:"
+
+#: builtin/log.c:1678
+msgid "ident"
+msgstr "identitat"
+
+#: builtin/log.c:1679
+msgid "set From address to <ident> (or committer ident if absent)"
+msgstr ""
+"estableix l'adreça From a <identitat> (o la identitat del comitent si manca)"
+
+#: builtin/log.c:1681
+msgid "message-id"
+msgstr "ID de missatge"
+
+#: builtin/log.c:1682
+msgid "make first mail a reply to <message-id>"
+msgstr "fes que el primer missatge sigui una resposta a <ID de missatge>"
+
+#: builtin/log.c:1683 builtin/log.c:1686
+msgid "boundary"
+msgstr "límit"
+
+#: builtin/log.c:1684
+msgid "attach the patch"
+msgstr "adjunta el pedaç"
+
+#: builtin/log.c:1687
+msgid "inline the patch"
+msgstr "posa el pedaç en el cos"
+
+#: builtin/log.c:1691
+msgid "enable message threading, styles: shallow, deep"
+msgstr "habilita l'enfilada de missatges, estils: shallow, deep"
+
+#: builtin/log.c:1693
+msgid "signature"
+msgstr "signatura"
+
+#: builtin/log.c:1694
+msgid "add a signature"
+msgstr "afegeix una signatura"
+
+#: builtin/log.c:1695
+msgid "base-commit"
+msgstr "comissió base"
+
+#: builtin/log.c:1696
+msgid "add prerequisite tree info to the patch series"
+msgstr "afegeix la informació d'arbre requerida a la sèrie de pedaços"
+
+#: builtin/log.c:1698
+msgid "add a signature from a file"
+msgstr "afegeix una signatura des d'un fitxer"
+
+#: builtin/log.c:1699
+msgid "don't print the patch filenames"
+msgstr "no imprimeixis els noms de fitxer del pedaç"
+
+#: builtin/log.c:1701
+msgid "show progress while generating patches"
+msgstr "mostra el progrés durant la generació de pedaços"
+
+#: builtin/log.c:1703
+msgid "show changes against <rev> in cover letter or single patch"
+msgstr ""
+
+#: builtin/log.c:1706
+msgid "show changes against <refspec> in cover letter or single patch"
+msgstr ""
+
+#: builtin/log.c:1708
+msgid "percentage by which creation is weighted"
+msgstr ""
+
+#: builtin/log.c:1792
+#, c-format
+msgid "invalid ident line: %s"
+msgstr "línia d'identitat no vàlida: %s"
+
+#: builtin/log.c:1807
+#, fuzzy
+msgid "-n and -k are mutually exclusive"
+msgstr "-n i -k són mútuament excloents."
+
+#: builtin/log.c:1809
+#, fuzzy
+msgid "--subject-prefix/--rfc and -k are mutually exclusive"
+msgstr "--subject-prefix/--rfc i -k són mútuament excloents."
+
+#: builtin/log.c:1817
+msgid "--name-only does not make sense"
+msgstr "--name-only no té sentit"
+
+#: builtin/log.c:1819
+msgid "--name-status does not make sense"
+msgstr "--name-status no té sentit"
+
+#: builtin/log.c:1821
+msgid "--check does not make sense"
+msgstr "--check no té sentit"
+
+#: builtin/log.c:1854
+msgid "standard output, or directory, which one?"
+msgstr "sortida estàndard o directori, quin dels dos?"
+
+#: builtin/log.c:1958
+msgid "--interdiff requires --cover-letter or single patch"
+msgstr ""
+
+#: builtin/log.c:1962
+msgid "Interdiff:"
+msgstr ""
+
+#: builtin/log.c:1963
+#, c-format
+msgid "Interdiff against v%d:"
+msgstr ""
+
+#: builtin/log.c:1969
+msgid "--creation-factor requires --range-diff"
+msgstr ""
+
+#: builtin/log.c:1973
+msgid "--range-diff requires --cover-letter or single patch"
+msgstr ""
+
+#: builtin/log.c:1981
+msgid "Range-diff:"
+msgstr ""
+
+#: builtin/log.c:1982
+#, c-format
+msgid "Range-diff against v%d:"
+msgstr ""
+
+#: builtin/log.c:1993
+#, c-format
+msgid "unable to read signature file '%s'"
+msgstr "no s'ha pogut llegir el fitxer de signatura «%s»"
+
+#: builtin/log.c:2029
+msgid "Generating patches"
+msgstr "S'estan generant els pedaços"
+
+#: builtin/log.c:2073
+#, fuzzy
+msgid "failed to create output files"
+msgstr "S'ha produït un error en crear els fitxers de sortida"
+
+#: builtin/log.c:2132
+msgid "git cherry [-v] [<upstream> [<head> [<limit>]]]"
+msgstr "git cherry [-v] [<font> [<cap> [<límit>]]]"
+
+#: builtin/log.c:2186
+#, c-format
+msgid ""
+"Could not find a tracked remote branch, please specify <upstream> manually.\n"
+msgstr ""
+"No s'ha pogut trobar una branca remota seguida. Especifiqueu <font> "
+"manualment.\n"
+
+#: builtin/ls-files.c:470
+msgid "git ls-files [<options>] [<file>...]"
+msgstr "git ls-files [<opcions>] [<fitxer>...]"
+
+#: builtin/ls-files.c:526
+msgid "identify the file status with tags"
+msgstr "identifica l'estat de fitxer amb etiquetes"
+
+#: builtin/ls-files.c:528
+msgid "use lowercase letters for 'assume unchanged' files"
+msgstr "usa lletres minúscules per als fitxers 'assume unchanged'"
+
+#: builtin/ls-files.c:530
+msgid "use lowercase letters for 'fsmonitor clean' files"
+msgstr "usa lletres minúscules per als fitxers 'fsmonitor clean'"
+
+#: builtin/ls-files.c:532
+msgid "show cached files in the output (default)"
+msgstr ""
+"mostra en la sortida els fitxers desats en la memòria cau (per defecte)"
+
+#: builtin/ls-files.c:534
+msgid "show deleted files in the output"
+msgstr "mostra en la sortida els fitxers suprimits"
+
+#: builtin/ls-files.c:536
+msgid "show modified files in the output"
+msgstr "mostra en la sortida els fitxers modificats"
+
+#: builtin/ls-files.c:538
+msgid "show other files in the output"
+msgstr "mostra en la sortida els altres fitxers"
+
+#: builtin/ls-files.c:540
+msgid "show ignored files in the output"
+msgstr "mostra en la sortida els fitxers ignorats"
+
+#: builtin/ls-files.c:543
+msgid "show staged contents' object name in the output"
+msgstr "mostra en la sortida el nom d'objecte dels continguts «stage»"
+
+#: builtin/ls-files.c:545
+msgid "show files on the filesystem that need to be removed"
+msgstr "mostra els fitxers en el sistema de fitxers que s'han d'eliminar"
+
+#: builtin/ls-files.c:547
+msgid "show 'other' directories' names only"
+msgstr "mostra només els noms dels directoris 'other'"
+
+#: builtin/ls-files.c:549
+msgid "show line endings of files"
+msgstr "mostra els terminadors de línia dels fitxers"
+
+#: builtin/ls-files.c:551
+msgid "don't show empty directories"
+msgstr "no mostris els directoris buits"
+
+#: builtin/ls-files.c:554
+msgid "show unmerged files in the output"
+msgstr "mostra en la sortida els fitxers sense fusionar"
+
+#: builtin/ls-files.c:556
+msgid "show resolve-undo information"
+msgstr "mostra la informació de resolució de desfet"
+
+#: builtin/ls-files.c:558
+msgid "skip files matching pattern"
+msgstr "omet els fitxers coincidents amb el patró"
+
+#: builtin/ls-files.c:561
+msgid "exclude patterns are read from <file>"
+msgstr "els patrons d'exclusió es llegeixen de <fitxer>"
+
+#: builtin/ls-files.c:564
+msgid "read additional per-directory exclude patterns in <file>"
+msgstr "llegeix els patrons addicionals d'exclusió per directori en <fitxer>"
+
+#: builtin/ls-files.c:566
+msgid "add the standard git exclusions"
+msgstr "afegeix les exclusions estàndards de git"
+
+#: builtin/ls-files.c:570
+msgid "make the output relative to the project top directory"
+msgstr "fes que la sortida sigui relativa al directori superior del projecte"
+
+#: builtin/ls-files.c:573
+msgid "recurse through submodules"
+msgstr "inclou recursivament als submòduls"
+
+#: builtin/ls-files.c:575
+msgid "if any <file> is not in the index, treat this as an error"
+msgstr "si qualsevol <fitxer> no és en l'índex, tracta-ho com a error"
+
+#: builtin/ls-files.c:576
+msgid "tree-ish"
+msgstr "arbre"
+
+#: builtin/ls-files.c:577
+msgid "pretend that paths removed since <tree-ish> are still present"
+msgstr ""
+"pretén que els camins eliminats després de <arbre> encara siguin presents"
+
+#: builtin/ls-files.c:579
+msgid "show debugging data"
+msgstr "mostra les dades de depuració"
+
+#: builtin/ls-remote.c:9
+msgid ""
+"git ls-remote [--heads] [--tags] [--refs] [--upload-pack=<exec>]\n"
+"                     [-q | --quiet] [--exit-code] [--get-url]\n"
+"                     [--symref] [<repository> [<refs>...]]"
+msgstr ""
+"git ls-remote [--heads] [--tags] [--refs]\n"
+"                     [--upload-pack=<executable>] [-q | --quiet]\n"
+"                     [--exit-code] [--get-url] [--symref]\n"
+"                     [<dipòsit> [<referències>...]]"
+
+#: builtin/ls-remote.c:59
+msgid "do not print remote URL"
+msgstr "no imprimeixis l'URL remot"
+
+#: builtin/ls-remote.c:60 builtin/ls-remote.c:62 builtin/rebase.c:1518
+msgid "exec"
+msgstr "executable"
+
+#: builtin/ls-remote.c:61 builtin/ls-remote.c:63
+msgid "path of git-upload-pack on the remote host"
+msgstr "camí a git-upload-pack en la màquina remota"
+
+#: builtin/ls-remote.c:65
+msgid "limit to tags"
+msgstr "limita a etiquetes"
+
+#: builtin/ls-remote.c:66
+msgid "limit to heads"
+msgstr "limita a caps"
+
+#: builtin/ls-remote.c:67
+msgid "do not show peeled tags"
+msgstr "no mostris les etiquetes pelades"
+
+#: builtin/ls-remote.c:69
+msgid "take url.<base>.insteadOf into account"
+msgstr "tingues en compte url.<base>.insteadOf"
+
+#: builtin/ls-remote.c:72
+msgid "exit with exit code 2 if no matching refs are found"
+msgstr "surt amb codi de sortida 2 si no es troba cap referència coincident"
+
+#: builtin/ls-remote.c:75
+msgid "show underlying ref in addition to the object pointed by it"
+msgstr "mostra la referència subjacent a més de l'objecte que senyali"
+
+#: builtin/ls-tree.c:30
+msgid "git ls-tree [<options>] <tree-ish> [<path>...]"
+msgstr "git ls-tree [<opcions>] <arbre> [<camí>...]"
+
+#: builtin/ls-tree.c:128
+msgid "only show trees"
+msgstr "mostra només els arbres"
+
+#: builtin/ls-tree.c:130
+msgid "recurse into subtrees"
+msgstr "inclou recursivament als subarbres"
+
+#: builtin/ls-tree.c:132
+msgid "show trees when recursing"
+msgstr "mostra els arbres quan es treballa recursivament"
+
+#: builtin/ls-tree.c:135
+msgid "terminate entries with NUL byte"
+msgstr "acaba les entrades amb un octet NUL"
+
+#: builtin/ls-tree.c:136
+msgid "include object size"
+msgstr "mida de l'objecte d'inclusió"
+
+#: builtin/ls-tree.c:138 builtin/ls-tree.c:140
+msgid "list only filenames"
+msgstr "llista només els noms de fitxer"
+
+#: builtin/ls-tree.c:143
+msgid "use full path names"
+msgstr "usa els noms de camí complets"
+
+#: builtin/ls-tree.c:145
+msgid "list entire tree; not just current directory (implies --full-name)"
+msgstr ""
+"llista l'arbre sencer; no només el directori actual (implica --full-name)"
+
+#: builtin/mailsplit.c:241
+#, c-format
+msgid "empty mbox: '%s'"
+msgstr "mbox buit: «%s»"
+
+#: builtin/merge.c:55
+msgid "git merge [<options>] [<commit>...]"
+msgstr "git merge [<opcions>] [<comissió>...]"
+
+#: builtin/merge.c:56
+msgid "git merge --abort"
+msgstr "git merge --abort"
+
+#: builtin/merge.c:57
+msgid "git merge --continue"
+msgstr "git merge --continue"
+
+#: builtin/merge.c:118
+msgid "switch `m' requires a value"
+msgstr "l'opció «m» requereix un valor"
+
+#: builtin/merge.c:141
+#, fuzzy, c-format
+msgid "option `%s' requires a value"
+msgstr "l'opció «%s» requereix un valor"
+
+#: builtin/merge.c:187
+#, c-format
+msgid "Could not find merge strategy '%s'.\n"
+msgstr "No s'ha pogut trobar l'estratègia de fusió «%s».\n"
+
+#: builtin/merge.c:188
+#, c-format
+msgid "Available strategies are:"
+msgstr "Les estratègies disponibles són:"
+
+#: builtin/merge.c:193
+#, c-format
+msgid "Available custom strategies are:"
+msgstr "Les estratègies personalitzades disponibles són:"
+
+#: builtin/merge.c:244 builtin/pull.c:152
+msgid "do not show a diffstat at the end of the merge"
+msgstr "no mostris les estadístiques de diferència al final de la fusió"
+
+#: builtin/merge.c:247 builtin/pull.c:155
+msgid "show a diffstat at the end of the merge"
+msgstr "mostra les estadístiques de diferència al final de la fusió"
+
+#: builtin/merge.c:248 builtin/pull.c:158
+msgid "(synonym to --stat)"
+msgstr "(sinònim de --stat)"
+
+#: builtin/merge.c:250 builtin/pull.c:161
+msgid "add (at most <n>) entries from shortlog to merge commit message"
+msgstr ""
+"afegeix (com a màxim <n>) entrades del registre curt al missatge de comissió "
+"de fusió"
+
+#: builtin/merge.c:253 builtin/pull.c:167
+msgid "create a single commit instead of doing a merge"
+msgstr "crea una única comissió en lloc de fusionar"
+
+#: builtin/merge.c:255 builtin/pull.c:170
+msgid "perform a commit if the merge succeeds (default)"
+msgstr "realitza una comissió si la fusió té èxit (per defecte)"
+
+#: builtin/merge.c:257 builtin/pull.c:173
+msgid "edit message before committing"
+msgstr "edita el missatge abans de cometre"
+
+#: builtin/merge.c:259
+msgid "allow fast-forward (default)"
+msgstr "permet l'avanç ràpid (per defecte)"
+
+#: builtin/merge.c:261 builtin/pull.c:180
+msgid "abort if fast-forward is not possible"
+msgstr "avorta si l'avanç ràpid no és possible"
+
+#: builtin/merge.c:265 builtin/pull.c:183
+msgid "verify that the named commit has a valid GPG signature"
+msgstr "verifica que la comissió anomenada tingui una signatura GPG vàlida"
+
+#: builtin/merge.c:266 builtin/notes.c:787 builtin/pull.c:187
+#: builtin/rebase.c:512 builtin/rebase.c:1531 builtin/revert.c:114
+msgid "strategy"
+msgstr "estratègia"
+
+#: builtin/merge.c:267 builtin/pull.c:188
+msgid "merge strategy to use"
+msgstr "estratègia de fusió a usar"
+
+#: builtin/merge.c:268 builtin/pull.c:191
+msgid "option=value"
+msgstr "opció=valor"
+
+#: builtin/merge.c:269 builtin/pull.c:192
+msgid "option for selected merge strategy"
+msgstr "opció per a l'estratègia de fusió seleccionada"
+
+#: builtin/merge.c:271
+msgid "merge commit message (for a non-fast-forward merge)"
+msgstr "missatge de comissió de fusió (per a una fusió no d'avanç ràpid)"
+
+#: builtin/merge.c:278
+msgid "abort the current in-progress merge"
+msgstr "avorta la fusió en curs actual"
+
+#: builtin/merge.c:280
+#, fuzzy
+msgid "--abort but leave index and working tree alone"
+msgstr "restableix HEAD, l'índex i l'arbre de treball"
+
+#: builtin/merge.c:282
+msgid "continue the current in-progress merge"
+msgstr "continua la fusió en curs actual"
+
+#: builtin/merge.c:284 builtin/pull.c:199
+msgid "allow merging unrelated histories"
+msgstr "permet fusionar històries no relacionades"
+
+#: builtin/merge.c:290
+#, fuzzy
+msgid "bypass pre-merge-commit and commit-msg hooks"
+msgstr "evita els lligams de precomissió i missatge de comissió"
+
+#: builtin/merge.c:307
+msgid "could not run stash."
+msgstr "no s'ha pogut executar «stash»."
+
+#: builtin/merge.c:312
+msgid "stash failed"
+msgstr "l'«stash» ha fallat"
+
+#: builtin/merge.c:317
+#, c-format
+msgid "not a valid object: %s"
+msgstr "no és un objecte vàlid: %s"
+
+#: builtin/merge.c:339 builtin/merge.c:356
+msgid "read-tree failed"
+msgstr "read-tree ha fallat"
+
+#: builtin/merge.c:386
+msgid " (nothing to squash)"
+msgstr " (res a fer «squash»)"
+
+#: builtin/merge.c:397
+#, c-format
+msgid "Squash commit -- not updating HEAD\n"
+msgstr "Comissió «squash» -- no s'està actualitzant HEAD\n"
+
+#: builtin/merge.c:447
+#, c-format
+msgid "No merge message -- not updating HEAD\n"
+msgstr "Cap missatge de fusió -- no s'està actualitzant HEAD\n"
+
+#: builtin/merge.c:498
+#, c-format
+msgid "'%s' does not point to a commit"
+msgstr "«%s» no assenyala una comissió"
+
+#: builtin/merge.c:585
+#, c-format
+msgid "Bad branch.%s.mergeoptions string: %s"
+msgstr "Cadena branch.%s.mergeoptions incorrecta: %s"
+
+#: builtin/merge.c:705
+msgid "Not handling anything other than two heads merge."
+msgstr "No s'està gestionant res a part de la fusió de dos caps."
+
+#: builtin/merge.c:719
+#, c-format
+msgid "Unknown option for merge-recursive: -X%s"
+msgstr "Opció desconeguda de merge-recursive: -X%s"
+
+#: builtin/merge.c:734
+#, c-format
+msgid "unable to write %s"
+msgstr "no s'ha pogut escriure %s"
+
+#: builtin/merge.c:786
+#, c-format
+msgid "Could not read from '%s'"
+msgstr "No s'ha pogut llegir de «%s»"
+
+#: builtin/merge.c:795
+#, c-format
+msgid "Not committing merge; use 'git commit' to complete the merge.\n"
+msgstr ""
+"No s'està cometent la fusió; useu 'git commit' per a completar la fusió.\n"
+
+#: builtin/merge.c:801
+#, fuzzy
+msgid ""
+"Please enter a commit message to explain why this merge is necessary,\n"
+"especially if it merges an updated upstream into a topic branch.\n"
+"\n"
+msgstr ""
+"Introduïu un missatge de comissió per a explicar per què\n"
+"aquesta fusió és necessària, especialment si fusiona una font\n"
+"actualitzada a una branca temàtica.\n"
+"\n"
+"S'ignoraran les línies que comencin amb «%c», i un missatge buit\n"
+"avorta la comissió.\n"
+
+#: builtin/merge.c:806
+#, fuzzy
+msgid "An empty message aborts the commit.\n"
+msgstr "edita el missatge abans de cometre"
+
+#: builtin/merge.c:809
+#, fuzzy, c-format
+msgid ""
+"Lines starting with '%c' will be ignored, and an empty message aborts\n"
+"the commit.\n"
+msgstr ""
+"Introduïu el missatge de comissió dels vostres canvis.\n"
+"S'ignoraran les línies que comencin amb «%c», i un missatge de\n"
+"comissió buit avorta la comissió.\n"
+
+#: builtin/merge.c:862
+msgid "Empty commit message."
+msgstr "El missatge de comissió és buit."
+
+#: builtin/merge.c:877
+#, c-format
+msgid "Wonderful.\n"
+msgstr "Meravellós.\n"
+
+#: builtin/merge.c:938
+#, c-format
+msgid "Automatic merge failed; fix conflicts and then commit the result.\n"
+msgstr ""
+"La fusió automàtica ha fallat; arregleu els conflictes i després cometeu el "
+"resultat.\n"
+
+#: builtin/merge.c:977
+msgid "No current branch."
+msgstr "No hi ha cap branca actual."
+
+#: builtin/merge.c:979
+msgid "No remote for the current branch."
+msgstr "No hi ha cap remot per a la branca actual."
+
+#: builtin/merge.c:981
+msgid "No default upstream defined for the current branch."
+msgstr "No hi ha cap font per defecte definida per a la branca actual."
+
+#: builtin/merge.c:986
+#, c-format
+msgid "No remote-tracking branch for %s from %s"
+msgstr "No hi ha cap branca amb seguiment remot per a %s de %s"
+
+#: builtin/merge.c:1043
+#, c-format
+msgid "Bad value '%s' in environment '%s'"
+msgstr "Valor incorrecte «%s» en l'entorn «%s»"
+
+#: builtin/merge.c:1146
+#, c-format
+msgid "not something we can merge in %s: %s"
+msgstr "no és quelcom que puguem fusionar en %s: %s"
+
+#: builtin/merge.c:1180
+msgid "not something we can merge"
+msgstr "no és quelcom que puguem fusionar"
+
+#: builtin/merge.c:1283
+msgid "--abort expects no arguments"
+msgstr "--abort no accepta paràmetres"
+
+#: builtin/merge.c:1287
+msgid "There is no merge to abort (MERGE_HEAD missing)."
+msgstr "No hi ha fusió a avortar (manca MERGE_HEAD)."
+
+#: builtin/merge.c:1296
+#, fuzzy
+msgid "--quit expects no arguments"
+msgstr "--abort no accepta paràmetres"
+
+#: builtin/merge.c:1309
+msgid "--continue expects no arguments"
+msgstr "--continue no accepta paràmetres"
+
+#: builtin/merge.c:1313
+msgid "There is no merge in progress (MERGE_HEAD missing)."
+msgstr "No hi ha cap fusió en curs (manca MERGE_HEAD)."
+
+#: builtin/merge.c:1329
+msgid ""
+"You have not concluded your merge (MERGE_HEAD exists).\n"
+"Please, commit your changes before you merge."
+msgstr ""
+"No heu conclòs la vostra fusió (MERGE_HEAD existeix).\n"
+"Cometeu els vostres canvis abans de fusionar."
+
+#: builtin/merge.c:1336
+msgid ""
+"You have not concluded your cherry-pick (CHERRY_PICK_HEAD exists).\n"
+"Please, commit your changes before you merge."
+msgstr ""
+"No heu conclòs el vostre «cherry pick» (CHERRY_PICK_HEAD existeix).\n"
+"Cometeu els vostres canvis abans de fusionar."
+
+#: builtin/merge.c:1339
+msgid "You have not concluded your cherry-pick (CHERRY_PICK_HEAD exists)."
+msgstr "No heu conclòs el vostre «cherry pick» (CHERRY_PICK_HEAD existeix)."
+
+#: builtin/merge.c:1353
+msgid "You cannot combine --squash with --no-ff."
+msgstr "No podeu combinar --squash amb --no-ff."
+
+#: builtin/merge.c:1355
+#, fuzzy
+msgid "You cannot combine --squash with --commit."
+msgstr "No podeu combinar --squash amb --no-ff."
+
+#: builtin/merge.c:1371
+msgid "No commit specified and merge.defaultToUpstream not set."
+msgstr ""
+"No hi ha una comissió especificada i merge.defaultToUpstream no està "
+"establert."
+
+#: builtin/merge.c:1388
+msgid "Squash commit into empty head not supported yet"
+msgstr "Una comissió «squash» a un HEAD buit encara no es permet"
+
+#: builtin/merge.c:1390
+msgid "Non-fast-forward commit does not make sense into an empty head"
+msgstr "Una comissió no d'avanç ràpid no té sentit a un HEAD buit"
+
+#: builtin/merge.c:1395
+#, c-format
+msgid "%s - not something we can merge"
+msgstr "%s - no és una cosa que puguem fusionar"
+
+#: builtin/merge.c:1397
+msgid "Can merge only exactly one commit into empty head"
+msgstr "Es pot fusionar només una comissió a un HEAD buit"
+
+#: builtin/merge.c:1476
+msgid "refusing to merge unrelated histories"
+msgstr "s'està refusant fusionar històries no relacionades"
+
+#: builtin/merge.c:1485
+msgid "Already up to date."
+msgstr "Ja està al dia."
+
+#: builtin/merge.c:1495
+#, c-format
+msgid "Updating %s..%s\n"
+msgstr "S'estan actualitzant %s..%s\n"
+
+#: builtin/merge.c:1537
+#, c-format
+msgid "Trying really trivial in-index merge...\n"
+msgstr "S'està intentant una fusió molt trivial en l'índex...\n"
+
+#: builtin/merge.c:1544
+#, c-format
+msgid "Nope.\n"
+msgstr "No.\n"
+
+#: builtin/merge.c:1569
+msgid "Already up to date. Yeeah!"
+msgstr "Ja està al dia. Estupend!"
+
+#: builtin/merge.c:1575
+msgid "Not possible to fast-forward, aborting."
+msgstr "No és possible avançar ràpidament, s'està avortant."
+
+#: builtin/merge.c:1598 builtin/merge.c:1663
+#, c-format
+msgid "Rewinding the tree to pristine...\n"
+msgstr "S'està rebobinant l'arbre a la pristina...\n"
+
+#: builtin/merge.c:1602
+#, c-format
+msgid "Trying merge strategy %s...\n"
+msgstr "S'està intentant l'estratègia de fusió %s...\n"
+
+#: builtin/merge.c:1654
+#, c-format
+msgid "No merge strategy handled the merge.\n"
+msgstr "Cap estratègia de fusió ha gestionat la fusió.\n"
+
+#: builtin/merge.c:1656
+#, c-format
+msgid "Merge with strategy %s failed.\n"
+msgstr "L'estratègia de fusió %s ha fallat.\n"
+
+#: builtin/merge.c:1665
+#, c-format
+msgid "Using the %s to prepare resolving by hand.\n"
+msgstr "S'està usant el %s per a preparar la resolució a mà.\n"
+
+#: builtin/merge.c:1677
+#, c-format
+msgid "Automatic merge went well; stopped before committing as requested\n"
+msgstr ""
+"La fusió automàtica ha sortit bé; s'ha aturat abans de cometre com s'havia "
+"demanat\n"
+
+#: builtin/merge-base.c:32
+msgid "git merge-base [-a | --all] <commit> <commit>..."
+msgstr "git merge-base [-a | --all] <comissió> <comissió>..."
+
+#: builtin/merge-base.c:33
+msgid "git merge-base [-a | --all] --octopus <commit>..."
+msgstr "git merge-base [-a | --all] --octopus <comissió>..."
+
+#: builtin/merge-base.c:34
+msgid "git merge-base --independent <commit>..."
+msgstr "git merge-base --independent <comissió>..."
+
+#: builtin/merge-base.c:35
+msgid "git merge-base --is-ancestor <commit> <commit>"
+msgstr "git merge-base --is-ancestor <comissió> <comissió>"
+
+#: builtin/merge-base.c:36
+msgid "git merge-base --fork-point <ref> [<commit>]"
+msgstr "git merge-base --fork-point <referència> [<comissió>]"
+
+#: builtin/merge-base.c:153
+msgid "output all common ancestors"
+msgstr "emet tots els avantpassats comuns"
+
+#: builtin/merge-base.c:155
+msgid "find ancestors for a single n-way merge"
+msgstr "troba els avantpassats per a una sola fusió d'n vies"
+
+#: builtin/merge-base.c:157
+msgid "list revs not reachable from others"
+msgstr "llista les revisions no abastables d'altres"
+
+#: builtin/merge-base.c:159
+msgid "is the first one ancestor of the other?"
+msgstr "és la primera un avantpassat de l'altre?"
+
+#: builtin/merge-base.c:161
+msgid "find where <commit> forked from reflog of <ref>"
+msgstr ""
+"troba on <comissió> s'ha bifurcat del registre de referències de <referència>"
+
+#: builtin/merge-file.c:9
+msgid ""
+"git merge-file [<options>] [-L <name1> [-L <orig> [-L <name2>]]] <file1> "
+"<orig-file> <file2>"
+msgstr ""
+"git merge-file [<opcions>] [-L <nom1> [-L <original> [-L <nom2>]]] <fitxer1> "
+"<fitxer-original> <fitxer2>"
+
+#: builtin/merge-file.c:35
+msgid "send results to standard output"
+msgstr "envia els resultats a la sortida estàndard"
+
+#: builtin/merge-file.c:36
+msgid "use a diff3 based merge"
+msgstr "usa una fusió basada en diff3"
+
+#: builtin/merge-file.c:37
+msgid "for conflicts, use our version"
+msgstr "en conflictes, usa la nostra versió"
+
+#: builtin/merge-file.c:39
+msgid "for conflicts, use their version"
+msgstr "en conflictes, usa la seva versió"
+
+#: builtin/merge-file.c:41
+msgid "for conflicts, use a union version"
+msgstr "en conflictes, usa una versió d'unió"
+
+#: builtin/merge-file.c:44
+msgid "for conflicts, use this marker size"
+msgstr "en conflictes, usa aquesta mida de marcador"
+
+#: builtin/merge-file.c:45
+msgid "do not warn about conflicts"
+msgstr "no avisis de conflictes"
+
+#: builtin/merge-file.c:47
+msgid "set labels for file1/orig-file/file2"
+msgstr "estableix les etiquetes per a fitxer1/fitxer-original/fitxer2"
+
+#: builtin/merge-recursive.c:47
+#, c-format
+msgid "unknown option %s"
+msgstr "opció desconeguda %s"
+
+#: builtin/merge-recursive.c:53
+#, c-format
+msgid "could not parse object '%s'"
+msgstr "no s'ha pogut analitzar l'objecte «%s»"
+
+#: builtin/merge-recursive.c:57
+#, c-format
+msgid "cannot handle more than %d base. Ignoring %s."
+msgid_plural "cannot handle more than %d bases. Ignoring %s."
+msgstr[0] "no es pot gestionar més d'%d base. S'està ignorant %s."
+msgstr[1] "no es poden gestionar més de %d bases. S'està ignorant %s."
+
+#: builtin/merge-recursive.c:65
+msgid "not handling anything other than two heads merge."
+msgstr "no s'està gestionant res a part de la fusió de dos caps."
+
+#: builtin/merge-recursive.c:74 builtin/merge-recursive.c:76
+#, c-format
+msgid "could not resolve ref '%s'"
+msgstr "no s'ha pogut resoldre la referència «%s»"
+
+#: builtin/merge-recursive.c:82
+#, c-format
+msgid "Merging %s with %s\n"
+msgstr "S'està fusionant %s amb %s\n"
+
+#: builtin/mktree.c:66
+msgid "git mktree [-z] [--missing] [--batch]"
+msgstr "git mktree [-z] [--missing] [--batch]"
+
+#: builtin/mktree.c:154
+msgid "input is NUL terminated"
+msgstr "l'entrada és acabada amb NUL"
+
+#: builtin/mktree.c:155 builtin/write-tree.c:26
+msgid "allow missing objects"
+msgstr "permet els objectes absents"
+
+#: builtin/mktree.c:156
+msgid "allow creation of more than one tree"
+msgstr "permet la creació de més d'un arbre"
+
+#: builtin/multi-pack-index.c:9
+msgid ""
+"git multi-pack-index [<options>] (write|verify|expire|repack --batch-"
+"size=<size>)"
+msgstr ""
+
+#: builtin/multi-pack-index.c:26
+msgid "object directory containing set of packfile and pack-index pairs"
+msgstr ""
+
+#: builtin/multi-pack-index.c:29
+msgid ""
+"during repack, collect pack-files of smaller size into a batch that is "
+"larger than this size"
+msgstr ""
+
+#: builtin/multi-pack-index.c:50 builtin/prune-packed.c:67
+msgid "too many arguments"
+msgstr "hi ha massa paràmetres"
+
+#: builtin/multi-pack-index.c:60
+msgid "--batch-size option is only for 'repack' subcommand"
+msgstr ""
+
+#: builtin/multi-pack-index.c:69
+#, fuzzy, c-format
+msgid "unrecognized subcommand: %s"
+msgstr "subordre desconeguda: %s"
+
+#: builtin/mv.c:18
+msgid "git mv [<options>] <source>... <destination>"
+msgstr "git mv [<opcions>] <font>... <destí>"
+
+#: builtin/mv.c:83
+#, c-format
+msgid "Directory %s is in index and no submodule?"
+msgstr "El directori %s és en l'índex i no hi ha cap submòdul?"
+
+#: builtin/mv.c:85
+msgid "Please stage your changes to .gitmodules or stash them to proceed"
+msgstr ""
+"Feu «stage» dels vostres canvis a .gitmodules o feu «stash» dels mateixos "
+"per a procedir"
+
+#: builtin/mv.c:103
+#, c-format
+msgid "%.*s is in index"
+msgstr "%.*s és en l'índex"
+
+#: builtin/mv.c:125
+msgid "force move/rename even if target exists"
+msgstr "força el moviment / canvi de nom encara que el destí existeixi"
+
+#: builtin/mv.c:127
+msgid "skip move/rename errors"
+msgstr "omet els errors de moviment / canvi de nom"
+
+#: builtin/mv.c:169
+#, c-format
+msgid "destination '%s' is not a directory"
+msgstr "el destí «%s» no és un directori"
+
+#: builtin/mv.c:180
+#, c-format
+msgid "Checking rename of '%s' to '%s'\n"
+msgstr "S'està comprovant el canvi de nom de «%s» a «%s»\n"
+
+#: builtin/mv.c:184
+msgid "bad source"
+msgstr "font incorrecta"
+
+#: builtin/mv.c:187
+msgid "can not move directory into itself"
+msgstr "no es pot moure un directori a dins d'ell mateix"
+
+#: builtin/mv.c:190
+msgid "cannot move directory over file"
+msgstr "no es pot moure un directori sobre un fitxer"
+
+#: builtin/mv.c:199
+msgid "source directory is empty"
+msgstr "el directori font està buit"
+
+#: builtin/mv.c:224
+msgid "not under version control"
+msgstr "no està sota control de versions"
+
+#: builtin/mv.c:227
+msgid "destination exists"
+msgstr "el destí existeix"
+
+#: builtin/mv.c:235
+#, c-format
+msgid "overwriting '%s'"
+msgstr "s'està sobreescrivint «%s»"
+
+#: builtin/mv.c:238
+msgid "Cannot overwrite"
+msgstr "No es pot sobreescriure"
+
+#: builtin/mv.c:241
+msgid "multiple sources for the same target"
+msgstr "múltiples fonts per al mateix destí"
+
+#: builtin/mv.c:243
+msgid "destination directory does not exist"
+msgstr "el directori destí no existeix"
+
+#: builtin/mv.c:250
+#, c-format
+msgid "%s, source=%s, destination=%s"
+msgstr "%s, origen=%s, destí=%s"
+
+#: builtin/mv.c:271
+#, c-format
+msgid "Renaming %s to %s\n"
+msgstr "S'està canviant el nom de %s a %s\n"
+
+#: builtin/mv.c:277 builtin/remote.c:716 builtin/repack.c:518
+#, c-format
+msgid "renaming '%s' failed"
+msgstr "el canvi del nom de «%s» ha fallat"
+
+#: builtin/name-rev.c:403
+msgid "git name-rev [<options>] <commit>..."
+msgstr "git name-rev [<opcions>] <comissió>..."
+
+#: builtin/name-rev.c:404
+msgid "git name-rev [<options>] --all"
+msgstr "git name-rev [<opcions>] --all"
+
+#: builtin/name-rev.c:405
+msgid "git name-rev [<options>] --stdin"
+msgstr "git name-rev [<opcions>] --stdin"
+
+#: builtin/name-rev.c:462
+msgid "print only names (no SHA-1)"
+msgstr "imprimeix només els noms (sense SHA-1)"
+
+#: builtin/name-rev.c:463
+msgid "only use tags to name the commits"
+msgstr "només usa les etiquetes per a anomenar les comissions"
+
+#: builtin/name-rev.c:465
+msgid "only use refs matching <pattern>"
+msgstr "només usa les referències que coincideixin amb <patró>"
+
+#: builtin/name-rev.c:467
+msgid "ignore refs matching <pattern>"
+msgstr "ignora les referències que coincideixin amb <patró>"
+
+#: builtin/name-rev.c:469
+msgid "list all commits reachable from all refs"
+msgstr "llista totes les comissions abastables de totes les referències"
+
+#: builtin/name-rev.c:470
+msgid "read from stdin"
+msgstr "llegeix de stdin"
+
+#: builtin/name-rev.c:471
+msgid "allow to print `undefined` names (default)"
+msgstr "permet imprimir els noms `undefined` (per defecte)"
+
+#: builtin/name-rev.c:477
+msgid "dereference tags in the input (internal use)"
+msgstr "desreferencia les etiquetes en l'entrada (ús intern)"
+
+#: builtin/notes.c:28
+msgid "git notes [--ref <notes-ref>] [list [<object>]]"
+msgstr "git notes [--ref <referència-de-notes>] [llista [<objecte>]]"
+
+#: builtin/notes.c:29
+msgid ""
+"git notes [--ref <notes-ref>] add [-f] [--allow-empty] [-m <msg> | -F <file> "
+"| (-c | -C) <object>] [<object>]"
+msgstr ""
+"git notes [--ref <referència-de-notes>] add [-f] [--allow-empty] [-m "
+"<missatge> | -F <fitxer> | (-c | -C) <objecte>] [<objecte>]"
+
+#: builtin/notes.c:30
+msgid "git notes [--ref <notes-ref>] copy [-f] <from-object> <to-object>"
+msgstr ""
+"git notes [--ref <referència-de-notes>] copy [-f] <d'objecte> <a-objecte>"
+
+#: builtin/notes.c:31
+msgid ""
+"git notes [--ref <notes-ref>] append [--allow-empty] [-m <msg> | -F <file> | "
+"(-c | -C) <object>] [<object>]"
+msgstr ""
+"git notes [--ref <referència-de-notes>] append [--allow-empty] [-m "
+"<missatge> | -F <fitxer> | (-c | -C) <objecte>] [<objecte>]"
+
+#: builtin/notes.c:32
+msgid "git notes [--ref <notes-ref>] edit [--allow-empty] [<object>]"
+msgstr ""
+"git notes [--ref <referència-de-notes>] edit [--allow-empty] [<objecte>]"
+
+#: builtin/notes.c:33
+msgid "git notes [--ref <notes-ref>] show [<object>]"
+msgstr "git notes [--ref <referència-de-notes>] show [<objecte>]"
+
+#: builtin/notes.c:34
+msgid ""
+"git notes [--ref <notes-ref>] merge [-v | -q] [-s <strategy>] <notes-ref>"
+msgstr ""
+"git notes [--ref <referència-de-notes>] merge [-v | -q] [-s <estratègia>] "
+"<referència-de-notes>"
+
+#: builtin/notes.c:35
+msgid "git notes merge --commit [-v | -q]"
+msgstr "git notes merge --commit [-v | -q]"
+
+#: builtin/notes.c:36
+msgid "git notes merge --abort [-v | -q]"
+msgstr "git notes merge --abort [-v | -q]"
+
+#: builtin/notes.c:37
+msgid "git notes [--ref <notes-ref>] remove [<object>...]"
+msgstr "git notes [--ref <referència-de-notes>] remove [<objecte>...]"
+
+#: builtin/notes.c:38
+msgid "git notes [--ref <notes-ref>] prune [-n] [-v]"
+msgstr "git notes [--ref <referència-de-notes>] prune [-n] [-v]"
+
+#: builtin/notes.c:39
+msgid "git notes [--ref <notes-ref>] get-ref"
+msgstr "git notes [--ref <referència-de-notes>] get-ref"
+
+#: builtin/notes.c:44
+msgid "git notes [list [<object>]]"
+msgstr "git notes [llista [<objecte>]]"
+
+#: builtin/notes.c:49
+msgid "git notes add [<options>] [<object>]"
+msgstr "git notes add [<opcions>] [<objecte>]"
+
+#: builtin/notes.c:54
+msgid "git notes copy [<options>] <from-object> <to-object>"
+msgstr "git notes copy [<opcions>] <d'objecte> <a-objecte>"
+
+#: builtin/notes.c:55
+msgid "git notes copy --stdin [<from-object> <to-object>]..."
+msgstr "git notes copy --stdin [<d'objecte> <a-objecte>]..."
+
+#: builtin/notes.c:60
+msgid "git notes append [<options>] [<object>]"
+msgstr "git notes append [<opcions>] [<objecte>]"
+
+#: builtin/notes.c:65
+msgid "git notes edit [<object>]"
+msgstr "git notes edit [<objecte>]"
+
+#: builtin/notes.c:70
+msgid "git notes show [<object>]"
+msgstr "git notes show [<objecte>]"
+
+#: builtin/notes.c:75
+msgid "git notes merge [<options>] <notes-ref>"
+msgstr "git notes merge [<opcions>] <referència-de-notes>"
+
+#: builtin/notes.c:76
+msgid "git notes merge --commit [<options>]"
+msgstr "git notes merge --commit [<opcions>]"
+
+#: builtin/notes.c:77
+msgid "git notes merge --abort [<options>]"
+msgstr "git notes merge --abort [<opcions>]"
+
+#: builtin/notes.c:82
+msgid "git notes remove [<object>]"
+msgstr "git notes remove [<objecte>]"
+
+#: builtin/notes.c:87
+msgid "git notes prune [<options>]"
+msgstr "git notes prune [<opcions>]"
+
+#: builtin/notes.c:92
+msgid "git notes get-ref"
+msgstr "git notes get-ref"
+
+#: builtin/notes.c:97
+msgid "Write/edit the notes for the following object:"
+msgstr "Escriviu/editeu les notes per l'objecte següent:"
+
+#: builtin/notes.c:150
+#, c-format
+msgid "unable to start 'show' for object '%s'"
+msgstr "no s'ha pogut iniciar 'show' per a l'objecte «%s»"
+
+#: builtin/notes.c:154
+msgid "could not read 'show' output"
+msgstr "no s'ha pogut llegir la sortida de 'show'"
+
+#: builtin/notes.c:162
+#, c-format
+msgid "failed to finish 'show' for object '%s'"
+msgstr "S'ha produït un error en finalitzar 'show' per a l'objecte «%s»"
+
+#: builtin/notes.c:197
+msgid "please supply the note contents using either -m or -F option"
+msgstr ""
+"especifiqueu el contingut de la nota fent servir l'opció -m o l'opció -F"
+
+#: builtin/notes.c:206
+msgid "unable to write note object"
+msgstr "no s'ha pogut escriure l'objecte de nota"
+
+#: builtin/notes.c:208
+#, c-format
+msgid "the note contents have been left in %s"
+msgstr "s'han deixat els continguts de la nota en %s"
+
+#: builtin/notes.c:242 builtin/tag.c:532
+#, c-format
+msgid "could not open or read '%s'"
+msgstr "no s'ha pogut obrir o llegir «%s»"
+
+#: builtin/notes.c:263 builtin/notes.c:313 builtin/notes.c:315
+#: builtin/notes.c:383 builtin/notes.c:438 builtin/notes.c:526
+#: builtin/notes.c:531 builtin/notes.c:610 builtin/notes.c:672
+#, c-format
+msgid "failed to resolve '%s' as a valid ref."
+msgstr "s'ha produït un error en resoldre «%s» com a referència vàlida."
+
+#: builtin/notes.c:265
+#, c-format
+msgid "failed to read object '%s'."
+msgstr "s'ha produït un error en llegir l'objecte «%s»."
+
+#: builtin/notes.c:268
+#, c-format
+msgid "cannot read note data from non-blob object '%s'."
+msgstr "no es poden llegir les dades de node de l'objecte no de blob «%s»."
+
+#: builtin/notes.c:309
+#, c-format
+msgid "malformed input line: '%s'."
+msgstr "línia d'entrada mal formada: «%s»."
+
+#: builtin/notes.c:324
+#, c-format
+msgid "failed to copy notes from '%s' to '%s'"
+msgstr "s'ha produït un error en copiar les notes de «%s» a «%s»"
+
+#. TRANSLATORS: the first %s will be replaced by a git
+#. notes command: 'add', 'merge', 'remove', etc.
+#.
+#: builtin/notes.c:356
+#, c-format
+msgid "refusing to %s notes in %s (outside of refs/notes/)"
+msgstr "s'està refusant %s les notes en %s (fora de refs/notes/)"
+
+#: builtin/notes.c:376 builtin/notes.c:431 builtin/notes.c:509
+#: builtin/notes.c:521 builtin/notes.c:598 builtin/notes.c:665
+#: builtin/notes.c:815 builtin/notes.c:963 builtin/notes.c:985
+msgid "too many parameters"
+msgstr "massa paràmetres"
+
+#: builtin/notes.c:389 builtin/notes.c:678
+#, c-format
+msgid "no note found for object %s."
+msgstr "no s'ha trobat cap nota per a l'objecte %s."
+
+#: builtin/notes.c:410 builtin/notes.c:576
+msgid "note contents as a string"
+msgstr "anota els continguts com a cadena"
+
+#: builtin/notes.c:413 builtin/notes.c:579
+msgid "note contents in a file"
+msgstr "anota els continguts en un fitxer"
+
+#: builtin/notes.c:416 builtin/notes.c:582
+msgid "reuse and edit specified note object"
+msgstr "reusa i edita l'objecte de nota especificat"
+
+#: builtin/notes.c:419 builtin/notes.c:585
+msgid "reuse specified note object"
+msgstr "reusa l'objecte de nota especificat"
+
+#: builtin/notes.c:422 builtin/notes.c:588
+msgid "allow storing empty note"
+msgstr "permet l'emmagatzematge d'una nota buida"
+
+#: builtin/notes.c:423 builtin/notes.c:496
+msgid "replace existing notes"
+msgstr "reemplaça les notes existents"
+
+#: builtin/notes.c:448
+#, c-format
+msgid ""
+"Cannot add notes. Found existing notes for object %s. Use '-f' to overwrite "
+"existing notes"
+msgstr ""
+"No es poden afegir les notes. S'han trobat notes existents de l'objecte %s. "
+"Useu '-f' per a sobreescriure les notes existents"
+
+#: builtin/notes.c:463 builtin/notes.c:544
+#, c-format
+msgid "Overwriting existing notes for object %s\n"
+msgstr "S'estan sobreescrivint les notes existents de l'objecte %s\n"
+
+#: builtin/notes.c:475 builtin/notes.c:637 builtin/notes.c:902
+#, c-format
+msgid "Removing note for object %s\n"
+msgstr "S'està eliminant la nota de l'objecte %s\n"
+
+#: builtin/notes.c:497
+msgid "read objects from stdin"
+msgstr "llegeix els objectes des de stdin"
+
+#: builtin/notes.c:499
+msgid "load rewriting config for <command> (implies --stdin)"
+msgstr ""
+"carrega la configuració de reescriptura per a <ordre> (implica --stdin)"
+
+#: builtin/notes.c:517
+msgid "too few parameters"
+msgstr "hi ha massa pocs paràmetres"
+
+#: builtin/notes.c:538
+#, c-format
+msgid ""
+"Cannot copy notes. Found existing notes for object %s. Use '-f' to overwrite "
+"existing notes"
+msgstr ""
+"No es poden copiar les notes. S'han trobat notes existents de l'objecte %s. "
+"Useu '-f' per a sobreescriure les notes existents."
+
+#: builtin/notes.c:550
+#, c-format
+msgid "missing notes on source object %s. Cannot copy."
+msgstr "manquen notes a l'objecte font %s. No es pot copiar."
+
+#: builtin/notes.c:603
+#, c-format
+msgid ""
+"The -m/-F/-c/-C options have been deprecated for the 'edit' subcommand.\n"
+"Please use 'git notes add -f -m/-F/-c/-C' instead.\n"
+msgstr ""
+"Es desaconsellen les opcions -m/-F/-c/-C en favor de la subordre 'edit'.\n"
+"Useu «git notes add -f -m/-F/-c/-C» en lloc d'això.\n"
+
+#: builtin/notes.c:698
+msgid "failed to delete ref NOTES_MERGE_PARTIAL"
+msgstr "s'ha produït un error en suprimir la referència NOTES_MERGE_PARTIAL"
+
+#: builtin/notes.c:700
+msgid "failed to delete ref NOTES_MERGE_REF"
+msgstr "s'ha produït un error en suprimir la referència NOTES_MERGE_REF"
+
+#: builtin/notes.c:702
+msgid "failed to remove 'git notes merge' worktree"
+msgstr ""
+"s'ha produït un error en eliminar l'arbre de treball de 'git notes merge'"
+
+#: builtin/notes.c:722
+msgid "failed to read ref NOTES_MERGE_PARTIAL"
+msgstr "s'ha produït un error en llegir la referència NOTES_MERGE_PARTIAL"
+
+#: builtin/notes.c:724
+msgid "could not find commit from NOTES_MERGE_PARTIAL."
+msgstr "no s'ha pogut trobar cap comissió de NOTES_MERGE_PARTIAL."
+
+#: builtin/notes.c:726
+msgid "could not parse commit from NOTES_MERGE_PARTIAL."
+msgstr "no s'ha pogut analitzar la comissió de NOTES_MERGE_PARTIAL."
+
+#: builtin/notes.c:739
+msgid "failed to resolve NOTES_MERGE_REF"
+msgstr "s'ha produït un error en resoldre NOTES_MERGE_REF"
+
+#: builtin/notes.c:742
+msgid "failed to finalize notes merge"
+msgstr "s'ha produït un error en finalitzar la fusió de notes"
+
+#: builtin/notes.c:768
+#, c-format
+msgid "unknown notes merge strategy %s"
+msgstr "estratègia de fusió de notes desconeguda %s"
+
+#: builtin/notes.c:784
+msgid "General options"
+msgstr "Opcions generals"
+
+#: builtin/notes.c:786
+msgid "Merge options"
+msgstr "Opcions de fusió"
+
+#: builtin/notes.c:788
+msgid ""
+"resolve notes conflicts using the given strategy (manual/ours/theirs/union/"
+"cat_sort_uniq)"
+msgstr ""
+"resol els conflictes de nota usant l'estratègia donada (manual/ours/theirs/"
+"union/cat_sort_uniq)"
+
+#: builtin/notes.c:790
+msgid "Committing unmerged notes"
+msgstr "S'estan cometent les notes sense fusionar"
+
+#: builtin/notes.c:792
+msgid "finalize notes merge by committing unmerged notes"
+msgstr "finalitza la fusió de notes cometent les notes sense fusionar"
+
+#: builtin/notes.c:794
+msgid "Aborting notes merge resolution"
+msgstr "S'està avortant la resolució de fusió de notes"
+
+#: builtin/notes.c:796
+msgid "abort notes merge"
+msgstr "avorta la fusió de notes"
+
+#: builtin/notes.c:807
+msgid "cannot mix --commit, --abort or -s/--strategy"
+msgstr "no es pot combinar --commit, --abort i -s/--strategy"
+
+#: builtin/notes.c:812
+msgid "must specify a notes ref to merge"
+msgstr "cal especificar una referència de notes a fusionar"
+
+#: builtin/notes.c:836
+#, c-format
+msgid "unknown -s/--strategy: %s"
+msgstr "-s/--strategy desconeguda: %s"
+
+#: builtin/notes.c:873
+#, c-format
+msgid "a notes merge into %s is already in-progress at %s"
+msgstr "una fusió de notes a %s ja està en curs a %s"
+
+#: builtin/notes.c:876
+#, c-format
+msgid "failed to store link to current notes ref (%s)"
+msgstr ""
+"s'ha produït un error en emmagatzemar l'enllaç a la referència de notes "
+"actual (%s)"
+
+#: builtin/notes.c:878
+#, c-format
+msgid ""
+"Automatic notes merge failed. Fix conflicts in %s and commit the result with "
+"'git notes merge --commit', or abort the merge with 'git notes merge --"
+"abort'.\n"
+msgstr ""
+"La fusió de notes automàtica ha fallat. Arregleu els conflictes en %s i "
+"cometeu el resultat amb 'git notes merge --commit', o avorteu la fusió amb "
+"'git notes merge --abort'.\n"
+
+#: builtin/notes.c:897 builtin/tag.c:545
+#, c-format
+msgid "Failed to resolve '%s' as a valid ref."
+msgstr "S'ha produït un error en resoldre «%s» com a referència vàlida."
+
+#: builtin/notes.c:900
+#, c-format
+msgid "Object %s has no note\n"
+msgstr "L'objecte %s no té cap nota\n"
+
+#: builtin/notes.c:912
+msgid "attempt to remove non-existent note is not an error"
+msgstr "l'intent d'eliminar una nota no existent no és un error"
+
+#: builtin/notes.c:915
+msgid "read object names from the standard input"
+msgstr "llegeix els noms d'objecte des de l'entrada estàndard"
+
+#: builtin/notes.c:954 builtin/prune.c:130 builtin/worktree.c:164
+msgid "do not remove, show only"
+msgstr "no eliminis, només mostra"
+
+#: builtin/notes.c:955
+msgid "report pruned notes"
+msgstr "informa de notes podades"
+
+#: builtin/notes.c:998
+msgid "notes-ref"
+msgstr "referència de notes"
+
+#: builtin/notes.c:999
+msgid "use notes from <notes-ref>"
+msgstr "usa les notes de <referència-de-notes>"
+
+#: builtin/notes.c:1034 builtin/stash.c:1607
+#, c-format
+msgid "unknown subcommand: %s"
+msgstr "subordre desconeguda: %s"
+
+#: builtin/pack-objects.c:52
+msgid ""
+"git pack-objects --stdout [<options>...] [< <ref-list> | < <object-list>]"
+msgstr ""
+"git pack-objects --stdout [<opcions>...] [< <llista-de-referències> | < "
+"<llista-de-objectes>]"
+
+#: builtin/pack-objects.c:53
+msgid ""
+"git pack-objects [<options>...] <base-name> [< <ref-list> | < <object-list>]"
+msgstr ""
+"git pack-objects [<opcions>...] <nom-base> [< <llista-de-referències> | < "
+"<llista-de-objectes>]"
+
+#: builtin/pack-objects.c:428
+#, fuzzy, c-format
+msgid "bad packed object CRC for %s"
+msgstr "ignora els objectes empaquetats"
+
+#: builtin/pack-objects.c:439
+#, fuzzy, c-format
+msgid "corrupt packed object for %s"
+msgstr "ignora els objectes empaquetats"
+
+#: builtin/pack-objects.c:570
+#, fuzzy, c-format
+msgid "recursive delta detected for object %s"
+msgstr "no s'ha rebut l'objecte esperat %s"
+
+#: builtin/pack-objects.c:781
+#, c-format
+msgid "ordered %u objects, expected %<PRIu32>"
+msgstr ""
+
+#: builtin/pack-objects.c:794
+#, fuzzy, c-format
+msgid "packfile is invalid: %s"
+msgstr "%s no vàlid"
+
+#: builtin/pack-objects.c:798
+#, fuzzy, c-format
+msgid "unable to open packfile for reuse: %s"
+msgstr "no s'ha pogut obrir o llegir %s"
+
+#: builtin/pack-objects.c:802
+#, fuzzy
+msgid "unable to seek in reused packfile"
+msgstr "no es pot llegir el fitxer d'índex"
+
+#: builtin/pack-objects.c:813
+#, fuzzy
+msgid "unable to read from reused packfile"
+msgstr "no es pot llegir el fitxer d'índex"
+
+#: builtin/pack-objects.c:841
+msgid "disabling bitmap writing, packs are split due to pack.packSizeLimit"
+msgstr ""
+"s'està inhabilitant l'escriptura de mapes de bits, es divideixen els paquets "
+"a causa de pack.packSizeLimit"
+
+#: builtin/pack-objects.c:854
+msgid "Writing objects"
+msgstr "S'estan escrivint els objectes"
+
+#: builtin/pack-objects.c:917 builtin/update-index.c:90
+#, c-format
+msgid "failed to stat %s"
+msgstr "s'ha produït un error en fer stat a %s"
+
+#: builtin/pack-objects.c:970
+#, c-format
+msgid "wrote %<PRIu32> objects while expecting %<PRIu32>"
+msgstr ""
+
+#: builtin/pack-objects.c:1164
+msgid "disabling bitmap writing, as some objects are not being packed"
+msgstr ""
+"s'està inhabilitant l'escriptura de mapes de bits, perquè alguns objectes no "
+"s'empaqueten"
+
+#: builtin/pack-objects.c:1592
+#, fuzzy, c-format
+msgid "delta base offset overflow in pack for %s"
+msgstr "el desplaçament de base de diferències està fora de límits"
+
+#: builtin/pack-objects.c:1601
+#, fuzzy, c-format
+msgid "delta base offset out of bound for %s"
+msgstr "el desplaçament de base de diferències està fora de límits"
+
+#: builtin/pack-objects.c:1870
+msgid "Counting objects"
+msgstr "S'estan comptant els objectes"
+
+#: builtin/pack-objects.c:2000
+#, fuzzy, c-format
+msgid "unable to get size of %s"
+msgstr "no s'ha pogut moure %s a %s"
+
+#: builtin/pack-objects.c:2015
+#, fuzzy, c-format
+msgid "unable to parse object header of %s"
+msgstr "no s'ha pogut analitzar l'objecte: %s"
+
+#: builtin/pack-objects.c:2085 builtin/pack-objects.c:2101
+#: builtin/pack-objects.c:2111
+#, fuzzy, c-format
+msgid "object %s cannot be read"
+msgstr "objecte %s no trobat"
+
+#: builtin/pack-objects.c:2088 builtin/pack-objects.c:2115
+#, c-format
+msgid "object %s inconsistent object length (%<PRIuMAX> vs %<PRIuMAX>)"
+msgstr ""
+
+#: builtin/pack-objects.c:2125
+msgid "suboptimal pack - out of memory"
+msgstr ""
+
+#: builtin/pack-objects.c:2440
+#, c-format
+msgid "Delta compression using up to %d threads"
+msgstr ""
+
+#: builtin/pack-objects.c:2572
+#, fuzzy, c-format
+msgid "unable to pack objects reachable from tag %s"
+msgstr "inclou els objectes abastables de qualsevol referència"
+
+#: builtin/pack-objects.c:2659
+msgid "Compressing objects"
+msgstr "S'estan comprimint els objectes"
+
+#: builtin/pack-objects.c:2665
+msgid "inconsistency with delta count"
+msgstr ""
+
+#: builtin/pack-objects.c:2742
+#, c-format
+msgid ""
+"expected edge object ID, got garbage:\n"
+" %s"
+msgstr ""
+
+#: builtin/pack-objects.c:2748
+#, c-format
+msgid ""
+"expected object ID, got garbage:\n"
+" %s"
+msgstr ""
+
+#: builtin/pack-objects.c:2846
+msgid "invalid value for --missing"
+msgstr "valor no vàlid per a --missing"
+
+#: builtin/pack-objects.c:2905 builtin/pack-objects.c:3013
+#, fuzzy
+msgid "cannot open pack index"
+msgstr "no es pot fer pread en el fitxer de paquet"
+
+#: builtin/pack-objects.c:2936
+#, c-format
+msgid "loose object at %s could not be examined"
+msgstr ""
+
+#: builtin/pack-objects.c:3021
+#, fuzzy
+msgid "unable to force loose object"
+msgstr "no s'ha pogut escriure l'objecte de nota"
+
+#: builtin/pack-objects.c:3113
+#, fuzzy, c-format
+msgid "not a rev '%s'"
+msgstr "no es pot llegir «%s»"
+
+#: builtin/pack-objects.c:3116
+#, c-format
+msgid "bad revision '%s'"
+msgstr "revisió incorrecte «%s»"
+
+#: builtin/pack-objects.c:3141
+msgid "unable to add recent objects"
+msgstr "no s'han pogut afegir els objectes recents"
+
+#: builtin/pack-objects.c:3194
+#, c-format
+msgid "unsupported index version %s"
+msgstr "versió d'índex no compatible %s"
+
+#: builtin/pack-objects.c:3198
+#, c-format
+msgid "bad index version '%s'"
+msgstr "versió d'índex incorrecta «%s»"
+
+#: builtin/pack-objects.c:3236
+msgid "<version>[,<offset>]"
+msgstr "<versió>[,<desplaçament>]"
+
+#: builtin/pack-objects.c:3237
+msgid "write the pack index file in the specified idx format version"
+msgstr ""
+"escriu el fitxer d'índex de paquet en la versió de format d'índex "
+"especificada"
+
+#: builtin/pack-objects.c:3240
+msgid "maximum size of each output pack file"
+msgstr "mida màxima de cada fitxer empaquetat de sortida"
+
+#: builtin/pack-objects.c:3242
+msgid "ignore borrowed objects from alternate object store"
+msgstr "ignora els objectes prestats d'un emmagatzematge d'objectes alternatiu"
+
+#: builtin/pack-objects.c:3244
+msgid "ignore packed objects"
+msgstr "ignora els objectes empaquetats"
+
+#: builtin/pack-objects.c:3246
+msgid "limit pack window by objects"
+msgstr "limita la finestra d'empaquetament per objectes"
+
+#: builtin/pack-objects.c:3248
+msgid "limit pack window by memory in addition to object limit"
+msgstr ""
+"limita la finestra d'empaquetament per memòria a més del límit d'objectes"
+
+#: builtin/pack-objects.c:3250
+msgid "maximum length of delta chain allowed in the resulting pack"
+msgstr ""
+"longitud màxima de la cadena de diferències permesa en el paquet resultant"
+
+#: builtin/pack-objects.c:3252
+msgid "reuse existing deltas"
+msgstr "reusa les diferències existents"
+
+#: builtin/pack-objects.c:3254
+msgid "reuse existing objects"
+msgstr "reusa els objectes existents"
+
+#: builtin/pack-objects.c:3256
+msgid "use OFS_DELTA objects"
+msgstr "usa objectes OFS_DELTA"
+
+#: builtin/pack-objects.c:3258
+msgid "use threads when searching for best delta matches"
+msgstr "usa fils en cercar les millores coincidències de diferències"
+
+#: builtin/pack-objects.c:3260
+msgid "do not create an empty pack output"
+msgstr "no creïs una emissió de paquet buida"
+
+#: builtin/pack-objects.c:3262
+msgid "read revision arguments from standard input"
+msgstr "llegeix els paràmetres de revisió des de l'entrada estàndard"
+
+#: builtin/pack-objects.c:3264
+msgid "limit the objects to those that are not yet packed"
+msgstr "limita els objectes als quals encara no s'hagin empaquetat"
+
+#: builtin/pack-objects.c:3267
+msgid "include objects reachable from any reference"
+msgstr "inclou els objectes abastables de qualsevol referència"
+
+#: builtin/pack-objects.c:3270
+msgid "include objects referred by reflog entries"
+msgstr ""
+"inclou els objectes als quals facin referència les entrades del registre de "
+"referències"
+
+#: builtin/pack-objects.c:3273
+msgid "include objects referred to by the index"
+msgstr "inclou els objectes als quals faci referència l'índex"
+
+#: builtin/pack-objects.c:3276
+msgid "output pack to stdout"
+msgstr "emet el paquet a stdout"
+
+#: builtin/pack-objects.c:3278
+msgid "include tag objects that refer to objects to be packed"
+msgstr ""
+"inclou els objectes d'etiqueta que facin referència als objectes a empaquetar"
+
+#: builtin/pack-objects.c:3280
+msgid "keep unreachable objects"
+msgstr "retén els objectes inabastables"
+
+#: builtin/pack-objects.c:3282
+msgid "pack loose unreachable objects"
+msgstr "empaqueta els objectes inabastables solts"
+
+#: builtin/pack-objects.c:3284
+msgid "unpack unreachable objects newer than <time>"
+msgstr "desempaqueta els objectes inabastables més nous que <hora>"
+
+#: builtin/pack-objects.c:3287
+msgid "use the sparse reachability algorithm"
+msgstr ""
+
+#: builtin/pack-objects.c:3289
+msgid "create thin packs"
+msgstr "crea paquets prims"
+
+#: builtin/pack-objects.c:3291
+msgid "create packs suitable for shallow fetches"
+msgstr "crea paquets adequats per a les obtencions superficials"
+
+#: builtin/pack-objects.c:3293
+msgid "ignore packs that have companion .keep file"
+msgstr "ignora els paquets que tinguin un fitxer .keep corresponent"
+
+#: builtin/pack-objects.c:3295
+#, fuzzy
+msgid "ignore this pack"
+msgstr "usa el paquet prim"
+
+#: builtin/pack-objects.c:3297
+msgid "pack compression level"
+msgstr "nivell de compressió de paquet"
+
+#: builtin/pack-objects.c:3299
+msgid "do not hide commits by grafts"
+msgstr "no amaguis les comissions per empelt"
+
+#: builtin/pack-objects.c:3301
+msgid "use a bitmap index if available to speed up counting objects"
+msgstr ""
+"usa un índex de mapa de bits, si està disponible, per a accelerar el "
+"recompte d'objectes"
+
+#: builtin/pack-objects.c:3303
+msgid "write a bitmap index together with the pack index"
+msgstr "escriu un índex de mapa de bits juntament amb l'índex de paquet"
+
+#: builtin/pack-objects.c:3307
+#, fuzzy
+msgid "write a bitmap index if possible"
+msgstr "escriu índex de mapa de bits"
+
+#: builtin/pack-objects.c:3311
+msgid "handling for missing objects"
+msgstr "gestió dels objectes absents"
+
+#: builtin/pack-objects.c:3314
+msgid "do not pack objects in promisor packfiles"
+msgstr ""
+
+#: builtin/pack-objects.c:3316
+#, fuzzy
+msgid "respect islands during delta compression"
+msgstr "mida de la finestra que s'usa per a compressió de diferències"
+
+#: builtin/pack-objects.c:3345
+#, c-format
+msgid "delta chain depth %d is too deep, forcing %d"
+msgstr ""
+
+#: builtin/pack-objects.c:3350
+#, c-format
+msgid "pack.deltaCacheLimit is too high, forcing %d"
+msgstr ""
+
+#: builtin/pack-objects.c:3404
+msgid "--max-pack-size cannot be used to build a pack for transfer"
+msgstr ""
+
+#: builtin/pack-objects.c:3406
+msgid "minimum pack size limit is 1 MiB"
+msgstr ""
+
+#: builtin/pack-objects.c:3411
+#, fuzzy
+msgid "--thin cannot be used to build an indexable pack"
+msgstr "--fix-thin no es pot usar sense --stdin"
+
+#: builtin/pack-objects.c:3414
+#, fuzzy
+msgid "--keep-unreachable and --unpack-unreachable are incompatible"
+msgstr "--keep-unreachable i -A són incompatibles"
+
+#: builtin/pack-objects.c:3420
+#, fuzzy
+msgid "cannot use --filter without --stdout"
+msgstr "no es pot usar -a amb -d"
+
+#: builtin/pack-objects.c:3481
+msgid "Enumerating objects"
+msgstr "S'estan enumerant els objectes"
+
+#: builtin/pack-objects.c:3511
+#, c-format
+msgid "Total %<PRIu32> (delta %<PRIu32>), reused %<PRIu32> (delta %<PRIu32>)"
+msgstr ""
+"Total %<PRIu32> (diferències %<PRIu32>), reusat %<PRIu32> (diferències "
+"%<PRIu32>)"
+
+#: builtin/pack-refs.c:8
+msgid "git pack-refs [<options>]"
+msgstr "git pack-refs [<opcions>]"
+
+#: builtin/pack-refs.c:16
+msgid "pack everything"
+msgstr "empaqueta-ho tot"
+
+#: builtin/pack-refs.c:17
+msgid "prune loose refs (default)"
+msgstr "poda les referències soltes (per defecte)"
+
+#: builtin/prune-packed.c:9
+msgid "git prune-packed [-n | --dry-run] [-q | --quiet]"
+msgstr "git prune-packed [-n | --dry-run] [-q | --quiet]"
+
+#: builtin/prune-packed.c:42
+msgid "Removing duplicate objects"
+msgstr "S'estan eliminant objectes duplicats"
+
+#: builtin/prune.c:12
+msgid "git prune [-n] [-v] [--progress] [--expire <time>] [--] [<head>...]"
+msgstr "git prune [-n] [-v] [--progress] [--expire <hora>] [--] [<head>...]"
+
+#: builtin/prune.c:131
+msgid "report pruned objects"
+msgstr "informa d'objectes podats"
+
+#: builtin/prune.c:134
+msgid "expire objects older than <time>"
+msgstr "fes caducar els objectes més vells que <hora>"
+
+#: builtin/prune.c:136
+msgid "limit traversal to objects outside promisor packfiles"
+msgstr ""
+
+#: builtin/prune.c:150
+msgid "cannot prune in a precious-objects repo"
+msgstr "no es pot podar en un dipòsit d'objectes preciosos"
+
+#: builtin/pull.c:66 builtin/pull.c:68
+#, c-format
+msgid "Invalid value for %s: %s"
+msgstr "Valor no vàlid per a %s: %s"
+
+#: builtin/pull.c:88
+msgid "git pull [<options>] [<repository> [<refspec>...]]"
+msgstr "git pull [<opcions>] [<dipòsit> [<especificació-de-referència>...]]"
+
+#: builtin/pull.c:142
+msgid "control for recursive fetching of submodules"
+msgstr "controla l'obtenció recursiva de submòduls"
+
+#: builtin/pull.c:146
+msgid "Options related to merging"
+msgstr "Opcions relacionades amb fusionar"
+
+#: builtin/pull.c:149
+msgid "incorporate changes by rebasing rather than merging"
+msgstr "incorpora els canvis fent «rebase» en lloc de fusionar"
+
+#: builtin/pull.c:177 builtin/rebase.c:467 builtin/revert.c:126
+msgid "allow fast-forward"
+msgstr "permet l'avanç ràpid"
+
+#: builtin/pull.c:186
+msgid "automatically stash/stash pop before and after rebase"
+msgstr ""
+"fes «stash» i «stash pop» automàticament abans i després de fer «rebase»"
+
+#: builtin/pull.c:202
+msgid "Options related to fetching"
+msgstr "Opcions relacionades amb obtenir"
+
+#: builtin/pull.c:212
+msgid "force overwrite of local branch"
+msgstr "força la sobreescriptura de la branca local"
+
+#: builtin/pull.c:220
+msgid "number of submodules pulled in parallel"
+msgstr "nombre de submòduls baixats en paral·lel"
+
+#: builtin/pull.c:320
+#, c-format
+msgid "Invalid value for pull.ff: %s"
+msgstr "Valor no vàlid per a pull.ff: %s"
+
+#: builtin/pull.c:437
+msgid ""
+"There is no candidate for rebasing against among the refs that you just "
+"fetched."
+msgstr ""
+"No hi ha cap candidat sobre el qual fer «rebase» entre les referències que "
+"acabeu d'obtenir."
+
+#: builtin/pull.c:439
+msgid ""
+"There are no candidates for merging among the refs that you just fetched."
+msgstr ""
+"No hi ha candidats per a fusionar entre les referències que acabeu d'obtenir."
+
+#: builtin/pull.c:440
+msgid ""
+"Generally this means that you provided a wildcard refspec which had no\n"
+"matches on the remote end."
+msgstr ""
+"Generalment això vol dir que heu proveït una especificació de\n"
+"referència de comodí que no tenia cap coincidència en el costat remot."
+
+#: builtin/pull.c:443
+#, c-format
+msgid ""
+"You asked to pull from the remote '%s', but did not specify\n"
+"a branch. Because this is not the default configured remote\n"
+"for your current branch, you must specify a branch on the command line."
+msgstr ""
+"Heu demanat baixar del remot «%s», però no heu especificat cap branca.\n"
+"Perquè aquest no és el remot configurat per defecte per a la vostra\n"
+"branca actual, heu d'especificar una branca en la línia d'ordres."
+
+#: builtin/pull.c:448 builtin/rebase.c:1375 git-parse-remote.sh:73
+msgid "You are not currently on a branch."
+msgstr "Actualment no sou en cap branca."
+
+#: builtin/pull.c:450 builtin/pull.c:465 git-parse-remote.sh:79
+msgid "Please specify which branch you want to rebase against."
+msgstr "Especifiqueu sobre quina branca voleu fer «rebase»."
+
+#: builtin/pull.c:452 builtin/pull.c:467 git-parse-remote.sh:82
+msgid "Please specify which branch you want to merge with."
+msgstr "Especifiqueu amb quina branca voleu fusionar."
+
+#: builtin/pull.c:453 builtin/pull.c:468
+msgid "See git-pull(1) for details."
+msgstr "Vegeu git-pull(1) per detalls."
+
+#: builtin/pull.c:455 builtin/pull.c:461 builtin/pull.c:470
+#: builtin/rebase.c:1381 git-parse-remote.sh:64
+msgid "<remote>"
+msgstr "<remot>"
+
+#: builtin/pull.c:455 builtin/pull.c:470 builtin/pull.c:475
+#: git-parse-remote.sh:65
+msgid "<branch>"
+msgstr "<branca>"
+
+#: builtin/pull.c:463 builtin/rebase.c:1373 git-parse-remote.sh:75
+msgid "There is no tracking information for the current branch."
+msgstr "No hi ha cap informació de seguiment per a la branca actual."
+
+#: builtin/pull.c:472 git-parse-remote.sh:95
+msgid ""
+"If you wish to set tracking information for this branch you can do so with:"
+msgstr ""
+"Si voleu establir informació de seguiment per a aquesta branca, podeu fer-ho "
+"amb:"
+
+#: builtin/pull.c:477
+#, c-format
+msgid ""
+"Your configuration specifies to merge with the ref '%s'\n"
+"from the remote, but no such ref was fetched."
+msgstr ""
+"La vostra configuració especifica fusionar amb la referència «%s»\n"
+"del remot, però no s'ha obtingut tal referència."
+
+#: builtin/pull.c:587
+#, c-format
+msgid "unable to access commit %s"
+msgstr "no s'ha pogut accedir a la comissió %s"
+
+#: builtin/pull.c:867
+msgid "ignoring --verify-signatures for rebase"
+msgstr "s'està ignorant --verify-signatures en fer «rebase»"
+
+#: builtin/pull.c:922
+msgid "--[no-]autostash option is only valid with --rebase."
+msgstr "l'opció --[no-]-autostash és vàlid només amb --rebase."
+
+#: builtin/pull.c:930
+msgid "Updating an unborn branch with changes added to the index."
+msgstr ""
+"S'està actualitzant una branca no nascuda amb canvis afegits a l'índex."
+
+#: builtin/pull.c:934
+msgid "pull with rebase"
+msgstr "baixar fent «rebase»"
+
+#: builtin/pull.c:935
+msgid "please commit or stash them."
+msgstr "cometeu-los o emmagatzemeu-los."
+
+#: builtin/pull.c:960
+#, c-format
+msgid ""
+"fetch updated the current branch head.\n"
+"fast-forwarding your working tree from\n"
+"commit %s."
+msgstr ""
+"l'obtenció ha actualitzat HEAD de la branca actual.\n"
+"s'està avançant ràpidament el vostre arbre de treball des de\n"
+"la comissió %s."
+
+#: builtin/pull.c:966
+#, c-format
+msgid ""
+"Cannot fast-forward your working tree.\n"
+"After making sure that you saved anything precious from\n"
+"$ git diff %s\n"
+"output, run\n"
+"$ git reset --hard\n"
+"to recover."
+msgstr ""
+"No es pot avançar ràpidament el vostre arbre de treball.\n"
+"Després d'assegurar que hàgiu desat qualsevol cosa preciosa de la sortida "
+"de\n"
+"$ git diff %s\n"
+"executeu\n"
+"$ git reset --hard\n"
+"per a recuperar."
+
+#: builtin/pull.c:981
+msgid "Cannot merge multiple branches into empty head."
+msgstr "No es poden fusionar múltiples branques a un HEAD buit."
+
+#: builtin/pull.c:985
+msgid "Cannot rebase onto multiple branches."
+msgstr "No es pot fer «rebase» sobre múltiples branques."
+
+#: builtin/pull.c:992
+msgid "cannot rebase with locally recorded submodule modifications"
+msgstr ""
+"no es pot fer «rebase» amb modificacions als submòduls enregistrades "
+"localment"
+
+#: builtin/push.c:19
+msgid "git push [<options>] [<repository> [<refspec>...]]"
+msgstr "git push [<opcions>] [<dipòsit> [<especificació-de-referència>...]]"
+
+#: builtin/push.c:112
+msgid "tag shorthand without <tag>"
+msgstr "abreviatura d'etiqueta sense <tag>"
+
+#: builtin/push.c:122
+msgid "--delete only accepts plain target ref names"
+msgstr "--delete només accepta noms de referència de destí senzills"
+
+#: builtin/push.c:168
+msgid ""
+"\n"
+"To choose either option permanently, see push.default in 'git help config'."
+msgstr ""
+"\n"
+"Per a triar qualsevol opció permanentment, vegeu push.default a 'git help "
+"config'."
+
+#: builtin/push.c:171
+#, c-format
+msgid ""
+"The upstream branch of your current branch does not match\n"
+"the name of your current branch.  To push to the upstream branch\n"
+"on the remote, use\n"
+"\n"
+"    git push %s HEAD:%s\n"
+"\n"
+"To push to the branch of the same name on the remote, use\n"
+"\n"
+"    git push %s HEAD\n"
+"%s"
+msgstr ""
+"La branca font de la vostra branca actual no coincideix\n"
+"amb el nom de la vostra branca actual. Per a pujar-la a la\n"
+"branca font en el remot, useu\n"
+"\n"
+"    git push %s HEAD:%s\n"
+"\n"
+"Per a pujar a la branca del mateix nom en el remot, useu\n"
+"\n"
+"    git push %s HEAD\n"
+"%s"
+
+#: builtin/push.c:186
+#, c-format
+msgid ""
+"You are not currently on a branch.\n"
+"To push the history leading to the current (detached HEAD)\n"
+"state now, use\n"
+"\n"
+"    git push %s HEAD:<name-of-remote-branch>\n"
+msgstr ""
+"Actualment no sou en cap branca.\n"
+"Per a pujar la història que condueix a l'estat actual\n"
+"(HEAD separat) ara, useu\n"
+"\n"
+"    git push %s HEAD:<nom-de-branca-remota>\n"
+
+#: builtin/push.c:200
+#, c-format
+msgid ""
+"The current branch %s has no upstream branch.\n"
+"To push the current branch and set the remote as upstream, use\n"
+"\n"
+"    git push --set-upstream %s %s\n"
+msgstr ""
+"La branca actual %s no té cap branca font.\n"
+"Per a pujar la branca actual i establir el remot com a font, useu\n"
+"\n"
+"    git push --set-upstream %s %s\n"
+
+#: builtin/push.c:208
+#, c-format
+msgid "The current branch %s has multiple upstream branches, refusing to push."
+msgstr ""
+"La branca actual %s té múltiples branques fonts, s'està refusant pujar."
+
+#: builtin/push.c:211
+#, c-format
+msgid ""
+"You are pushing to remote '%s', which is not the upstream of\n"
+"your current branch '%s', without telling me what to push\n"
+"to update which remote branch."
+msgstr ""
+"Esteu pujant al remot «%s», que no és la font de la vostra\n"
+"branca actual «%s», sense dir-me què pujar per a actualitzar\n"
+"quina branca remota."
+
+#: builtin/push.c:270
+msgid ""
+"You didn't specify any refspecs to push, and push.default is \"nothing\"."
+msgstr ""
+"No heu especificat cap especificació de referència a pujar, i push.default "
+"és \"nothing\"."
+
+#: builtin/push.c:277
+msgid ""
+"Updates were rejected because the tip of your current branch is behind\n"
+"its remote counterpart. Integrate the remote changes (e.g.\n"
+"'git pull ...') before pushing again.\n"
+"See the 'Note about fast-forwards' in 'git push --help' for details."
+msgstr ""
+"S'han rebutjat les actualitzacions perquè el punt de la vostra branca\n"
+"actual està darrere de la seva branca remota corresponent. Integreu\n"
+"els canvis remots (per exemple, 'git pull ...') abans de pujar de nou.\n"
+"Vegeu la 'Nota sobre avanços ràpids' a 'git push --help' per detalls."
+
+#: builtin/push.c:283
+msgid ""
+"Updates were rejected because a pushed branch tip is behind its remote\n"
+"counterpart. Check out this branch and integrate the remote changes\n"
+"(e.g. 'git pull ...') before pushing again.\n"
+"See the 'Note about fast-forwards' in 'git push --help' for details."
+msgstr ""
+"S'han rebutjat les actualitzacions perquè un punt de branca pujada\n"
+"està darrere de la seva branca remota corresponent. Agafeu aquesta\n"
+"branca i integreu els canvis remots (per exemple, 'git pull ...')\n"
+"abans de pujar de nou.\n"
+"Vegeu la 'Nota sobre avanços ràpids' a 'git push --help' per detalls."
+
+#: builtin/push.c:289
+msgid ""
+"Updates were rejected because the remote contains work that you do\n"
+"not have locally. This is usually caused by another repository pushing\n"
+"to the same ref. You may want to first integrate the remote changes\n"
+"(e.g., 'git pull ...') before pushing again.\n"
+"See the 'Note about fast-forwards' in 'git push --help' for details."
+msgstr ""
+"S'han rebutjat les actualitzacions perquè el remot conté canvis\n"
+"que no teniu localment. Això acostuma a ser causat per un altre dipòsit\n"
+"que ha pujat a la mateixa referència. Pot ser que primer vulgueu\n"
+"integrar els canvis remots (per exemple, 'git pull ...') abans de\n"
+"pujar de nou.\n"
+"Vegeu la 'Nota sobre avanços ràpids' a 'git push --help' per detalls."
+
+#: builtin/push.c:296
+msgid "Updates were rejected because the tag already exists in the remote."
+msgstr ""
+"S'han rebutjat les actualitzacions perquè l'etiqueta ja existeix en el remot."
+
+#: builtin/push.c:299
+msgid ""
+"You cannot update a remote ref that points at a non-commit object,\n"
+"or update a remote ref to make it point at a non-commit object,\n"
+"without using the '--force' option.\n"
+msgstr ""
+"No podeu actualitzar una referència remota que assenyala un\n"
+"objecte no de comissió, ni actualitzar una referència remota per\n"
+"fer que assenyali un objecte no de comissió, sense usar l'opció\n"
+"'--force'.\n"
+
+#: builtin/push.c:360
+#, c-format
+msgid "Pushing to %s\n"
+msgstr "S'està pujant a %s\n"
+
+#: builtin/push.c:367
+#, c-format
+msgid "failed to push some refs to '%s'"
+msgstr "s'ha produït un error en pujar algunes referències a «%s»"
+
+#: builtin/push.c:542
+msgid "repository"
+msgstr "dipòsit"
+
+#: builtin/push.c:543 builtin/send-pack.c:164
+msgid "push all refs"
+msgstr "puja totes les referències"
+
+#: builtin/push.c:544 builtin/send-pack.c:166
+msgid "mirror all refs"
+msgstr "reflecteix totes les referències"
+
+#: builtin/push.c:546
+msgid "delete refs"
+msgstr "suprimeix les referències"
+
+#: builtin/push.c:547
+msgid "push tags (can't be used with --all or --mirror)"
+msgstr "puja les etiquetes (no es pot usar amb --all o --mirror)"
+
+#: builtin/push.c:550 builtin/send-pack.c:167
+msgid "force updates"
+msgstr "força les actualitzacions"
+
+#: builtin/push.c:552 builtin/send-pack.c:181
+msgid "<refname>:<expect>"
+msgstr "<nom-de-referència>:<esperat>"
+
+#: builtin/push.c:553 builtin/send-pack.c:182
+msgid "require old value of ref to be at this value"
+msgstr "requereix que el valor antic de la referència sigui d'aquest valor"
+
+#: builtin/push.c:556
+msgid "control recursive pushing of submodules"
+msgstr "controla la pujada recursiva dels submòduls"
+
+#: builtin/push.c:558 builtin/send-pack.c:175
+msgid "use thin pack"
+msgstr "usa el paquet prim"
+
+#: builtin/push.c:559 builtin/push.c:560 builtin/send-pack.c:161
+#: builtin/send-pack.c:162
+msgid "receive pack program"
+msgstr "programa que rep els paquets"
+
+#: builtin/push.c:561
+msgid "set upstream for git pull/status"
+msgstr "estableix la font per a git pull/status"
+
+#: builtin/push.c:564
+msgid "prune locally removed refs"
+msgstr "poda les referències eliminades localment"
+
+#: builtin/push.c:566
+msgid "bypass pre-push hook"
+msgstr "evita el lligam de prepujada"
+
+#: builtin/push.c:567
+msgid "push missing but relevant tags"
+msgstr "puja les etiquetes absents però rellevants"
+
+#: builtin/push.c:570 builtin/send-pack.c:169
+msgid "GPG sign the push"
+msgstr "signa la pujada amb GPG"
+
+#: builtin/push.c:572 builtin/send-pack.c:176
+msgid "request atomic transaction on remote side"
+msgstr "demana una transacció atòmica al costat remot"
+
+#: builtin/push.c:590
+msgid "--delete is incompatible with --all, --mirror and --tags"
+msgstr "--delete és incompatible amb --all, --mirror i --tags"
+
+#: builtin/push.c:592
+msgid "--delete doesn't make sense without any refs"
+msgstr "--delete no té sentit sense referències"
+
+#: builtin/push.c:612
+#, c-format
+msgid "bad repository '%s'"
+msgstr "dipòsit incorrecte «%s»"
+
+#: builtin/push.c:613
+msgid ""
+"No configured push destination.\n"
+"Either specify the URL from the command-line or configure a remote "
+"repository using\n"
+"\n"
+"    git remote add <name> <url>\n"
+"\n"
+"and then push using the remote name\n"
+"\n"
+"    git push <name>\n"
+msgstr ""
+"No hi ha cap destí de pujada configurat.\n"
+"Especifiqueu l'URL des de la línia d'ordres o bé configureu un dipòsit remot "
+"fent servir\n"
+"\n"
+"    git remote add <nom> <url>\n"
+"\n"
+"i després pugeu fent servir el nom remot\n"
+"\n"
+"    git push <nom>\n"
+
+#: builtin/push.c:628
+msgid "--all and --tags are incompatible"
+msgstr "--all i --tags són incompatibles"
+
+#: builtin/push.c:630
+msgid "--all can't be combined with refspecs"
+msgstr "--all no es pot combinar amb especificacions de referència"
+
+#: builtin/push.c:634
+msgid "--mirror and --tags are incompatible"
+msgstr "--mirror i --tags són incompatibles"
+
+#: builtin/push.c:636
+msgid "--mirror can't be combined with refspecs"
+msgstr "--mirror no es pot combinar amb especificacions de referència"
+
+#: builtin/push.c:639
+msgid "--all and --mirror are incompatible"
+msgstr "--all i --mirror són incompatibles"
+
+#: builtin/push.c:643
+msgid "push options must not have new line characters"
+msgstr "les opcions de pujada no han de tenir caràcters de línia nova"
+
+#: builtin/range-diff.c:8
+msgid "git range-diff [<options>] <old-base>..<old-tip> <new-base>..<new-tip>"
+msgstr ""
 
-#: builtin/merge.c:49
-msgid "git merge [<options>] [<commit>...]"
+#: builtin/range-diff.c:9
+#, fuzzy
+msgid "git range-diff [<options>] <old-tip>...<new-tip>"
 msgstr "git merge [<opcions>] [<comissió>...]"
 
-#: builtin/merge.c:50
-msgid "git merge --abort"
-msgstr "git merge --abort"
+#: builtin/range-diff.c:10
+#, fuzzy
+msgid "git range-diff [<options>] <base> <old-tip> <new-tip>"
+msgstr "git mv [<opcions>] <font>... <destí>"
 
-#: builtin/merge.c:51
-msgid "git merge --continue"
-msgstr "git merge --continue"
+#: builtin/range-diff.c:22
+msgid "Percentage by which creation is weighted"
+msgstr ""
 
-#: builtin/merge.c:108
-msgid "switch `m' requires a value"
-msgstr "l'opció «m» requereix un valor"
+#: builtin/range-diff.c:24
+msgid "use simple diff colors"
+msgstr "utilitza colors simples de diff"
 
-#: builtin/merge.c:145
-#, c-format
-msgid "Could not find merge strategy '%s'.\n"
-msgstr "No s'ha pogut trobar l'estratègia de fusió «%s».\n"
+#: builtin/range-diff.c:26
+#, fuzzy
+msgid "notes"
+msgstr "notes"
 
-#: builtin/merge.c:146
-#, c-format
-msgid "Available strategies are:"
-msgstr "Les estratègies disponibles són:"
+#: builtin/range-diff.c:26
+#, fuzzy
+msgid "passed to 'git log'"
+msgstr "passa-ho a «git am»"
 
-#: builtin/merge.c:151
+#: builtin/range-diff.c:50 builtin/range-diff.c:54
 #, c-format
-msgid "Available custom strategies are:"
-msgstr "Les estratègies personalitzades disponibles són:"
-
-#: builtin/merge.c:201 builtin/pull.c:137
-msgid "do not show a diffstat at the end of the merge"
-msgstr "no mostris les estadístiques de diferència al final de la fusió"
+msgid "no .. in range: '%s'"
+msgstr "cap .. en rang: «%s»"
 
-#: builtin/merge.c:204 builtin/pull.c:140
-msgid "show a diffstat at the end of the merge"
-msgstr "mostra les estadístiques de diferència al final de la fusió"
+#: builtin/range-diff.c:64
+msgid "single arg format must be symmetric range"
+msgstr "el format de l'argument únic ha de ser de rang simètric"
 
-#: builtin/merge.c:205 builtin/pull.c:143
-msgid "(synonym to --stat)"
-msgstr "(sinònim de --stat)"
+#: builtin/range-diff.c:79
+msgid "need two commit ranges"
+msgstr "calen dos rangs de comissió"
 
-#: builtin/merge.c:207 builtin/pull.c:146
-msgid "add (at most <n>) entries from shortlog to merge commit message"
+#: builtin/read-tree.c:41
+msgid ""
+"git read-tree [(-m [--trivial] [--aggressive] | --reset | --prefix=<prefix>) "
+"[-u [--exclude-per-directory=<gitignore>] | -i]] [--no-sparse-checkout] [--"
+"index-output=<file>] (--empty | <tree-ish1> [<tree-ish2> [<tree-ish3>]])"
 msgstr ""
-"afegeix (com a màxim <n>) entrades del registre curt al missatge de comissió "
-"de fusió"
-
-#: builtin/merge.c:210 builtin/pull.c:152
-msgid "create a single commit instead of doing a merge"
-msgstr "crea una única comissió en lloc de fusionar"
+"git read-tree [(-m [--trivial] [--aggressive] | --reset | --prefix=<prefix>) "
+"[-u [--exclude-per-directory=<gitignore>] | -i]] [--no-sparse-checkout] [--"
+"index-output=<fitxer>] (--empty | <arbre1> [<arbre2> [<arbre3>]])"
 
-#: builtin/merge.c:212 builtin/pull.c:155
-msgid "perform a commit if the merge succeeds (default)"
-msgstr "realitza una comissió si la fusió té èxit (per defecte)"
+#: builtin/read-tree.c:124
+msgid "write resulting index to <file>"
+msgstr "escriu l'índex resultant al <fitxer>"
 
-#: builtin/merge.c:214 builtin/pull.c:158
-msgid "edit message before committing"
-msgstr "edita el missatge abans de cometre"
+#: builtin/read-tree.c:127
+msgid "only empty the index"
+msgstr "només buida l'índex"
 
-#: builtin/merge.c:215
-msgid "allow fast-forward (default)"
-msgstr "permet l'avanç ràpid (per defecte)"
+#: builtin/read-tree.c:129
+msgid "Merging"
+msgstr "S'està fusionant"
 
-#: builtin/merge.c:217 builtin/pull.c:164
-msgid "abort if fast-forward is not possible"
-msgstr "avorta si l'avanç ràpid no és possible"
+#: builtin/read-tree.c:131
+msgid "perform a merge in addition to a read"
+msgstr "realitza una fusió a més d'una lectura"
 
-#: builtin/merge.c:221 builtin/pull.c:167
-msgid "verify that the named commit has a valid GPG signature"
-msgstr "verifica que la comissió anomenada tingui una signatura GPG vàlida"
+#: builtin/read-tree.c:133
+msgid "3-way merge if no file level merging required"
+msgstr "fusió de 3 vies si no cal fusió a nivell de fitxers"
 
-#: builtin/merge.c:222 builtin/notes.c:777 builtin/pull.c:171
-#: builtin/revert.c:109
-msgid "strategy"
-msgstr "estratègia"
+#: builtin/read-tree.c:135
+msgid "3-way merge in presence of adds and removes"
+msgstr "fusió de 3 vies en presència d'afegiments i eliminacions"
 
-#: builtin/merge.c:223 builtin/pull.c:172
-msgid "merge strategy to use"
-msgstr "estratègia de fusió a usar"
+#: builtin/read-tree.c:137
+msgid "same as -m, but discard unmerged entries"
+msgstr "el mateix que -m, però descarta les entrades no fusionades"
 
-#: builtin/merge.c:224 builtin/pull.c:175
-msgid "option=value"
-msgstr "opció=valor"
+#: builtin/read-tree.c:138
+msgid "<subdirectory>/"
+msgstr "<subdirectori>/"
 
-#: builtin/merge.c:225 builtin/pull.c:176
-msgid "option for selected merge strategy"
-msgstr "opció per a l'estratègia de fusió seleccionada"
+#: builtin/read-tree.c:139
+msgid "read the tree into the index under <subdirectory>/"
+msgstr "llegiu l'arbre a l'índex sota <subdirectori>/"
 
-#: builtin/merge.c:227
-msgid "merge commit message (for a non-fast-forward merge)"
-msgstr "missatge de comissió de fusió (per a una fusió no d'avanç ràpid)"
+#: builtin/read-tree.c:142
+msgid "update working tree with merge result"
+msgstr "actualitza l'arbre de treball amb el resultat de fusió"
 
-#: builtin/merge.c:231
-msgid "abort the current in-progress merge"
-msgstr "avorta la fusió en curs actual"
+#: builtin/read-tree.c:144
+msgid "gitignore"
+msgstr "gitignore"
 
-#: builtin/merge.c:233
-msgid "continue the current in-progress merge"
-msgstr "continua la fusió en curs actual"
+#: builtin/read-tree.c:145
+msgid "allow explicitly ignored files to be overwritten"
+msgstr "permet que els fitxers explícitament ignorats se sobreescriguin"
 
-#: builtin/merge.c:235 builtin/pull.c:183
-msgid "allow merging unrelated histories"
-msgstr "permet fusionar històries no relacionades"
+#: builtin/read-tree.c:148
+msgid "don't check the working tree after merging"
+msgstr "no comprovis l'arbre de treball després de fusionar"
 
-#: builtin/merge.c:241
-msgid "verify commit-msg hook"
-msgstr "verifica el lligam de missatge de comissió"
+#: builtin/read-tree.c:149
+msgid "don't update the index or the work tree"
+msgstr "no actualitzis l'índex ni l'arbre de treball"
 
-#: builtin/merge.c:266
-msgid "could not run stash."
-msgstr "no s'ha pogut executar «stash»."
+#: builtin/read-tree.c:151
+msgid "skip applying sparse checkout filter"
+msgstr "omet l'aplicació del filtre d'agafament parcial"
 
-#: builtin/merge.c:271
-msgid "stash failed"
-msgstr "l'«stash» ha fallat"
+#: builtin/read-tree.c:153
+msgid "debug unpack-trees"
+msgstr "depura unpack-trees"
 
-#: builtin/merge.c:276
-#, c-format
-msgid "not a valid object: %s"
-msgstr "no és un objecte vàlid: %s"
+#: builtin/read-tree.c:157
+#, fuzzy
+msgid "suppress feedback messages"
+msgstr "omet els missatges informatius"
 
-#: builtin/merge.c:298 builtin/merge.c:315
-msgid "read-tree failed"
-msgstr "read-tree ha fallat"
+#: builtin/read-tree.c:188
+#, fuzzy
+msgid "You need to resolve your current index first"
+msgstr "heu de primer resoldre el vostre índex actual"
 
-#: builtin/merge.c:345
-msgid " (nothing to squash)"
-msgstr " (res a fer «squash»)"
+#: builtin/rebase.c:32
+#, fuzzy
+msgid ""
+"git rebase [-i] [options] [--exec <cmd>] [--onto <newbase> | --keep-base] "
+"[<upstream> [<branch>]]"
+msgstr ""
+"git archive --remote <dipòsit> [--exec <ordre>] [<opcions>] <arbre> "
+"[<camí>...]"
 
-#: builtin/merge.c:356
-#, c-format
-msgid "Squash commit -- not updating HEAD\n"
-msgstr "Comissió «squash» -- no s'està actualitzant HEAD\n"
+#: builtin/rebase.c:34
+msgid ""
+"git rebase [-i] [options] [--exec <cmd>] [--onto <newbase>] --root [<branch>]"
+msgstr ""
 
-#: builtin/merge.c:406
-#, c-format
-msgid "No merge message -- not updating HEAD\n"
-msgstr "Cap missatge de fusió -- no s'està actualitzant HEAD\n"
+#: builtin/rebase.c:36
+msgid "git rebase --continue | --abort | --skip | --edit-todo"
+msgstr "git rebase --continue | --abort | --skip | --edit-todo"
 
-#: builtin/merge.c:456
+#: builtin/rebase.c:177 builtin/rebase.c:201 builtin/rebase.c:228
 #, c-format
-msgid "'%s' does not point to a commit"
-msgstr "«%s» no assenyala una comissió"
+msgid "unusable todo list: '%s'"
+msgstr "llista per a fer inestable: «%s»"
 
-#: builtin/merge.c:546
+#: builtin/rebase.c:186 builtin/rebase.c:212 builtin/rebase.c:236
 #, c-format
-msgid "Bad branch.%s.mergeoptions string: %s"
-msgstr "Cadena branch.%s.mergeoptions incorrecta: %s"
+msgid "could not write '%s'."
+msgstr "no s'ha pogut escriure a «%s»."
 
-#: builtin/merge.c:668
-msgid "Not handling anything other than two heads merge."
-msgstr "No s'està gestionant res a part de la fusió de dos caps."
+#: builtin/rebase.c:271
+msgid "no HEAD?"
+msgstr "no hi ha cap HEAD?"
 
-#: builtin/merge.c:682
+#: builtin/rebase.c:298
 #, c-format
-msgid "Unknown option for merge-recursive: -X%s"
-msgstr "Opció desconeguda de merge-recursive: -X%s"
+msgid "could not create temporary %s"
+msgstr "no s'ha pogut crear el fitxer temporal %s"
 
-#: builtin/merge.c:697
-#, c-format
-msgid "unable to write %s"
-msgstr "no s'ha pogut escriure %s"
+#: builtin/rebase.c:304
+msgid "could not mark as interactive"
+msgstr "no s'ha pogut marcar com a interactiu"
 
-#: builtin/merge.c:749
-#, c-format
-msgid "Could not read from '%s'"
-msgstr "No s'ha pogut llegir de «%s»"
+#: builtin/rebase.c:362
+msgid "could not generate todo list"
+msgstr "no s'ha pogut generar la llista per a fer"
 
-#: builtin/merge.c:758
-#, c-format
-msgid "Not committing merge; use 'git commit' to complete the merge.\n"
+#: builtin/rebase.c:402
+msgid "a base commit must be provided with --upstream or --onto"
 msgstr ""
-"No s'està cometent la fusió; useu 'git commit' per a completar la fusió.\n"
 
-#: builtin/merge.c:764
-#, c-format
-msgid ""
-"Please enter a commit message to explain why this merge is necessary,\n"
-"especially if it merges an updated upstream into a topic branch.\n"
-"\n"
-"Lines starting with '%c' will be ignored, and an empty message aborts\n"
-"the commit.\n"
-msgstr ""
-"Introduïu un missatge de comissió per a explicar per què\n"
-"aquesta fusió és necessària, especialment si fusiona una font\n"
-"actualitzada a una branca temàtica.\n"
-"\n"
-"S'ignoraran les línies que comencin amb '%c', i un missatge buit\n"
-"avorta la comissió.\n"
+#: builtin/rebase.c:457
+msgid "git rebase--interactive [<options>]"
+msgstr "git rebase--interactive [<opcions>]"
 
-#: builtin/merge.c:800
-msgid "Empty commit message."
-msgstr "El missatge de comissió és buit."
+#: builtin/rebase.c:469
+msgid "keep empty commits"
+msgstr "mantén les comissions buides"
 
-#: builtin/merge.c:820
-#, c-format
-msgid "Wonderful.\n"
-msgstr "Meravellós.\n"
+#: builtin/rebase.c:471 builtin/revert.c:128
+msgid "allow commits with empty messages"
+msgstr "permet les comissions amb missatges buits"
 
-#: builtin/merge.c:873
-#, c-format
-msgid "Automatic merge failed; fix conflicts and then commit the result.\n"
+#: builtin/rebase.c:472
+msgid "rebase merge commits"
+msgstr "fes «rebase» de les comissions de fusió"
+
+#: builtin/rebase.c:474
+msgid "keep original branch points of cousins"
 msgstr ""
-"La fusió automàtica ha fallat; arregleu els conflictes i després cometeu el "
-"resultat.\n"
 
-#: builtin/merge.c:912
-msgid "No current branch."
-msgstr "No hi ha cap branca actual."
+#: builtin/rebase.c:476
+msgid "move commits that begin with squash!/fixup!"
+msgstr ""
 
-#: builtin/merge.c:914
-msgid "No remote for the current branch."
-msgstr "No hi ha cap remot per a la branca actual."
+#: builtin/rebase.c:477
+msgid "sign commits"
+msgstr "signa les comissions"
 
-#: builtin/merge.c:916
-msgid "No default upstream defined for the current branch."
-msgstr "No hi ha cap font per defecte definida per a la branca actual."
+#: builtin/rebase.c:479 builtin/rebase.c:1455
+msgid "display a diffstat of what changed upstream"
+msgstr ""
 
-#: builtin/merge.c:921
-#, c-format
-msgid "No remote-tracking branch for %s from %s"
-msgstr "No hi ha cap branca amb seguiment remot per a %s de %s"
+#: builtin/rebase.c:481
+msgid "continue rebase"
+msgstr "continua el «rebase»"
 
-#: builtin/merge.c:974
-#, c-format
-msgid "Bad value '%s' in environment '%s'"
-msgstr "Valor incorrecte «%s» en l'entorn «%s»"
+#: builtin/rebase.c:483
+msgid "skip commit"
+msgstr "omet la comissió"
+
+#: builtin/rebase.c:484
+msgid "edit the todo list"
+msgstr "edita la llista a fer"
+
+#: builtin/rebase.c:486
+msgid "show the current patch"
+msgstr "mostra el pedaç actual"
 
-#: builtin/merge.c:1076
-#, c-format
-msgid "not something we can merge in %s: %s"
-msgstr "no és quelcom que puguem fusionar en %s: %s"
+#: builtin/rebase.c:489
+msgid "shorten commit ids in the todo list"
+msgstr "escurça els ids de les comissions en la llista per a fer"
 
-#: builtin/merge.c:1110
-msgid "not something we can merge"
-msgstr "no és quelcom que puguem fusionar"
+#: builtin/rebase.c:491
+msgid "expand commit ids in the todo list"
+msgstr "expandeix els ids de les comissions en la llista per a fer"
 
-#: builtin/merge.c:1212
-msgid "--abort expects no arguments"
-msgstr "--abort no accepta paràmetres"
+#: builtin/rebase.c:493
+msgid "check the todo list"
+msgstr "comprova la llista a fer"
 
-#: builtin/merge.c:1216
-msgid "There is no merge to abort (MERGE_HEAD missing)."
-msgstr "No hi ha fusió a avortar (manca MERGE_HEAD)."
+#: builtin/rebase.c:495
+msgid "rearrange fixup/squash lines"
+msgstr "reorganitza les línies «fixup/pick»"
 
-#: builtin/merge.c:1228
-msgid "--continue expects no arguments"
-msgstr "--continue no accepta paràmetres"
+#: builtin/rebase.c:497
+msgid "insert exec commands in todo list"
+msgstr "expandeix les ordres exec en la llista per a fer"
 
-#: builtin/merge.c:1232
-msgid "There is no merge in progress (MERGE_HEAD missing)."
-msgstr "No hi ha cap fusió en curs (manca MERGE_HEAD)."
+#: builtin/rebase.c:498
+msgid "onto"
+msgstr ""
 
-#: builtin/merge.c:1248
-msgid ""
-"You have not concluded your merge (MERGE_HEAD exists).\n"
-"Please, commit your changes before you merge."
+#: builtin/rebase.c:501
+#, fuzzy
+msgid "restrict-revision"
+msgstr "revisió"
+
+#: builtin/rebase.c:501
+#, fuzzy
+msgid "restrict revision"
+msgstr "revisió"
+
+#: builtin/rebase.c:503
+msgid "squash-onto"
 msgstr ""
-"No heu conclòs la vostra fusió (MERGE_HEAD existeix).\n"
-"Cometeu els vostres canvis abans de fusionar."
 
-#: builtin/merge.c:1255
-msgid ""
-"You have not concluded your cherry-pick (CHERRY_PICK_HEAD exists).\n"
-"Please, commit your changes before you merge."
+#: builtin/rebase.c:504
+msgid "squash onto"
 msgstr ""
-"No heu conclòs el vostre «cherry pick» (CHERRY_PICK_HEAD existeix).\n"
-"Cometeu els vostres canvis abans de fusionar."
 
-#: builtin/merge.c:1258
-msgid "You have not concluded your cherry-pick (CHERRY_PICK_HEAD exists)."
-msgstr "No heu conclòs el vostre «cherry pick» (CHERRY_PICK_HEAD existeix)."
+#: builtin/rebase.c:506
+#, fuzzy
+msgid "the upstream commit"
+msgstr "Desassigna la informació de font"
 
-#: builtin/merge.c:1267
-msgid "You cannot combine --squash with --no-ff."
-msgstr "No podeu combinar --squash amb --no-ff."
+#: builtin/rebase.c:508
+#, fuzzy
+msgid "head-name"
+msgstr "canvi de nom"
+
+#: builtin/rebase.c:508
+#, fuzzy
+msgid "head name"
+msgstr "davant per "
+
+#: builtin/rebase.c:513
+#, fuzzy
+msgid "rebase strategy"
+msgstr "estratègia de fusió"
+
+#: builtin/rebase.c:514
+#, fuzzy
+msgid "strategy-opts"
+msgstr "estratègia"
+
+#: builtin/rebase.c:515
+#, fuzzy
+msgid "strategy options"
+msgstr "opcions de decoració"
 
-#: builtin/merge.c:1275
-msgid "No commit specified and merge.defaultToUpstream not set."
+#: builtin/rebase.c:516
+msgid "switch-to"
 msgstr ""
-"No hi ha una comissió especificada i merge.defaultToUpstream no està "
-"establert."
 
-#: builtin/merge.c:1292
-msgid "Squash commit into empty head not supported yet"
-msgstr "Una comissió «squash» a un HEAD buit encara no es permet"
+#: builtin/rebase.c:517
+msgid "the branch or commit to checkout"
+msgstr ""
 
-#: builtin/merge.c:1294
-msgid "Non-fast-forward commit does not make sense into an empty head"
-msgstr "Una comissió no d'avanç ràpid no té sentit a un HEAD buit"
+#: builtin/rebase.c:518
+#, fuzzy
+msgid "onto-name"
+msgstr "nom"
 
-#: builtin/merge.c:1299
-#, c-format
-msgid "%s - not something we can merge"
-msgstr "%s - no és una cosa que puguem fusionar"
+#: builtin/rebase.c:518
+#, fuzzy
+msgid "onto name"
+msgstr "nom del remot"
 
-#: builtin/merge.c:1301
-msgid "Can merge only exactly one commit into empty head"
-msgstr "Es pot fusionar només una comissió a un HEAD buit"
+#: builtin/rebase.c:519
+#, fuzzy
+msgid "cmd"
+msgstr "ordre"
 
-#: builtin/merge.c:1335
-#, c-format
-msgid "Commit %s has an untrusted GPG signature, allegedly by %s."
-msgstr "La comissió %s té una signatura GPG no fiable, suposadament de %s."
+#: builtin/rebase.c:519
+msgid "the command to run"
+msgstr "l'ordre a executar"
 
-#: builtin/merge.c:1338
-#, c-format
-msgid "Commit %s has a bad GPG signature allegedly by %s."
-msgstr "La comissió %s té una signatura GPG incorrecta suposadament de %s."
+#: builtin/rebase.c:522 builtin/rebase.c:1540
+msgid "automatically re-schedule any `exec` that fails"
+msgstr ""
 
-#: builtin/merge.c:1341
-#, c-format
-msgid "Commit %s does not have a GPG signature."
-msgstr "La comissió %s no té signatura GPG."
+#: builtin/rebase.c:540
+msgid "--[no-]rebase-cousins has no effect without --rebase-merges"
+msgstr ""
 
-#: builtin/merge.c:1344
+#: builtin/rebase.c:556
 #, c-format
-msgid "Commit %s has a good GPG signature by %s\n"
-msgstr "La comissió %s té una signatura GPG bona de %s\n"
+msgid "%s requires an interactive rebase"
+msgstr "%s requereix un «rebase» interactiu"
 
-#: builtin/merge.c:1403
-msgid "refusing to merge unrelated histories"
-msgstr "s'està refusant fusionar històries no relacionades"
+#: builtin/rebase.c:608
+#, fuzzy, c-format
+msgid "could not get 'onto': '%s'"
+msgstr "no s'ha pogut establir «%s» a «%s»"
 
-#: builtin/merge.c:1412
-msgid "Already up to date."
-msgstr "Ja està al dia."
+#: builtin/rebase.c:623
+#, fuzzy, c-format
+msgid "invalid orig-head: '%s'"
+msgstr "fitxer no vàlid: «%s»"
 
-#: builtin/merge.c:1422
+#: builtin/rebase.c:648
 #, c-format
-msgid "Updating %s..%s\n"
-msgstr "S'estan actualitzant %s..%s\n"
+msgid "ignoring invalid allow_rerere_autoupdate: '%s'"
+msgstr ""
 
-#: builtin/merge.c:1463
+#: builtin/rebase.c:724
 #, c-format
-msgid "Trying really trivial in-index merge...\n"
-msgstr "S'està intentant una fusió molt trivial en l'índex...\n"
+msgid "Could not read '%s'"
+msgstr "No s'ha pogut llegir «%s»"
 
-#: builtin/merge.c:1470
+#: builtin/rebase.c:742
 #, c-format
-msgid "Nope.\n"
-msgstr "No.\n"
-
-#: builtin/merge.c:1495
-msgid "Already up to date. Yeeah!"
-msgstr "Ja està al dia. Estupend!"
+msgid "Cannot store %s"
+msgstr "No es pot emmagatzemar %s"
 
-#: builtin/merge.c:1501
-msgid "Not possible to fast-forward, aborting."
-msgstr "No és possible avançar ràpidament, s'està avortant."
+#: builtin/rebase.c:849
+msgid "could not determine HEAD revision"
+msgstr "no s'ha pogut determinar la revisió de HEAD"
 
-#: builtin/merge.c:1524 builtin/merge.c:1603
-#, c-format
-msgid "Rewinding the tree to pristine...\n"
-msgstr "S'està rebobinant l'arbre a la pristina...\n"
+#: builtin/rebase.c:972 git-rebase--preserve-merges.sh:81
+msgid ""
+"Resolve all conflicts manually, mark them as resolved with\n"
+"\"git add/rm <conflicted_files>\", then run \"git rebase --continue\".\n"
+"You can instead skip this commit: run \"git rebase --skip\".\n"
+"To abort and get back to the state before \"git rebase\", run \"git rebase --"
+"abort\"."
+msgstr ""
+"Resoleu tots els conflictes manualment, marqueu-los com a resolts amb\n"
+"«git add/rm <fitxers amb conflicte>», llavors executeu «git rebase --"
+"continue».\n"
+"Podeu en comptes ometre aquesta comissió: executeu «git rebase --skip».\n"
+"Per a avortar i tornar a l'estat anterior abans de l'ordre «git rebase», "
+"executeu «git rebase --abort»."
 
-#: builtin/merge.c:1528
+#: builtin/rebase.c:1060
 #, c-format
-msgid "Trying merge strategy %s...\n"
-msgstr "S'està intentant l'estratègia de fusió %s...\n"
+msgid ""
+"\n"
+"git encountered an error while preparing the patches to replay\n"
+"these revisions:\n"
+"\n"
+"    %s\n"
+"\n"
+"As a result, git cannot rebase them."
+msgstr ""
 
-#: builtin/merge.c:1594
+#: builtin/rebase.c:1367
 #, c-format
-msgid "No merge strategy handled the merge.\n"
-msgstr "Cap estratègia de fusió ha gestionat la fusió.\n"
+msgid ""
+"%s\n"
+"Please specify which branch you want to rebase against.\n"
+"See git-rebase(1) for details.\n"
+"\n"
+"    git rebase '<branch>'\n"
+"\n"
+msgstr ""
+"%s\n"
+"Especifiqueu sobre què branca voleu fer «rebase».\n"
+"Vegeu git-rebase(1) per detalls.\n"
+"\n"
+"    git rebase '<branca>'\n"
+"\n"
 
-#: builtin/merge.c:1596
+#: builtin/rebase.c:1383
 #, c-format
-msgid "Merge with strategy %s failed.\n"
-msgstr "L'estratègia de fusió %s ha fallat.\n"
+msgid ""
+"If you wish to set tracking information for this branch you can do so with:\n"
+"\n"
+"    git branch --set-upstream-to=%s/<branch> %s\n"
+"\n"
+msgstr ""
+"Si voleu establir informació de seguiment per a aquesta branca, podeu fer-ho "
+"amb:\n"
+"\n"
+"    git branch --set-upstream-to=%s/<branch> %s\n"
+"\n"
 
-#: builtin/merge.c:1605
-#, c-format
-msgid "Using the %s to prepare resolving by hand.\n"
-msgstr "S'està usant el %s per a preparar la resolució a mà.\n"
+#: builtin/rebase.c:1413
+#, fuzzy
+msgid "exec commands cannot contain newlines"
+msgstr "expandeix les ordres exec en la llista per a fer"
 
-#: builtin/merge.c:1617
-#, c-format
-msgid "Automatic merge went well; stopped before committing as requested\n"
+#: builtin/rebase.c:1417
+msgid "empty exec command"
 msgstr ""
-"La fusió automàtica ha sortit bé; s'ha aturat abans de cometre com s'havia "
-"demanat\n"
 
-#: builtin/merge-base.c:30
-msgid "git merge-base [-a | --all] <commit> <commit>..."
-msgstr "git merge-base [-a | --all] <comissió> <comissió>..."
+#: builtin/rebase.c:1446
+msgid "rebase onto given branch instead of upstream"
+msgstr "fes un «rebase» en la branca donada en comptes de la font"
 
-#: builtin/merge-base.c:31
-msgid "git merge-base [-a | --all] --octopus <commit>..."
-msgstr "git merge-base [-a | --all] --octopus <comissió>..."
+#: builtin/rebase.c:1448
+#, fuzzy
+msgid "use the merge-base of upstream and branch as the current base"
+msgstr "la branca font demanada «%s» no existeix"
 
-#: builtin/merge-base.c:32
-msgid "git merge-base --independent <commit>..."
-msgstr "git merge-base --independent <comissió>..."
+#: builtin/rebase.c:1450
+msgid "allow pre-rebase hook to run"
+msgstr "permet al lligam pre-rebase executar-se"
+
+#: builtin/rebase.c:1452
+msgid "be quiet. implies --no-stat"
+msgstr "silenciós. Implica --no-stat"
 
-#: builtin/merge-base.c:33
-msgid "git merge-base --is-ancestor <commit> <commit>"
-msgstr "git merge-base --is-ancestor <comissió> <comissió>"
+#: builtin/rebase.c:1458
+#, fuzzy
+msgid "do not show diffstat of what changed upstream"
+msgstr "no mostris les estadístiques de diferència al final de la fusió"
 
-#: builtin/merge-base.c:34
-msgid "git merge-base --fork-point <ref> [<commit>]"
-msgstr "git merge-base --fork-point <referència> [<comissió>]"
+#: builtin/rebase.c:1461
+#, fuzzy
+msgid "add a Signed-off-by: line to each commit"
+msgstr "afegeix una línia «Signed-off-by» al missatge de comissió"
 
-#: builtin/merge-base.c:220
-msgid "output all common ancestors"
-msgstr "emet tots els avantpassats comuns"
+#: builtin/rebase.c:1464
+#, fuzzy
+msgid "make committer date match author date"
+msgstr "Agrupa per «comitter» en comptes de per autor"
 
-#: builtin/merge-base.c:222
-msgid "find ancestors for a single n-way merge"
-msgstr "troba els avantpassats per a una sola fusió d'n vies"
+#: builtin/rebase.c:1466
+msgid "ignore author date and use current date"
+msgstr ""
 
-#: builtin/merge-base.c:224
-msgid "list revs not reachable from others"
-msgstr "llista les revisions no abastables d'altres"
+#: builtin/rebase.c:1468
+#, fuzzy
+msgid "synonym of --reset-author-date"
+msgstr "sinònim de --files-with-matches"
 
-#: builtin/merge-base.c:226
-msgid "is the first one ancestor of the other?"
-msgstr "és la primera un avantpassat de l'altre?"
+#: builtin/rebase.c:1470 builtin/rebase.c:1474
+msgid "passed to 'git apply'"
+msgstr "passa-ho a «git-apply»"
 
-#: builtin/merge-base.c:228
-msgid "find where <commit> forked from reflog of <ref>"
+#: builtin/rebase.c:1472
+#, fuzzy
+msgid "ignore changes in whitespace"
+msgstr "ignora els canvis d'espai en blanc al final de la línia"
+
+#: builtin/rebase.c:1476 builtin/rebase.c:1479
+msgid "cherry-pick all commits, even if unchanged"
+msgstr "«cherry pick» totes les comissions, inclús les no canviades"
+
+#: builtin/rebase.c:1481
+msgid "continue"
+msgstr "continua"
+
+#: builtin/rebase.c:1484
+msgid "skip current patch and continue"
+msgstr "omet el pedaç actual i continua"
+
+#: builtin/rebase.c:1486
+msgid "abort and check out the original branch"
+msgstr "interromp i agafa la branca original"
+
+#: builtin/rebase.c:1489
+msgid "abort but keep HEAD where it is"
+msgstr "interromp però manté HEAD on és"
+
+#: builtin/rebase.c:1490
+msgid "edit the todo list during an interactive rebase"
+msgstr "edita la llista de coses a fer durant un «rebase» interactiu"
+
+#: builtin/rebase.c:1493
+msgid "show the patch file being applied or merged"
+msgstr "mostra el pedaç que s'està aplicant o fusionant"
+
+#: builtin/rebase.c:1496
+#, fuzzy
+msgid "use merging strategies to rebase"
+msgstr "estratègia de fusió a usar"
+
+#: builtin/rebase.c:1500
+msgid "let the user edit the list of commits to rebase"
 msgstr ""
-"troba on <comissió> s'ha bifurcat del registre de referències de <referència>"
 
-#: builtin/merge-file.c:9
-msgid ""
-"git merge-file [<options>] [-L <name1> [-L <orig> [-L <name2>]]] <file1> "
-"<orig-file> <file2>"
+#: builtin/rebase.c:1504
+#, fuzzy
+msgid "(DEPRECATED) try to recreate merges instead of ignoring them"
+msgstr "intenta recrear les "
+
+#: builtin/rebase.c:1509
+#, fuzzy
+msgid "preserve empty commits during rebase"
+msgstr "preserva les comissions inicialment buides"
+
+#: builtin/rebase.c:1511
+msgid "move commits that begin with squash!/fixup! under -i"
 msgstr ""
-"git merge-file [<opcions>] [-L <nom1> [-L <original> [-L <nom2>]]] <fitxer1> "
-"<fitxer-original> <fitxer2>"
 
-#: builtin/merge-file.c:33
-msgid "send results to standard output"
-msgstr "envia els resultats a la sortida estàndard"
+#: builtin/rebase.c:1517
+#, fuzzy
+msgid "automatically stash/stash pop before and after"
+msgstr ""
+"fes «stash» i «stash pop» automàticament abans i després de fer «rebase»"
 
-#: builtin/merge-file.c:34
-msgid "use a diff3 based merge"
-msgstr "usa una fusió basada en diff3"
+#: builtin/rebase.c:1519
+msgid "add exec lines after each commit of the editable list"
+msgstr ""
 
-#: builtin/merge-file.c:35
-msgid "for conflicts, use our version"
-msgstr "en conflictes, usa la nostra versió"
+#: builtin/rebase.c:1523
+#, fuzzy
+msgid "allow rebasing commits with empty messages"
+msgstr "permet les comissions amb missatges buits"
 
-#: builtin/merge-file.c:37
-msgid "for conflicts, use their version"
-msgstr "en conflictes, usa la seva versió"
+#: builtin/rebase.c:1526
+msgid "try to rebase merges instead of skipping them"
+msgstr ""
 
-#: builtin/merge-file.c:39
-msgid "for conflicts, use a union version"
-msgstr "en conflictes, usa una versió d'unió"
+#: builtin/rebase.c:1529
+#, fuzzy
+msgid "use 'merge-base --fork-point' to refine upstream"
+msgstr "git merge-base --fork-point <referència> [<comissió>]"
 
-#: builtin/merge-file.c:42
-msgid "for conflicts, use this marker size"
-msgstr "en conflictes, usa aquesta mida de marcador"
+#: builtin/rebase.c:1531
+msgid "use the given merge strategy"
+msgstr "utilitza l'estratègia de fusió donada"
 
-#: builtin/merge-file.c:43
-msgid "do not warn about conflicts"
-msgstr "no avisis de conflictes"
+#: builtin/rebase.c:1533 builtin/revert.c:115
+msgid "option"
+msgstr "opció"
 
-#: builtin/merge-file.c:45
-msgid "set labels for file1/orig-file/file2"
-msgstr "estableix les etiquetes per a fitxer1/fitxer-original/fitxer2"
+#: builtin/rebase.c:1534
+msgid "pass the argument through to the merge strategy"
+msgstr "passa l'argument a l'estratègia de fusió"
 
-#: builtin/merge-recursive.c:45
-#, c-format
-msgid "unknown option %s"
-msgstr "opció desconeguda %s"
+#: builtin/rebase.c:1537
+msgid "rebase all reachable commits up to the root(s)"
+msgstr "fes «rebase» de totes les comissions accessibles fins l'arrel"
 
-#: builtin/merge-recursive.c:51
-#, c-format
-msgid "could not parse object '%s'"
-msgstr "no s'ha pogut analitzar l'objecte «%s»"
+#: builtin/rebase.c:1554
+msgid ""
+"the rebase.useBuiltin support has been removed!\n"
+"See its entry in 'git help config' for details."
+msgstr ""
 
-#: builtin/merge-recursive.c:55
-#, c-format
-msgid "cannot handle more than %d base. Ignoring %s."
-msgid_plural "cannot handle more than %d bases. Ignoring %s."
-msgstr[0] "no es pot gestionar més d'%d base. S'està ignorant %s."
-msgstr[1] "no es poden gestionar més de %d bases. S'està ignorant %s."
+#: builtin/rebase.c:1560
+msgid "It looks like 'git am' is in progress. Cannot rebase."
+msgstr "Sembla que «git am» està en curs. No es pot fer «rebase»."
 
-#: builtin/merge-recursive.c:63
-msgid "not handling anything other than two heads merge."
-msgstr "no s'està gestionant res a part de la fusió de dos caps."
+#: builtin/rebase.c:1601
+#, fuzzy
+msgid ""
+"git rebase --preserve-merges is deprecated. Use --rebase-merges instead."
+msgstr "error: no es pot combinar «--preserve-merges» amb «--rebase-merges»"
 
-#: builtin/merge-recursive.c:69 builtin/merge-recursive.c:71
-#, c-format
-msgid "could not resolve ref '%s'"
-msgstr "no s'ha pogut resoldre la referència «%s»"
+#: builtin/rebase.c:1606
+#, fuzzy
+msgid "cannot combine '--keep-base' with '--onto'"
+msgstr "error: no es pot combinar «--rebase-merges» amb «--strategy»"
 
-#: builtin/merge-recursive.c:77
-#, c-format
-msgid "Merging %s with %s\n"
-msgstr "S'està fusionant %s amb %s\n"
+#: builtin/rebase.c:1608
+#, fuzzy
+msgid "cannot combine '--keep-base' with '--root'"
+msgstr "error: no es pot combinar «--rebase-merges» amb «--strategy»"
 
-#: builtin/mktree.c:65
-msgid "git mktree [-z] [--missing] [--batch]"
-msgstr "git mktree [-z] [--missing] [--batch]"
+#: builtin/rebase.c:1612
+msgid "No rebase in progress?"
+msgstr "No hi ha un «rebase» en curs?"
 
-#: builtin/mktree.c:153
-msgid "input is NUL terminated"
-msgstr "l'entrada és acabada amb NUL"
+#: builtin/rebase.c:1616
+msgid "The --edit-todo action can only be used during interactive rebase."
+msgstr "L'acció --edit-todo només es pot usar durant un «rebase» interactiu."
 
-#: builtin/mktree.c:154 builtin/write-tree.c:25
-msgid "allow missing objects"
-msgstr "permet els objectes absents"
+#: builtin/rebase.c:1639
+msgid "Cannot read HEAD"
+msgstr "No es pot llegir HEAD"
 
-#: builtin/mktree.c:155
-msgid "allow creation of more than one tree"
-msgstr "permet la creació de més d'un arbre"
+#: builtin/rebase.c:1651
+msgid ""
+"You must edit all merge conflicts and then\n"
+"mark them as resolved using git add"
+msgstr ""
+"Heu d'editar tots els conflictes de fusió i després\n"
+"marcar-los com a resolts fent servir git add"
 
-#: builtin/mv.c:17
-msgid "git mv [<options>] <source>... <destination>"
-msgstr "git mv [<opcions>] <font>... <destí>"
+#: builtin/rebase.c:1670
+msgid "could not discard worktree changes"
+msgstr "no s'han pogut descartar els canvis de l'arbre de treball"
 
-#: builtin/mv.c:83
+#: builtin/rebase.c:1689
 #, c-format
-msgid "Directory %s is in index and no submodule?"
-msgstr "El directori %s és en l'índex i no hi ha cap submòdul?"
+msgid "could not move back to %s"
+msgstr "no s'ha pogut tornar a %s"
 
-#: builtin/mv.c:85 builtin/rm.c:289
-msgid "Please stage your changes to .gitmodules or stash them to proceed"
+#: builtin/rebase.c:1734
+#, fuzzy, c-format
+msgid ""
+"It seems that there is already a %s directory, and\n"
+"I wonder if you are in the middle of another rebase.  If that is the\n"
+"case, please try\n"
+"\t%s\n"
+"If that is not the case, please\n"
+"\t%s\n"
+"and run me again.  I am stopping in case you still have something\n"
+"valuable there.\n"
 msgstr ""
-"Feu «stage» dels vostres canvis a .gitmodules o feu «stash» dels mateixos "
-"per a procedir"
+"Sembla que ja hi ha un directori $state_dir_base, i\n"
+"em pregunto si esteu enmig d'un altre «rebase». Si aquest és el\n"
+"cas, proveu\n"
+"\t$cmd_live_rebase\n"
+"Si no és el cas, \n"
+"\t$cmd_clear_stale_rebase\n"
+"i executeu-me de nou. M'aturo per si encara hi teniu alguna cosa\n"
+"de valor."
+
+#: builtin/rebase.c:1757
+msgid "switch `C' expects a numerical value"
+msgstr "«switch» «c» espera un valor numèric"
 
-#: builtin/mv.c:103
+#: builtin/rebase.c:1798
 #, c-format
-msgid "%.*s is in index"
-msgstr "%.*s és en l'índex"
+msgid "Unknown mode: %s"
+msgstr "Mode desconegut: %s"
 
-#: builtin/mv.c:125
-msgid "force move/rename even if target exists"
-msgstr "força el moviment / canvi de nom encara que el destí existeixi"
+#: builtin/rebase.c:1820
+msgid "--strategy requires --merge or --interactive"
+msgstr "--strategy requereix --merge o --interactive"
 
-#: builtin/mv.c:127
-msgid "skip move/rename errors"
-msgstr "omet els errors de moviment / canvi de nom"
+#: builtin/rebase.c:1860
+#, fuzzy
+msgid "--reschedule-failed-exec requires --exec or --interactive"
+msgstr "--strategy requereix --merge o --interactive"
 
-#: builtin/mv.c:168
-#, c-format
-msgid "destination '%s' is not a directory"
-msgstr "el destí «%s» no és un directori"
+#: builtin/rebase.c:1872
+msgid "cannot combine am options with either interactive or merge options"
+msgstr ""
 
-#: builtin/mv.c:179
-#, c-format
-msgid "Checking rename of '%s' to '%s'\n"
-msgstr "S'està comprovant el canvi de nom de «%s» a «%s»\n"
+#: builtin/rebase.c:1891
+#, fuzzy
+msgid "cannot combine '--preserve-merges' with '--rebase-merges'"
+msgstr "error: no es pot combinar «--preserve-merges» amb «--rebase-merges»"
 
-#: builtin/mv.c:183
-msgid "bad source"
-msgstr "font incorrecta"
+#: builtin/rebase.c:1895
+#, fuzzy
+msgid ""
+"error: cannot combine '--preserve-merges' with '--reschedule-failed-exec'"
+msgstr "error: no es pot combinar «--preserve-merges» amb «--rebase-merges»"
 
-#: builtin/mv.c:186
-msgid "can not move directory into itself"
-msgstr "no es pot moure un directori a dins d'ell mateix"
+#: builtin/rebase.c:1919
+#, c-format
+msgid "invalid upstream '%s'"
+msgstr "font no vàlida: «%s»"
 
-#: builtin/mv.c:189
-msgid "cannot move directory over file"
-msgstr "no es pot moure un directori sobre un fitxer"
+#: builtin/rebase.c:1925
+msgid "Could not create new root commit"
+msgstr "no s'ha pogut crear una comissió arrel nova"
 
-#: builtin/mv.c:198
-msgid "source directory is empty"
-msgstr "el directori font està buit"
+#: builtin/rebase.c:1951
+#, fuzzy, c-format
+msgid "'%s': need exactly one merge base with branch"
+msgstr "Cal exactament un rang."
 
-#: builtin/mv.c:223
-msgid "not under version control"
-msgstr "no està sota control de versions"
+#: builtin/rebase.c:1954
+#, fuzzy, c-format
+msgid "'%s': need exactly one merge base"
+msgstr "Cal exactament un rang."
 
-#: builtin/mv.c:226
-msgid "destination exists"
-msgstr "el destí existeix"
+#: builtin/rebase.c:1962
+#, fuzzy, c-format
+msgid "Does not point to a valid commit '%s'"
+msgstr "No assenyala una comissió vàlida: $onto_name"
+
+#: builtin/rebase.c:1987
+#, fuzzy, c-format
+msgid "fatal: no such branch/commit '%s'"
+msgstr "fatal: no hi ha tal branca: $branch_name"
 
-#: builtin/mv.c:234
+#: builtin/rebase.c:1995 builtin/submodule--helper.c:40
+#: builtin/submodule--helper.c:1961
 #, c-format
-msgid "overwriting '%s'"
-msgstr "s'està sobreescrivint «%s»"
+msgid "No such ref: %s"
+msgstr "No hi ha tal referència: %s"
 
-#: builtin/mv.c:237
-msgid "Cannot overwrite"
-msgstr "No es pot sobreescriure"
+#: builtin/rebase.c:2006
+#, fuzzy
+msgid "Could not resolve HEAD to a revision"
+msgstr "no s'ha pogut resoldre la comissió HEAD"
 
-#: builtin/mv.c:240
-msgid "multiple sources for the same target"
-msgstr "múltiples fonts per al mateix destí"
+#: builtin/rebase.c:2044
+msgid "Cannot autostash"
+msgstr "No es pot emmagatzemar automàticament"
 
-#: builtin/mv.c:242
-msgid "destination directory does not exist"
-msgstr "el directori destí no existeix"
+#: builtin/rebase.c:2047
+#, fuzzy, c-format
+msgid "Unexpected stash response: '%s'"
+msgstr "final de fitxer inesperat"
 
-#: builtin/mv.c:249
-#, c-format
-msgid "%s, source=%s, destination=%s"
-msgstr "%s, origen=%s, destí=%s"
+#: builtin/rebase.c:2053
+#, fuzzy, c-format
+msgid "Could not create directory for '%s'"
+msgstr "No s'ha pogut crear el directori «%s»"
+
+#: builtin/rebase.c:2056
+#, fuzzy, c-format
+msgid "Created autostash: %s\n"
+msgstr "S'ha creat un magatzem automàtic: $stash_abbrev"
+
+#: builtin/rebase.c:2059
+#, fuzzy
+msgid "could not reset --hard"
+msgstr "No s'ha pogut llegir orig-head"
+
+#: builtin/rebase.c:2068
+msgid "Please commit or stash them."
+msgstr "Cometeu-los o emmagatzemeu-los."
 
-#: builtin/mv.c:270
+#: builtin/rebase.c:2095
 #, c-format
-msgid "Renaming %s to %s\n"
-msgstr "S'està canviant el nom de %s a %s\n"
+msgid "could not parse '%s'"
+msgstr "no s'ha pogut analitzar «%s»"
 
-#: builtin/mv.c:276 builtin/remote.c:712 builtin/repack.c:394
+#: builtin/rebase.c:2108
 #, c-format
-msgid "renaming '%s' failed"
-msgstr "el canvi del nom de «%s» ha fallat"
+msgid "could not switch to %s"
+msgstr "no s'ha pogut commutar a %s"
 
-#: builtin/name-rev.c:338
-msgid "git name-rev [<options>] <commit>..."
-msgstr "git name-rev [<opcions>] <comissió>..."
+#: builtin/rebase.c:2119
+msgid "HEAD is up to date."
+msgstr "HEAD està al dia."
 
-#: builtin/name-rev.c:339
-msgid "git name-rev [<options>] --all"
-msgstr "git name-rev [<opcions>] --all"
+#: builtin/rebase.c:2121
+#, c-format
+msgid "Current branch %s is up to date.\n"
+msgstr "La branca actual %s està al dia.\n"
 
-#: builtin/name-rev.c:340
-msgid "git name-rev [<options>] --stdin"
-msgstr "git name-rev [<opcions>] --stdin"
+#: builtin/rebase.c:2129
+msgid "HEAD is up to date, rebase forced."
+msgstr "La branca actual està al dia, «rebase» forçat."
 
-#: builtin/name-rev.c:395
-msgid "print only names (no SHA-1)"
-msgstr "imprimeix només els noms (sense SHA-1)"
+#: builtin/rebase.c:2131
+#, c-format
+msgid "Current branch %s is up to date, rebase forced.\n"
+msgstr "La branca actual %s està al dia; «rebase» forçat.\n"
 
-#: builtin/name-rev.c:396
-msgid "only use tags to name the commits"
-msgstr "només usa les etiquetes per a anomenar les comissions"
+#: builtin/rebase.c:2139
+msgid "The pre-rebase hook refused to rebase."
+msgstr "El lligam pre-«rebase» ha refusat a fer «rebase»."
 
-#: builtin/name-rev.c:398
-msgid "only use refs matching <pattern>"
-msgstr "només usa les referències que coincideixin amb <patró>"
+#: builtin/rebase.c:2146
+#, c-format
+msgid "Changes to %s:\n"
+msgstr "Canvis a  %s:\n"
 
-#: builtin/name-rev.c:400
-msgid "ignore refs matching <pattern>"
-msgstr "ignora les referències que coincideixin amb <patró>"
+#: builtin/rebase.c:2149
+#, c-format
+msgid "Changes from %s to %s:\n"
+msgstr "Canvis de %s a %s:\n"
 
-#: builtin/name-rev.c:402
-msgid "list all commits reachable from all refs"
-msgstr "llista totes les comissions abastables de totes les referències"
+#: builtin/rebase.c:2174
+#, c-format
+msgid "First, rewinding head to replay your work on top of it...\n"
+msgstr ""
+"Primer, s'està rebobinant HEAD per a reproduir el vostre treball al "
+"damunt...\n"
 
-#: builtin/name-rev.c:403
-msgid "read from stdin"
-msgstr "llegeix de stdin"
+#: builtin/rebase.c:2183
+msgid "Could not detach HEAD"
+msgstr "No s'ha pogut separar HEAD"
 
-#: builtin/name-rev.c:404
-msgid "allow to print `undefined` names (default)"
-msgstr "permet imprimir els noms `undefined` (per defecte)"
+#: builtin/rebase.c:2192
+#, c-format
+msgid "Fast-forwarded %s to %s.\n"
+msgstr "Avanç ràpid %s a %s.\n"
 
-#: builtin/name-rev.c:410
-msgid "dereference tags in the input (internal use)"
-msgstr "desreferencia les etiquetes en l'entrada (ús intern)"
+#: builtin/receive-pack.c:32
+msgid "git receive-pack <git-dir>"
+msgstr "git receive-pack <git-dir>"
 
-#: builtin/notes.c:26
-msgid "git notes [--ref <notes-ref>] [list [<object>]]"
-msgstr "git notes [--ref <referència-de-notes>] [llista [<objecte>]]"
+#: builtin/receive-pack.c:830
+msgid ""
+"By default, updating the current branch in a non-bare repository\n"
+"is denied, because it will make the index and work tree inconsistent\n"
+"with what you pushed, and will require 'git reset --hard' to match\n"
+"the work tree to HEAD.\n"
+"\n"
+"You can set the 'receive.denyCurrentBranch' configuration variable\n"
+"to 'ignore' or 'warn' in the remote repository to allow pushing into\n"
+"its current branch; however, this is not recommended unless you\n"
+"arranged to update its work tree to match what you pushed in some\n"
+"other way.\n"
+"\n"
+"To squelch this message and still keep the default behaviour, set\n"
+"'receive.denyCurrentBranch' configuration variable to 'refuse'."
+msgstr ""
+"Per defecte, es denega actualitzar la branca actual en un dipòsit no\n"
+"nu, perquè faria l'índex i l'arbre de treball inconsistents amb el\n"
+"que hàgiu pujat, i requeriria 'git reset --hard' per a fer que\n"
+"l'arbre de treball coincideixi amb HEAD.\n"
+"\n"
+"Podeu establir la variable de configuració\n"
+"'receive.denyCurrentBranch' a 'ignore' o 'warn' en el dipòsit remot\n"
+"per a permetre pujar a la seva branca actual; no obstant, no es\n"
+"recomana això a menys que hàgiu decidit actualitzar el seu arbre en\n"
+"alguna altra manera per a coincidir amb el que hàgiu pujat.\n"
+"\n"
+"Per a silenciar aquest missatge i mantenir el comportament\n"
+"predeterminat, establiu la variable de configuració\n"
+"'receive.denyCurrentBranch' a 'refuse'."
 
-#: builtin/notes.c:27
+#: builtin/receive-pack.c:850
 msgid ""
-"git notes [--ref <notes-ref>] add [-f] [--allow-empty] [-m <msg> | -F <file> "
-"| (-c | -C) <object>] [<object>]"
+"By default, deleting the current branch is denied, because the next\n"
+"'git clone' won't result in any file checked out, causing confusion.\n"
+"\n"
+"You can set 'receive.denyDeleteCurrent' configuration variable to\n"
+"'warn' or 'ignore' in the remote repository to allow deleting the\n"
+"current branch, with or without a warning message.\n"
+"\n"
+"To squelch this message, you can set it to 'refuse'."
 msgstr ""
-"git notes [--ref <referència-de-notes>] add [-f] [--allow-empty] [-m "
-"<missatge> | -F <fitxer> | (-c | -C) <objecte>] [<objecte>]"
+"Per defecte, es denega suprimir la branca actual, perquè el\n"
+"'git clone' següent no resultarà en cap fitxer agafat, causant\n"
+"confusió.\n"
+"\n"
+"Podeu establir la variable de configuració\n"
+"'receive.denyDeleteCurrent' a 'warn' o 'ignore' en el dipòsit remot\n"
+"per a permetre suprimir la branca actual, amb un missatge\n"
+"d'advertència o sense.\n"
+"\n"
+"Per a silenciar aquest missatge, podeu establir-la a 'refuse'."
 
-#: builtin/notes.c:28
-msgid "git notes [--ref <notes-ref>] copy [-f] <from-object> <to-object>"
+#: builtin/receive-pack.c:1936
+msgid "quiet"
+msgstr "silenciós"
+
+#: builtin/receive-pack.c:1950
+msgid "You must specify a directory."
+msgstr "Heu d'especificar un directori."
+
+#: builtin/reflog.c:17
+msgid ""
+"git reflog expire [--expire=<time>] [--expire-unreachable=<time>] [--"
+"rewrite] [--updateref] [--stale-fix] [--dry-run | -n] [--verbose] [--all] "
+"<refs>..."
 msgstr ""
-"git notes [--ref <referència-de-notes>] copy [-f] <d'objecte> <a-objecte>"
 
-#: builtin/notes.c:29
+#: builtin/reflog.c:22
 msgid ""
-"git notes [--ref <notes-ref>] append [--allow-empty] [-m <msg> | -F <file> | "
-"(-c | -C) <object>] [<object>]"
+"git reflog delete [--rewrite] [--updateref] [--dry-run | -n] [--verbose] "
+"<refs>..."
 msgstr ""
-"git notes [--ref <referència-de-notes>] append [--allow-empty] [-m "
-"<missatge> | -F <fitxer> | (-c | -C) <objecte>] [<objecte>]"
 
-#: builtin/notes.c:30
-msgid "git notes [--ref <notes-ref>] edit [--allow-empty] [<object>]"
+#: builtin/reflog.c:25
+msgid "git reflog exists <ref>"
 msgstr ""
-"git notes [--ref <referència-de-notes>] edit [--allow-empty] [<objecte>]"
 
-#: builtin/notes.c:31
-msgid "git notes [--ref <notes-ref>] show [<object>]"
-msgstr "git notes [--ref <referència-de-notes>] show [<objecte>]"
+#: builtin/reflog.c:567 builtin/reflog.c:572
+#, c-format
+msgid "'%s' is not a valid timestamp"
+msgstr "«%s» no és una marca de temps vàlida"
 
-#: builtin/notes.c:32
-msgid ""
-"git notes [--ref <notes-ref>] merge [-v | -q] [-s <strategy>] <notes-ref>"
+#: builtin/reflog.c:605
+#, fuzzy, c-format
+msgid "Marking reachable objects..."
+msgstr "retén els objectes inabastables"
+
+#: builtin/reflog.c:643
+#, c-format
+msgid "%s points nowhere!"
 msgstr ""
-"git notes [--ref <referència-de-notes>] merge [-v | -q] [-s <estratègia>] "
-"<referència-de-notes>"
 
-#: builtin/notes.c:33
-msgid "git notes merge --commit [-v | -q]"
-msgstr "git notes merge --commit [-v | -q]"
+#: builtin/reflog.c:695
+#, fuzzy
+msgid "no reflog specified to delete"
+msgstr "cap remot especificat"
 
-#: builtin/notes.c:34
-msgid "git notes merge --abort [-v | -q]"
-msgstr "git notes merge --abort [-v | -q]"
+#: builtin/reflog.c:704
+#, fuzzy, c-format
+msgid "not a reflog: %s"
+msgstr "no es pot llegir «%s»"
 
-#: builtin/notes.c:35
-msgid "git notes [--ref <notes-ref>] remove [<object>...]"
-msgstr "git notes [--ref <referència-de-notes>] remove [<objecte>...]"
+#: builtin/reflog.c:709
+#, fuzzy, c-format
+msgid "no reflog for '%s'"
+msgstr "no s'ha pogut llegir el fitxer de registre per «%s»"
 
-#: builtin/notes.c:36
-msgid "git notes [--ref <notes-ref>] prune [-n] [-v]"
-msgstr "git notes [--ref <referència-de-notes>] prune [-n] [-v]"
+#: builtin/reflog.c:755
+#, c-format
+msgid "invalid ref format: %s"
+msgstr "format de referència no vàlid: %s"
 
-#: builtin/notes.c:37
-msgid "git notes [--ref <notes-ref>] get-ref"
-msgstr "git notes [--ref <referència-de-notes>] get-ref"
+#: builtin/reflog.c:764
+msgid "git reflog [ show | expire | delete | exists ]"
+msgstr ""
 
-#: builtin/notes.c:42
-msgid "git notes [list [<object>]]"
-msgstr "git notes [llista [<objecte>]]"
+#: builtin/remote.c:16
+msgid "git remote [-v | --verbose]"
+msgstr "git remote [-v | --verbose]"
 
-#: builtin/notes.c:47
-msgid "git notes add [<options>] [<object>]"
-msgstr "git notes add [<opcions>] [<objecte>]"
+#: builtin/remote.c:17
+msgid ""
+"git remote add [-t <branch>] [-m <master>] [-f] [--tags | --no-tags] [--"
+"mirror=<fetch|push>] <name> <url>"
+msgstr ""
+"git remote add [-t <branca>] [-m <mestra>] [-f] [--tags | --no-tags] [--"
+"mirror=<fetch|push>] <nom> <url>"
 
-#: builtin/notes.c:52
-msgid "git notes copy [<options>] <from-object> <to-object>"
-msgstr "git notes copy [<opcions>] <d'objecte> <a-objecte>"
+#: builtin/remote.c:18 builtin/remote.c:38
+msgid "git remote rename <old> <new>"
+msgstr "git remote rename <antic> <nou>"
+
+#: builtin/remote.c:19 builtin/remote.c:43
+msgid "git remote remove <name>"
+msgstr "git remote remove <nom>"
+
+#: builtin/remote.c:20 builtin/remote.c:48
+msgid "git remote set-head <name> (-a | --auto | -d | --delete | <branch>)"
+msgstr "git remote set-head <nom> (-a | --auto | -d | --delete | <branca>)"
+
+#: builtin/remote.c:21
+msgid "git remote [-v | --verbose] show [-n] <name>"
+msgstr "git remote [-v | --verbose] show [-n] <nom>"
+
+#: builtin/remote.c:22
+msgid "git remote prune [-n | --dry-run] <name>"
+msgstr "git remote prune [-n | --dry-run] <nom>"
+
+#: builtin/remote.c:23
+msgid ""
+"git remote [-v | --verbose] update [-p | --prune] [(<group> | <remote>)...]"
+msgstr ""
+"git remote [-v | --verbose] update [-p | --prune] [(<grup> | <remot>)...]"
 
-#: builtin/notes.c:53
-msgid "git notes copy --stdin [<from-object> <to-object>]..."
-msgstr "git notes copy --stdin [<d'objecte> <a-objecte>]..."
+#: builtin/remote.c:24
+msgid "git remote set-branches [--add] <name> <branch>..."
+msgstr "git remote set-branches [--add] <nom> <branca>..."
 
-#: builtin/notes.c:58
-msgid "git notes append [<options>] [<object>]"
-msgstr "git notes append [<opcions>] [<objecte>]"
+#: builtin/remote.c:25 builtin/remote.c:74
+msgid "git remote get-url [--push] [--all] <name>"
+msgstr "git remote get-url [--push] [--all] <nom>"
 
-#: builtin/notes.c:63
-msgid "git notes edit [<object>]"
-msgstr "git notes edit [<objecte>]"
+#: builtin/remote.c:26 builtin/remote.c:79
+msgid "git remote set-url [--push] <name> <newurl> [<oldurl>]"
+msgstr "git remote set-url [--push] <nom> <url-nou> [<url-antic>]"
 
-#: builtin/notes.c:68
-msgid "git notes show [<object>]"
-msgstr "git notes show [<objecte>]"
+#: builtin/remote.c:27 builtin/remote.c:80
+msgid "git remote set-url --add <name> <newurl>"
+msgstr "git remote set-url --add <nom> <url-nou>"
 
-#: builtin/notes.c:73
-msgid "git notes merge [<options>] <notes-ref>"
-msgstr "git notes merge [<opcions>] <referència-de-notes>"
+#: builtin/remote.c:28 builtin/remote.c:81
+msgid "git remote set-url --delete <name> <url>"
+msgstr "git remote set-url --delete <nom> <url>"
 
-#: builtin/notes.c:74
-msgid "git notes merge --commit [<options>]"
-msgstr "git notes merge --commit [<opcions>]"
+#: builtin/remote.c:33
+msgid "git remote add [<options>] <name> <url>"
+msgstr "git remote add [<opcions>] <nom> <url>"
 
-#: builtin/notes.c:75
-msgid "git notes merge --abort [<options>]"
-msgstr "git notes merge --abort [<opcions>]"
+#: builtin/remote.c:53
+msgid "git remote set-branches <name> <branch>..."
+msgstr "git remote set-branches <nom> <branca>..."
 
-#: builtin/notes.c:80
-msgid "git notes remove [<object>]"
-msgstr "git notes remove [<objecte>]"
+#: builtin/remote.c:54
+msgid "git remote set-branches --add <name> <branch>..."
+msgstr "git remote set-branches --add <nom> <branca>..."
 
-#: builtin/notes.c:85
-msgid "git notes prune [<options>]"
-msgstr "git notes prune [<opcions>]"
+#: builtin/remote.c:59
+msgid "git remote show [<options>] <name>"
+msgstr "git remote show [<opcions>] <nom>"
 
-#: builtin/notes.c:90
-msgid "git notes get-ref"
-msgstr "git notes get-ref"
+#: builtin/remote.c:64
+msgid "git remote prune [<options>] <name>"
+msgstr "git remote prune [<opcions>] <nom>"
 
-#: builtin/notes.c:95
-msgid "Write/edit the notes for the following object:"
-msgstr "Escriviu/editeu les notes per l'objecte següent:"
+#: builtin/remote.c:69
+msgid "git remote update [<options>] [<group> | <remote>]..."
+msgstr "git remote update [<opcions>] [<grup> | <remot>]..."
 
-#: builtin/notes.c:148
+#: builtin/remote.c:98
 #, c-format
-msgid "unable to start 'show' for object '%s'"
-msgstr "no s'ha pogut iniciar 'show' per a l'objecte «%s»"
+msgid "Updating %s"
+msgstr "S'està actualitzant %s"
 
-#: builtin/notes.c:152
-msgid "could not read 'show' output"
-msgstr "no s'ha pogut llegir la sortida de 'show'"
+#: builtin/remote.c:130
+msgid ""
+"--mirror is dangerous and deprecated; please\n"
+"\t use --mirror=fetch or --mirror=push instead"
+msgstr ""
+"--mirror és perillós i està en desús; \n"
+"\t useu --mirror=fetch o\n"
+"\t --mirror=push en lloc d'això"
 
-#: builtin/notes.c:160
+#: builtin/remote.c:147
 #, c-format
-msgid "failed to finish 'show' for object '%s'"
-msgstr "S'ha produït un error en finalitzar 'show' per a l'objecte «%s»"
+msgid "unknown mirror argument: %s"
+msgstr "paràmetre de reflexió desconegut: %s"
 
-#: builtin/notes.c:195
-msgid "please supply the note contents using either -m or -F option"
-msgstr ""
-"especifiqueu el contingut de la nota fent servir l'opció -m o l'opció -F"
+#: builtin/remote.c:163
+msgid "fetch the remote branches"
+msgstr "obtén les branques remotes"
 
-#: builtin/notes.c:204
-msgid "unable to write note object"
-msgstr "no s'ha pogut escriure l'objecte de nota"
+#: builtin/remote.c:165
+msgid "import all tags and associated objects when fetching"
+msgstr "en obtenir, importa totes les etiquetes i tots els objectes"
 
-#: builtin/notes.c:206
-#, c-format
-msgid "the note contents have been left in %s"
-msgstr "s'han deixat els continguts de la nota en %s"
+#: builtin/remote.c:168
+msgid "or do not fetch any tag at all (--no-tags)"
+msgstr "o no obtinguis cap etiqueta (--no-tags)"
 
-#: builtin/notes.c:234 builtin/tag.c:506
-#, c-format
-msgid "cannot read '%s'"
-msgstr "no es pot llegir «%s»"
+#: builtin/remote.c:170
+msgid "branch(es) to track"
+msgstr "branques a seguir"
 
-#: builtin/notes.c:236 builtin/tag.c:509
-#, c-format
-msgid "could not open or read '%s'"
-msgstr "no s'ha pogut obrir o llegir «%s»"
+#: builtin/remote.c:171
+msgid "master branch"
+msgstr "branca mestra"
 
-#: builtin/notes.c:255 builtin/notes.c:306 builtin/notes.c:308
-#: builtin/notes.c:376 builtin/notes.c:431 builtin/notes.c:517
-#: builtin/notes.c:522 builtin/notes.c:600 builtin/notes.c:662
-#, c-format
-msgid "failed to resolve '%s' as a valid ref."
-msgstr "s'ha produït un error en resoldre «%s» com a referència vàlida."
+#: builtin/remote.c:173
+msgid "set up remote as a mirror to push to or fetch from"
+msgstr "estableix el remot com a mirall al qual pujar o del qual obtenir"
 
-#: builtin/notes.c:258
-#, c-format
-msgid "failed to read object '%s'."
-msgstr "s'ha produït un error en llegir l'objecte «%s»."
+#: builtin/remote.c:185
+msgid "specifying a master branch makes no sense with --mirror"
+msgstr "especificar una branca mestra no té sentit amb --mirror"
 
-#: builtin/notes.c:262
-#, c-format
-msgid "cannot read note data from non-blob object '%s'."
-msgstr "no es poden llegir les dades de node de l'objecte no de blob «%s»."
+#: builtin/remote.c:187
+msgid "specifying branches to track makes sense only with fetch mirrors"
+msgstr ""
+"especificar les branques a seguir té sentit només amb miralls d'obtenció"
 
-#: builtin/notes.c:302
+#: builtin/remote.c:194 builtin/remote.c:636
 #, c-format
-msgid "malformed input line: '%s'."
-msgstr "línia d'entrada mal formada: «%s»."
+msgid "remote %s already exists."
+msgstr "el remot %s ja existeix."
 
-#: builtin/notes.c:317
+#: builtin/remote.c:198 builtin/remote.c:640
 #, c-format
-msgid "failed to copy notes from '%s' to '%s'"
-msgstr "s'ha produït un error en copiar les notes de «%s» a «%s»"
+msgid "'%s' is not a valid remote name"
+msgstr "«%s» no és un nom de remot vàlid"
 
-#. TRANSLATORS: the first %s will be replaced by a git
-#. notes command: 'add', 'merge', 'remove', etc.
-#.
-#: builtin/notes.c:349
+#: builtin/remote.c:238
 #, c-format
-msgid "refusing to %s notes in %s (outside of refs/notes/)"
-msgstr "s'està refusant %s les notes en %s (fora de refs/notes/)"
-
-#: builtin/notes.c:369 builtin/notes.c:424 builtin/notes.c:500
-#: builtin/notes.c:512 builtin/notes.c:588 builtin/notes.c:655
-#: builtin/notes.c:805 builtin/notes.c:952 builtin/notes.c:973
-msgid "too many parameters"
-msgstr "massa paràmetres"
+msgid "Could not setup master '%s'"
+msgstr "No s'ha pogut configurar la mestra «%s»"
 
-#: builtin/notes.c:382 builtin/notes.c:668
+#: builtin/remote.c:344
 #, c-format
-msgid "no note found for object %s."
-msgstr "no s'ha trobat cap nota per a l'objecte %s."
-
-#: builtin/notes.c:403 builtin/notes.c:566
-msgid "note contents as a string"
-msgstr "anota els continguts com a cadena"
-
-#: builtin/notes.c:406 builtin/notes.c:569
-msgid "note contents in a file"
-msgstr "anota els continguts en un fitxer"
+msgid "Could not get fetch map for refspec %s"
+msgstr ""
+"No s'ha pogut obtenir el mapa d'obtenció de l'especificació de referència %s"
 
-#: builtin/notes.c:409 builtin/notes.c:572
-msgid "reuse and edit specified note object"
-msgstr "reusa i edita l'objecte de nota especificat"
+#: builtin/remote.c:443 builtin/remote.c:451
+msgid "(matching)"
+msgstr "(coincident)"
 
-#: builtin/notes.c:412 builtin/notes.c:575
-msgid "reuse specified note object"
-msgstr "reusa l'objecte de nota especificat"
+#: builtin/remote.c:455
+msgid "(delete)"
+msgstr "(suprimir)"
 
-#: builtin/notes.c:415 builtin/notes.c:578
-msgid "allow storing empty note"
-msgstr "permet l'emmagatzematge d'una nota buida"
+#: builtin/remote.c:629 builtin/remote.c:764 builtin/remote.c:863
+#, c-format
+msgid "No such remote: '%s'"
+msgstr "No existeix el remot «%s»"
 
-#: builtin/notes.c:416 builtin/notes.c:487
-msgid "replace existing notes"
-msgstr "reemplaça les notes existents"
+#: builtin/remote.c:646
+#, c-format
+msgid "Could not rename config section '%s' to '%s'"
+msgstr "No s'ha pogut canviar el nom de la secció de configuració «%s» a «%s»"
 
-#: builtin/notes.c:441
+#: builtin/remote.c:666
 #, c-format
 msgid ""
-"Cannot add notes. Found existing notes for object %s. Use '-f' to overwrite "
-"existing notes"
+"Not updating non-default fetch refspec\n"
+"\t%s\n"
+"\tPlease update the configuration manually if necessary."
 msgstr ""
-"No es poden afegir les notes. S'han trobat notes existents de l'objecte %s. "
-"Useu '-f' per a sobreescriure les notes existents."
+"No s'està actualitzant l'especificació de referències d'obtenció no per "
+"defecte\n"
+"\t%s\n"
+"\tActualitzeu la configuració manualment si és necessari."
 
-#: builtin/notes.c:456 builtin/notes.c:535
+#: builtin/remote.c:701
 #, c-format
-msgid "Overwriting existing notes for object %s\n"
-msgstr "S'estan sobreescrivint les notes existents de l'objecte %s\n"
+msgid "deleting '%s' failed"
+msgstr "la supressió de «%s» ha fallat"
 
-#: builtin/notes.c:467 builtin/notes.c:627 builtin/notes.c:892
+#: builtin/remote.c:735
 #, c-format
-msgid "Removing note for object %s\n"
-msgstr "S'està eliminant la nota de l'objecte %s\n"
-
-#: builtin/notes.c:488
-msgid "read objects from stdin"
-msgstr "llegeix els objectes des de stdin"
-
-#: builtin/notes.c:490
-msgid "load rewriting config for <command> (implies --stdin)"
-msgstr ""
-"carrega la configuració de reescriptura per a <ordre> (implica --stdin)"
-
-#: builtin/notes.c:508
-msgid "too few parameters"
-msgstr "hi ha massa pocs paràmetres"
+msgid "creating '%s' failed"
+msgstr "la creació de «%s» ha fallat"
 
-#: builtin/notes.c:529
-#, c-format
+#: builtin/remote.c:801
 msgid ""
-"Cannot copy notes. Found existing notes for object %s. Use '-f' to overwrite "
-"existing notes"
-msgstr ""
-"No es poden copiar les notes. S'han trobat notes existents de l'objecte %s. "
-"Useu '-f' per a sobreescriure les notes existents."
+"Note: A branch outside the refs/remotes/ hierarchy was not removed;\n"
+"to delete it, use:"
+msgid_plural ""
+"Note: Some branches outside the refs/remotes/ hierarchy were not removed;\n"
+"to delete them, use:"
+msgstr[0] ""
+"Nota: Una branca fora de la jerarquia refs/remotes/ no s'ha eliminat;\n"
+"per a suprimir-la, useu:"
+msgstr[1] ""
+"Nota: Algunes branques fora de la jerarquia refs/remotes/ no s'han "
+"eliminat;\n"
+"per a suprimir-les, useu:"
 
-#: builtin/notes.c:541
+#: builtin/remote.c:815
 #, c-format
-msgid "missing notes on source object %s. Cannot copy."
-msgstr "manquen notes a l'objecte font %s. No es pot copiar."
+msgid "Could not remove config section '%s'"
+msgstr "No s'ha pogut eliminar la secció de configuració «%s»"
 
-#: builtin/notes.c:593
+#: builtin/remote.c:916
 #, c-format
-msgid ""
-"The -m/-F/-c/-C options have been deprecated for the 'edit' subcommand.\n"
-"Please use 'git notes add -f -m/-F/-c/-C' instead.\n"
-msgstr ""
-"Es desaconsellen les opcions -m/-F/-c/-C en favor de la subordre 'edit'.\n"
-"Useu «git notes add -f -m/-F/-c/-C» en lloc d'això.\n"
+msgid " new (next fetch will store in remotes/%s)"
+msgstr " nou (la pròxima obtenció emmagatzemarà a remotes/%s)"
 
-#: builtin/notes.c:688
-msgid "failed to delete ref NOTES_MERGE_PARTIAL"
-msgstr "s'ha produït un error en suprimir la referència NOTES_MERGE_PARTIAL"
+#: builtin/remote.c:919
+msgid " tracked"
+msgstr " seguit"
 
-#: builtin/notes.c:690
-msgid "failed to delete ref NOTES_MERGE_REF"
-msgstr "s'ha produït un error en suprimir la referència NOTES_MERGE_REF"
+#: builtin/remote.c:921
+msgid " stale (use 'git remote prune' to remove)"
+msgstr " estancat (useu 'git remote prune' per a eliminar)"
 
-#: builtin/notes.c:692
-msgid "failed to remove 'git notes merge' worktree"
-msgstr ""
-"s'ha produït un error en eliminar l'arbre de treball de 'git notes merge'"
+#: builtin/remote.c:923
+msgid " ???"
+msgstr " ???"
 
-#: builtin/notes.c:712
-msgid "failed to read ref NOTES_MERGE_PARTIAL"
-msgstr "s'ha produït un error en llegir la referència NOTES_MERGE_PARTIAL"
+#: builtin/remote.c:964
+#, c-format
+msgid "invalid branch.%s.merge; cannot rebase onto > 1 branch"
+msgstr "branch.%s.merge no vàlid; no es pot fer «rebase» sobre > 1 branca"
 
-#: builtin/notes.c:714
-msgid "could not find commit from NOTES_MERGE_PARTIAL."
-msgstr "no s'ha pogut trobar cap comissió de NOTES_MERGE_PARTIAL."
+#: builtin/remote.c:973
+#, c-format
+msgid "rebases interactively onto remote %s"
+msgstr "es fa «rebase» interactivament sobre el remot %s"
 
-#: builtin/notes.c:716
-msgid "could not parse commit from NOTES_MERGE_PARTIAL."
-msgstr "no s'ha pogut analitzar la comissió de NOTES_MERGE_PARTIAL."
+#: builtin/remote.c:975
+#, fuzzy, c-format
+msgid "rebases interactively (with merges) onto remote %s"
+msgstr "es fa «rebase» interactivament sobre el remot %s"
 
-#: builtin/notes.c:729
-msgid "failed to resolve NOTES_MERGE_REF"
-msgstr "s'ha produït un error en resoldre NOTES_MERGE_REF"
+#: builtin/remote.c:978
+#, c-format
+msgid "rebases onto remote %s"
+msgstr "es fa «rebase» sobre el remot %s"
 
-#: builtin/notes.c:732
-msgid "failed to finalize notes merge"
-msgstr "s'ha produït un error en finalitzar la fusió de notes"
+#: builtin/remote.c:982
+#, c-format
+msgid " merges with remote %s"
+msgstr "es fusiona amb el remot %s"
+
+#: builtin/remote.c:985
+#, c-format
+msgid "merges with remote %s"
+msgstr "es fusiona amb el remot %s"
+
+#: builtin/remote.c:988
+#, c-format
+msgid "%-*s    and with remote %s\n"
+msgstr "%-*s    i amb el remot %s\n"
 
-#: builtin/notes.c:758
-#, c-format
-msgid "unknown notes merge strategy %s"
-msgstr "estratègia de fusió de notes desconeguda %s"
+#: builtin/remote.c:1031
+msgid "create"
+msgstr "crea"
 
-#: builtin/notes.c:774
-msgid "General options"
-msgstr "Opcions generals"
+#: builtin/remote.c:1034
+msgid "delete"
+msgstr "suprimeix"
 
-#: builtin/notes.c:776
-msgid "Merge options"
-msgstr "Opcions de fusió"
+#: builtin/remote.c:1038
+msgid "up to date"
+msgstr "al dia"
 
-#: builtin/notes.c:778
-msgid ""
-"resolve notes conflicts using the given strategy (manual/ours/theirs/union/"
-"cat_sort_uniq)"
-msgstr ""
-"resol els conflictes de nota usant l'estratègia donada (manual/ours/theirs/"
-"union/cat_sort_uniq)"
+#: builtin/remote.c:1041
+msgid "fast-forwardable"
+msgstr "avanç ràpid possible"
 
-#: builtin/notes.c:780
-msgid "Committing unmerged notes"
-msgstr "S'estan cometent les notes sense fusionar"
+#: builtin/remote.c:1044
+msgid "local out of date"
+msgstr "local no actualitzat"
 
-#: builtin/notes.c:782
-msgid "finalize notes merge by committing unmerged notes"
-msgstr "finalitza la fusió de notes cometent les notes sense fusionar"
+#: builtin/remote.c:1051
+#, c-format
+msgid "    %-*s forces to %-*s (%s)"
+msgstr "    %-*s força a %-*s (%s)"
 
-#: builtin/notes.c:784
-msgid "Aborting notes merge resolution"
-msgstr "S'està avortant la resolució de fusió de notes"
+#: builtin/remote.c:1054
+#, c-format
+msgid "    %-*s pushes to %-*s (%s)"
+msgstr "    %-*s puja a %-*s (%s)"
 
-#: builtin/notes.c:786
-msgid "abort notes merge"
-msgstr "avorta la fusió de notes"
+#: builtin/remote.c:1058
+#, c-format
+msgid "    %-*s forces to %s"
+msgstr "    %-*s força a %s"
 
-#: builtin/notes.c:797
-msgid "cannot mix --commit, --abort or -s/--strategy"
-msgstr "no es pot combinar --commit, --abort i -s/--strategy"
+#: builtin/remote.c:1061
+#, c-format
+msgid "    %-*s pushes to %s"
+msgstr "    %-*s puja a %s"
 
-#: builtin/notes.c:802
-msgid "must specify a notes ref to merge"
-msgstr "cal especificar una referència de notes a fusionar"
+#: builtin/remote.c:1129
+msgid "do not query remotes"
+msgstr "no consultis els remots"
 
-#: builtin/notes.c:826
+#: builtin/remote.c:1156
 #, c-format
-msgid "unknown -s/--strategy: %s"
-msgstr "-s/--strategy desconeguda: %s"
+msgid "* remote %s"
+msgstr "* remot %s"
 
-#: builtin/notes.c:863
+#: builtin/remote.c:1157
 #, c-format
-msgid "a notes merge into %s is already in-progress at %s"
-msgstr "una fusió de notes a %s ja està en curs a %s"
+msgid "  Fetch URL: %s"
+msgstr "  URL d'obtenció: %s"
+
+#: builtin/remote.c:1158 builtin/remote.c:1174 builtin/remote.c:1313
+msgid "(no URL)"
+msgstr "(sense URL)"
+
+#. TRANSLATORS: the colon ':' should align
+#. with the one in " Fetch URL: %s"
+#. translation.
+#.
+#: builtin/remote.c:1172 builtin/remote.c:1174
+#, c-format
+msgid "  Push  URL: %s"
+msgstr "  URL de pujada: %s"
 
-#: builtin/notes.c:866
+#: builtin/remote.c:1176 builtin/remote.c:1178 builtin/remote.c:1180
 #, c-format
-msgid "failed to store link to current notes ref (%s)"
-msgstr ""
-"s'ha produït un error en emmagatzemar l'enllaç a la referència de notes "
-"actual (%s)"
+msgid "  HEAD branch: %s"
+msgstr "  Branca de HEAD: %s"
+
+#: builtin/remote.c:1176
+msgid "(not queried)"
+msgstr "(no consultat)"
+
+#: builtin/remote.c:1178
+msgid "(unknown)"
+msgstr "(desconegut)"
 
-#: builtin/notes.c:868
+#: builtin/remote.c:1182
 #, c-format
 msgid ""
-"Automatic notes merge failed. Fix conflicts in %s and commit the result with "
-"'git notes merge --commit', or abort the merge with 'git notes merge --"
-"abort'.\n"
+"  HEAD branch (remote HEAD is ambiguous, may be one of the following):\n"
 msgstr ""
-"La fusió de notes automàtica ha fallat. Arregleu els conflictes en %s i "
-"cometeu el resultat amb 'git notes merge --commit', o avorteu la fusió amb "
-"'git notes merge --abort'.\n"
+"  Branca de HEAD (la HEAD remot és ambigua, pot ser un dels següents):\n"
 
-#: builtin/notes.c:890
+#: builtin/remote.c:1194
 #, c-format
-msgid "Object %s has no note\n"
-msgstr "L'objecte %s no té cap nota\n"
-
-#: builtin/notes.c:902
-msgid "attempt to remove non-existent note is not an error"
-msgstr "l'intent d'eliminar una nota no existent no és un error"
+msgid "  Remote branch:%s"
+msgid_plural "  Remote branches:%s"
+msgstr[0] "  Branca remota:%s"
+msgstr[1] "  Branques remotes:%s"
 
-#: builtin/notes.c:905
-msgid "read object names from the standard input"
-msgstr "llegeix els noms d'objecte des de l'entrada estàndard"
+#: builtin/remote.c:1197 builtin/remote.c:1223
+msgid " (status not queried)"
+msgstr " (estat no consultat)"
 
-#: builtin/notes.c:943 builtin/prune.c:106 builtin/worktree.c:160
-msgid "do not remove, show only"
-msgstr "no eliminis, només mostra"
+#: builtin/remote.c:1206
+msgid "  Local branch configured for 'git pull':"
+msgid_plural "  Local branches configured for 'git pull':"
+msgstr[0] "  Branca local configurada per a «git pull»:"
+msgstr[1] "  Branques locals configurades per a «git pull»:"
 
-#: builtin/notes.c:944
-msgid "report pruned notes"
-msgstr "informa de notes podades"
+#: builtin/remote.c:1214
+msgid "  Local refs will be mirrored by 'git push'"
+msgstr "  «git push» reflectirà les referències locals"
 
-#: builtin/notes.c:986
-msgid "notes-ref"
-msgstr "referència de notes"
+#: builtin/remote.c:1220
+#, c-format
+msgid "  Local ref configured for 'git push'%s:"
+msgid_plural "  Local refs configured for 'git push'%s:"
+msgstr[0] "  Referència local configurada per a «git push»%s:"
+msgstr[1] "  Referències locals configurades per a «git push»%s:"
 
-#: builtin/notes.c:987
-msgid "use notes from <notes-ref>"
-msgstr "usa les notes de <referència-de-notes>"
+#: builtin/remote.c:1241
+msgid "set refs/remotes/<name>/HEAD according to remote"
+msgstr "estableix refs/remotes/<name>/HEAD segons el remot"
 
-#: builtin/notes.c:1022
-#, c-format
-msgid "unknown subcommand: %s"
-msgstr "subordre desconeguda: %s"
+#: builtin/remote.c:1243
+msgid "delete refs/remotes/<name>/HEAD"
+msgstr "suprimeix refs/remotes/<name>/HEAD"
 
-#: builtin/pack-objects.c:33
-msgid ""
-"git pack-objects --stdout [<options>...] [< <ref-list> | < <object-list>]"
-msgstr ""
-"git pack-objects --stdout [<opcions>...] [< <llista-de-referències> | < "
-"<llista-de-objectes>]"
+#: builtin/remote.c:1258
+msgid "Cannot determine remote HEAD"
+msgstr "No es pot determinar la HEAD remota"
 
-#: builtin/pack-objects.c:34
-msgid ""
-"git pack-objects [<options>...] <base-name> [< <ref-list> | < <object-list>]"
-msgstr ""
-"git pack-objects [<opcions>...] <nom-base> [< <llista-de-referències> | < "
-"<llista-de-objectes>]"
+#: builtin/remote.c:1260
+msgid "Multiple remote HEAD branches. Please choose one explicitly with:"
+msgstr "Múltiples branques de HEAD remotes. Trieu-ne una explícitament amb:"
 
-#: builtin/pack-objects.c:195 builtin/pack-objects.c:198
+#: builtin/remote.c:1270
 #, c-format
-msgid "deflate error (%d)"
-msgstr "error de deflació (%d)"
-
-#: builtin/pack-objects.c:791
-msgid "disabling bitmap writing, packs are split due to pack.packSizeLimit"
-msgstr ""
-"s'està inhabilitant l'escriptura de mapes de bits, es divideixen els paquets "
-"a causa de pack.packSizeLimit"
+msgid "Could not delete %s"
+msgstr "No s'ha pogut suprimir %s"
 
-#: builtin/pack-objects.c:804
-msgid "Writing objects"
-msgstr "S'estan escrivint els objectes"
+#: builtin/remote.c:1278
+#, c-format
+msgid "Not a valid ref: %s"
+msgstr "No és una referència vàlida: %s"
 
-#: builtin/pack-objects.c:1084
-msgid "disabling bitmap writing, as some objects are not being packed"
-msgstr ""
-"s'està inhabilitant l'escriptura de mapes de bits, perquè alguns objectes no "
-"s'empaqueten"
+#: builtin/remote.c:1280
+#, c-format
+msgid "Could not setup %s"
+msgstr "No s'ha pogut configurar %s"
 
-#: builtin/pack-objects.c:2454
-msgid "Compressing objects"
-msgstr "S'estan comprimint els objectes"
+#: builtin/remote.c:1298
+#, c-format
+msgid " %s will become dangling!"
+msgstr " %s es tornarà penjant!"
 
-#: builtin/pack-objects.c:2625
-msgid "invalid value for --missing"
-msgstr "valor no vàlid per a --missing"
+#: builtin/remote.c:1299
+#, c-format
+msgid " %s has become dangling!"
+msgstr " %s s'ha tornat penjant!"
 
-#: builtin/pack-objects.c:2928
+#: builtin/remote.c:1309
 #, c-format
-msgid "unsupported index version %s"
-msgstr "versió d'índex no compatible %s"
+msgid "Pruning %s"
+msgstr "S'està podant %s"
 
-#: builtin/pack-objects.c:2932
+#: builtin/remote.c:1310
 #, c-format
-msgid "bad index version '%s'"
-msgstr "versió d'índex incorrecta «%s»"
+msgid "URL: %s"
+msgstr "URL: %s"
 
-#: builtin/pack-objects.c:2962
-msgid "do not show progress meter"
-msgstr "no mostris l'indicador de progrés"
+#: builtin/remote.c:1326
+#, c-format
+msgid " * [would prune] %s"
+msgstr " * [podaria] %s"
 
-#: builtin/pack-objects.c:2964
-msgid "show progress meter"
-msgstr "mostra l'indicador de progrés"
+#: builtin/remote.c:1329
+#, c-format
+msgid " * [pruned] %s"
+msgstr " * [podat] %s"
 
-#: builtin/pack-objects.c:2966
-msgid "show progress meter during object writing phase"
-msgstr "mostra l'indicador de progrés durant la fase d'escriptura d'objectes"
+#: builtin/remote.c:1374
+msgid "prune remotes after fetching"
+msgstr "poda els remots després d'obtenir-los"
 
-#: builtin/pack-objects.c:2969
-msgid "similar to --all-progress when progress meter is shown"
-msgstr "similar a --all-progress quan l'indicador de progrés es mostra"
+#: builtin/remote.c:1437 builtin/remote.c:1491 builtin/remote.c:1559
+#, c-format
+msgid "No such remote '%s'"
+msgstr "No hi ha tal remot «%s»"
 
-#: builtin/pack-objects.c:2970
-msgid "version[,offset]"
-msgstr "versió[,desplaçament]"
+#: builtin/remote.c:1453
+msgid "add branch"
+msgstr "afegeix branca"
 
-#: builtin/pack-objects.c:2971
-msgid "write the pack index file in the specified idx format version"
-msgstr ""
-"escriu el fitxer d'índex de paquet en la versió de format d'índex "
-"especificada"
+#: builtin/remote.c:1460
+msgid "no remote specified"
+msgstr "cap remot especificat"
 
-#: builtin/pack-objects.c:2974
-msgid "maximum size of each output pack file"
-msgstr "mida màxima de cada fitxer de paquet de sortida"
+#: builtin/remote.c:1477
+msgid "query push URLs rather than fetch URLs"
+msgstr "consulta els URL de pujada en lloc dels URL d'obtenció"
 
-#: builtin/pack-objects.c:2976
-msgid "ignore borrowed objects from alternate object store"
-msgstr "ignora els objectes prestats d'un emmagatzematge d'objectes alternatiu"
+#: builtin/remote.c:1479
+msgid "return all URLs"
+msgstr "retorna tots els URL"
 
-#: builtin/pack-objects.c:2978
-msgid "ignore packed objects"
-msgstr "ignora els objectes empaquetats"
+#: builtin/remote.c:1507
+#, c-format
+msgid "no URLs configured for remote '%s'"
+msgstr "cap URL configurat per al remot «%s»"
 
-#: builtin/pack-objects.c:2980
-msgid "limit pack window by objects"
-msgstr "limita la finestra d'empaquetament per objectes"
+#: builtin/remote.c:1533
+msgid "manipulate push URLs"
+msgstr "manipula els URL de pujada"
 
-#: builtin/pack-objects.c:2982
-msgid "limit pack window by memory in addition to object limit"
-msgstr ""
-"limita la finestra d'empaquetament per memòria a més del límit d'objectes"
+#: builtin/remote.c:1535
+msgid "add URL"
+msgstr "afegeix URL"
 
-#: builtin/pack-objects.c:2984
-msgid "maximum length of delta chain allowed in the resulting pack"
-msgstr ""
-"longitud màxima de la cadena de diferències permesa en el paquet resultant"
+#: builtin/remote.c:1537
+msgid "delete URLs"
+msgstr "suprimeix els URL"
 
-#: builtin/pack-objects.c:2986
-msgid "reuse existing deltas"
-msgstr "reusa les diferències existents"
+#: builtin/remote.c:1544
+msgid "--add --delete doesn't make sense"
+msgstr "--add --delete no té sentit"
 
-#: builtin/pack-objects.c:2988
-msgid "reuse existing objects"
-msgstr "reusa els objectes existents"
+#: builtin/remote.c:1583
+#, c-format
+msgid "Invalid old URL pattern: %s"
+msgstr "Patró d'URL antic no vàlid: %s"
 
-#: builtin/pack-objects.c:2990
-msgid "use OFS_DELTA objects"
-msgstr "usa objectes OFS_DELTA"
+#: builtin/remote.c:1591
+#, c-format
+msgid "No such URL found: %s"
+msgstr "No s'ha trobat tal URL: %s"
 
-#: builtin/pack-objects.c:2992
-msgid "use threads when searching for best delta matches"
-msgstr "usa fils en cercar les millores coincidències de diferències"
+#: builtin/remote.c:1593
+msgid "Will not delete all non-push URLs"
+msgstr "No se suprimiran tots els URL no de pujada"
 
-#: builtin/pack-objects.c:2994
-msgid "do not create an empty pack output"
-msgstr "no creïs una emissió de paquet buida"
+#: builtin/repack.c:23
+msgid "git repack [<options>]"
+msgstr "git repack [<opcions>]"
 
-#: builtin/pack-objects.c:2996
-msgid "read revision arguments from standard input"
-msgstr "llegeix els paràmetres de revisió des de l'entrada estàndard"
+#: builtin/repack.c:28
+msgid ""
+"Incremental repacks are incompatible with bitmap indexes.  Use\n"
+"--no-write-bitmap-index or disable the pack.writebitmaps configuration."
+msgstr ""
+"Els reempaquetaments incrementals són incompatibles amb els índexs de "
+"bitmaps.  Useu\n"
+"--no-write-bitmap-index o inhabiliteu el paràmetre de configuració pack."
+"writebitmaps."
 
-#: builtin/pack-objects.c:2998
-msgid "limit the objects to those that are not yet packed"
-msgstr "limita els objectes als quals encara no s'hagin empaquetat"
+#: builtin/repack.c:191
+msgid "could not start pack-objects to repack promisor objects"
+msgstr ""
 
-#: builtin/pack-objects.c:3001
-msgid "include objects reachable from any reference"
-msgstr "inclou els objectes abastables de qualsevol referència"
+#: builtin/repack.c:230 builtin/repack.c:416
+msgid "repack: Expecting full hex object ID lines only from pack-objects."
+msgstr ""
 
-#: builtin/pack-objects.c:3004
-msgid "include objects referred by reflog entries"
+#: builtin/repack.c:254
+msgid "could not finish pack-objects to repack promisor objects"
 msgstr ""
-"inclou els objectes als quals facin referència les entrades del registre de "
-"referències"
 
-#: builtin/pack-objects.c:3007
-msgid "include objects referred to by the index"
-msgstr "inclou els objectes als quals faci referència l'índex"
+#: builtin/repack.c:292
+msgid "pack everything in a single pack"
+msgstr "empaqueta-ho tot en un únic paquet"
 
-#: builtin/pack-objects.c:3010
-msgid "output pack to stdout"
-msgstr "emet el paquet a stdout"
+#: builtin/repack.c:294
+msgid "same as -a, and turn unreachable objects loose"
+msgstr "el mateix que -a, i solta els objectes inabastables"
 
-#: builtin/pack-objects.c:3012
-msgid "include tag objects that refer to objects to be packed"
-msgstr ""
-"inclou els objectes d'etiqueta que facin referència als objectes a empaquetar"
+#: builtin/repack.c:297
+msgid "remove redundant packs, and run git-prune-packed"
+msgstr "elimina els paquets redundants, i executeu git-prune-packed"
 
-#: builtin/pack-objects.c:3014
-msgid "keep unreachable objects"
-msgstr "retén els objectes inabastables"
+#: builtin/repack.c:299
+msgid "pass --no-reuse-delta to git-pack-objects"
+msgstr "passa --no-reuse-delta a git-pack-objects"
 
-#: builtin/pack-objects.c:3016
-msgid "pack loose unreachable objects"
-msgstr "empaqueta els objectes inabastables solts"
+#: builtin/repack.c:301
+msgid "pass --no-reuse-object to git-pack-objects"
+msgstr "passa --no-reuse-object a git-pack-objects"
 
-#: builtin/pack-objects.c:3018
-msgid "unpack unreachable objects newer than <time>"
-msgstr "desempaqueta els objectes inabastables més nous que <hora>"
+#: builtin/repack.c:303
+msgid "do not run git-update-server-info"
+msgstr "no executis git-update-server-info"
 
-#: builtin/pack-objects.c:3021
-msgid "create thin packs"
-msgstr "crea paquets prims"
+#: builtin/repack.c:306
+msgid "pass --local to git-pack-objects"
+msgstr "passa --local a git-pack-objects"
 
-#: builtin/pack-objects.c:3023
-msgid "create packs suitable for shallow fetches"
-msgstr "crea paquets adequats per a les obtencions superficials"
+#: builtin/repack.c:308
+msgid "write bitmap index"
+msgstr "escriu índex de mapa de bits"
 
-#: builtin/pack-objects.c:3025
-msgid "ignore packs that have companion .keep file"
-msgstr "ignora els paquets que tinguin un fitxer .keep corresponent"
+#: builtin/repack.c:310
+#, fuzzy
+msgid "pass --delta-islands to git-pack-objects"
+msgstr "passa --local a git-pack-objects"
 
-#: builtin/pack-objects.c:3027
-msgid "pack compression level"
-msgstr "nivell de compressió de paquet"
+#: builtin/repack.c:311
+msgid "approxidate"
+msgstr "data aproximada"
 
-#: builtin/pack-objects.c:3029
-msgid "do not hide commits by grafts"
-msgstr "no amaguis les comissions per empelt"
+#: builtin/repack.c:312
+msgid "with -A, do not loosen objects older than this"
+msgstr "amb -A, no soltis els objectes més vells que aquest"
 
-#: builtin/pack-objects.c:3031
-msgid "use a bitmap index if available to speed up counting objects"
-msgstr ""
-"usa un índex de mapa de bits, si està disponible, per a accelerar el "
-"recompte d'objectes"
+#: builtin/repack.c:314
+msgid "with -a, repack unreachable objects"
+msgstr "amb -a, reempaqueta els objectes inabastables"
 
-#: builtin/pack-objects.c:3033
-msgid "write a bitmap index together with the pack index"
-msgstr "escriu un índex de mapa de bits juntament amb l'índex de paquet"
+#: builtin/repack.c:316
+msgid "size of the window used for delta compression"
+msgstr "mida de la finestra que s'usa per a compressió de diferències"
 
-#: builtin/pack-objects.c:3036
-msgid "handling for missing objects"
-msgstr "gestió dels objectes absents"
+#: builtin/repack.c:317 builtin/repack.c:323
+msgid "bytes"
+msgstr "octets"
 
-#: builtin/pack-objects.c:3039
-msgid "do not pack objects in promisor packfiles"
+#: builtin/repack.c:318
+msgid "same as the above, but limit memory size instead of entries count"
 msgstr ""
+"el mateix que l'anterior, però limita la mida de memòria en lloc del nombre "
+"d'entrades"
 
-#: builtin/pack-objects.c:3178
-msgid "Counting objects"
-msgstr "S'estan comptant els objectes"
-
-#: builtin/pack-refs.c:6
-msgid "git pack-refs [<options>]"
-msgstr "git pack-refs [<opcions>]"
+#: builtin/repack.c:320
+msgid "limits the maximum delta depth"
+msgstr "limita la profunditat màxima de les diferències"
 
-#: builtin/pack-refs.c:14
-msgid "pack everything"
-msgstr "empaqueta-ho tot"
+#: builtin/repack.c:322
+msgid "limits the maximum number of threads"
+msgstr "limita el nombre màxim de fils"
 
-#: builtin/pack-refs.c:15
-msgid "prune loose refs (default)"
-msgstr "poda les referències soltes (per defecte)"
+#: builtin/repack.c:324
+msgid "maximum size of each packfile"
+msgstr "mida màxima de cada fitxer de paquet"
 
-#: builtin/prune-packed.c:8
-msgid "git prune-packed [-n | --dry-run] [-q | --quiet]"
-msgstr "git prune-packed [-n | --dry-run] [-q | --quiet]"
+#: builtin/repack.c:326
+msgid "repack objects in packs marked with .keep"
+msgstr "reempaqueta els objectes en paquets marcats amb .keep"
 
-#: builtin/prune-packed.c:41
-msgid "Removing duplicate objects"
-msgstr "S'estan eliminant objectes duplicats"
+#: builtin/repack.c:328
+#, fuzzy
+msgid "do not repack this pack"
+msgstr "crea paquets prims"
 
-#: builtin/prune.c:11
-msgid "git prune [-n] [-v] [--progress] [--expire <time>] [--] [<head>...]"
-msgstr "git prune [-n] [-v] [--progress] [--expire <hora>] [--] [<head>...]"
+#: builtin/repack.c:338
+msgid "cannot delete packs in a precious-objects repo"
+msgstr "no es poden suprimir paquets en un dipòsit d'objectes preciosos"
 
-#: builtin/prune.c:107
-msgid "report pruned objects"
-msgstr "informa d'objectes podats"
+#: builtin/repack.c:342
+msgid "--keep-unreachable and -A are incompatible"
+msgstr "--keep-unreachable i -A són incompatibles"
 
-#: builtin/prune.c:110
-msgid "expire objects older than <time>"
-msgstr "fes caducar els objectes més vells que <hora>"
+#: builtin/repack.c:425
+#, fuzzy
+msgid "Nothing new to pack."
+msgstr "usa el paquet prim"
 
-#: builtin/prune.c:112
-msgid "limit traversal to objects outside promisor packfiles"
+#: builtin/repack.c:486
+#, c-format
+msgid ""
+"WARNING: Some packs in use have been renamed by\n"
+"WARNING: prefixing old- to their name, in order to\n"
+"WARNING: replace them with the new version of the\n"
+"WARNING: file.  But the operation failed, and the\n"
+"WARNING: attempt to rename them back to their\n"
+"WARNING: original names also failed.\n"
+"WARNING: Please rename them in %s manually:\n"
 msgstr ""
 
-#: builtin/prune.c:126
-msgid "cannot prune in a precious-objects repo"
-msgstr "no es pot podar en un dipòsit d'objectes preciosos"
-
-#: builtin/pull.c:54 builtin/pull.c:56
+#: builtin/repack.c:534
 #, c-format
-msgid "Invalid value for %s: %s"
-msgstr "Valor no vàlid per a %s: %s"
+msgid "failed to remove '%s'"
+msgstr "s'ha produït un error en eliminar «%s»"
 
-#: builtin/pull.c:76
-msgid "git pull [<options>] [<repository> [<refspec>...]]"
-msgstr "git pull [<opcions>] [<dipòsit> [<especificació-de-referència>...]]"
+#: builtin/replace.c:22
+msgid "git replace [-f] <object> <replacement>"
+msgstr "git replace [-f] <objecte> <reemplaçament>"
 
-#: builtin/pull.c:127
-msgid "control for recursive fetching of submodules"
-msgstr "controla l'obtenció recursiva de submòduls"
+#: builtin/replace.c:23
+msgid "git replace [-f] --edit <object>"
+msgstr "git replace [-f] --edit <objecte>"
 
-#: builtin/pull.c:131
-msgid "Options related to merging"
-msgstr "Opcions relacionades amb fusionar"
+#: builtin/replace.c:24
+msgid "git replace [-f] --graft <commit> [<parent>...]"
+msgstr "git replace [-f] --graft <comissió> [<mare>...]"
 
-#: builtin/pull.c:134
-msgid "incorporate changes by rebasing rather than merging"
-msgstr "incorpora els canvis fent «rebase» en lloc de fusionar"
+#: builtin/replace.c:25
+msgid "git replace [-f] --convert-graft-file"
+msgstr "git replace [-f] --convert-graft-file"
 
-#: builtin/pull.c:161 builtin/rebase--helper.c:23 builtin/revert.c:121
-msgid "allow fast-forward"
-msgstr "permet l'avanç ràpid"
+#: builtin/replace.c:26
+msgid "git replace -d <object>..."
+msgstr "git replace -d <objecte>..."
 
-#: builtin/pull.c:170
-msgid "automatically stash/stash pop before and after rebase"
+#: builtin/replace.c:27
+msgid "git replace [--format=<format>] [-l [<pattern>]]"
+msgstr "git replace [--format=<format>] [-l [<patró>]]"
+
+#: builtin/replace.c:90
+#, c-format
+msgid ""
+"invalid replace format '%s'\n"
+"valid formats are 'short', 'medium' and 'long'"
 msgstr ""
-"fes «stash» i «stash pop» automàticament abans i després de fer «rebase»"
 
-#: builtin/pull.c:186
-msgid "Options related to fetching"
-msgstr "Opcions relacionades amb obtenir"
+#: builtin/replace.c:125
+#, fuzzy, c-format
+msgid "replace ref '%s' not found"
+msgstr "no s'ha trobat la branca «%s»."
 
-#: builtin/pull.c:204
-msgid "number of submodules pulled in parallel"
-msgstr "nombre de submòduls baixats en paral·lel"
+#: builtin/replace.c:141
+#, fuzzy, c-format
+msgid "Deleted replace ref '%s'"
+msgstr "suprimeix les referències reemplaçades"
 
-#: builtin/pull.c:299
-#, c-format
-msgid "Invalid value for pull.ff: %s"
-msgstr "Valor no vàlid per a pull.ff: %s"
+#: builtin/replace.c:153
+#, fuzzy, c-format
+msgid "'%s' is not a valid ref name"
+msgstr "«%s» no és un nom de remot vàlid"
 
-#: builtin/pull.c:415
-msgid ""
-"There is no candidate for rebasing against among the refs that you just "
-"fetched."
-msgstr ""
-"No hi ha cap candidat sobre el qual fer «rebase» entre les referències que "
-"acabeu d'obtenir."
+#: builtin/replace.c:158
+#, fuzzy, c-format
+msgid "replace ref '%s' already exists"
+msgstr "el destí «%s» ja existeix"
 
-#: builtin/pull.c:417
+#: builtin/replace.c:178
+#, c-format
 msgid ""
-"There are no candidates for merging among the refs that you just fetched."
+"Objects must be of the same type.\n"
+"'%s' points to a replaced object of type '%s'\n"
+"while '%s' points to a replacement object of type '%s'."
 msgstr ""
-"No hi ha candidats per a fusionar entre les referències que acabeu d'obtenir."
 
-#: builtin/pull.c:418
-msgid ""
-"Generally this means that you provided a wildcard refspec which had no\n"
-"matches on the remote end."
-msgstr ""
-"Generalment això vol dir que heu proveït una especificació de\n"
-"referència de comodí que no tenia cap coincidència en el costat remot."
+#: builtin/replace.c:229
+#, fuzzy, c-format
+msgid "unable to open %s for writing"
+msgstr "No s'ha pogut obrir «%s» per a escriptura"
 
-#: builtin/pull.c:421
-#, c-format
-msgid ""
-"You asked to pull from the remote '%s', but did not specify\n"
-"a branch. Because this is not the default configured remote\n"
-"for your current branch, you must specify a branch on the command line."
+#: builtin/replace.c:242
+msgid "cat-file reported failure"
 msgstr ""
-"Heu demanat baixar del remot «%s», però no heu especificat cap branca.\n"
-"Perquè aquest no és el remot configurat per defecte per a la vostra\n"
-"branca actual, heu d'especificar una branca en la línia d'ordres."
 
-#: builtin/pull.c:426 git-parse-remote.sh:73
-msgid "You are not currently on a branch."
-msgstr "Actualment no sou en cap branca."
+#: builtin/replace.c:258
+#, fuzzy, c-format
+msgid "unable to open %s for reading"
+msgstr "no s'ha pogut obrir o llegir %s"
 
-#: builtin/pull.c:428 builtin/pull.c:443 git-parse-remote.sh:79
-msgid "Please specify which branch you want to rebase against."
-msgstr "Especifiqueu sobre què branca voleu fer «rebase»."
+#: builtin/replace.c:272
+#, fuzzy
+msgid "unable to spawn mktree"
+msgstr "no s'ha pogut llegir l'arbre (%s)"
 
-#: builtin/pull.c:430 builtin/pull.c:445 git-parse-remote.sh:82
-msgid "Please specify which branch you want to merge with."
-msgstr "Especifiqueu amb quina branca voleu fusionar."
+#: builtin/replace.c:276
+#, fuzzy
+msgid "unable to read from mktree"
+msgstr "no s'ha pogut llegir l'arbre (%s)"
 
-#: builtin/pull.c:431 builtin/pull.c:446
-msgid "See git-pull(1) for details."
-msgstr "Vegeu git-pull(1) per detalls."
+#: builtin/replace.c:285
+#, fuzzy
+msgid "mktree reported failure"
+msgstr "la reversió ha fallat"
 
-#: builtin/pull.c:433 builtin/pull.c:439 builtin/pull.c:448
-#: git-parse-remote.sh:64
-msgid "<remote>"
-msgstr "<remot>"
+#: builtin/replace.c:289
+#, fuzzy
+msgid "mktree did not return an object name"
+msgstr "el remot no ha enviat tots els objectes necessaris"
 
-#: builtin/pull.c:433 builtin/pull.c:448 builtin/pull.c:453 git-rebase.sh:477
-#: git-parse-remote.sh:65
-msgid "<branch>"
-msgstr "<branca>"
+#: builtin/replace.c:298
+#, fuzzy, c-format
+msgid "unable to fstat %s"
+msgstr "no s'ha pogut actualitzar %s"
 
-#: builtin/pull.c:441 git-parse-remote.sh:75
-msgid "There is no tracking information for the current branch."
-msgstr "No hi ha cap informació de seguiment per a la branca actual."
+#: builtin/replace.c:303
+#, fuzzy
+msgid "unable to write object to database"
+msgstr "no s'ha pogut escriure l'objecte de nota"
 
-#: builtin/pull.c:450 git-parse-remote.sh:95
-msgid ""
-"If you wish to set tracking information for this branch you can do so with:"
-msgstr ""
-"Si voleu establir informació de seguiment per a aquesta branca, podeu fer-ho "
-"amb:"
+#: builtin/replace.c:322 builtin/replace.c:378 builtin/replace.c:423
+#: builtin/replace.c:453
+#, fuzzy, c-format
+msgid "not a valid object name: '%s'"
+msgstr "No és un nom d'objecte vàlid: «%s»"
+
+#: builtin/replace.c:326
+#, fuzzy, c-format
+msgid "unable to get object type for %s"
+msgstr "no es pot fer grep des d'un objecte de tipus %s"
 
-#: builtin/pull.c:455
+#: builtin/replace.c:342
+#, fuzzy
+msgid "editing object file failed"
+msgstr "la lectura de les referències de bisecció ha fallat"
+
+#: builtin/replace.c:351
 #, c-format
-msgid ""
-"Your configuration specifies to merge with the ref '%s'\n"
-"from the remote, but no such ref was fetched."
+msgid "new object is the same as the old one: '%s'"
 msgstr ""
-"La vostra configuració especifica fusionar amb la referència «%s»\n"
-"del remot, però no s'ha obtingut tal referència."
 
-#: builtin/pull.c:819
-msgid "ignoring --verify-signatures for rebase"
-msgstr "s'està ignorant --verify-signatures en fer «rebase»"
+#: builtin/replace.c:384
+#, fuzzy, c-format
+msgid "could not parse %s as a commit"
+msgstr "no s'ha pogut analitzar la comissió HEAD"
+
+#: builtin/replace.c:415
+#, c-format
+msgid "bad mergetag in commit '%s'"
+msgstr "etiqueta de fusió incorrecta en la comissió «%s»"
 
-#: builtin/pull.c:867
-msgid "--[no-]autostash option is only valid with --rebase."
-msgstr "l'opció --[no-]-autostash és vàlid només amb --rebase."
+#: builtin/replace.c:417
+#, c-format
+msgid "malformed mergetag in commit '%s'"
+msgstr "etiqueta de fusió mal formada en la comissió «%s»"
 
-#: builtin/pull.c:875
-msgid "Updating an unborn branch with changes added to the index."
+#: builtin/replace.c:429
+#, c-format
+msgid ""
+"original commit '%s' contains mergetag '%s' that is discarded; use --edit "
+"instead of --graft"
 msgstr ""
-"S'està actualitzant una branca no nascuda amb canvis afegits a l'índex."
+"la comissió original «%s» conté l'etiqueta de fusió «%s» que es descarta; "
+"useu --edit en lloc de --graft"
 
-#: builtin/pull.c:878
-msgid "pull with rebase"
-msgstr "baixar fent «rebase»"
+#: builtin/replace.c:468
+#, c-format
+msgid "the original commit '%s' has a gpg signature"
+msgstr "la comissió original «%s» té una signatura gpg"
 
-#: builtin/pull.c:879
-msgid "please commit or stash them."
-msgstr "cometeu-los o emmagatzemeu-los."
+#: builtin/replace.c:469
+msgid "the signature will be removed in the replacement commit!"
+msgstr "s'eliminarà la signatura en la comissió de reemplaçament!"
 
-#: builtin/pull.c:904
+#: builtin/replace.c:479
 #, c-format
-msgid ""
-"fetch updated the current branch head.\n"
-"fast-forwarding your working tree from\n"
-"commit %s."
+msgid "could not write replacement commit for: '%s'"
+msgstr "no s'ha pogut escriure la comissió de reemplaçament per a: «%s»"
+
+#: builtin/replace.c:487
+#, c-format
+msgid "graft for '%s' unnecessary"
 msgstr ""
-"l'obtenció ha actualitzat HEAD de la branca actual.\n"
-"s'està avançant ràpidament el vostre arbre de treball des de\n"
-"la comissió %s."
 
-#: builtin/pull.c:909
+#: builtin/replace.c:491
 #, c-format
+msgid "new commit is the same as the old one: '%s'"
+msgstr "la comissió nova és la mateixa que l'antiga: «%s»"
+
+#: builtin/replace.c:526
+#, fuzzy, c-format
 msgid ""
-"Cannot fast-forward your working tree.\n"
-"After making sure that you saved anything precious from\n"
-"$ git diff %s\n"
-"output, run\n"
-"$ git reset --hard\n"
-"to recover."
-msgstr ""
-"No es pot avançar ràpidament el vostre arbre de treball.\n"
-"Després d'assegurar que hàgiu desat qualsevol cosa preciosa de la sortida "
-"de\n"
-"$ git diff %s\n"
-"executeu\n"
-"$ git reset --hard\n"
-"per a recuperar."
+"could not convert the following graft(s):\n"
+"%s"
+msgstr "Eliminaria l'ítem següent:"
 
-#: builtin/pull.c:924
-msgid "Cannot merge multiple branches into empty head."
-msgstr "No es poden fusionar múltiples branques a un HEAD buit."
+#: builtin/replace.c:547
+msgid "list replace refs"
+msgstr "llista les referències reemplaçades"
 
-#: builtin/pull.c:928
-msgid "Cannot rebase onto multiple branches."
-msgstr "No es pot fer «rebase» sobre múltiples branques."
+#: builtin/replace.c:548
+msgid "delete replace refs"
+msgstr "suprimeix les referències reemplaçades"
 
-#: builtin/pull.c:935
-msgid "cannot rebase with locally recorded submodule modifications"
-msgstr ""
-"no es pot fer «rebase» amb modificacions als submòduls enregistrades "
-"localment"
+#: builtin/replace.c:549
+msgid "edit existing object"
+msgstr "edita un objecte existent"
 
-#: builtin/push.c:17
-msgid "git push [<options>] [<repository> [<refspec>...]]"
-msgstr "git push [<opcions>] [<dipòsit> [<especificació-de-referència>...]]"
+#: builtin/replace.c:550
+msgid "change a commit's parents"
+msgstr "canvia les mares d'una comissió"
 
-#: builtin/push.c:92
-msgid "tag shorthand without <tag>"
-msgstr "abreviatura d'etiqueta sense <tag>"
+#: builtin/replace.c:551
+#, fuzzy
+msgid "convert existing graft file"
+msgstr "força la sobreescriptura de fitxers existents"
 
-#: builtin/push.c:102
-msgid "--delete only accepts plain target ref names"
-msgstr "--delete només accepta noms de referència de destí senzills"
+#: builtin/replace.c:552
+msgid "replace the ref if it exists"
+msgstr "reemplaça la referència si existeix"
 
-#: builtin/push.c:146
-msgid ""
-"\n"
-"To choose either option permanently, see push.default in 'git help config'."
-msgstr ""
-"\n"
-"Per a triar qualsevol opció permanentment, vegeu push.default a 'git help "
-"config'."
+#: builtin/replace.c:554
+msgid "do not pretty-print contents for --edit"
+msgstr "no imprimeixis bellament els continguts per a --edit"
 
-#: builtin/push.c:149
-#, c-format
-msgid ""
-"The upstream branch of your current branch does not match\n"
-"the name of your current branch.  To push to the upstream branch\n"
-"on the remote, use\n"
-"\n"
-"    git push %s HEAD:%s\n"
-"\n"
-"To push to the branch of the same name on the remote, use\n"
-"\n"
-"    git push %s %s\n"
-"%s"
-msgstr ""
-"La branca font de la vostra branca actual no coincideix\n"
-"amb el nom de la vostra branca actual. Per a pujar-la a la\n"
-"branca font en el remot, useu\n"
-"\n"
-"    git push %s HEAD:%s\n"
-"\n"
-"Per a pujar a la branca del mateix nom en el remot, useu\n"
-"\n"
-"    git push %s %s\n"
-"%s"
+#: builtin/replace.c:555
+msgid "use this format"
+msgstr "usa aquest format"
 
-#: builtin/push.c:164
-#, c-format
-msgid ""
-"You are not currently on a branch.\n"
-"To push the history leading to the current (detached HEAD)\n"
-"state now, use\n"
-"\n"
-"    git push %s HEAD:<name-of-remote-branch>\n"
-msgstr ""
-"Actualment no sou en cap branca.\n"
-"Per a pujar la història que condueix a l'estat actual\n"
-"(HEAD separat) ara, useu\n"
-"\n"
-"    git push %s HEAD:<nom-de-branca-remota>\n"
+#: builtin/replace.c:568
+#, fuzzy
+msgid "--format cannot be used when not listing"
+msgstr "--fix-thin no es pot usar sense --stdin"
 
-#: builtin/push.c:178
-#, c-format
-msgid ""
-"The current branch %s has no upstream branch.\n"
-"To push the current branch and set the remote as upstream, use\n"
-"\n"
-"    git push --set-upstream %s %s\n"
-msgstr ""
-"La branca actual %s no té cap branca font.\n"
-"Per a pujar la branca actual i establir el remot com a font, useu\n"
-"\n"
-"    git push --set-upstream %s %s\n"
+#: builtin/replace.c:576
+#, fuzzy
+msgid "-f only makes sense when writing a replacement"
+msgstr "-z només té sentit amb --stdin"
 
-#: builtin/push.c:186
-#, c-format
-msgid "The current branch %s has multiple upstream branches, refusing to push."
-msgstr ""
-"La branca actual %s té múltiples branques fonts, s'està refusant pujar."
+#: builtin/replace.c:580
+msgid "--raw only makes sense with --edit"
+msgstr "--raw només té sentit amb --edit"
 
-#: builtin/push.c:189
-#, c-format
-msgid ""
-"You are pushing to remote '%s', which is not the upstream of\n"
-"your current branch '%s', without telling me what to push\n"
-"to update which remote branch."
+#: builtin/replace.c:586
+msgid "-d needs at least one argument"
 msgstr ""
-"Esteu pujant al remot «%s», que no és la font de la vostra\n"
-"branca actual «%s», sense dir-me què pujar per a actualitzar\n"
-"quina branca remota."
 
-#: builtin/push.c:248
-msgid ""
-"You didn't specify any refspecs to push, and push.default is \"nothing\"."
-msgstr ""
-"No heu especificat cap especificació de referència a pujar, i push.default "
-"és \"nothing\"."
+#: builtin/replace.c:592
+msgid "bad number of arguments"
+msgstr "nombre incorrecte d'arguments"
 
-#: builtin/push.c:255
-msgid ""
-"Updates were rejected because the tip of your current branch is behind\n"
-"its remote counterpart. Integrate the remote changes (e.g.\n"
-"'git pull ...') before pushing again.\n"
-"See the 'Note about fast-forwards' in 'git push --help' for details."
-msgstr ""
-"S'han rebutjat les actualitzacions perquè el punt de la vostra branca\n"
-"actual està darrere de la seva branca remota corresponent. Integreu\n"
-"els canvis remots (per exemple, 'git pull ...') abans de pujar de nou.\n"
-"Vegeu la 'Nota sobre avanços ràpids' a 'git push --help' per detalls."
+#: builtin/replace.c:598
+msgid "-e needs exactly one argument"
+msgstr "-e necessita exactament un argument"
 
-#: builtin/push.c:261
-msgid ""
-"Updates were rejected because a pushed branch tip is behind its remote\n"
-"counterpart. Check out this branch and integrate the remote changes\n"
-"(e.g. 'git pull ...') before pushing again.\n"
-"See the 'Note about fast-forwards' in 'git push --help' for details."
+#: builtin/replace.c:604
+msgid "-g needs at least one argument"
+msgstr "-g necessita almenys un argument"
+
+#: builtin/replace.c:610
+msgid "--convert-graft-file takes no argument"
+msgstr "--convert-graft-file arguments"
+
+#: builtin/replace.c:616
+msgid "only one pattern can be given with -l"
+msgstr "només es pot especificar un patró amb -l"
+
+#: builtin/rerere.c:13
+msgid "git rerere [clear | forget <path>... | status | remaining | diff | gc]"
+msgstr "git rerere [clear | forget <camí>... | status | remaining | diff | gc]"
+
+#: builtin/rerere.c:60
+msgid "register clean resolutions in index"
+msgstr "registra les resolucions netes en l'índex"
+
+#: builtin/rerere.c:79
+msgid "'git rerere forget' without paths is deprecated"
 msgstr ""
-"S'han rebutjat les actualitzacions perquè un punt de branca pujada\n"
-"està darrere de la seva branca remota corresponent. Agafeu aquesta\n"
-"branca i integreu els canvis remots (per exemple, 'git pull ...')\n"
-"abans de pujar de nou.\n"
-"Vegeu la 'Nota sobre avanços ràpids' a 'git push --help' per detalls."
 
-#: builtin/push.c:267
+#: builtin/rerere.c:113
+#, c-format
+msgid "unable to generate diff for '%s'"
+msgstr "s'ha pogut generar el diff per a «%s»"
+
+#: builtin/reset.c:32
 msgid ""
-"Updates were rejected because the remote contains work that you do\n"
-"not have locally. This is usually caused by another repository pushing\n"
-"to the same ref. You may want to first integrate the remote changes\n"
-"(e.g., 'git pull ...') before pushing again.\n"
-"See the 'Note about fast-forwards' in 'git push --help' for details."
+"git reset [--mixed | --soft | --hard | --merge | --keep] [-q] [<commit>]"
 msgstr ""
-"S'han rebutjat les actualitzacions perquè el remot conté canvis\n"
-"que no teniu localment. Això acostuma a ser causat per un altre dipòsit\n"
-"que ha pujat a la mateixa referència. Pot ser que primer vulgueu\n"
-"integrar els canvis remots (per exemple, 'git pull ...') abans de\n"
-"pujar de nou.\n"
-"Vegeu la 'Nota sobre avanços ràpids' a 'git push --help' per detalls."
+"git reset [--mixed | --soft | --hard | --merge | --keep] [-q] [<comissió>]"
 
-#: builtin/push.c:274
-msgid "Updates were rejected because the tag already exists in the remote."
-msgstr ""
-"S'han rebutjat les actualitzacions perquè l'etiqueta ja existeix en el remot."
+#: builtin/reset.c:33
+#, fuzzy
+msgid "git reset [-q] [<tree-ish>] [--] <pathspec>..."
+msgstr "git reset [-q] [<arbre>] [--] <camins>..."
 
-#: builtin/push.c:277
+#: builtin/reset.c:34
 msgid ""
-"You cannot update a remote ref that points at a non-commit object,\n"
-"or update a remote ref to make it point at a non-commit object,\n"
-"without using the '--force' option.\n"
+"git reset [-q] [--pathspec-from-file [--pathspec-file-nul]] [<tree-ish>]"
 msgstr ""
-"No podeu actualitzar una referència remota que assenyala un\n"
-"objecte no de comissió, ni actualitzar una referència remota per\n"
-"fer que assenyali un objecte no de comissió, sense usar l'opció\n"
-"'--force'.\n"
 
-#: builtin/push.c:337
-#, c-format
-msgid "Pushing to %s\n"
-msgstr "S'està pujant a %s\n"
+#: builtin/reset.c:35
+#, fuzzy
+msgid "git reset --patch [<tree-ish>] [--] [<pathspec>...]"
+msgstr "git reset --patch [<arbre>] [--] [<camins>...]"
 
-#: builtin/push.c:341
-#, c-format
-msgid "failed to push some refs to '%s'"
-msgstr "s'ha produït un error en pujar algunes referències a «%s»"
+#: builtin/reset.c:41
+msgid "mixed"
+msgstr "mixt"
 
-#: builtin/push.c:372
-#, c-format
-msgid "bad repository '%s'"
-msgstr "dipòsit incorrecte «%s»"
+#: builtin/reset.c:41
+msgid "soft"
+msgstr "suau"
 
-#: builtin/push.c:373
-msgid ""
-"No configured push destination.\n"
-"Either specify the URL from the command-line or configure a remote "
-"repository using\n"
-"\n"
-"    git remote add <name> <url>\n"
-"\n"
-"and then push using the remote name\n"
-"\n"
-"    git push <name>\n"
-msgstr ""
-"No hi ha cap destí de pujada configurat.\n"
-"Especifiqueu l'URL des de la línia d'ordres o bé configureu un dipòsit remot "
-"fent servir\n"
-"\n"
-"    git remote add <nom> <url>\n"
-"\n"
-"i després pugeu fent servir el nom remot\n"
-"\n"
-"    git push <nom>\n"
+#: builtin/reset.c:41
+msgid "hard"
+msgstr "dur"
 
-#: builtin/push.c:391
-msgid "--all and --tags are incompatible"
-msgstr "--all i --tags són incompatibles"
+#: builtin/reset.c:41
+msgid "merge"
+msgstr "fusió"
 
-#: builtin/push.c:392
-msgid "--all can't be combined with refspecs"
-msgstr "--all no es pot combinar amb especificacions de referència"
+#: builtin/reset.c:41
+msgid "keep"
+msgstr "reteniment"
 
-#: builtin/push.c:397
-msgid "--mirror and --tags are incompatible"
-msgstr "--mirror i --tags són incompatibles"
+#: builtin/reset.c:82
+msgid "You do not have a valid HEAD."
+msgstr "No teniu un HEAD vàlid."
 
-#: builtin/push.c:398
-msgid "--mirror can't be combined with refspecs"
-msgstr "--mirror no es pot combinar amb especificacions de referència"
+#: builtin/reset.c:84
+msgid "Failed to find tree of HEAD."
+msgstr "S'ha produït un error en trobar l'arbre de HEAD."
 
-#: builtin/push.c:403
-msgid "--all and --mirror are incompatible"
-msgstr "--all i --mirror són incompatibles"
+#: builtin/reset.c:90
+#, c-format
+msgid "Failed to find tree of %s."
+msgstr "S'ha produït un error en cercar l'arbre de %s."
 
-#: builtin/push.c:535
-msgid "repository"
-msgstr "dipòsit"
+#: builtin/reset.c:115
+#, c-format
+msgid "HEAD is now at %s"
+msgstr "HEAD ara és a %s"
 
-#: builtin/push.c:536 builtin/send-pack.c:163
-msgid "push all refs"
-msgstr "puja totes les referències"
+#: builtin/reset.c:194
+#, c-format
+msgid "Cannot do a %s reset in the middle of a merge."
+msgstr "No es pot fer un restabliment de %s enmig d'una fusió."
 
-#: builtin/push.c:537 builtin/send-pack.c:165
-msgid "mirror all refs"
-msgstr "reflecteix totes les referències"
+#: builtin/reset.c:294 builtin/stash.c:519 builtin/stash.c:594
+#: builtin/stash.c:618
+msgid "be quiet, only report errors"
+msgstr "sigues silenciós, només informa d'errors"
 
-#: builtin/push.c:539
-msgid "delete refs"
-msgstr "suprimeix les referències"
+#: builtin/reset.c:296
+msgid "reset HEAD and index"
+msgstr "restableix HEAD i l'índex"
 
-#: builtin/push.c:540
-msgid "push tags (can't be used with --all or --mirror)"
-msgstr "puja les etiquetes (no es pot usar amb --all o --mirror)"
+#: builtin/reset.c:297
+msgid "reset only HEAD"
+msgstr "restableix només HEAD"
 
-#: builtin/push.c:543 builtin/send-pack.c:166
-msgid "force updates"
-msgstr "força les actualitzacions"
+#: builtin/reset.c:299 builtin/reset.c:301
+msgid "reset HEAD, index and working tree"
+msgstr "restableix HEAD, l'índex i l'arbre de treball"
 
-#: builtin/push.c:545 builtin/send-pack.c:180
-msgid "refname>:<expect"
-msgstr "nom-de-referència>:<esperat"
+#: builtin/reset.c:303
+msgid "reset HEAD but keep local changes"
+msgstr "restableix HEAD però retén els canvis locals"
 
-#: builtin/push.c:546 builtin/send-pack.c:181
-msgid "require old value of ref to be at this value"
-msgstr "requereix que el valor antic de la referència sigui d'aquest valor"
+#: builtin/reset.c:309
+msgid "record only the fact that removed paths will be added later"
+msgstr "registra només el fet que els camins eliminats s'afegiran després"
 
-#: builtin/push.c:549
-msgid "control recursive pushing of submodules"
-msgstr "controla la pujada recursiva dels submòduls"
+#: builtin/reset.c:343
+#, c-format
+msgid "Failed to resolve '%s' as a valid revision."
+msgstr "S'ha produït un error en resoldre «%s» com a revisió vàlida."
 
-#: builtin/push.c:551 builtin/send-pack.c:174
-msgid "use thin pack"
-msgstr "usa el paquet prim"
+#: builtin/reset.c:351
+#, c-format
+msgid "Failed to resolve '%s' as a valid tree."
+msgstr "S'ha produït un error en resoldre «%s» com a arbre vàlid."
 
-#: builtin/push.c:552 builtin/push.c:553 builtin/send-pack.c:160
-#: builtin/send-pack.c:161
-msgid "receive pack program"
-msgstr "programa que rep els paquets"
+#: builtin/reset.c:360
+msgid "--patch is incompatible with --{hard,mixed,soft}"
+msgstr "--patch és incompatible amb --{hard,mixed,soft}"
 
-#: builtin/push.c:554
-msgid "set upstream for git pull/status"
-msgstr "estableix la font per a git pull/status"
+#: builtin/reset.c:370
+msgid "--mixed with paths is deprecated; use 'git reset -- <paths>' instead."
+msgstr ""
+"--mixed amb camins està en desús; useu 'git reset -- <camins>' en lloc "
+"d'això."
 
-#: builtin/push.c:557
-msgid "prune locally removed refs"
-msgstr "poda les referències eliminades localment"
+#: builtin/reset.c:372
+#, c-format
+msgid "Cannot do %s reset with paths."
+msgstr "No es pot restablir de %s amb camins."
 
-#: builtin/push.c:559
-msgid "bypass pre-push hook"
-msgstr "evita el lligam de prepujada"
+#: builtin/reset.c:387
+#, c-format
+msgid "%s reset is not allowed in a bare repository"
+msgstr "el restabliment de %s no es permet en un dipòsit nu"
 
-#: builtin/push.c:560
-msgid "push missing but relevant tags"
-msgstr "puja les etiquetes absents però rellevants"
+#: builtin/reset.c:391
+msgid "-N can only be used with --mixed"
+msgstr "-N només es pot usar amb --mixed"
 
-#: builtin/push.c:563 builtin/send-pack.c:168
-msgid "GPG sign the push"
-msgstr "signa la pujada amb GPG"
+#: builtin/reset.c:412
+msgid "Unstaged changes after reset:"
+msgstr "Canvis «unstaged» després del restabliment:"
 
-#: builtin/push.c:565 builtin/send-pack.c:175
-msgid "request atomic transaction on remote side"
-msgstr "demana una transacció atòmica al costat remot"
+#: builtin/reset.c:415
+#, c-format
+msgid ""
+"\n"
+"It took %.2f seconds to enumerate unstaged changes after reset.  You can\n"
+"use '--quiet' to avoid this.  Set the config setting reset.quiet to true\n"
+"to make this the default.\n"
+msgstr ""
 
-#: builtin/push.c:566 builtin/send-pack.c:171
-msgid "server-specific"
-msgstr "específic al servidor"
+#: builtin/reset.c:425
+#, c-format
+msgid "Could not reset index file to revision '%s'."
+msgstr "No s'ha pogut restablir el fitxer d'índex a la revisió «%s»."
 
-#: builtin/push.c:566 builtin/send-pack.c:172
-msgid "option to transmit"
-msgstr "opció a transmetre"
+#: builtin/reset.c:429
+msgid "Could not write new index file."
+msgstr "No s'ha pogut escriure el fitxer d'índex nou."
 
-#: builtin/push.c:583
-msgid "--delete is incompatible with --all, --mirror and --tags"
-msgstr "--delete és incompatible amb --all, --mirror i --tags"
+#: builtin/rev-list.c:411
+msgid "cannot combine --exclude-promisor-objects and --missing"
+msgstr "no es pot combinar --exclude-promisor-objects i --missing"
 
-#: builtin/push.c:585
-msgid "--delete doesn't make sense without any refs"
-msgstr "--delete no té sentit sense referències"
+#: builtin/rev-list.c:472
+msgid "object filtering requires --objects"
+msgstr "el filtratge d'objectes requereix --objects"
 
-#: builtin/push.c:604
-msgid "push options must not have new line characters"
-msgstr "les opcions de pujada no han de tenir caràcters de línia nova"
+#: builtin/rev-list.c:522
+msgid "rev-list does not support display of notes"
+msgstr "el rev-list no permet mostrar notes"
 
-#: builtin/read-tree.c:40
-msgid ""
-"git read-tree [(-m [--trivial] [--aggressive] | --reset | --prefix=<prefix>) "
-"[-u [--exclude-per-directory=<gitignore>] | -i]] [--no-sparse-checkout] [--"
-"index-output=<file>] (--empty | <tree-ish1> [<tree-ish2> [<tree-ish3>]])"
-msgstr ""
-"git read-tree [(-m [--trivial] [--aggressive] | --reset | --prefix=<prefix>) "
-"[-u [--exclude-per-directory=<gitignore>] | -i]] [--no-sparse-checkout] [--"
-"index-output=<fitxer>] (--empty | <arbre1> [<arbre2> [<arbre3>]])"
+#: builtin/rev-list.c:525
+msgid "cannot combine --use-bitmap-index with object filtering"
+msgstr "no es pot combinar --use-bitmap-index amb el filtratge d'objectes"
 
-#: builtin/read-tree.c:121
-msgid "write resulting index to <file>"
-msgstr "escriu l'índex resultant al <fitxer>"
+#: builtin/rev-parse.c:408
+msgid "git rev-parse --parseopt [<options>] -- [<args>...]"
+msgstr "git rev-parse --parseopt [<opcions>] -- [<paràmetres>...]"
 
-#: builtin/read-tree.c:124
-msgid "only empty the index"
-msgstr "només buida l'índex"
+#: builtin/rev-parse.c:413
+msgid "keep the `--` passed as an arg"
+msgstr "retén el «--» passat com a paràmetre"
 
-#: builtin/read-tree.c:126
-msgid "Merging"
-msgstr "S'està fusionant"
+#: builtin/rev-parse.c:415
+msgid "stop parsing after the first non-option argument"
+msgstr "deixa d'analitzar després del primer paràmetre no d'opció"
 
-#: builtin/read-tree.c:128
-msgid "perform a merge in addition to a read"
-msgstr "realitza una fusió a més d'una lectura"
+#: builtin/rev-parse.c:418
+msgid "output in stuck long form"
+msgstr "emet en forma llarga enganxada"
 
-#: builtin/read-tree.c:130
-msgid "3-way merge if no file level merging required"
-msgstr "fusió de 3 vies si no cal fusió a nivell de fitxers"
+#: builtin/rev-parse.c:551
+msgid ""
+"git rev-parse --parseopt [<options>] -- [<args>...]\n"
+"   or: git rev-parse --sq-quote [<arg>...]\n"
+"   or: git rev-parse [<options>] [<arg>...]\n"
+"\n"
+"Run \"git rev-parse --parseopt -h\" for more information on the first usage."
+msgstr ""
+"git rev-parse --parseopt [<opcions>] -- [<paràmetres>...]\n"
+"   or: git rev-parse --sq-quote [<paràmetre>...]\n"
+"   or: git rev-parse [<opcions>] [<paràmetre>...]\n"
+"\n"
+"Executeu \"git rev-parse --parseopt -h\" per més informació sobre l'ús "
+"inicial."
 
-#: builtin/read-tree.c:132
-msgid "3-way merge in presence of adds and removes"
-msgstr "fusió de 3 vies en presència d'afegiments i eliminacions"
+#: builtin/revert.c:24
+msgid "git revert [<options>] <commit-ish>..."
+msgstr "git revert [<opcions>] <comissió>..."
 
-#: builtin/read-tree.c:134
-msgid "same as -m, but discard unmerged entries"
-msgstr "el mateix que -m, però descarta les entrades no fusionades"
+#: builtin/revert.c:25
+msgid "git revert <subcommand>"
+msgstr "git revert <subordre>"
 
-#: builtin/read-tree.c:135
-msgid "<subdirectory>/"
-msgstr "<subdirectori>/"
+#: builtin/revert.c:30
+msgid "git cherry-pick [<options>] <commit-ish>..."
+msgstr "git cherry-pick [<opcions>] <comissió>..."
 
-#: builtin/read-tree.c:136
-msgid "read the tree into the index under <subdirectory>/"
-msgstr "llegiu l'arbre a l'índex sota <subdirectori>/"
+#: builtin/revert.c:31
+msgid "git cherry-pick <subcommand>"
+msgstr "git cherry-pick <subordre>"
 
-#: builtin/read-tree.c:139
-msgid "update working tree with merge result"
-msgstr "actualitza l'arbre de treball amb el resultat de fusió"
+#: builtin/revert.c:72
+#, c-format
+msgid "option `%s' expects a number greater than zero"
+msgstr "l'opció «%s» espera un nombre major que zero"
 
-#: builtin/read-tree.c:141
-msgid "gitignore"
-msgstr "gitignore"
+#: builtin/revert.c:92
+#, c-format
+msgid "%s: %s cannot be used with %s"
+msgstr "%s: %s no es pot usar amb %s"
 
-#: builtin/read-tree.c:142
-msgid "allow explicitly ignored files to be overwritten"
-msgstr "permet que els fitxers explícitament ignorats se sobreescriguin"
+#: builtin/revert.c:102
+msgid "end revert or cherry-pick sequence"
+msgstr "acaba la seqüència de reversió o el «cherry pick»"
 
-#: builtin/read-tree.c:145
-msgid "don't check the working tree after merging"
-msgstr "no comprovis l'arbre de treball després de fusionar"
+#: builtin/revert.c:103
+msgid "resume revert or cherry-pick sequence"
+msgstr "reprèn la seqüència de reversió o el «cherry pick»"
 
-#: builtin/read-tree.c:146
-msgid "don't update the index or the work tree"
-msgstr "no actualitzis l'índex ni l'arbre de treball"
+#: builtin/revert.c:104
+msgid "cancel revert or cherry-pick sequence"
+msgstr "cancel·la la seqüència de reversió o el «cherry pick»"
 
-#: builtin/read-tree.c:148
-msgid "skip applying sparse checkout filter"
-msgstr "omet l'aplicació del filtre d'agafament parcial"
+#: builtin/revert.c:105
+msgid "skip current commit and continue"
+msgstr "omet la comissió actual i continua"
 
-#: builtin/read-tree.c:150
-msgid "debug unpack-trees"
-msgstr "depura unpack-trees"
+#: builtin/revert.c:107
+msgid "don't automatically commit"
+msgstr "no cometis automàticament"
 
-#: builtin/rebase--helper.c:8
-msgid "git rebase--helper [<options>]"
-msgstr "git rebase--helper [<opcions>]"
+#: builtin/revert.c:108
+msgid "edit the commit message"
+msgstr "edita el missatge de comissió"
 
-#: builtin/rebase--helper.c:24
-msgid "keep empty commits"
-msgstr "mantén les comissions buides"
+#: builtin/revert.c:111
+msgid "parent-number"
+msgstr "número del pare"
 
-#: builtin/rebase--helper.c:26 builtin/revert.c:123
-msgid "allow commits with empty messages"
-msgstr "permet les comissions amb missatges buits"
+#: builtin/revert.c:112
+msgid "select mainline parent"
+msgstr "selecciona la línia principal del pare"
 
-#: builtin/rebase--helper.c:27
-msgid "continue rebase"
-msgstr "continua el «rebase»"
+#: builtin/revert.c:114
+msgid "merge strategy"
+msgstr "estratègia de fusió"
 
-#: builtin/rebase--helper.c:29
-msgid "abort rebase"
-msgstr "avorta el «rebase»"
-
-#: builtin/rebase--helper.c:32
-msgid "make rebase script"
-msgstr "fes un script de «rebase»"
+#: builtin/revert.c:116
+msgid "option for merge strategy"
+msgstr "opció d'estratègia de fusió"
 
-#: builtin/rebase--helper.c:34
-msgid "shorten commit ids in the todo list"
-msgstr "escurça els ids de les comissions en la llista per a fer"
+#: builtin/revert.c:125
+msgid "append commit name"
+msgstr "nom de la comissió a annexar"
 
-#: builtin/rebase--helper.c:36
-msgid "expand commit ids in the todo list"
-msgstr "expandeix els ids de els comissions en la llista per a fer"
+#: builtin/revert.c:127
+msgid "preserve initially empty commits"
+msgstr "preserva les comissions inicialment buides"
 
-#: builtin/rebase--helper.c:38
-msgid "check the todo list"
-msgstr "comprova la llista a fer"
+#: builtin/revert.c:129
+msgid "keep redundant, empty commits"
+msgstr "retén les comissions redundants i buides"
 
-#: builtin/rebase--helper.c:40
-msgid "skip unnecessary picks"
-msgstr "omet els «picks» no necessaris"
+#: builtin/revert.c:232
+msgid "revert failed"
+msgstr "la reversió ha fallat"
 
-#: builtin/rebase--helper.c:42
-msgid "rearrange fixup/squash lines"
-msgstr "reorganitza les línies «fixup/pick»"
+#: builtin/revert.c:245
+msgid "cherry-pick failed"
+msgstr "el «cherry pick» ha fallat"
 
-#: builtin/rebase--helper.c:44
-msgid "insert exec commands in todo list"
-msgstr "expandeix les ordres exec en la llista per a fer"
+#: builtin/rm.c:19
+msgid "git rm [<options>] [--] <file>..."
+msgstr "git rm [<opcions>] [--] <fitxer>..."
 
-#: builtin/receive-pack.c:30
-msgid "git receive-pack <git-dir>"
-msgstr "git receive-pack <git-dir>"
+#: builtin/rm.c:207
+msgid ""
+"the following file has staged content different from both the\n"
+"file and the HEAD:"
+msgid_plural ""
+"the following files have staged content different from both the\n"
+"file and the HEAD:"
+msgstr[0] ""
+"el fitxer següent té contingut «stage» diferent d'ambdós el\n"
+"fitxer i la HEAD:"
+msgstr[1] ""
+"els fitxers següents tenen contingut «stage» diferent d'ambdós\n"
+"el fitxer i la HEAD:"
 
-#: builtin/receive-pack.c:841
+#: builtin/rm.c:212
 msgid ""
-"By default, updating the current branch in a non-bare repository\n"
-"is denied, because it will make the index and work tree inconsistent\n"
-"with what you pushed, and will require 'git reset --hard' to match\n"
-"the work tree to HEAD.\n"
-"\n"
-"You can set the 'receive.denyCurrentBranch' configuration variable\n"
-"to 'ignore' or 'warn' in the remote repository to allow pushing into\n"
-"its current branch; however, this is not recommended unless you\n"
-"arranged to update its work tree to match what you pushed in some\n"
-"other way.\n"
 "\n"
-"To squelch this message and still keep the default behaviour, set\n"
-"'receive.denyCurrentBranch' configuration variable to 'refuse'."
+"(use -f to force removal)"
 msgstr ""
-"Per defecte, es denega actualitzar la branca actual en un dipòsit no\n"
-"nu, perquè faria l'índex i l'arbre de treball inconsistents amb el\n"
-"que hàgiu pujat, i requeriria 'git reset --hard' per a fer que\n"
-"l'arbre de treball coincideixi amb HEAD.\n"
-"\n"
-"Podeu establir la variable de configuració\n"
-"'receive.denyCurrentBranch' a 'ignore' o 'warn' en el dipòsit remot\n"
-"per a permetre pujar a la seva branca actual; no obstant, no es\n"
-"recomana això a menys que hàgiu decidit actualitzar el seu arbre en\n"
-"alguna altra manera per a coincidir amb el que hàgiu pujat.\n"
 "\n"
-"Per a silenciar aquest missatge i mantenir el comportament\n"
-"predeterminat, establiu la variable de configuració\n"
-"'receive.denyCurrentBranch' a 'refuse'."
+"(useu -f per a forçar l'eliminació)"
+
+#: builtin/rm.c:216
+msgid "the following file has changes staged in the index:"
+msgid_plural "the following files have changes staged in the index:"
+msgstr[0] "el fitxer següent té canvis «staged» en l'índex:"
+msgstr[1] "els fitxers següents tenen canvis «staged» en l'índex:"
 
-#: builtin/receive-pack.c:861
+#: builtin/rm.c:220 builtin/rm.c:229
 msgid ""
-"By default, deleting the current branch is denied, because the next\n"
-"'git clone' won't result in any file checked out, causing confusion.\n"
-"\n"
-"You can set 'receive.denyDeleteCurrent' configuration variable to\n"
-"'warn' or 'ignore' in the remote repository to allow deleting the\n"
-"current branch, with or without a warning message.\n"
 "\n"
-"To squelch this message, you can set it to 'refuse'."
+"(use --cached to keep the file, or -f to force removal)"
 msgstr ""
-"Per defecte, es denega suprimir la branca actual, perquè el\n"
-"'git clone' següent no resultarà en cap fitxer agafat, causant\n"
-"confusió.\n"
-"\n"
-"Podeu establir la variable de configuració\n"
-"'receive.denyDeleteCurrent' a 'warn' o 'ignore' en el dipòsit remot\n"
-"per a permetre suprimir la branca actual, amb un missatge\n"
-"d'advertència o sense.\n"
 "\n"
-"Per a silenciar aquest missatge, podeu establir-la a 'refuse'."
-
-#: builtin/receive-pack.c:1934
-msgid "quiet"
-msgstr "silenciós"
+"(useu --cached per a mantenir el fitxer, o -f per a forçar l'eliminació)"
 
-#: builtin/receive-pack.c:1948
-msgid "You must specify a directory."
-msgstr "Heu d'especificar un directori."
+#: builtin/rm.c:226
+msgid "the following file has local modifications:"
+msgid_plural "the following files have local modifications:"
+msgstr[0] "el fitxer següent té modificacions locals:"
+msgstr[1] "els fitxers següents tenen modificacions locals:"
 
-#: builtin/reflog.c:532 builtin/reflog.c:537
-#, c-format
-msgid "'%s' is not a valid timestamp"
-msgstr "«%s» no és una marca de temps vàlida"
+#: builtin/rm.c:242
+msgid "do not list removed files"
+msgstr "no llistis els fitxers eliminats"
 
-#: builtin/remote.c:13
-msgid "git remote [-v | --verbose]"
-msgstr "git remote [-v | --verbose]"
+#: builtin/rm.c:243
+msgid "only remove from the index"
+msgstr "només elimina de l'índex"
 
-#: builtin/remote.c:14
-msgid ""
-"git remote add [-t <branch>] [-m <master>] [-f] [--tags | --no-tags] [--"
-"mirror=<fetch|push>] <name> <url>"
-msgstr ""
-"git remote add [-t <branca>] [-m <mestra>] [-f] [--tags | --no-tags] [--"
-"mirror=<fetch|push>] <nom> <url>"
+#: builtin/rm.c:244
+msgid "override the up-to-date check"
+msgstr "passa per alt la comprovació d'actualitat"
 
-#: builtin/remote.c:15 builtin/remote.c:35
-msgid "git remote rename <old> <new>"
-msgstr "git remote rename <antic> <nou>"
+#: builtin/rm.c:245
+msgid "allow recursive removal"
+msgstr "permet l'eliminació recursiva"
 
-#: builtin/remote.c:16 builtin/remote.c:40
-msgid "git remote remove <name>"
-msgstr "git remote remove <nom>"
+#: builtin/rm.c:247
+msgid "exit with a zero status even if nothing matched"
+msgstr "surt amb estat zero encara que res hagi coincidit"
 
-#: builtin/remote.c:17 builtin/remote.c:45
-msgid "git remote set-head <name> (-a | --auto | -d | --delete | <branch>)"
-msgstr "git remote set-head <nom> (-a | --auto | -d | --delete | <branca>)"
+#: builtin/rm.c:289
+#, fuzzy
+msgid "please stage your changes to .gitmodules or stash them to proceed"
+msgstr ""
+"Feu «stage» dels vostres canvis a .gitmodules o feu «stash» dels mateixos "
+"per a procedir"
 
-#: builtin/remote.c:18
-msgid "git remote [-v | --verbose] show [-n] <name>"
-msgstr "git remote [-v | --verbose] show [-n] <nom>"
+#: builtin/rm.c:307
+#, c-format
+msgid "not removing '%s' recursively without -r"
+msgstr "no s'està eliminant «%s» recursivament sense -r"
 
-#: builtin/remote.c:19
-msgid "git remote prune [-n | --dry-run] <name>"
-msgstr "git remote prune [-n | --dry-run] <nom>"
+#: builtin/rm.c:346
+#, c-format
+msgid "git rm: unable to remove %s"
+msgstr "git rm: no s'ha pogut eliminar %s"
 
-#: builtin/remote.c:20
+#: builtin/send-pack.c:20
 msgid ""
-"git remote [-v | --verbose] update [-p | --prune] [(<group> | <remote>)...]"
+"git send-pack [--all | --mirror] [--dry-run] [--force] [--receive-pack=<git-"
+"receive-pack>] [--verbose] [--thin] [--atomic] [<host>:]<directory> "
+"[<ref>...]\n"
+"  --all and explicit <ref> specification are mutually exclusive."
 msgstr ""
-"git remote [-v | --verbose] update [-p | --prune] [(<grup> | <remot>)...]"
+"git send-pack [--all | --mirror] [--dry-run] [--force] [--receive-"
+"pack=<paquet-del-git-receive>] [--verbose] [--thin] [--atomic] "
+"[<màquina>:]<directori> [<referència>...]\n"
+"  --all i especificació <referència> explícita són mútuament excloents."
 
-#: builtin/remote.c:21
-msgid "git remote set-branches [--add] <name> <branch>..."
-msgstr "git remote set-branches [--add] <nom> <branca>..."
+#: builtin/send-pack.c:163
+msgid "remote name"
+msgstr "nom del remot"
 
-#: builtin/remote.c:22 builtin/remote.c:71
-msgid "git remote get-url [--push] [--all] <name>"
-msgstr "git remote get-url [--push] [--all] <nom>"
+#: builtin/send-pack.c:177
+msgid "use stateless RPC protocol"
+msgstr "usa el protocol RPC sense estat"
 
-#: builtin/remote.c:23 builtin/remote.c:76
-msgid "git remote set-url [--push] <name> <newurl> [<oldurl>]"
-msgstr "git remote set-url [--push] <nom> <url-nou> [<url-antic>]"
+#: builtin/send-pack.c:178
+msgid "read refs from stdin"
+msgstr "llegeix les referències des de stdin"
 
-#: builtin/remote.c:24 builtin/remote.c:77
-msgid "git remote set-url --add <name> <newurl>"
-msgstr "git remote set-url --add <nom> <url-nou>"
+#: builtin/send-pack.c:179
+msgid "print status from remote helper"
+msgstr "imprimeix l'estat des de l'ajudant remot"
 
-#: builtin/remote.c:25 builtin/remote.c:78
-msgid "git remote set-url --delete <name> <url>"
-msgstr "git remote set-url --delete <nom> <url>"
+#: builtin/shortlog.c:14
+#, fuzzy
+msgid "git shortlog [<options>] [<revision-range>] [[--] <path>...]"
+msgstr "git shortlog [<opcions>] [<rang-de-revisions>] [[--] [<camí>...]]"
 
-#: builtin/remote.c:30
-msgid "git remote add [<options>] <name> <url>"
-msgstr "git remote add [<opcions>] <nom> <url>"
+#: builtin/shortlog.c:15
+#, fuzzy
+msgid "git log --pretty=short | git shortlog [<options>]"
+msgstr "git worktree list [<opcions>]"
 
-#: builtin/remote.c:50
-msgid "git remote set-branches <name> <branch>..."
-msgstr "git remote set-branches <nom> <branca>..."
+#: builtin/shortlog.c:264
+msgid "Group by committer rather than author"
+msgstr "Agrupa per «comitter» en comptes de per autor"
 
-#: builtin/remote.c:51
-msgid "git remote set-branches --add <name> <branch>..."
-msgstr "git remote set-branches --add <nom> <branca>..."
+#: builtin/shortlog.c:266
+msgid "sort output according to the number of commits per author"
+msgstr "ordena la sortida segons el nombre de comissions per autor"
 
-#: builtin/remote.c:56
-msgid "git remote show [<options>] <name>"
-msgstr "git remote show [<opcions>] <nom>"
+#: builtin/shortlog.c:268
+msgid "Suppress commit descriptions, only provides commit count"
+msgstr ""
+"Omet les descripcions de comissió, només proveeix el recompte de comissions"
 
-#: builtin/remote.c:61
-msgid "git remote prune [<options>] <name>"
-msgstr "git remote prune [<opcions>] <nom>"
+#: builtin/shortlog.c:270
+msgid "Show the email address of each author"
+msgstr "Mostra l'adreça electrònica de cada autor"
 
-#: builtin/remote.c:66
-msgid "git remote update [<options>] [<group> | <remote>]..."
-msgstr "git remote update [<opcions>] [<grup> | <remot>]..."
+#: builtin/shortlog.c:271
+msgid "<w>[,<i1>[,<i2>]]"
+msgstr ""
 
-#: builtin/remote.c:95
-#, c-format
-msgid "Updating %s"
-msgstr "S'està actualitzant %s"
+#: builtin/shortlog.c:272
+msgid "Linewrap output"
+msgstr "Ajusta les línies de la sortida"
+
+#: builtin/shortlog.c:301
+#, fuzzy
+msgid "too many arguments given outside repository"
+msgstr "hi ha massa arguments per a desassignar la font"
 
-#: builtin/remote.c:127
+#: builtin/show-branch.c:13
 msgid ""
-"--mirror is dangerous and deprecated; please\n"
-"\t use --mirror=fetch or --mirror=push instead"
+"git show-branch [-a | --all] [-r | --remotes] [--topo-order | --date-order]\n"
+"\t\t[--current] [--color[=<when>] | --no-color] [--sparse]\n"
+"\t\t[--more=<n> | --list | --independent | --merge-base]\n"
+"\t\t[--no-name | --sha1-name] [--topics] [(<rev> | <glob>)...]"
 msgstr ""
-"--mirror és perillós i està en desús; \n"
-"\t useu --mirror=fetch o\n"
-"\t --mirror=push en lloc d'això"
+"git show-branch [-a | --all] [-r | --remotes] [--topo-order | --date-order]\n"
+"\t\t[--current] [--color[=<quan>] | --no-color] [--sparse]\n"
+"\t\t[--more=<n> | --list | --independent | --merge-base]\n"
+"\t\t[--no-name | --sha1-name] [--topics] [(<revisió> | <glob>)...]"
+
+#: builtin/show-branch.c:17
+msgid "git show-branch (-g | --reflog)[=<n>[,<base>]] [--list] [<ref>]"
+msgstr "git show-branch (-g | --reflog)[=<n>[,<base>]] [--list] [<referència>]"
 
-#: builtin/remote.c:144
+#: builtin/show-branch.c:395
 #, c-format
-msgid "unknown mirror argument: %s"
-msgstr "paràmetre de reflexió desconegut: %s"
+msgid "ignoring %s; cannot handle more than %d ref"
+msgid_plural "ignoring %s; cannot handle more than %d refs"
+msgstr[0] "s'està ignorant %s; no es pot gestionar més de %d referència"
+msgstr[1] "s'està ignorant %s; no es poden gestionar més de %d referències"
 
-#: builtin/remote.c:160
-msgid "fetch the remote branches"
-msgstr "obtén les branques remotes"
+#: builtin/show-branch.c:548
+#, c-format
+msgid "no matching refs with %s"
+msgstr "no hi ha referències coincidents amb %s"
 
-#: builtin/remote.c:162
-msgid "import all tags and associated objects when fetching"
-msgstr "en obtenir, importa totes les etiquetes i tots els objectes"
+#: builtin/show-branch.c:645
+msgid "show remote-tracking and local branches"
+msgstr "mostra les branques amb seguiment remot i les locals"
 
-#: builtin/remote.c:165
-msgid "or do not fetch any tag at all (--no-tags)"
-msgstr "o no obtinguis cap etiqueta (--no-tags)"
+#: builtin/show-branch.c:647
+msgid "show remote-tracking branches"
+msgstr "mostra les branques amb seguiment remot"
 
-#: builtin/remote.c:167
-msgid "branch(es) to track"
-msgstr "branques a seguir"
+#: builtin/show-branch.c:649
+msgid "color '*!+-' corresponding to the branch"
+msgstr "colora '*!+-' corresponent a la branca"
 
-#: builtin/remote.c:168
-msgid "master branch"
-msgstr "branca mestra"
+#: builtin/show-branch.c:651
+msgid "show <n> more commits after the common ancestor"
+msgstr "mostra <n> comissions després de l'avantpassat comú"
 
-#: builtin/remote.c:169
-msgid "push|fetch"
-msgstr "push|fetch"
+#: builtin/show-branch.c:653
+msgid "synonym to more=-1"
+msgstr "sinònim de more=-1"
 
-#: builtin/remote.c:170
-msgid "set up remote as a mirror to push to or fetch from"
-msgstr "estableix el remot com a mirall al qual pujar o del qual obtenir"
+#: builtin/show-branch.c:654
+msgid "suppress naming strings"
+msgstr "omet anomenar cadenes"
 
-#: builtin/remote.c:182
-msgid "specifying a master branch makes no sense with --mirror"
-msgstr "especificar una branca mestra no té sentit amb --mirror"
+#: builtin/show-branch.c:656
+msgid "include the current branch"
+msgstr "inclou la branca actual"
 
-#: builtin/remote.c:184
-msgid "specifying branches to track makes sense only with fetch mirrors"
-msgstr ""
-"especificar les branques a seguir té sentit només amb miralls d'obtenció"
+#: builtin/show-branch.c:658
+msgid "name commits with their object names"
+msgstr "anomena les comissions amb els seus noms d'objecte"
 
-#: builtin/remote.c:191 builtin/remote.c:631
-#, c-format
-msgid "remote %s already exists."
-msgstr "el remot %s ja existeix."
+#: builtin/show-branch.c:660
+msgid "show possible merge bases"
+msgstr "mostra les bases de fusió possibles"
+
+#: builtin/show-branch.c:662
+msgid "show refs unreachable from any other ref"
+msgstr "mostra les referències inabastables de qualsevol altra referència"
+
+#: builtin/show-branch.c:664
+msgid "show commits in topological order"
+msgstr "mostra les comissions en ordre topològic"
+
+#: builtin/show-branch.c:667
+msgid "show only commits not on the first branch"
+msgstr "mostra només les comissions que no siguin en la primera branca"
+
+#: builtin/show-branch.c:669
+msgid "show merges reachable from only one tip"
+msgstr "mostra les fusions abastables de només una punta"
+
+#: builtin/show-branch.c:671
+msgid "topologically sort, maintaining date order where possible"
+msgstr "ordena topològicament, mantenint l'ordre de dates on sigui possible"
 
-#: builtin/remote.c:195 builtin/remote.c:635
-#, c-format
-msgid "'%s' is not a valid remote name"
-msgstr "«%s» no és un nom de remot vàlid"
+#: builtin/show-branch.c:674
+msgid "<n>[,<base>]"
+msgstr "<n>[,<base>]"
 
-#: builtin/remote.c:235
-#, c-format
-msgid "Could not setup master '%s'"
-msgstr "No s'ha pogut configurar la mestra «%s»"
+#: builtin/show-branch.c:675
+msgid "show <n> most recent ref-log entries starting at base"
+msgstr "mostra les <n> entrades més recents començant a la base"
 
-#: builtin/remote.c:337
-#, c-format
-msgid "Could not get fetch map for refspec %s"
+#: builtin/show-branch.c:711
+msgid ""
+"--reflog is incompatible with --all, --remotes, --independent or --merge-base"
 msgstr ""
-"No s'ha pogut obtenir el mapa d'obtenció de l'especificació de referència %s"
+"--reflog és incompatible amb --all, --remotes, --independent o --merge-base"
 
-#: builtin/remote.c:438 builtin/remote.c:446
-msgid "(matching)"
-msgstr "(coincident)"
+#: builtin/show-branch.c:735
+msgid "no branches given, and HEAD is not valid"
+msgstr "no s'ha donat cap branca, i HEAD no és vàlid"
 
-#: builtin/remote.c:450
-msgid "(delete)"
-msgstr "(suprimir)"
+#: builtin/show-branch.c:738
+msgid "--reflog option needs one branch name"
+msgstr "l'opció --reflog necessita un nom de branca"
 
-#: builtin/remote.c:624 builtin/remote.c:759 builtin/remote.c:858
+#: builtin/show-branch.c:741
 #, c-format
-msgid "No such remote: %s"
-msgstr "No hi ha tal remot: %s"
+msgid "only %d entry can be shown at one time."
+msgid_plural "only %d entries can be shown at one time."
+msgstr[0] "es pot mostrar només %d entrada a la vegada."
+msgstr[1] "es poden mostrar només %d entrades a la vegada."
 
-#: builtin/remote.c:641
+#: builtin/show-branch.c:745
 #, c-format
-msgid "Could not rename config section '%s' to '%s'"
-msgstr "No s'ha pogut canviar el nom de la secció de configuració «%s» a «%s»"
+msgid "no such ref %s"
+msgstr "no hi ha tal referència %s"
 
-#: builtin/remote.c:661
+#: builtin/show-branch.c:831
 #, c-format
-msgid ""
-"Not updating non-default fetch refspec\n"
-"\t%s\n"
-"\tPlease update the configuration manually if necessary."
-msgstr ""
-"No s'està actualitzant l'especificació de referències d'obtenció no per "
-"defecte\n"
-"\t%s\n"
-"\tActualitzeu la configuració manualment si és necessari."
+msgid "cannot handle more than %d rev."
+msgid_plural "cannot handle more than %d revs."
+msgstr[0] "no es pot gestionar més d'%d revisió."
+msgstr[1] "no es poden gestionar més de %d revisions."
 
-#: builtin/remote.c:697
+#: builtin/show-branch.c:835
 #, c-format
-msgid "deleting '%s' failed"
-msgstr "la supressió de «%s» ha fallat"
+msgid "'%s' is not a valid ref."
+msgstr "«%s» no és una referència vàlida."
 
-#: builtin/remote.c:731
+#: builtin/show-branch.c:838
 #, c-format
-msgid "creating '%s' failed"
-msgstr "la creació de «%s» ha fallat"
+msgid "cannot find commit %s (%s)"
+msgstr "no es pot trobar la comissió %s (%s)"
 
-#: builtin/remote.c:796
+#: builtin/show-ref.c:12
 msgid ""
-"Note: A branch outside the refs/remotes/ hierarchy was not removed;\n"
-"to delete it, use:"
-msgid_plural ""
-"Note: Some branches outside the refs/remotes/ hierarchy were not removed;\n"
-"to delete them, use:"
-msgstr[0] ""
-"Nota: Una branca fora de la jerarquia refs/remotes/ no s'ha eliminat;\n"
-"per a suprimir-la, useu:"
-msgstr[1] ""
-"Nota: Algunes branques fora de la jerarquia refs/remotes/ no s'han "
-"eliminat;\n"
-"per a suprimir-les, useu:"
+"git show-ref [-q | --quiet] [--verify] [--head] [-d | --dereference] [-s | --"
+"hash[=<n>]] [--abbrev[=<n>]] [--tags] [--heads] [--] [<pattern>...]"
+msgstr ""
+"git show-ref [-q | --quiet] [--verify] [--head] [-d | --dereference] [-s | --"
+"hash[=<n>]] [--abbrev[=<n>]] [--tags] [--heads] [--] [<patró>...]"
 
-#: builtin/remote.c:810
-#, c-format
-msgid "Could not remove config section '%s'"
-msgstr "No s'ha pogut eliminar la secció de configuració «%s»"
+#: builtin/show-ref.c:13
+msgid "git show-ref --exclude-existing[=<pattern>]"
+msgstr "git show-ref --exclude-existing[=<patró>]"
 
-#: builtin/remote.c:911
-#, c-format
-msgid " new (next fetch will store in remotes/%s)"
-msgstr " nou (la pròxima obtenció emmagatzemarà a remotes/%s)"
+#: builtin/show-ref.c:162
+msgid "only show tags (can be combined with heads)"
+msgstr "mostra només les etiquetes (es pot combinar amb heads)"
 
-#: builtin/remote.c:914
-msgid " tracked"
-msgstr " seguit"
+#: builtin/show-ref.c:163
+msgid "only show heads (can be combined with tags)"
+msgstr "mostra només els caps (es pot combinar amb tags)"
 
-#: builtin/remote.c:916
-msgid " stale (use 'git remote prune' to remove)"
-msgstr " estancat (useu 'git remote prune' per a eliminar)"
+#: builtin/show-ref.c:164
+msgid "stricter reference checking, requires exact ref path"
+msgstr ""
+"comprovació de referència més estricta, requereix el camí de referència "
+"exacte"
 
-#: builtin/remote.c:918
-msgid " ???"
-msgstr " ???"
+#: builtin/show-ref.c:167 builtin/show-ref.c:169
+msgid "show the HEAD reference, even if it would be filtered out"
+msgstr "mostra la referència HEAD, encara que es filtrés"
 
-#: builtin/remote.c:959
-#, c-format
-msgid "invalid branch.%s.merge; cannot rebase onto > 1 branch"
-msgstr "branch.%s.merge no vàlid; no es pot fer «rebase» sobre > 1 branca"
+#: builtin/show-ref.c:171
+msgid "dereference tags into object IDs"
+msgstr "desreferencia les etiquetes a ID d'objecte"
 
-#: builtin/remote.c:967
-#, c-format
-msgid "rebases interactively onto remote %s"
-msgstr "es fa «rebase» interactivament sobre el remot %s"
+#: builtin/show-ref.c:173
+msgid "only show SHA1 hash using <n> digits"
+msgstr "mostra el hash SHA1 usant només <n> xifres"
 
-#: builtin/remote.c:968
-#, c-format
-msgid "rebases onto remote %s"
-msgstr "es fa «rebase» sobre el remot %s"
+#: builtin/show-ref.c:177
+msgid "do not print results to stdout (useful with --verify)"
+msgstr "no imprimeixis els resultats a stdout (útil amb --verify)"
 
-#: builtin/remote.c:971
-#, c-format
-msgid " merges with remote %s"
-msgstr "es fusiona amb el remot %s"
+#: builtin/show-ref.c:179
+msgid "show refs from stdin that aren't in local repository"
+msgstr "mostra les referències de stdin que no siguin en el dipòsit local"
 
-#: builtin/remote.c:974
-#, c-format
-msgid "merges with remote %s"
-msgstr "es fusiona amb el remot %s"
+#: builtin/sparse-checkout.c:20
+msgid "git sparse-checkout (init|list|set|disable) <options>"
+msgstr ""
 
-#: builtin/remote.c:977
-#, c-format
-msgid "%-*s    and with remote %s\n"
-msgstr "%-*s    i amb el remot %s\n"
+#: builtin/sparse-checkout.c:61
+msgid "this worktree is not sparse (sparse-checkout file may not exist)"
+msgstr ""
 
-#: builtin/remote.c:1020
-msgid "create"
-msgstr "crea"
+#: builtin/sparse-checkout.c:220
+msgid "failed to set extensions.worktreeConfig setting"
+msgstr ""
 
-#: builtin/remote.c:1023
-msgid "delete"
-msgstr "suprimeix"
+#: builtin/sparse-checkout.c:237
+msgid "git sparse-checkout init [--cone]"
+msgstr ""
 
-#: builtin/remote.c:1027
-msgid "up to date"
-msgstr "al dia"
+#: builtin/sparse-checkout.c:256
+msgid "initialize the sparse-checkout in cone mode"
+msgstr ""
 
-#: builtin/remote.c:1030
-msgid "fast-forwardable"
-msgstr "avanç ràpid possible"
+#: builtin/sparse-checkout.c:262
+#, fuzzy
+msgid "initialize sparse-checkout"
+msgstr "omet l'aplicació del filtre d'agafament parcial"
 
-#: builtin/remote.c:1033
-msgid "local out of date"
-msgstr "local no actualitzat"
+#: builtin/sparse-checkout.c:295
+#, fuzzy, c-format
+msgid "failed to open '%s'"
+msgstr "s'ha fallat en obrir '%s'"
 
-#: builtin/remote.c:1040
-#, c-format
-msgid "    %-*s forces to %-*s (%s)"
-msgstr "    %-*s força a %-*s (%s)"
+#: builtin/sparse-checkout.c:361
+#, fuzzy
+msgid "git sparse-checkout set (--stdin | <patterns>)"
+msgstr "git hash-object  --stdin-paths"
 
-#: builtin/remote.c:1043
-#, c-format
-msgid "    %-*s pushes to %-*s (%s)"
-msgstr "    %-*s puja a %-*s (%s)"
+#: builtin/sparse-checkout.c:378
+#, fuzzy
+msgid "read patterns from standard in"
+msgstr "llegeix les actualitzacions des de stdin"
 
-#: builtin/remote.c:1047
-#, c-format
-msgid "    %-*s forces to %s"
-msgstr "    %-*s força a %s"
+#: builtin/sparse-checkout.c:384
+#, fuzzy
+msgid "set sparse-checkout patterns"
+msgstr "omet l'aplicació del filtre d'agafament parcial"
 
-#: builtin/remote.c:1050
-#, c-format
-msgid "    %-*s pushes to %s"
-msgstr "    %-*s puja a %s"
+#: builtin/sparse-checkout.c:447
+#, fuzzy
+msgid "disable sparse-checkout"
+msgstr "omet l'aplicació del filtre d'agafament parcial"
 
-#: builtin/remote.c:1118
-msgid "do not query remotes"
-msgstr "no consultis els remots"
+#: builtin/sparse-checkout.c:459
+#, fuzzy
+msgid "error while refreshing working directory"
+msgstr "no s'ha pogut obtenir el directori de treball actual"
 
-#: builtin/remote.c:1145
-#, c-format
-msgid "* remote %s"
-msgstr "* remot %s"
+#: builtin/stash.c:22 builtin/stash.c:37
+#, fuzzy
+msgid "git stash list [<options>]"
+msgstr "git worktree list [<opcions>]"
 
-#: builtin/remote.c:1146
-#, c-format
-msgid "  Fetch URL: %s"
-msgstr "  URL d'obtenció: %s"
+#: builtin/stash.c:23 builtin/stash.c:42
+#, fuzzy
+msgid "git stash show [<options>] [<stash>]"
+msgstr "git remote show [<opcions>] <nom>"
 
-#: builtin/remote.c:1147 builtin/remote.c:1163 builtin/remote.c:1302
-msgid "(no URL)"
-msgstr "(sense URL)"
+#: builtin/stash.c:24 builtin/stash.c:47
+msgid "git stash drop [-q|--quiet] [<stash>]"
+msgstr ""
 
-#. TRANSLATORS: the colon ':' should align
-#. with the one in " Fetch URL: %s"
-#. translation.
-#.
-#: builtin/remote.c:1161 builtin/remote.c:1163
-#, c-format
-msgid "  Push  URL: %s"
-msgstr "  URL de pujada: %s"
+#: builtin/stash.c:25
+msgid "git stash ( pop | apply ) [--index] [-q|--quiet] [<stash>]"
+msgstr ""
 
-#: builtin/remote.c:1165 builtin/remote.c:1167 builtin/remote.c:1169
-#, c-format
-msgid "  HEAD branch: %s"
-msgstr "  Branca de HEAD: %s"
+#: builtin/stash.c:26 builtin/stash.c:62
+#, fuzzy
+msgid "git stash branch <branchname> [<stash>]"
+msgstr "git branch [<opcions>] [-l] [-f] <nom-de-branca> [<punt-inicial>]"
 
-#: builtin/remote.c:1165
-msgid "(not queried)"
-msgstr "(no consultat)"
+#: builtin/stash.c:27 builtin/stash.c:67
+msgid "git stash clear"
+msgstr ""
 
-#: builtin/remote.c:1167
-msgid "(unknown)"
-msgstr "(desconegut)"
+#: builtin/stash.c:28 builtin/stash.c:77
+msgid ""
+"git stash [push [-p|--patch] [-k|--[no-]keep-index] [-q|--quiet]\n"
+"          [-u|--include-untracked] [-a|--all] [-m|--message <message>]\n"
+"          [--] [<pathspec>...]]"
+msgstr ""
 
-#: builtin/remote.c:1171
-#, c-format
+#: builtin/stash.c:31 builtin/stash.c:84
 msgid ""
-"  HEAD branch (remote HEAD is ambiguous, may be one of the following):\n"
+"git stash save [-p|--patch] [-k|--[no-]keep-index] [-q|--quiet]\n"
+"          [-u|--include-untracked] [-a|--all] [<message>]"
 msgstr ""
-"  Branca de HEAD (la HEAD remot és ambigua, pot ser un dels següents):\n"
 
-#: builtin/remote.c:1183
-#, c-format
-msgid "  Remote branch:%s"
-msgid_plural "  Remote branches:%s"
-msgstr[0] "  Branca remota:%s"
-msgstr[1] "  Branques remotes:%s"
+#: builtin/stash.c:52
+msgid "git stash pop [--index] [-q|--quiet] [<stash>]"
+msgstr ""
 
-#: builtin/remote.c:1186 builtin/remote.c:1212
-msgid " (status not queried)"
-msgstr " (estat no consultat)"
+#: builtin/stash.c:57
+msgid "git stash apply [--index] [-q|--quiet] [<stash>]"
+msgstr ""
 
-#: builtin/remote.c:1195
-msgid "  Local branch configured for 'git pull':"
-msgid_plural "  Local branches configured for 'git pull':"
-msgstr[0] "  Branca local configurada per a «git pull»:"
-msgstr[1] "  Branques locals configurades per a «git pull»:"
+#: builtin/stash.c:72
+msgid "git stash store [-m|--message <message>] [-q|--quiet] <commit>"
+msgstr ""
 
-#: builtin/remote.c:1203
-msgid "  Local refs will be mirrored by 'git push'"
-msgstr "  «git push» reflectirà les referències locals"
+#: builtin/stash.c:127
+#, fuzzy, c-format
+msgid "'%s' is not a stash-like commit"
+msgstr "'$args' no és una comissió de tipus magatzem"
 
-#: builtin/remote.c:1209
-#, c-format
-msgid "  Local ref configured for 'git push'%s:"
-msgid_plural "  Local refs configured for 'git push'%s:"
-msgstr[0] "  Referència local configurada per a «git push»%s:"
-msgstr[1] "  Referències locals configurades per a «git push»%s:"
+#: builtin/stash.c:147
+#, fuzzy, c-format
+msgid "Too many revisions specified:%s"
+msgstr "S'han especificat massa revisions: $REV"
 
-#: builtin/remote.c:1230
-msgid "set refs/remotes/<name>/HEAD according to remote"
-msgstr "estableix refs/remotes/<name>/HEAD segons el remot"
+#: builtin/stash.c:161 git-legacy-stash.sh:549
+msgid "No stash entries found."
+msgstr "No s'ha trobat cap «stash»."
 
-#: builtin/remote.c:1232
-msgid "delete refs/remotes/<name>/HEAD"
-msgstr "suprimeix refs/remotes/<name>/HEAD"
+#: builtin/stash.c:175
+#, fuzzy, c-format
+msgid "%s is not a valid reference"
+msgstr "«%s» no és un nom de remot vàlid"
+
+#: builtin/stash.c:224 git-legacy-stash.sh:75
+msgid "git stash clear with parameters is unimplemented"
+msgstr "git stash clear amb paràmetres no està implementat"
+
+#: builtin/stash.c:403
+#, fuzzy
+msgid "cannot apply a stash in the middle of a merge"
+msgstr "No es pot aplicar un magatzem enmig d'una fusió"
+
+#: builtin/stash.c:414
+#, fuzzy, c-format
+msgid "could not generate diff %s^!."
+msgstr "no s'ha pogut generar la llista per a fer"
+
+#: builtin/stash.c:421
+#, fuzzy
+msgid "conflicts in index.Try without --index."
+msgstr "Hi ha conflictes en l'índex. Proveu-ho sense --index."
+
+#: builtin/stash.c:427
+#, fuzzy
+msgid "could not save index tree"
+msgstr "No s'ha pogut desar l'arbre d'índex"
+
+#: builtin/stash.c:436
+#, fuzzy
+msgid "could not restore untracked files from stash"
+msgstr "No s'han pogut restaurar els fitxers no seguits des del «stash»"
+
+#: builtin/stash.c:450
+#, fuzzy, c-format
+msgid "Merging %s with %s"
+msgstr "S'està fusionant %s amb %s\n"
+
+#: builtin/stash.c:460 git-legacy-stash.sh:681
+msgid "Index was not unstashed."
+msgstr "L'índex no estava sense emmagatzemar."
 
-#: builtin/remote.c:1247
-msgid "Cannot determine remote HEAD"
-msgstr "No es pot determinar la HEAD remota"
+#: builtin/stash.c:521 builtin/stash.c:620
+#, fuzzy
+msgid "attempt to recreate the index"
+msgstr "S'ha produït un error en llegir l'índex"
 
-#: builtin/remote.c:1249
-msgid "Multiple remote HEAD branches. Please choose one explicitly with:"
-msgstr "Múltiples branques de HEAD remotes. Trieu-ne una explícitament amb:"
+#: builtin/stash.c:554
+#, fuzzy, c-format
+msgid "Dropped %s (%s)"
+msgstr "${REV} ($s) descartada"
 
-#: builtin/remote.c:1259
-#, c-format
-msgid "Could not delete %s"
-msgstr "No s'ha pogut suprimir %s"
+#: builtin/stash.c:557
+#, fuzzy, c-format
+msgid "%s: Could not drop stash entry"
+msgstr "${REV}: No s'ha pogut descartar l'entrada de magatzem"
 
-#: builtin/remote.c:1267
-#, c-format
-msgid "Not a valid ref: %s"
-msgstr "No és una referència vàlida: %s"
+#: builtin/stash.c:582
+#, fuzzy, c-format
+msgid "'%s' is not a stash reference"
+msgstr "'$args' no és una referència de magatzem"
 
-#: builtin/remote.c:1269
-#, c-format
-msgid "Could not setup %s"
-msgstr "No s'ha pogut configurar %s"
+#: builtin/stash.c:632 git-legacy-stash.sh:695
+msgid "The stash entry is kept in case you need it again."
+msgstr "Es conserva l'entrada «stash» en cas que la necessiteu altra vegada."
 
-#: builtin/remote.c:1287
-#, c-format
-msgid " %s will become dangling!"
-msgstr " %s es tornarà penjant!"
+#: builtin/stash.c:655 git-legacy-stash.sh:713
+msgid "No branch name specified"
+msgstr "Cap nom de branca especificat"
 
-#: builtin/remote.c:1288
-#, c-format
-msgid " %s has become dangling!"
-msgstr " %s s'ha tornat penjant!"
+#: builtin/stash.c:795 builtin/stash.c:832
+#, fuzzy, c-format
+msgid "Cannot update %s with %s"
+msgstr "No es pot actualitzar $ref_stash amb $w_commit"
 
-#: builtin/remote.c:1298
-#, c-format
-msgid "Pruning %s"
-msgstr "S'està podant %s"
+#: builtin/stash.c:813 builtin/stash.c:1470 builtin/stash.c:1506
+#, fuzzy
+msgid "stash message"
+msgstr "missatge d'etiqueta"
 
-#: builtin/remote.c:1299
-#, c-format
-msgid "URL: %s"
-msgstr "URL: %s"
+#: builtin/stash.c:823
+#, fuzzy
+msgid "\"git stash store\" requires one <commit> argument"
+msgstr "--bisect-clean-state no accepta paràmetres"
 
-#: builtin/remote.c:1315
-#, c-format
-msgid " * [would prune] %s"
-msgstr " * [podaria] %s"
+#: builtin/stash.c:1045 git-legacy-stash.sh:218
+msgid "No changes selected"
+msgstr "No hi ha canvis seleccionats"
 
-#: builtin/remote.c:1318
-#, c-format
-msgid " * [pruned] %s"
-msgstr " * [podat] %s"
+#: builtin/stash.c:1145 git-legacy-stash.sh:150
+msgid "You do not have the initial commit yet"
+msgstr "Encara no teniu la comissió inicial"
 
-#: builtin/remote.c:1363
-msgid "prune remotes after fetching"
-msgstr "poda els remots després d'obtenir-los"
+#: builtin/stash.c:1172 git-legacy-stash.sh:165
+msgid "Cannot save the current index state"
+msgstr "No es pot desar l'estat d'índex actual"
 
-#: builtin/remote.c:1426 builtin/remote.c:1480 builtin/remote.c:1548
-#, c-format
-msgid "No such remote '%s'"
-msgstr "No hi ha tal remot «%s»"
+#: builtin/stash.c:1181 git-legacy-stash.sh:180
+msgid "Cannot save the untracked files"
+msgstr "No es poden desar els fitxers no seguits"
 
-#: builtin/remote.c:1442
-msgid "add branch"
-msgstr "afegeix branca"
+#: builtin/stash.c:1192 builtin/stash.c:1201 git-legacy-stash.sh:201
+#: git-legacy-stash.sh:214
+msgid "Cannot save the current worktree state"
+msgstr "No es pot desar l'estat d'arbre de treball actual"
 
-#: builtin/remote.c:1449
-msgid "no remote specified"
-msgstr "cap remot especificat"
+#: builtin/stash.c:1229 git-legacy-stash.sh:234
+msgid "Cannot record working tree state"
+msgstr "No es pot registrar l'estat de l'arbre de treball"
 
-#: builtin/remote.c:1466
-msgid "query push URLs rather than fetch URLs"
-msgstr "consulta els URL de pujada en lloc dels URL d'obtenció"
+#: builtin/stash.c:1278 git-legacy-stash.sh:338
+msgid "Can't use --patch and --include-untracked or --all at the same time"
+msgstr "No es poden usar --patch i --include-untracked o --all a la vegada"
 
-#: builtin/remote.c:1468
-msgid "return all URLs"
-msgstr "retorna tots els URL"
+#: builtin/stash.c:1294
+#, fuzzy
+msgid "Did you forget to 'git add'?"
+msgstr "Potser volíeu dir «git add .»?\n"
 
-#: builtin/remote.c:1496
-#, c-format
-msgid "no URLs configured for remote '%s'"
-msgstr "cap URL configurat per al remot «%s»"
+#: builtin/stash.c:1309 git-legacy-stash.sh:346
+msgid "No local changes to save"
+msgstr "No hi ha canvis locals a desar"
 
-#: builtin/remote.c:1522
-msgid "manipulate push URLs"
-msgstr "manipula els URL de pujada"
+#: builtin/stash.c:1316 git-legacy-stash.sh:351
+msgid "Cannot initialize stash"
+msgstr "No es pot inicialitzar el magatzem"
 
-#: builtin/remote.c:1524
-msgid "add URL"
-msgstr "afegeix URL"
+#: builtin/stash.c:1331 git-legacy-stash.sh:355
+msgid "Cannot save the current status"
+msgstr "No es pot desar l'estat actual"
 
-#: builtin/remote.c:1526
-msgid "delete URLs"
-msgstr "suprimeix els URL"
+#: builtin/stash.c:1336
+#, fuzzy, c-format
+msgid "Saved working directory and index state %s"
+msgstr "S'han desat el directori de treball i l'estat d'índex $stash_msg"
 
-#: builtin/remote.c:1533
-msgid "--add --delete doesn't make sense"
-msgstr "--add --delete no té sentit"
+#: builtin/stash.c:1426 git-legacy-stash.sh:385
+msgid "Cannot remove worktree changes"
+msgstr "No es poden eliminar els canvis de l'arbre de treball"
 
-#: builtin/remote.c:1572
-#, c-format
-msgid "Invalid old URL pattern: %s"
-msgstr "Patró d'URL antic no vàlid: %s"
+#: builtin/stash.c:1461 builtin/stash.c:1497
+#, fuzzy
+msgid "keep index"
+msgstr "Actualitza l'índex"
 
-#: builtin/remote.c:1580
-#, c-format
-msgid "No such URL found: %s"
-msgstr "No s'ha trobat tal URL: %s"
+#: builtin/stash.c:1463 builtin/stash.c:1499
+msgid "stash in patch mode"
+msgstr ""
 
-#: builtin/remote.c:1582
-msgid "Will not delete all non-push URLs"
-msgstr "No se suprimiran tots els URL no de pujada"
+#: builtin/stash.c:1464 builtin/stash.c:1500
+#, fuzzy
+msgid "quiet mode"
+msgstr "silenciós"
 
-#: builtin/remote.c:1598
-msgid "be verbose; must be placed before a subcommand"
-msgstr "sigues detallat; s'ha de col·locar abans d'una subordre"
+#: builtin/stash.c:1466 builtin/stash.c:1502
+#, fuzzy
+msgid "include untracked files in stash"
+msgstr "mostra els fitxers no seguits en columnes"
 
-#: builtin/remote.c:1629
+#: builtin/stash.c:1468 builtin/stash.c:1504
+#, fuzzy
+msgid "include ignore files"
+msgstr "elimina només els fitxers ignorats"
+
+#: builtin/stash.c:1564
 #, c-format
-msgid "Unknown subcommand: %s"
-msgstr "Subordre desconeguda: %s"
+msgid "could not exec %s"
+msgstr "no s'ha pogut executar %s"
 
-#: builtin/repack.c:18
-msgid "git repack [<options>]"
-msgstr "git repack [<opcions>]"
+#: builtin/stripspace.c:18
+msgid "git stripspace [-s | --strip-comments]"
+msgstr "git stripspace [-s | --strip-comments]"
 
-#: builtin/repack.c:23
-msgid ""
-"Incremental repacks are incompatible with bitmap indexes.  Use\n"
-"--no-write-bitmap-index or disable the pack.writebitmaps configuration."
+#: builtin/stripspace.c:19
+msgid "git stripspace [-c | --comment-lines]"
+msgstr "git stripspace [-c | --comment-lines]"
+
+#: builtin/stripspace.c:37
+msgid "skip and remove all lines starting with comment character"
 msgstr ""
-"Els reempaquetaments incrementals són incompatibles amb els índexs de "
-"bitmaps.  Useu\n"
-"--no-write-bitmap-index o inhabiliteu el paràmetre de configuració pack."
-"writebitmaps."
+"omet i elimina totes les línies que comencin amb el caràcter de comentari"
 
-#: builtin/repack.c:170
-msgid "pack everything in a single pack"
-msgstr "empaqueta-ho tot en un únic paquet"
+#: builtin/stripspace.c:40
+msgid "prepend comment character and space to each line"
+msgstr "anteposa el caràcter de comentari i un espai a cada línia"
 
-#: builtin/repack.c:172
-msgid "same as -a, and turn unreachable objects loose"
-msgstr "el mateix que -a, i solta els objectes inabastables"
+#: builtin/submodule--helper.c:47 builtin/submodule--helper.c:1970
+#, c-format
+msgid "Expecting a full ref name, got %s"
+msgstr "S'espera un nom de referència ple, s'ha rebut %s"
 
-#: builtin/repack.c:175
-msgid "remove redundant packs, and run git-prune-packed"
-msgstr "elimina els paquets redundants, i executeu git-prune-packed"
+#: builtin/submodule--helper.c:64
+msgid "submodule--helper print-default-remote takes no arguments"
+msgstr ""
 
-#: builtin/repack.c:177
-msgid "pass --no-reuse-delta to git-pack-objects"
-msgstr "passa --no-reuse-delta a git-pack-objects"
+#: builtin/submodule--helper.c:102
+#, c-format
+msgid "cannot strip one component off url '%s'"
+msgstr "no es pot despullar un component de l'url «%s»"
 
-#: builtin/repack.c:179
-msgid "pass --no-reuse-object to git-pack-objects"
-msgstr "passa --no-reuse-object a git-pack-objects"
+#: builtin/submodule--helper.c:410 builtin/submodule--helper.c:1380
+msgid "alternative anchor for relative paths"
+msgstr "àncora alternativa per als camins relatius"
 
-#: builtin/repack.c:181
-msgid "do not run git-update-server-info"
-msgstr "no executis git-update-server-info"
+#: builtin/submodule--helper.c:415
+msgid "git submodule--helper list [--prefix=<path>] [<path>...]"
+msgstr "git submodule--helper list [--prefix=<camí>] [<camí>...]"
 
-#: builtin/repack.c:184
-msgid "pass --local to git-pack-objects"
-msgstr "passa --local a git-pack-objects"
+#: builtin/submodule--helper.c:472 builtin/submodule--helper.c:630
+#: builtin/submodule--helper.c:653
+#, c-format
+msgid "No url found for submodule path '%s' in .gitmodules"
+msgstr "No s'ha trobat cap url per al camí de submòdul «%s» a .gitmodules"
 
-#: builtin/repack.c:186
-msgid "write bitmap index"
-msgstr "escriu índex de mapa de bits"
+#: builtin/submodule--helper.c:524
+#, c-format
+msgid "Entering '%s'\n"
+msgstr "S'està entrant a «%s»\n"
 
-#: builtin/repack.c:187
-msgid "approxidate"
-msgstr "data aproximada"
+#: builtin/submodule--helper.c:527
+#, c-format
+msgid ""
+"run_command returned non-zero status for %s\n"
+"."
+msgstr ""
 
-#: builtin/repack.c:188
-msgid "with -A, do not loosen objects older than this"
-msgstr "amb -A, no soltis els objectes més vells que aquest"
+#: builtin/submodule--helper.c:549
+#, c-format
+msgid ""
+"run_command returned non-zero status while recursing in the nested "
+"submodules of %s\n"
+"."
+msgstr ""
 
-#: builtin/repack.c:190
-msgid "with -a, repack unreachable objects"
-msgstr "amb -a, reempaqueta els objectes inabastables"
+#: builtin/submodule--helper.c:565
+msgid "Suppress output of entering each submodule command"
+msgstr "Omet la sortida en entrar l'ordre de cada submòdul"
 
-#: builtin/repack.c:192
-msgid "size of the window used for delta compression"
-msgstr "mida de la finestra que s'usa per a compressió de diferències"
+#: builtin/submodule--helper.c:567 builtin/submodule--helper.c:1053
+msgid "Recurse into nested submodules"
+msgstr "Inclou recursivament els submòduls imbricats"
 
-#: builtin/repack.c:193 builtin/repack.c:199
-msgid "bytes"
-msgstr "octets"
+#: builtin/submodule--helper.c:572
+#, fuzzy
+msgid "git submodule--helper foreach [--quiet] [--recursive] [--] <command>"
+msgstr "git submodule--helper foreach [--quiet] [--recursive] [<ordre>]"
 
-#: builtin/repack.c:194
-msgid "same as the above, but limit memory size instead of entries count"
+#: builtin/submodule--helper.c:599
+#, c-format
+msgid ""
+"could not look up configuration '%s'. Assuming this repository is its own "
+"authoritative upstream."
 msgstr ""
-"el mateix que l'anterior, però limita la mida de memòria en lloc del nombre "
-"d'entrades"
+"no s'ha pogut trobar la configuració «%s». S'assumeix que aquest dipòsit és "
+"el seu dipòsit font autoritzat."
 
-#: builtin/repack.c:196
-msgid "limits the maximum delta depth"
-msgstr "limita la profunditat màxima de les diferències"
+#: builtin/submodule--helper.c:667
+#, c-format
+msgid "Failed to register url for submodule path '%s'"
+msgstr "S'ha produït un error en registrar l'url per al camí de submòdul «%s»"
 
-#: builtin/repack.c:198
-msgid "limits the maximum number of threads"
-msgstr "limita el nombre màxim de fils"
+#: builtin/submodule--helper.c:671
+#, c-format
+msgid "Submodule '%s' (%s) registered for path '%s'\n"
+msgstr "S'ha registrat el submòdul «%s» (%s) per al camí «%s»\n"
 
-#: builtin/repack.c:200
-msgid "maximum size of each packfile"
-msgstr "mida màxima de cada fitxer de paquet"
+#: builtin/submodule--helper.c:681
+#, c-format
+msgid "warning: command update mode suggested for submodule '%s'\n"
+msgstr ""
+"advertència: se suggereix el mode d'actualització per ordre per al submòdul "
+"«%s»\n"
 
-#: builtin/repack.c:202
-msgid "repack objects in packs marked with .keep"
-msgstr "reempaqueta els objectes en paquets marcats amb .keep"
+#: builtin/submodule--helper.c:688
+#, c-format
+msgid "Failed to register update mode for submodule path '%s'"
+msgstr ""
+"S'ha produït un error en registrar el mode d'actualització per al camí de "
+"submòdul «%s»"
 
-#: builtin/repack.c:212
-msgid "cannot delete packs in a precious-objects repo"
-msgstr "no es poden suprimir paquets en un dipòsit d'objectes preciosos"
+#: builtin/submodule--helper.c:710
+msgid "Suppress output for initializing a submodule"
+msgstr "Omet la sortida d'inicialitzar un submòdul"
 
-#: builtin/repack.c:216
-msgid "--keep-unreachable and -A are incompatible"
-msgstr "--keep-unreachable i -A són incompatibles"
+#: builtin/submodule--helper.c:715
+#, fuzzy
+msgid "git submodule--helper init [<options>] [<path>]"
+msgstr "git submodule--helper init [<camí>]"
 
-#: builtin/repack.c:410 builtin/worktree.c:148
+#: builtin/submodule--helper.c:787 builtin/submodule--helper.c:914
 #, c-format
-msgid "failed to remove '%s'"
-msgstr "s'ha produït un error en eliminar «%s»"
+msgid "no submodule mapping found in .gitmodules for path '%s'"
+msgstr "No s'ha trobat cap mapatge de submòdul a .gitmodules per al camí «%s»"
 
-#: builtin/replace.c:20
-msgid "git replace [-f] <object> <replacement>"
-msgstr "git replace [-f] <objecte> <reemplaçament>"
+#: builtin/submodule--helper.c:827
+#, c-format
+msgid "could not resolve HEAD ref inside the submodule '%s'"
+msgstr "no s'ha pogut resoldre la referència a HEAD dins del submòdul «%s»"
 
-#: builtin/replace.c:21
-msgid "git replace [-f] --edit <object>"
-msgstr "git replace [-f] --edit <objecte>"
+#: builtin/submodule--helper.c:854 builtin/submodule--helper.c:1023
+#, c-format
+msgid "failed to recurse into submodule '%s'"
+msgstr "s'ha produït un error en cercar recursivament al submòdul «%s»"
 
-#: builtin/replace.c:22
-msgid "git replace [-f] --graft <commit> [<parent>...]"
-msgstr "git replace [-f] --graft <comissió> [<mare>...]"
+#: builtin/submodule--helper.c:878 builtin/submodule--helper.c:1189
+msgid "Suppress submodule status output"
+msgstr "Suprimeix la sortida de l'estat del submòdul"
+
+#: builtin/submodule--helper.c:879
+msgid ""
+"Use commit stored in the index instead of the one stored in the submodule "
+"HEAD"
+msgstr ""
 
-#: builtin/replace.c:23
-msgid "git replace -d <object>..."
-msgstr "git replace -d <objecte>..."
+#: builtin/submodule--helper.c:880
+msgid "recurse into nested submodules"
+msgstr "inclou recursivament els submòduls imbrincats"
 
-#: builtin/replace.c:24
-msgid "git replace [--format=<format>] [-l [<pattern>]]"
-msgstr "git replace [--format=<format>] [-l [<patró>]]"
+#: builtin/submodule--helper.c:885
+msgid "git submodule status [--quiet] [--cached] [--recursive] [<path>...]"
+msgstr "git submodule status [--quiet] [--cached] [--recursive] [<camí>...]"
 
-#: builtin/replace.c:331 builtin/replace.c:369 builtin/replace.c:397
-#, c-format
-msgid "Not a valid object name: '%s'"
-msgstr "No és un nom d'objecte vàlid: «%s»"
+#: builtin/submodule--helper.c:909
+msgid "git submodule--helper name <path>"
+msgstr "git submodule--helper name <camí>"
 
-#: builtin/replace.c:361
+#: builtin/submodule--helper.c:973
 #, c-format
-msgid "bad mergetag in commit '%s'"
-msgstr "etiqueta de fusió incorrecta en la comissió «%s»"
+msgid "Synchronizing submodule url for '%s'\n"
+msgstr "S'està sincronitzant l'url del submòdul per a «%s»\n"
 
-#: builtin/replace.c:363
+#: builtin/submodule--helper.c:979
 #, c-format
-msgid "malformed mergetag in commit '%s'"
-msgstr "etiqueta de fusió mal formada en la comissió «%s»"
+msgid "failed to register url for submodule path '%s'"
+msgstr "s'ha produït un error en registrar l'url per al camí del submòdul «%s»"
 
-#: builtin/replace.c:374
+#: builtin/submodule--helper.c:993
 #, c-format
-msgid ""
-"original commit '%s' contains mergetag '%s' that is discarded; use --edit "
-"instead of --graft"
+msgid "failed to get the default remote for submodule '%s'"
 msgstr ""
-"la comissió original «%s» conté l'etiqueta de fusió «%s» que es descarta; "
-"useu --edit en lloc de --graft"
+"s'ha produït un error en obtenir el remot per defecte pel submòdul «%s»"
 
-#: builtin/replace.c:407
+#: builtin/submodule--helper.c:1004
 #, c-format
-msgid "the original commit '%s' has a gpg signature."
-msgstr "la comissió original «%s» té una signatura gpg."
+msgid "failed to update remote for submodule '%s'"
+msgstr "s'ha produït un error en actualitzar el remot pel submòdul «%s»"
 
-#: builtin/replace.c:408
-msgid "the signature will be removed in the replacement commit!"
-msgstr "s'eliminarà la signatura en la comissió de reemplaçament!"
+#: builtin/submodule--helper.c:1051
+msgid "Suppress output of synchronizing submodule url"
+msgstr "Omet la sortida de la sincronització de l'url del submòdul"
+
+#: builtin/submodule--helper.c:1058
+msgid "git submodule--helper sync [--quiet] [--recursive] [<path>]"
+msgstr "git submodule--helper sync [--quiet] [--recursive] [<camí>]"
 
-#: builtin/replace.c:414
+#: builtin/submodule--helper.c:1112
 #, c-format
-msgid "could not write replacement commit for: '%s'"
-msgstr "no s'ha pogut escriure la comissió de reemplaçament per a: «%s»"
+msgid ""
+"Submodule work tree '%s' contains a .git directory (use 'rm -rf' if you "
+"really want to remove it including all of its history)"
+msgstr ""
+"L'arbre de treball de submòdul «%s» conté un directori .git\n"
+"(useu 'rm -rf' si realment voleu eliminar-lo, incloent tota la seva història)"
 
-#: builtin/replace.c:438
-msgid "list replace refs"
-msgstr "llista les referències reemplaçades"
+#: builtin/submodule--helper.c:1124
+#, c-format
+msgid ""
+"Submodule work tree '%s' contains local modifications; use '-f' to discard "
+"them"
+msgstr ""
+"L'arbre de treball del submòdul «%s» conté modificacions locals; useu '-f' "
+"per a descartar-les"
 
-#: builtin/replace.c:439
-msgid "delete replace refs"
-msgstr "suprimeix les referències reemplaçades"
+#: builtin/submodule--helper.c:1132
+#, c-format
+msgid "Cleared directory '%s'\n"
+msgstr "S'ha netejat el directori «%s»\n"
 
-#: builtin/replace.c:440
-msgid "edit existing object"
-msgstr "edita un objecte existent"
+#: builtin/submodule--helper.c:1134
+#, c-format
+msgid "Could not remove submodule work tree '%s'\n"
+msgstr "No s'ha pogut eliminar l'arbre de treball de submòdul «%s»\n"
 
-#: builtin/replace.c:441
-msgid "change a commit's parents"
-msgstr "canvia les mares d'una comissió"
+#: builtin/submodule--helper.c:1145
+#, c-format
+msgid "could not create empty submodule directory %s"
+msgstr "no s'ha pogut crear el directori de submòdul buit %s"
 
-#: builtin/replace.c:442
-msgid "replace the ref if it exists"
-msgstr "reemplaça la referència si existeix"
+#: builtin/submodule--helper.c:1161
+#, c-format
+msgid "Submodule '%s' (%s) unregistered for path '%s'\n"
+msgstr "S'ha desregistrat el submòdul «%s» (%s) per al camí «%s»\n"
 
-#: builtin/replace.c:444
-msgid "do not pretty-print contents for --edit"
-msgstr "no imprimeixis bellament els continguts per a --edit"
+#: builtin/submodule--helper.c:1190
+msgid "Remove submodule working trees even if they contain local changes"
+msgstr ""
+"Suprimeix els arbres de treball dels submòduls fins i tot si contenen canvis "
+"locals"
 
-#: builtin/replace.c:445
-msgid "use this format"
-msgstr "usa aquest format"
+#: builtin/submodule--helper.c:1191
+msgid "Unregister all submodules"
+msgstr "Desregistra recursivament tots els submòduls"
 
-#: builtin/rerere.c:13
-msgid "git rerere [clear | forget <path>... | status | remaining | diff | gc]"
-msgstr "git rerere [clear | forget <camí>... | status | remaining | diff | gc]"
+#: builtin/submodule--helper.c:1196
+msgid ""
+"git submodule deinit [--quiet] [-f | --force] [--all | [--] [<path>...]]"
+msgstr ""
+"git submodule deinit [--quiet] [-f | --force] [--all | [--] [<camí>...]]"
 
-#: builtin/rerere.c:59
-msgid "register clean resolutions in index"
-msgstr "registra les resolucions netes en l'índex"
+#: builtin/submodule--helper.c:1210
+msgid "Use '--all' if you really want to deinitialize all submodules"
+msgstr "Useu '--all' si realment voleu desinicialitzar tots els submòduls"
 
-#: builtin/reset.c:29
+#: builtin/submodule--helper.c:1275
 msgid ""
-"git reset [--mixed | --soft | --hard | --merge | --keep] [-q] [<commit>]"
+"An alternate computed from a superproject's alternate is invalid.\n"
+"To allow Git to clone without an alternate in such a case, set\n"
+"submodule.alternateErrorStrategy to 'info' or, equivalently, clone with\n"
+"'--reference-if-able' instead of '--reference'."
 msgstr ""
-"git reset [--mixed | --soft | --hard | --merge | --keep] [-q] [<comissió>]"
 
-#: builtin/reset.c:30
-msgid "git reset [-q] [<tree-ish>] [--] <paths>..."
-msgstr "git reset [-q] [<arbre>] [--] <camins>..."
+#: builtin/submodule--helper.c:1314 builtin/submodule--helper.c:1317
+#, c-format
+msgid "submodule '%s' cannot add alternate: %s"
+msgstr "el submòdul «%s» no pot afegir un alternatiu: %s"
 
-#: builtin/reset.c:31
-msgid "git reset --patch [<tree-ish>] [--] [<paths>...]"
-msgstr "git reset --patch [<arbre>] [--] [<camins>...]"
+#: builtin/submodule--helper.c:1353
+#, c-format
+msgid "Value '%s' for submodule.alternateErrorStrategy is not recognized"
+msgstr "No es reconeix el valor «%s» per a submodule.alternateErrorStrategy"
 
-#: builtin/reset.c:37
-msgid "mixed"
-msgstr "mixt"
+#: builtin/submodule--helper.c:1360
+#, c-format
+msgid "Value '%s' for submodule.alternateLocation is not recognized"
+msgstr "No es reconeix el valor «%s» per a submodule.alternateLocation"
 
-#: builtin/reset.c:37
-msgid "soft"
-msgstr "suau"
+#: builtin/submodule--helper.c:1383
+msgid "where the new submodule will be cloned to"
+msgstr "a on es clonarà el submòdul nou"
 
-#: builtin/reset.c:37
-msgid "hard"
-msgstr "dur"
+#: builtin/submodule--helper.c:1386
+msgid "name of the new submodule"
+msgstr "nom del submòdul nou"
 
-#: builtin/reset.c:37
-msgid "merge"
-msgstr "fusió"
+#: builtin/submodule--helper.c:1389
+msgid "url where to clone the submodule from"
+msgstr "url del qual clonar el submòdul"
 
-#: builtin/reset.c:37
-msgid "keep"
-msgstr "reteniment"
+#: builtin/submodule--helper.c:1397
+msgid "depth for shallow clones"
+msgstr "profunditat dels clons superficials"
 
-#: builtin/reset.c:78
-msgid "You do not have a valid HEAD."
-msgstr "No teniu un HEAD vàlid."
+#: builtin/submodule--helper.c:1400 builtin/submodule--helper.c:1897
+msgid "force cloning progress"
+msgstr "força el progrés del clonatge"
 
-#: builtin/reset.c:80
-msgid "Failed to find tree of HEAD."
-msgstr "S'ha produït un error en trobar l'arbre de HEAD."
+#: builtin/submodule--helper.c:1402 builtin/submodule--helper.c:1899
+#, fuzzy
+msgid "disallow cloning into non-empty directory"
+msgstr "s'està aplicant a una història buida"
 
-#: builtin/reset.c:86
-#, c-format
-msgid "Failed to find tree of %s."
-msgstr "S'ha produït un error en cercar l'arbre de %s."
+#: builtin/submodule--helper.c:1407
+msgid ""
+"git submodule--helper clone [--prefix=<path>] [--quiet] [--reference "
+"<repository>] [--name <name>] [--depth <depth>] --url <url> --path <path>"
+msgstr ""
+"git submodule--helper clone [--prefix=<camí>] [--quiet] [--reference "
+"<dipòsit>] [--name <nom>] [--depth <profunditat>] --url <url> --path <camí>"
 
-#: builtin/reset.c:111
+#: builtin/submodule--helper.c:1431
 #, c-format
-msgid "HEAD is now at %s"
-msgstr "HEAD ara és a %s"
+msgid "refusing to create/use '%s' in another submodule's git dir"
+msgstr ""
 
-#: builtin/reset.c:189
+#: builtin/submodule--helper.c:1442
 #, c-format
-msgid "Cannot do a %s reset in the middle of a merge."
-msgstr "No es pot fer un restabliment de %s enmig d'una fusió."
-
-#: builtin/reset.c:289
-msgid "be quiet, only report errors"
-msgstr "sigues silenciós, només informa d'errors"
-
-#: builtin/reset.c:291
-msgid "reset HEAD and index"
-msgstr "restableix HEAD i l'índex"
-
-#: builtin/reset.c:292
-msgid "reset only HEAD"
-msgstr "restableix només HEAD"
-
-#: builtin/reset.c:294 builtin/reset.c:296
-msgid "reset HEAD, index and working tree"
-msgstr "restableix HEAD, l'índex i l'arbre de treball"
-
-#: builtin/reset.c:298
-msgid "reset HEAD but keep local changes"
-msgstr "restableix HEAD però retén els canvis locals"
+msgid "clone of '%s' into submodule path '%s' failed"
+msgstr "el clonatge de «%s» al camí de submòdul «%s» ha fallat"
 
-#: builtin/reset.c:304
-msgid "record only the fact that removed paths will be added later"
-msgstr "registra només el fet que els camins eliminats s'afegiran després"
+#: builtin/submodule--helper.c:1446
+#, fuzzy, c-format
+msgid "directory not empty: '%s'"
+msgstr "el directori font està buit"
 
-#: builtin/reset.c:321
+#: builtin/submodule--helper.c:1458
 #, c-format
-msgid "Failed to resolve '%s' as a valid revision."
-msgstr "S'ha produït un error en resoldre «%s» com a revisió vàlida."
+msgid "could not get submodule directory for '%s'"
+msgstr "no s'ha pogut obtenir el directori de submòdul per a «%s»"
 
-#: builtin/reset.c:329
+#: builtin/submodule--helper.c:1494
 #, c-format
-msgid "Failed to resolve '%s' as a valid tree."
-msgstr "S'ha produït un error en resoldre «%s» com a arbre vàlid."
-
-#: builtin/reset.c:338
-msgid "--patch is incompatible with --{hard,mixed,soft}"
-msgstr "--patch és incompatible amb --{hard,mixed,soft}"
+msgid "Invalid update mode '%s' for submodule path '%s'"
+msgstr "Mode d'actualització «%s» no vàlid per al camí de submòdul «%s»"
 
-#: builtin/reset.c:347
-msgid "--mixed with paths is deprecated; use 'git reset -- <paths>' instead."
+#: builtin/submodule--helper.c:1498
+#, c-format
+msgid "Invalid update mode '%s' configured for submodule path '%s'"
 msgstr ""
-"--mixed amb camins està en desús; useu 'git reset -- <camins>' en lloc "
-"d'això."
+"Mode d'actualització «%s» configurat no vàlid per al camí de submòdul «%s»"
 
-#: builtin/reset.c:349
+#: builtin/submodule--helper.c:1594
 #, c-format
-msgid "Cannot do %s reset with paths."
-msgstr "No es pot restablir de %s amb camins."
+msgid "Submodule path '%s' not initialized"
+msgstr "El camí de submòdul «%s» no està inicialitzat"
 
-#: builtin/reset.c:359
-#, c-format
-msgid "%s reset is not allowed in a bare repository"
-msgstr "el restabliment de %s no es permet en un dipòsit nu"
+#: builtin/submodule--helper.c:1598
+msgid "Maybe you want to use 'update --init'?"
+msgstr "Potser voleu usar 'update --init'?"
 
-#: builtin/reset.c:363
-msgid "-N can only be used with --mixed"
-msgstr "-N només es pot usar amb --mixed"
+#: builtin/submodule--helper.c:1628
+#, c-format
+msgid "Skipping unmerged submodule %s"
+msgstr "S'està ometent el submòdul no fusionat %s"
 
-#: builtin/reset.c:380
-msgid "Unstaged changes after reset:"
-msgstr "Canvis «unstaged» després del restabliment:"
+#: builtin/submodule--helper.c:1657
+#, c-format
+msgid "Skipping submodule '%s'"
+msgstr "S'està ometent el submòdul «%s»"
 
-#: builtin/reset.c:386
+#: builtin/submodule--helper.c:1803
 #, c-format
-msgid "Could not reset index file to revision '%s'."
-msgstr "No s'ha pogut restablir el fitxer d'índex a la revisió «%s»."
+msgid "Failed to clone '%s'. Retry scheduled"
+msgstr "S'ha produït un error en clonar «%s». S'ha programat un reintent"
 
-#: builtin/reset.c:390
-msgid "Could not write new index file."
-msgstr "No s'ha pogut escriure el fitxer d'índex nou."
+#: builtin/submodule--helper.c:1814
+#, c-format
+msgid "Failed to clone '%s' a second time, aborting"
+msgstr "S'ha produït un error per segon cop en clonar «%s», s'està avortant"
 
-#: builtin/rev-list.c:397
-msgid "cannot combine --exclude-promisor-objects and --missing"
-msgstr ""
+#: builtin/submodule--helper.c:1876 builtin/submodule--helper.c:2120
+msgid "path into the working tree"
+msgstr "camí a l'arbre de treball"
 
-#: builtin/rev-list.c:455
-msgid "object filtering requires --objects"
-msgstr "el filtratge d'objectes requereix --objects"
+#: builtin/submodule--helper.c:1879
+msgid "path into the working tree, across nested submodule boundaries"
+msgstr "camí a l'arbre de treball, a través de fronteres de submòduls niats"
 
-#: builtin/rev-list.c:458
-#, c-format
-msgid "invalid sparse value '%s'"
-msgstr "valor parcial no vàlid: «%s»"
+#: builtin/submodule--helper.c:1883
+msgid "rebase, merge, checkout or none"
+msgstr "rebase, merge, checkout o none"
 
-#: builtin/rev-list.c:499
-msgid "rev-list does not support display of notes"
-msgstr "el rev-list no permet mostrar notes"
+#: builtin/submodule--helper.c:1889
+msgid "Create a shallow clone truncated to the specified number of revisions"
+msgstr "Crea un clon superficial truncat al nombre de revisions especificat"
 
-#: builtin/rev-list.c:502
-msgid "cannot combine --use-bitmap-index with object filtering"
-msgstr "no es pot combinar --use-bitmap-index amb el filtratge d'objectes"
+#: builtin/submodule--helper.c:1892
+msgid "parallel jobs"
+msgstr "tasques paral·leles"
 
-#: builtin/rev-parse.c:402
-msgid "git rev-parse --parseopt [<options>] -- [<args>...]"
-msgstr "git rev-parse --parseopt [<opcions>] -- [<paràmetres>...]"
+#: builtin/submodule--helper.c:1894
+msgid "whether the initial clone should follow the shallow recommendation"
+msgstr "si el clonatge inicial ha de seguir la recomanació de superficialitat"
 
-#: builtin/rev-parse.c:407
-msgid "keep the `--` passed as an arg"
-msgstr "retén el «--» passat com a paràmetre"
+#: builtin/submodule--helper.c:1895
+msgid "don't print cloning progress"
+msgstr "no imprimeixis el progrés del clonatge"
 
-#: builtin/rev-parse.c:409
-msgid "stop parsing after the first non-option argument"
-msgstr "deixa d'analitzar després del primer paràmetre no d'opció"
+#: builtin/submodule--helper.c:1904
+#, fuzzy
+msgid "git submodule--helper update-clone [--prefix=<path>] [<path>...]"
+msgstr "git submodule--helper update_clone [--prefix=<camí>] [<camí>...]"
 
-#: builtin/rev-parse.c:412
-msgid "output in stuck long form"
-msgstr "emet en forma llarga enganxada"
+#: builtin/submodule--helper.c:1917
+msgid "bad value for update parameter"
+msgstr "valor incorrecte per al paràmetre update"
 
-#: builtin/rev-parse.c:545
+#: builtin/submodule--helper.c:1965
+#, c-format
 msgid ""
-"git rev-parse --parseopt [<options>] -- [<args>...]\n"
-"   or: git rev-parse --sq-quote [<arg>...]\n"
-"   or: git rev-parse [<options>] [<arg>...]\n"
-"\n"
-"Run \"git rev-parse --parseopt -h\" for more information on the first usage."
+"Submodule (%s) branch configured to inherit branch from superproject, but "
+"the superproject is not on any branch"
 msgstr ""
-"git rev-parse --parseopt [<opcions>] -- [<paràmetres>...]\n"
-"   or: git rev-parse --sq-quote [<paràmetre>...]\n"
-"   or: git rev-parse [<opcions>] [<paràmetre>...]\n"
-"\n"
-"Executeu \"git rev-parse --parseopt -h\" per més informació sobre l'ús "
-"inicial."
+"La branca de submòdul (%s) està configurada per a heretar la branca del "
+"superprojecte, però el superprojecte no és en cap branca"
 
-#: builtin/revert.c:23
-msgid "git revert [<options>] <commit-ish>..."
-msgstr "git revert [<opcions>] <comissió>..."
+#: builtin/submodule--helper.c:2088
+#, c-format
+msgid "could not get a repository handle for submodule '%s'"
+msgstr "no s'ha pogut obtenir el gestor del dipòsit pel submòdul «%s»"
 
-#: builtin/revert.c:24
-msgid "git revert <subcommand>"
-msgstr "git revert <subordre>"
+#: builtin/submodule--helper.c:2121
+msgid "recurse into submodules"
+msgstr "inclou recursivament als submòduls"
 
-#: builtin/revert.c:29
-msgid "git cherry-pick [<options>] <commit-ish>..."
-msgstr "git cherry-pick [<opcions>] <comissió>..."
+#: builtin/submodule--helper.c:2127
+#, fuzzy
+msgid "git submodule--helper absorb-git-dirs [<options>] [<path>...]"
+msgstr "git submodule--helper embed-git-dir [<camí>...]"
 
-#: builtin/revert.c:30
-msgid "git cherry-pick <subcommand>"
-msgstr "git cherry-pick <subordre>"
+#: builtin/submodule--helper.c:2183
+msgid "check if it is safe to write to the .gitmodules file"
+msgstr "comprova si és segur escriure al fitxer .gitmodules"
 
-#: builtin/revert.c:90
-#, c-format
-msgid "%s: %s cannot be used with %s"
-msgstr "%s: %s no es pot usar amb %s"
+#: builtin/submodule--helper.c:2186
+#, fuzzy
+msgid "unset the config in the .gitmodules file"
+msgstr "l'allistament del .gitmodules actualitzat ha fallat"
 
-#: builtin/revert.c:99
-msgid "end revert or cherry-pick sequence"
-msgstr "acaba la seqüència de reversió o el «cherry pick»"
+#: builtin/submodule--helper.c:2191
+#, fuzzy
+msgid "git submodule--helper config <name> [<value>]"
+msgstr "git submodule--helper config name [valor]"
 
-#: builtin/revert.c:100
-msgid "resume revert or cherry-pick sequence"
-msgstr "reprèn la seqüència de reversió o el «cherry pick»"
+#: builtin/submodule--helper.c:2192
+#, fuzzy
+msgid "git submodule--helper config --unset <name>"
+msgstr "git submodule--helper config name [valor]"
 
-#: builtin/revert.c:101
-msgid "cancel revert or cherry-pick sequence"
-msgstr "cancel·la la seqüència de reversió o el «cherry pick»"
+#: builtin/submodule--helper.c:2193
+msgid "git submodule--helper config --check-writeable"
+msgstr "git submodule--helper config --check-writeable"
 
-#: builtin/revert.c:102
-msgid "don't automatically commit"
-msgstr "no cometis automàticament"
+#: builtin/submodule--helper.c:2212 git-submodule.sh:173
+#, fuzzy, sh-format
+msgid "please make sure that the .gitmodules file is in the working tree"
+msgstr ""
+"Feu «stage» dels vostres canvis a .gitmodules o feu «stash» dels mateixos "
+"per a procedir"
 
-#: builtin/revert.c:103
-msgid "edit the commit message"
-msgstr "edita el missatge de comissió"
+#: builtin/submodule--helper.c:2262 git.c:433 git.c:684
+#, c-format
+msgid "%s doesn't support --super-prefix"
+msgstr "%s no admet --super-prefix"
 
-#: builtin/revert.c:106
-msgid "parent-number"
-msgstr "número del pare"
+#: builtin/submodule--helper.c:2268
+#, c-format
+msgid "'%s' is not a valid submodule--helper subcommand"
+msgstr "«%s» no és un subordre vàlid de submodule--helper"
 
-#: builtin/revert.c:107
-msgid "select mainline parent"
-msgstr "selecciona la línia principal del pare"
+#: builtin/symbolic-ref.c:8
+msgid "git symbolic-ref [<options>] <name> [<ref>]"
+msgstr "git symbolic-ref [<opcions>] <nom> [<referència>]"
 
-#: builtin/revert.c:109
-msgid "merge strategy"
-msgstr "estratègia de fusió"
+#: builtin/symbolic-ref.c:9
+msgid "git symbolic-ref -d [-q] <name>"
+msgstr "git symbolic-ref -d [-q] <nom>"
 
-#: builtin/revert.c:110
-msgid "option"
-msgstr "opció"
+#: builtin/symbolic-ref.c:40
+msgid "suppress error message for non-symbolic (detached) refs"
+msgstr "omet el missatge d'error de referències no simbòliques (separades)"
 
-#: builtin/revert.c:111
-msgid "option for merge strategy"
-msgstr "opció d'estratègia de fusió"
+#: builtin/symbolic-ref.c:41
+msgid "delete symbolic ref"
+msgstr "suprimeix la referència simbòlica"
 
-#: builtin/revert.c:120
-msgid "append commit name"
-msgstr "nom de la comissió a annexar"
+#: builtin/symbolic-ref.c:42
+msgid "shorten ref output"
+msgstr "escurça la sortida de referències"
 
-#: builtin/revert.c:122
-msgid "preserve initially empty commits"
-msgstr "preserva les comissions inicialment buides"
+#: builtin/symbolic-ref.c:43 builtin/update-ref.c:363
+msgid "reason"
+msgstr "raó"
 
-#: builtin/revert.c:124
-msgid "keep redundant, empty commits"
-msgstr "retén les comissions redundants i buides"
+#: builtin/symbolic-ref.c:43 builtin/update-ref.c:363
+msgid "reason of the update"
+msgstr "raó de l'actualització"
 
-#: builtin/revert.c:214
-msgid "revert failed"
-msgstr "la reversió ha fallat"
+#: builtin/tag.c:25
+#, fuzzy
+msgid ""
+"git tag [-a | -s | -u <key-id>] [-f] [-m <msg> | -F <file>]\n"
+"\t\t<tagname> [<head>]"
+msgstr ""
+"git tag [-a | -s | -u <id-de-clau>] [-f] [-m <missatge> | -F <fitxer>] <nom-"
+"d'etiqueta> [<cap>]"
 
-#: builtin/revert.c:227
-msgid "cherry-pick failed"
-msgstr "el «cherry pick» ha fallat"
+#: builtin/tag.c:27
+msgid "git tag -d <tagname>..."
+msgstr "git tag -d <nom-d'etiqueta>..."
 
-#: builtin/rm.c:18
-msgid "git rm [<options>] [--] <file>..."
-msgstr "git rm [<opcions>] [--] <fitxer>..."
+#: builtin/tag.c:28
+msgid ""
+"git tag -l [-n[<num>]] [--contains <commit>] [--no-contains <commit>] [--"
+"points-at <object>]\n"
+"\t\t[--format=<format>] [--[no-]merged [<commit>]] [<pattern>...]"
+msgstr ""
+"git tag -l [-n[<nombre>]] [--contains <comissió>] [--no-contains <comissió>] "
+"[--points-at <objecte>]\n"
+"\t\t[--format=<format>] [--[no-]merged [<comissió>]] [<patró>...]"
 
-#: builtin/rm.c:206
+#: builtin/tag.c:30
+msgid "git tag -v [--format=<format>] <tagname>..."
+msgstr "git tag -v [--format=<format>] <nom-d'etiqueta>..."
+
+#: builtin/tag.c:89
+#, c-format
+msgid "tag '%s' not found."
+msgstr "no s'ha trobat l'etiqueta «%s»."
+
+#: builtin/tag.c:105
+#, c-format
+msgid "Deleted tag '%s' (was %s)\n"
+msgstr "S'ha suprimit l'etiqueta «%s» (era %s)\n"
+
+#: builtin/tag.c:135
+#, c-format
 msgid ""
-"the following file has staged content different from both the\n"
-"file and the HEAD:"
-msgid_plural ""
-"the following files have staged content different from both the\n"
-"file and the HEAD:"
-msgstr[0] ""
-"el fitxer següent té contingut «stage» diferent d'ambdós el\n"
-"fitxer i la HEAD:"
-msgstr[1] ""
-"els fitxers següents tenen contingut «stage» diferent d'ambdós\n"
-"el fitxer i la HEAD:"
+"\n"
+"Write a message for tag:\n"
+"  %s\n"
+"Lines starting with '%c' will be ignored.\n"
+msgstr ""
+"\n"
+"Escriviu el missatge de l'etiqueta:\n"
+"  %s\n"
+"Les línies que comencin amb «%c» s'ignoraran.\n"
 
-#: builtin/rm.c:211
+#: builtin/tag.c:139
+#, c-format
 msgid ""
 "\n"
-"(use -f to force removal)"
+"Write a message for tag:\n"
+"  %s\n"
+"Lines starting with '%c' will be kept; you may remove them yourself if you "
+"want to.\n"
 msgstr ""
 "\n"
-"(useu -f per a forçar l'eliminació)"
+"Escriviu el missatge de l'etiqueta:\n"
+"  %s\n"
+"Les línies que comencin amb «%c» es retindran; podeu eliminar-les per vós "
+"mateix si voleu.\n"
 
-#: builtin/rm.c:215
-msgid "the following file has changes staged in the index:"
-msgid_plural "the following files have changes staged in the index:"
-msgstr[0] "el fitxer següent té canvis «staged» en l'índex:"
-msgstr[1] "els fitxers següents tenen canvis «staged» en l'índex:"
+#: builtin/tag.c:198
+msgid "unable to sign the tag"
+msgstr "no s'ha pogut signar l'etiqueta"
 
-#: builtin/rm.c:219 builtin/rm.c:228
+#: builtin/tag.c:200
+msgid "unable to write tag file"
+msgstr "no s'ha pogut escriure el fitxer d'etiqueta"
+
+#: builtin/tag.c:216
+#, c-format
 msgid ""
+"You have created a nested tag. The object referred to by your new tag is\n"
+"already a tag. If you meant to tag the object that it points to, use:\n"
 "\n"
-"(use --cached to keep the file, or -f to force removal)"
+"\tgit tag -f %s %s^{}"
 msgstr ""
-"\n"
-"(useu --cached per a mantenir el fitxer, o -f per a forçar l'eliminació)"
 
-#: builtin/rm.c:225
-msgid "the following file has local modifications:"
-msgid_plural "the following files have local modifications:"
-msgstr[0] "el fitxer següent té modificacions locals:"
-msgstr[1] "els fitxers següents tenen modificacions locals:"
+#: builtin/tag.c:232
+msgid "bad object type."
+msgstr "el tipus d'objecte és incorrecte."
 
-#: builtin/rm.c:243
-msgid "do not list removed files"
-msgstr "no llistis els fitxers eliminats"
+#: builtin/tag.c:284
+msgid "no tag message?"
+msgstr "no hi ha cap missatge d'etiqueta?"
 
-#: builtin/rm.c:244
-msgid "only remove from the index"
-msgstr "només elimina de l'índex"
+#: builtin/tag.c:291
+#, c-format
+msgid "The tag message has been left in %s\n"
+msgstr "S'ha deixat el missatge de l'etiqueta en %s\n"
 
-#: builtin/rm.c:245
-msgid "override the up-to-date check"
-msgstr "passa per alt la comprovació d'actualitat"
+#: builtin/tag.c:402
+msgid "list tag names"
+msgstr "llista els noms d'etiqueta"
 
-#: builtin/rm.c:246
-msgid "allow recursive removal"
-msgstr "permet l'eliminació recursiva"
+#: builtin/tag.c:404
+msgid "print <n> lines of each tag message"
+msgstr "imprimeix <n> línies de cada missatge d'etiqueta"
 
-#: builtin/rm.c:248
-msgid "exit with a zero status even if nothing matched"
-msgstr "surt amb estat zero encara que res hagi coincidit"
+#: builtin/tag.c:406
+msgid "delete tags"
+msgstr "suprimeix les etiquetes"
 
-#: builtin/rm.c:307
-#, c-format
-msgid "not removing '%s' recursively without -r"
-msgstr "no s'està eliminant «%s» recursivament sense -r"
+#: builtin/tag.c:407
+msgid "verify tags"
+msgstr "verifica les etiquetes"
 
-#: builtin/rm.c:346
-#, c-format
-msgid "git rm: unable to remove %s"
-msgstr "git rm: no s'ha pogut eliminar %s"
+#: builtin/tag.c:409
+msgid "Tag creation options"
+msgstr "Opcions de creació d'etiquetes"
 
-#: builtin/rm.c:369
-#, c-format
-msgid "could not remove '%s'"
-msgstr "no s'ha pogut suprimir «%s»"
+#: builtin/tag.c:411
+msgid "annotated tag, needs a message"
+msgstr "etiqueta anotada, necessita un missatge"
 
-#: builtin/send-pack.c:19
-msgid ""
-"git send-pack [--all | --mirror] [--dry-run] [--force] [--receive-pack=<git-"
-"receive-pack>] [--verbose] [--thin] [--atomic] [<host>:]<directory> "
-"[<ref>...]\n"
-"  --all and explicit <ref> specification are mutually exclusive."
-msgstr ""
-"git send-pack [--all | --mirror] [--dry-run] [--force] [--receive-"
-"pack=<paquet-del-git-receive>] [--verbose] [--thin] [--atomic] "
-"[<màquina>:]<directori> [<referència>...]\n"
-"  --all i especificació <referència> explícita són mútuament excloents."
+#: builtin/tag.c:413
+msgid "tag message"
+msgstr "missatge d'etiqueta"
 
-#: builtin/send-pack.c:162
-msgid "remote name"
-msgstr "nom del remot"
+#: builtin/tag.c:415
+msgid "force edit of tag message"
+msgstr "força l'edició del missatge de l'etiqueta"
+
+#: builtin/tag.c:416
+msgid "annotated and GPG-signed tag"
+msgstr "etiqueta anotada i signada per GPG"
+
+#: builtin/tag.c:419
+msgid "use another key to sign the tag"
+msgstr "usa una altra clau per a signar l'etiqueta"
+
+#: builtin/tag.c:420
+msgid "replace the tag if exists"
+msgstr "reemplaça l'etiqueta si existeix"
+
+#: builtin/tag.c:421 builtin/update-ref.c:369
+msgid "create a reflog"
+msgstr "crea un registre de referències"
+
+#: builtin/tag.c:423
+msgid "Tag listing options"
+msgstr "Opcions de llistat d'etiquetes"
+
+#: builtin/tag.c:424
+msgid "show tag list in columns"
+msgstr "mostra la llista d'etiquetes en columnes"
+
+#: builtin/tag.c:425 builtin/tag.c:427
+msgid "print only tags that contain the commit"
+msgstr "imprimeix només les etiquetes que continguin la comissió"
 
-#: builtin/send-pack.c:176
-msgid "use stateless RPC protocol"
-msgstr "usa el protocol RPC sense estat"
+#: builtin/tag.c:426 builtin/tag.c:428
+msgid "print only tags that don't contain the commit"
+msgstr "imprimeix només les etiquetes que no continguin la comissió"
 
-#: builtin/send-pack.c:177
-msgid "read refs from stdin"
-msgstr "llegeix les referències des de stdin"
+#: builtin/tag.c:429
+msgid "print only tags that are merged"
+msgstr "imprimeix només les etiquetes que s'han fusionat"
 
-#: builtin/send-pack.c:178
-msgid "print status from remote helper"
-msgstr "imprimeix l'estat des de l'ajudant remot"
+#: builtin/tag.c:430
+msgid "print only tags that are not merged"
+msgstr "imprimeix només les etiquetes que no s'han fusionat"
 
-#: builtin/shortlog.c:14
-msgid "git shortlog [<options>] [<revision-range>] [[--] [<path>...]]"
-msgstr "git shortlog [<opcions>] [<rang-de-revisions>] [[--] [<camí>...]]"
+#: builtin/tag.c:434
+msgid "print only tags of the object"
+msgstr "imprimeix només les etiquetes de l'objecte"
 
-#: builtin/shortlog.c:263
-msgid "Group by committer rather than author"
-msgstr "Agrupa per «comitter» en comptes de per autor"
+#: builtin/tag.c:482
+msgid "--column and -n are incompatible"
+msgstr "--column i -n són incompatibles"
 
-#: builtin/shortlog.c:265
-msgid "sort output according to the number of commits per author"
-msgstr "ordena la sortida segons el nombre de comissions per autor"
+#: builtin/tag.c:504
+msgid "-n option is only allowed in list mode"
+msgstr "es permet l'opció -n només amb mode llista"
 
-#: builtin/shortlog.c:267
-msgid "Suppress commit descriptions, only provides commit count"
-msgstr ""
-"Omet les descripcions de comissió, només proveeix el recompte de comissions"
+#: builtin/tag.c:506
+msgid "--contains option is only allowed in list mode"
+msgstr "es permet l'opció --contains només amb mode llista"
 
-#: builtin/shortlog.c:269
-msgid "Show the email address of each author"
-msgstr "Mostra l'adreça electrònica de cada autor"
+#: builtin/tag.c:508
+msgid "--no-contains option is only allowed in list mode"
+msgstr "es permet l'opció --no-contains només amb mode llista"
 
-#: builtin/shortlog.c:270
-msgid "w[,i1[,i2]]"
-msgstr "w[,i1[,i2]]"
+#: builtin/tag.c:510
+msgid "--points-at option is only allowed in list mode"
+msgstr "es permet --points-at option només amb mode llista"
 
-#: builtin/shortlog.c:271
-msgid "Linewrap output"
-msgstr "Ajusta les línies de la sortida"
+#: builtin/tag.c:512
+msgid "--merged and --no-merged options are only allowed in list mode"
+msgstr "es permeten les opcions --merged i --no-merged només amb mode llista"
 
-#: builtin/show-branch.c:12
-msgid ""
-"git show-branch [-a | --all] [-r | --remotes] [--topo-order | --date-order]\n"
-"\t\t[--current] [--color[=<when>] | --no-color] [--sparse]\n"
-"\t\t[--more=<n> | --list | --independent | --merge-base]\n"
-"\t\t[--no-name | --sha1-name] [--topics] [(<rev> | <glob>)...]"
-msgstr ""
-"git show-branch [-a | --all] [-r | --remotes] [--topo-order | --date-order]\n"
-"\t\t[--current] [--color[=<quan>] | --no-color] [--sparse]\n"
-"\t\t[--more=<n> | --list | --independent | --merge-base]\n"
-"\t\t[--no-name | --sha1-name] [--topics] [(<revisió> | <glob>)...]"
+#: builtin/tag.c:523
+msgid "only one -F or -m option is allowed."
+msgstr "només es permet una opció -F o -m."
 
-#: builtin/show-branch.c:16
-msgid "git show-branch (-g | --reflog)[=<n>[,<base>]] [--list] [<ref>]"
-msgstr "git show-branch (-g | --reflog)[=<n>[,<base>]] [--list] [<referència>]"
+#: builtin/tag.c:542
+msgid "too many params"
+msgstr "massa paràmetres"
 
-#: builtin/show-branch.c:376
+#: builtin/tag.c:548
 #, c-format
-msgid "ignoring %s; cannot handle more than %d ref"
-msgid_plural "ignoring %s; cannot handle more than %d refs"
-msgstr[0] "s'està ignorant %s; no es pot gestionar més de %d referència"
-msgstr[1] "s'està ignorant %s; no es poden gestionar més de %d referències"
+msgid "'%s' is not a valid tag name."
+msgstr "«%s» no és un nom d'etiqueta vàlid."
 
-#: builtin/show-branch.c:530
+#: builtin/tag.c:553
 #, c-format
-msgid "no matching refs with %s"
-msgstr "no hi ha referències coincidents amb %s"
-
-#: builtin/show-branch.c:626
-msgid "show remote-tracking and local branches"
-msgstr "mostra les branques amb seguiment remot i les locals"
+msgid "tag '%s' already exists"
+msgstr "l'etiqueta «%s» ja existeix"
 
-#: builtin/show-branch.c:628
-msgid "show remote-tracking branches"
-msgstr "mostra les branques amb seguiment remot"
+#: builtin/tag.c:584
+#, c-format
+msgid "Updated tag '%s' (was %s)\n"
+msgstr "Etiqueta «%s» actualitzada (era %s)\n"
 
-#: builtin/show-branch.c:630
-msgid "color '*!+-' corresponding to the branch"
-msgstr "colora '*!+-' corresponent a la branca"
+#: builtin/unpack-objects.c:501
+msgid "Unpacking objects"
+msgstr "S'estan desempaquetant els objectes"
 
-#: builtin/show-branch.c:632
-msgid "show <n> more commits after the common ancestor"
-msgstr "mostra <n> comissions després de l'avantpassat comú"
+#: builtin/update-index.c:84
+#, c-format
+msgid "failed to create directory %s"
+msgstr "s'ha produït un error en crear el directori %s"
 
-#: builtin/show-branch.c:634
-msgid "synonym to more=-1"
-msgstr "sinònim de more=-1"
+#: builtin/update-index.c:100
+#, c-format
+msgid "failed to create file %s"
+msgstr "s'ha produït un error en crear el fitxer %s"
 
-#: builtin/show-branch.c:635
-msgid "suppress naming strings"
-msgstr "omet anomenar cadenes"
+#: builtin/update-index.c:108
+#, c-format
+msgid "failed to delete file %s"
+msgstr "s'ha produït un error en suprimir el fitxer %s"
 
-#: builtin/show-branch.c:637
-msgid "include the current branch"
-msgstr "inclou la branca actual"
+#: builtin/update-index.c:115 builtin/update-index.c:221
+#, c-format
+msgid "failed to delete directory %s"
+msgstr "s'ha produït un error en suprimir el directori %s"
 
-#: builtin/show-branch.c:639
-msgid "name commits with their object names"
-msgstr "anomena les comissions amb els seus noms d'objecte"
+#: builtin/update-index.c:140
+#, c-format
+msgid "Testing mtime in '%s' "
+msgstr "S'està provant mtime en «%s» "
 
-#: builtin/show-branch.c:641
-msgid "show possible merge bases"
-msgstr "mostra les bases de fusió possibles"
+#: builtin/update-index.c:154
+msgid "directory stat info does not change after adding a new file"
+msgstr ""
+"la informació d'stat de directori no canvia després d'afegir un fitxer nou"
 
-#: builtin/show-branch.c:643
-msgid "show refs unreachable from any other ref"
-msgstr "mostra les referències inabastables de qualsevol altra referència"
+#: builtin/update-index.c:167
+msgid "directory stat info does not change after adding a new directory"
+msgstr ""
+"la informació d'stat de directori no canvia després d'afegir un directori nou"
 
-#: builtin/show-branch.c:645
-msgid "show commits in topological order"
-msgstr "mostra les comissions en ordre topològic"
+#: builtin/update-index.c:180
+msgid "directory stat info changes after updating a file"
+msgstr ""
+"la informació d'stat de directori canvia després d'actualitzar un fitxer"
 
-#: builtin/show-branch.c:648
-msgid "show only commits not on the first branch"
-msgstr "mostra només les comissions que no siguin en la primera branca"
+#: builtin/update-index.c:191
+msgid "directory stat info changes after adding a file inside subdirectory"
+msgstr ""
+"la informació d'stat de directori canvia després d'afegir un fitxer dins "
+"d'un subdirectori"
 
-#: builtin/show-branch.c:650
-msgid "show merges reachable from only one tip"
-msgstr "mostra les fusions abastables de només una punta"
+#: builtin/update-index.c:202
+msgid "directory stat info does not change after deleting a file"
+msgstr ""
+"la informació d'stat de directori no canvia després de suprimir un fitxer"
 
-#: builtin/show-branch.c:652
-msgid "topologically sort, maintaining date order where possible"
-msgstr "ordena topològicament, mantenint l'ordre de dates on sigui possible"
+#: builtin/update-index.c:215
+msgid "directory stat info does not change after deleting a directory"
+msgstr ""
+"la informació d'stat de directori no canvia després de suprimir un directori"
 
-#: builtin/show-branch.c:655
-msgid "<n>[,<base>]"
-msgstr "<n>[,<base>]"
+#: builtin/update-index.c:222
+msgid " OK"
+msgstr " D'acord"
 
-#: builtin/show-branch.c:656
-msgid "show <n> most recent ref-log entries starting at base"
-msgstr "mostra les <n> entrades més recents començant a la base"
+#: builtin/update-index.c:591
+msgid "git update-index [<options>] [--] [<file>...]"
+msgstr "git update-index [<opcions>] [--] [<fitxer>...]"
 
-#: builtin/show-branch.c:690
-msgid ""
-"--reflog is incompatible with --all, --remotes, --independent or --merge-base"
+#: builtin/update-index.c:974
+msgid "continue refresh even when index needs update"
 msgstr ""
-"--reflog és incompatible amb --all, --remotes, --independent o --merge-base"
+"continua l'actualització encara que l'índex necessiti una actualització"
 
-#: builtin/show-branch.c:714
-msgid "no branches given, and HEAD is not valid"
-msgstr "no s'ha donat cap branca, i HEAD no és vàlid"
+#: builtin/update-index.c:977
+msgid "refresh: ignore submodules"
+msgstr "actualitza: ignora els submòduls"
 
-#: builtin/show-branch.c:717
-msgid "--reflog option needs one branch name"
-msgstr "l'opció --reflog necessita un nom de branca"
+#: builtin/update-index.c:980
+msgid "do not ignore new files"
+msgstr "no ignoris els fitxers nous"
 
-#: builtin/show-branch.c:720
-#, c-format
-msgid "only %d entry can be shown at one time."
-msgid_plural "only %d entries can be shown at one time."
-msgstr[0] "es pot mostrar només %d entrada a la vegada."
-msgstr[1] "es poden mostrar només %d entrades a la vegada."
+#: builtin/update-index.c:982
+msgid "let files replace directories and vice-versa"
+msgstr "deixa que els fitxers reemplacin els directoris i viceversa"
 
-#: builtin/show-branch.c:724
-#, c-format
-msgid "no such ref %s"
-msgstr "no hi ha tal referència %s"
+#: builtin/update-index.c:984
+msgid "notice files missing from worktree"
+msgstr "tingues en compte els fitxers absents de l'arbre de treball"
 
-#: builtin/show-branch.c:808
-#, c-format
-msgid "cannot handle more than %d rev."
-msgid_plural "cannot handle more than %d revs."
-msgstr[0] "no es pot gestionar més d'%d revisió."
-msgstr[1] "no es poden gestionar més de %d revisions."
+#: builtin/update-index.c:986
+msgid "refresh even if index contains unmerged entries"
+msgstr "actualitza encara que l'índex contingui entrades no fusionades"
 
-#: builtin/show-branch.c:812
-#, c-format
-msgid "'%s' is not a valid ref."
-msgstr "«%s» no és una referència vàlida."
+#: builtin/update-index.c:989
+msgid "refresh stat information"
+msgstr "actualitza la informació d'estadístiques"
 
-#: builtin/show-branch.c:815
-#, c-format
-msgid "cannot find commit %s (%s)"
-msgstr "no es pot trobar la comissió %s (%s)"
+#: builtin/update-index.c:993
+msgid "like --refresh, but ignore assume-unchanged setting"
+msgstr "com --refresh, però ignora el paràmetre assume-unchanged"
 
-#: builtin/show-ref.c:10
-msgid ""
-"git show-ref [-q | --quiet] [--verify] [--head] [-d | --dereference] [-s | --"
-"hash[=<n>]] [--abbrev[=<n>]] [--tags] [--heads] [--] [<pattern>...]"
-msgstr ""
-"git show-ref [-q | --quiet] [--verify] [--head] [-d | --dereference] [-s | --"
-"hash[=<n>]] [--abbrev[=<n>]] [--tags] [--heads] [--] [<patró>...]"
+#: builtin/update-index.c:997
+msgid "<mode>,<object>,<path>"
+msgstr "<mode>,<objecte>,<camí>"
 
-#: builtin/show-ref.c:11
-msgid "git show-ref --exclude-existing[=<pattern>]"
-msgstr "git show-ref --exclude-existing[=<patró>]"
+#: builtin/update-index.c:998
+msgid "add the specified entry to the index"
+msgstr "afegeix l'entrada especificada a l'índex"
 
-#: builtin/show-ref.c:159
-msgid "only show tags (can be combined with heads)"
-msgstr "mostra només les etiquetes (es pot combinar amb heads)"
+#: builtin/update-index.c:1008
+msgid "mark files as \"not changing\""
+msgstr "marca els fitxers com a \"no canviant\""
 
-#: builtin/show-ref.c:160
-msgid "only show heads (can be combined with tags)"
-msgstr "mostra només els caps (es pot combinar amb tags)"
+#: builtin/update-index.c:1011
+msgid "clear assumed-unchanged bit"
+msgstr "neteja el bit assumed-unchanged"
 
-#: builtin/show-ref.c:161
-msgid "stricter reference checking, requires exact ref path"
-msgstr ""
-"comprovació de referència més estricta, requereix el camí de referència "
-"exacte"
+#: builtin/update-index.c:1014
+msgid "mark files as \"index-only\""
+msgstr "marca els fitxers com a \"només índex\""
 
-#: builtin/show-ref.c:164 builtin/show-ref.c:166
-msgid "show the HEAD reference, even if it would be filtered out"
-msgstr "mostra la referència HEAD, encara que es filtrés"
+#: builtin/update-index.c:1017
+msgid "clear skip-worktree bit"
+msgstr "neteja el bit skip-worktree"
 
-#: builtin/show-ref.c:168
-msgid "dereference tags into object IDs"
-msgstr "desreferencia les etiquetes a ID d'objecte"
+#: builtin/update-index.c:1020
+msgid "do not touch index-only entries"
+msgstr ""
 
-#: builtin/show-ref.c:170
-msgid "only show SHA1 hash using <n> digits"
-msgstr "mostra el hash SHA1 usant només <n> xifres"
+#: builtin/update-index.c:1022
+msgid "add to index only; do not add content to object database"
+msgstr ""
+"només afegeix a l'índex; no afegeixis el contingut a la base de dades "
+"d'objectes"
 
-#: builtin/show-ref.c:174
-msgid "do not print results to stdout (useful with --verify)"
-msgstr "no imprimeixis els resultats a stdout (útil amb --verify)"
+#: builtin/update-index.c:1024
+msgid "remove named paths even if present in worktree"
+msgstr ""
+"elimina els camins anomenats encara que estiguin presents en l'arbre de "
+"treball"
 
-#: builtin/show-ref.c:176
-msgid "show refs from stdin that aren't in local repository"
-msgstr "mostra les referències de stdin que no siguin en el dipòsit local"
+#: builtin/update-index.c:1026
+msgid "with --stdin: input lines are terminated by null bytes"
+msgstr "amb --stdin: les línies d'entrada acaben amb octets nuls"
 
-#: builtin/stripspace.c:18
-msgid "git stripspace [-s | --strip-comments]"
-msgstr "git stripspace [-s | --strip-comments]"
+#: builtin/update-index.c:1028
+msgid "read list of paths to be updated from standard input"
+msgstr "llegeix la llista de camins a actualitzar des de l'entrada estàndard"
 
-#: builtin/stripspace.c:19
-msgid "git stripspace [-c | --comment-lines]"
-msgstr "git stripspace [-c | --comment-lines]"
+#: builtin/update-index.c:1032
+msgid "add entries from standard input to the index"
+msgstr "afegeix les entrades de l'entrada estàndard a l'índex"
+
+#: builtin/update-index.c:1036
+msgid "repopulate stages #2 and #3 for the listed paths"
+msgstr "reemplena les «stage» #2 i #3 per als camins llistats"
 
-#: builtin/stripspace.c:36
-msgid "skip and remove all lines starting with comment character"
-msgstr ""
-"omet i elimina totes les línies que comencin amb el caràcter de comentari"
+#: builtin/update-index.c:1040
+msgid "only update entries that differ from HEAD"
+msgstr "només actualitza les entrades que difereixin de HEAD"
 
-#: builtin/stripspace.c:39
-msgid "prepend comment character and space to each line"
-msgstr "anteposa el caràcter de comentari i un espai a cada línia"
+#: builtin/update-index.c:1044
+msgid "ignore files missing from worktree"
+msgstr "ignora els fitxers absents de l'arbre de treball"
 
-#: builtin/submodule--helper.c:35 builtin/submodule--helper.c:1669
-#, c-format
-msgid "No such ref: %s"
-msgstr "No hi ha tal referència: %s"
+#: builtin/update-index.c:1047
+msgid "report actions to standard output"
+msgstr "informa de les accions en la sortida estàndard"
 
-#: builtin/submodule--helper.c:42 builtin/submodule--helper.c:1678
-#, c-format
-msgid "Expecting a full ref name, got %s"
-msgstr "S'espera un nom de referència ple, s'ha rebut %s"
+#: builtin/update-index.c:1049
+msgid "(for porcelains) forget saved unresolved conflicts"
+msgstr "(per a porcellanes) oblida't dels conflictes no resolts ni desats"
 
-#: builtin/submodule--helper.c:59
-msgid "submodule--helper print-default-remote takes no arguments"
-msgstr ""
+#: builtin/update-index.c:1053
+msgid "write index in this format"
+msgstr "escriu l'índex en aquest format"
 
-#: builtin/submodule--helper.c:96
-#, c-format
-msgid "cannot strip one component off url '%s'"
-msgstr "no es pot despullar un component de l'url «%s»"
+#: builtin/update-index.c:1055
+msgid "enable or disable split index"
+msgstr "habilita o inhabilita l'índex dividit"
 
-#: builtin/submodule--helper.c:404 builtin/submodule--helper.c:1198
-msgid "alternative anchor for relative paths"
-msgstr "àncora alternativa per als camins relatius"
+#: builtin/update-index.c:1057
+msgid "enable/disable untracked cache"
+msgstr "habilita/inhabilita la memòria cau no seguida"
 
-#: builtin/submodule--helper.c:409
-msgid "git submodule--helper list [--prefix=<path>] [<path>...]"
-msgstr "git submodule--helper list [--prefix=<camí>] [<camí>...]"
+#: builtin/update-index.c:1059
+msgid "test if the filesystem supports untracked cache"
+msgstr "prova si el sistema de fitxers admet la memòria cau no seguida"
 
-#: builtin/submodule--helper.c:460 builtin/submodule--helper.c:483
-#, c-format
-msgid "No url found for submodule path '%s' in .gitmodules"
-msgstr "No s'ha trobat cap url per al camí de submòdul «%s» a .gitmodules"
+#: builtin/update-index.c:1061
+msgid "enable untracked cache without testing the filesystem"
+msgstr "habilita la memòria cau no seguida sense provar el sistema de fitxers"
 
-#: builtin/submodule--helper.c:498
-#, c-format
-msgid ""
-"could not lookup configuration '%s'. Assuming this repository is its own "
-"authoritative upstream."
+#: builtin/update-index.c:1063
+msgid "write out the index even if is not flagged as changed"
 msgstr ""
-"no s'ha pogut trobar la configuració «%s». S'assumeix que aquest dipòsit és "
-"el seu dipòsit font autoritzat."
 
-#: builtin/submodule--helper.c:509
-#, c-format
-msgid "Failed to register url for submodule path '%s'"
-msgstr "S'ha produït un error en registrar l'url per al camí de submòdul «%s»"
+#: builtin/update-index.c:1065
+msgid "enable or disable file system monitor"
+msgstr "habilita o inhabilita el monitor del sistema de fitxers"
 
-#: builtin/submodule--helper.c:513
-#, c-format
-msgid "Submodule '%s' (%s) registered for path '%s'\n"
-msgstr "S'ha registrat el submòdul «%s» (%s) per al camí «%s»\n"
+#: builtin/update-index.c:1067
+msgid "mark files as fsmonitor valid"
+msgstr "marca els fitxers com a vàlids pel fsmonitor"
 
-#: builtin/submodule--helper.c:523
-#, c-format
-msgid "warning: command update mode suggested for submodule '%s'\n"
+#: builtin/update-index.c:1070
+msgid "clear fsmonitor valid bit"
+msgstr "neteja el bit de validesa del fsmonitor"
+
+#: builtin/update-index.c:1173
+msgid ""
+"core.splitIndex is set to false; remove or change it, if you really want to "
+"enable split index"
 msgstr ""
-"advertència: se suggereix el mode d'actualització per ordre per al submòdul "
-"«%s»\n"
+"core.splitIndex està establert a fals; elimineu-lo o canviar-lo, si realment "
+"voleu habilitar l'índex dividit"
 
-#: builtin/submodule--helper.c:530
-#, c-format
-msgid "Failed to register update mode for submodule path '%s'"
+#: builtin/update-index.c:1182
+msgid ""
+"core.splitIndex is set to true; remove or change it, if you really want to "
+"disable split index"
 msgstr ""
-"S'ha produït un error en registrar el mode d'actualització per al camí de "
-"submòdul «%s»"
+"core.splitIndex està establert a cert; elimineu-lo o canvieu-lo, si realment "
+"voleu inhabilitar l'índex dividit"
 
-#: builtin/submodule--helper.c:552
-msgid "Suppress output for initializing a submodule"
-msgstr "Omet la sortida d'inicialitzar un submòdul"
+#: builtin/update-index.c:1194
+msgid ""
+"core.untrackedCache is set to true; remove or change it, if you really want "
+"to disable the untracked cache"
+msgstr ""
+"core.untrackedCache està establert a cert; elimineu-lo o canvieu-lo, si "
+"realment voleu inhabilitar el cau no seguit"
 
-#: builtin/submodule--helper.c:557
-msgid "git submodule--helper init [<path>]"
-msgstr "git submodule--helper init [<camí>]"
+#: builtin/update-index.c:1198
+msgid "Untracked cache disabled"
+msgstr "La memòria cau no seguida està inhabilitada"
 
-#: builtin/submodule--helper.c:625 builtin/submodule--helper.c:747
-#, c-format
-msgid "no submodule mapping found in .gitmodules for path '%s'"
-msgstr "No s'ha trobat cap mapatge de submòdul a .gitmodules per al camí «%s»"
+#: builtin/update-index.c:1206
+msgid ""
+"core.untrackedCache is set to false; remove or change it, if you really want "
+"to enable the untracked cache"
+msgstr ""
+"core.untrackedCache està establert a fals; elimineu-lo o canviar-lo, si "
+"realment voleu habilitar el cau no seguit"
 
-#: builtin/submodule--helper.c:660
+#: builtin/update-index.c:1210
 #, c-format
-msgid "could not resolve HEAD ref inside the submodule '%s'"
-msgstr "no s'ha pogut resoldre la referència a HEAD dins del submòdul «%s»"
+msgid "Untracked cache enabled for '%s'"
+msgstr "La memòria cau no seguida està habilitada per a «%s»"
 
-#: builtin/submodule--helper.c:687 builtin/submodule--helper.c:856
-#, c-format
-msgid "failed to recurse into submodule '%s'"
-msgstr "s'ha produït un error en cercar recursivament al submòdul «%s»"
+#: builtin/update-index.c:1218
+msgid "core.fsmonitor is unset; set it if you really want to enable fsmonitor"
+msgstr ""
+"core.fsmonitor està establert a fals; establiu-lo a cert si realment voleu "
+"habilitar fsmonitor"
 
-#: builtin/submodule--helper.c:711 builtin/submodule--helper.c:1021
-msgid "Suppress submodule status output"
-msgstr "Suprimeix la sortida de l'estat del submòdul"
+#: builtin/update-index.c:1222
+msgid "fsmonitor enabled"
+msgstr "fsmonitor habilitat"
 
-#: builtin/submodule--helper.c:712
+#: builtin/update-index.c:1225
 msgid ""
-"Use commit stored in the index instead of the one stored in the submodule "
-"HEAD"
+"core.fsmonitor is set; remove it if you really want to disable fsmonitor"
 msgstr ""
+"core.fsmonitor està establert a cert; elimineu-lo si realment voleu "
+"inhabilitar fsmonitor"
 
-#: builtin/submodule--helper.c:713
-msgid "recurse into nested submodules"
-msgstr "inclou recursivament els submòduls imbrincats"
+#: builtin/update-index.c:1229
+msgid "fsmonitor disabled"
+msgstr "fsmonitor inhabilitat"
 
-#: builtin/submodule--helper.c:718
-msgid "git submodule status [--quiet] [--cached] [--recursive] [<path>...]"
-msgstr "git submodule status [--quiet] [--cached] [--recursive] [<camí>...]"
+#: builtin/update-ref.c:10
+msgid "git update-ref [<options>] -d <refname> [<old-val>]"
+msgstr "git update-ref [<opcions>] -d <nom-de-referència> [<valor-antic>]"
 
-#: builtin/submodule--helper.c:742
-msgid "git submodule--helper name <path>"
-msgstr "git submodule--helper name <camí>"
+#: builtin/update-ref.c:11
+msgid "git update-ref [<options>]    <refname> <new-val> [<old-val>]"
+msgstr ""
+"git update-ref [<opcions>]    <nom-de-referència> <valor-nou> [<valor-antic>]"
 
-#: builtin/submodule--helper.c:806
-#, c-format
-msgid "Synchronizing submodule url for '%s'\n"
-msgstr "S'està sincronitzant l'url del submòdul per a «%s»\n"
+#: builtin/update-ref.c:12
+msgid "git update-ref [<options>] --stdin [-z]"
+msgstr "git update-ref [<opcions>] --stdin [-z]"
 
-#: builtin/submodule--helper.c:812
-#, c-format
-msgid "failed to register url for submodule path '%s'"
-msgstr "s'ha produït un error en registrar l'url per al camí del submòdul «%s»"
+#: builtin/update-ref.c:364
+msgid "delete the reference"
+msgstr "suprimeix la referència"
 
-#: builtin/submodule--helper.c:826
-#, c-format
-msgid "failed to get the default remote for submodule '%s'"
-msgstr ""
-"s'ha produït un error en obtenir el remot per defecte pel submòdul «%s»"
+#: builtin/update-ref.c:366
+msgid "update <refname> not the one it points to"
+msgstr "actualitza <nom de referència>, no la que apunti"
 
-#: builtin/submodule--helper.c:837
-#, c-format
-msgid "failed to update remote for submodule '%s'"
-msgstr "s'ha produït un error en actualitzar el remot pel submòdul «%s»"
+#: builtin/update-ref.c:367
+msgid "stdin has NUL-terminated arguments"
+msgstr "stdin té paràmetres acabats amb NUL"
 
-#: builtin/submodule--helper.c:885
-msgid "Suppress output of synchronizing submodule url"
-msgstr "Omet la sortida de la sincronització de l'url del submòdul"
+#: builtin/update-ref.c:368
+msgid "read updates from stdin"
+msgstr "llegeix les actualitzacions des de stdin"
 
-#: builtin/submodule--helper.c:887
-msgid "Recurse into nested submodules"
-msgstr "Inclou recursivament els submòduls imbrincats"
+#: builtin/update-server-info.c:7
+msgid "git update-server-info [--force]"
+msgstr "git update-server-info [--force]"
 
-#: builtin/submodule--helper.c:892
-msgid "git submodule--helper sync [--quiet] [--recursive] [<path>]"
-msgstr "git submodule--helper sync [--quiet] [--recursive] [<camí>]"
+#: builtin/update-server-info.c:15
+msgid "update the info files from scratch"
+msgstr "actualitza els fitxers d'informació des de zero"
 
-#: builtin/submodule--helper.c:946
-#, c-format
-msgid ""
-"Submodule work tree '%s' contains a .git directory (use 'rm -rf' if you "
-"really want to remove it including all of its history)"
-msgstr ""
-"L'arbre de treball de submòdul «%s» conté un directori .git\n"
-"(useu 'rm -rf' si realment voleu eliminar-lo, incloent tota la seva història)"
+#: builtin/upload-pack.c:11
+msgid "git upload-pack [<options>] <dir>"
+msgstr "git upload-pack [<opcions>] <directori>"
 
-#: builtin/submodule--helper.c:958
-#, c-format
-msgid ""
-"Submodule work tree '%s' contains local modifications; use '-f' to discard "
-"them"
-msgstr ""
-"L'arbre de treball del submòdul «%s» conté modificacions locals; useu '-f' "
-"per a descartar-les"
+#: builtin/upload-pack.c:23 t/helper/test-serve-v2.c:17
+msgid "quit after a single request/response exchange"
+msgstr "surt després d'un sol intercanvi de sol·licitud/resposta"
 
-#: builtin/submodule--helper.c:966
-#, c-format
-msgid "Cleared directory '%s'\n"
-msgstr "S'ha netejat el directori «%s»\n"
+#: builtin/upload-pack.c:25
+msgid "exit immediately after initial ref advertisement"
+msgstr "surt immediatament després de l'anunci inicial de referència"
 
-#: builtin/submodule--helper.c:968
-#, c-format
-msgid "Could not remove submodule work tree '%s'\n"
-msgstr "No s'ha pogut eliminar l'arbre de treball de submòdul «%s»\n"
+#: builtin/upload-pack.c:27
+msgid "do not try <directory>/.git/ if <directory> is no Git directory"
+msgstr ""
+"no intentis <directori>/.git/ si <directori> no és cap directori del Git"
 
-#: builtin/submodule--helper.c:977
-#, c-format
-msgid "could not create empty submodule directory %s"
-msgstr "no s'ha pogut crear el directori de submòdul buit %s"
+#: builtin/upload-pack.c:29
+msgid "interrupt transfer after <n> seconds of inactivity"
+msgstr "interromp la transferència després de <n> segons d'inactivitat"
 
-#: builtin/submodule--helper.c:993
-#, c-format
-msgid "Submodule '%s' (%s) unregistered for path '%s'\n"
-msgstr "S'ha desregistrat el submòdul «%s» (%s) per al camí «%s»\n"
+#: builtin/verify-commit.c:19
+msgid "git verify-commit [-v | --verbose] <commit>..."
+msgstr "git verify-commit [-v | --verbose] <comissió>..."
 
-#: builtin/submodule--helper.c:1022
-msgid "Remove submodule working trees even if they contain local changes"
-msgstr ""
-"Suprimeix els arbres de treball dels submòduls fins i tot si contenen canvis "
-"locals"
+#: builtin/verify-commit.c:68
+msgid "print commit contents"
+msgstr "imprimeix els continguts de la comissió"
 
-#: builtin/submodule--helper.c:1023
-msgid "Unregister all submodules"
-msgstr "Desregistra recursivament tots els submòduls"
+#: builtin/verify-commit.c:69 builtin/verify-tag.c:37
+msgid "print raw gpg status output"
+msgstr "imprimeix la sortida crua de l'estat gpg"
 
-#: builtin/submodule--helper.c:1028
-msgid ""
-"git submodule deinit [--quiet] [-f | --force] [--all | [--] [<path>...]]"
-msgstr ""
-"git submodule deinit [--quiet] [-f | --force] [--all | [--] [<camí>...]]"
+#: builtin/verify-pack.c:55
+msgid "git verify-pack [-v | --verbose] [-s | --stat-only] <pack>..."
+msgstr "git verify-pack [-v | --verbose] [-s | --stat-only] <paquet>..."
 
-#: builtin/submodule--helper.c:1042
-msgid "Use '--all' if you really want to deinitialize all submodules"
-msgstr "Useu '--all' si realment voleu desinicialitzar tots els submòduls"
+#: builtin/verify-pack.c:65
+msgid "verbose"
+msgstr "detallat"
 
-#: builtin/submodule--helper.c:1133 builtin/submodule--helper.c:1136
-#, c-format
-msgid "submodule '%s' cannot add alternate: %s"
-msgstr "el submòdul «%s» no pot afegir un alternatiu: %s"
+#: builtin/verify-pack.c:67
+msgid "show statistics only"
+msgstr "mostra només estadístiques"
 
-#: builtin/submodule--helper.c:1172
-#, c-format
-msgid "Value '%s' for submodule.alternateErrorStrategy is not recognized"
-msgstr "No es reconeix el valor «%s» per a submodule.alternateErrorStrategy"
+#: builtin/verify-tag.c:18
+msgid "git verify-tag [-v | --verbose] [--format=<format>] <tag>..."
+msgstr "git verify-tag [-v | --verbose] [--format=<format>] <etiqueta>..."
 
-#: builtin/submodule--helper.c:1179
-#, c-format
-msgid "Value '%s' for submodule.alternateLocation is not recognized"
-msgstr "No es reconeix el valor «%s» per a submodule.alternateLocation"
+#: builtin/verify-tag.c:36
+msgid "print tag contents"
+msgstr "imprimeix els continguts de l'etiqueta"
 
-#: builtin/submodule--helper.c:1201
-msgid "where the new submodule will be cloned to"
-msgstr "a on es clonarà el submòdul nou"
+#: builtin/worktree.c:17
+msgid "git worktree add [<options>] <path> [<commit-ish>]"
+msgstr "git worktree add [<opcions>] <camí> [<commit-ish>"
+
+#: builtin/worktree.c:18
+msgid "git worktree list [<options>]"
+msgstr "git worktree list [<opcions>]"
 
-#: builtin/submodule--helper.c:1204
-msgid "name of the new submodule"
-msgstr "nom del submòdul nou"
+#: builtin/worktree.c:19
+msgid "git worktree lock [<options>] <path>"
+msgstr "git worktree lock [<opcions>] <camí>"
 
-#: builtin/submodule--helper.c:1207
-msgid "url where to clone the submodule from"
-msgstr "url del qual clonar el submòdul"
+#: builtin/worktree.c:20
+msgid "git worktree move <worktree> <new-path>"
+msgstr "git worktree move <arbre de treball> <camí-nou>"
 
-#: builtin/submodule--helper.c:1213
-msgid "depth for shallow clones"
-msgstr "profunditat dels clons superficials"
+#: builtin/worktree.c:21
+msgid "git worktree prune [<options>]"
+msgstr "git worktree prune [<opcions>]"
 
-#: builtin/submodule--helper.c:1216 builtin/submodule--helper.c:1587
-msgid "force cloning progress"
-msgstr "força el progrés del clonatge"
+#: builtin/worktree.c:22
+msgid "git worktree remove [<options>] <worktree>"
+msgstr "git worktree lock [<opcions>] <arbre de treball>"
 
-#: builtin/submodule--helper.c:1221
-msgid ""
-"git submodule--helper clone [--prefix=<path>] [--quiet] [--reference "
-"<repository>] [--name <name>] [--depth <depth>] --url <url> --path <path>"
-msgstr ""
-"git submodule--helper clone [--prefix=<camí>] [--quiet] [--reference "
-"<dipòsit>] [--name <nom>] [--depth <profunditat>] --url <url> --path <camí>"
+#: builtin/worktree.c:23
+msgid "git worktree unlock <path>"
+msgstr "git worktree unlock <camí>"
 
-#: builtin/submodule--helper.c:1252
+#: builtin/worktree.c:60 builtin/worktree.c:898
 #, c-format
-msgid "clone of '%s' into submodule path '%s' failed"
-msgstr "el clonatge de «%s» al camí de submòdul «%s» ha fallat"
+msgid "failed to delete '%s'"
+msgstr "s'ha produït un error en suprimir «%s»"
 
-#: builtin/submodule--helper.c:1267
+#: builtin/worktree.c:79
 #, c-format
-msgid "could not get submodule directory for '%s'"
-msgstr "no s'ha pogut obtenir el directori de submòdul per a «%s»"
+msgid "Removing worktrees/%s: not a valid directory"
+msgstr "Eliminació de worktrees/%s: no és un directori vàlid"
 
-#: builtin/submodule--helper.c:1332
+#: builtin/worktree.c:85
 #, c-format
-msgid "Submodule path '%s' not initialized"
-msgstr "El camí de submòdul «%s» no està inicialitzat"
-
-#: builtin/submodule--helper.c:1336
-msgid "Maybe you want to use 'update --init'?"
-msgstr "Potser voleu usar 'update --init'?"
+msgid "Removing worktrees/%s: gitdir file does not exist"
+msgstr "Eliminació de worktrees/%s: el fitxer gitdir no existeix"
 
-#: builtin/submodule--helper.c:1365
+#: builtin/worktree.c:90 builtin/worktree.c:99
 #, c-format
-msgid "Skipping unmerged submodule %s"
-msgstr "S'està ometent el submòdul no fusionat %s"
+msgid "Removing worktrees/%s: unable to read gitdir file (%s)"
+msgstr "Eliminació de worktrees/%s: no s'ha pogut llegir el fitxer gitdir (%s)"
 
-#: builtin/submodule--helper.c:1394
+#: builtin/worktree.c:109
 #, c-format
-msgid "Skipping submodule '%s'"
-msgstr "S'està ometent el submòdul «%s»"
+msgid ""
+"Removing worktrees/%s: short read (expected %<PRIuMAX> bytes, read "
+"%<PRIuMAX>)"
+msgstr ""
+"S'estan suprimint els arbres de treball/%s: lectura curta (s'esperaven "
+"%<PRIuMAX> bytes, llegits %<PRIuMAX>)"
 
-#: builtin/submodule--helper.c:1527
+#: builtin/worktree.c:117
 #, c-format
-msgid "Failed to clone '%s'. Retry scheduled"
-msgstr "S'ha produït un error en clonar «%s». S'ha programat un reintent"
+msgid "Removing worktrees/%s: invalid gitdir file"
+msgstr "Eliminació de worktrees/%s: fitxer gitdir no vàlid"
 
-#: builtin/submodule--helper.c:1538
+#: builtin/worktree.c:126
 #, c-format
-msgid "Failed to clone '%s' a second time, aborting"
-msgstr "S'ha produït un error per segon cop en clonar «%s», s'està avortant"
-
-#: builtin/submodule--helper.c:1568 builtin/submodule--helper.c:1788
-msgid "path into the working tree"
-msgstr "camí a l'arbre de treball"
-
-#: builtin/submodule--helper.c:1571
-msgid "path into the working tree, across nested submodule boundaries"
-msgstr "camí a l'arbre de treball, a través de fronteres de submòduls niats"
-
-#: builtin/submodule--helper.c:1575
-msgid "rebase, merge, checkout or none"
-msgstr "rebase, merge, checkout o none"
-
-#: builtin/submodule--helper.c:1579
-msgid "Create a shallow clone truncated to the specified number of revisions"
-msgstr "Crea un clon superficial truncat al nombre de revisions especificat"
+msgid "Removing worktrees/%s: gitdir file points to non-existent location"
+msgstr ""
+"Eliminació de worktrees/%s: el fitxer gitdir es refereix a una ubicació no "
+"existent"
 
-#: builtin/submodule--helper.c:1582
-msgid "parallel jobs"
-msgstr "tasques paral·leles"
+#: builtin/worktree.c:165
+msgid "report pruned working trees"
+msgstr "informa dels arbres de treball podats"
 
-#: builtin/submodule--helper.c:1584
-msgid "whether the initial clone should follow the shallow recommendation"
-msgstr "si el clonatge inicial ha de seguir la recomanació de superficialitat"
+#: builtin/worktree.c:167
+msgid "expire working trees older than <time>"
+msgstr "fes caducar els arbres de treball més vells que <hora>"
 
-#: builtin/submodule--helper.c:1585
-msgid "don't print cloning progress"
-msgstr "no imprimeixis el progrés del clonatge"
+#: builtin/worktree.c:234
+#, c-format
+msgid "'%s' already exists"
+msgstr "«%s» ja existeix"
 
-#: builtin/submodule--helper.c:1592
-msgid "git submodule--helper update_clone [--prefix=<path>] [<path>...]"
-msgstr "git submodule--helper update_clone [--prefix=<camí>] [<camí>...]"
+#: builtin/worktree.c:251
+#, c-format
+msgid "unable to re-add worktree '%s'"
+msgstr "no s'ha pogut tornar a afegir a l'arbre de treball «%s»"
 
-#: builtin/submodule--helper.c:1605
-msgid "bad value for update parameter"
-msgstr "valor incorrecte per al paràmetre update"
+#: builtin/worktree.c:256
+#, c-format
+msgid ""
+"'%s' is a missing but locked worktree;\n"
+"use 'add -f -f' to override, or 'unlock' and 'prune' or 'remove' to clear"
+msgstr ""
 
-#: builtin/submodule--helper.c:1673
+#: builtin/worktree.c:258
 #, c-format
 msgid ""
-"Submodule (%s) branch configured to inherit branch from superproject, but "
-"the superproject is not on any branch"
+"'%s' is a missing but already registered worktree;\n"
+"use 'add -f' to override, or 'prune' or 'remove' to clear"
 msgstr ""
-"La branca de submòdul (%s) està configurada per a heretar la branca del "
-"superprojecte, però el superprojecte no és en cap branca"
 
-#: builtin/submodule--helper.c:1789
-msgid "recurse into submodules"
-msgstr "inclou recursivament als submòduls"
+#: builtin/worktree.c:308
+#, c-format
+msgid "could not create directory of '%s'"
+msgstr "no s'ha pogut crear directori de «%s»"
 
-#: builtin/submodule--helper.c:1795
-msgid "git submodule--helper embed-git-dir [<path>...]"
-msgstr "git submodule--helper embed-git-dir [<camí>...]"
+#: builtin/worktree.c:439 builtin/worktree.c:445
+#, c-format
+msgid "Preparing worktree (new branch '%s')"
+msgstr "S'està preparant l'arbre de treball (branca nova «%s»)"
 
-#: builtin/submodule--helper.c:1857
+#: builtin/worktree.c:441
 #, c-format
-msgid "%s doesn't support --super-prefix"
-msgstr "%s no admet --super-prefix"
+msgid "Preparing worktree (resetting branch '%s'; was at %s)"
+msgstr ""
 
-#: builtin/submodule--helper.c:1863
+#: builtin/worktree.c:450
 #, c-format
-msgid "'%s' is not a valid submodule--helper subcommand"
-msgstr "«%s» no és una subordre vàlida de submodule--helper"
+msgid "Preparing worktree (checking out '%s')"
+msgstr "S'està preparant l'arbre de treball (s'està agafant «%s»)"
 
-#: builtin/symbolic-ref.c:8
-msgid "git symbolic-ref [<options>] <name> [<ref>]"
-msgstr "git symbolic-ref [<opcions>] <nom> [<referència>]"
+#: builtin/worktree.c:456
+#, c-format
+msgid "Preparing worktree (detached HEAD %s)"
+msgstr "S'està preparant l'arbre de treball (HEAD %s separat)"
 
-#: builtin/symbolic-ref.c:9
-msgid "git symbolic-ref -d [-q] <name>"
-msgstr "git symbolic-ref -d [-q] <nom>"
+#: builtin/worktree.c:497
+msgid "checkout <branch> even if already checked out in other worktree"
+msgstr "agafa <branca> encara que sigui agafada en altre arbre de treball"
 
-#: builtin/symbolic-ref.c:40
-msgid "suppress error message for non-symbolic (detached) refs"
-msgstr "omet el missatge d'error de referències no simbòliques (separades)"
+#: builtin/worktree.c:500
+msgid "create a new branch"
+msgstr "crea una branca nova"
 
-#: builtin/symbolic-ref.c:41
-msgid "delete symbolic ref"
-msgstr "suprimeix la referència simbòlica"
+#: builtin/worktree.c:502
+msgid "create or reset a branch"
+msgstr "crea o restableix una branca"
 
-#: builtin/symbolic-ref.c:42
-msgid "shorten ref output"
-msgstr "escurça la sortida de referències"
+#: builtin/worktree.c:504
+msgid "populate the new working tree"
+msgstr "emplena l'arbre de treball nou"
 
-#: builtin/symbolic-ref.c:43 builtin/update-ref.c:362
-msgid "reason"
-msgstr "raó"
+#: builtin/worktree.c:505
+msgid "keep the new working tree locked"
+msgstr "mantén l'arbre de treball nou bloquejat"
 
-#: builtin/symbolic-ref.c:43 builtin/update-ref.c:362
-msgid "reason of the update"
-msgstr "raó de l'actualització"
+#: builtin/worktree.c:508
+msgid "set up tracking mode (see git-branch(1))"
+msgstr "configura el mode de seguiment (vegeu git-branch(1))"
 
-#: builtin/tag.c:24
-msgid ""
-"git tag [-a | -s | -u <key-id>] [-f] [-m <msg> | -F <file>] <tagname> "
-"[<head>]"
+#: builtin/worktree.c:511
+msgid "try to match the new branch name with a remote-tracking branch"
 msgstr ""
-"git tag [-a | -s | -u <id-de-clau>] [-f] [-m <missatge> | -F <fitxer>] <nom-"
-"d'etiqueta> [<cap>]"
+"prova de fer coincidir el nom de la branca nova amb una branca amb seguiment "
+"remot"
 
-#: builtin/tag.c:25
-msgid "git tag -d <tagname>..."
-msgstr "git tag -d <nom-d'etiqueta>..."
+#: builtin/worktree.c:519
+msgid "-b, -B, and --detach are mutually exclusive"
+msgstr "-b, -B i --detach són mútuament excloents"
 
-#: builtin/tag.c:26
-msgid ""
-"git tag -l [-n[<num>]] [--contains <commit>] [--no-contains <commit>] [--"
-"points-at <object>]\n"
-"\t\t[--format=<format>] [--[no-]merged [<commit>]] [<pattern>...]"
-msgstr ""
-"git tag -l [-n[<nombre>]] [--contains <comissió>] [--no-contains <comissió>] "
-"[--points-at <objecte>]\n"
-"\t\t[--format=<format>] [--[no-]merged [<comissió>]] [<patró>...]"
+#: builtin/worktree.c:580
+msgid "--[no-]track can only be used if a new branch is created"
+msgstr "--[no-]track només es pot usar si es crea una branca nova"
 
-#: builtin/tag.c:28
-msgid "git tag -v [--format=<format>] <tagname>..."
-msgstr "git tag -v [--format=<format>] <nom-d'etiqueta>..."
+#: builtin/worktree.c:680
+msgid "reason for locking"
+msgstr "raó per bloquejar"
 
-#: builtin/tag.c:86
+#: builtin/worktree.c:692 builtin/worktree.c:725 builtin/worktree.c:799
+#: builtin/worktree.c:926
 #, c-format
-msgid "tag '%s' not found."
-msgstr "no s'ha trobat l'etiqueta «%s»."
+msgid "'%s' is not a working tree"
+msgstr "«%s» no és un arbre de treball"
 
-#: builtin/tag.c:102
+#: builtin/worktree.c:694 builtin/worktree.c:727
+msgid "The main working tree cannot be locked or unlocked"
+msgstr "No es pot bloquejar ni desbloquejar l'arbre de treball principal"
+
+#: builtin/worktree.c:699
 #, c-format
-msgid "Deleted tag '%s' (was %s)\n"
-msgstr "S'ha suprimit l'etiqueta «%s» (era %s)\n"
+msgid "'%s' is already locked, reason: %s"
+msgstr "«%s» ja està bloquejat, raó: «%s»"
 
-#: builtin/tag.c:131
+#: builtin/worktree.c:701
 #, c-format
-msgid ""
-"\n"
-"Write a message for tag:\n"
-"  %s\n"
-"Lines starting with '%c' will be ignored.\n"
-msgstr ""
-"\n"
-"Escriviu el missatge de l'etiqueta:\n"
-"  %s\n"
-"Les línies que comencin amb '%c' s'ignoraran.\n"
+msgid "'%s' is already locked"
+msgstr "«%s» ja està bloquejat"
 
-#: builtin/tag.c:135
+#: builtin/worktree.c:729
 #, c-format
-msgid ""
-"\n"
-"Write a message for tag:\n"
-"  %s\n"
-"Lines starting with '%c' will be kept; you may remove them yourself if you "
-"want to.\n"
-msgstr ""
-"\n"
-"Escriviu el missatge de l'etiqueta:\n"
-"  %s\n"
-"Les línies que comencin amb '%c' es retindran; podeu eliminar-les per vós "
-"mateix si voleu.\n"
+msgid "'%s' is not locked"
+msgstr "«%s» no està bloquejat"
 
-#: builtin/tag.c:189
-msgid "unable to sign the tag"
-msgstr "no s'ha pogut signar l'etiqueta"
+#: builtin/worktree.c:770
+msgid "working trees containing submodules cannot be moved or removed"
+msgstr "els arbres de treball que content submòduls no es poden moure o suprimir"
 
-#: builtin/tag.c:191
-msgid "unable to write tag file"
-msgstr "no s'ha pogut escriure el fitxer d'etiqueta"
+#: builtin/worktree.c:778
+msgid "force move even if worktree is dirty or locked"
+msgstr "força el moviment encara que l'arbre de treball estigui brut o bloquejat"
 
-#: builtin/tag.c:216
-msgid "bad object type."
-msgstr "el tipus d'objecte és incorrecte."
+#: builtin/worktree.c:801 builtin/worktree.c:928
+#, c-format
+msgid "'%s' is a main working tree"
+msgstr "«%s» és un arbre de treball principal"
 
-#: builtin/tag.c:265
-msgid "no tag message?"
-msgstr "no hi ha cap missatge d'etiqueta?"
+#: builtin/worktree.c:806
+#, c-format
+msgid "could not figure out destination name from '%s'"
+msgstr "no s'ha pogut deduir el nom de destí des de «%s»"
 
-#: builtin/tag.c:272
+#: builtin/worktree.c:812
 #, c-format
-msgid "The tag message has been left in %s\n"
-msgstr "S'ha deixat el missatge de l'etiqueta en %s\n"
+msgid "target '%s' already exists"
+msgstr "el destí «%s» ja existeix"
 
-#: builtin/tag.c:381
-msgid "list tag names"
-msgstr "llista els noms d'etiqueta"
+#: builtin/worktree.c:820
+#, fuzzy, c-format
+msgid ""
+"cannot move a locked working tree, lock reason: %s\n"
+"use 'move -f -f' to override or unlock first"
+msgstr "No es poden eliminar els canvis de l'arbre de treball"
 
-#: builtin/tag.c:383
-msgid "print <n> lines of each tag message"
-msgstr "imprimeix <n> línies de cada missatge d'etiqueta"
+#: builtin/worktree.c:822
+#, fuzzy
+msgid ""
+"cannot move a locked working tree;\n"
+"use 'move -f -f' to override or unlock first"
+msgstr "No es poden eliminar els canvis de l'arbre de treball"
 
-#: builtin/tag.c:385
-msgid "delete tags"
-msgstr "suprimeix les etiquetes"
+#: builtin/worktree.c:825
+#, c-format
+msgid "validation failed, cannot move working tree: %s"
+msgstr "la validació ha fallat, no es pot moure l'arbre de treball: %s"
 
-#: builtin/tag.c:386
-msgid "verify tags"
-msgstr "verifica les etiquetes"
+#: builtin/worktree.c:830
+#, c-format
+msgid "failed to move '%s' to '%s'"
+msgstr "s'ha produït un error en moure «%s» a «%s»"
 
-#: builtin/tag.c:388
-msgid "Tag creation options"
-msgstr "Opcions de creació d'etiquetes"
+#: builtin/worktree.c:878
+#, c-format
+msgid "failed to run 'git status' on '%s'"
+msgstr "no s'ha pogut executar «git status» a «%s»"
 
-#: builtin/tag.c:390
-msgid "annotated tag, needs a message"
-msgstr "etiqueta anotada, necessita un missatge"
+#: builtin/worktree.c:882
+#, c-format
+msgid "'%s' contains modified or untracked files, use --force to delete it"
+msgstr ""
 
-#: builtin/tag.c:392
-msgid "tag message"
-msgstr "missatge d'etiqueta"
+#: builtin/worktree.c:887
+#, c-format
+msgid "failed to run 'git status' on '%s', code %d"
+msgstr "no s'ha pogut executar «git status» a «%s», codi %d"
 
-#: builtin/tag.c:394
-msgid "force edit of tag message"
-msgstr "força l'edició del missatge de l'etiqueta"
+#: builtin/worktree.c:910
+msgid "force removal even if worktree is dirty or locked"
+msgstr "força la supressió encara que l'arbre de treball estigui brut o bloquejat"
 
-#: builtin/tag.c:395
-msgid "annotated and GPG-signed tag"
-msgstr "etiqueta anotada i signada per GPG"
+#: builtin/worktree.c:933
+#, fuzzy, c-format
+msgid ""
+"cannot remove a locked working tree, lock reason: %s\n"
+"use 'remove -f -f' to override or unlock first"
+msgstr "No es poden eliminar els canvis de l'arbre de treball"
 
-#: builtin/tag.c:399
-msgid "use another key to sign the tag"
-msgstr "usa una altra clau per a signar l'etiqueta"
+#: builtin/worktree.c:935
+#, fuzzy
+msgid ""
+"cannot remove a locked working tree;\n"
+"use 'remove -f -f' to override or unlock first"
+msgstr "No es poden eliminar els canvis de l'arbre de treball"
 
-#: builtin/tag.c:400
-msgid "replace the tag if exists"
-msgstr "reemplaça l'etiqueta si existeix"
+#: builtin/worktree.c:938
+#, c-format
+msgid "validation failed, cannot remove working tree: %s"
+msgstr ""
 
-#: builtin/tag.c:401 builtin/update-ref.c:368
-msgid "create a reflog"
-msgstr "crea un registre de referències"
+#: builtin/write-tree.c:15
+msgid "git write-tree [--missing-ok] [--prefix=<prefix>/]"
+msgstr "git write-tree [--missing-ok] [--prefix=<prefix>/]"
 
-#: builtin/tag.c:403
-msgid "Tag listing options"
-msgstr "Opcions de llistat d'etiquetes"
+#: builtin/write-tree.c:28
+msgid "<prefix>/"
+msgstr "<prefix>/"
 
-#: builtin/tag.c:404
-msgid "show tag list in columns"
-msgstr "mostra la llista d'etiquetes en columnes"
+#: builtin/write-tree.c:29
+msgid "write tree object for a subdirectory <prefix>"
+msgstr "escriu l'objecte d'arbre per a un subdirectori <prefix>"
 
-#: builtin/tag.c:405 builtin/tag.c:407
-msgid "print only tags that contain the commit"
-msgstr "imprimeix només les etiquetes que continguin la comissió"
+#: builtin/write-tree.c:31
+msgid "only useful for debugging"
+msgstr "només útil per a la depuració"
 
-#: builtin/tag.c:406 builtin/tag.c:408
-msgid "print only tags that don't contain the commit"
-msgstr "imprimeix només les etiquetes que no continguin la comissió"
+#: fast-import.c:3125
+#, c-format
+msgid "Expected 'mark' command, got %s"
+msgstr "S'esperava l'ordre «mark», s'ha rebut %s"
 
-#: builtin/tag.c:409
-msgid "print only tags that are merged"
-msgstr "imprimeix només les etiquetes que s'han fusionat"
+#: fast-import.c:3130
+#, c-format
+msgid "Expected 'to' command, got %s"
+msgstr "S'esperava l'ordre «to», s'ha rebut «%s»"
 
-#: builtin/tag.c:410
-msgid "print only tags that are not merged"
-msgstr "imprimeix només les etiquetes que no s'han fusionat"
+#: fast-import.c:3254
+#, c-format
+msgid "feature '%s' forbidden in input without --allow-unsafe-features"
+msgstr ""
 
-#: builtin/tag.c:415
-msgid "print only tags of the object"
-msgstr "imprimeix només les etiquetes de l'objecte"
+#: credential-cache--daemon.c:223
+#, c-format
+msgid ""
+"The permissions on your socket directory are too loose; other\n"
+"users may be able to read your cached credentials. Consider running:\n"
+"\n"
+"\tchmod 0700 %s"
+msgstr ""
+"Els permisos en el vostre directori de sòcol són massa liberals;\n"
+"pot ser que altres usuaris poden llegir les vostres credencials.\n"
+"Considereu executar:\n"
+"\n"
+"\tchmod 0700 %s"
 
-#: builtin/tag.c:459
-msgid "--column and -n are incompatible"
-msgstr "--column i -n són incompatibles"
+#: credential-cache--daemon.c:272
+msgid "print debugging messages to stderr"
+msgstr "imprimeix els missatges de depuració a stderr"
 
-#: builtin/tag.c:481
-msgid "-n option is only allowed in list mode"
-msgstr "es permet l'opció -n només amb mode llista"
+#: t/helper/test-reach.c:152
+#, c-format
+msgid "commit %s is not marked reachable"
+msgstr "la comissió %s no està marcada com abastable"
 
-#: builtin/tag.c:483
-msgid "--contains option is only allowed in list mode"
-msgstr "es permet l'opció --contains només amb mode llista"
+#: t/helper/test-reach.c:162
+msgid "too many commits marked reachable"
+msgstr "masses comission marcades com abastable"
 
-#: builtin/tag.c:485
-msgid "--no-contains option is only allowed in list mode"
-msgstr "es permet l'opció --no-contains només amb mode llista"
+#: t/helper/test-serve-v2.c:7
+msgid "test-tool serve-v2 [<options>]"
+msgstr "test-tool serve-v2 [<opcions>]"
 
-#: builtin/tag.c:487
-msgid "--points-at option is only allowed in list mode"
-msgstr "es permet --points-at option només amb mode llista"
+#: t/helper/test-serve-v2.c:19
+msgid "exit immediately after advertising capabilities"
+msgstr "surt immediatament després d'anunciar les funcionalitats"
 
-#: builtin/tag.c:489
-msgid "--merged and --no-merged options are only allowed in list mode"
-msgstr "es permeten les opcions --merged i --no-merged només amb mode llista"
+#: git.c:27
+msgid ""
+"git [--version] [--help] [-C <path>] [-c <name>=<value>]\n"
+"           [--exec-path[=<path>]] [--html-path] [--man-path] [--info-path]\n"
+"           [-p | --paginate | -P | --no-pager] [--no-replace-objects] [--"
+"bare]\n"
+"           [--git-dir=<path>] [--work-tree=<path>] [--namespace=<name>]\n"
+"           <command> [<args>]"
+msgstr ""
 
-#: builtin/tag.c:500
-msgid "only one -F or -m option is allowed."
-msgstr "només es permet una opció -F o -m."
+#: git.c:34
+msgid ""
+"'git help -a' and 'git help -g' list available subcommands and some\n"
+"concept guides. See 'git help <command>' or 'git help <concept>'\n"
+"to read about a specific subcommand or concept.\n"
+"See 'git help git' for an overview of the system."
+msgstr ""
+"«git help -a» i «git help -g» llisten subordres disponibles i\n"
+"algunes guies de concepte. Vegeu «git help <ordre>» o\n"
+"«git help <concepte>» per a llegir sobre un subordre o concepte específic.\n"
+"Vegeu «git help git» per a una visió general del sistema."
 
-#: builtin/tag.c:519
-msgid "too many params"
-msgstr "massa paràmetres"
+#: git.c:186
+#, c-format
+msgid "no directory given for --git-dir\n"
+msgstr "no s'ha especificat un directori per --git-dir\n"
 
-#: builtin/tag.c:525
+#: git.c:200
 #, c-format
-msgid "'%s' is not a valid tag name."
-msgstr "«%s» no és un nom d'etiqueta vàlid."
+msgid "no namespace given for --namespace\n"
+msgstr "no s'ha especificat un nom d'espai per --namespace\n"
 
-#: builtin/tag.c:530
+#: git.c:214
 #, c-format
-msgid "tag '%s' already exists"
-msgstr "l'etiqueta «%s» ja existeix"
+msgid "no directory given for --work-tree\n"
+msgstr "no s'ha especificat un directori per --work-tree\n"
 
-#: builtin/tag.c:561
+#: git.c:228
 #, c-format
-msgid "Updated tag '%s' (was %s)\n"
-msgstr "Etiqueta «%s» actualitzada (era %s)\n"
+msgid "no prefix given for --super-prefix\n"
+msgstr "no s'ha especificat cap prefix per a --super-prefix\n"
 
-#: builtin/unpack-objects.c:498
-msgid "Unpacking objects"
-msgstr "S'estan desempaquetant els objectes"
+#: git.c:250
+#, c-format
+msgid "-c expects a configuration string\n"
+msgstr "-c espera una cadena de configuració\n"
 
-#: builtin/update-index.c:82
+#: git.c:288
 #, c-format
-msgid "failed to create directory %s"
-msgstr "s'ha produït un error en crear el directori %s"
+msgid "no directory given for -C\n"
+msgstr "no s'ha especificat un directori per -C\n"
 
-#: builtin/update-index.c:88
+#: git.c:314
 #, c-format
-msgid "failed to stat %s"
-msgstr "s'ha produït un error en fer stat a %s"
+msgid "unknown option: %s\n"
+msgstr "opció desconeguda: %s\n"
 
-#: builtin/update-index.c:98
+#: git.c:360
 #, c-format
-msgid "failed to create file %s"
-msgstr "s'ha produït un error en crear el fitxer %s"
+msgid "while expanding alias '%s': '%s'"
+msgstr ""
 
-#: builtin/update-index.c:106
+#: git.c:369
 #, c-format
-msgid "failed to delete file %s"
-msgstr "s'ha produït un error en suprimir el fitxer %s"
+msgid ""
+"alias '%s' changes environment variables.\n"
+"You can use '!git' in the alias to do this"
+msgstr ""
 
-#: builtin/update-index.c:113 builtin/update-index.c:219
+#: git.c:376
 #, c-format
-msgid "failed to delete directory %s"
-msgstr "s'ha produït un error en suprimir el directori %s"
+msgid "empty alias for %s"
+msgstr ""
 
-#: builtin/update-index.c:138
+#: git.c:379
 #, c-format
-msgid "Testing mtime in '%s' "
-msgstr "S'està provant mtime en «%s» "
+msgid "recursive alias: %s"
+msgstr "àlies recursiu: %s"
 
-#: builtin/update-index.c:152
-msgid "directory stat info does not change after adding a new file"
+#: git.c:459
+msgid "write failure on standard output"
+msgstr "fallada d'escriptura en la sortida estàndard"
+
+#: git.c:461
+msgid "unknown write failure on standard output"
+msgstr "fallada d'escriptura desconeguda en la sortida estàndard"
+
+#: git.c:463
+msgid "close failed on standard output"
+msgstr "ha fallat el tancament en la sortida estàndard"
+
+#: git.c:793
+#, c-format
+msgid "alias loop detected: expansion of '%s' does not terminate:%s"
 msgstr ""
-"la informació d'stat de directori no canvia després d'afegir un fitxer nou"
 
-#: builtin/update-index.c:165
-msgid "directory stat info does not change after adding a new directory"
+#: git.c:843
+#, fuzzy, c-format
+msgid "cannot handle %s as a builtin"
+msgstr "no es pot usar  %s com a fitxer d'exclusió"
+
+#: git.c:856
+#, c-format
+msgid ""
+"usage: %s\n"
+"\n"
 msgstr ""
-"la informació d'stat de directori no canvia després d'afegir un directori nou"
+"ús: %s\n"
+"\n"
 
-#: builtin/update-index.c:178
-msgid "directory stat info changes after updating a file"
+#: git.c:876
+#, c-format
+msgid "expansion of alias '%s' failed; '%s' is not a git command\n"
 msgstr ""
-"la informació d'stat de directori canvia després d'actualitzar un fitxer"
 
-#: builtin/update-index.c:189
-msgid "directory stat info changes after adding a file inside subdirectory"
+#: git.c:888
+#, c-format
+msgid "failed to run command '%s': %s\n"
+msgstr "s'ha produït un error en executar l'ordre «%s»: %s\n"
+
+#: http.c:378
+#, c-format
+msgid "negative value for http.postbuffer; defaulting to %d"
+msgstr "valor negatiu per http.postbuffer; utilitzant el valor %d"
+
+#: http.c:399
+msgid "Delegation control is not supported with cURL < 7.22.0"
+msgstr "No s'admet el control de delegació amb el cURL < 7.22.0"
+
+#: http.c:408
+msgid "Public key pinning not supported with cURL < 7.44.0"
+msgstr "No s'admet l'enganx de clau pública amb cURL < 7.44.0"
+
+#: http.c:876
+#, fuzzy
+msgid "CURLSSLOPT_NO_REVOKE not supported with cURL < 7.44.0"
+msgstr "No s'admet l'enganx de clau pública amb cURL < 7.44.0"
+
+#: http.c:949
+#, fuzzy
+msgid "Protocol restrictions not supported with cURL < 7.19.4"
+msgstr "No s'admet l'enganx de clau pública amb cURL < 7.44.0"
+
+#: http.c:1086
+#, c-format
+msgid "Unsupported SSL backend '%s'. Supported SSL backends:"
 msgstr ""
-"la informació d'stat de directori canvia després d'afegir un fitxer dins "
-"d'un subdirectori"
 
-#: builtin/update-index.c:200
-msgid "directory stat info does not change after deleting a file"
+#: http.c:1093
+#, c-format
+msgid "Could not set SSL backend to '%s': cURL was built without SSL backends"
 msgstr ""
-"la informació d'stat de directori no canvia després de suprimir un fitxer"
 
-#: builtin/update-index.c:213
-msgid "directory stat info does not change after deleting a directory"
+#: http.c:1097
+#, fuzzy, c-format
+msgid "Could not set SSL backend to '%s': already set"
+msgstr "No s'ha pogut tornar a $head_name"
+
+#: http.c:1966
+#, c-format
+msgid ""
+"unable to update url base from redirection:\n"
+"  asked for: %s\n"
+"   redirect: %s"
 msgstr ""
-"la informació d'stat de directori no canvia després de suprimir un directori"
+"no s'ha pogut actualitzar l'URL base des de la redirecció:\n"
+"  petició: %s\n"
+"   redirecció: %s"
 
-#: builtin/update-index.c:220
-msgid " OK"
-msgstr " D'acord"
+#: remote-curl.c:166
+#, fuzzy, c-format
+msgid "invalid quoting in push-option value: '%s'"
+msgstr "valor parcial no vàlid: «%s»"
 
-#: builtin/update-index.c:579
-msgid "git update-index [<options>] [--] [<file>...]"
-msgstr "git update-index [<opcions>] [--] [<fitxer>...]"
+#: remote-curl.c:263
+#, fuzzy, c-format
+msgid "%sinfo/refs not valid: is this a git repository?"
+msgstr "«%s» no reconegut com un dipòsit git"
 
-#: builtin/update-index.c:936
-msgid "continue refresh even when index needs update"
-msgstr ""
-"continua l'actualització encara que l'índex necessiti una actualització"
+#: remote-curl.c:364
+#, fuzzy
+msgid "invalid server response; expected service, got flush packet"
+msgstr "git archive: s'esperava ACK/NAK, s'ha rebut un paquet de neteja"
 
-#: builtin/update-index.c:939
-msgid "refresh: ignore submodules"
-msgstr "actualitza: ignora els submòduls"
+#: remote-curl.c:395
+#, fuzzy, c-format
+msgid "invalid server response; got '%s'"
+msgstr "referència no vàlida: %s"
 
-#: builtin/update-index.c:942
-msgid "do not ignore new files"
-msgstr "no ignoris els fitxers nous"
+#: remote-curl.c:455
+#, c-format
+msgid "repository '%s' not found"
+msgstr "no s'ha trobat el dipòsit «%s»"
 
-#: builtin/update-index.c:944
-msgid "let files replace directories and vice-versa"
-msgstr "deixa que els fitxers reemplacin els directoris i viceversa"
+#: remote-curl.c:459
+#, c-format
+msgid "Authentication failed for '%s'"
+msgstr "S'ha produït un error en autenticar per «%s»"
 
-#: builtin/update-index.c:946
-msgid "notice files missing from worktree"
-msgstr "tingues en compte els fitxers absents de l'arbre de treball"
+#: remote-curl.c:463
+#, c-format
+msgid "unable to access '%s': %s"
+msgstr "no s'ha pogut accedir a «%s»: %s"
 
-#: builtin/update-index.c:948
-msgid "refresh even if index contains unmerged entries"
-msgstr "actualitza encara que l'índex contingui entrades no fusionades"
+#: remote-curl.c:469
+#, c-format
+msgid "redirecting to %s"
+msgstr "s'està redirigint a %s"
 
-#: builtin/update-index.c:951
-msgid "refresh stat information"
-msgstr "actualitza la informació d'estadístiques"
+#: remote-curl.c:593
+msgid "shouldn't have EOF when not gentle on EOF"
+msgstr ""
 
-#: builtin/update-index.c:955
-msgid "like --refresh, but ignore assume-unchanged setting"
-msgstr "com --refresh, però ignora el paràmetre assume-unchanged"
+#: remote-curl.c:673
+msgid "unable to rewind rpc post data - try increasing http.postBuffer"
+msgstr ""
 
-#: builtin/update-index.c:959
-msgid "<mode>,<object>,<path>"
-msgstr "<mode>,<objecte>,<camí>"
+#: remote-curl.c:733
+#, fuzzy, c-format
+msgid "RPC failed; %s"
+msgstr "STARTTLS ha fallat! %s"
 
-#: builtin/update-index.c:960
-msgid "add the specified entry to the index"
-msgstr "afegeix l'entrada especificada a l'índex"
+#: remote-curl.c:773
+#, fuzzy
+msgid "cannot handle pushes this big"
+msgstr "no es pot usar  %s com a fitxer d'exclusió"
 
-#: builtin/update-index.c:969
-msgid "mark files as \"not changing\""
-msgstr "marca els fitxers com a \"no canviant\""
+#: remote-curl.c:888
+#, c-format
+msgid "cannot deflate request; zlib deflate error %d"
+msgstr ""
 
-#: builtin/update-index.c:972
-msgid "clear assumed-unchanged bit"
-msgstr "neteja el bit assumed-unchanged"
+#: remote-curl.c:892
+#, c-format
+msgid "cannot deflate request; zlib end error %d"
+msgstr ""
 
-#: builtin/update-index.c:975
-msgid "mark files as \"index-only\""
-msgstr "marca els fitxers com a \"només índex\""
+#: remote-curl.c:1023
+#, fuzzy
+msgid "dumb http transport does not support shallow capabilities"
+msgstr "El servidor no permet clients superficials"
 
-#: builtin/update-index.c:978
-msgid "clear skip-worktree bit"
-msgstr "neteja el bit skip-worktree"
+#: remote-curl.c:1037
+#, fuzzy
+msgid "fetch failed."
+msgstr "l'«stash» ha fallat"
 
-#: builtin/update-index.c:981
-msgid "add to index only; do not add content to object database"
+#: remote-curl.c:1085
+msgid "cannot fetch by sha1 over smart http"
 msgstr ""
-"només afegeix a l'índex; no afegeixis el contingut a la base de dades "
-"d'objectes"
 
-#: builtin/update-index.c:983
-msgid "remove named paths even if present in worktree"
+#: remote-curl.c:1129 remote-curl.c:1135
+#, fuzzy, c-format
+msgid "protocol error: expected sha/ref, got '%s'"
 msgstr ""
-"elimina els camins anomenats encara que estiguin presents en l'arbre de "
-"treball"
+"s'ha produït un error de protocol: s'esperava shallow sha-1, s'ha rebut «%s»"
 
-#: builtin/update-index.c:985
-msgid "with --stdin: input lines are terminated by null bytes"
-msgstr "amb --stdin: les línies d'entrada acaben amb octets nuls"
+#: remote-curl.c:1147 remote-curl.c:1261
+#, fuzzy, c-format
+msgid "http transport does not support %s"
+msgstr "la variant «simple» d'ssh no és compatible amb -4"
 
-#: builtin/update-index.c:987
-msgid "read list of paths to be updated from standard input"
-msgstr "llegeix la llista de camins a actualitzar des de l'entrada estàndard"
+#: remote-curl.c:1183
+#, fuzzy
+msgid "git-http-push failed"
+msgstr "l'«stash» ha fallat"
 
-#: builtin/update-index.c:991
-msgid "add entries from standard input to the index"
-msgstr "afegeix les entrades de l'entrada estàndard a l'índex"
+#: remote-curl.c:1367
+msgid "remote-curl: usage: git remote-curl <remote> [<url>]"
+msgstr ""
 
-#: builtin/update-index.c:995
-msgid "repopulate stages #2 and #3 for the listed paths"
-msgstr "reemplena les «stage» #2 i #3 per als camins llistats"
+#: remote-curl.c:1399
+msgid "remote-curl: error reading command stream from git"
+msgstr ""
 
-#: builtin/update-index.c:999
-msgid "only update entries that differ from HEAD"
-msgstr "només actualitza les entrades que difereixin de HEAD"
+#: remote-curl.c:1406
+msgid "remote-curl: fetch attempted without a local repo"
+msgstr ""
 
-#: builtin/update-index.c:1003
-msgid "ignore files missing from worktree"
-msgstr "ignora els fitxers absents de l'arbre de treball"
+#: remote-curl.c:1446
+#, c-format
+msgid "remote-curl: unknown command '%s' from git"
+msgstr ""
 
-#: builtin/update-index.c:1006
-msgid "report actions to standard output"
-msgstr "informa de les accions en la sortida estàndard"
+#: list-objects-filter-options.h:85
+msgid "args"
+msgstr "args"
 
-#: builtin/update-index.c:1008
-msgid "(for porcelains) forget saved unresolved conflicts"
-msgstr "(per a porcellanes) oblida't dels conflictes no resolts ni desats"
+#: list-objects-filter-options.h:86
+msgid "object filtering"
+msgstr "filtratge d'objecte"
 
-#: builtin/update-index.c:1012
-msgid "write index in this format"
-msgstr "escriu l'índex en aquest format"
+#: parse-options.h:183
+msgid "expiry-date"
+msgstr "data-de-caducitat"
 
-#: builtin/update-index.c:1014
-msgid "enable or disable split index"
-msgstr "habilita o inhabilita l'índex dividit"
+#: parse-options.h:197
+msgid "no-op (backward compatibility)"
+msgstr "operació nul·la (per a compatibilitat amb versions anteriors)"
 
-#: builtin/update-index.c:1016
-msgid "enable/disable untracked cache"
-msgstr "habilita/inhabilita la memòria cau no seguida"
+#: parse-options.h:309
+msgid "be more verbose"
+msgstr "sigues més detallat"
 
-#: builtin/update-index.c:1018
-msgid "test if the filesystem supports untracked cache"
-msgstr "prova si el sistema de fitxers admet la memòria cau no seguida"
+#: parse-options.h:311
+msgid "be more quiet"
+msgstr "sigues més discret"
 
-#: builtin/update-index.c:1020
-msgid "enable untracked cache without testing the filesystem"
-msgstr "habilita la memòria cau no seguida sense provar el sistema de fitxers"
+#: parse-options.h:317
+msgid "use <n> digits to display SHA-1s"
+msgstr "usa <n> xifres per presentar els SHA-1"
 
-#: builtin/update-index.c:1022
-msgid "write out the index even if is not flagged as changed"
-msgstr ""
+#: parse-options.h:336
+msgid "how to strip spaces and #comments from message"
+msgstr "com suprimir els espais i #comentaris del missatge"
 
-#: builtin/update-index.c:1024
-msgid "enable or disable file system monitor"
-msgstr "habilita o inhabilita el monitor del sistema de fitxers"
+#: parse-options.h:337
+#, fuzzy
+msgid "read pathspec from file"
+msgstr "llegeix els patrons des d'un fitxer"
 
-#: builtin/update-index.c:1026
-msgid "mark files as fsmonitor valid"
-msgstr "marca els fitxers com a vàlids pel fsmonitor"
+#: parse-options.h:338
+#, fuzzy
+msgid ""
+"with --pathspec-from-file, pathspec elements are separated with NUL character"
+msgstr "els camins se separen amb el caràcter NUL"
 
-#: builtin/update-index.c:1029
-msgid "clear fsmonitor valid bit"
-msgstr "neteja el bit de validesa del fsmonitor"
+#: ref-filter.h:101
+msgid "key"
+msgstr "clau"
 
-#: builtin/update-index.c:1127
-msgid ""
-"core.splitIndex is set to false; remove or change it, if you really want to "
-"enable split index"
-msgstr ""
-"core.splitIndex està establert a fals; elimineu-lo o canviar-lo, si realment "
-"voleu habilitar l'índex dividit"
+#: ref-filter.h:101
+msgid "field name to sort on"
+msgstr "nom del camp en el qual ordenar"
 
-#: builtin/update-index.c:1136
-msgid ""
-"core.splitIndex is set to true; remove or change it, if you really want to "
-"disable split index"
+#: rerere.h:44
+msgid "update the index with reused conflict resolution if possible"
 msgstr ""
-"core.splitIndex està establert a cert; elimineu-lo o canvieu-lo, si realment "
-"voleu inhabilitar l'índex dividit"
+"actualitza l'índex amb la resolució de conflicte reusada si és possible"
 
-#: builtin/update-index.c:1147
-msgid ""
-"core.untrackedCache is set to true; remove or change it, if you really want "
-"to disable the untracked cache"
-msgstr ""
-"core.untrackedCache està establert a cert; elimineu-lo o canvieu-lo, si "
-"realment voleu inhabilitar el cau no seguit"
+#: wt-status.h:67
+msgid "HEAD detached at "
+msgstr "HEAD separat a "
 
-#: builtin/update-index.c:1151
-msgid "Untracked cache disabled"
-msgstr "La memòria cau no seguida està inhabilitada"
+#: wt-status.h:68
+msgid "HEAD detached from "
+msgstr "HEAD separat de "
 
-#: builtin/update-index.c:1159
-msgid ""
-"core.untrackedCache is set to false; remove or change it, if you really want "
-"to enable the untracked cache"
-msgstr ""
-"core.untrackedCache està establert a fals; elimineu-lo o canviar-lo, si "
-"realment voleu habilitar el cau no seguit"
+#: command-list.h:50
+msgid "Add file contents to the index"
+msgstr "Afegeix els continguts dels fitxers a l'índex"
 
-#: builtin/update-index.c:1163
-#, c-format
-msgid "Untracked cache enabled for '%s'"
-msgstr "La memòria cau no seguida està habilitada per a «%s»"
+#: command-list.h:51
+msgid "Apply a series of patches from a mailbox"
+msgstr "Aplica una sèrie de pedaços des d'una bústia de correu"
+
+#: command-list.h:52
+msgid "Annotate file lines with commit information"
+msgstr "Anota les línies del fitxer amb la informació de la comissió"
+
+#: command-list.h:53
+msgid "Apply a patch to files and/or to the index"
+msgstr "Aplica un pedaç a fitxer i/o a l'índex"
+
+#: command-list.h:54
+msgid "Import a GNU Arch repository into Git"
+msgstr "Importa un dipòsit GNU Arch a Git"
+
+#: command-list.h:55
+msgid "Create an archive of files from a named tree"
+msgstr "Crea un arxiu de fitxers des d'un arbre amb nom"
 
-#: builtin/update-index.c:1171
-msgid "core.fsmonitor is unset; set it if you really want to enable fsmonitor"
+#: command-list.h:56
+msgid "Use binary search to find the commit that introduced a bug"
+msgstr "Troba per cerca binària el canvi que hagi introduït un defecte"
+
+#: command-list.h:57
+msgid "Show what revision and author last modified each line of a file"
 msgstr ""
-"core.fsmonitor està establert a fals; establiu-lo a cert si realment voleu "
-"habilitar fsmonitor"
+"Mostra quina revisió i autor ha modificat per últim cop cada línia d'un "
+"fitxer"
 
-#: builtin/update-index.c:1175
-msgid "fsmonitor enabled"
-msgstr "fsmonitor habilitat"
+#: command-list.h:58
+msgid "List, create, or delete branches"
+msgstr "Llista, crea o suprimeix branques"
 
-#: builtin/update-index.c:1178
-msgid ""
-"core.fsmonitor is set; remove it if you really want to disable fsmonitor"
+#: command-list.h:59
+msgid "Move objects and refs by archive"
 msgstr ""
-"core.fsmonitor està establert a cert; elimineu-lo si realment voleu "
-"inhabilitar fsmonitor"
 
-#: builtin/update-index.c:1182
-msgid "fsmonitor disabled"
-msgstr "fsmonitor inhabilitat"
+#: command-list.h:60
+msgid "Provide content or type and size information for repository objects"
+msgstr ""
+"Proveeix contingut o informació del tipus i mida per als objectes del dipòsit"
 
-#: builtin/update-ref.c:10
-msgid "git update-ref [<options>] -d <refname> [<old-val>]"
-msgstr "git update-ref [<opcions>] -d <nom-de-referència> [<valor-antic>]"
+#: command-list.h:61
+msgid "Display gitattributes information"
+msgstr "Mostra la informació de .gitattributes"
 
-#: builtin/update-ref.c:11
-msgid "git update-ref [<options>]    <refname> <new-val> [<old-val>]"
-msgstr ""
-"git update-ref [<opcions>]    <nom-de-referència> <valor-nou> [<valor-antic>]"
+#: command-list.h:62
+msgid "Debug gitignore / exclude files"
+msgstr "Depura gitignore / fitxers d'exclusió"
 
-#: builtin/update-ref.c:12
-msgid "git update-ref [<options>] --stdin [-z]"
-msgstr "git update-ref [<opcions>] --stdin [-z]"
+#: command-list.h:63
+#, fuzzy
+msgid "Show canonical names and email addresses of contacts"
+msgstr "Mostra l'adreça electrònica de cada autor"
 
-#: builtin/update-ref.c:363
-msgid "delete the reference"
-msgstr "suprimeix la referència"
+#: command-list.h:64
+msgid "Switch branches or restore working tree files"
+msgstr "Canvia de branca o restaura els fitxers de l'arbre de treball"
 
-#: builtin/update-ref.c:365
-msgid "update <refname> not the one it points to"
-msgstr "actualitza <nom de referència>, no la que assenyali"
+#: command-list.h:65
+msgid "Copy files from the index to the working tree"
+msgstr "Copia fitxers des de l'índex a l'arbre de treball"
+
+#: command-list.h:66
+msgid "Ensures that a reference name is well formed"
+msgstr "Assegura que un nom de referència està ben format"
+
+#: command-list.h:67
+msgid "Find commits yet to be applied to upstream"
+msgstr "Troba les comissions que encara s'han d'aplicar a la font"
+
+#: command-list.h:68
+msgid "Apply the changes introduced by some existing commits"
+msgstr "Aplica els canvis introduïts per algunes comissions existents"
+
+#: command-list.h:69
+msgid "Graphical alternative to git-commit"
+msgstr "Alternativa gràfica a git-commit"
+
+#: command-list.h:70
+msgid "Remove untracked files from the working tree"
+msgstr "Suprimeix els fitxers no seguits de l'arbre de treball"
 
-#: builtin/update-ref.c:366
-msgid "stdin has NUL-terminated arguments"
-msgstr "stdin té paràmetres acabats amb NUL"
+#: command-list.h:71
+msgid "Clone a repository into a new directory"
+msgstr "Clona un dipòsit a un directori nou"
 
-#: builtin/update-ref.c:367
-msgid "read updates from stdin"
-msgstr "llegeix les actualitzacions des de stdin"
+#: command-list.h:72
+msgid "Display data in columns"
+msgstr "Mostra les dades en columnes"
 
-#: builtin/update-server-info.c:7
-msgid "git update-server-info [--force]"
-msgstr "git update-server-info [--force]"
+#: command-list.h:73
+msgid "Record changes to the repository"
+msgstr "Registra els canvis al dipòsit"
 
-#: builtin/update-server-info.c:15
-msgid "update the info files from scratch"
-msgstr "actualitza els fitxers d'informació des de zero"
+#: command-list.h:74
+msgid "Write and verify Git commit-graph files"
+msgstr "Escriu i verifica els fitxers commit-graph de Git"
 
-#: builtin/verify-commit.c:18
-msgid "git verify-commit [-v | --verbose] <commit>..."
-msgstr "git verify-commit [-v | --verbose] <comissió>..."
+#: command-list.h:75
+msgid "Create a new commit object"
+msgstr "Crea un objecte de comissió nou"
 
-#: builtin/verify-commit.c:73
-msgid "print commit contents"
-msgstr "imprimeix els continguts de la comissió"
+#: command-list.h:76
+msgid "Get and set repository or global options"
+msgstr "Obté o estableix opcions de dipòsit o globals"
 
-#: builtin/verify-commit.c:74 builtin/verify-tag.c:38
-msgid "print raw gpg status output"
-msgstr "imprimeix la sortida crua de l'estat gpg"
+#: command-list.h:77
+msgid "Count unpacked number of objects and their disk consumption"
+msgstr ""
 
-#: builtin/verify-pack.c:55
-msgid "git verify-pack [-v | --verbose] [-s | --stat-only] <pack>..."
-msgstr "git verify-pack [-v | --verbose] [-s | --stat-only] <paquet>..."
+#: command-list.h:78
+msgid "Retrieve and store user credentials"
+msgstr ""
 
-#: builtin/verify-pack.c:65
-msgid "verbose"
-msgstr "detallat"
+#: command-list.h:79
+msgid "Helper to temporarily store passwords in memory"
+msgstr ""
 
-#: builtin/verify-pack.c:67
-msgid "show statistics only"
-msgstr "mostra només estadístiques"
+#: command-list.h:80
+msgid "Helper to store credentials on disk"
+msgstr "Ajudant per a emmagatzemar credencials a disc"
 
-#: builtin/verify-tag.c:19
-msgid "git verify-tag [-v | --verbose] [--format=<format>] <tag>..."
-msgstr "git verify-tag [-v | --verbose] [--format=<format>] <etiqueta>..."
+#: command-list.h:81
+msgid "Export a single commit to a CVS checkout"
+msgstr ""
 
-#: builtin/verify-tag.c:37
-msgid "print tag contents"
-msgstr "imprimeix els continguts de l'etiqueta"
+#: command-list.h:82
+msgid "Salvage your data out of another SCM people love to hate"
+msgstr ""
 
-#: builtin/worktree.c:17
-msgid "git worktree add [<options>] <path> [<commit-ish>]"
-msgstr "git worktree add [<opcions>] <camí> [<commit-ish>"
+#: command-list.h:83
+msgid "A CVS server emulator for Git"
+msgstr "Un emulador de servidor CVS per al Git"
 
-#: builtin/worktree.c:18
-msgid "git worktree list [<options>]"
-msgstr "git worktree list [<opcions>]"
+#: command-list.h:84
+msgid "A really simple server for Git repositories"
+msgstr "Un servidor realment senzill per a dipòsits Git"
 
-#: builtin/worktree.c:19
-msgid "git worktree lock [<options>] <path>"
-msgstr "git worktree lock [<opcions>] <camí>"
+#: command-list.h:85
+msgid "Give an object a human readable name based on an available ref"
+msgstr ""
+"Dóna un nom llegible per humans basant-se en les referències disponibles"
 
-#: builtin/worktree.c:20
-msgid "git worktree move <worktree> <new-path>"
-msgstr "git worktree move <arbre de treball> <camí-nou>"
+#: command-list.h:86
+msgid "Show changes between commits, commit and working tree, etc"
+msgstr ""
+"Mostra els canvis entre comissions, la comissió i l'arbre de treball, etc"
 
-#: builtin/worktree.c:21
-msgid "git worktree prune [<options>]"
-msgstr "git worktree prune [<opcions>]"
+#: command-list.h:87
+msgid "Compares files in the working tree and the index"
+msgstr "Compara fitxers en l'arbre de treball i l'índex"
 
-#: builtin/worktree.c:22
-msgid "git worktree remove [<options>] <worktree>"
-msgstr "git worktree lock [<opcions>] <arbre de treball>"
+#: command-list.h:88
+msgid "Compare a tree to the working tree or index"
+msgstr "Compara un arbre amb l'arbre de treball o l'índex"
 
-#: builtin/worktree.c:23
-msgid "git worktree unlock <path>"
-msgstr "git worktree unlock <camí>"
+#: command-list.h:89
+msgid "Compares the content and mode of blobs found via two tree objects"
+msgstr ""
 
-#: builtin/worktree.c:60
-#, c-format
-msgid "Removing worktrees/%s: not a valid directory"
-msgstr "Eliminació de worktrees/%s: no és un directori vàlid"
+#: command-list.h:90
+msgid "Show changes using common diff tools"
+msgstr "Mostra els canvis usant eines diff comunes"
 
-#: builtin/worktree.c:66
-#, c-format
-msgid "Removing worktrees/%s: gitdir file does not exist"
-msgstr "Eliminació de worktrees/%s: el fitxer gitdir no existeix"
+#: command-list.h:91
+msgid "Git data exporter"
+msgstr "Explorador de dades del Git"
 
-#: builtin/worktree.c:71 builtin/worktree.c:80
-#, c-format
-msgid "Removing worktrees/%s: unable to read gitdir file (%s)"
-msgstr "Eliminació de worktrees/%s: no s'ha pogut llegir el fitxer gitdir (%s)"
+#: command-list.h:92
+msgid "Backend for fast Git data importers"
+msgstr "Rerefons per a importadors ràpids de dades de Git"
 
-#: builtin/worktree.c:90
-#, c-format
-msgid ""
-"Removing worktrees/%s: short read (expected %<PRIuMAX> bytes, read "
-"%<PRIuMAX>)"
-msgstr ""
-"S'estan suprimint els arbres de treball/%s: lectura curta (s'esperaven "
-"%<PRIuMAX> bytes, llegits %<PRIuMAX>)"
+#: command-list.h:93
+msgid "Download objects and refs from another repository"
+msgstr "Baixa objectes i referències d'un altre dipòsit"
 
-#: builtin/worktree.c:98
-#, c-format
-msgid "Removing worktrees/%s: invalid gitdir file"
-msgstr "Eliminació de worktrees/%s: fitxer gitdir no vàlid"
+#: command-list.h:94
+msgid "Receive missing objects from another repository"
+msgstr "Rep els objectes que manquen des d'un altre dipòsit"
 
-#: builtin/worktree.c:114
-#, c-format
-msgid "Removing worktrees/%s: gitdir file points to non-existent location"
-msgstr ""
-"Eliminació de worktrees/%s: el fitxer gitdir es refereix a una ubicació no "
-"existent"
+#: command-list.h:95
+msgid "Rewrite branches"
+msgstr "Torna a escriure les branques"
 
-#: builtin/worktree.c:161
-msgid "report pruned working trees"
-msgstr "informa dels arbres de treball podats"
+#: command-list.h:96
+msgid "Produce a merge commit message"
+msgstr "Produeix un missatge de comissió de fusió"
 
-#: builtin/worktree.c:163
-msgid "expire working trees older than <time>"
-msgstr "fes caducar els arbres de treball més vells que <hora>"
+#: command-list.h:97
+msgid "Output information on each ref"
+msgstr "Mostra la informació en cada referència"
 
-#: builtin/worktree.c:238
-#, c-format
-msgid "'%s' already exists"
-msgstr "«%s» ja existeix"
+#: command-list.h:98
+msgid "Prepare patches for e-mail submission"
+msgstr "Prepara pedaços per enviar-los per correu electrònic"
 
-#: builtin/worktree.c:269
-#, c-format
-msgid "could not create directory of '%s'"
-msgstr "no s'ha pogut crear directori de «%s»"
+#: command-list.h:99
+msgid "Verifies the connectivity and validity of the objects in the database"
+msgstr "Verifica la connectivitat i validesa del objectes a la base de dades"
 
-#: builtin/worktree.c:308
-#, c-format
-msgid "Preparing %s (identifier %s)"
-msgstr "S'està preparant %s (identificador %s)"
+#: command-list.h:100
+msgid "Cleanup unnecessary files and optimize the local repository"
+msgstr "Neteja els fitxers innecessaris i optimitza el dipòsit local"
 
-#: builtin/worktree.c:385
-msgid "checkout <branch> even if already checked out in other worktree"
-msgstr "agafa <branca> encara que sigui agafada en altre arbre de treball"
+#: command-list.h:101
+msgid "Extract commit ID from an archive created using git-archive"
+msgstr ""
 
-#: builtin/worktree.c:388
-msgid "create a new branch"
-msgstr "crea una branca nova"
+#: command-list.h:102
+msgid "Print lines matching a pattern"
+msgstr "Imprimeix les línies coincidents amb un patró"
 
-#: builtin/worktree.c:390
-msgid "create or reset a branch"
-msgstr "crea o restableix una branca"
+#: command-list.h:103
+msgid "A portable graphical interface to Git"
+msgstr "Una interfície gràfic portable per al Git"
 
-#: builtin/worktree.c:392
-msgid "populate the new working tree"
-msgstr "emplena l'arbre de treball nou"
+#: command-list.h:104
+msgid "Compute object ID and optionally creates a blob from a file"
+msgstr "Calcula l'ID de l'objecte i opcionalment crea un blob des del fitxer"
 
-#: builtin/worktree.c:393
-msgid "keep the new working tree locked"
-msgstr "mantén l'arbre de treball nou bloquejat"
+#: command-list.h:105
+msgid "Display help information about Git"
+msgstr "Mostra informació d'ajuda del Git"
 
-#: builtin/worktree.c:395
-msgid "set up tracking mode (see git-branch(1))"
-msgstr "configura el mode de seguiment (vegeu git-branch(1))"
+#: command-list.h:106
+msgid "Server side implementation of Git over HTTP"
+msgstr ""
+
+#: command-list.h:107
+msgid "Download from a remote Git repository via HTTP"
+msgstr "Baixa des d'un dipòsit Git remot via HTTP"
 
-#: builtin/worktree.c:398
+#: command-list.h:108
 #, fuzzy
-msgid "try to match the new branch name with a remote-tracking branch"
-msgstr "la branca font «%s» no s'emmagatzema com a branca amb seguiment remot"
+msgid "Push objects over HTTP/DAV to another repository"
+msgstr "Baixa objectes i referències d'un altre dipòsit"
 
-#: builtin/worktree.c:406
-msgid "-b, -B, and --detach are mutually exclusive"
-msgstr "-b, -B i --detach són mútuament excloents"
+#: command-list.h:109
+msgid "Send a collection of patches from stdin to an IMAP folder"
+msgstr ""
 
-#: builtin/worktree.c:471
-#, fuzzy
-msgid "--[no-]track can only be used if a new branch is created"
-msgstr "--local només es pot usar dins d'un dipòsit git"
+#: command-list.h:110
+msgid "Build pack index file for an existing packed archive"
+msgstr ""
 
-#: builtin/worktree.c:571
-msgid "reason for locking"
-msgstr "raó per bloquejar"
+#: command-list.h:111
+msgid "Create an empty Git repository or reinitialize an existing one"
+msgstr "Crea un dipòsit de Git buit o reinicialitza un existent"
 
-#: builtin/worktree.c:583 builtin/worktree.c:616 builtin/worktree.c:670
-#: builtin/worktree.c:809
-#, c-format
-msgid "'%s' is not a working tree"
-msgstr "«%s» no és un arbre de treball"
+#: command-list.h:112
+msgid "Instantly browse your working repository in gitweb"
+msgstr ""
 
-#: builtin/worktree.c:585 builtin/worktree.c:618
-msgid "The main working tree cannot be locked or unlocked"
-msgstr "No es pot bloquejar ni desbloquejar l'arbre de treball principal"
+#: command-list.h:113
+msgid "Add or parse structured information in commit messages"
+msgstr ""
 
-#: builtin/worktree.c:590
-#, c-format
-msgid "'%s' is already locked, reason: %s"
-msgstr "«%s» ja està bloquejat, raó: «%s»"
+#: command-list.h:114
+msgid "The Git repository browser"
+msgstr "El navegador de dipòsits Git"
 
-#: builtin/worktree.c:592
-#, c-format
-msgid "'%s' is already locked"
-msgstr "«%s» ja està bloquejat"
+#: command-list.h:115
+msgid "Show commit logs"
+msgstr "Mostra els registres de comissió"
 
-#: builtin/worktree.c:620
-#, c-format
-msgid "'%s' is not locked"
-msgstr "«%s» no està bloquejat"
+#: command-list.h:116
+msgid "Show information about files in the index and the working tree"
+msgstr "Mostra informació sobre els fitxer a l'índex i a l'arbre de treball"
 
-#: builtin/worktree.c:645
-msgid "working trees containing submodules cannot be moved or removed"
-msgstr ""
+#: command-list.h:117
+msgid "List references in a remote repository"
+msgstr "Mostra les referències d'un dipòsit remot"
 
-#: builtin/worktree.c:672 builtin/worktree.c:811
-#, c-format
-msgid "'%s' is a main working tree"
-msgstr "«%s» és un arbre de treball principal"
+#: command-list.h:118
+msgid "List the contents of a tree object"
+msgstr "Mostra els continguts d'un objecte de l'arbre"
 
-#: builtin/worktree.c:677
-#, c-format
-msgid "could not figure out destination name from '%s'"
-msgstr "no s'ha pogut deduir el nom de destí des de «%s»"
+#: command-list.h:119
+msgid "Extracts patch and authorship from a single e-mail message"
+msgstr ""
 
-#: builtin/worktree.c:683
-#, c-format
-msgid "target '%s' already exists"
-msgstr "el destí «%s» ja existeix"
+#: command-list.h:120
+msgid "Simple UNIX mbox splitter program"
+msgstr ""
 
-#: builtin/worktree.c:690
-#, fuzzy, c-format
-msgid "cannot move a locked working tree, lock reason: %s"
-msgstr "No es poden eliminar els canvis de l'arbre de treball"
+#: command-list.h:121
+msgid "Join two or more development histories together"
+msgstr "Uneix dues o més històries de desenvolupament"
 
-#: builtin/worktree.c:692
+#: command-list.h:122
 #, fuzzy
-msgid "cannot move a locked working tree"
-msgstr "No es pot registrar l'estat de l'arbre de treball"
+msgid "Find as good common ancestors as possible for a merge"
+msgstr "troba els avantpassats per a una sola fusió d'n vies"
 
-#: builtin/worktree.c:695
-#, c-format
-msgid "validation failed, cannot move working tree: %s"
-msgstr ""
+#: command-list.h:123
+#, fuzzy
+msgid "Run a three-way file merge"
+msgstr "S'està retrocedint a una fusió de 3 vies...\n"
 
-#: builtin/worktree.c:700
-#, c-format
-msgid "failed to move '%s' to '%s'"
-msgstr "s'ha produït un error en moure «%s» a «%s»"
+#: command-list.h:124
+#, fuzzy
+msgid "Run a merge for files needing merging"
+msgstr "fusió de 3 vies si no cal fusió a nivell de fitxers"
 
-#: builtin/worktree.c:748
-#, fuzzy, c-format
-msgid "failed to run 'git status' on '%s'"
-msgstr "no s'ha pogut escriure a «%s»"
+#: command-list.h:125
+msgid "The standard helper program to use with git-merge-index"
+msgstr ""
 
-#: builtin/worktree.c:752
-#, c-format
-msgid "'%s' is dirty, use --force to delete it"
+#: command-list.h:126
+msgid "Run merge conflict resolution tools to resolve merge conflicts"
 msgstr ""
+"Executa eines de resolució de conflictes per a resoldre conflictes de fussió"
 
-#: builtin/worktree.c:757
-#, fuzzy, c-format
-msgid "failed to run 'git status' on '%s', code %d"
-msgstr "no s'ha pogut executar 'git status' al submòdul «%s»"
+#: command-list.h:127
+msgid "Show three-way merge without touching index"
+msgstr ""
 
-#: builtin/worktree.c:768 builtin/worktree.c:782
-#, fuzzy, c-format
-msgid "failed to delete '%s'"
-msgstr "s'ha produït un error en executar «%s»"
+#: command-list.h:128
+msgid "Write and verify multi-pack-indexes"
+msgstr ""
 
-#: builtin/worktree.c:794
-#, fuzzy
-msgid "force removing even if the worktree is dirty"
-msgstr "força el moviment / canvi de nom encara que el destí existeixi"
+#: command-list.h:129
+msgid "Creates a tag object"
+msgstr "Crea un objecte etiqueta"
 
-#: builtin/worktree.c:815
-#, fuzzy, c-format
-msgid "cannot remove a locked working tree, lock reason: %s"
-msgstr "No es poden eliminar els canvis de l'arbre de treball"
+#: command-list.h:130
+msgid "Build a tree-object from ls-tree formatted text"
+msgstr ""
 
-#: builtin/worktree.c:817
-#, fuzzy
-msgid "cannot remove a locked working tree"
-msgstr "No es pot registrar l'estat de l'arbre de treball"
+#: command-list.h:131
+msgid "Move or rename a file, a directory, or a symlink"
+msgstr "Mou o canvia de nom a un fitxer, directori o enllaç simbòlic"
 
-#: builtin/worktree.c:820
-#, c-format
-msgid "validation failed, cannot remove working tree: %s"
+#: command-list.h:132
+msgid "Find symbolic names for given revs"
 msgstr ""
 
-#: builtin/write-tree.c:14
-msgid "git write-tree [--missing-ok] [--prefix=<prefix>/]"
-msgstr "git write-tree [--missing-ok] [--prefix=<prefix>/]"
+#: command-list.h:133
+msgid "Add or inspect object notes"
+msgstr "Afegeix o inspecciona notes de l'objecte"
 
-#: builtin/write-tree.c:27
-msgid "<prefix>/"
-msgstr "<prefix>/"
+#: command-list.h:134
+msgid "Import from and submit to Perforce repositories"
+msgstr "Importa des de i envia a dipòsits Perforce"
 
-#: builtin/write-tree.c:28
-msgid "write tree object for a subdirectory <prefix>"
-msgstr "escriu l'objecte d'arbre per a un subdirectori <prefix>"
+#: command-list.h:135
+msgid "Create a packed archive of objects"
+msgstr "Crea un arxiu empaquetat d'objectes"
 
-#: builtin/write-tree.c:31
-msgid "only useful for debugging"
-msgstr "només útil per a la depuració"
+#: command-list.h:136
+msgid "Find redundant pack files"
+msgstr "Troba fitxers empaquetats redundants"
 
-#: upload-pack.c:27
-msgid "git upload-pack [<options>] <dir>"
-msgstr "git upload-pack [<opcions>] <directori>"
+#: command-list.h:137
+msgid "Pack heads and tags for efficient repository access"
+msgstr ""
 
-#: upload-pack.c:1070
-msgid "quit after a single request/response exchange"
-msgstr "surt després d'un sol intercanvi de sol·licitud/resposta"
+#: command-list.h:138
+msgid "Routines to help parsing remote repository access parameters"
+msgstr ""
 
-#: upload-pack.c:1072
-msgid "exit immediately after initial ref advertisement"
-msgstr "surt immediatament després de l'anunci inicial de referència"
+#: command-list.h:139
+msgid "Compute unique ID for a patch"
+msgstr "Calcula un identificador única per a cada pedaç"
 
-#: upload-pack.c:1074
-msgid "do not try <directory>/.git/ if <directory> is no Git directory"
+#: command-list.h:140
+msgid "Prune all unreachable objects from the object database"
+msgstr "Poda tots els objectes no accessibles de la base de dades d'objectes"
+
+#: command-list.h:141
+msgid "Remove extra objects that are already in pack files"
 msgstr ""
-"no intentis <directori>/.git/ si <directori> no és cap directori del Git"
 
-#: upload-pack.c:1076
-msgid "interrupt transfer after <n> seconds of inactivity"
-msgstr "interromp la transferència després de <n> segons d'inactivitat"
+#: command-list.h:142
+msgid "Fetch from and integrate with another repository or a local branch"
+msgstr "Obtén i integra amb un altre dipòsit o una branca local"
 
-#: credential-cache--daemon.c:222
-#, c-format
-msgid ""
-"The permissions on your socket directory are too loose; other\n"
-"users may be able to read your cached credentials. Consider running:\n"
-"\n"
-"\tchmod 0700 %s"
+#: command-list.h:143
+msgid "Update remote refs along with associated objects"
 msgstr ""
-"Els permisos en el vostre directori de sòcol són massa liberals;\n"
-"pot ser que altres usuaris poden llegir les vostres credencials.\n"
-"Considereu executar:\n"
-"\n"
-"\tchmod 0700 %s"
+"Actualitza les referències remotes juntament amb els objectes associats"
 
-#: credential-cache--daemon.c:271
-msgid "print debugging messages to stderr"
-msgstr "imprimeix els missatges de depuració a stderr"
+#: command-list.h:144
+#, fuzzy
+msgid "Applies a quilt patchset onto the current branch"
+msgstr "No hi ha cap font per defecte definida per a la branca actual."
 
-#: git.c:8
-msgid ""
-"git [--version] [--help] [-C <path>] [-c <name>=<value>]\n"
-"           [--exec-path[=<path>]] [--html-path] [--man-path] [--info-path]\n"
-"           [-p | --paginate | --no-pager] [--no-replace-objects] [--bare]\n"
-"           [--git-dir=<path>] [--work-tree=<path>] [--namespace=<name>]\n"
-"           <command> [<args>]"
+#: command-list.h:145
+msgid "Compare two commit ranges (e.g. two versions of a branch)"
 msgstr ""
 
-#: git.c:15
-msgid ""
-"'git help -a' and 'git help -g' list available subcommands and some\n"
-"concept guides. See 'git help <command>' or 'git help <concept>'\n"
-"to read about a specific subcommand or concept."
-msgstr ""
-"'git help -a' i 'git help -g' llisten subordres disponibles i\n"
-"algunes guies de concepte. Vegeu 'git help <ordre>' o\n"
-"'git help <concepte>' per a llegir sobre una subordre o concepte específic."
+#: command-list.h:146
+#, fuzzy
+msgid "Reads tree information into the index"
+msgstr "actualitza la informació d'estadístiques en el fitxer d'índex"
 
-#: git.c:95
-#, c-format
-msgid "no directory given for --git-dir\n"
-msgstr "no s'ha especificat un directori per --git-dir\n"
+#: command-list.h:147
+msgid "Reapply commits on top of another base tip"
+msgstr "Torna a aplicar les comissions sobre un altre punt de basament"
 
-#: git.c:109
-#, c-format
-msgid "no namespace given for --namespace\n"
-msgstr "no s'ha especificat un nom d'espai per --namespace\n"
+#: command-list.h:148
+#, fuzzy
+msgid "Receive what is pushed into the repository"
+msgstr "Registra els canvis al dipòsit"
 
-#: git.c:123
-#, c-format
-msgid "no directory given for --work-tree\n"
-msgstr "no s'ha especificat un directori per --work-tree\n"
+#: command-list.h:149
+#, fuzzy
+msgid "Manage reflog information"
+msgstr "mostra la informació de resolució de desfet"
 
-#: git.c:137
-#, fuzzy, c-format
-msgid "no prefix given for --super-prefix\n"
-msgstr "%s no admet --super-prefix"
+#: command-list.h:150
+#, fuzzy
+msgid "Manage set of tracked repositories"
+msgstr "Registra els canvis al dipòsit"
 
-#: git.c:159
-#, c-format
-msgid "-c expects a configuration string\n"
-msgstr "-c espera una cadena de configuració\n"
+#: command-list.h:151
+#, fuzzy
+msgid "Pack unpacked objects in a repository"
+msgstr "--cached fora d'un dipòsit"
 
-#: git.c:197
-#, c-format
-msgid "no directory given for -C\n"
-msgstr "no s'ha especificat un directori per -C\n"
+#: command-list.h:152
+#, fuzzy
+msgid "Create, list, delete refs to replace objects"
+msgstr ""
+"Crea, llista, suprimeix o verifica un objecte d'etiqueta signat amb GPG"
 
-#: git.c:212
-#, c-format
-msgid "unknown option: %s\n"
-msgstr "opció desconeguda: %s\n"
+#: command-list.h:153
+msgid "Generates a summary of pending changes"
+msgstr ""
 
-#: git.c:687
-#, c-format
-msgid "expansion of alias '%s' failed; '%s' is not a git command\n"
+#: command-list.h:154
+msgid "Reuse recorded resolution of conflicted merges"
 msgstr ""
 
-#: git.c:699
-#, fuzzy, c-format
-msgid "failed to run command '%s': %s\n"
-msgstr "s'ha produït un error en obrir «%s»: %s"
+#: command-list.h:155
+msgid "Reset current HEAD to the specified state"
+msgstr "Restableix la HEAD actual a l'estat especificat"
 
-#: http.c:342
-#, c-format
-msgid "negative value for http.postbuffer; defaulting to %d"
-msgstr "valor negatiu per http.postbuffer; utilitzant el valor %d"
+#: command-list.h:156
+msgid "Restore working tree files"
+msgstr "Restaura els fitxers de l'arbre de treball"
+
+#: command-list.h:157
+msgid "Revert some existing commits"
+msgstr "Reverteix comissions existents"
+
+#: command-list.h:158
+msgid "Lists commit objects in reverse chronological order"
+msgstr "Mostra les comissions en ordre topològic invers"
+
+#: command-list.h:159
+msgid "Pick out and massage parameters"
+msgstr "Escolleix i personalitza els paràmetres"
 
-#: http.c:363
-msgid "Delegation control is not supported with cURL < 7.22.0"
-msgstr "No s'admet el control de delegació amb el cURL < 7.22.0"
+#: command-list.h:160
+msgid "Remove files from the working tree and from the index"
+msgstr "Elimina fitxers de l'arbre de treball i de l'índex"
 
-#: http.c:372
-msgid "Public key pinning not supported with cURL < 7.44.0"
-msgstr "No s'admet l'enganx de clau pública amb cURL < 7.44.0"
+#: command-list.h:161
+msgid "Send a collection of patches as emails"
+msgstr "Envia una col·lecció de pedaços com a correus electrònics"
 
-#: http.c:1857
-#, c-format
-msgid ""
-"unable to update url base from redirection:\n"
-"  asked for: %s\n"
-"   redirect: %s"
+#: command-list.h:162
+msgid "Push objects over Git protocol to another repository"
+msgstr "Puja objectes sobre el protocol Git a un altre dipòsit"
+
+#: command-list.h:163
+msgid "Restricted login shell for Git-only SSH access"
 msgstr ""
-"no s'ha pogut actualitzar l'URL base des de la redirecció:\n"
-"  petició: %s\n"
-"   redirecció: %s"
 
-#: remote-curl.c:345
-#, c-format
-msgid "redirecting to %s"
-msgstr "s'està redirigint a %s"
+#: command-list.h:164
+msgid "Summarize 'git log' output"
+msgstr ""
 
-#: list-objects-filter-options.h:59
-msgid "args"
-msgstr "args"
+#: command-list.h:165
+msgid "Show various types of objects"
+msgstr "Mostra diversos tipus d'objectes"
 
-#: list-objects-filter-options.h:60
-#, fuzzy
-msgid "object filtering"
-msgstr "tipus d'objecte"
+#: command-list.h:166
+msgid "Show branches and their commits"
+msgstr "Mostra les branques i les seves comissions"
 
-#: common-cmds.h:9
-msgid "start a working area (see also: git help tutorial)"
-msgstr "començar una àrea de treball (vegeu també: git help tutorial)"
+#: command-list.h:167
+msgid "Show packed archive index"
+msgstr "Mostra l'índex d'arxius empaquetat"
 
-#: common-cmds.h:10
-msgid "work on the current change (see also: git help everyday)"
-msgstr "treballar en el canvi actual (vegeu també: git help everyday)"
+#: command-list.h:168
+msgid "List references in a local repository"
+msgstr "Llista les referències en un dipòsit local"
 
-#: common-cmds.h:11
-msgid "examine the history and state (see also: git help revisions)"
-msgstr "examinar la història i l'estat (vegeu també: git help revisions)"
+#: command-list.h:169
+msgid "Git's i18n setup code for shell scripts"
+msgstr ""
 
-#: common-cmds.h:12
-msgid "grow, mark and tweak your common history"
-msgstr "fer créixer, marcar i ajustar la vostra història comuna"
+#: command-list.h:170
+msgid "Common Git shell script setup code"
+msgstr "Codi de scripts de configuració comuns pel Git shell"
 
-#: common-cmds.h:13
-msgid "collaborate (see also: git help workflows)"
-msgstr "col·laborar (vegeu també: git help workflow)"
+#: command-list.h:171
+msgid "Initialize and modify the sparse-checkout"
+msgstr ""
 
-#: common-cmds.h:17
-msgid "Add file contents to the index"
+#: command-list.h:172
+#, fuzzy
+msgid "Stash the changes in a dirty working directory away"
+msgstr "%s: ja existeix en el directori de treball"
+
+#: command-list.h:173
+#, fuzzy
+msgid "Add file contents to the staging area"
 msgstr "Afegeix els continguts dels fitxers a l'índex"
 
-#: common-cmds.h:18
-msgid "Use binary search to find the commit that introduced a bug"
-msgstr "Troba per cerca binària el canvi que hagi introduït un defecte"
+#: command-list.h:174
+msgid "Show the working tree status"
+msgstr "Mostra l'estat de l'arbre de treball"
 
-#: common-cmds.h:19
-msgid "List, create, or delete branches"
-msgstr "Llista, crea o suprimeix branques"
+#: command-list.h:175
+msgid "Remove unnecessary whitespace"
+msgstr "Suprimeix l'espai en blanc innecessari"
+
+#: command-list.h:176
+msgid "Initialize, update or inspect submodules"
+msgstr "Inicialitza, actualitza o inspecciona submòduls"
+
+#: command-list.h:177
+msgid "Bidirectional operation between a Subversion repository and Git"
+msgstr "Operació bidireccional entre un dipòsit a Subversion i Git"
+
+#: command-list.h:178
+msgid "Switch branches"
+msgstr "Commuta branques"
+
+#: command-list.h:179
+msgid "Read, modify and delete symbolic refs"
+msgstr "Llegeix, modifica i suprimeix referències simbòliques"
 
-#: common-cmds.h:20
-msgid "Switch branches or restore working tree files"
-msgstr "Canvia de branca o restaura els fitxers de l'arbre de treball"
+#: command-list.h:180
+msgid "Create, list, delete or verify a tag object signed with GPG"
+msgstr ""
+"Crea, llista, suprimeix o verifica un objecte d'etiqueta signat amb GPG"
 
-#: common-cmds.h:21
-msgid "Clone a repository into a new directory"
-msgstr "Clona un dipòsit a un directori nou"
+#: command-list.h:181
+msgid "Creates a temporary file with a blob's contents"
+msgstr "Crea un fitxer temporal amb els continguts dels blobs"
 
-#: common-cmds.h:22
-msgid "Record changes to the repository"
-msgstr "Registra els canvis al dipòsit"
+#: command-list.h:182
+msgid "Unpack objects from a packed archive"
+msgstr "Desempaqueta objectes d'un arxiu empaquetat"
 
-#: common-cmds.h:23
-msgid "Show changes between commits, commit and working tree, etc"
+#: command-list.h:183
+msgid "Register file contents in the working tree to the index"
+msgstr "Registra els continguts del fitxer en l'arbre de treball a l'índex"
+
+#: command-list.h:184
+msgid "Update the object name stored in a ref safely"
 msgstr ""
-"Mostra els canvis entre comissions, la comissió i l'arbre de treball, etc."
+"Actualitza el nom de l'objecte emmagatzema en una referència de forma segura"
 
-#: common-cmds.h:24
-msgid "Download objects and refs from another repository"
-msgstr "Baixa objectes i referències d'un altre dipòsit"
+#: command-list.h:185
+msgid "Update auxiliary info file to help dumb servers"
+msgstr ""
+
+#: command-list.h:186
+msgid "Send archive back to git-archive"
+msgstr "Envia l'arxiu de tornada al git-archive"
+
+#: command-list.h:187
+msgid "Send objects packed back to git-fetch-pack"
+msgstr "Envia els objectes empaquetats de tornada al git-fetch-pack"
 
-#: common-cmds.h:25
-msgid "Print lines matching a pattern"
-msgstr "Imprimeix les línies coincidents amb un patró"
+#: command-list.h:188
+msgid "Show a Git logical variable"
+msgstr "Mostra una variable lògica del Git"
 
-#: common-cmds.h:26
-msgid "Create an empty Git repository or reinitialize an existing one"
-msgstr "Crea un dipòsit de Git buit o reinicialitza un existent"
+#: command-list.h:189
+msgid "Check the GPG signature of commits"
+msgstr "Verifica la signatura GPG de les comissions"
 
-#: common-cmds.h:27
-msgid "Show commit logs"
-msgstr "Mostra els registres de comissió"
+#: command-list.h:190
+msgid "Validate packed Git archive files"
+msgstr "Valida els fitxers d'arxius Git empaquetats"
 
-#: common-cmds.h:28
-msgid "Join two or more development histories together"
-msgstr "Uneix dues o més històries de desenvolupament"
+#: command-list.h:191
+msgid "Check the GPG signature of tags"
+msgstr "Verifica la signatura GPG de les etiquetes"
 
-#: common-cmds.h:29
-msgid "Move or rename a file, a directory, or a symlink"
-msgstr "Mou o canvia de nom a un fitxer, directori o enllaç simbòlic"
+#: command-list.h:192
+msgid "Git web interface (web frontend to Git repositories)"
+msgstr "Interfície web del Git (interfície web pels dipòsits Git)"
 
-#: common-cmds.h:30
-msgid "Fetch from and integrate with another repository or a local branch"
-msgstr "Obtén i integra amb un altre dipòsit o una branca local"
+#: command-list.h:193
+msgid "Show logs with difference each commit introduces"
+msgstr "Mostra registres amb la diferència introduïda per cada comissió"
 
-#: common-cmds.h:31
-msgid "Update remote refs along with associated objects"
-msgstr ""
-"Actualitza les referències remotes juntament amb els objectes associats"
+#: command-list.h:194
+msgid "Manage multiple working trees"
+msgstr "Gestiona múltiples arbres de treball"
 
-#: common-cmds.h:32
-msgid "Reapply commits on top of another base tip"
-msgstr "Reaplica les comissions sobre un altre punt de basament"
+#: command-list.h:195
+msgid "Create a tree object from the current index"
+msgstr "Crea un objecte arbre des de l'índex actual"
 
-#: common-cmds.h:33
-msgid "Reset current HEAD to the specified state"
-msgstr "Restableix la HEAD actual a l'estat especificat"
+#: command-list.h:196
+msgid "Defining attributes per path"
+msgstr "La definició d'atributs per camí"
 
-#: common-cmds.h:34
-msgid "Remove files from the working tree and from the index"
-msgstr "Elimina fitxers de l'arbre de treball i de l'índex"
+#: command-list.h:197
+msgid "Git command-line interface and conventions"
+msgstr "Interfície i convencions de la línia d'ordres del Git"
+
+#: command-list.h:198
+msgid "A Git core tutorial for developers"
+msgstr "Un tutorial bàsic del Git per a desenvolupadors"
+
+#: command-list.h:199
+msgid "Git for CVS users"
+msgstr "Git per a usuaris del CVS"
 
-#: common-cmds.h:35
-msgid "Show various types of objects"
-msgstr "Mostra diversos tipus d'objectes"
+#: command-list.h:200
+#, fuzzy
+msgid "Tweaking diff output"
+msgstr "omet la sortida de diferències"
 
-#: common-cmds.h:36
-msgid "Show the working tree status"
-msgstr "Mostra l'estat de l'arbre de treball"
+#: command-list.h:201
+msgid "A useful minimum set of commands for Everyday Git"
+msgstr "Un conjunt mínim útil d'ordres diàries del Git"
 
-#: common-cmds.h:37
-msgid "Create, list, delete or verify a tag object signed with GPG"
-msgstr ""
-"Crea, llista, suprimeix o verifica un objecte d'etiqueta signat amb GPG"
+#: command-list.h:202
+msgid "A Git Glossary"
+msgstr "Un glossari de Git"
 
-#: parse-options.h:157
-msgid "expiry-date"
-msgstr "data-de-caducitat"
+#: command-list.h:203
+msgid "Hooks used by Git"
+msgstr "Lligams utilitzats pel Git"
 
-#: parse-options.h:172
-msgid "no-op (backward compatibility)"
-msgstr "operació nul·la (per a compatibilitat amb versions anteriors)"
+#: command-list.h:204
+msgid "Specifies intentionally untracked files to ignore"
+msgstr "Especifica els fitxers intencionalment no seguits a ignorar"
 
-#: parse-options.h:250
-msgid "be more verbose"
-msgstr "sigues més detallat"
+#: command-list.h:205
+msgid "Defining submodule properties"
+msgstr "La definició de les propietats de submòduls"
 
-#: parse-options.h:252
-msgid "be more quiet"
-msgstr "sigues més callat"
+#: command-list.h:206
+msgid "Git namespaces"
+msgstr "Espais de noms del Git"
+
+#: command-list.h:207
+msgid "Git Repository Layout"
+msgstr "Disposició del dipòsit del Git"
 
-#: parse-options.h:258
-msgid "use <n> digits to display SHA-1s"
-msgstr "usa <n> xifres per presentar els SHA-1"
+#: command-list.h:208
+msgid "Specifying revisions and ranges for Git"
+msgstr "L'especificació de revisions i rangs per al Git"
 
-#: rerere.h:40
-msgid "update the index with reused conflict resolution if possible"
+#: command-list.h:209
+msgid "Mounting one repository inside another"
 msgstr ""
-"actualitza l'índex amb la resolució de conflicte reusada si és possible"
+
+#: command-list.h:210
+msgid "A tutorial introduction to Git: part two"
+msgstr "Un tutorial d'introducció al Git: segona part"
+
+#: command-list.h:211
+msgid "A tutorial introduction to Git"
+msgstr "Un tutorial d'introducció al Git"
+
+#: command-list.h:212
+msgid "An overview of recommended workflows with Git"
+msgstr "Una visió de conjunt de fluxos de treball recomanats amb Git"
 
 #: git-bisect.sh:54
 msgid "You need to start by \"git bisect start\""
@@ -15218,134 +22789,49 @@ msgstr "Cal començar per \"git bisect s
 msgid "Do you want me to do it for you [Y/n]? "
 msgstr "Voleu que ho faci per vostè [Y/n]? "
 
-#: git-bisect.sh:121
-#, sh-format
-msgid "unrecognised option: '$arg'"
-msgstr "opció no reconeguda: '$arg'"
-
-#: git-bisect.sh:125
-#, sh-format
-msgid "'$arg' does not appear to be a valid revision"
-msgstr "'$arg' no sembla una revisió vàlida"
-
-#: git-bisect.sh:154
-msgid "Bad HEAD - I need a HEAD"
-msgstr "HEAD incorrecte - Cal un HEAD"
-
-#: git-bisect.sh:167
-#, sh-format
-msgid ""
-"Checking out '$start_head' failed. Try 'git bisect reset <valid-branch>'."
-msgstr ""
-"L'agafament de '$start_head' ha fallat. Proveu 'git bisect reset <branca-"
-"vàlida>'."
-
-#: git-bisect.sh:177
-msgid "won't bisect on cg-seek'ed tree"
-msgstr "no es bisecarà en un arbre en el qual s'ha fet cg-seek"
-
-#: git-bisect.sh:181
-msgid "Bad HEAD - strange symbolic ref"
-msgstr "HEAD incorrecte - referència simbòlica estranya"
-
-#: git-bisect.sh:233
-#, sh-format
-msgid "Bad bisect_write argument: $state"
-msgstr "Paràmetre bisect_write incorrecte: $state"
-
-#: git-bisect.sh:246
+#: git-bisect.sh:101
 #, sh-format
 msgid "Bad rev input: $arg"
 msgstr "Introducció de revisió errònia: $arg"
 
-#: git-bisect.sh:265
+#: git-bisect.sh:121
 #, sh-format
 msgid "Bad rev input: $bisected_head"
 msgstr "Entrada de revisió errònia: $bisected_head"
 
-#: git-bisect.sh:274
+#: git-bisect.sh:130
 #, sh-format
 msgid "Bad rev input: $rev"
 msgstr "Introducció de revisió errònia: $rev"
 
-#: git-bisect.sh:283
+#: git-bisect.sh:139
 #, sh-format
 msgid "'git bisect $TERM_BAD' can take only one argument."
 msgstr "'git bisect $TERM_BAD' pot acceptar només un paràmetre."
 
-#: git-bisect.sh:306
-#, sh-format
-msgid "Warning: bisecting only with a $TERM_BAD commit."
-msgstr "Advertència: bisecant amb només comissió $TERM_BAD."
-
-#. TRANSLATORS: Make sure to include [Y] and [n] in your
-#. translation. The program will only accept English input
-#. at this point.
-#: git-bisect.sh:312
-msgid "Are you sure [Y/n]? "
-msgstr "N'esteu segur [Y/n]? "
-
-#: git-bisect.sh:324
-#, sh-format
-msgid ""
-"You need to give me at least one $bad_syn and one $good_syn revision.\n"
-"(You can use \"git bisect $bad_syn\" and \"git bisect $good_syn\" for that.)"
-msgstr ""
-"Cal donar-me almenys una revisió $bad_syn i una $good_syn.\n"
-"(Podeu usar \"git bisect $bad_syn\" i \"git bisect $good_syn\" per això.)"
-
-#: git-bisect.sh:327
-#, sh-format
-msgid ""
-"You need to start by \"git bisect start\".\n"
-"You then need to give me at least one $good_syn and one $bad_syn revision.\n"
-"(You can use \"git bisect $bad_syn\" and \"git bisect $good_syn\" for that.)"
-msgstr ""
-"Cal començar amb \"git bisect start\".\n"
-"Després cal donar-me almenys una revisió $good_syn i una $bad_syn.\n"
-"(Podeu usar \"git bisect $bad_syn\" i \"git bisect $good_syn\" per això.)"
-
-#: git-bisect.sh:398 git-bisect.sh:512
-msgid "We are not bisecting."
-msgstr "No estem bisecant."
-
-#: git-bisect.sh:405
-#, sh-format
-msgid "'$invalid' is not a valid commit"
-msgstr "'$invalid' no és una comissió vàlida"
-
-#: git-bisect.sh:414
-#, sh-format
-msgid ""
-"Could not check out original HEAD '$branch'.\n"
-"Try 'git bisect reset <commit>'."
-msgstr ""
-"No s'ha pogut agafar la HEAD original '$branch'.\n"
-"Proveu 'git bisect reset <comissió>'."
-
-#: git-bisect.sh:422
+#: git-bisect.sh:209
 msgid "No logfile given"
 msgstr "Cap fitxer de registre donat"
 
-#: git-bisect.sh:423
+#: git-bisect.sh:210
 #, sh-format
 msgid "cannot read $file for replaying"
 msgstr "no es pot llegir $file per a reproducció"
 
-#: git-bisect.sh:444
+#: git-bisect.sh:232
 msgid "?? what are you talking about?"
 msgstr "?? de què parleu?"
 
-#: git-bisect.sh:453
+#: git-bisect.sh:241
 msgid "bisect run failed: no command provided."
 msgstr ""
 
-#: git-bisect.sh:458
+#: git-bisect.sh:246
 #, sh-format
 msgid "running $command"
 msgstr "s'està executant $command"
 
-#: git-bisect.sh:465
+#: git-bisect.sh:253
 #, sh-format
 msgid ""
 "bisect run failed:\n"
@@ -15354,11 +22840,11 @@ msgstr ""
 "el pas de bisecció ha fallat:\n"
 "el codi de sortida $res de '$command' és < 0 o >= 128"
 
-#: git-bisect.sh:491
+#: git-bisect.sh:279
 msgid "bisect run cannot continue any more"
 msgstr "el pas de bisecció no pot continuar més"
 
-#: git-bisect.sh:497
+#: git-bisect.sh:285
 #, sh-format
 msgid ""
 "bisect run failed:\n"
@@ -15367,28 +22853,13 @@ msgstr ""
 "el pas de bisecció ha fallat:\n"
 "'bisect_state $state' ha sortit amb el codi d'error $res"
 
-#: git-bisect.sh:504
+#: git-bisect.sh:292
 msgid "bisect run success"
 msgstr "pas de bisecció reeixit"
 
-#: git-bisect.sh:533
-#, sh-format
-msgid "Invalid command: you're currently in a $TERM_BAD/$TERM_GOOD bisect."
-msgstr ""
-"Ordre no vàlida: actualment esteu en una bisecció $TERM_BAD/$TERM_GOOD."
-
-#: git-bisect.sh:567
-msgid "no terms defined"
-msgstr "cap terme definit"
-
-#: git-bisect.sh:584
-#, sh-format
-msgid ""
-"invalid argument $arg for 'git bisect terms'.\n"
-"Supported options are: --term-good|--term-old and --term-bad|--term-new."
-msgstr ""
-"paràmetre no vàlid $arg per a 'git bisect terms'.\n"
-"Les opcions admeses són: --term-good|--term-old i --term-bad|--term-new."
+#: git-bisect.sh:300
+msgid "We are not bisecting."
+msgstr "No estem bisecant."
 
 #: git-merge-octopus.sh:46
 msgid ""
@@ -15408,349 +22879,138 @@ msgstr "No s'ha de fer un pop."
 
 #: git-merge-octopus.sh:73
 #, sh-format
-msgid "Unable to find common commit with $pretty_name"
-msgstr "No s'ha pogut trobar cap comissió en comú amb $pretty_name"
-
-#: git-merge-octopus.sh:77
-#, sh-format
-msgid "Already up to date with $pretty_name"
-msgstr "Ja està al dia amb $pretty_name"
-
-#: git-merge-octopus.sh:89
-#, sh-format
-msgid "Fast-forwarding to: $pretty_name"
-msgstr "S'està avançant ràpidament a: $pretty_name"
-
-#: git-merge-octopus.sh:97
-#, sh-format
-msgid "Trying simple merge with $pretty_name"
-msgstr "S'està intentant una fusió simple amb $pretty_name"
-
-#: git-merge-octopus.sh:102
-msgid "Simple merge did not work, trying automatic merge."
-msgstr ""
-"La fusió simple no ha funcionat, s'està intentant una fusió automàtica."
-
-#: git-rebase.sh:60
-msgid ""
-"Resolve all conflicts manually, mark them as resolved with\n"
-"\"git add/rm <conflicted_files>\", then run \"git rebase --continue\".\n"
-"You can instead skip this commit: run \"git rebase --skip\".\n"
-"To abort and get back to the state before \"git rebase\", run \"git rebase --"
-"abort\"."
-msgstr ""
-"Resolgueu tots els conflictes manualment, marqueu-los com a resolts amb\n"
-"«git add/rm <fitxers amb conflicte>», llavors executeu «git rebase --"
-"continue».\n"
-"Podeu en comptes ometre aquesta comissió: executeu «git rebase --skip».\n"
-"Per a avortar i tornar a l'estat anterior abans de l'ordre «git rebase», "
-"executeu «git rebase --abort»."
-
-#: git-rebase.sh:163 git-rebase.sh:409
-#, sh-format
-msgid "Could not move back to $head_name"
-msgstr "No s'ha pogut tornar a $head_name"
-
-#: git-rebase.sh:174
-msgid "Applied autostash."
-msgstr "S'ha aplicat el magatzem automàtic."
-
-#: git-rebase.sh:177
-#, sh-format
-msgid "Cannot store $stash_sha1"
-msgstr "No es pot emmagatzemar $stash_sha1"
-
-#: git-rebase.sh:218
-msgid "The pre-rebase hook refused to rebase."
-msgstr "El lligam pre-«rebase» ha refusat a fer «rebase»."
-
-#: git-rebase.sh:223
-#, fuzzy
-msgid "It looks like 'git am' is in progress. Cannot rebase."
-msgstr "Sembla que git-am està en curs. No es pot fer «rebase»."
-
-#: git-rebase.sh:370
-msgid "No rebase in progress?"
-msgstr "No hi ha un «rebase» en curs?"
-
-#: git-rebase.sh:381
-msgid "The --edit-todo action can only be used during interactive rebase."
-msgstr "L'acció --edit-todo només es pot usar durant un «rebase» interactiu."
-
-#: git-rebase.sh:388
-msgid "Cannot read HEAD"
-msgstr "No es pot llegir HEAD"
-
-#: git-rebase.sh:391
-msgid ""
-"You must edit all merge conflicts and then\n"
-"mark them as resolved using git add"
-msgstr ""
-"Heu d'editar tots els conflictes de fusió i després\n"
-"marcar-los com a resolts fent servir git add"
-
-#: git-rebase.sh:435
-#, sh-format
-msgid ""
-"It seems that there is already a $state_dir_base directory, and\n"
-"I wonder if you are in the middle of another rebase.  If that is the\n"
-"case, please try\n"
-"\t$cmd_live_rebase\n"
-"If that is not the case, please\n"
-"\t$cmd_clear_stale_rebase\n"
-"and run me again.  I am stopping in case you still have something\n"
-"valuable there."
-msgstr ""
-"Sembla que ja hi ha un directori $state_dir_base, i\n"
-"em pregunto si esteu enmig d'un altre «rebase». Si aquest és el\n"
-"cas, proveu\n"
-"\t$cmd_live_rebase\n"
-"Si no és el cas, \n"
-"\t$cmd_clear_stale_rebase\n"
-"i executeu-me de nou. M'aturo per si encara hi teniu alguna cosa\n"
-"de valor."
-
-#: git-rebase.sh:491
-#, fuzzy, sh-format
-msgid "invalid upstream '$upstream_name'"
-msgstr "font no vàlida $upstream_name"
-
-#: git-rebase.sh:515
-#, sh-format
-msgid "$onto_name: there are more than one merge bases"
-msgstr "$onto_name: ja hi ha més d'una base de fusió"
-
-#: git-rebase.sh:518 git-rebase.sh:522
-#, sh-format
-msgid "$onto_name: there is no merge base"
-msgstr "$onto_name: no hi ha cap base de fusió"
-
-#: git-rebase.sh:527
-#, sh-format
-msgid "Does not point to a valid commit: $onto_name"
-msgstr "No assenyala una comissió vàlida: $onto_name"
-
-#: git-rebase.sh:553
-#, fuzzy, sh-format
-msgid "fatal: no such branch/commit '$branch_name'"
-msgstr "fatal: no hi ha tal branca: $branch_name"
-
-#: git-rebase.sh:586
-msgid "Cannot autostash"
-msgstr "No es pot emmagatzemar automàticament"
-
-#: git-rebase.sh:591
-#, sh-format
-msgid "Created autostash: $stash_abbrev"
-msgstr "S'ha creat un magatzem automàtic: $stash_abbrev"
-
-#: git-rebase.sh:595
-msgid "Please commit or stash them."
-msgstr "Cometeu-los o emmagatzemeu-los."
-
-#: git-rebase.sh:618
-#, sh-format
-msgid "HEAD is up to date."
-msgstr "HEAD està al dia."
-
-#: git-rebase.sh:620
-#, sh-format
-msgid "Current branch $branch_name is up to date."
-msgstr "La branca actual $branch_name està al dia."
-
-#: git-rebase.sh:628
-#, fuzzy, sh-format
-msgid "HEAD is up to date, rebase forced."
-msgstr "La branca actual $branch_name està al dia; «rebase» forçat."
-
-#: git-rebase.sh:630
-#, sh-format
-msgid "Current branch $branch_name is up to date, rebase forced."
-msgstr "La branca actual $branch_name està al dia; «rebase» forçat."
-
-#: git-rebase.sh:642
-#, sh-format
-msgid "Changes from $mb to $onto:"
-msgstr "Canvis de $mb a $onto:"
-
-#: git-rebase.sh:651
-msgid "First, rewinding head to replay your work on top of it..."
-msgstr ""
-"Primer, s'està rebobinant HEAD per a reproduir el vostre treball al damunt..."
-
-#: git-rebase.sh:661
-#, sh-format
-msgid "Fast-forwarded $branch_name to $onto_name."
-msgstr "S'ha avançat $branch_name ràpidament a $onto_name."
-
-#: git-stash.sh:61
-msgid "git stash clear with parameters is unimplemented"
-msgstr "git stash clear amb paràmetres no està implementat"
-
-#: git-stash.sh:108
-msgid "You do not have the initial commit yet"
-msgstr "Encara no teniu la comissió inicial"
+msgid "Unable to find common commit with $pretty_name"
+msgstr "No s'ha pogut trobar cap comissió en comú amb $pretty_name"
 
-#: git-stash.sh:123
-msgid "Cannot save the current index state"
-msgstr "No es pot desar l'estat d'índex actual"
+#: git-merge-octopus.sh:77
+#, sh-format
+msgid "Already up to date with $pretty_name"
+msgstr "Ja està al dia amb $pretty_name"
 
-#: git-stash.sh:138
-msgid "Cannot save the untracked files"
-msgstr "No es poden desar els fitxers no seguits"
+#: git-merge-octopus.sh:89
+#, sh-format
+msgid "Fast-forwarding to: $pretty_name"
+msgstr "S'està avançant ràpidament a: $pretty_name"
 
-#: git-stash.sh:158 git-stash.sh:171
-msgid "Cannot save the current worktree state"
-msgstr "No es pot desar l'estat d'arbre de treball actual"
+#: git-merge-octopus.sh:97
+#, sh-format
+msgid "Trying simple merge with $pretty_name"
+msgstr "S'està intentant una fusió simple amb $pretty_name"
 
-#: git-stash.sh:175
-msgid "No changes selected"
-msgstr "No hi ha canvis seleccionats"
+#: git-merge-octopus.sh:102
+msgid "Simple merge did not work, trying automatic merge."
+msgstr ""
+"La fusió simple no ha funcionat, s'està intentant una fusió automàtica."
 
-#: git-stash.sh:178
+#: git-legacy-stash.sh:221
 msgid "Cannot remove temporary index (can't happen)"
 msgstr "No es pot eliminar l'índex temporal (això no pot passar)"
 
-#: git-stash.sh:191
-msgid "Cannot record working tree state"
-msgstr "No es pot registrar l'estat de l'arbre de treball"
-
-#: git-stash.sh:229
+#: git-legacy-stash.sh:272
 #, sh-format
 msgid "Cannot update $ref_stash with $w_commit"
 msgstr "No es pot actualitzar $ref_stash amb $w_commit"
 
-#: git-stash.sh:281
+#: git-legacy-stash.sh:324
 #, sh-format
 msgid "error: unknown option for 'stash push': $option"
 msgstr ""
 
-#: git-stash.sh:295
-msgid "Can't use --patch and --include-untracked or --all at the same time"
-msgstr "No es poden usar --patch i --include-untracked o --all a la vegada."
-
-#: git-stash.sh:303
-msgid "No local changes to save"
-msgstr "No hi ha canvis locals a desar"
-
-#: git-stash.sh:308
-msgid "Cannot initialize stash"
-msgstr "No es pot inicialitzar el magatzem"
-
-#: git-stash.sh:312
-msgid "Cannot save the current status"
-msgstr "No es pot desar l'estat actual"
-
-#: git-stash.sh:313
+#: git-legacy-stash.sh:356
 #, sh-format
 msgid "Saved working directory and index state $stash_msg"
 msgstr "S'han desat el directori de treball i l'estat d'índex $stash_msg"
 
-#: git-stash.sh:340
-msgid "Cannot remove worktree changes"
-msgstr "No es poden eliminar els canvis de l'arbre de treball"
-
-#: git-stash.sh:488
+#: git-legacy-stash.sh:536
 #, sh-format
 msgid "unknown option: $opt"
 msgstr "opció desconeguda: $opt"
 
-#: git-stash.sh:501
-msgid "No stash entries found."
-msgstr "No s'ha trobat cap «stash»."
-
-#: git-stash.sh:508
+#: git-legacy-stash.sh:556
 #, sh-format
 msgid "Too many revisions specified: $REV"
 msgstr "S'han especificat massa revisions: $REV"
 
-#: git-stash.sh:523
+#: git-legacy-stash.sh:571
 #, sh-format
 msgid "$reference is not a valid reference"
 msgstr "$reference no és una referència vàlida"
 
-#: git-stash.sh:551
+#: git-legacy-stash.sh:599
 #, sh-format
 msgid "'$args' is not a stash-like commit"
 msgstr "'$args' no és una comissió de tipus magatzem"
 
-#: git-stash.sh:562
+#: git-legacy-stash.sh:610
 #, sh-format
 msgid "'$args' is not a stash reference"
 msgstr "'$args' no és una referència de magatzem"
 
-#: git-stash.sh:570
+#: git-legacy-stash.sh:618
 msgid "unable to refresh index"
 msgstr "no s'ha pogut actualitzar l'índex"
 
-#: git-stash.sh:574
+#: git-legacy-stash.sh:622
 msgid "Cannot apply a stash in the middle of a merge"
 msgstr "No es pot aplicar un magatzem enmig d'una fusió"
 
-#: git-stash.sh:582
+#: git-legacy-stash.sh:630
 msgid "Conflicts in index. Try without --index."
 msgstr "Hi ha conflictes en l'índex. Proveu-ho sense --index."
 
-#: git-stash.sh:584
+#: git-legacy-stash.sh:632
 msgid "Could not save index tree"
 msgstr "No s'ha pogut desar l'arbre d'índex"
 
-#: git-stash.sh:593
+#: git-legacy-stash.sh:641
 msgid "Could not restore untracked files from stash entry"
 msgstr "No s'han pogut restaurar els fitxers no seguits des del «stash»"
 
-#: git-stash.sh:618
+#: git-legacy-stash.sh:666
 msgid "Cannot unstage modified files"
 msgstr "No es pot fer «unstage» dels fitxers modificats"
 
-#: git-stash.sh:633
-msgid "Index was not unstashed."
-msgstr "L'índex no estava sense emmagatzemar."
-
-#: git-stash.sh:647
-msgid "The stash entry is kept in case you need it again."
-msgstr "Es conserva l'entrada «stash» en cas que la necessiteu altra vegada."
-
-#: git-stash.sh:656
+#: git-legacy-stash.sh:704
 #, sh-format
 msgid "Dropped ${REV} ($s)"
 msgstr "${REV} ($s) descartada"
 
-#: git-stash.sh:657
+#: git-legacy-stash.sh:705
 #, sh-format
 msgid "${REV}: Could not drop stash entry"
 msgstr "${REV}: No s'ha pogut descartar l'entrada de magatzem"
 
-#: git-stash.sh:665
-msgid "No branch name specified"
-msgstr "Cap nom de branca especificat"
-
-#: git-stash.sh:744
+#: git-legacy-stash.sh:792
 msgid "(To restore them type \"git stash apply\")"
 msgstr "(Per restaurar-les teclegeu \"git stash apply\")"
 
-#: git-submodule.sh:181
+#: git-submodule.sh:202
 msgid "Relative path can only be used from the toplevel of the working tree"
 msgstr ""
 "El camí relatiu només es pot usar des del nivell superior de l'arbre de "
 "treball"
 
-#: git-submodule.sh:191
+#: git-submodule.sh:212
 #, sh-format
 msgid "repo URL: '$repo' must be absolute or begin with ./|../"
 msgstr "URL de dipòsit: '$repo' ha de ser absolut o començar amb ./|../"
 
-#: git-submodule.sh:210
+#: git-submodule.sh:231
 #, sh-format
 msgid "'$sm_path' already exists in the index"
 msgstr "'$sm_path' ja existeix en l'índex"
 
-#: git-submodule.sh:213
+#: git-submodule.sh:234
 #, sh-format
 msgid "'$sm_path' already exists in the index and is not a submodule"
 msgstr "'$sm_path' ja existeix en l'índex i no és submòdul"
 
-#: git-submodule.sh:219
+#: git-submodule.sh:241
+#, fuzzy, sh-format
+msgid "'$sm_path' does not have a commit checked out"
+msgstr "el camí «%s» no té la seva versió"
+
+#: git-submodule.sh:247
 #, sh-format
 msgid ""
 "The following path is ignored by one of your .gitignore files:\n"
@@ -15761,23 +23021,23 @@ msgstr ""
 "$sm_path\n"
 "Useu -f si realment voleu afegir-lo."
 
-#: git-submodule.sh:237
+#: git-submodule.sh:270
 #, sh-format
 msgid "Adding existing repo at '$sm_path' to the index"
 msgstr "S'està afegint el dipòsit existent a '$sm_path' a l'índex"
 
-#: git-submodule.sh:239
+#: git-submodule.sh:272
 #, sh-format
 msgid "'$sm_path' already exists and is not a valid git repo"
 msgstr "'$sm_path' ja existeix i no és un dipòsit de git vàlid"
 
-#: git-submodule.sh:247
+#: git-submodule.sh:280
 #, sh-format
 msgid "A git directory for '$sm_name' is found locally with remote(s):"
 msgstr ""
 "Es troba un directori de git per a '$sm_name' localment amb els remots:"
 
-#: git-submodule.sh:249
+#: git-submodule.sh:282
 #, sh-format
 msgid ""
 "If you want to reuse this local git directory instead of cloning again from\n"
@@ -15794,50 +23054,39 @@ msgstr ""
 "o no esteu segur de què vol dir això, trieu un altre nom amb l'opció '--"
 "name'."
 
-#: git-submodule.sh:255
+#: git-submodule.sh:288
 #, sh-format
 msgid "Reactivating local git directory for submodule '$sm_name'."
 msgstr ""
 "S'està reactivant el directori de git local per al submòdul '$sm_name'."
 
-#: git-submodule.sh:267
+#: git-submodule.sh:300
 #, sh-format
 msgid "Unable to checkout submodule '$sm_path'"
 msgstr "No s'ha pogut agafar el submòdul '$sm_path'"
 
-#: git-submodule.sh:272
+#: git-submodule.sh:305
 #, sh-format
 msgid "Failed to add submodule '$sm_path'"
 msgstr "S'ha produït un error en afegir el submòdul '$sm_path'"
 
-#: git-submodule.sh:281
+#: git-submodule.sh:314
 #, sh-format
 msgid "Failed to register submodule '$sm_path'"
 msgstr "S'ha produït un error en registrar el submòdul '$sm_path'"
 
-#: git-submodule.sh:342
-#, sh-format
-msgid "Entering '$displaypath'"
-msgstr "S'està entrant '$displaypath'"
-
-#: git-submodule.sh:362
-#, sh-format
-msgid "Stopping at '$displaypath'; script returned non-zero status."
-msgstr ""
-"S'està aturant a '$displaypath'; l'script ha retornat un estat no zero."
-
-#: git-submodule.sh:584
+#: git-submodule.sh:580
 #, sh-format
 msgid "Unable to find current revision in submodule path '$displaypath'"
 msgstr ""
 "No s'ha pogut trobar la revisió actual en el camí de submòdul '$displaypath'"
 
-#: git-submodule.sh:594
+#: git-submodule.sh:590
 #, sh-format
 msgid "Unable to fetch in submodule path '$sm_path'"
 msgstr "No s'ha pogut obtenir en el camí de submòdul '$sm_path'"
 
-#: git-submodule.sh:599
+#: git-submodule.sh:595
 #, sh-format
 msgid ""
 "Unable to find current ${remote_name}/${branch} revision in submodule path "
@@ -15846,90 +23095,94 @@ msgstr ""
 "No s'ha pogut trobar la revisió actual de ${remote_name}/${branch} en el "
 "camí de submòdul '$sm_path'"
 
-#: git-submodule.sh:617
+#: git-submodule.sh:613
 #, sh-format
-msgid "Unable to fetch in submodule path '$displaypath'"
-msgstr "No s'ha pogut obtenir en el camí de submòdul '$displaypath'"
+msgid ""
+"Unable to fetch in submodule path '$displaypath'; trying to directly fetch "
+"$sha1:"
+msgstr ""
+"No s'ha pogut obtenir en el camí de submòdul «$displaypath»; s'està "
+"intentant obtenir directament $sha1:"
 
-#: git-submodule.sh:623
+#: git-submodule.sh:619
 #, sh-format
 msgid ""
 "Fetched in submodule path '$displaypath', but it did not contain $sha1. "
 "Direct fetching of that commit failed."
 msgstr ""
-"S'ha obtingut en el camí de submòdul '$displaypath', però no contenia $sha1. "
+"S'ha obtingut en el camí de submòdul «$displaypath», però no contenia $sha1. "
 "L'obtenció directa d'aquella comissió ha fallat."
 
-#: git-submodule.sh:630
+#: git-submodule.sh:626
 #, sh-format
 msgid "Unable to checkout '$sha1' in submodule path '$displaypath'"
-msgstr "No s'ha pogut agafar '$sha1' en el camí de submòdul '$displaypath'"
+msgstr "No s'ha pogut agafar «$sha1» en el camí de submòdul «$displaypath»"
 
-#: git-submodule.sh:631
+#: git-submodule.sh:627
 #, sh-format
 msgid "Submodule path '$displaypath': checked out '$sha1'"
-msgstr "Camí de submòdul '$displaypath': s'ha agafat '$sha1'"
+msgstr "Camí de submòdul «$displaypath»: s'ha agafat «$sha1»"
 
-#: git-submodule.sh:635
+#: git-submodule.sh:631
 #, sh-format
 msgid "Unable to rebase '$sha1' in submodule path '$displaypath'"
 msgstr ""
-"No s'ha pogut fer «rebase» '$sha1' en el camí de submòdul '$displaypath'"
+"No s'ha pogut fer «rebase» «$sha1»' en el camí de submòdul «$displaypath»"
 
-#: git-submodule.sh:636
+#: git-submodule.sh:632
 #, sh-format
 msgid "Submodule path '$displaypath': rebased into '$sha1'"
-msgstr "Camí de submòdul '$displaypath': s'ha fet «rebase» en '$sha1'"
+msgstr "Camí de submòdul «$displaypath»: s'ha fet «rebase» en «$sha1»"
 
-#: git-submodule.sh:641
+#: git-submodule.sh:637
 #, sh-format
 msgid "Unable to merge '$sha1' in submodule path '$displaypath'"
-msgstr "No s'ha pogut fusionar '$sha1' en el camí de submòdul '$displaypath'"
+msgstr "No s'ha pogut fusionar «$sha1» en el camí de submòdul «$displaypath»"
 
-#: git-submodule.sh:642
+#: git-submodule.sh:638
 #, sh-format
 msgid "Submodule path '$displaypath': merged in '$sha1'"
-msgstr "Camí de submòdul '$displaypath': s'ha fusionat en '$sha1'"
+msgstr "Camí de submòdul «$displaypath»: s'ha fusionat en «$sha1»"
 
-#: git-submodule.sh:647
+#: git-submodule.sh:643
 #, sh-format
 msgid "Execution of '$command $sha1' failed in submodule path '$displaypath'"
 msgstr ""
-"L'execució de '$command $sha1' ha fallat en el camí de submòdul "
-"'$displaypath'"
+"L'execució de «$command $sha1» ha fallat en el camí de submòdul "
+"«$displaypath»"
 
-#: git-submodule.sh:648
+#: git-submodule.sh:644
 #, sh-format
 msgid "Submodule path '$displaypath': '$command $sha1'"
-msgstr "Camí de submòdul '$displaypath': '$command $sha1'"
+msgstr "Camí de submòdul «$displaypath»: «$command $sha1»"
 
-#: git-submodule.sh:679
+#: git-submodule.sh:675
 #, sh-format
 msgid "Failed to recurse into submodule path '$displaypath'"
 msgstr ""
 "S'ha produït un error en recorre recursivament dins del camí de submòdul "
-"'$displaypath'"
+"«$displaypath»"
 
-#: git-submodule.sh:775
+#: git-submodule.sh:886
 msgid "The --cached option cannot be used with the --files option"
 msgstr "L'opció --cached no es pot usar amb l'opció --files"
 
-#: git-submodule.sh:827
+#: git-submodule.sh:938
 #, sh-format
 msgid "unexpected mode $mod_dst"
 msgstr "mode inesperat $mod_dst"
 
-#: git-submodule.sh:847
+#: git-submodule.sh:958
 #, sh-format
 msgid "  Warn: $display_name doesn't contain commit $sha1_src"
 msgstr "  Avís: $display_name no conté la comissió $sha1_src"
 
-#: git-submodule.sh:850
+#: git-submodule.sh:961
 #, sh-format
 msgid "  Warn: $display_name doesn't contain commit $sha1_dst"
 msgstr "  Avís: $display_name no conté la comissió $sha1_dst"
 
-#: git-submodule.sh:853
+#: git-submodule.sh:964
 #, sh-format
 msgid "  Warn: $display_name doesn't contain commits $sha1_src and $sha1_dst"
 msgstr "  Avís: $display_name no conté les comissions $sha1_src i $sha1_dst"
@@ -15939,32 +23192,48 @@ msgstr "  Avís: $display_name no conté
 msgid "See git-${cmd}(1) for details."
 msgstr "Vegeu git-${cmd}(1) per detalls."
 
-#: git-rebase--interactive.sh:140
+#: git-rebase--preserve-merges.sh:109
+msgid "Applied autostash."
+msgstr "S'ha aplicat l'«autostash»."
+
+#: git-rebase--preserve-merges.sh:112
+#, sh-format
+msgid "Cannot store $stash_sha1"
+msgstr "No es pot emmagatzemar $stash_sha1"
+
+#: git-rebase--preserve-merges.sh:191
 #, sh-format
 msgid "Rebasing ($new_count/$total)"
 msgstr "S'està fent «rebase» ($new_count/$total)"
 
-#: git-rebase--interactive.sh:156
+#: git-rebase--preserve-merges.sh:207
+#, fuzzy
 msgid ""
 "\n"
 "Commands:\n"
-"p, pick = use commit\n"
-"r, reword = use commit, but edit the commit message\n"
-"e, edit = use commit, but stop for amending\n"
-"s, squash = use commit, but meld into previous commit\n"
-"f, fixup = like \"squash\", but discard this commit's log message\n"
-"x, exec = run command (the rest of the line) using shell\n"
-"d, drop = remove commit\n"
+"p, pick <commit> = use commit\n"
+"r, reword <commit> = use commit, but edit the commit message\n"
+"e, edit <commit> = use commit, but stop for amending\n"
+"s, squash <commit> = use commit, but meld into previous commit\n"
+"f, fixup <commit> = like \"squash\", but discard this commit's log message\n"
+"x, exec <commit> = run command (the rest of the line) using shell\n"
+"d, drop <commit> = remove commit\n"
+"l, label <label> = label current HEAD with a name\n"
+"t, reset <label> = reset HEAD to a label\n"
+"m, merge [-C <commit> | -c <commit>] <label> [# <oneline>]\n"
+".       create a merge commit using the original merge commit's\n"
+".       message (or the oneline, if no original merge commit was\n"
+".       specified). Use -c <commit> to reword the commit message.\n"
 "\n"
 "These lines can be re-ordered; they are executed from top to bottom.\n"
 msgstr ""
 "\n"
 "Ordres:\n"
-" p, pick = usa la comissió\n"
-" r, reword = usa la comissió, però edita el missatge de comissió\n"
-" e, edit = usa la comissió, però atura't per a esmenar\n"
-" s, squash = usa la comissió, però fusiona'l a la comissió prèvia\n"
-" f, fixup = com \"squash\", però descarta el missatge de registre d'aquesta "
+" p, pick <comissió> = usa la comissió\n"
+" r, reword <comissió> = usa la comissió, però edita el missatge de comissió\n"
+" e, edit <comissió> = usa la comissió, però atura't per a esmenar\n"
+" s, squash <comissió> = usa la comissió, però fusiona'l a la comissió prèvia\n"
+" f, fixup <comissió> = com \"squash\", però descarta el missatge de registre d'aquesta "
 "comissió\n"
 " x, exec = executa l'ordre (la resta de la línia) usant l'intèrpret "
 "d'ordres\n"
@@ -15972,24 +23241,7 @@ msgstr ""
 "\n"
 "Es pot canviar l'ordre d'aquestes línies; s'executen de dalt a baix.\n"
 
-#: git-rebase--interactive.sh:171
-msgid ""
-"\n"
-"Do not remove any line. Use 'drop' explicitly to remove a commit.\n"
-msgstr ""
-"\n"
-"No elimineu cap línia. Useu 'drop' explícitament per a eliminar una "
-"comissió.\n"
-
-#: git-rebase--interactive.sh:175
-msgid ""
-"\n"
-"If you remove a line here THAT COMMIT WILL BE LOST.\n"
-msgstr ""
-"\n"
-"Si elimineu una línia aquí, ES PERDRÀ AQUELLA COMISSIÓ.\n"
-
-#: git-rebase--interactive.sh:213
+#: git-rebase--preserve-merges.sh:270
 #, sh-format
 msgid ""
 "You can amend the commit now, with\n"
@@ -16008,83 +23260,83 @@ msgstr ""
 "\n"
 "\tgit rebase --continue"
 
-#: git-rebase--interactive.sh:238
+#: git-rebase--preserve-merges.sh:295
 #, sh-format
 msgid "$sha1: not a commit that can be picked"
 msgstr "$sha1: no és una comissió que es pugui escollir"
 
-#: git-rebase--interactive.sh:277
+#: git-rebase--preserve-merges.sh:334
 #, sh-format
 msgid "Invalid commit name: $sha1"
 msgstr "Nom de comissió no vàlid: $sha1"
 
-#: git-rebase--interactive.sh:319
+#: git-rebase--preserve-merges.sh:364
 msgid "Cannot write current commit's replacement sha1"
 msgstr "No es pot escriure el sha1 reemplaçant de la comissió actual"
 
-#: git-rebase--interactive.sh:371
+#: git-rebase--preserve-merges.sh:415
 #, sh-format
 msgid "Fast-forward to $sha1"
 msgstr "Avanç ràpid a $sha1"
 
-#: git-rebase--interactive.sh:373
+#: git-rebase--preserve-merges.sh:417
 #, sh-format
 msgid "Cannot fast-forward to $sha1"
 msgstr "No es pot avançar ràpidament a $sha1"
 
-#: git-rebase--interactive.sh:382
+#: git-rebase--preserve-merges.sh:426
 #, sh-format
 msgid "Cannot move HEAD to $first_parent"
 msgstr "No es pot moure HEAD a $first_parent"
 
-#: git-rebase--interactive.sh:387
+#: git-rebase--preserve-merges.sh:431
 #, sh-format
 msgid "Refusing to squash a merge: $sha1"
 msgstr "S'està refusant fer «squash» a una fusió: $sha1"
 
-#: git-rebase--interactive.sh:405
+#: git-rebase--preserve-merges.sh:449
 #, sh-format
 msgid "Error redoing merge $sha1"
 msgstr "Error en refer la fusió $sha1"
 
-#: git-rebase--interactive.sh:414
+#: git-rebase--preserve-merges.sh:458
 #, sh-format
 msgid "Could not pick $sha1"
 msgstr "No s'ha pogut escollir $sha1"
 
-#: git-rebase--interactive.sh:423
+#: git-rebase--preserve-merges.sh:467
 #, sh-format
 msgid "This is the commit message #${n}:"
 msgstr "Aquest és el missatge de comissió núm. ${n}:"
 
-#: git-rebase--interactive.sh:428
+#: git-rebase--preserve-merges.sh:472
 #, sh-format
 msgid "The commit message #${n} will be skipped:"
 msgstr "El missatge de comissió núm. ${n} s'ometrà:"
 
-#: git-rebase--interactive.sh:439
+#: git-rebase--preserve-merges.sh:483
 #, sh-format
 msgid "This is a combination of $count commit."
 msgid_plural "This is a combination of $count commits."
 msgstr[0] "Això és una combinació de $count comissió."
 msgstr[1] "Això és una combinació de $count comissions."
 
-#: git-rebase--interactive.sh:448
+#: git-rebase--preserve-merges.sh:492
 #, sh-format
 msgid "Cannot write $fixup_msg"
 msgstr "No es pot escriure $fixup_msg"
 
-#: git-rebase--interactive.sh:451
+#: git-rebase--preserve-merges.sh:495
 msgid "This is a combination of 2 commits."
 msgstr "Això és una combinació de 2 comissions."
 
-#: git-rebase--interactive.sh:492 git-rebase--interactive.sh:535
-#: git-rebase--interactive.sh:538
+#: git-rebase--preserve-merges.sh:536 git-rebase--preserve-merges.sh:579
+#: git-rebase--preserve-merges.sh:582
 #, sh-format
 msgid "Could not apply $sha1... $rest"
 msgstr "No s'ha pogut aplicar $sha1... $rest"
 
-#: git-rebase--interactive.sh:567
+#: git-rebase--preserve-merges.sh:611
 #, sh-format
 msgid ""
 "Could not amend commit after successfully picking $sha1... $rest\n"
@@ -16100,31 +23352,31 @@ msgstr ""
 "necessiteu resoldre el problema abans que pugueu canviar el missatge de\n"
 "comissió."
 
-#: git-rebase--interactive.sh:582
+#: git-rebase--preserve-merges.sh:626
 #, sh-format
 msgid "Stopped at $sha1_abbrev... $rest"
 msgstr "S'ha aturat a $sha1_abbrev... $rest"
 
-#: git-rebase--interactive.sh:597
+#: git-rebase--preserve-merges.sh:641
 #, sh-format
 msgid "Cannot '$squash_style' without a previous commit"
 msgstr "No es pot '$squash_style' sense una comissió prèvia"
 
-#: git-rebase--interactive.sh:639
+#: git-rebase--preserve-merges.sh:683
 #, sh-format
 msgid "Executing: $rest"
 msgstr "S'està executant: $rest"
 
-#: git-rebase--interactive.sh:647
+#: git-rebase--preserve-merges.sh:691
 #, sh-format
 msgid "Execution failed: $rest"
 msgstr "L'execució ha fallat: $rest"
 
-#: git-rebase--interactive.sh:649
+#: git-rebase--preserve-merges.sh:693
 msgid "and made changes to the index and/or the working tree"
 msgstr "i ha fet canvis a l'índex o l'arbre de treball"
 
-#: git-rebase--interactive.sh:651
+#: git-rebase--preserve-merges.sh:695
 msgid ""
 "You can fix the problem, and then run\n"
 "\n"
@@ -16135,7 +23387,7 @@ msgstr ""
 "\tgit rebase --continue"
 
 #. TRANSLATORS: after these lines is a command to be issued by the user
-#: git-rebase--interactive.sh:664
+#: git-rebase--preserve-merges.sh:708
 #, sh-format
 msgid ""
 "Execution succeeded: $rest\n"
@@ -16150,29 +23402,25 @@ msgstr ""
 "\n"
 "\tgit rebase --continue"
 
-#: git-rebase--interactive.sh:675
+#: git-rebase--preserve-merges.sh:719
 #, sh-format
 msgid "Unknown command: $command $sha1 $rest"
 msgstr "Ordre desconeguda: $command $sha1 $rest"
 
-#: git-rebase--interactive.sh:676
+#: git-rebase--preserve-merges.sh:720
 msgid "Please fix this using 'git rebase --edit-todo'."
 msgstr "Corregiu-ho usant «git rebase --edit-todo»."
 
-#: git-rebase--interactive.sh:711
+#: git-rebase--preserve-merges.sh:755
 #, sh-format
 msgid "Successfully rebased and updated $head_name."
 msgstr "S'ha fet «rebase» i actualitzat $head_name amb èxit."
 
-#: git-rebase--interactive.sh:735
-msgid "could not detach HEAD"
-msgstr "no s'ha pogut separar HEAD"
-
-#: git-rebase--interactive.sh:771
+#: git-rebase--preserve-merges.sh:812
 msgid "Could not remove CHERRY_PICK_HEAD"
 msgstr "No s'ha pogut eliminar CHERRY_PICK_HEAD"
 
-#: git-rebase--interactive.sh:776
+#: git-rebase--preserve-merges.sh:817
 #, sh-format
 msgid ""
 "You have staged changes in your working tree.\n"
@@ -16203,13 +23451,13 @@ msgstr ""
 "\n"
 "  git rebase --continue\n"
 
-#: git-rebase--interactive.sh:793
+#: git-rebase--preserve-merges.sh:834
 msgid "Error trying to find the author identity to amend commit"
 msgstr ""
 "Hi ha hagut un error en intentar trobar la identitat d'autor per a esmenar "
 "la comissió"
 
-#: git-rebase--interactive.sh:798
+#: git-rebase--preserve-merges.sh:839
 msgid ""
 "You have uncommitted changes in your working tree. Please commit them\n"
 "first and then run 'git rebase --continue' again."
@@ -16217,212 +23465,118 @@ msgstr ""
 "Teniu canvis no comesos en el vostre arbre de treball. \n"
 "Primer cometeu-los i després executeu «git rebase --continue» de nou."
 
-#: git-rebase--interactive.sh:803 git-rebase--interactive.sh:807
+#: git-rebase--preserve-merges.sh:844 git-rebase--preserve-merges.sh:848
 msgid "Could not commit staged changes."
 msgstr "No s'han pogut cometre els canvis «staged»."
 
-#: git-rebase--interactive.sh:836
-msgid ""
-"\n"
-"You are editing the todo file of an ongoing interactive rebase.\n"
-"To continue rebase after editing, run:\n"
-"    git rebase --continue\n"
-"\n"
-msgstr ""
-"\n"
-"Esteu editant el fitxer de coses a fer d'un «rebase» interactiu en marxa.\n"
-"Per a continuar el «rebase» després d'editar, executeu:\n"
-"    git rebase --continue\n"
-"\n"
-
-#: git-rebase--interactive.sh:844 git-rebase--interactive.sh:1008
+#: git-rebase--preserve-merges.sh:879 git-rebase--preserve-merges.sh:965
 msgid "Could not execute editor"
 msgstr "No s'ha pogut executar l'editor"
 
-#: git-rebase--interactive.sh:860
+#: git-rebase--preserve-merges.sh:900
 #, sh-format
 msgid "Could not checkout $switch_to"
 msgstr "No s'ha pogut agafar $switch_to"
 
-#: git-rebase--interactive.sh:865
+#: git-rebase--preserve-merges.sh:907
 msgid "No HEAD?"
 msgstr "No hi ha cap HEAD?"
 
-#: git-rebase--interactive.sh:866
+#: git-rebase--preserve-merges.sh:908
 #, sh-format
 msgid "Could not create temporary $state_dir"
 msgstr "No s'ha pogut crear el $state_dir temporal"
 
-#: git-rebase--interactive.sh:869
+#: git-rebase--preserve-merges.sh:911
 msgid "Could not mark as interactive"
 msgstr "No s'ha pogut marcar com a interactiu"
 
-#: git-rebase--interactive.sh:879 git-rebase--interactive.sh:884
-msgid "Could not init rewritten commits"
-msgstr "No s'han pogut iniciar les comissions reescrites"
-
-#: git-rebase--interactive.sh:910
-msgid "Could not generate todo list"
-msgstr "no s'ha pogut escriure la llista per a fer"
-
-#: git-rebase--interactive.sh:986
+#: git-rebase--preserve-merges.sh:943
 #, sh-format
 msgid "Rebase $shortrevisions onto $shortonto ($todocount command)"
 msgid_plural "Rebase $shortrevisions onto $shortonto ($todocount commands)"
-msgstr[0] "Rebasa $shortrevisions sobre $shortonto ($todocount ordre)"
-msgstr[1] "Rebasa $shortrevisions sobre $shortonto ($todocount ordres)"
-
-#: git-rebase--interactive.sh:991
-msgid ""
-"\n"
-"However, if you remove everything, the rebase will be aborted.\n"
-"\n"
-msgstr ""
-"\n"
-"No obstant, si elimineu tot, s'avortarà el «rebase».\n"
-"\n"
+msgstr[0] "Fes «rebase» $shortrevisions sobre $shortonto ($todocount ordre)"
+msgstr[1] "Fes «rebase» $shortrevisions sobre $shortonto ($todocount ordres)"
 
-#: git-rebase--interactive.sh:998
-msgid "Note that empty commits are commented out"
-msgstr "Nota que les comissions buides estan comentades"
+#: git-rebase--preserve-merges.sh:997 git-rebase--preserve-merges.sh:1002
+msgid "Could not init rewritten commits"
+msgstr "No s'han pogut iniciar les comissions reescrites"
 
 #: git-sh-setup.sh:89 git-sh-setup.sh:94
 #, sh-format
 msgid "usage: $dashless $USAGE"
 msgstr "ús: $dashless $USAGE"
 
-#: git-sh-setup.sh:190
+#: git-sh-setup.sh:191
 #, sh-format
 msgid "Cannot chdir to $cdup, the toplevel of the working tree"
 msgstr ""
 "No es pot canviar de directori a $cdup, el nivell superior de l'arbre de "
 "treball"
 
-#: git-sh-setup.sh:199 git-sh-setup.sh:206
+#: git-sh-setup.sh:200 git-sh-setup.sh:207
 #, sh-format
 msgid "fatal: $program_name cannot be used without a working tree."
 msgstr "fatal: no es pot usar $program_name sense un arbre de treball."
 
-#: git-sh-setup.sh:220
+#: git-sh-setup.sh:221
 msgid "Cannot rebase: You have unstaged changes."
 msgstr "No es pot fer «rebase»: teniu canvis «unstaged»."
 
-#: git-sh-setup.sh:223
+#: git-sh-setup.sh:224
 msgid "Cannot rewrite branches: You have unstaged changes."
 msgstr "No es poden reescriure branques: Teniu canvis «unstaged»."
 
-#: git-sh-setup.sh:226
+#: git-sh-setup.sh:227
 msgid "Cannot pull with rebase: You have unstaged changes."
 msgstr "No es pot baixar fent «rebase»: Teniu canvis «unstaged»."
 
-#: git-sh-setup.sh:229
+#: git-sh-setup.sh:230
 #, sh-format
 msgid "Cannot $action: You have unstaged changes."
 msgstr "No es pot $action: Teniu canvis «unstaged»."
 
-#: git-sh-setup.sh:242
+#: git-sh-setup.sh:243
 msgid "Cannot rebase: Your index contains uncommitted changes."
 msgstr "No es pot fer «rebase»: El vostre índex conté canvis sense cometre."
 
-#: git-sh-setup.sh:245
+#: git-sh-setup.sh:246
 msgid "Cannot pull with rebase: Your index contains uncommitted changes."
 msgstr ""
 "No es pot baixar fent «rebase»: El vostre índex conté canvis sense cometre."
 
-#: git-sh-setup.sh:248
+#: git-sh-setup.sh:249
 #, sh-format
 msgid "Cannot $action: Your index contains uncommitted changes."
 msgstr "No es pot $action: El vostre índex conté canvis sense cometre."
 
-#: git-sh-setup.sh:252
+#: git-sh-setup.sh:253
 msgid "Additionally, your index contains uncommitted changes."
 msgstr "Addicionalment, el vostre índex conté canvis sense cometre."
 
-#: git-sh-setup.sh:372
+#: git-sh-setup.sh:373
 msgid "You need to run this command from the toplevel of the working tree."
 msgstr ""
 "Heu d'executar aquesta ordre des del nivell superior de l'arbre de treball."
 
-#: git-sh-setup.sh:377
+#: git-sh-setup.sh:378
 msgid "Unable to determine absolute path of git directory"
 msgstr "No s'ha pogut determinar el camí absolut del directori de git"
 
 #. TRANSLATORS: you can adjust this to align "git add -i" status menu
-#: git-add--interactive.perl:196
+#: git-add--interactive.perl:212
 #, perl-format
 msgid "%12s %12s %s"
 msgstr "%12s %12s %s"
 
-#: git-add--interactive.perl:197
-msgid "staged"
-msgstr "staged"
-
-#: git-add--interactive.perl:197
-msgid "unstaged"
-msgstr "unstaged"
-
-#: git-add--interactive.perl:246 git-add--interactive.perl:271
-msgid "binary"
-msgstr "binari"
-
-#: git-add--interactive.perl:255 git-add--interactive.perl:309
-msgid "nothing"
-msgstr "res"
-
-#: git-add--interactive.perl:291 git-add--interactive.perl:306
-msgid "unchanged"
-msgstr "sense canvis"
-
-#: git-add--interactive.perl:602
-#, perl-format
-msgid "added %d path\n"
-msgid_plural "added %d paths\n"
-msgstr[0] "afegit %d camí\n"
-msgstr[1] "afegits %d camins\n"
-
-#: git-add--interactive.perl:605
-#, perl-format
-msgid "updated %d path\n"
-msgid_plural "updated %d paths\n"
-msgstr[0] "actualitzat %d camí\n"
-msgstr[1] "actualitzats %d camins\n"
-
-#: git-add--interactive.perl:608
-#, perl-format
-msgid "reverted %d path\n"
-msgid_plural "reverted %d paths\n"
-msgstr[0] "revertit %d camí\n"
-msgstr[1] "revertits %d camins\n"
-
-#: git-add--interactive.perl:611
+#: git-add--interactive.perl:634
 #, perl-format
 msgid "touched %d path\n"
 msgid_plural "touched %d paths\n"
 msgstr[0] "modificat %d camí\n"
 msgstr[1] "modificat %d camins\n"
 
-#: git-add--interactive.perl:620
-msgid "Update"
-msgstr "Actualitza"
-
-#: git-add--interactive.perl:632
-msgid "Revert"
-msgstr "Reverteix"
-
-#: git-add--interactive.perl:655
-#, perl-format
-msgid "note: %s is untracked now.\n"
-msgstr "nota: %s està ara sense seguiment.\n"
-
-#: git-add--interactive.perl:666
-msgid "Add untracked"
-msgstr "Afegeix sense seguiment"
-
-#: git-add--interactive.perl:672
-msgid "No untracked files.\n"
-msgstr "Sense fitxers no seguits.\n"
-
-#: git-add--interactive.perl:1026
+#: git-add--interactive.perl:1053
 msgid ""
 "If the patch applies cleanly, the edited hunk will immediately be\n"
 "marked for staging."
@@ -16430,7 +23584,7 @@ msgstr ""
 "Si el pedaç s'aplica correctament, el tros editat es marcarà immediatament\n"
 "per «staging»."
 
-#: git-add--interactive.perl:1029
+#: git-add--interactive.perl:1056
 msgid ""
 "If the patch applies cleanly, the edited hunk will immediately be\n"
 "marked for stashing."
@@ -16438,7 +23592,7 @@ msgstr ""
 "Si el pedaç s'aplica correctament, el tros editat es marcarà immediatament\n"
 "per «stashing»."
 
-#: git-add--interactive.perl:1032
+#: git-add--interactive.perl:1059
 msgid ""
 "If the patch applies cleanly, the edited hunk will immediately be\n"
 "marked for unstaging."
@@ -16446,7 +23600,8 @@ msgstr ""
 "Si el pedaç s'aplica correctament, el tros editat es marcarà immediatament\n"
 "per «unstaging»."
 
-#: git-add--interactive.perl:1035 git-add--interactive.perl:1044
+#: git-add--interactive.perl:1062 git-add--interactive.perl:1071
+#: git-add--interactive.perl:1077
 msgid ""
 "If the patch applies cleanly, the edited hunk will immediately be\n"
 "marked for applying."
@@ -16454,7 +23609,8 @@ msgstr ""
 "Si el pedaç s'aplica correctament, el tros editat es marcarà immediatament\n"
 "per aplicar-se."
 
-#: git-add--interactive.perl:1038 git-add--interactive.perl:1041
+#: git-add--interactive.perl:1065 git-add--interactive.perl:1068
+#: git-add--interactive.perl:1074
 msgid ""
 "If the patch applies cleanly, the edited hunk will immediately be\n"
 "marked for discarding."
@@ -16462,17 +23618,12 @@ msgstr ""
 "Si el pedaç s'aplica correctament, el tros editat es marcarà immediatament\n"
 "per descartar-se."
 
-#: git-add--interactive.perl:1078
+#: git-add--interactive.perl:1111
 #, perl-format
 msgid "failed to open hunk edit file for writing: %s"
 msgstr "s'ha produït un error en escriure al fitxer d'edició del tros: %s"
 
-#: git-add--interactive.perl:1079
-msgid "Manual hunk edit mode -- see bottom for a quick guide.\n"
-msgstr ""
-"Mode d'edició de trossos manual - vegeu més avall per una guia ràpida.\n"
-
-#: git-add--interactive.perl:1085
+#: git-add--interactive.perl:1118
 #, perl-format
 msgid ""
 "---\n"
@@ -16485,37 +23636,12 @@ msgstr ""
 "Per suprimir «%s» línies, suprimiu-les.\n"
 "Les línies que comencin per %s seran suprimides.\n"
 
-#. TRANSLATORS: 'it' refers to the patch mentioned in the previous messages.
-#: git-add--interactive.perl:1093
-msgid ""
-"If it does not apply cleanly, you will be given an opportunity to\n"
-"edit again.  If all lines of the hunk are removed, then the edit is\n"
-"aborted and the hunk is left unchanged.\n"
-msgstr ""
-"Si no s'aplica correctament, tindreu una oportunitat per editar-lo\n"
-"de nou. Si totes les línies del tros se suprimeixen, llavors l'edició "
-"s'avorta\n"
-"i el tros es deixa sense cap canvi.\n"
-
-#: git-add--interactive.perl:1107
+#: git-add--interactive.perl:1140
 #, perl-format
 msgid "failed to open hunk edit file for reading: %s"
 msgstr "s'ha produït un error en llegir al fitxer d'edició del tros: %s"
 
-#. TRANSLATORS: do not translate [y/n]
-#. The program will only accept that input
-#. at this point.
-#. Consider translating (saying "no" discards!) as
-#. (saying "n" for "no" discards!) if the translation
-#. of the word "no" does not start with n.
-#: git-add--interactive.perl:1206
-msgid ""
-"Your edited hunk does not apply. Edit again (saying \"no\" discards!) [y/n]? "
-msgstr ""
-"El tros editat no s'aplica. Editeu-lo de nou (si responeu \"no\" es "
-"descartarà) [y/n]? "
-
-#: git-add--interactive.perl:1215
+#: git-add--interactive.perl:1248
 msgid ""
 "y - stage this hunk\n"
 "n - do not stage this hunk\n"
@@ -16529,7 +23655,7 @@ msgstr ""
 "a - fes «stage» d'aquest tros i tota la resta de trossos del fitxer\n"
 "d - no facis «stage» d'aquest tros o de cap altre restant del fitxer"
 
-#: git-add--interactive.perl:1221
+#: git-add--interactive.perl:1254
 msgid ""
 "y - stash this hunk\n"
 "n - do not stash this hunk\n"
@@ -16543,7 +23669,7 @@ msgstr ""
 "a - fes «stash» d'aquest tros i tota la resta de trossos del fitxer\n"
 "d - no facis «stash» d'aquest tros o de cap altre restant del fitxer"
 
-#: git-add--interactive.perl:1227
+#: git-add--interactive.perl:1260
 msgid ""
 "y - unstage this hunk\n"
 "n - do not unstage this hunk\n"
@@ -16557,7 +23683,7 @@ msgstr ""
 "a - fes «unstage» d'aquest tros i tota la resta de trossos del fitxer\n"
 "d - no facis «unstage» d'aquest tros o de cap altre restant del fitxer"
 
-#: git-add--interactive.perl:1233
+#: git-add--interactive.perl:1266
 msgid ""
 "y - apply this hunk to index\n"
 "n - do not apply this hunk to index\n"
@@ -16571,7 +23697,7 @@ msgstr ""
 "a - aplica aquest tros i tots els trossos posteriors en el fitxer\n"
 "d - no apliquis aquest tros ni cap dels trossos posteriors en el fitxer"
 
-#: git-add--interactive.perl:1239
+#: git-add--interactive.perl:1272 git-add--interactive.perl:1290
 msgid ""
 "y - discard this hunk from worktree\n"
 "n - do not discard this hunk from worktree\n"
@@ -16585,7 +23711,7 @@ msgstr ""
 "a - descarta aquest tros i tots els trossos posteriors en el fitxer\n"
 "d - no descartis aquest tros ni cap dels trossos posteriors en el fitxer"
 
-#: git-add--interactive.perl:1245
+#: git-add--interactive.perl:1278
 msgid ""
 "y - discard this hunk from index and worktree\n"
 "n - do not discard this hunk from index and worktree\n"
@@ -16599,7 +23725,7 @@ msgstr ""
 "a - descarta aquest tros i tots els trossos posteriors en el fitxer\n"
 "d - no descartis aquest tros ni cap dels trossos posteriors en el fitxer"
 
-#: git-add--interactive.perl:1251
+#: git-add--interactive.perl:1284
 msgid ""
 "y - apply this hunk to index and worktree\n"
 "n - do not apply this hunk to index and worktree\n"
@@ -16613,7 +23739,21 @@ msgstr ""
 "a - aplica aquest tros i tots els trossos posteriors en el fitxer\n"
 "d - no apliquis aquest tros ni cap dels trossos posteriors en el fitxer"
 
-#: git-add--interactive.perl:1266
+#: git-add--interactive.perl:1296
+msgid ""
+"y - apply this hunk to worktree\n"
+"n - do not apply this hunk to worktree\n"
+"q - quit; do not apply this hunk or any of the remaining ones\n"
+"a - apply this hunk and all later hunks in the file\n"
+"d - do not apply this hunk or any of the later hunks in the file"
+msgstr ""
+"y - aplica aquest tros a l'arbre de treball\n"
+"n - no apliquis aquest tros a l'arbre de treball\n"
+"q - surt; no apliquis aquest tros ni cap dels pendents\n"
+"a - aplica aquest tros i tots els trossos posteriors en el fitxer\n"
+"d - no apliquis aquest tros ni cap dels trossos posteriors en el fitxer"
+
+#: git-add--interactive.perl:1311
 msgid ""
 "g - select a hunk to go to\n"
 "/ - search for a hunk matching the given regex\n"
@@ -16635,216 +23775,203 @@ msgstr ""
 "e - edita manualment el tros actual\n"
 "? - mostra l'ajuda\n"
 
-#: git-add--interactive.perl:1297
+#: git-add--interactive.perl:1342
 msgid "The selected hunks do not apply to the index!\n"
 msgstr "Els trossos seleccionats no apliquen a l'índex\n"
 
-#: git-add--interactive.perl:1298
+#: git-add--interactive.perl:1343
 msgid "Apply them to the worktree anyway? "
 msgstr "Voleu aplicar-los igualment a l'arbre de treball? "
 
-#: git-add--interactive.perl:1301
+#: git-add--interactive.perl:1346
 msgid "Nothing was applied.\n"
 msgstr "No s'ha aplicat res.\n"
 
-#: git-add--interactive.perl:1312
+#: git-add--interactive.perl:1357
 #, perl-format
 msgid "ignoring unmerged: %s\n"
 msgstr "s'està ignorant %s no fusionat\n"
 
-#: git-add--interactive.perl:1321
-msgid "Only binary files changed.\n"
-msgstr "Només s'han canviat els fitxers binaris.\n"
-
-#: git-add--interactive.perl:1323
-msgid "No changes.\n"
-msgstr "Sense canvis.\n"
-
-#: git-add--interactive.perl:1331
-msgid "Patch update"
-msgstr "Actualització del pedaç"
-
-#: git-add--interactive.perl:1383
+#: git-add--interactive.perl:1428
 #, perl-format
 msgid "Stage mode change [y,n,q,a,d%s,?]? "
 msgstr "Canvia el mode de «stage» [y,n,q,a,d%s,?]? "
 
-#: git-add--interactive.perl:1384
+#: git-add--interactive.perl:1429
 #, perl-format
 msgid "Stage deletion [y,n,q,a,d%s,?]? "
 msgstr "Suprimeix «stage» [y,n,q,a,d%s,?]? "
 
-#: git-add--interactive.perl:1385
+#: git-add--interactive.perl:1430
 #, perl-format
 msgid "Stage this hunk [y,n,q,a,d%s,?]? "
 msgstr "Fer un «stage» d'aquest tros [y,n,q,a,d%s,?]? "
 
-#: git-add--interactive.perl:1388
+#: git-add--interactive.perl:1433
 #, perl-format
 msgid "Stash mode change [y,n,q,a,d%s,?]? "
 msgstr "Canvia el mode de «stash» [y,n,q,a,d%s,?]? "
 
-#: git-add--interactive.perl:1389
+#: git-add--interactive.perl:1434
 #, perl-format
 msgid "Stash deletion [y,n,q,a,d%s,?]? "
 msgstr "Suprimeix «stash» [y,n,q,a,d%s,?]? "
 
-#: git-add--interactive.perl:1390
+#: git-add--interactive.perl:1435
 #, perl-format
 msgid "Stash this hunk [y,n,q,a,d%s,?]? "
 msgstr "Fer un «stash» d'aquest tros [y,n,q,a,d%s,?]? "
 
-#: git-add--interactive.perl:1393
+#: git-add--interactive.perl:1438
 #, perl-format
 msgid "Unstage mode change [y,n,q,a,d%s,?]? "
 msgstr "Canvia el mode de «unstage» [y,n,q,a,d%s,?]? "
 
-#: git-add--interactive.perl:1394
+#: git-add--interactive.perl:1439
 #, perl-format
 msgid "Unstage deletion [y,n,q,a,d%s,?]? "
 msgstr "Suprimeix «Unstage» [y,n,q,a,d%s,?]? "
 
-#: git-add--interactive.perl:1395
+#: git-add--interactive.perl:1440
 #, perl-format
 msgid "Unstage this hunk [y,n,q,a,d%s,?]? "
 msgstr "Fer un «unstage» d'aquest tros [y,n,q,a,d%s,?]? "
 
-#: git-add--interactive.perl:1398
+#: git-add--interactive.perl:1443
 #, perl-format
 msgid "Apply mode change to index [y,n,q,a,d%s,?]? "
 msgstr "Aplica el canvi de mode a l'índex [y,n,q,a,d%s,?]? "
 
-#: git-add--interactive.perl:1399
+#: git-add--interactive.perl:1444
 #, perl-format
 msgid "Apply deletion to index [y,n,q,a,d%s,?]? "
 msgstr "Aplica l'esborrat a l'índex [y,n,q,a,d%s,?]? "
 
-#: git-add--interactive.perl:1400
+#: git-add--interactive.perl:1445
 #, perl-format
 msgid "Apply this hunk to index [y,n,q,a,d%s,?]? "
 msgstr "Aplica aquest tros a l'índex [y,n,q,a,d%s,?]? "
 
-#: git-add--interactive.perl:1403
+#: git-add--interactive.perl:1448 git-add--interactive.perl:1463
 #, perl-format
 msgid "Discard mode change from worktree [y,n,q,a,d%s,?]? "
 msgstr "Descarta el canvi de mode des de l'arbre de treball [y,n,q,a,d%s,?]? "
 
-#: git-add--interactive.perl:1404
+#: git-add--interactive.perl:1449 git-add--interactive.perl:1464
 #, perl-format
 msgid "Discard deletion from worktree [y,n,q,a,d%s,?]? "
 msgstr "Descarta l'esborrat des de l'arbre de treball [y,n,q,a,d%s,?]? "
 
-#: git-add--interactive.perl:1405
+#: git-add--interactive.perl:1450 git-add--interactive.perl:1465
 #, perl-format
 msgid "Discard this hunk from worktree [y,n,q,a,d%s,?]? "
 msgstr "Descarta aquest tros des de l'arbre de treball  [y,n,q,a,d%s,?]? "
 
-#: git-add--interactive.perl:1408
+#: git-add--interactive.perl:1453
 #, perl-format
 msgid "Discard mode change from index and worktree [y,n,q,a,d%s,?]? "
 msgstr ""
 "Descarta el canvi de mode des de l'índex i l'arbre de treball [y,n,q,a,d"
 "%s,?]? "
 
-#: git-add--interactive.perl:1409
+#: git-add--interactive.perl:1454
 #, perl-format
 msgid "Discard deletion from index and worktree [y,n,q,a,d%s,?]? "
 msgstr ""
 "Descarta la supressió des de l'índex i l'arbre de treball [y,n,q,a,d%s,?]? "
 
-#: git-add--interactive.perl:1410
+#: git-add--interactive.perl:1455
 #, perl-format
 msgid "Discard this hunk from index and worktree [y,n,q,a,d%s,?]? "
 msgstr ""
 "Descarta aquest tros des de l'índex i l'arbre de treball [y,n,q,a,d%s,?]? "
 
-#: git-add--interactive.perl:1413
+#: git-add--interactive.perl:1458
 #, perl-format
 msgid "Apply mode change to index and worktree [y,n,q,a,d%s,?]? "
 msgstr ""
 "Aplica el canvi de mode a l'índex i l'arbre de treball [y,n,q,a,d%s,?]? "
 
-#: git-add--interactive.perl:1414
+#: git-add--interactive.perl:1459
 #, perl-format
 msgid "Apply deletion to index and worktree [y,n,q,a,d%s,?]? "
 msgstr "Aplica la supressió a l'índex i l'arbre de treball [y,n,q,a,d%s,?]? "
 
-#: git-add--interactive.perl:1415
+#: git-add--interactive.perl:1460
 #, perl-format
 msgid "Apply this hunk to index and worktree [y,n,q,a,d%s,?]? "
 msgstr "Aplica aquest tros a l'índex i l'arbre de treball [y,n,q,a,d%s,?]? "
 
-#: git-add--interactive.perl:1515
-msgid "No other hunks to goto\n"
-msgstr "No hi ha altres trossos on anar-hi\n"
+#: git-add--interactive.perl:1468
+#, perl-format
+msgid "Apply mode change to worktree [y,n,q,a,d%s,?]? "
+msgstr "Aplica el canvi de mode a l'arbre de treball [y,n,q,a,d%s,?]? "
 
-#: git-add--interactive.perl:1522
-msgid "go to which hunk (<ret> to see more)? "
-msgstr "ves a quin tros (<ret> per veure'n més)? "
+#: git-add--interactive.perl:1469
+#, perl-format
+msgid "Apply deletion to worktree [y,n,q,a,d%s,?]? "
+msgstr "Aplica la supressió a l'arbre de treball [y,n,q,a,d%s,?]? "
 
-#: git-add--interactive.perl:1524
-msgid "go to which hunk? "
-msgstr "ves a quin tros? "
+#: git-add--interactive.perl:1470
+#, perl-format
+msgid "Apply this hunk to worktree [y,n,q,a,d%s,?]? "
+msgstr "Aplica aquest tros a l'arbre de treball [y,n,q,a,d%s,?]? "
+
+#: git-add--interactive.perl:1570
+msgid "No other hunks to goto\n"
+msgstr "No hi ha altres trossos on anar-hi\n"
 
-#: git-add--interactive.perl:1533
+#: git-add--interactive.perl:1588
 #, perl-format
 msgid "Invalid number: '%s'\n"
-msgstr "Número no vàlid: '%s'\n"
+msgstr "Número no vàlid: «%s»\n"
 
-#: git-add--interactive.perl:1538
+#: git-add--interactive.perl:1593
 #, perl-format
 msgid "Sorry, only %d hunk available.\n"
 msgid_plural "Sorry, only %d hunks available.\n"
 msgstr[0] "Només %d tros disponible.\n"
 msgstr[1] "Només %d trossos disponibles.\n"
 
-#: git-add--interactive.perl:1564
+#: git-add--interactive.perl:1619
 msgid "No other hunks to search\n"
 msgstr "No hi ha cap altre tros a cercar\n"
 
-#: git-add--interactive.perl:1568
-msgid "search for regex? "
-msgstr "Cerca per expressió regular? "
-
-#: git-add--interactive.perl:1581
+#: git-add--interactive.perl:1636
 #, perl-format
 msgid "Malformed search regexp %s: %s\n"
 msgstr "Expressió regular de cerca mal formada %s: %s\n"
 
-#: git-add--interactive.perl:1591
+#: git-add--interactive.perl:1646
 msgid "No hunk matches the given pattern\n"
 msgstr "No hi ha trossos que coincideixin amb el patró donat\n"
 
-#: git-add--interactive.perl:1603 git-add--interactive.perl:1625
+#: git-add--interactive.perl:1658 git-add--interactive.perl:1680
 msgid "No previous hunk\n"
 msgstr "Sense tros previ\n"
 
-#: git-add--interactive.perl:1612 git-add--interactive.perl:1631
+#: git-add--interactive.perl:1667 git-add--interactive.perl:1686
 msgid "No next hunk\n"
 msgstr "No hi ha tros següent\n"
 
-#: git-add--interactive.perl:1637
+#: git-add--interactive.perl:1692
 msgid "Sorry, cannot split this hunk\n"
 msgstr "No es pot dividir aquest tros\n"
 
-#: git-add--interactive.perl:1643
+#: git-add--interactive.perl:1698
 #, perl-format
 msgid "Split into %d hunk.\n"
 msgid_plural "Split into %d hunks.\n"
 msgstr[0] "Divideix en %d tros.\n"
 msgstr[1] "Divideix en %d trossos.\n"
 
-#: git-add--interactive.perl:1653
+#: git-add--interactive.perl:1708
 msgid "Sorry, cannot edit this hunk\n"
 msgstr "No es pot editar aquest tros\n"
 
-#: git-add--interactive.perl:1699
-msgid "Review diff"
-msgstr "Reviseu les diferències"
-
 #. TRANSLATORS: please do not translate the command names
 #. 'status', 'update', 'revert', etc.
-#: git-add--interactive.perl:1718
+#: git-add--interactive.perl:1773
 msgid ""
 "status        - show paths with changes\n"
 "update        - add working tree state to the staged set of changes\n"
@@ -16863,90 +23990,91 @@ msgstr ""
 "add untracked - afegeix el contingut dels fitxers no seguits al conjunt de "
 "canvis «staged»\n"
 
-#: git-add--interactive.perl:1735 git-add--interactive.perl:1740
-#: git-add--interactive.perl:1743 git-add--interactive.perl:1750
-#: git-add--interactive.perl:1754 git-add--interactive.perl:1760
+#: git-add--interactive.perl:1790 git-add--interactive.perl:1795
+#: git-add--interactive.perl:1798 git-add--interactive.perl:1805
+#: git-add--interactive.perl:1808 git-add--interactive.perl:1815
+#: git-add--interactive.perl:1819 git-add--interactive.perl:1825
 msgid "missing --"
 msgstr "manca --"
 
-#: git-add--interactive.perl:1756
+#: git-add--interactive.perl:1821
 #, perl-format
 msgid "unknown --patch mode: %s"
 msgstr "desconegut --patch mode: %s"
 
-#: git-add--interactive.perl:1762 git-add--interactive.perl:1768
+#: git-add--interactive.perl:1827 git-add--interactive.perl:1833
 #, perl-format
 msgid "invalid argument %s, expecting --"
 msgstr "argument %s no vàlid, s'esperava --"
 
-#: git-send-email.perl:130
+#: git-send-email.perl:138
 msgid "local zone differs from GMT by a non-minute interval\n"
 msgstr "la zona local difereix de GMT per un interval que no és de minuts\n"
 
-#: git-send-email.perl:137 git-send-email.perl:143
+#: git-send-email.perl:145 git-send-email.perl:151
 msgid "local time offset greater than or equal to 24 hours\n"
 msgstr "el desplaçament de la zona local és més gran o igual a 24 hores\n"
 
-#: git-send-email.perl:211 git-send-email.perl:217
+#: git-send-email.perl:223 git-send-email.perl:229
 msgid "the editor exited uncleanly, aborting everything"
 msgstr "l'editor no ha sortit correctament, avortant-ho tot"
 
-#: git-send-email.perl:294
+#: git-send-email.perl:310
 #, perl-format
 msgid ""
 "'%s' contains an intermediate version of the email you were composing.\n"
 msgstr "«%s» conté una versió intermèdia del correu que estàveu redactant.\n"
 
-#: git-send-email.perl:299
+#: git-send-email.perl:315
 #, perl-format
 msgid "'%s.final' contains the composed email.\n"
 msgstr "'%s.final' conté el correu redactat.\n"
 
-#: git-send-email.perl:317
+#: git-send-email.perl:408
 msgid "--dump-aliases incompatible with other options\n"
 msgstr "--dump-aliases és incompatible amb altres opcions\n"
 
-#: git-send-email.perl:383 git-send-email.perl:638
+#: git-send-email.perl:481 git-send-email.perl:683
 msgid "Cannot run git format-patch from outside a repository\n"
 msgstr "No es pot executar git format-patch des de fora del dipòsit\n"
 
-#: git-send-email.perl:386
+#: git-send-email.perl:484
 msgid ""
 "`batch-size` and `relogin` must be specified together (via command-line or "
 "configuration option)\n"
 msgstr ""
 
-#: git-send-email.perl:456
+#: git-send-email.perl:497
 #, perl-format
 msgid "Unknown --suppress-cc field: '%s'\n"
 msgstr "Camp --suppress-cc desconegut: «%s»\n"
 
-#: git-send-email.perl:485
+#: git-send-email.perl:528
 #, perl-format
 msgid "Unknown --confirm setting: '%s'\n"
 msgstr "--confirm setting desconegut: «%s»\n"
 
-#: git-send-email.perl:513
+#: git-send-email.perl:556
 #, perl-format
 msgid "warning: sendmail alias with quotes is not supported: %s\n"
 msgstr "avís: el sobrenom de sendmail amb cometes no està suportat: %s\n"
 
-#: git-send-email.perl:515
+#: git-send-email.perl:558
 #, perl-format
 msgid "warning: `:include:` not supported: %s\n"
 msgstr "avís: `:include:` no està suportat: %s\n"
 
-#: git-send-email.perl:517
+#: git-send-email.perl:560
 #, perl-format
 msgid "warning: `/file` or `|pipe` redirection not supported: %s\n"
 msgstr "avís: les redireccions `/file` or `|pipe no són admeses: %s\n"
 
-#: git-send-email.perl:522
+#: git-send-email.perl:565
 #, perl-format
 msgid "warning: sendmail line is not recognized: %s\n"
 msgstr "avís: no es pot reconèixer la línia sendmail: %s\n"
 
-#: git-send-email.perl:604
+#: git-send-email.perl:649
 #, perl-format
 msgid ""
 "File '%s' exists but it could also be the range of commits\n"
@@ -16961,12 +24089,12 @@ msgstr ""
 "    * Dient \"./%s\" si volíeu especificar aquest fitxer; o\n"
 "    * Proporcionant l'opció --format-patch si volíeu especificar un rang.\n"
 
-#: git-send-email.perl:625
+#: git-send-email.perl:670
 #, perl-format
 msgid "Failed to opendir %s: %s"
 msgstr "S'ha produït un error en obrir el directori %s: %s"
 
-#: git-send-email.perl:649
+#: git-send-email.perl:694
 #, perl-format
 msgid ""
 "fatal: %s: %s\n"
@@ -16975,7 +24103,7 @@ msgstr ""
 "fatal: %s: %s\n"
 "avís: no s'han enviat pedaços\n"
 
-#: git-send-email.perl:660
+#: git-send-email.perl:705
 msgid ""
 "\n"
 "No patch files specified!\n"
@@ -16985,17 +24113,17 @@ msgstr ""
 "No s'han especificat fitxers de pedaç\n"
 "\n"
 
-#: git-send-email.perl:673
+#: git-send-email.perl:718
 #, perl-format
 msgid "No subject line in %s?"
 msgstr "Sense assumpte a %s?"
 
-#: git-send-email.perl:683
+#: git-send-email.perl:728
 #, perl-format
 msgid "Failed to open for writing %s: %s"
 msgstr "S'ha produït un error en obrir per escriptura %s: %s"
 
-#: git-send-email.perl:694
+#: git-send-email.perl:739
 msgid ""
 "Lines beginning in \"GIT:\" will be removed.\n"
 "Consider including an overall diffstat or table of contents\n"
@@ -17009,27 +24137,27 @@ msgstr ""
 "\n"
 "Netegeu el contingut del cos si no voleu enviar un resum.\n"
 
-#: git-send-email.perl:718
+#: git-send-email.perl:763
 #, perl-format
 msgid "Failed to open %s: %s"
 msgstr "S'ha produït un error en obrir %s: %s"
 
-#: git-send-email.perl:735
+#: git-send-email.perl:780
 #, perl-format
 msgid "Failed to open %s.final: %s"
 msgstr "S'ha produït un error en obrir %s.final: %s"
 
-#: git-send-email.perl:778
+#: git-send-email.perl:823
 msgid "Summary email is empty, skipping it\n"
 msgstr "El correu electrònic de resum està buit, s'omet\n"
 
 #. TRANSLATORS: please keep [y/N] as is.
-#: git-send-email.perl:813
+#: git-send-email.perl:858
 #, perl-format
 msgid "Are you sure you want to use <%s> [y/N]? "
 msgstr "Esteu segur que voleu usar <%s> [y/N]? "
 
-#: git-send-email.perl:868
+#: git-send-email.perl:913
 msgid ""
 "The following files are 8bit, but do not declare a Content-Transfer-"
 "Encoding.\n"
@@ -17037,11 +24165,11 @@ msgstr ""
 "Els fitxers següents són 8bit, però no declaren un Content-Transfer-"
 "Encoding.\n"
 
-#: git-send-email.perl:873
+#: git-send-email.perl:918
 msgid "Which 8bit encoding should I declare [UTF-8]? "
 msgstr "Quina codificació de 8 bits hauria de declarar [UTF-8]? "
 
-#: git-send-email.perl:881
+#: git-send-email.perl:926
 #, perl-format
 msgid ""
 "Refusing to send because the patch\n"
@@ -17054,23 +24182,23 @@ msgstr ""
 "perquè la plantilla té l'assumpte '*** SUBJECT HERE ***'. Passeu --force si "
 "realment voleu enviar-lo.\n"
 
-#: git-send-email.perl:900
+#: git-send-email.perl:945
 msgid "To whom should the emails be sent (if anyone)?"
 msgstr ""
 "A qui s'haurien d'enviar els correus electrònics (si s'han d'enviar a algú)?"
 
-#: git-send-email.perl:918
+#: git-send-email.perl:963
 #, perl-format
 msgid "fatal: alias '%s' expands to itself\n"
 msgstr "fatal: l'àlies «%s» s'expandeix a si mateix\n"
 
-#: git-send-email.perl:930
+#: git-send-email.perl:975
 msgid "Message-ID to be used as In-Reply-To for the first email (if any)? "
 msgstr ""
 "S'ha d'usar el Message-ID com a In-Reply-To pel primer correu (si n'hi ha "
 "cap)? "
 
-#: git-send-email.perl:988 git-send-email.perl:996
+#: git-send-email.perl:1033 git-send-email.perl:1041
 #, perl-format
 msgid "error: unable to extract a valid address from: %s\n"
 msgstr "error: no s'ha pogut extreure una adreça vàlida de: %s\n"
@@ -17078,16 +24206,16 @@ msgstr "error: no s'ha pogut extreure un
 #. TRANSLATORS: Make sure to include [q] [d] [e] in your
 #. translation. The program will only accept English input
 #. at this point.
-#: git-send-email.perl:1000
+#: git-send-email.perl:1045
 msgid "What to do with this address? ([q]uit|[d]rop|[e]dit): "
 msgstr "Què cal fer amb aquesta adreça? ([q]surt|[d]escarta|[e]dita): "
 
-#: git-send-email.perl:1317
+#: git-send-email.perl:1362
 #, perl-format
 msgid "CA path \"%s\" does not exist"
-msgstr "el camí CA \"%s\" no existeix"
+msgstr "el camí CA «%s» no existeix"
 
-#: git-send-email.perl:1395
+#: git-send-email.perl:1445
 msgid ""
 "    The Cc list above has been expanded by additional\n"
 "    addresses found in the patch commit message. By default\n"
@@ -17111,133 +24239,134 @@ msgstr ""
 "    missatge, executeu 'git config --global sendemail.confirm auto'.\n"
 "\n"
 
-#. TRANSLATORS: Make sure to include [y] [n] [q] [a] in your
+#. TRANSLATORS: Make sure to include [y] [n] [e] [q] [a] in your
 #. translation. The program will only accept English input
 #. at this point.
-#: git-send-email.perl:1410
-msgid "Send this email? ([y]es|[n]o|[q]uit|[a]ll): "
-msgstr "Voleu enviar aquest correu electrònic? ([y]sí|[n]o|[q]surt|[a]tot): "
+#: git-send-email.perl:1460
+msgid "Send this email? ([y]es|[n]o|[e]dit|[q]uit|[a]ll): "
+msgstr ""
+"Voleu enviar aquest correu electrònic? ([y]sí|[n]o|[e]dita|[q]surt|[a]tot): "
 
-#: git-send-email.perl:1413
+#: git-send-email.perl:1463
 msgid "Send this email reply required"
 msgstr "Requereix resposta en enviar el correu"
 
-#: git-send-email.perl:1439
+#: git-send-email.perl:1491
 msgid "The required SMTP server is not properly defined."
 msgstr "El servidor SMTP requerit no està correctament definit."
 
-#: git-send-email.perl:1486
+#: git-send-email.perl:1538
 #, perl-format
 msgid "Server does not support STARTTLS! %s"
 msgstr "El servidor no admet STARTTLS! %s"
 
-#: git-send-email.perl:1491 git-send-email.perl:1495
+#: git-send-email.perl:1543 git-send-email.perl:1547
 #, perl-format
 msgid "STARTTLS failed! %s"
 msgstr "STARTTLS ha fallat! %s"
 
-#: git-send-email.perl:1505
+#: git-send-email.perl:1556
 msgid "Unable to initialize SMTP properly. Check config and use --smtp-debug."
 msgstr ""
 "No s'ha pogut inicialitzar SMTP correctament. Comproveu-ho la configuració i "
 "useu --smtp-debug."
 
-#: git-send-email.perl:1523
+#: git-send-email.perl:1574
 #, perl-format
 msgid "Failed to send %s\n"
 msgstr "S'ha produït un error en enviar %s\n"
 
-#: git-send-email.perl:1526
+#: git-send-email.perl:1577
 #, perl-format
 msgid "Dry-Sent %s\n"
 msgstr "Simulació d'enviament %s\n"
 
-#: git-send-email.perl:1526
+#: git-send-email.perl:1577
 #, perl-format
 msgid "Sent %s\n"
 msgstr "Enviat %s\n"
 
-#: git-send-email.perl:1528
+#: git-send-email.perl:1579
 msgid "Dry-OK. Log says:\n"
 msgstr "Simulació de correcte. El registre diu:\n"
 
-#: git-send-email.perl:1528
+#: git-send-email.perl:1579
 msgid "OK. Log says:\n"
 msgstr "Correcte. El registre diu: \n"
 
-#: git-send-email.perl:1540
+#: git-send-email.perl:1591
 msgid "Result: "
 msgstr "Resultat: "
 
-#: git-send-email.perl:1543
+#: git-send-email.perl:1594
 msgid "Result: OK\n"
 msgstr "Resultat: correcte\n"
 
-#: git-send-email.perl:1556
+#: git-send-email.perl:1612
 #, perl-format
 msgid "can't open file %s"
 msgstr "no es pot obrir el fitxer %s"
 
-#: git-send-email.perl:1603 git-send-email.perl:1623
+#: git-send-email.perl:1659 git-send-email.perl:1679
 #, perl-format
 msgid "(mbox) Adding cc: %s from line '%s'\n"
 msgstr "(mbox) S'està afegint cc: %s des de la línia «%s»\n"
 
-#: git-send-email.perl:1609
+#: git-send-email.perl:1665
 #, perl-format
 msgid "(mbox) Adding to: %s from line '%s'\n"
 msgstr "(mbox) S'està afegint a: %s des de la línia «%s»\n"
 
-#: git-send-email.perl:1657
+#: git-send-email.perl:1718
 #, perl-format
 msgid "(non-mbox) Adding cc: %s from line '%s'\n"
 msgstr "(no mbox) S'està afegint cc: %s des de la línia «%s»\n"
 
-#: git-send-email.perl:1682
+#: git-send-email.perl:1753
 #, perl-format
 msgid "(body) Adding cc: %s from line '%s'\n"
 msgstr "(cos) S'està afegint cc: %s des de la línia «%s»\n"
 
-#: git-send-email.perl:1788
+#: git-send-email.perl:1864
 #, perl-format
 msgid "(%s) Could not execute '%s'"
 msgstr "(%s) no s'ha pogut executar «%s»"
 
-#: git-send-email.perl:1795
+#: git-send-email.perl:1871
 #, perl-format
 msgid "(%s) Adding %s: %s from: '%s'\n"
 msgstr "(%s) S'està afegint %s: %s des de: «%s»\n"
 
-#: git-send-email.perl:1799
+#: git-send-email.perl:1875
 #, perl-format
 msgid "(%s) failed to close pipe to '%s'"
 msgstr "(%s) s'ha produït un error en tancar el conducte «%s»"
 
-#: git-send-email.perl:1826
+#: git-send-email.perl:1905
 msgid "cannot send message as 7bit"
 msgstr "no es pot enviar el missatge en 7 bits"
 
-#: git-send-email.perl:1834
+#: git-send-email.perl:1913
 msgid "invalid transfer encoding"
 msgstr "codificació de transferència no vàlida"
 
-#: git-send-email.perl:1872 git-send-email.perl:1923 git-send-email.perl:1933
+#: git-send-email.perl:1954 git-send-email.perl:2006 git-send-email.perl:2016
 #, perl-format
 msgid "unable to open %s: %s\n"
 msgstr "no s'ha pogut obrir %s: %s\n"
 
-#: git-send-email.perl:1875
+#: git-send-email.perl:1957
 #, perl-format
 msgid "%s: patch contains a line longer than 998 characters"
 msgstr "%s: el pedaç conté una línia més gran de 998 caràcters"
 
-#: git-send-email.perl:1891
+#: git-send-email.perl:1974
 #, perl-format
 msgid "Skipping %s with backup suffix '%s'.\n"
 msgstr "S'està ometent %s amb el sufix de còpia de seguretat «%s».\n"
 
 #. TRANSLATORS: please keep "[y|N]" as is.
-#: git-send-email.perl:1895
+#: git-send-email.perl:1978
 #, perl-format
 msgid "Do you really want to send %s? [y|N]: "
 msgstr "Esteu segur que voleu enviar %s? [y|N]: "
diff -pruN 1.2.1+git2.18.0-1/git/po/de.po 1.2.3+git2.25.1-1/git/po/de.po
--- 1.2.1+git2.18.0-1/git/po/de.po	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/po/de.po	2020-02-17 04:47:35.000000000 +0000
@@ -1,59 +1,492 @@
 # German translations for Git.
-# Copyright (C) 2010-2016 Ralf Thielow <ralf.thielow@gmail.com>
+# Copyright (C) 2019 Matthias Rüster <matthias.ruester@gmail.com>
 # This file is distributed under the same license as the Git package.
-# Ralf Thielow <ralf.thielow@gmail.com>, 2010-2016.
+# Matthias Rüster <matthias.ruester@gmail.com>, 2019.
+# Ralf Thielow <ralf.thielow@gmail.com>, 2010-2019.
 #
 msgid ""
 msgstr ""
 "Project-Id-Version: Git\n"
 "Report-Msgid-Bugs-To: Git Mailing List <git@vger.kernel.org>\n"
-"POT-Creation-Date: 2018-03-16 07:29+0800\n"
+"POT-Creation-Date: 2019-12-30 08:48+0800\n"
 "PO-Revision-Date: 2016-11-28 18:10+0100\n"
-"Last-Translator: Ralf Thielow <ralf.thielow@gmail.com>\n"
-"Language-Team: German <>\n"
+"Last-Translator: Matthias Rüster <matthias.ruester@gmail.com>\n"
+"Language-Team: Matthias Rüster <matthias.ruester@gmail.com>\n"
 "Language: de\n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
 "Plural-Forms: nplurals=2; plural=(n!=1);\n"
 
-#: advice.c:62
+#: add-interactive.c:347
 #, c-format
-msgid "hint: %.*s\n"
-msgstr "Hinweis: %.*s\n"
+msgid "Huh (%s)?"
+msgstr "Wie bitte (%s)?"
 
-#: advice.c:90
+#: add-interactive.c:500 add-interactive.c:801 sequencer.c:3216
+#: sequencer.c:3656 builtin/rebase.c:871 builtin/rebase.c:1643
+#: builtin/rebase.c:2019 builtin/rebase.c:2063
+msgid "could not read index"
+msgstr "Konnte den Index nicht lesen."
+
+#: add-interactive.c:555 git-add--interactive.perl:269
+#: git-add--interactive.perl:294
+msgid "binary"
+msgstr "Binär"
+
+#: add-interactive.c:613 git-add--interactive.perl:278
+#: git-add--interactive.perl:332
+msgid "nothing"
+msgstr "Nichts"
+
+#: add-interactive.c:614 git-add--interactive.perl:314
+#: git-add--interactive.perl:329
+msgid "unchanged"
+msgstr "unverändert"
+
+#: add-interactive.c:651 git-add--interactive.perl:643
+msgid "Update"
+msgstr "Aktualisieren"
+
+#: add-interactive.c:668 add-interactive.c:856
+#, c-format
+msgid "could not stage '%s'"
+msgstr "Konnte '%s' nicht zum Commit vormerken."
+
+#: add-interactive.c:674 add-interactive.c:863 sequencer.c:3409
+#: builtin/rebase.c:895
+msgid "could not write index"
+msgstr "Konnte Index nicht schreiben."
+
+#: add-interactive.c:677 git-add--interactive.perl:628
+#, c-format, perl-format
+msgid "updated %d path\n"
+msgid_plural "updated %d paths\n"
+msgstr[0] "%d Pfad aktualisiert\n"
+msgstr[1] "%d Pfade aktualisiert\n"
+
+#: add-interactive.c:695 git-add--interactive.perl:678
+#, c-format, perl-format
+msgid "note: %s is untracked now.\n"
+msgstr "Hinweis: %s ist nun unversioniert.\n"
+
+#: add-interactive.c:700 apply.c:4108 builtin/checkout.c:281
+#: builtin/reset.c:144
+#, c-format
+msgid "make_cache_entry failed for path '%s'"
+msgstr "make_cache_entry für Pfad '%s' fehlgeschlagen"
+
+#: add-interactive.c:730 git-add--interactive.perl:655
+msgid "Revert"
+msgstr "Revert"
+
+#: add-interactive.c:746
+msgid "Could not parse HEAD^{tree}"
+msgstr "Konnte HEAD^{tree} nicht parsen."
+
+#: add-interactive.c:784 git-add--interactive.perl:631
+#, c-format, perl-format
+msgid "reverted %d path\n"
+msgid_plural "reverted %d paths\n"
+msgstr[0] "%d Pfad wiederhergestellt\n"
+msgstr[1] "%d Pfade wiederhergestellt\n"
+
+#: add-interactive.c:835 git-add--interactive.perl:695
+#, c-format
+msgid "No untracked files.\n"
+msgstr "Keine unversionierten Dateien.\n"
+
+#: add-interactive.c:839 git-add--interactive.perl:689
+msgid "Add untracked"
+msgstr "unversionierte Dateien hinzufügen"
+
+#: add-interactive.c:866 git-add--interactive.perl:625
+#, c-format, perl-format
+msgid "added %d path\n"
+msgid_plural "added %d paths\n"
+msgstr[0] "%d Pfad hinzugefügt\n"
+msgstr[1] "%d Pfade hinzugefügt\n"
+
+#: add-interactive.c:896
+#, c-format
+msgid "ignoring unmerged: %s"
+msgstr "Ignoriere nicht zusammengeführte Datei: %s"
+
+#: add-interactive.c:908 add-patch.c:1331 git-add--interactive.perl:1366
+#, c-format
+msgid "Only binary files changed.\n"
+msgstr "Nur Binärdateien geändert.\n"
+
+#: add-interactive.c:910 add-patch.c:1329 git-add--interactive.perl:1368
+#, c-format
+msgid "No changes.\n"
+msgstr "Keine Änderungen.\n"
+
+#: add-interactive.c:914 git-add--interactive.perl:1376
+msgid "Patch update"
+msgstr "Patch Aktualisierung"
+
+#: add-interactive.c:953 git-add--interactive.perl:1754
+msgid "Review diff"
+msgstr "Diff überprüfen"
+
+#: add-interactive.c:981
+msgid "show paths with changes"
+msgstr "Zeige Pfade mit Änderungen"
+
+#: add-interactive.c:983
+msgid "add working tree state to the staged set of changes"
+msgstr "Zustand des Arbeitsverzeichnisses zum Commit vormerken"
+
+#: add-interactive.c:985
+msgid "revert staged set of changes back to the HEAD version"
+msgstr "Zum Commit vorgemerkte Änderungen auf HEAD-Version zurücksetzen"
+
+#: add-interactive.c:987
+msgid "pick hunks and update selectively"
+msgstr "Blöcke und Änderung gezielt auswählen"
+
+#: add-interactive.c:989
+msgid "view diff between HEAD and index"
+msgstr "Differenz zwischen HEAD und Index ansehen"
+
+#: add-interactive.c:991
+msgid "add contents of untracked files to the staged set of changes"
+msgstr "Inhalte von unversionierten Dateien zum Commit vormerken"
+
+#: add-interactive.c:999 add-interactive.c:1048
+msgid "Prompt help:"
+msgstr "Hilfe für Eingaben:"
+
+#: add-interactive.c:1001
+msgid "select a single item"
+msgstr "Ein einzelnes Element auswählen"
+
+#: add-interactive.c:1003
+msgid "select a range of items"
+msgstr "Eine Reihe von Elementen auswählen"
+
+#: add-interactive.c:1005
+msgid "select multiple ranges"
+msgstr "Mehrere Reihen auswählen"
+
+#: add-interactive.c:1007 add-interactive.c:1052
+msgid "select item based on unique prefix"
+msgstr "Element basierend auf eindeutigen Präfix auswählen"
+
+#: add-interactive.c:1009
+msgid "unselect specified items"
+msgstr "Angegebene Elemente abwählen"
+
+#: add-interactive.c:1011
+msgid "choose all items"
+msgstr "Alle Elemente auswählen"
+
+#: add-interactive.c:1013
+msgid "(empty) finish selecting"
+msgstr "(leer) Auswählen beenden"
+
+#: add-interactive.c:1050
+msgid "select a numbered item"
+msgstr "Ein nummeriertes Element auswählen"
+
+#: add-interactive.c:1054
+msgid "(empty) select nothing"
+msgstr "(leer) nichts auswählen"
+
+#: add-interactive.c:1062 builtin/clean.c:822 git-add--interactive.perl:1851
+msgid "*** Commands ***"
+msgstr "*** Befehle ***"
+
+#: add-interactive.c:1063 builtin/clean.c:823 git-add--interactive.perl:1848
+msgid "What now"
+msgstr "Was nun"
+
+#: add-interactive.c:1115 git-add--interactive.perl:213
+msgid "staged"
+msgstr "zur Staging-Area hinzugefügt"
+
+#: add-interactive.c:1115 git-add--interactive.perl:213
+msgid "unstaged"
+msgstr "aus Staging-Area entfernt"
+
+#: add-interactive.c:1115 apply.c:4965 apply.c:4968 builtin/am.c:2197
+#: builtin/am.c:2200 builtin/clone.c:123 builtin/fetch.c:144
+#: builtin/merge.c:273 builtin/pull.c:209 builtin/submodule--helper.c:409
+#: builtin/submodule--helper.c:1379 builtin/submodule--helper.c:1382
+#: builtin/submodule--helper.c:1875 builtin/submodule--helper.c:1878
+#: builtin/submodule--helper.c:2119 git-add--interactive.perl:213
+msgid "path"
+msgstr "Pfad"
+
+#: add-interactive.c:1122
+msgid "could not refresh index"
+msgstr "Konnte den Index nicht aktualisieren."
+
+#: add-interactive.c:1136 builtin/clean.c:787 git-add--interactive.perl:1765
+#, c-format
+msgid "Bye.\n"
+msgstr "Tschüss.\n"
+
+#: add-patch.c:15
+#, c-format
+msgid "Stage mode change [y,n,a,q,d%s,?]? "
+msgstr "Modusänderung der Staging-Area hinzufügen [y,n,a,q,d%s,?]? "
+
+#: add-patch.c:16
+#, c-format
+msgid "Stage deletion [y,n,a,q,d%s,?]? "
+msgstr "Löschung der Staging-Area hinzufügen [y,n,a,q,d%s,?]? "
+
+#: add-patch.c:17
+#, c-format
+msgid "Stage this hunk [y,n,a,q,d%s,?]? "
+msgstr "Diesen Patch-Block der Staging-Area hinzufügen [y,n,a,q,d%s,?]? "
+
+#: add-patch.c:111
+#, c-format
+msgid "could not parse hunk header '%.*s'"
+msgstr "Konnte Block-Header '%.*s' nicht parsen."
+
+#: add-patch.c:130 add-patch.c:134
+#, c-format
+msgid "could not parse colored hunk header '%.*s'"
+msgstr "Konnte farbigen Block-Header '%.*s' nicht parsen."
+
+#: add-patch.c:176
+msgid "could not parse diff"
+msgstr "Konnte Differenz nicht parsen."
+
+#: add-patch.c:194
+msgid "could not parse colored diff"
+msgstr "Konnte farbige Differenz nicht parsen."
+
+#: add-patch.c:508
+#, c-format
+msgid ""
+"expected context line #%d in\n"
+"%.*s"
+msgstr "Erwartete Kontextzeile #%d in\n"
+"%.*s"
+
+#: add-patch.c:523
+#, c-format
+msgid ""
+"hunks do not overlap:\n"
+"%.*s\n"
+"\tdoes not end with:\n"
+"%.*s"
+msgstr ""
+"Patch-Blöcke überlappen sich nicht:\n"
+"%.*s\n"
+"\tendet nicht mit:\n"
+"%.*s"
+
+#: add-patch.c:799 git-add--interactive.perl:1112
+msgid "Manual hunk edit mode -- see bottom for a quick guide.\n"
+msgstr ""
+"Manueller Editiermodus für Patch-Blöcke -- siehe nach unten für eine\n"
+"Kurzanleitung.\n"
+
+#: add-patch.c:803
+#, c-format
+msgid ""
+"---\n"
+"To remove '%c' lines, make them ' ' lines (context).\n"
+"To remove '%c' lines, delete them.\n"
+"Lines starting with %c will be removed.\n"
+msgstr ""
+"---\n"
+"Um '%c' Zeilen zu entfernen, machen Sie aus diesen ' ' Zeilen (Kontext).\n"
+"Um '%c' Zeilen zu entfernen, löschen Sie diese.\n"
+"Zeilen, die mit %c beginnen, werden entfernt.\n"
+
+#: add-patch.c:810
+msgid ""
+"If the patch applies cleanly, the edited hunk will immediately be\n"
+"marked for staging.\n"
+msgstr ""
+"Wenn der Patch sauber angewendet werden kann, wird der bearbeitete Patch-"
+"Block\n"
+"direkt als zum Hinzufügen zur Staging-Area markiert.\n"
+
+#. TRANSLATORS: 'it' refers to the patch mentioned in the previous messages.
+#: add-patch.c:818 git-add--interactive.perl:1126
+msgid ""
+"If it does not apply cleanly, you will be given an opportunity to\n"
+"edit again.  If all lines of the hunk are removed, then the edit is\n"
+"aborted and the hunk is left unchanged.\n"
+msgstr ""
+"Wenn das nicht sauber angewendet werden kann, haben Sie die Möglichkeit\n"
+"einer erneuten Bearbeitung. Wenn alle Zeilen des Patch-Blocks entfernt "
+"werden,\n"
+"wird die Bearbeitung abgebrochen und der Patch-Block bleibt unverändert.\n"
+
+#: add-patch.c:851
+msgid "could not parse hunk header"
+msgstr "Konnte Block-Header nicht parsen."
+
+#: add-patch.c:895 add-patch.c:1294
+msgid "'git apply --cached' failed"
+msgstr "'git apply --cached' schlug fehl."
+
+#. TRANSLATORS: do not translate [y/n]
+#. The program will only accept that input at this point.
+#. Consider translating (saying "no" discards!) as
+#. (saying "n" for "no" discards!) if the translation
+#. of the word "no" does not start with n.
+#.
+#. TRANSLATORS: do not translate [y/n]
+#. The program will only accept that input
+#. at this point.
+#. Consider translating (saying "no" discards!) as
+#. (saying "n" for "no" discards!) if the translation
+#. of the word "no" does not start with n.
+#: add-patch.c:952 git-add--interactive.perl:1239
+msgid ""
+"Your edited hunk does not apply. Edit again (saying \"no\" discards!) [y/n]? "
+msgstr ""
+"Ihr bearbeiteter Patch-Block kann nicht angewendet werden.\n"
+"Erneut bearbeiten? (\"n\" verwirft Bearbeitung!) [y/n]?"
+
+#: add-patch.c:1009
+msgid ""
+"y - stage this hunk\n"
+"n - do not stage this hunk\n"
+"q - quit; do not stage this hunk or any of the remaining ones\n"
+"a - stage this and all the remaining hunks\n"
+"d - do not stage this hunk nor any of the remaining hunks\n"
+msgstr ""
+"y - diesen Patch-Block zum Commit vormerken\n"
+"n - diesen Patch-Block nicht zum Commit vormerken\n"
+"q - Beenden; diesen oder alle verbleibenden Patch-Blöcke nicht zum Commit "
+"vormerken\n"
+"a - diesen und alle weiteren Patch-Blöcke zum Commit vormerken\n"
+"d - diesen und alle weiteren Patch-Blöcke nicht zum Commit vormerken\n"
+
+#: add-patch.c:1016
+msgid ""
+"j - leave this hunk undecided, see next undecided hunk\n"
+"J - leave this hunk undecided, see next hunk\n"
+"k - leave this hunk undecided, see previous undecided hunk\n"
+"K - leave this hunk undecided, see previous hunk\n"
+"g - select a hunk to go to\n"
+"/ - search for a hunk matching the given regex\n"
+"s - split the current hunk into smaller hunks\n"
+"e - manually edit the current hunk\n"
+"? - print help\n"
+msgstr ""
+"j - diesen Patch-Block unbestimmt lassen, nächsten unbestimmten Patch-Block "
+"anzeigen\n"
+"J - diesen Patch-Block unbestimmt lassen, nächsten Patch-Block anzeigen\n"
+"k - diesen Patch-Block unbestimmt lassen, vorherigen unbestimmten Patch-"
+"Block anzeigen\n"
+"K - diesen Patch-Block unbestimmt lassen, vorherigen Patch-Block anzeigen\n"
+"g - Patch-Block zum Hinspringen auswählen\n"
+"/ - nach Patch-Block suchen, der gegebenem regulärem Ausdruck entspricht\n"
+"s - aktuellen Patch-Block in kleinere Patch-Blöcke aufteilen\n"
+"e - aktuellen Patch-Block manuell editieren\n"
+"? - Hilfe anzeigen\n"
+
+#: add-patch.c:1137 add-patch.c:1147
+msgid "No previous hunk"
+msgstr "Kein vorheriger Patch-Block"
+
+#: add-patch.c:1142 add-patch.c:1152
+msgid "No next hunk"
+msgstr "Kein folgender Patch-Block"
+
+#: add-patch.c:1158
+msgid "No other hunks to goto"
+msgstr "Keine anderen Patch-Blöcke verbleibend"
+
+#: add-patch.c:1169 git-add--interactive.perl:1577
+msgid "go to which hunk (<ret> to see more)? "
+msgstr "zu welchem Patch-Block springen (<Enter> für mehr Informationen)? "
+
+#: add-patch.c:1170 git-add--interactive.perl:1579
+msgid "go to which hunk? "
+msgstr "zu welchem Patch-Block springen? "
+
+#: add-patch.c:1181
+#, c-format
+msgid "Invalid number: '%s'"
+msgstr "Ungültige Nummer: '%s'"
+
+#: add-patch.c:1186
+#, c-format
+msgid "Sorry, only %d hunk available."
+msgid_plural "Sorry, only %d hunks available."
+msgstr[0] "Entschuldigung, nur %d Patch-Block verfügbar."
+msgstr[1] "Entschuldigung, nur %d Patch-Blöcke verfügbar."
+
+#: add-patch.c:1195
+msgid "No other hunks to search"
+msgstr "Keine anderen Patch-Blöcke zum Durchsuchen"
+
+#: add-patch.c:1201 git-add--interactive.perl:1623
+msgid "search for regex? "
+msgstr "Suche nach regulärem Ausdruck? "
+
+#: add-patch.c:1216
+#, c-format
+msgid "Malformed search regexp %s: %s"
+msgstr "Fehlerhafter regulärer Ausdruck für Suche %s: %s"
+
+#: add-patch.c:1233
+msgid "No hunk matches the given pattern"
+msgstr "Kein Patch-Block entspricht dem angegebenen Muster"
+
+#: add-patch.c:1240
+msgid "Sorry, cannot split this hunk"
+msgstr "Entschuldigung, kann diesen Patch-Block nicht aufteilen"
+
+#: add-patch.c:1244
+#, c-format
+msgid "Split into %d hunks."
+msgstr "In %d Patch-Block aufgeteilt."
+
+#: add-patch.c:1248
+msgid "Sorry, cannot edit this hunk"
+msgstr "Entschuldigung, kann diesen Patch-Block nicht bearbeiten"
+
+#: advice.c:111
+#, c-format
+msgid "%shint: %.*s%s\n"
+msgstr "%sHinweis: %.*s%s\n"
+
+#: advice.c:164
 msgid "Cherry-picking is not possible because you have unmerged files."
 msgstr ""
 "Cherry-Picken ist nicht möglich, weil Sie nicht zusammengeführte Dateien "
 "haben."
 
-#: advice.c:92
+#: advice.c:166
 msgid "Committing is not possible because you have unmerged files."
 msgstr ""
 "Committen ist nicht möglich, weil Sie nicht zusammengeführte Dateien haben."
 
-#: advice.c:94
+#: advice.c:168
 msgid "Merging is not possible because you have unmerged files."
 msgstr ""
 "Mergen ist nicht möglich, weil Sie nicht zusammengeführte Dateien haben."
 
-#: advice.c:96
+#: advice.c:170
 msgid "Pulling is not possible because you have unmerged files."
 msgstr ""
 "Pullen ist nicht möglich, weil Sie nicht zusammengeführte Dateien haben."
 
-#: advice.c:98
+#: advice.c:172
 msgid "Reverting is not possible because you have unmerged files."
 msgstr ""
 "Reverten ist nicht möglich, weil Sie nicht zusammengeführte Dateien haben."
 
-#: advice.c:100
+#: advice.c:174
 #, c-format
 msgid "It is not possible to %s because you have unmerged files."
 msgstr "%s ist nicht möglich, weil Sie nicht zusammengeführte Dateien haben."
 
-#: advice.c:108
+#: advice.c:182
 msgid ""
 "Fix them up in the work tree, and then use 'git add/rm <file>'\n"
 "as appropriate to mark resolution and make a commit."
@@ -62,146 +495,156 @@ msgstr ""
 "dann 'git add/rm <Datei>', um die Auflösung entsprechend zu markieren\n"
 "und zu committen."
 
-#: advice.c:116
+#: advice.c:190
 msgid "Exiting because of an unresolved conflict."
 msgstr "Beende wegen unaufgelöstem Konflikt."
 
-#: advice.c:121 builtin/merge.c:1251
+#: advice.c:195 builtin/merge.c:1332
 msgid "You have not concluded your merge (MERGE_HEAD exists)."
 msgstr "Sie haben Ihren Merge nicht abgeschlossen (MERGE_HEAD existiert)."
 
-#: advice.c:123
+#: advice.c:197
 msgid "Please, commit your changes before merging."
 msgstr "Bitte committen Sie Ihre Änderungen, bevor Sie mergen."
 
-#: advice.c:124
+#: advice.c:198
 msgid "Exiting because of unfinished merge."
 msgstr "Beende wegen nicht abgeschlossenem Merge."
 
-#: advice.c:130
+#: advice.c:204
 #, c-format
 msgid ""
-"Note: checking out '%s'.\n"
+"Note: switching to '%s'.\n"
 "\n"
 "You are in 'detached HEAD' state. You can look around, make experimental\n"
 "changes and commit them, and you can discard any commits you make in this\n"
-"state without impacting any branches by performing another checkout.\n"
+"state without impacting any branches by switching back to a branch.\n"
 "\n"
 "If you want to create a new branch to retain commits you create, you may\n"
-"do so (now or later) by using -b with the checkout command again. Example:\n"
+"do so (now or later) by using -c with the switch command. Example:\n"
+"\n"
+"  git switch -c <new-branch-name>\n"
 "\n"
-"  git checkout -b <new-branch-name>\n"
+"Or undo this operation with:\n"
+"\n"
+"  git switch -\n"
+"\n"
+"Turn off this advice by setting config variable advice.detachedHead to "
+"false\n"
 "\n"
 msgstr ""
-"Hinweis: Checke '%s' aus.\n"
+"Hinweis: Wechsle zu '%s'.\n"
 "\n"
 "Sie befinden sich im Zustand eines 'losgelösten HEAD'. Sie können sich\n"
 "umschauen, experimentelle Änderungen vornehmen und diese committen, und\n"
 "Sie können alle möglichen Commits, die Sie in diesem Zustand machen,\n"
-"ohne Auswirkungen auf irgendeinen Branch verwerfen, indem Sie einen\n"
-"weiteren Checkout durchführen.\n"
+"ohne Auswirkungen auf irgendeinen Branch verwerfen, indem Sie zu einem\n"
+"anderen Branch wechseln.\n"
 "\n"
 "Wenn Sie einen neuen Branch erstellen möchten, um Ihre erstellten Commits\n"
-"zu behalten, können Sie das (jetzt oder später) durch einen weiteren "
-"Checkout\n"
-"mit der Option -b tun. Beispiel:\n"
+"zu behalten, können Sie das (jetzt oder später) durch Nutzung von\n"
+"'switch' mit der Option -c tun. Beispiel:\n"
+"\n"
+"  git switch -c <neuer-Branchname>\n"
+"\n"
+"Oder um diese Operation rückgängig zu machen:\n"
+"  git switch -\n"
 "\n"
-"  git checkout -b <neuer-Branchname>\n"
+"Sie können diesen Hinweis ausschalten, indem Sie die Konfigurationsvariable\n"
+"'advice.detachedHead' auf 'false' setzen.\n"
 "\n"
 
-#: apply.c:58
+#: alias.c:50
+msgid "cmdline ends with \\"
+msgstr "Befehlszeile endet mit \\"
+
+#: alias.c:51
+msgid "unclosed quote"
+msgstr "Nicht geschlossene Anführungszeichen."
+
+#: apply.c:69
 #, c-format
 msgid "unrecognized whitespace option '%s'"
-msgstr "nicht erkannte Whitespace-Option: '%s'"
+msgstr "Nicht erkannte Whitespace-Option: '%s'"
 
-#: apply.c:74
+#: apply.c:85
 #, c-format
 msgid "unrecognized whitespace ignore option '%s'"
 msgstr "nicht erkannte Option zum Ignorieren von Whitespace: '%s'"
 
-#: apply.c:122
+#: apply.c:135
 msgid "--reject and --3way cannot be used together."
 msgstr "--reject und --3way können nicht gemeinsam verwendet werden."
 
-#: apply.c:124
+#: apply.c:137
 msgid "--cached and --3way cannot be used together."
 msgstr "--cached und --3way können nicht gemeinsam verwendet werden."
 
-#: apply.c:127
+#: apply.c:140
 msgid "--3way outside a repository"
 msgstr ""
 "Die Option --3way kann nicht außerhalb eines Repositories verwendet werden."
 
-#: apply.c:138
+#: apply.c:151
 msgid "--index outside a repository"
 msgstr ""
 "Die Option --index kann nicht außerhalb eines Repositories verwendet werden."
 
-#: apply.c:141
+#: apply.c:154
 msgid "--cached outside a repository"
 msgstr ""
 "Die Option --cached kann nicht außerhalb eines Repositories verwendet werden."
 
-#: apply.c:821
+#: apply.c:801
 #, c-format
 msgid "Cannot prepare timestamp regexp %s"
 msgstr "Kann regulären Ausdruck für Zeitstempel %s nicht verarbeiten"
 
-#: apply.c:830
+#: apply.c:810
 #, c-format
 msgid "regexec returned %d for input: %s"
 msgstr "Ausführung des regulären Ausdrucks gab %d zurück. Eingabe: %s"
 
-#: apply.c:904
+#: apply.c:884
 #, c-format
 msgid "unable to find filename in patch at line %d"
 msgstr "Konnte keinen Dateinamen in Zeile %d des Patches finden."
 
-#: apply.c:942
+#: apply.c:922
 #, c-format
 msgid "git apply: bad git-diff - expected /dev/null, got %s on line %d"
 msgstr ""
 "git apply: ungültiges 'git-diff' - erwartete /dev/null, erhielt %s in Zeile "
 "%d"
 
-#: apply.c:948
+#: apply.c:928
 #, c-format
 msgid "git apply: bad git-diff - inconsistent new filename on line %d"
 msgstr ""
 "git apply: ungültiges 'git-diff' - Inkonsistenter neuer Dateiname in Zeile %d"
 
-#: apply.c:949
+#: apply.c:929
 #, c-format
 msgid "git apply: bad git-diff - inconsistent old filename on line %d"
 msgstr ""
 "git apply: ungültiges 'git-diff' - Inkonsistenter alter Dateiname in Zeile %d"
 
-#: apply.c:954
+#: apply.c:934
 #, c-format
 msgid "git apply: bad git-diff - expected /dev/null on line %d"
 msgstr "git apply: ungültiges 'git-diff' - erwartete /dev/null in Zeile %d"
 
-#: apply.c:983
+#: apply.c:963
 #, c-format
 msgid "invalid mode on line %d: %s"
 msgstr "Ungültiger Modus in Zeile %d: %s"
 
-#: apply.c:1301
+#: apply.c:1282
 #, c-format
 msgid "inconsistent header lines %d and %d"
 msgstr "Inkonsistente Kopfzeilen %d und %d."
 
-#: apply.c:1473
-#, c-format
-msgid "recount: unexpected line: %.*s"
-msgstr "recount: unerwartete Zeile: %.*s"
-
-#: apply.c:1542
-#, c-format
-msgid "patch fragment without header at line %d: %.*s"
-msgstr "Patch-Fragment ohne Kopfbereich bei Zeile %d: %.*s"
-
-#: apply.c:1562
+#: apply.c:1372
 #, c-format
 msgid ""
 "git diff header lacks filename information when removing %d leading pathname "
@@ -216,72 +659,82 @@ msgstr[1] ""
 "Dem Kopfbereich von \"git diff\" fehlen Informationen zum Dateinamen, wenn "
 "%d vorangestellte Teile des Pfades entfernt werden (Zeile %d)"
 
-#: apply.c:1575
+#: apply.c:1385
 #, c-format
 msgid "git diff header lacks filename information (line %d)"
 msgstr ""
 "Dem Kopfbereich von \"git diff\" fehlen Informationen zum Dateinamen (Zeile "
 "%d)"
 
-#: apply.c:1763
+#: apply.c:1481
+#, c-format
+msgid "recount: unexpected line: %.*s"
+msgstr "recount: unerwartete Zeile: %.*s"
+
+#: apply.c:1550
+#, c-format
+msgid "patch fragment without header at line %d: %.*s"
+msgstr "Patch-Fragment ohne Kopfbereich bei Zeile %d: %.*s"
+
+#: apply.c:1753
 msgid "new file depends on old contents"
 msgstr "neue Datei hängt von alten Inhalten ab"
 
-#: apply.c:1765
+#: apply.c:1755
 msgid "deleted file still has contents"
 msgstr "entfernte Datei hat noch Inhalte"
 
-#: apply.c:1799
+#: apply.c:1789
 #, c-format
 msgid "corrupt patch at line %d"
 msgstr "fehlerhafter Patch bei Zeile %d"
 
-#: apply.c:1836
+#: apply.c:1826
 #, c-format
 msgid "new file %s depends on old contents"
 msgstr "neue Datei %s hängt von alten Inhalten ab"
 
-#: apply.c:1838
+#: apply.c:1828
 #, c-format
 msgid "deleted file %s still has contents"
 msgstr "entfernte Datei %s hat noch Inhalte"
 
-#: apply.c:1841
+#: apply.c:1831
 #, c-format
 msgid "** warning: file %s becomes empty but is not deleted"
 msgstr "** Warnung: Datei %s wird leer, aber nicht entfernt."
 
-#: apply.c:1988
+#: apply.c:1978
 #, c-format
 msgid "corrupt binary patch at line %d: %.*s"
 msgstr "fehlerhafter Binär-Patch bei Zeile %d: %.*s"
 
-#: apply.c:2025
+#: apply.c:2015
 #, c-format
 msgid "unrecognized binary patch at line %d"
 msgstr "nicht erkannter Binär-Patch bei Zeile %d"
 
-#: apply.c:2185
+#: apply.c:2177
 #, c-format
 msgid "patch with only garbage at line %d"
 msgstr "Patch mit nutzlosen Informationen bei Zeile %d"
 
-#: apply.c:2271
+#: apply.c:2263
 #, c-format
 msgid "unable to read symlink %s"
 msgstr "konnte symbolische Verknüpfung %s nicht lesen"
 
-#: apply.c:2275
+#: apply.c:2267
 #, c-format
 msgid "unable to open or read %s"
 msgstr "konnte %s nicht öffnen oder lesen"
 
-#: apply.c:2934
+#: apply.c:2936
 #, c-format
 msgid "invalid start of line: '%c'"
 msgstr "Ungültiger Zeilenanfang: '%c'"
 
-#: apply.c:3055
+#: apply.c:3057
 #, c-format
 msgid "Hunk #%d succeeded at %d (offset %d line)."
 msgid_plural "Hunk #%d succeeded at %d (offset %d lines)."
@@ -289,12 +742,12 @@ msgstr[0] "Patch-Bereich #%d erfolgreich
 msgstr[1] ""
 "Patch-Bereich #%d erfolgreich angewendet bei %d (%d Zeilen versetzt)"
 
-#: apply.c:3067
+#: apply.c:3069
 #, c-format
 msgid "Context reduced to (%ld/%ld) to apply fragment at %d"
 msgstr "Kontext reduziert zu (%ld/%ld), um Patch-Bereich bei %d anzuwenden"
 
-#: apply.c:3073
+#: apply.c:3075
 #, c-format
 msgid ""
 "while searching for:\n"
@@ -303,25 +756,25 @@ msgstr ""
 "bei der Suche nach:\n"
 "%.*s"
 
-#: apply.c:3095
+#: apply.c:3097
 #, c-format
 msgid "missing binary patch data for '%s'"
 msgstr "keine Daten in Binär-Patch für '%s'"
 
-#: apply.c:3103
+#: apply.c:3105
 #, c-format
 msgid "cannot reverse-apply a binary patch without the reverse hunk to '%s'"
 msgstr ""
 "kann binären Patch nicht in umgekehrter Reihenfolge anwenden ohne einen\n"
 "umgekehrten Patch-Block auf '%s'"
 
-#: apply.c:3149
+#: apply.c:3152
 #, c-format
 msgid "cannot apply binary patch to '%s' without full index line"
 msgstr ""
 "kann binären Patch auf '%s' nicht ohne eine vollständige Index-Zeile anwenden"
 
-#: apply.c:3159
+#: apply.c:3162
 #, c-format
 msgid ""
 "the patch applies to '%s' (%s), which does not match the current contents."
@@ -329,560 +782,626 @@ msgstr ""
 "der Patch wird angewendet auf '%s' (%s), was nicht den aktuellen Inhalten\n"
 "entspricht"
 
-#: apply.c:3167
+#: apply.c:3170
 #, c-format
 msgid "the patch applies to an empty '%s' but it is not empty"
 msgstr "der Patch wird auf ein leeres '%s' angewendet, was aber nicht leer ist"
 
-#: apply.c:3185
+#: apply.c:3188
 #, c-format
 msgid "the necessary postimage %s for '%s' cannot be read"
 msgstr "das erforderliche Postimage %s für '%s' kann nicht gelesen werden"
 
-#: apply.c:3198
+#: apply.c:3201
 #, c-format
 msgid "binary patch does not apply to '%s'"
 msgstr "Konnte Binär-Patch nicht auf '%s' anwenden"
 
-#: apply.c:3204
+#: apply.c:3207
 #, c-format
 msgid "binary patch to '%s' creates incorrect result (expecting %s, got %s)"
 msgstr ""
 "Binär-Patch für '%s' erzeugt falsches Ergebnis (erwartete %s, bekam %s)"
 
-#: apply.c:3225
+#: apply.c:3228
 #, c-format
 msgid "patch failed: %s:%ld"
 msgstr "Anwendung des Patches fehlgeschlagen: %s:%ld"
 
-#: apply.c:3347
+#: apply.c:3351
 #, c-format
 msgid "cannot checkout %s"
 msgstr "kann %s nicht auschecken"
 
-#: apply.c:3396 apply.c:3407 apply.c:3453 setup.c:277
+#: apply.c:3403 apply.c:3414 apply.c:3460 midx.c:61 setup.c:280
 #, c-format
 msgid "failed to read %s"
 msgstr "Fehler beim Lesen von %s"
 
-#: apply.c:3404
+#: apply.c:3411
 #, c-format
 msgid "reading from '%s' beyond a symbolic link"
 msgstr "'%s' ist hinter einer symbolischen Verknüpfung"
 
-#: apply.c:3433 apply.c:3673
+#: apply.c:3440 apply.c:3683
 #, c-format
 msgid "path %s has been renamed/deleted"
 msgstr "Pfad %s wurde umbenannt/gelöscht"
 
-#: apply.c:3516 apply.c:3687
+#: apply.c:3526 apply.c:3698
 #, c-format
 msgid "%s: does not exist in index"
 msgstr "%s ist nicht im Index"
 
-#: apply.c:3525 apply.c:3695
+#: apply.c:3535 apply.c:3706
 #, c-format
 msgid "%s: does not match index"
 msgstr "%s entspricht nicht der Version im Index"
 
-#: apply.c:3560
+#: apply.c:3570
 msgid "repository lacks the necessary blob to fall back on 3-way merge."
 msgstr ""
 "Dem Repository fehlt der notwendige Blob, um auf einen 3-Wege-Merge\n"
 "zurückzufallen."
 
-#: apply.c:3563
+#: apply.c:3573
 #, c-format
 msgid "Falling back to three-way merge...\n"
 msgstr "Falle zurück auf 3-Wege-Merge ...\n"
 
-#: apply.c:3579 apply.c:3583
+#: apply.c:3589 apply.c:3593
 #, c-format
 msgid "cannot read the current contents of '%s'"
 msgstr "kann aktuelle Inhalte von '%s' nicht lesen"
 
-#: apply.c:3595
+#: apply.c:3605
 #, c-format
 msgid "Failed to fall back on three-way merge...\n"
 msgstr "Fehler beim Zurückfallen auf 3-Wege-Merge...\n"
 
-#: apply.c:3609
+#: apply.c:3619
 #, c-format
 msgid "Applied patch to '%s' with conflicts.\n"
 msgstr "Patch auf '%s' mit Konflikten angewendet.\n"
 
-#: apply.c:3614
+#: apply.c:3624
 #, c-format
 msgid "Applied patch to '%s' cleanly.\n"
 msgstr "Patch auf '%s' sauber angewendet.\n"
 
-#: apply.c:3640
+#: apply.c:3650
 msgid "removal patch leaves file contents"
 msgstr "Lösch-Patch hinterlässt Dateiinhalte"
 
-#: apply.c:3712
+#: apply.c:3723
 #, c-format
 msgid "%s: wrong type"
 msgstr "%s: falscher Typ"
 
-#: apply.c:3714
+#: apply.c:3725
 #, c-format
 msgid "%s has type %o, expected %o"
 msgstr "%s ist vom Typ %o, erwartete %o"
 
-#: apply.c:3864 apply.c:3866
+#: apply.c:3876 apply.c:3878 read-cache.c:830 read-cache.c:856
+#: read-cache.c:1320
 #, c-format
 msgid "invalid path '%s'"
 msgstr "Ungültiger Pfad '%s'"
 
-#: apply.c:3922
+#: apply.c:3934
 #, c-format
 msgid "%s: already exists in index"
 msgstr "%s ist bereits bereitgestellt"
 
-#: apply.c:3925
+#: apply.c:3937
 #, c-format
 msgid "%s: already exists in working directory"
 msgstr "%s existiert bereits im Arbeitsverzeichnis"
 
-#: apply.c:3945
+#: apply.c:3957
 #, c-format
 msgid "new mode (%o) of %s does not match old mode (%o)"
 msgstr "neuer Modus (%o) von %s entspricht nicht dem alten Modus (%o)"
 
-#: apply.c:3950
+#: apply.c:3962
 #, c-format
 msgid "new mode (%o) of %s does not match old mode (%o) of %s"
 msgstr "neuer Modus (%o) von %s entspricht nicht dem alten Modus (%o) von %s"
 
-#: apply.c:3970
+#: apply.c:3982
 #, c-format
 msgid "affected file '%s' is beyond a symbolic link"
 msgstr "betroffene Datei '%s' ist hinter einer symbolischen Verknüpfung"
 
-#: apply.c:3974
+#: apply.c:3986
 #, c-format
 msgid "%s: patch does not apply"
 msgstr "%s: Patch konnte nicht angewendet werden"
 
-#: apply.c:3989
+#: apply.c:4001
 #, c-format
 msgid "Checking patch %s..."
 msgstr "Prüfe Patch %s ..."
 
-#: apply.c:4080
+#: apply.c:4093
 #, c-format
 msgid "sha1 information is lacking or useless for submodule %s"
 msgstr "SHA-1 Information fehlt oder ist unbrauchbar für Submodul %s"
 
-#: apply.c:4087
+#: apply.c:4100
 #, c-format
 msgid "mode change for %s, which is not in current HEAD"
 msgstr "Modusänderung für %s, was sich nicht im aktuellen HEAD befindet"
 
-#: apply.c:4090
+#: apply.c:4103
 #, c-format
 msgid "sha1 information is lacking or useless (%s)."
 msgstr "SHA-1 Information fehlt oder ist unbrauchbar (%s)."
 
-#: apply.c:4095 builtin/checkout.c:235 builtin/reset.c:140
-#, c-format
-msgid "make_cache_entry failed for path '%s'"
-msgstr "make_cache_entry für Pfad '%s' fehlgeschlagen"
-
-#: apply.c:4099
+#: apply.c:4112
 #, c-format
 msgid "could not add %s to temporary index"
 msgstr "konnte %s nicht zum temporären Index hinzufügen"
 
-#: apply.c:4109
+#: apply.c:4122
 #, c-format
 msgid "could not write temporary index to %s"
 msgstr "konnte temporären Index nicht nach %s schreiben"
 
-#: apply.c:4247
+#: apply.c:4260
 #, c-format
 msgid "unable to remove %s from index"
 msgstr "konnte %s nicht aus dem Index entfernen"
 
-#: apply.c:4282
+#: apply.c:4294
 #, c-format
 msgid "corrupt patch for submodule %s"
 msgstr "fehlerhafter Patch für Submodul %s"
 
-#: apply.c:4288
+#: apply.c:4300
 #, c-format
 msgid "unable to stat newly created file '%s'"
 msgstr "konnte neu erstellte Datei '%s' nicht lesen"
 
-#: apply.c:4296
+#: apply.c:4308
 #, c-format
 msgid "unable to create backing store for newly created file %s"
 msgstr "kann internen Speicher für eben erstellte Datei %s nicht erzeugen"
 
-#: apply.c:4302 apply.c:4446
+#: apply.c:4314 apply.c:4459
 #, c-format
 msgid "unable to add cache entry for %s"
 msgstr "kann für %s keinen Eintrag in den Zwischenspeicher hinzufügen"
 
-#: apply.c:4343
+#: apply.c:4357
 #, c-format
 msgid "failed to write to '%s'"
 msgstr "Fehler beim Schreiben nach '%s'"
 
-#: apply.c:4347
+#: apply.c:4361
 #, c-format
 msgid "closing file '%s'"
 msgstr "schließe Datei '%s'"
 
-#: apply.c:4417
+#: apply.c:4431
 #, c-format
 msgid "unable to write file '%s' mode %o"
 msgstr "konnte Datei '%s' mit Modus %o nicht schreiben"
 
-#: apply.c:4515
+#: apply.c:4529
 #, c-format
 msgid "Applied patch %s cleanly."
 msgstr "Patch %s sauber angewendet"
 
-#: apply.c:4523
+#: apply.c:4537
 msgid "internal error"
 msgstr "interner Fehler"
 
-#: apply.c:4526
+#: apply.c:4540
 #, c-format
 msgid "Applying patch %%s with %d reject..."
 msgid_plural "Applying patch %%s with %d rejects..."
 msgstr[0] "Wende Patch %%s mit %d Zurückweisung an..."
 msgstr[1] "Wende Patch %%s mit %d Zurückweisungen an..."
 
-#: apply.c:4537
+#: apply.c:4551
 #, c-format
 msgid "truncating .rej filename to %.*s.rej"
 msgstr "Verkürze Name von .rej Datei zu %.*s.rej"
 
-#: apply.c:4545 builtin/fetch.c:775 builtin/fetch.c:1025
+#: apply.c:4559 builtin/fetch.c:901 builtin/fetch.c:1192
 #, c-format
 msgid "cannot open %s"
 msgstr "kann '%s' nicht öffnen"
 
-#: apply.c:4559
+#: apply.c:4573
 #, c-format
 msgid "Hunk #%d applied cleanly."
 msgstr "Patch-Bereich #%d sauber angewendet."
 
-#: apply.c:4563
+#: apply.c:4577
 #, c-format
 msgid "Rejected hunk #%d."
 msgstr "Patch-Block #%d zurückgewiesen."
 
-#: apply.c:4673
+#: apply.c:4696
 #, c-format
 msgid "Skipped patch '%s'."
 msgstr "Patch '%s' ausgelassen."
 
-#: apply.c:4681
+#: apply.c:4704
 msgid "unrecognized input"
 msgstr "nicht erkannte Eingabe"
 
-#: apply.c:4700
+#: apply.c:4724
 msgid "unable to read index file"
 msgstr "Konnte Index-Datei nicht lesen"
 
-#: apply.c:4837
+#: apply.c:4881
 #, c-format
 msgid "can't open patch '%s': %s"
 msgstr "kann Patch '%s' nicht öffnen: %s"
 
-#: apply.c:4864
+#: apply.c:4908
 #, c-format
 msgid "squelched %d whitespace error"
 msgid_plural "squelched %d whitespace errors"
 msgstr[0] "unterdrückte %d Whitespace-Fehler"
 msgstr[1] "unterdrückte %d Whitespace-Fehler"
 
-#: apply.c:4870 apply.c:4885
+#: apply.c:4914 apply.c:4929
 #, c-format
 msgid "%d line adds whitespace errors."
 msgid_plural "%d lines add whitespace errors."
 msgstr[0] "%d Zeile fügt Whitespace-Fehler hinzu."
 msgstr[1] "%d Zeilen fügen Whitespace-Fehler hinzu."
 
-#: apply.c:4878
+#: apply.c:4922
 #, c-format
 msgid "%d line applied after fixing whitespace errors."
 msgid_plural "%d lines applied after fixing whitespace errors."
 msgstr[0] "%d Zeile nach Behebung von Whitespace-Fehlern angewendet."
 msgstr[1] "%d Zeilen nach Behebung von Whitespace-Fehlern angewendet."
 
-#: apply.c:4894 builtin/add.c:539 builtin/mv.c:298 builtin/rm.c:390
+#: apply.c:4938 builtin/add.c:579 builtin/mv.c:301 builtin/rm.c:390
 msgid "Unable to write new index file"
 msgstr "Konnte neue Index-Datei nicht schreiben."
 
-#: apply.c:4921 apply.c:4924 builtin/am.c:2254 builtin/am.c:2257
-#: builtin/clone.c:118 builtin/fetch.c:127 builtin/pull.c:193
-#: builtin/submodule--helper.c:403 builtin/submodule--helper.c:1197
-#: builtin/submodule--helper.c:1200 builtin/submodule--helper.c:1567
-#: builtin/submodule--helper.c:1570 builtin/submodule--helper.c:1787
-#: git-add--interactive.perl:197
-msgid "path"
-msgstr "Pfad"
-
-#: apply.c:4922
+#: apply.c:4966
 msgid "don't apply changes matching the given path"
 msgstr "keine Änderungen im angegebenen Pfad anwenden"
 
-#: apply.c:4925
+#: apply.c:4969
 msgid "apply changes matching the given path"
 msgstr "Änderungen nur im angegebenen Pfad anwenden"
 
-#: apply.c:4927 builtin/am.c:2263
+#: apply.c:4971 builtin/am.c:2206
 msgid "num"
 msgstr "Anzahl"
 
-#: apply.c:4928
+#: apply.c:4972
 msgid "remove <num> leading slashes from traditional diff paths"
 msgstr ""
 "<Anzahl> vorangestellte Schrägstriche von herkömmlichen Differenzpfaden "
 "entfernen"
 
-#: apply.c:4931
+#: apply.c:4975
 msgid "ignore additions made by the patch"
 msgstr "hinzugefügte Zeilen des Patches ignorieren"
 
-#: apply.c:4933
+#: apply.c:4977
 msgid "instead of applying the patch, output diffstat for the input"
 msgstr ""
 "anstatt der Anwendung des Patches, den \"diffstat\" für die Eingabe "
 "ausgegeben"
 
-#: apply.c:4937
+#: apply.c:4981
 msgid "show number of added and deleted lines in decimal notation"
 msgstr ""
 "die Anzahl von hinzugefügten/entfernten Zeilen in Dezimalnotation anzeigen"
 
-#: apply.c:4939
+#: apply.c:4983
 msgid "instead of applying the patch, output a summary for the input"
 msgstr ""
 "anstatt der Anwendung des Patches, eine Zusammenfassung für die Eingabe "
 "ausgeben"
 
-#: apply.c:4941
+#: apply.c:4985
 msgid "instead of applying the patch, see if the patch is applicable"
 msgstr ""
 "anstatt der Anwendung des Patches, zeige ob Patch angewendet werden kann"
 
-#: apply.c:4943
+#: apply.c:4987
 msgid "make sure the patch is applicable to the current index"
 msgstr ""
 "sicherstellen, dass der Patch mit dem aktuellen Index angewendet werden kann"
 
-#: apply.c:4945
+#: apply.c:4989
+msgid "mark new files with `git add --intent-to-add`"
+msgstr "neue Dateien mit `git add --intent-to-add` markieren"
+
+#: apply.c:4991
 msgid "apply a patch without touching the working tree"
 msgstr "Patch anwenden, ohne Änderungen im Arbeitsverzeichnis vorzunehmen"
 
-#: apply.c:4947
+#: apply.c:4993
 msgid "accept a patch that touches outside the working area"
 msgstr ""
 "Patch anwenden, der Änderungen außerhalb des Arbeitsverzeichnisses vornimmt"
 
-#: apply.c:4950
+#: apply.c:4996
 msgid "also apply the patch (use with --stat/--summary/--check)"
 msgstr "Patch anwenden (Benutzung mit --stat/--summary/--check)"
 
-#: apply.c:4952
+#: apply.c:4998
 msgid "attempt three-way merge if a patch does not apply"
 msgstr "versuche 3-Wege-Merge, wenn der Patch nicht angewendet werden konnte"
 
-#: apply.c:4954
+#: apply.c:5000
 msgid "build a temporary index based on embedded index information"
 msgstr ""
 "einen temporären Index, basierend auf den integrierten Index-Informationen, "
 "erstellen"
 
-#: apply.c:4957 builtin/checkout-index.c:168 builtin/ls-files.c:515
+#: apply.c:5003 builtin/checkout-index.c:173 builtin/ls-files.c:524
 msgid "paths are separated with NUL character"
 msgstr "Pfade sind getrennt durch NUL Zeichen"
 
-#: apply.c:4959
+#: apply.c:5005
 msgid "ensure at least <n> lines of context match"
 msgstr ""
 "sicher stellen, dass mindestens <n> Zeilen des Kontextes übereinstimmen"
 
-#: apply.c:4960 builtin/am.c:2242 builtin/interpret-trailers.c:95
-#: builtin/interpret-trailers.c:97 builtin/interpret-trailers.c:99
-#: builtin/pack-objects.c:3035
+#: apply.c:5006 builtin/am.c:2185 builtin/interpret-trailers.c:98
+#: builtin/interpret-trailers.c:100 builtin/interpret-trailers.c:102
+#: builtin/pack-objects.c:3310 builtin/rebase.c:1474
 msgid "action"
 msgstr "Aktion"
 
-#: apply.c:4961
+#: apply.c:5007
 msgid "detect new or modified lines that have whitespace errors"
 msgstr "neue oder geänderte Zeilen, die Whitespace-Fehler haben, ermitteln"
 
-#: apply.c:4964 apply.c:4967
+#: apply.c:5010 apply.c:5013
 msgid "ignore changes in whitespace when finding context"
 msgstr "Änderungen im Whitespace bei der Suche des Kontextes ignorieren"
 
-#: apply.c:4970
+#: apply.c:5016
 msgid "apply the patch in reverse"
 msgstr "den Patch in umgekehrter Reihenfolge anwenden"
 
-#: apply.c:4972
+#: apply.c:5018
 msgid "don't expect at least one line of context"
 msgstr "keinen Kontext erwarten"
 
-#: apply.c:4974
+#: apply.c:5020
 msgid "leave the rejected hunks in corresponding *.rej files"
 msgstr ""
 "zurückgewiesene Patch-Blöcke in entsprechenden *.rej Dateien hinterlassen"
 
-#: apply.c:4976
+#: apply.c:5022
 msgid "allow overlapping hunks"
 msgstr "sich überlappende Patch-Blöcke erlauben"
 
-#: apply.c:4977 builtin/add.c:292 builtin/check-ignore.c:21
-#: builtin/commit.c:1276 builtin/count-objects.c:96 builtin/fsck.c:665
-#: builtin/log.c:1901 builtin/mv.c:123 builtin/read-tree.c:125
+#: apply.c:5023 builtin/add.c:309 builtin/check-ignore.c:22
+#: builtin/commit.c:1355 builtin/count-objects.c:98 builtin/fsck.c:774
+#: builtin/log.c:2166 builtin/mv.c:123 builtin/read-tree.c:128
 msgid "be verbose"
 msgstr "erweiterte Ausgaben"
 
-#: apply.c:4979
+#: apply.c:5025
 msgid "tolerate incorrectly detected missing new-line at the end of file"
 msgstr "fehlerhaft erkannten fehlenden Zeilenumbruch am Dateiende tolerieren"
 
-#: apply.c:4982
+#: apply.c:5028
 msgid "do not trust the line counts in the hunk headers"
 msgstr "den Zeilennummern im Kopf des Patch-Blocks nicht vertrauen"
 
-#: apply.c:4984 builtin/am.c:2251
+#: apply.c:5030 builtin/am.c:2194
 msgid "root"
 msgstr "Wurzelverzeichnis"
 
-#: apply.c:4985
+#: apply.c:5031
 msgid "prepend <root> to all filenames"
 msgstr "<Wurzelverzeichnis> vor alle Dateinamen stellen"
 
-#: archive.c:13
+#: archive.c:14
 msgid "git archive [<options>] <tree-ish> [<path>...]"
 msgstr "git archive [<Optionen>] <Commit-Referenz> [<Pfad>...]"
 
-#: archive.c:14
+#: archive.c:15
 msgid "git archive --list"
 msgstr "git archive --list"
 
-#: archive.c:15
+#: archive.c:16
 msgid ""
 "git archive --remote <repo> [--exec <cmd>] [<options>] <tree-ish> [<path>...]"
 msgstr ""
 "git archive --remote <Repository> [--exec <Programm>] [<Optionen>] <Commit-"
 "Referenz> [<Pfad>...]"
 
-#: archive.c:16
+#: archive.c:17
 msgid "git archive --remote <repo> [--exec <cmd>] --list"
 msgstr "git archive --remote <Repository> [--exec <Programm>] --list"
 
-#: archive.c:351 builtin/add.c:176 builtin/add.c:515 builtin/rm.c:299
+#: archive.c:372 builtin/add.c:180 builtin/add.c:555 builtin/rm.c:299
 #, c-format
 msgid "pathspec '%s' did not match any files"
 msgstr "Pfadspezifikation '%s' stimmt mit keinen Dateien überein"
 
-#: archive.c:436
+#: archive.c:396
+#, c-format
+msgid "no such ref: %.*s"
+msgstr "Keine solche Referenz: %.*s"
+
+#: archive.c:401
+#, c-format
+msgid "not a valid object name: %s"
+msgstr "Kein gültiger Objektname: %s"
+
+#: archive.c:414
+#, c-format
+msgid "not a tree object: %s"
+msgstr "Kein Tree-Objekt: %s"
+
+#: archive.c:426
+msgid "current working directory is untracked"
+msgstr "Aktuelles Arbeitsverzeichnis ist unversioniert."
+
+#: archive.c:457
 msgid "fmt"
 msgstr "Format"
 
-#: archive.c:436
+#: archive.c:457
 msgid "archive format"
 msgstr "Archivformat"
 
-#: archive.c:437 builtin/log.c:1462
+#: archive.c:458 builtin/log.c:1653
 msgid "prefix"
 msgstr "Präfix"
 
-#: archive.c:438
+#: archive.c:459
 msgid "prepend prefix to each pathname in the archive"
 msgstr "einen Präfix vor jeden Pfadnamen in dem Archiv stellen"
 
-#: archive.c:439 builtin/blame.c:702 builtin/blame.c:703 builtin/config.c:62
-#: builtin/fast-export.c:1005 builtin/fast-export.c:1007 builtin/grep.c:869
-#: builtin/hash-object.c:103 builtin/ls-files.c:551 builtin/ls-files.c:554
-#: builtin/notes.c:405 builtin/notes.c:568 builtin/read-tree.c:120
-#: parse-options.h:165
+#: archive.c:460 builtin/blame.c:861 builtin/blame.c:865 builtin/blame.c:866
+#: builtin/commit-tree.c:117 builtin/config.c:129 builtin/fast-export.c:1162
+#: builtin/fast-export.c:1164 builtin/fast-export.c:1168 builtin/grep.c:899
+#: builtin/hash-object.c:105 builtin/ls-files.c:560 builtin/ls-files.c:563
+#: builtin/notes.c:412 builtin/notes.c:578 builtin/read-tree.c:123
+#: parse-options.h:190
 msgid "file"
 msgstr "Datei"
 
-#: archive.c:440 builtin/archive.c:89
+#: archive.c:461 builtin/archive.c:90
 msgid "write the archive to this file"
 msgstr "das Archiv in diese Datei schreiben"
 
-#: archive.c:442
+#: archive.c:463
 msgid "read .gitattributes in working directory"
 msgstr ".gitattributes aus dem Arbeitsverzeichnis lesen"
 
-#: archive.c:443
+#: archive.c:464
 msgid "report archived files on stderr"
 msgstr "archivierte Dateien in der Standard-Fehlerausgabe ausgeben"
 
-#: archive.c:444
+#: archive.c:465
 msgid "store only"
 msgstr "nur speichern"
 
-#: archive.c:445
+#: archive.c:466
 msgid "compress faster"
 msgstr "schneller komprimieren"
 
-#: archive.c:453
+#: archive.c:474
 msgid "compress better"
 msgstr "besser komprimieren"
 
-#: archive.c:456
+#: archive.c:477
 msgid "list supported archive formats"
 msgstr "unterstützte Archivformate auflisten"
 
-#: archive.c:458 builtin/archive.c:90 builtin/clone.c:108 builtin/clone.c:111
-#: builtin/submodule--helper.c:1209 builtin/submodule--helper.c:1576
+#: archive.c:479 builtin/archive.c:91 builtin/clone.c:113 builtin/clone.c:116
+#: builtin/submodule--helper.c:1391 builtin/submodule--helper.c:1884
 msgid "repo"
 msgstr "Repository"
 
-#: archive.c:459 builtin/archive.c:91
+#: archive.c:480 builtin/archive.c:92
 msgid "retrieve the archive from remote repository <repo>"
 msgstr "Archiv vom Remote-Repository <Repository> abrufen"
 
-#: archive.c:460 builtin/archive.c:92 builtin/notes.c:489
+#: archive.c:481 builtin/archive.c:93 builtin/difftool.c:715
+#: builtin/notes.c:498
 msgid "command"
 msgstr "Programm"
 
-#: archive.c:461 builtin/archive.c:93
+#: archive.c:482 builtin/archive.c:94
 msgid "path to the remote git-upload-archive command"
 msgstr "Pfad zum externen \"git-upload-archive\"-Programm"
 
-#: archive.c:468
+#: archive.c:489
 msgid "Unexpected option --remote"
 msgstr "Unerwartete Option --remote"
 
-#: archive.c:470
+#: archive.c:491
 msgid "Option --exec can only be used together with --remote"
 msgstr "Die Option --exec kann nur zusammen mit --remote verwendet werden."
 
-#: archive.c:472
+#: archive.c:493
 msgid "Unexpected option --output"
 msgstr "Unerwartete Option --output"
 
-#: archive.c:494
+#: archive.c:515
 #, c-format
 msgid "Unknown archive format '%s'"
 msgstr "Unbekanntes Archivformat '%s'"
 
-#: archive.c:501
+#: archive.c:522
 #, c-format
 msgid "Argument not supported for format '%s': -%d"
 msgstr "Argument für Format '%s' nicht unterstützt: -%d"
 
-#: attr.c:218
+#: archive-tar.c:125 archive-zip.c:350
+#, c-format
+msgid "cannot stream blob %s"
+msgstr "Kann Blob %s nicht streamen."
+
+#: archive-tar.c:266 archive-zip.c:368
+#, c-format
+msgid "unsupported file mode: 0%o (SHA1: %s)"
+msgstr "Nicht unterstützter Dateimodus: 0%o (SHA1: %s)"
+
+#: archive-tar.c:293 archive-zip.c:358
+#, c-format
+msgid "cannot read %s"
+msgstr "Kann %s nicht lesen."
+
+#: archive-tar.c:465
+#, c-format
+msgid "unable to start '%s' filter"
+msgstr "Konnte '%s' Filter nicht starten."
+
+#: archive-tar.c:468
+msgid "unable to redirect descriptor"
+msgstr "Konnte Descriptor nicht umleiten."
+
+#: archive-tar.c:475
+#, c-format
+msgid "'%s' filter reported error"
+msgstr "'%s' Filter meldete Fehler."
+
+#: archive-zip.c:319
+#, c-format
+msgid "path is not valid UTF-8: %s"
+msgstr "Pfad ist kein gültiges UTF-8: %s"
+
+#: archive-zip.c:323
+#, c-format
+msgid "path too long (%d chars, SHA1: %s): %s"
+msgstr "Pfad zu lang (%d Zeichen, SHA1: %s): %s"
+
+#: archive-zip.c:479 builtin/pack-objects.c:230 builtin/pack-objects.c:233
+#, c-format
+msgid "deflate error (%d)"
+msgstr "Fehler beim Komprimieren (%d)"
+
+#: archive-zip.c:614
+#, c-format
+msgid "timestamp too large for this system: %<PRIuMAX>"
+msgstr "Timestamp zu groß für dieses System: %<PRIuMAX>"
+
+#: attr.c:212
 #, c-format
 msgid "%.*s is not a valid attribute name"
 msgstr "%.*s ist kein gültiger Attributname"
 
-#: attr.c:415
+#: attr.c:369
+#, c-format
+msgid "%s not allowed: %s:%d"
+msgstr "%s nicht erlaubt: %s:%d"
+
+#: attr.c:409
 msgid ""
 "Negative patterns are ignored in git attributes\n"
 "Use '\\!' for literal leading exclamation."
@@ -890,22 +1409,22 @@ msgstr ""
 "Verneinende Muster werden in Git-Attributen ignoriert.\n"
 "Benutzen Sie '\\!' für führende Ausrufezeichen."
 
-#: bisect.c:460
+#: bisect.c:468
 #, c-format
 msgid "Badly quoted content in file '%s': %s"
-msgstr "Ungültiger Inhalt bzgl. Anführungsstriche in Datei '%s': %s"
+msgstr "Ungültiger Inhalt bzgl. Anführungszeichen in Datei '%s': %s"
 
-#: bisect.c:668
+#: bisect.c:678
 #, c-format
 msgid "We cannot bisect more!\n"
 msgstr "Keine binäre Suche mehr möglich!\n"
 
-#: bisect.c:722
+#: bisect.c:733
 #, c-format
 msgid "Not a valid commit name %s"
 msgstr "%s ist kein gültiger Commit-Name"
 
-#: bisect.c:746
+#: bisect.c:758
 #, c-format
 msgid ""
 "The merge base %s is bad.\n"
@@ -914,7 +1433,7 @@ msgstr ""
 "Die Merge-Basis %s ist fehlerhaft.\n"
 "Das bedeutet, der Fehler wurde zwischen %s und [%s] behoben.\n"
 
-#: bisect.c:751
+#: bisect.c:763
 #, c-format
 msgid ""
 "The merge base %s is new.\n"
@@ -923,7 +1442,7 @@ msgstr ""
 "Die Merge-Basis %s ist neu.\n"
 "Das bedeutet, die Eigenschaft hat sich zwischen %s und [%s] geändert.\n"
 
-#: bisect.c:756
+#: bisect.c:768
 #, c-format
 msgid ""
 "The merge base %s is %s.\n"
@@ -932,7 +1451,7 @@ msgstr ""
 "Die Merge-Basis %s ist %s.\n"
 "Das bedeutet, der erste '%s' Commit befindet sich zwischen %s und [%s].\n"
 
-#: bisect.c:764
+#: bisect.c:776
 #, c-format
 msgid ""
 "Some %s revs are not ancestors of the %s rev.\n"
@@ -943,7 +1462,7 @@ msgstr ""
 "git bisect kann in diesem Fall nicht richtig arbeiten.\n"
 "Vielleicht verwechselten Sie %s und %s Commits?\n"
 
-#: bisect.c:777
+#: bisect.c:789
 #, c-format
 msgid ""
 "the merge base between %s and [%s] must be skipped.\n"
@@ -955,36 +1474,36 @@ msgstr ""
 "erste %s Commit zwischen %s und %s befindet.\n"
 "Es wird dennoch fortgesetzt."
 
-#: bisect.c:810
+#: bisect.c:822
 #, c-format
 msgid "Bisecting: a merge base must be tested\n"
 msgstr "binäre Suche: eine Merge-Basis muss geprüft werden\n"
 
-#: bisect.c:850
+#: bisect.c:865
 #, c-format
 msgid "a %s revision is needed"
 msgstr "ein %s Commit wird benötigt"
 
-#: bisect.c:869 builtin/notes.c:175 builtin/tag.c:235
+#: bisect.c:884 builtin/notes.c:177 builtin/tag.c:254
 #, c-format
 msgid "could not create file '%s'"
 msgstr "konnte Datei '%s' nicht erstellen"
 
-#: bisect.c:920
+#: bisect.c:928 builtin/merge.c:148
 #, c-format
 msgid "could not read file '%s'"
 msgstr "Konnte Datei '%s' nicht lesen"
 
-#: bisect.c:950
+#: bisect.c:958
 msgid "reading bisect refs failed"
 msgstr "Lesen von Referenzen für binäre Suche fehlgeschlagen"
 
-#: bisect.c:969
+#: bisect.c:977
 #, c-format
 msgid "%s was both %s and %s\n"
 msgstr "%s war sowohl %s als auch %s\n"
 
-#: bisect.c:977
+#: bisect.c:985
 #, c-format
 msgid ""
 "No testable commit found.\n"
@@ -993,7 +1512,7 @@ msgstr ""
 "Kein testbarer Commit gefunden.\n"
 "Vielleicht starteten Sie mit falschen Pfad-Parametern?\n"
 
-#: bisect.c:996
+#: bisect.c:1004
 #, c-format
 msgid "(roughly %d step)"
 msgid_plural "(roughly %d steps)"
@@ -1003,49 +1522,50 @@ msgstr[1] "(ungefähr %d Schritte)"
 #. TRANSLATORS: the last %s will be replaced with "(roughly %d
 #. steps)" translation.
 #.
-#: bisect.c:1002
+#: bisect.c:1010
 #, c-format
 msgid "Bisecting: %d revision left to test after this %s\n"
 msgid_plural "Bisecting: %d revisions left to test after this %s\n"
 msgstr[0] "binäre Suche: danach noch %d Commit zum Testen übrig %s\n"
 msgstr[1] "binäre Suche: danach noch %d Commits zum Testen übrig %s\n"
 
-#: blame.c:1758
+#: blame.c:2700
 msgid "--contents and --reverse do not blend well."
 msgstr "--contents und --reverse funktionieren gemeinsam nicht."
 
-#: blame.c:1769
+#: blame.c:2714
 msgid "cannot use --contents with final commit object name"
 msgstr ""
 "kann --contents nicht mit endgültigem Namen des Commit-Objektes benutzen"
 
-#: blame.c:1789
+#: blame.c:2735
 msgid "--reverse and --first-parent together require specified latest commit"
 msgstr ""
 "--reverse und --first-parent zusammen erfordern die Angabe eines "
 "endgültigen\n"
 "Commits"
 
-#: blame.c:1798 bundle.c:160 ref-filter.c:1978 sequencer.c:1699
-#: sequencer.c:2901 builtin/commit.c:976 builtin/log.c:366 builtin/log.c:920
-#: builtin/log.c:1371 builtin/log.c:1702 builtin/log.c:1950 builtin/merge.c:370
-#: builtin/shortlog.c:191
+#: blame.c:2744 bundle.c:167 ref-filter.c:2203 remote.c:1941 sequencer.c:2093
+#: sequencer.c:4460 builtin/commit.c:1040 builtin/log.c:388 builtin/log.c:991
+#: builtin/log.c:1520 builtin/log.c:1925 builtin/log.c:2215 builtin/merge.c:411
+#: builtin/pack-objects.c:3128 builtin/pack-objects.c:3143
+#: builtin/shortlog.c:192
 msgid "revision walk setup failed"
 msgstr "Einrichtung des Revisionsgangs fehlgeschlagen"
 
-#: blame.c:1816
+#: blame.c:2762
 msgid ""
 "--reverse --first-parent together require range along first-parent chain"
 msgstr ""
 "--reverse und --first-parent zusammen erfordern einen Bereich entlang der\n"
 "\"first-parent\"-Kette"
 
-#: blame.c:1827
+#: blame.c:2773
 #, c-format
 msgid "no such path %s in %s"
 msgstr "Pfad %s nicht in %s"
 
-#: blame.c:1838
+#: blame.c:2784
 #, c-format
 msgid "cannot read blob %s for path %s"
 msgstr "kann Blob %s für Pfad '%s' nicht lesen"
@@ -1167,100 +1687,109 @@ msgstr ""
 "\"git push -u\" verwenden, um den Upstream-Branch beim \"push\"\n"
 "zu konfigurieren."
 
-#: branch.c:280
+#: branch.c:281
 #, c-format
 msgid "Not a valid object name: '%s'."
 msgstr "Ungültiger Objekt-Name: '%s'"
 
-#: branch.c:300
+#: branch.c:301
 #, c-format
 msgid "Ambiguous object name: '%s'."
 msgstr "mehrdeutiger Objekt-Name: '%s'"
 
-#: branch.c:305
+#: branch.c:306
 #, c-format
 msgid "Not a valid branch point: '%s'."
 msgstr "Ungültiger Branchpunkt: '%s'"
 
-#: branch.c:359
+#: branch.c:364
 #, c-format
 msgid "'%s' is already checked out at '%s'"
 msgstr "'%s' ist bereits in '%s' ausgecheckt"
 
-#: branch.c:382
+#: branch.c:387
 #, c-format
 msgid "HEAD of working tree %s is not updated"
 msgstr "HEAD des Arbeitsverzeichnisses %s ist nicht aktualisiert."
 
-#: bundle.c:34
+#: bundle.c:36
 #, c-format
 msgid "'%s' does not look like a v2 bundle file"
 msgstr "'%s' sieht nicht wie eine v2 Paketdatei aus"
 
-#: bundle.c:62
+#: bundle.c:64
 #, c-format
 msgid "unrecognized header: %s%s (%d)"
 msgstr "nicht erkannter Kopfbereich: %s%s (%d)"
 
-#: bundle.c:88 sequencer.c:1879 sequencer.c:2337 builtin/commit.c:750
+#: bundle.c:90 rerere.c:480 rerere.c:690 sequencer.c:2344 sequencer.c:3108
+#: builtin/commit.c:811
 #, c-format
 msgid "could not open '%s'"
 msgstr "Konnte '%s' nicht öffnen"
 
-#: bundle.c:139
+#: bundle.c:143
 msgid "Repository lacks these prerequisite commits:"
 msgstr "Dem Repository fehlen folgende vorausgesetzte Commits:"
 
-#: bundle.c:190
+#: bundle.c:146
+msgid "need a repository to verify a bundle"
+msgstr "Um ein Paket zu überprüfen wird ein Repository benötigt."
+
+#: bundle.c:197
 #, c-format
 msgid "The bundle contains this ref:"
 msgid_plural "The bundle contains these %d refs:"
 msgstr[0] "Das Paket enthält diese Referenz:"
 msgstr[1] "Das Paket enthält diese %d Referenzen:"
 
-#: bundle.c:197
+#: bundle.c:204
 msgid "The bundle records a complete history."
 msgstr "Das Paket speichert eine komplette Historie."
 
-#: bundle.c:199
+#: bundle.c:206
 #, c-format
 msgid "The bundle requires this ref:"
 msgid_plural "The bundle requires these %d refs:"
 msgstr[0] "Das Paket benötigt diese Referenz:"
 msgstr[1] "Das Paket benötigt diese %d Referenzen:"
 
-#: bundle.c:258
+#: bundle.c:273
+msgid "unable to dup bundle descriptor"
+msgstr "Konnte dup für Descriptor des Pakets nicht ausführen."
+
+#: bundle.c:280
 msgid "Could not spawn pack-objects"
 msgstr "Konnte Paketobjekte nicht erstellen"
 
-#: bundle.c:269
+#: bundle.c:291
 msgid "pack-objects died"
 msgstr "Erstellung der Paketobjekte abgebrochen"
 
-#: bundle.c:311
+#: bundle.c:333
 msgid "rev-list died"
 msgstr "\"rev-list\" abgebrochen"
 
-#: bundle.c:360
+#: bundle.c:382
 #, c-format
 msgid "ref '%s' is excluded by the rev-list options"
 msgstr "Referenz '%s' wird durch \"rev-list\" Optionen ausgeschlossen"
 
-#: bundle.c:450 builtin/log.c:183 builtin/log.c:1607 builtin/shortlog.c:296
+#: bundle.c:461 builtin/log.c:203 builtin/log.c:1814 builtin/shortlog.c:306
 #, c-format
 msgid "unrecognized argument: %s"
 msgstr "nicht erkanntes Argument: %s"
 
-#: bundle.c:458
+#: bundle.c:469
 msgid "Refusing to create empty bundle."
 msgstr "Erstellung eines leeren Pakets zurückgewiesen."
 
-#: bundle.c:470
+#: bundle.c:479
 #, c-format
 msgid "cannot create '%s'"
 msgstr "kann '%s' nicht erstellen"
 
-#: bundle.c:498
+#: bundle.c:504
 msgid "index-pack died"
 msgstr "Erstellung der Paketindexdatei abgebrochen"
 
@@ -1269,18 +1798,60 @@ msgstr "Erstellung der Paketindexdatei a
 msgid "invalid color value: %.*s"
 msgstr "Ungültiger Farbwert: %.*s"
 
-#: commit.c:41 sequencer.c:2141 builtin/am.c:421 builtin/am.c:465
-#: builtin/am.c:1436 builtin/am.c:2072
+#: commit.c:51 sequencer.c:2811 builtin/am.c:354 builtin/am.c:398
+#: builtin/am.c:1366 builtin/am.c:2009 builtin/replace.c:456
 #, c-format
 msgid "could not parse %s"
 msgstr "konnte %s nicht parsen"
 
-#: commit.c:43
+#: commit.c:53
 #, c-format
 msgid "%s %s is not a commit!"
 msgstr "%s %s ist kein Commit!"
 
-#: commit.c:1506
+#: commit.c:193
+msgid ""
+"Support for <GIT_DIR>/info/grafts is deprecated\n"
+"and will be removed in a future Git version.\n"
+"\n"
+"Please use \"git replace --convert-graft-file\"\n"
+"to convert the grafts into replace refs.\n"
+"\n"
+"Turn this message off by running\n"
+"\"git config advice.graftFileDeprecated false\""
+msgstr ""
+"Die Unterstützung für <GIT_DIR>/info/grafts ist veraltet\n"
+"und wird in zukünftigen Git Versionen entfernt.\n"
+"\n"
+"Bitte benutzen Sie \"git replace --convert-graft-file\"\n"
+"zum Konvertieren der künstlichen Vorgänger (\"grafts\")\n"
+"in ersetzende Referenzen.<\n"
+"\n"
+"Sie können diese Meldung unterdrücken, indem Sie\n"
+"\"git config advice.graftFileDeprecated false\" ausführen."
+
+#: commit.c:1152
+#, c-format
+msgid "Commit %s has an untrusted GPG signature, allegedly by %s."
+msgstr ""
+"Commit %s hat eine nicht vertrauenswürdige GPG-Signatur, angeblich von %s."
+
+#: commit.c:1155
+#, c-format
+msgid "Commit %s has a bad GPG signature allegedly by %s."
+msgstr "Commit %s hat eine ungültige GPG-Signatur, angeblich von %s."
+
+#: commit.c:1158
+#, c-format
+msgid "Commit %s does not have a GPG signature."
+msgstr "Commit %s hat keine GPG-Signatur."
+
+#: commit.c:1161
+#, c-format
+msgid "Commit %s has a good GPG signature by %s\n"
+msgstr "Commit %s hat eine gültige GPG-Signatur von %s\n"
+
+#: commit.c:1415
 msgid ""
 "Warning: commit message did not conform to UTF-8.\n"
 "You may want to amend it after fixing the message, or set the config\n"
@@ -1292,187 +1863,597 @@ msgstr ""
 "Encoding,\n"
 "welches von ihrem Projekt verwendet wird.\n"
 
-#: compat/obstack.c:405 compat/obstack.c:407
+#: commit-graph.c:130
+msgid "commit-graph file is too small"
+msgstr "Commit-Graph-Datei ist zu klein."
+
+#: commit-graph.c:195
+#, c-format
+msgid "commit-graph signature %X does not match signature %X"
+msgstr "Commit-Graph-Signatur %X stimmt nicht mit Signatur %X überein."
+
+#: commit-graph.c:202
+#, c-format
+msgid "commit-graph version %X does not match version %X"
+msgstr "Commit-Graph-Version %X stimmt nicht mit Version %X überein."
+
+#: commit-graph.c:209
+#, c-format
+msgid "commit-graph hash version %X does not match version %X"
+msgstr "Hash-Version des Commit-Graph %X stimmt nicht mit Version %X überein."
+
+#: commit-graph.c:232
+msgid "commit-graph chunk lookup table entry missing; file may be incomplete"
+msgstr ""
+"fehlender Tabelleneintrag für Commit-Graph Chunk-Lookup; Datei "
+"möglicherweise unvollständig"
+
+#: commit-graph.c:243
+#, c-format
+msgid "commit-graph improper chunk offset %08x%08x"
+msgstr "Unzulässiger Commit-Graph Chunk-Offset %08x%08x"
+
+#: commit-graph.c:286
+#, c-format
+msgid "commit-graph chunk id %08x appears multiple times"
+msgstr "Commit-Graph Chunk-Id %08x kommt mehrfach vor."
+
+#: commit-graph.c:350
+msgid "commit-graph has no base graphs chunk"
+msgstr "Commit-Graph hat keinen Basis-Graph-Chunk"
+
+#: commit-graph.c:360
+msgid "commit-graph chain does not match"
+msgstr "Commit-Graph Verkettung stimmt nicht überein."
+
+#: commit-graph.c:407
+#, c-format
+msgid "invalid commit-graph chain: line '%s' not a hash"
+msgstr "Ungültige Commit-Graph Verkettung: Zeile '%s' ist kein Hash"
+
+#: commit-graph.c:433
+msgid "unable to find all commit-graph files"
+msgstr "Konnte nicht alle Commit-Graph-Dateien finden."
+
+#: commit-graph.c:564 commit-graph.c:624
+msgid "invalid commit position. commit-graph is likely corrupt"
+msgstr "Ungültige Commit-Position. Commit-Graph ist wahrscheinlich beschädigt."
+
+#: commit-graph.c:585
+#, c-format
+msgid "could not find commit %s"
+msgstr "Konnte Commit %s nicht finden."
+
+#: commit-graph.c:858 builtin/am.c:1287
+#, c-format
+msgid "unable to parse commit %s"
+msgstr "Konnte Commit '%s' nicht parsen."
+
+#: commit-graph.c:1017 builtin/pack-objects.c:2641
+#, c-format
+msgid "unable to get type of object %s"
+msgstr "Konnte Art von Objekt '%s' nicht bestimmen."
+
+#: commit-graph.c:1049
+msgid "Loading known commits in commit graph"
+msgstr "Lade bekannte Commits in Commit-Graph"
+
+#: commit-graph.c:1066
+msgid "Expanding reachable commits in commit graph"
+msgstr "Erweitere erreichbare Commits in Commit-Graph"
+
+#: commit-graph.c:1085
+msgid "Clearing commit marks in commit graph"
+msgstr "Lösche Commit-Markierungen in Commit-Graph"
+
+#: commit-graph.c:1104
+msgid "Computing commit graph generation numbers"
+msgstr "Commit-Graph Generationsnummern berechnen"
+
+#: commit-graph.c:1179
+#, c-format
+msgid "Finding commits for commit graph in %d pack"
+msgid_plural "Finding commits for commit graph in %d packs"
+msgstr[0] "Suche Commits für Commit-Graph in %d Paket"
+msgstr[1] "Suche Commits für Commit-Graph in %d Paketen"
+
+#: commit-graph.c:1192
+#, c-format
+msgid "error adding pack %s"
+msgstr "Fehler beim Hinzufügen von Paket %s."
+
+#: commit-graph.c:1196
+#, c-format
+msgid "error opening index for %s"
+msgstr "Fehler beim Öffnen des Index für %s."
+
+#: commit-graph.c:1220
+#, c-format
+msgid "Finding commits for commit graph from %d ref"
+msgid_plural "Finding commits for commit graph from %d refs"
+msgstr[0] "Suche Commits für Commit-Graph in %d Referenz"
+msgstr[1] "Suche Commits für Commit-Graph in %d Referenzen"
+
+#: commit-graph.c:1240
+#, c-format
+msgid "invalid commit object id: %s"
+msgstr "ungültige Commit-Objekt-ID: %s"
+
+#: commit-graph.c:1255
+msgid "Finding commits for commit graph among packed objects"
+msgstr "Suche Commits für Commit-Graph in gepackten Objekten"
+
+#: commit-graph.c:1270
+msgid "Counting distinct commits in commit graph"
+msgstr "Zähle Commits in Commit-Graph"
+
+#: commit-graph.c:1300
+msgid "Finding extra edges in commit graph"
+msgstr "Suche zusätzliche Ränder in Commit-Graph"
+
+#: commit-graph.c:1346
+msgid "failed to write correct number of base graph ids"
+msgstr "Fehler beim Schreiben der korrekten Anzahl von Basis-Graph-IDs."
+
+#: commit-graph.c:1379 midx.c:814
+#, c-format
+msgid "unable to create leading directories of %s"
+msgstr "Konnte führende Verzeichnisse von '%s' nicht erstellen."
+
+#: commit-graph.c:1391 builtin/index-pack.c:306 builtin/repack.c:248
+#, c-format
+msgid "unable to create '%s'"
+msgstr "konnte '%s' nicht erstellen"
+
+#: commit-graph.c:1451
+#, c-format
+msgid "Writing out commit graph in %d pass"
+msgid_plural "Writing out commit graph in %d passes"
+msgstr[0] "Schreibe Commit-Graph in %d Durchgang"
+msgstr[1] "Schreibe Commit-Graph in %d Durchgängen"
+
+#: commit-graph.c:1492
+msgid "unable to open commit-graph chain file"
+msgstr "Konnte Commit-Graph Chain-Datei nicht öffnen."
+
+#: commit-graph.c:1504
+msgid "failed to rename base commit-graph file"
+msgstr "Konnte Basis-Commit-Graph-Datei nicht umbenennen."
+
+#: commit-graph.c:1524
+msgid "failed to rename temporary commit-graph file"
+msgstr "Konnte temporäre Commit-Graph-Datei nicht umbenennen."
+
+#: commit-graph.c:1635
+msgid "Scanning merged commits"
+msgstr "Durchsuche zusammengeführte Commits"
+
+#: commit-graph.c:1646
+#, c-format
+msgid "unexpected duplicate commit id %s"
+msgstr "Unerwartete doppelte Commit-ID %s"
+
+#: commit-graph.c:1670
+msgid "Merging commit-graph"
+msgstr "Zusammenführen von Commit-Graph"
+
+#: commit-graph.c:1860
+#, c-format
+msgid "the commit graph format cannot write %d commits"
+msgstr "Das Commit-Graph Format kann nicht %d Commits schreiben."
+
+#: commit-graph.c:1871
+msgid "too many commits to write graph"
+msgstr "Zu viele Commits zum Schreiben des Graphen."
+
+#: commit-graph.c:1961
+msgid "the commit-graph file has incorrect checksum and is likely corrupt"
+msgstr ""
+"Die Commit-Graph-Datei hat eine falsche Prüfsumme und ist wahrscheinlich "
+"beschädigt."
+
+#: commit-graph.c:1971
+#, c-format
+msgid "commit-graph has incorrect OID order: %s then %s"
+msgstr "Commit-Graph hat fehlerhafte OID-Reihenfolge: %s dann %s"
+
+#: commit-graph.c:1981 commit-graph.c:1996
+#, c-format
+msgid "commit-graph has incorrect fanout value: fanout[%d] = %u != %u"
+msgstr "Commit-Graph hat fehlerhaften Fanout-Wert: fanout[%d] = %u != %u"
+
+#: commit-graph.c:1988
+#, c-format
+msgid "failed to parse commit %s from commit-graph"
+msgstr "Konnte Commit %s von Commit-Graph nicht parsen."
+
+#: commit-graph.c:2006
+msgid "Verifying commits in commit graph"
+msgstr "Commit in Commit-Graph überprüfen"
+
+#: commit-graph.c:2020
+#, c-format
+msgid "failed to parse commit %s from object database for commit-graph"
+msgstr ""
+"Fehler beim Parsen des Commits %s von Objekt-Datenbank für Commit-Graph"
+
+#: commit-graph.c:2027
+#, c-format
+msgid "root tree OID for commit %s in commit-graph is %s != %s"
+msgstr ""
+"OID des Wurzelverzeichnisses für Commit %s in Commit-Graph ist %s != %s"
+
+#: commit-graph.c:2037
+#, c-format
+msgid "commit-graph parent list for commit %s is too long"
+msgstr "Commit-Graph Vorgänger-Liste für Commit %s ist zu lang"
+
+#: commit-graph.c:2046
+#, c-format
+msgid "commit-graph parent for %s is %s != %s"
+msgstr "Commit-Graph-Vorgänger für %s ist %s != %s"
+
+#: commit-graph.c:2059
+#, c-format
+msgid "commit-graph parent list for commit %s terminates early"
+msgstr "Commit-Graph Vorgänger-Liste für Commit %s endet zu früh"
+
+#: commit-graph.c:2064
+#, c-format
+msgid ""
+"commit-graph has generation number zero for commit %s, but non-zero elsewhere"
+msgstr ""
+"Commit-Graph hat Generationsnummer null für Commit %s, aber sonst ungleich "
+"null"
+
+#: commit-graph.c:2068
+#, c-format
+msgid ""
+"commit-graph has non-zero generation number for commit %s, but zero elsewhere"
+msgstr ""
+"Commit-Graph hat Generationsnummer ungleich null für Commit %s, aber sonst "
+"null"
+
+#: commit-graph.c:2083
+#, c-format
+msgid "commit-graph generation for commit %s is %u != %u"
+msgstr "Commit-Graph Erstellung für Commit %s ist %u != %u"
+
+#: commit-graph.c:2089
+#, c-format
+msgid "commit date for commit %s in commit-graph is %<PRIuMAX> != %<PRIuMAX>"
+msgstr ""
+"Commit-Datum für Commit %s in Commit-Graph ist %<PRIuMAX> != %<PRIuMAX>"
+
+#: compat/obstack.c:406 compat/obstack.c:408
 msgid "memory exhausted"
 msgstr "Speicher verbraucht"
 
-#: config.c:186
+#: config.c:124
+#, c-format
+msgid ""
+"exceeded maximum include depth (%d) while including\n"
+"\t%s\n"
+"from\n"
+"\t%s\n"
+"This might be due to circular includes."
+msgstr ""
+"Maximale Include-Tiefe (%d) beim Einbinden von\n"
+"\t%s\n"
+"von\n"
+"\t%s\n"
+"überschritten.\n"
+"Das könnte durch zirkulare Includes entstanden sein."
+
+#: config.c:140
+#, c-format
+msgid "could not expand include path '%s'"
+msgstr "Konnte Include-Pfad '%s' nicht erweitern."
+
+#: config.c:151
+msgid "relative config includes must come from files"
+msgstr "Relative Includes von Konfigurationen müssen aus Dateien kommen."
+
+#: config.c:197
 msgid "relative config include conditionals must come from files"
 msgstr ""
 "Bedingungen für das Einbinden von Konfigurationen aus relativen Pfaden "
 "müssen\n"
 "aus Dateien kommen."
 
-#: config.c:720
+#: config.c:376
+#, c-format
+msgid "key does not contain a section: %s"
+msgstr "Schlüssel enthält keine Sektion: %s"
+
+#: config.c:382
+#, c-format
+msgid "key does not contain variable name: %s"
+msgstr "Schlüssel enthält keinen Variablennamen: %s"
+
+#: config.c:406 sequencer.c:2530
+#, c-format
+msgid "invalid key: %s"
+msgstr "Ungültiger Schlüssel: %s"
+
+#: config.c:412
+#, c-format
+msgid "invalid key (newline): %s"
+msgstr "Ungültiger Schlüssel (neue Zeile): %s"
+
+#: config.c:448 config.c:460
+#, c-format
+msgid "bogus config parameter: %s"
+msgstr "Fehlerhafter Konfigurationsparameter: %s"
+
+#: config.c:495
+#, c-format
+msgid "bogus format in %s"
+msgstr "Fehlerhaftes Format in %s"
+
+#: config.c:821
 #, c-format
 msgid "bad config line %d in blob %s"
 msgstr "Ungültige Konfigurationszeile %d in Blob %s"
 
-#: config.c:724
+#: config.c:825
 #, c-format
 msgid "bad config line %d in file %s"
 msgstr "Ungültige Konfigurationszeile %d in Datei %s"
 
-#: config.c:728
+#: config.c:829
 #, c-format
 msgid "bad config line %d in standard input"
 msgstr "Ungültige Konfigurationszeile %d in Standard-Eingabe"
 
-#: config.c:732
+#: config.c:833
 #, c-format
 msgid "bad config line %d in submodule-blob %s"
 msgstr "Ungültige Konfigurationszeile %d in Submodul-Blob %s"
 
-#: config.c:736
+#: config.c:837
 #, c-format
 msgid "bad config line %d in command line %s"
 msgstr "Ungültige Konfigurationszeile %d in Kommandozeile %s"
 
-#: config.c:740
+#: config.c:841
 #, c-format
 msgid "bad config line %d in %s"
 msgstr "Ungültige Konfigurationszeile %d in %s"
 
-#: config.c:868
+#: config.c:978
 msgid "out of range"
 msgstr "Außerhalb des Bereichs"
 
-#: config.c:868
+#: config.c:978
 msgid "invalid unit"
 msgstr "Ungültige Einheit"
 
-#: config.c:874
+#: config.c:979
 #, c-format
 msgid "bad numeric config value '%s' for '%s': %s"
 msgstr "Ungültiger numerischer Wert '%s' für Konfiguration '%s': %s"
 
-#: config.c:879
+#: config.c:998
 #, c-format
 msgid "bad numeric config value '%s' for '%s' in blob %s: %s"
 msgstr "Ungültiger numerischer Wert '%s' für Konfiguration '%s' in Blob %s: %s"
 
-#: config.c:882
+#: config.c:1001
 #, c-format
 msgid "bad numeric config value '%s' for '%s' in file %s: %s"
 msgstr ""
 "Ungültiger numerischer Wert '%s' für Konfiguration '%s' in Datei %s: %s"
 
-#: config.c:885
+#: config.c:1004
 #, c-format
 msgid "bad numeric config value '%s' for '%s' in standard input: %s"
 msgstr ""
 "Ungültiger numerischer Wert '%s' für Konfiguration '%s' in Standard-Eingabe: "
 "%s"
 
-#: config.c:888
+#: config.c:1007
 #, c-format
 msgid "bad numeric config value '%s' for '%s' in submodule-blob %s: %s"
 msgstr ""
 "Ungültiger numerischer Wert '%s' für Konfiguration '%s' in Submodul-Blob %s: "
 "%s"
 
-#: config.c:891
+#: config.c:1010
 #, c-format
 msgid "bad numeric config value '%s' for '%s' in command line %s: %s"
 msgstr ""
 "Ungültiger numerischer Wert '%s' für Konfiguration '%s' in Befehlszeile %s: "
 "%s"
 
-#: config.c:894
+#: config.c:1013
 #, c-format
 msgid "bad numeric config value '%s' for '%s' in %s: %s"
 msgstr "Ungültiger numerischer Wert '%s' für Konfiguration '%s' in %s: %s"
 
-#: config.c:989
+#: config.c:1108
 #, c-format
 msgid "failed to expand user dir in: '%s'"
 msgstr "Fehler beim Erweitern des Nutzerverzeichnisses in: '%s'"
 
-#: config.c:998
+#: config.c:1117
 #, c-format
 msgid "'%s' for '%s' is not a valid timestamp"
 msgstr "'%s' ist kein gültiger Zeitstempel für '%s'"
 
-#: config.c:1094 config.c:1105
+#: config.c:1208
+#, c-format
+msgid "abbrev length out of range: %d"
+msgstr "Länge für Abkürzung von Commit-IDs außerhalb des Bereichs: %d"
+
+#: config.c:1222 config.c:1233
 #, c-format
 msgid "bad zlib compression level %d"
 msgstr "ungültiger zlib Komprimierungsgrad %d"
 
-#: config.c:1225
+#: config.c:1325
+msgid "core.commentChar should only be one character"
+msgstr "core.commentChar sollte nur ein Zeichen sein"
+
+#: config.c:1358
 #, c-format
 msgid "invalid mode for object creation: %s"
 msgstr "Ungültiger Modus für Objekterstellung: %s"
 
-#: config.c:1386
+#: config.c:1430
+#, c-format
+msgid "malformed value for %s"
+msgstr "Ungültiger Wert für %s."
+
+#: config.c:1456
+#, c-format
+msgid "malformed value for %s: %s"
+msgstr "Ungültiger Wert für %s: %s"
+
+#: config.c:1457
+msgid "must be one of nothing, matching, simple, upstream or current"
+msgstr ""
+"Muss einer von diesen sein: nothing, matching, simple, upstream, current"
+
+#: config.c:1518 builtin/pack-objects.c:3394
 #, c-format
 msgid "bad pack compression level %d"
 msgstr "ungültiger Komprimierungsgrad (%d) für Paketierung"
 
-#: config.c:1582
+#: config.c:1639
+#, c-format
+msgid "unable to load config blob object '%s'"
+msgstr "Konnte Blob-Objekt '%s' für Konfiguration nicht laden."
+
+#: config.c:1642
+#, c-format
+msgid "reference '%s' does not point to a blob"
+msgstr "Referenz '%s' zeigt auf keinen Blob."
+
+#: config.c:1659
+#, c-format
+msgid "unable to resolve config blob '%s'"
+msgstr "Konnte Blob '%s' für Konfiguration nicht auflösen."
+
+#: config.c:1689
+#, c-format
+msgid "failed to parse %s"
+msgstr "Fehler beim Parsen von %s."
+
+#: config.c:1745
 msgid "unable to parse command-line config"
 msgstr ""
 "Konnte die über die Befehlszeile angegebene Konfiguration nicht parsen."
 
-#: config.c:1914
+#: config.c:2096
 msgid "unknown error occurred while reading the configuration files"
 msgstr ""
 "Es trat ein unbekannter Fehler beim Lesen der Konfigurationsdateien auf."
 
-#: config.c:2101
+#: config.c:2266
 #, c-format
 msgid "Invalid %s: '%s'"
 msgstr "Ungültiger %s: '%s'"
 
-#: config.c:2144
-#, c-format
-msgid "unknown core.untrackedCache value '%s'; using 'keep' default value"
-msgstr ""
-"Unbekannter Wert '%s' in core.untrackedCache; benutze Standardwert 'keep'"
-
-#: config.c:2170
+#: config.c:2311
 #, c-format
 msgid "splitIndex.maxPercentChange value '%d' should be between 0 and 100"
 msgstr ""
 "Der Wert '%d' von splitIndex.maxPercentChange sollte zwischen 0 und 100 "
 "liegen."
 
-#: config.c:2195
+#: config.c:2357
 #, c-format
 msgid "unable to parse '%s' from command-line config"
 msgstr ""
 "Konnte Wert '%s' aus der über die Befehlszeile angegebenen Konfiguration\n"
 "nicht parsen."
 
-#: config.c:2197
+#: config.c:2359
 #, c-format
 msgid "bad config variable '%s' in file '%s' at line %d"
 msgstr "ungültige Konfigurationsvariable '%s' in Datei '%s' bei Zeile %d"
 
-#: config.c:2256
+#: config.c:2440
+#, c-format
+msgid "invalid section name '%s'"
+msgstr "Ungültiger Sektionsname '%s'"
+
+#: config.c:2472
 #, c-format
 msgid "%s has multiple values"
 msgstr "%s hat mehrere Werte"
 
-#: config.c:2599 config.c:2816
+#: config.c:2501
+#, c-format
+msgid "failed to write new configuration file %s"
+msgstr "Konnte neue Konfigurationsdatei '%s' nicht schreiben."
+
+#: config.c:2753 config.c:3077
+#, c-format
+msgid "could not lock config file %s"
+msgstr "Konnte Konfigurationsdatei '%s' nicht sperren."
+
+#: config.c:2764
+#, c-format
+msgid "opening %s"
+msgstr "Öffne %s"
+
+#: config.c:2799 builtin/config.c:328
+#, c-format
+msgid "invalid pattern: %s"
+msgstr "Ungültiges Muster: %s"
+
+#: config.c:2824
+#, c-format
+msgid "invalid config file %s"
+msgstr "Ungültige Konfigurationsdatei %s"
+
+#: config.c:2837 config.c:3090
 #, c-format
 msgid "fstat on %s failed"
 msgstr "fstat auf %s fehlgeschlagen"
 
-#: config.c:2706
+#: config.c:2848
+#, c-format
+msgid "unable to mmap '%s'"
+msgstr "mmap für '%s' fehlgeschlagen"
+
+#: config.c:2857 config.c:3095
+#, c-format
+msgid "chmod on %s failed"
+msgstr "chmod auf %s fehlgeschlagen"
+
+#: config.c:2942 config.c:3192
+#, c-format
+msgid "could not write config file %s"
+msgstr "Konnte Konfigurationsdatei %s nicht schreiben."
+
+#: config.c:2976
 #, c-format
 msgid "could not set '%s' to '%s'"
 msgstr "Konnte '%s' nicht zu '%s' setzen."
 
-#: config.c:2708 builtin/remote.c:776
+#: config.c:2978 builtin/remote.c:781
 #, c-format
 msgid "could not unset '%s'"
 msgstr "Konnte '%s' nicht aufheben."
 
-#: connect.c:52
-msgid "The remote end hung up upon initial contact"
+#: config.c:3068
+#, c-format
+msgid "invalid section name: %s"
+msgstr "Ungültiger Sektionsname: %s"
+
+#: config.c:3235
+#, c-format
+msgid "missing value for '%s'"
+msgstr "Fehlender Wert für '%s'"
+
+#: connect.c:61
+msgid "the remote end hung up upon initial contact"
 msgstr "Die Gegenseite hat nach dem ersten Kontakt abgebrochen."
 
-#: connect.c:54
+#: connect.c:63
 msgid ""
 "Could not read from remote repository.\n"
 "\n"
@@ -1485,99 +2466,344 @@ msgstr ""
 "bestehen\n"
 "und das Repository existiert."
 
-#: connected.c:66 builtin/fsck.c:198 builtin/prune.c:144
-msgid "Checking connectivity"
-msgstr "Prüfe Konnektivität"
-
-#: connected.c:78
-msgid "Could not run 'git rev-list'"
-msgstr "Konnte 'git rev-list' nicht ausführen"
+#: connect.c:81
+#, c-format
+msgid "server doesn't support '%s'"
+msgstr "Der Server unterstützt kein '%s'."
 
-#: connected.c:98
-msgid "failed write to rev-list"
-msgstr "Fehler beim Schreiben nach rev-list"
+#: connect.c:103
+#, c-format
+msgid "server doesn't support feature '%s'"
+msgstr "Der Server unterstützt das Feature '%s' nicht."
 
-#: connected.c:105
-msgid "failed to close rev-list's stdin"
-msgstr "Fehler beim Schließen von rev-list's Standard-Eingabe"
+#: connect.c:114
+msgid "expected flush after capabilities"
+msgstr "Erwartete Flush nach Fähigkeiten."
 
-#: convert.c:205
+#: connect.c:233
 #, c-format
-msgid "CRLF would be replaced by LF in %s."
-msgstr "CRLF würde in %s durch LF ersetzt werden."
+msgid "ignoring capabilities after first line '%s'"
+msgstr "Ignoriere Fähigkeiten nach der ersten Zeile '%s'."
 
-#: convert.c:207
+#: connect.c:252
+msgid "protocol error: unexpected capabilities^{}"
+msgstr "Protokollfehler: unerwartetes capabilities^{}"
+
+#: connect.c:273
 #, c-format
-msgid ""
-"CRLF will be replaced by LF in %s.\n"
-"The file will have its original line endings in your working directory."
+msgid "protocol error: expected shallow sha-1, got '%s'"
+msgstr "Protokollfehler: shallow SHA-1 erwartet, '%s' bekommen"
+
+#: connect.c:275
+msgid "repository on the other end cannot be shallow"
 msgstr ""
-"CRLF wird in %s durch LF ersetzt.\n"
-"Die Datei wird ihre ursprünglichen Zeilenenden im Arbeitsverzeichnis "
+"Repository auf der Gegenseite kann keine unvollständige Historie (shallow) "
+"enthalten"
+
+#: connect.c:313
+msgid "invalid packet"
+msgstr "Ungültiges Paket."
+
+#: connect.c:333
+#, c-format
+msgid "protocol error: unexpected '%s'"
+msgstr "Protokollfehler: unerwartetes '%s'"
+
+#: connect.c:441
+#, c-format
+msgid "invalid ls-refs response: %s"
+msgstr "Ungültige ls-refs Antwort: %s"
+
+#: connect.c:445
+msgid "expected flush after ref listing"
+msgstr "Erwartete Flush nach Auflistung der Referenzen."
+
+#: connect.c:544
+#, c-format
+msgid "protocol '%s' is not supported"
+msgstr "Protokoll '%s' wird nicht unterstützt."
+
+#: connect.c:595
+msgid "unable to set SO_KEEPALIVE on socket"
+msgstr "Kann SO_KEEPALIVE bei Socket nicht setzen."
+
+#: connect.c:635 connect.c:698
+#, c-format
+msgid "Looking up %s ... "
+msgstr "Suche nach %s ..."
+
+#: connect.c:639
+#, c-format
+msgid "unable to look up %s (port %s) (%s)"
+msgstr "Fehler bei Suche nach %s (Port %s) (%s)."
+
+#. TRANSLATORS: this is the end of "Looking up %s ... "
+#: connect.c:643 connect.c:714
+#, c-format
+msgid ""
+"done.\n"
+"Connecting to %s (port %s) ... "
+msgstr ""
+"Fertig.\n"
+"Verbinde nach %s (Port %s) ... "
+
+#: connect.c:665 connect.c:742
+#, c-format
+msgid ""
+"unable to connect to %s:\n"
+"%s"
+msgstr ""
+"Konnte nicht nach %s verbinden:\n"
+"%s"
+
+#. TRANSLATORS: this is the end of "Connecting to %s (port %s) ... "
+#: connect.c:671 connect.c:748
+msgid "done."
+msgstr "Fertig."
+
+#: connect.c:702
+#, c-format
+msgid "unable to look up %s (%s)"
+msgstr "Fehler bei der Suche nach %s (%s)"
+
+#: connect.c:708
+#, c-format
+msgid "unknown port %s"
+msgstr "Unbekannter Port %s"
+
+#: connect.c:845 connect.c:1175
+#, c-format
+msgid "strange hostname '%s' blocked"
+msgstr "Merkwürdigen Hostnamen '%s' blockiert."
+
+#: connect.c:847
+#, c-format
+msgid "strange port '%s' blocked"
+msgstr "Merkwürdigen Port '%s' blockiert."
+
+#: connect.c:857
+#, c-format
+msgid "cannot start proxy %s"
+msgstr "Kann Proxy %s nicht starten."
+
+#: connect.c:928
+msgid "no path specified; see 'git help pull' for valid url syntax"
+msgstr ""
+"Kein Pfad angegeben; siehe 'git help pull' für eine gültige URL-Syntax."
+
+#: connect.c:1123
+msgid "ssh variant 'simple' does not support -4"
+msgstr "SSH-Variante 'simple' unterstützt kein -4."
+
+#: connect.c:1135
+msgid "ssh variant 'simple' does not support -6"
+msgstr "SSH-Variante 'simple' unterstützt kein -6."
+
+#: connect.c:1152
+msgid "ssh variant 'simple' does not support setting port"
+msgstr "SSH-Variante 'simple' unterstützt nicht das Setzen eines Ports."
+
+#: connect.c:1264
+#, c-format
+msgid "strange pathname '%s' blocked"
+msgstr "Merkwürdigen Pfadnamen '%s' blockiert."
+
+#: connect.c:1311
+msgid "unable to fork"
+msgstr "Kann Prozess nicht starten."
+
+#: connected.c:89 builtin/fsck.c:208 builtin/prune.c:43
+msgid "Checking connectivity"
+msgstr "Prüfe Konnektivität"
+
+#: connected.c:101
+msgid "Could not run 'git rev-list'"
+msgstr "Konnte 'git rev-list' nicht ausführen"
+
+#: connected.c:121
+msgid "failed write to rev-list"
+msgstr "Fehler beim Schreiben nach rev-list"
+
+#: connected.c:128
+msgid "failed to close rev-list's stdin"
+msgstr "Fehler beim Schließen von rev-list's Standard-Eingabe"
+
+#: convert.c:194
+#, c-format
+msgid "illegal crlf_action %d"
+msgstr "Unerlaubte crlf_action %d"
+
+#: convert.c:207
+#, c-format
+msgid "CRLF would be replaced by LF in %s"
+msgstr "CRLF würde in %s durch LF ersetzt werden."
+
+#: convert.c:209
+#, c-format
+msgid ""
+"CRLF will be replaced by LF in %s.\n"
+"The file will have its original line endings in your working directory"
+msgstr ""
+"CRLF wird in %s durch LF ersetzt.\n"
+"Die Datei wird ihre ursprünglichen Zeilenenden im Arbeitsverzeichnis "
 "behalten."
 
-#: convert.c:215
+#: convert.c:217
 #, c-format
 msgid "LF would be replaced by CRLF in %s"
 msgstr "LF würde in %s durch CRLF ersetzt werden."
 
-#: convert.c:217
+#: convert.c:219
 #, c-format
 msgid ""
 "LF will be replaced by CRLF in %s.\n"
-"The file will have its original line endings in your working directory."
+"The file will have its original line endings in your working directory"
 msgstr ""
 "LF wird in %s durch CRLF ersetzt.\n"
 "Die Datei wird ihre ursprünglichen Zeilenenden im Arbeitsverzeichnis "
 "behalten."
 
-#: date.c:116
+#: convert.c:284
+#, c-format
+msgid "BOM is prohibited in '%s' if encoded as %s"
+msgstr "BOM ist in '%s' unzulässig, wenn als %s codiert."
+
+#: convert.c:291
+#, c-format
+msgid ""
+"The file '%s' contains a byte order mark (BOM). Please use UTF-%.*s as "
+"working-tree-encoding."
+msgstr ""
+"Die Datei '%s' enthält ein Byte-Order-Mark (BOM). Bitte benutzen Sie\n"
+"UTF-%.*s als Codierung im Arbeitsverzeichnis."
+
+#: convert.c:304
+#, c-format
+msgid "BOM is required in '%s' if encoded as %s"
+msgstr "BOM ist erforderlich in '%s', wenn als %s codiert."
+
+#: convert.c:306
+#, c-format
+msgid ""
+"The file '%s' is missing a byte order mark (BOM). Please use UTF-%sBE or UTF-"
+"%sLE (depending on the byte order) as working-tree-encoding."
+msgstr ""
+"Der Datei '%s' fehlt ein Byte-Order-Mark (BOM). Bitte benutzen Sie UTF-%sBE\n"
+"oder UTF-%sLE (abhängig von der Byte-Reihenfolge) als Codierung im\n"
+"Arbeitsverzeichnis."
+
+#: convert.c:419 convert.c:490
+#, c-format
+msgid "failed to encode '%s' from %s to %s"
+msgstr "Fehler beim Codieren von '%s' von %s nach %s."
+
+#: convert.c:462
+#, c-format
+msgid "encoding '%s' from %s to %s and back is not the same"
+msgstr "Die Codierung '%s' von %s nach %s und zurück ist nicht dasselbe."
+
+#: convert.c:668
+#, c-format
+msgid "cannot fork to run external filter '%s'"
+msgstr "Kann externen Filter '%s' nicht starten."
+
+#: convert.c:688
+#, c-format
+msgid "cannot feed the input to external filter '%s'"
+msgstr "Kann Eingaben nicht an externen Filter '%s' übergeben."
+
+#: convert.c:695
+#, c-format
+msgid "external filter '%s' failed %d"
+msgstr "Externer Filter '%s' fehlgeschlagen %d"
+
+#: convert.c:730 convert.c:733
+#, c-format
+msgid "read from external filter '%s' failed"
+msgstr "Lesen von externem Filter '%s' fehlgeschlagen."
+
+#: convert.c:736 convert.c:791
+#, c-format
+msgid "external filter '%s' failed"
+msgstr "Externer Filter '%s' fehlgeschlagen."
+
+#: convert.c:839
+msgid "unexpected filter type"
+msgstr "Unerwartete Filterart."
+
+#: convert.c:850
+msgid "path name too long for external filter"
+msgstr "Pfadname zu lang für externen Filter."
+
+#: convert.c:924
+#, c-format
+msgid ""
+"external filter '%s' is not available anymore although not all paths have "
+"been filtered"
+msgstr ""
+"Externer Filter '%s' nicht mehr verfügbar. Nicht alle Pfade wurden gefiltert."
+
+#: convert.c:1223
+msgid "true/false are no valid working-tree-encodings"
+msgstr "true/false sind keine gültigen Codierungen im Arbeitsverzeichnis."
+
+#: convert.c:1411 convert.c:1445
+#, c-format
+msgid "%s: clean filter '%s' failed"
+msgstr "%s: clean-Filter '%s' fehlgeschlagen."
+
+#: convert.c:1489
+#, c-format
+msgid "%s: smudge filter %s failed"
+msgstr "%s: smudge-Filter '%s' fehlgeschlagen."
+
+#: date.c:138
 msgid "in the future"
 msgstr "in der Zukunft"
 
-#: date.c:122
+#: date.c:144
 #, c-format
 msgid "%<PRIuMAX> second ago"
 msgid_plural "%<PRIuMAX> seconds ago"
 msgstr[0] "vor %<PRIuMAX> Sekunde"
 msgstr[1] "vor %<PRIuMAX> Sekunden"
 
-#: date.c:129
+#: date.c:151
 #, c-format
 msgid "%<PRIuMAX> minute ago"
 msgid_plural "%<PRIuMAX> minutes ago"
 msgstr[0] "vor %<PRIuMAX> Minute"
 msgstr[1] "vor %<PRIuMAX> Minuten"
 
-#: date.c:136
+#: date.c:158
 #, c-format
 msgid "%<PRIuMAX> hour ago"
 msgid_plural "%<PRIuMAX> hours ago"
 msgstr[0] "vor %<PRIuMAX> Stunde"
 msgstr[1] "vor %<PRIuMAX> Stunden"
 
-#: date.c:143
+#: date.c:165
 #, c-format
 msgid "%<PRIuMAX> day ago"
 msgid_plural "%<PRIuMAX> days ago"
 msgstr[0] "vor %<PRIuMAX> Tag"
 msgstr[1] "vor %<PRIuMAX> Tagen"
 
-#: date.c:149
+#: date.c:171
 #, c-format
 msgid "%<PRIuMAX> week ago"
 msgid_plural "%<PRIuMAX> weeks ago"
 msgstr[0] "vor %<PRIuMAX> Woche"
 msgstr[1] "vor %<PRIuMAX> Wochen"
 
-#: date.c:156
+#: date.c:178
 #, c-format
 msgid "%<PRIuMAX> month ago"
 msgid_plural "%<PRIuMAX> months ago"
 msgstr[0] "vor %<PRIuMAX> Monat"
 msgstr[1] "vor %<PRIuMAX> Monaten"
 
-#: date.c:167
+#: date.c:189
 #, c-format
 msgid "%<PRIuMAX> year"
 msgid_plural "%<PRIuMAX> years"
@@ -1585,59 +2811,110 @@ msgstr[0] "vor %<PRIuMAX> Jahr"
 msgstr[1] "vor %<PRIuMAX> Jahren"
 
 #. TRANSLATORS: "%s" is "<n> years"
-#: date.c:170
+#: date.c:192
 #, c-format
 msgid "%s, %<PRIuMAX> month ago"
 msgid_plural "%s, %<PRIuMAX> months ago"
 msgstr[0] "%s, und %<PRIuMAX> Monat"
 msgstr[1] "%s, und %<PRIuMAX> Monaten"
 
-#: date.c:175 date.c:180
+#: date.c:197 date.c:202
 #, c-format
 msgid "%<PRIuMAX> year ago"
 msgid_plural "%<PRIuMAX> years ago"
 msgstr[0] "vor %<PRIuMAX> Jahr"
 msgstr[1] "vor %<PRIuMAX> Jahren"
 
+#: delta-islands.c:272
+msgid "Propagating island marks"
+msgstr "Erzeuge Delta-Island Markierungen"
+
+#: delta-islands.c:290
+#, c-format
+msgid "bad tree object %s"
+msgstr "Ungültiges Tree-Objekt %s."
+
+#: delta-islands.c:334
+#, c-format
+msgid "failed to load island regex for '%s': %s"
+msgstr ""
+"Fehler beim Laden des regulären Ausdrucks des Delta-Island für '%s': %s"
+
+#: delta-islands.c:390
+#, c-format
+msgid "island regex from config has too many capture groups (max=%d)"
+msgstr ""
+"Regulärer Ausdruck des Delta-Island aus Konfiguration hat zu\n"
+"viele Capture-Gruppen (maximal %d)."
+
+#: delta-islands.c:467
+#, c-format
+msgid "Marked %d islands, done.\n"
+msgstr "%d Delta-Islands markiert, fertig.\n"
+
 #: diffcore-order.c:24
 #, c-format
 msgid "failed to read orderfile '%s'"
 msgstr "Fehler beim Lesen der Reihenfolgedatei '%s'."
 
-#: diffcore-rename.c:535
+#: diffcore-rename.c:543
 msgid "Performing inexact rename detection"
 msgstr "Führe Erkennung für ungenaue Umbenennung aus"
 
-#: diff.c:74
-#, c-format
-msgid "option '%s' requires a value"
-msgstr "Option '%s' erfordert einen Wert."
+#: diff-no-index.c:238
+msgid "git diff --no-index [<options>] <path> <path>"
+msgstr "git diff --no-index [<Optionen>] <Pfad> <Pfad>"
+
+#: diff-no-index.c:263
+msgid ""
+"Not a git repository. Use --no-index to compare two paths outside a working "
+"tree"
+msgstr ""
+"Kein Git-Repository. Nutzen Sie --no-index, um zwei Pfade außerhalb des "
+"Arbeitsverzeichnisses zu vergleichen."
 
-#: diff.c:152
+#: diff.c:155
 #, c-format
 msgid "  Failed to parse dirstat cut-off percentage '%s'\n"
 msgstr ""
 "  Fehler beim Parsen des abgeschnittenen \"dirstat\" Prozentsatzes '%s'\n"
 
-#: diff.c:157
+#: diff.c:160
 #, c-format
 msgid "  Unknown dirstat parameter '%s'\n"
 msgstr "  Unbekannter \"dirstat\" Parameter '%s'\n"
 
-#: diff.c:281
+#: diff.c:296
 msgid ""
-"color moved setting must be one of 'no', 'default', 'zebra', 'dimmed_zebra', "
-"'plain'"
+"color moved setting must be one of 'no', 'default', 'blocks', 'zebra', "
+"'dimmed-zebra', 'plain'"
 msgstr ""
 "\"color moved\"-Einstellung muss eines von diesen sein: 'no', 'default', "
-"'zebra', 'dimmed_zebra', 'plain'"
+"'blocks', 'zebra', 'dimmed_zebra', 'plain'"
+
+#: diff.c:324
+#, c-format
+msgid ""
+"unknown color-moved-ws mode '%s', possible values are 'ignore-space-change', "
+"'ignore-space-at-eol', 'ignore-all-space', 'allow-indentation-change'"
+msgstr ""
+"Unbekannter color-moved-ws Modus '%s', mögliche Werte sind 'ignore-space-"
+"change', 'ignore-space-at-eol', 'ignore-all-space', 'allow-identation-change'"
+
+#: diff.c:332
+msgid ""
+"color-moved-ws: allow-indentation-change cannot be combined with other "
+"whitespace modes"
+msgstr ""
+"color-moved-ws: allow-indentation-change kann nicht mit anderen\n"
+"Whitespace-Modi kombiniert werden."
 
-#: diff.c:341
+#: diff.c:405
 #, c-format
 msgid "Unknown value for 'diff.submodule' config variable: '%s'"
 msgstr "Unbekannter Wert in Konfigurationsvariable 'diff.dirstat': '%s'"
 
-#: diff.c:401
+#: diff.c:465
 #, c-format
 msgid ""
 "Found errors in 'diff.dirstat' config variable:\n"
@@ -1646,25 +2923,36 @@ msgstr ""
 "Fehler in 'diff.dirstat' Konfigurationsvariable gefunden:\n"
 "%s"
 
-#: diff.c:3822
+#: diff.c:4202
 #, c-format
 msgid "external diff died, stopping at %s"
 msgstr "externes Diff-Programm unerwartet beendet, angehalten bei %s"
 
-#: diff.c:4146
+#: diff.c:4547
 msgid "--name-only, --name-status, --check and -s are mutually exclusive"
 msgstr ""
 "--name-only, --name-status, --check und -s schließen sich gegenseitig aus"
 
-#: diff.c:4149
+#: diff.c:4550
 msgid "-G, -S and --find-object are mutually exclusive"
 msgstr "-G, -S und --find-object schließen sich gegenseitig aus"
 
-#: diff.c:4237
+#: diff.c:4628
 msgid "--follow requires exactly one pathspec"
 msgstr "--follow erfordert genau eine Pfadspezifikation"
 
-#: diff.c:4403
+#: diff.c:4676
+#, c-format
+msgid "invalid --stat value: %s"
+msgstr "Ungültiger --stat Wert: %s"
+
+#: diff.c:4681 diff.c:4686 diff.c:4691 diff.c:4696 diff.c:5209
+#: parse-options.c:199 parse-options.c:203
+#, c-format
+msgid "%s expects a numerical value"
+msgstr "%s erwartet einen numerischen Wert."
+
+#: diff.c:4713
 #, c-format
 msgid ""
 "Failed to parse --dirstat/-X option parameter:\n"
@@ -1673,10877 +2961,15742 @@ msgstr ""
 "Fehler beim Parsen des --dirstat/-X Optionsparameters:\n"
 "%s"
 
-#: diff.c:4417
+#: diff.c:4798
 #, c-format
-msgid "Failed to parse --submodule option parameter: '%s'"
-msgstr "Fehler beim Parsen des --submodule Optionsparameters: '%s'"
+msgid "unknown change class '%c' in --diff-filter=%s"
+msgstr "Unbekannte Änderungsklasse '%c' in --diff-filter=%s"
 
-#: diff.c:5493
-msgid "inexact rename detection was skipped due to too many files."
-msgstr ""
-"Ungenaue Erkennung für Umbenennungen wurde aufgrund zu vieler Dateien\n"
-"übersprungen."
+#: diff.c:4822
+#, c-format
+msgid "unknown value after ws-error-highlight=%.*s"
+msgstr "Unbekannter Wert nach ws-error-highlight=%.*s"
 
-#: diff.c:5496
-msgid "only found copies from modified paths due to too many files."
-msgstr "nur Kopien von geänderten Pfaden, aufgrund zu vieler Dateien, gefunden"
+#: diff.c:4836
+#, c-format
+msgid "unable to resolve '%s'"
+msgstr "konnte '%s' nicht auflösen"
 
-#: diff.c:5499
+#: diff.c:4886 diff.c:4892
 #, c-format
-msgid ""
-"you may want to set your %s variable to at least %d and retry the command."
-msgstr ""
-"Sie könnten die Variable %s auf mindestens %d setzen und den Befehl\n"
-"erneut versuchen."
+msgid "%s expects <n>/<m> form"
+msgstr "%s erwartet die Form <n>/<m>"
 
-#: dir.c:1866
+#: diff.c:4904
 #, c-format
-msgid "could not open directory '%s'"
-msgstr "Konnte Verzeichnis '%s' nicht öffnen."
+msgid "%s expects a character, got '%s'"
+msgstr "%s erwartet ein Zeichen, '%s' bekommen"
 
-#: dir.c:2108
-msgid "failed to get kernel name and information"
-msgstr "Fehler beim Sammeln von Namen und Informationen zum Kernel"
+#: diff.c:4925
+#, c-format
+msgid "bad --color-moved argument: %s"
+msgstr "Ungültiges --color-moved Argument: %s"
+
+#: diff.c:4944
+#, c-format
+msgid "invalid mode '%s' in --color-moved-ws"
+msgstr "Ungültiger Modus '%s' in --color-moved-ws"
 
-#: dir.c:2232
-msgid "Untracked cache is disabled on this system or location."
+#: diff.c:4984
+msgid ""
+"option diff-algorithm accepts \"myers\", \"minimal\", \"patience\" and "
+"\"histogram\""
 msgstr ""
-"Cache für unversionierte Dateien ist auf diesem System oder\n"
-"für dieses Verzeichnis deaktiviert."
+"Option diff-algorithm akzeptiert: \"myers\", \"minimal\", \"patience\" and "
+"\"histogram\""
 
-#: dir.c:3024 dir.c:3029
+#: diff.c:5020 diff.c:5040
 #, c-format
-msgid "could not create directories for %s"
-msgstr "Konnte Verzeichnisse für '%s' nicht erstellen."
+msgid "invalid argument to %s"
+msgstr "Ungültiges Argument für %s"
 
-#: dir.c:3054
+#: diff.c:5178
 #, c-format
-msgid "could not migrate git directory from '%s' to '%s'"
-msgstr "Konnte Git-Verzeichnis nicht von '%s' nach '%s' migrieren."
+msgid "failed to parse --submodule option parameter: '%s'"
+msgstr "Fehler beim Parsen des --submodule Optionsparameters: '%s'"
 
-#: editor.c:61
+#: diff.c:5234
 #, c-format
-msgid "hint: Waiting for your editor to close the file...%c"
-msgstr "Hinweis: Warte auf das Schließen der Datei durch Ihren Editor...%c"
+msgid "bad --word-diff argument: %s"
+msgstr "Ungültiges --word-diff Argument: %s"
 
-#: entry.c:177
-msgid "Filtering content"
-msgstr "Filtere Inhalt"
+#: diff.c:5257
+msgid "Diff output format options"
+msgstr "Diff-Optionen zu Ausgabeformaten"
 
-#: entry.c:435
-#, c-format
-msgid "could not stat file '%s'"
-msgstr "Konnte Datei '%s' nicht lesen."
+#: diff.c:5259 diff.c:5265
+msgid "generate patch"
+msgstr "Erzeuge Patch"
 
-#: fetch-object.c:17
-msgid "Remote with no URL"
-msgstr "Remote-Repository ohne URL"
+#: diff.c:5262 builtin/log.c:173
+msgid "suppress diff output"
+msgstr "Ausgabe der Unterschiede unterdrücken"
 
-#: fetch-pack.c:253
-msgid "git fetch-pack: expected shallow list"
-msgstr "git fetch-pack: erwartete shallow-Liste"
+#: diff.c:5267 diff.c:5381 diff.c:5388
+msgid "<n>"
+msgstr "<n>"
 
-#: fetch-pack.c:265
-msgid "git fetch-pack: expected ACK/NAK, got a flush packet"
-msgstr "git fetch-pack: ACK/NAK erwartet, Flush-Paket bekommen"
+#: diff.c:5268 diff.c:5271
+msgid "generate diffs with <n> lines context"
+msgstr "Erstelle Unterschiede mit <n> Zeilen des Kontextes"
 
-#: fetch-pack.c:284 builtin/archive.c:63
-#, c-format
-msgid "remote error: %s"
-msgstr "Fehler am anderen Ende: %s"
+#: diff.c:5273
+msgid "generate the diff in raw format"
+msgstr "Erstelle Unterschiede im Rohformat"
 
-#: fetch-pack.c:285
-#, c-format
-msgid "git fetch-pack: expected ACK/NAK, got '%s'"
-msgstr "git fetch-pack: ACK/NAK erwartet, '%s' bekommen"
+#: diff.c:5276
+msgid "synonym for '-p --raw'"
+msgstr "Synonym für '-p --raw'"
 
-#: fetch-pack.c:337
-msgid "--stateless-rpc requires multi_ack_detailed"
-msgstr "--stateless-rpc benötigt multi_ack_detailed"
+#: diff.c:5280
+msgid "synonym for '-p --stat'"
+msgstr "Synonym für '-p --stat'"
 
-#: fetch-pack.c:428
-#, c-format
-msgid "invalid shallow line: %s"
-msgstr "Ungültige shallow-Zeile: %s"
+#: diff.c:5284
+msgid "machine friendly --stat"
+msgstr "maschinenlesbare Ausgabe von --stat"
 
-#: fetch-pack.c:434
-#, c-format
-msgid "invalid unshallow line: %s"
-msgstr "Ungültige unshallow-Zeile: %s"
+#: diff.c:5287
+msgid "output only the last line of --stat"
+msgstr "nur die letzte Zeile von --stat ausgeben"
 
-#: fetch-pack.c:436
-#, c-format
-msgid "object not found: %s"
-msgstr "Objekt nicht gefunden: %s"
+#: diff.c:5289 diff.c:5297
+msgid "<param1,param2>..."
+msgstr "<Parameter1,Parameter2>..."
 
-#: fetch-pack.c:439
-#, c-format
-msgid "error in object: %s"
-msgstr "Fehler in Objekt: %s"
+#: diff.c:5290
+msgid ""
+"output the distribution of relative amount of changes for each sub-directory"
+msgstr ""
+"Gebe die Verteilung des relativen Umfangs der Änderungen für jedes "
+"Unterverzeichnis aus"
 
-#: fetch-pack.c:441
-#, c-format
-msgid "no shallow found: %s"
-msgstr "Kein shallow-Objekt gefunden: %s"
+#: diff.c:5294
+msgid "synonym for --dirstat=cumulative"
+msgstr "Synonym für --dirstat=cumulative"
 
-#: fetch-pack.c:444
-#, c-format
-msgid "expected shallow/unshallow, got %s"
-msgstr "shallow/unshallow erwartet, %s bekommen"
+#: diff.c:5298
+msgid "synonym for --dirstat=files,param1,param2..."
+msgstr "Synonym für --dirstat=files,Parameter1,Parameter2..."
 
-#: fetch-pack.c:485
-#, c-format
-msgid "got %s %d %s"
-msgstr "%s %d %s bekommen"
+#: diff.c:5302
+msgid "warn if changes introduce conflict markers or whitespace errors"
+msgstr ""
+"Warnen, wenn Änderungen Konfliktmarker oder Whitespace-Fehler einbringen"
 
-#: fetch-pack.c:499
-#, c-format
-msgid "invalid commit %s"
-msgstr "Ungültiger Commit %s"
+#: diff.c:5305
+msgid "condensed summary such as creations, renames and mode changes"
+msgstr ""
+"Gekürzte Zusammenfassung, wie z.B. Erstellungen, Umbenennungen und "
+"Änderungen der Datei-Rechte"
 
-#: fetch-pack.c:532
-msgid "giving up"
-msgstr "Gebe auf"
+#: diff.c:5308
+msgid "show only names of changed files"
+msgstr "nur Dateinamen der geänderten Dateien anzeigen"
 
-#: fetch-pack.c:542 progress.c:229
-msgid "done"
-msgstr "Fertig"
+#: diff.c:5311
+msgid "show only names and status of changed files"
+msgstr "nur Dateinamen und Status der geänderten Dateien anzeigen"
 
-#: fetch-pack.c:554
-#, c-format
-msgid "got %s (%d) %s"
-msgstr "%s (%d) %s bekommen"
+#: diff.c:5313
+msgid "<width>[,<name-width>[,<count>]]"
+msgstr "<Breite>[,<Namens-Breite>[,<Anzahl>]]"
 
-#: fetch-pack.c:600
-#, c-format
-msgid "Marking %s as complete"
-msgstr "Markiere %s als vollständig"
+#: diff.c:5314
+msgid "generate diffstat"
+msgstr "Generiere Zusammenfassung der Unterschiede"
 
-#: fetch-pack.c:788
-#, c-format
-msgid "already have %s (%s)"
-msgstr "habe %s (%s) bereits"
+#: diff.c:5316 diff.c:5319 diff.c:5322
+msgid "<width>"
+msgstr "<Breite>"
 
-#: fetch-pack.c:829
-msgid "fetch-pack: unable to fork off sideband demultiplexer"
-msgstr "fetch-pack: Fehler beim Starten des sideband demultiplexer"
+#: diff.c:5317
+msgid "generate diffstat with a given width"
+msgstr "Erzeuge Zusammenfassung der Unterschiede mit gegebener Breite"
 
-#: fetch-pack.c:837
-msgid "protocol error: bad pack header"
-msgstr "Protokollfehler: ungültiger Pack-Header"
+#: diff.c:5320
+msgid "generate diffstat with a given name width"
+msgstr "Erzeuge Zusammenfassung der Unterschiede mit gegebener Namens-Breite"
 
-#: fetch-pack.c:895
-#, c-format
-msgid "fetch-pack: unable to fork off %s"
-msgstr "fetch-pack: konnte %s nicht starten"
+#: diff.c:5323
+msgid "generate diffstat with a given graph width"
+msgstr "Erzeuge Zusammenfassung der Unterschiede mit gegebener Graph-Breite"
 
-#: fetch-pack.c:911
-#, c-format
-msgid "%s failed"
-msgstr "%s fehlgeschlagen"
+#: diff.c:5325
+msgid "<count>"
+msgstr "<Anzahl>"
 
-#: fetch-pack.c:913
-msgid "error in sideband demultiplexer"
-msgstr "Fehler in sideband demultiplexer"
+#: diff.c:5326
+msgid "generate diffstat with limited lines"
+msgstr "Erzeuge Zusammenfassung der Unterschiede mit begrenzten Zeilen"
 
-#: fetch-pack.c:940
-msgid "Server does not support shallow clients"
-msgstr "Server unterstützt keine shallow-Clients"
+#: diff.c:5329
+msgid "generate compact summary in diffstat"
+msgstr "Erzeuge kompakte Zusammenstellung in Zusammenfassung der Unterschiede"
 
-#: fetch-pack.c:944
-msgid "Server supports multi_ack_detailed"
-msgstr "Server unterstützt multi_ack_detailed"
-
-#: fetch-pack.c:947
-msgid "Server supports no-done"
-msgstr "Server unterstützt no-done"
-
-#: fetch-pack.c:953
-msgid "Server supports multi_ack"
-msgstr "Server unterstützt multi_ack"
-
-#: fetch-pack.c:957
-msgid "Server supports side-band-64k"
-msgstr "Server unterstützt side-band-64k"
-
-#: fetch-pack.c:961
-msgid "Server supports side-band"
-msgstr "Server unterstützt side-band"
+#: diff.c:5332
+msgid "output a binary diff that can be applied"
+msgstr "Gebe eine binäre Differenz aus, dass angewendet werden kann"
 
-#: fetch-pack.c:965
-msgid "Server supports allow-tip-sha1-in-want"
-msgstr "Server unterstützt allow-tip-sha1-in-want"
+#: diff.c:5335
+msgid "show full pre- and post-image object names on the \"index\" lines"
+msgstr "Zeige vollständige Objekt-Namen in den \"index\"-Zeilen"
 
-#: fetch-pack.c:969
-msgid "Server supports allow-reachable-sha1-in-want"
-msgstr "Server unterstützt allow-reachable-sha1-in-want"
-
-#: fetch-pack.c:979
-msgid "Server supports ofs-delta"
-msgstr "Server unterstützt ofs-delta"
+#: diff.c:5337
+msgid "show colored diff"
+msgstr "Zeige farbige Unterschiede"
 
-#: fetch-pack.c:985
-msgid "Server supports filter"
-msgstr "Server unterstützt Filter"
+#: diff.c:5338
+msgid "<kind>"
+msgstr "<Art>"
 
-#: fetch-pack.c:993
-#, c-format
-msgid "Server version is %.*s"
-msgstr "Server-Version ist %.*s"
+#: diff.c:5339
+msgid ""
+"highlight whitespace errors in the 'context', 'old' or 'new' lines in the "
+"diff"
+msgstr ""
+"Hebe Whitespace-Fehler in den Zeilen 'context', 'old' oder 'new' bei den "
+"Unterschieden hervor"
 
-#: fetch-pack.c:999
-msgid "Server does not support --shallow-since"
-msgstr "Server unterstützt kein --shallow-since"
+#: diff.c:5342
+msgid ""
+"do not munge pathnames and use NULs as output field terminators in --raw or "
+"--numstat"
+msgstr ""
+"Verschleiere nicht die Pfadnamen und nutze NUL-Zeichen als Schlusszeichen in "
+"Ausgabefeldern bei --raw oder --numstat"
 
-#: fetch-pack.c:1003
-msgid "Server does not support --shallow-exclude"
-msgstr "Server unterstützt kein --shallow-exclude"
+#: diff.c:5345 diff.c:5348 diff.c:5351 diff.c:5457
+msgid "<prefix>"
+msgstr "<Präfix>"
 
-#: fetch-pack.c:1005
-msgid "Server does not support --deepen"
-msgstr "Server unterstützt kein --deepen"
+#: diff.c:5346
+msgid "show the given source prefix instead of \"a/\""
+msgstr "Zeige den gegebenen Quell-Präfix statt \"a/\""
 
-#: fetch-pack.c:1016
-msgid "no common commits"
-msgstr "keine gemeinsamen Commits"
+#: diff.c:5349
+msgid "show the given destination prefix instead of \"b/\""
+msgstr "Zeige den gegebenen Ziel-Präfix statt \"b/\""
 
-#: fetch-pack.c:1028
-msgid "git fetch-pack: fetch failed."
-msgstr "git fetch-pack: Abholen fehlgeschlagen."
+#: diff.c:5352
+msgid "prepend an additional prefix to every line of output"
+msgstr "Stelle einen zusätzlichen Präfix bei jeder Ausgabezeile voran"
 
-#: fetch-pack.c:1190
-msgid "no matching remote head"
-msgstr "kein übereinstimmender Remote-Branch"
+#: diff.c:5355
+msgid "do not show any source or destination prefix"
+msgstr "Zeige keine Quell- oder Ziel-Präfixe an"
 
-#: fetch-pack.c:1212
-#, c-format
-msgid "no such remote ref %s"
-msgstr "keine solche Remote-Referenz %s"
+#: diff.c:5358
+msgid "show context between diff hunks up to the specified number of lines"
+msgstr ""
+"Zeige Kontext zwischen Unterschied-Blöcken bis zur angegebenen Anzahl von "
+"Zeilen."
 
-#: fetch-pack.c:1215
-#, c-format
-msgid "Server does not allow request for unadvertised object %s"
-msgstr "Der Server lehnt Anfrage nach nicht angebotenem Objekt %s ab."
+#: diff.c:5362 diff.c:5367 diff.c:5372
+msgid "<char>"
+msgstr "<Zeichen>"
 
-#: gpg-interface.c:181
-msgid "gpg failed to sign the data"
-msgstr "gpg beim Signieren der Daten fehlgeschlagen"
+#: diff.c:5363
+msgid "specify the character to indicate a new line instead of '+'"
+msgstr "Das Zeichen festlegen, das eine neue Zeile kennzeichnet (statt '+')"
 
-#: gpg-interface.c:211
-msgid "could not create temporary file"
-msgstr "konnte temporäre Datei nicht erstellen"
+#: diff.c:5368
+msgid "specify the character to indicate an old line instead of '-'"
+msgstr "Das Zeichen festlegen, das eine alte Zeile kennzeichnet (statt '-')"
 
-#: gpg-interface.c:214
-#, c-format
-msgid "failed writing detached signature to '%s'"
-msgstr "Fehler beim Schreiben der losgelösten Signatur nach '%s'"
+#: diff.c:5373
+msgid "specify the character to indicate a context instead of ' '"
+msgstr "Das Zeichen festlegen, das den Kontext kennzeichnet (statt ' ')"
 
-#: graph.c:97
-#, c-format
-msgid "ignore invalid color '%.*s' in log.graphColors"
-msgstr "Ignoriere ungültige Farbe '%.*s' in log.graphColors"
+#: diff.c:5376
+msgid "Diff rename options"
+msgstr "Diff-Optionen zur Umbenennung"
 
-#: grep.c:2022
-#, c-format
-msgid "'%s': unable to read %s"
-msgstr "'%s': konnte %s nicht lesen"
+#: diff.c:5377
+msgid "<n>[/<m>]"
+msgstr "<n>[/<m>]"
 
-#: grep.c:2039 setup.c:163 builtin/clone.c:407 builtin/diff.c:81
-#: builtin/rm.c:134
-#, c-format
-msgid "failed to stat '%s'"
-msgstr "Konnte '%s' nicht lesen"
+#: diff.c:5378
+msgid "break complete rewrite changes into pairs of delete and create"
+msgstr ""
+"Teile komplette Rewrite-Änderungen in Änderungen mit \"löschen\" und "
+"\"erstellen\""
 
-#: grep.c:2050
-#, c-format
-msgid "'%s': short read"
-msgstr "'%s': read() zu kurz"
+#: diff.c:5382
+msgid "detect renames"
+msgstr "Umbenennungen erkennen"
 
-#: help.c:179
-#, c-format
-msgid "available git commands in '%s'"
-msgstr "Vorhandene Git-Befehle in '%s'"
+#: diff.c:5386
+msgid "omit the preimage for deletes"
+msgstr "Preimage für Löschungen weglassen."
 
-#: help.c:186
-msgid "git commands available from elsewhere on your $PATH"
-msgstr "Vorhandene Git-Befehle anderswo in Ihrem $PATH"
+#: diff.c:5389
+msgid "detect copies"
+msgstr "Kopien erkennen"
 
-#: help.c:217
-msgid "These are common Git commands used in various situations:"
-msgstr "Allgemeine Git-Befehle, verwendet in verschiedenen Situationen:"
+#: diff.c:5393
+msgid "use unmodified files as source to find copies"
+msgstr "Nutze ungeänderte Dateien als Quelle zum Finden von Kopien"
 
-#: help.c:281
-#, c-format
-msgid ""
-"'%s' appears to be a git command, but we were not\n"
-"able to execute it. Maybe git-%s is broken?"
-msgstr ""
-"'%s' scheint ein git-Befehl zu sein, konnte aber\n"
-"nicht ausgeführt werden. Vielleicht ist git-%s fehlerhaft?"
+#: diff.c:5395
+msgid "disable rename detection"
+msgstr "Erkennung von Umbenennungen deaktivieren"
 
-#: help.c:336
-msgid "Uh oh. Your system reports no Git commands at all."
-msgstr "Uh oh. Keine Git-Befehle auf Ihrem System vorhanden."
+#: diff.c:5398
+msgid "use empty blobs as rename source"
+msgstr "Nutze leere Blobs als Quelle von Umbennungen"
 
-#: help.c:358
-#, c-format
-msgid "WARNING: You called a Git command named '%s', which does not exist."
+#: diff.c:5400
+msgid "continue listing the history of a file beyond renames"
+msgstr "Fortführen der Auflistung der Historie einer Datei nach Umbennung"
+
+#: diff.c:5403
+msgid ""
+"prevent rename/copy detection if the number of rename/copy targets exceeds "
+"given limit"
 msgstr ""
-"WARNUNG: Sie haben Git-Befehl '%s' ausgeführt, welcher nicht existiert."
+"Verhindere die Erkennung von Umbennungen und Kopien, wenn die Anzahl der "
+"Ziele für Umbennungen und Kopien das gegebene Limit überschreitet"
 
-#: help.c:363
-#, c-format
-msgid "Continuing under the assumption that you meant '%s'."
-msgstr "Setze fort unter der Annahme, dass Sie '%s' meinten."
+#: diff.c:5405
+msgid "Diff algorithm options"
+msgstr "Diff Algorithmus-Optionen"
 
-#: help.c:368
-#, c-format
-msgid "Continuing in %0.1f seconds, assuming that you meant '%s'."
-msgstr "Setze in %0.1f Sekunden fort unter der Annahme, dass Sie '%s' meinten."
+#: diff.c:5407
+msgid "produce the smallest possible diff"
+msgstr "Erzeuge die kleinstmöglichen Änderungen"
 
-#: help.c:376
-#, c-format
-msgid "git: '%s' is not a git command. See 'git --help'."
-msgstr "git: '%s' ist kein Git-Befehl. Siehe 'git --help'."
+#: diff.c:5410
+msgid "ignore whitespace when comparing lines"
+msgstr "Whitespace-Änderungen beim Vergleich von Zeilen ignorieren"
 
-#: help.c:380
-msgid ""
-"\n"
-"The most similar command is"
-msgid_plural ""
-"\n"
-"The most similar commands are"
-msgstr[0] ""
-"\n"
-"Der ähnlichste Befehl ist"
-msgstr[1] ""
-"\n"
-"Die ähnlichsten Befehle sind"
+#: diff.c:5413
+msgid "ignore changes in amount of whitespace"
+msgstr "Änderungen bei der Anzahl von Whitespace ignorieren"
 
-#: help.c:395
-msgid "git version [<options>]"
-msgstr "git version [<Optionen>]"
+#: diff.c:5416
+msgid "ignore changes in whitespace at EOL"
+msgstr "Whitespace-Änderungen am Zeilenende ignorieren"
 
-#: help.c:462
-#, c-format
-msgid "%s: %s - %s"
-msgstr "%s: %s - %s"
+#: diff.c:5419
+msgid "ignore carrier-return at the end of line"
+msgstr "Ignoriere den Zeilenumbruch am Ende der Zeile"
 
-#: help.c:466
-msgid ""
-"\n"
-"Did you mean this?"
-msgid_plural ""
-"\n"
-"Did you mean one of these?"
-msgstr[0] ""
-"\n"
-"Haben Sie das gemeint?"
-msgstr[1] ""
-"\n"
-"Haben Sie eines von diesen gemeint?"
+#: diff.c:5422
+msgid "ignore changes whose lines are all blank"
+msgstr "Ignoriere Änderungen in leeren Zeilen"
 
-#: ident.c:342
-msgid ""
-"\n"
-"*** Please tell me who you are.\n"
-"\n"
-"Run\n"
-"\n"
-"  git config --global user.email \"you@example.com\"\n"
-"  git config --global user.name \"Your Name\"\n"
-"\n"
-"to set your account's default identity.\n"
-"Omit --global to set the identity only in this repository.\n"
-"\n"
+#: diff.c:5425
+msgid "heuristic to shift diff hunk boundaries for easy reading"
 msgstr ""
-"\n"
-"*** Bitte geben Sie an, wer Sie sind.\n"
-"\n"
-"Führen Sie\n"
-"\n"
-"  git config --global user.email \"you@example.com\"\n"
-"  git config --global user.name \"Your Name\"\n"
-"\n"
-"aus, um das als Ihre standardmäßige Identität zu setzen.\n"
-"Lassen Sie die Option \"--global\" weg, um die Identität nur\n"
-"für dieses Repository zu setzen.\n"
+"Heuristik, um Grenzen der Änderungsblöcke für bessere Lesbarkeit zu "
+"verschieben"
 
-#: ident.c:366
-msgid "no email was given and auto-detection is disabled"
-msgstr "keine E-Mail angegeben und automatische Erkennung ist deaktiviert"
+#: diff.c:5428
+msgid "generate diff using the \"patience diff\" algorithm"
+msgstr "Erzeuge Änderungen durch Nutzung des Algorithmus \"Patience Diff\""
 
-#: ident.c:371
-#, c-format
-msgid "unable to auto-detect email address (got '%s')"
-msgstr "Konnte die E-Mail-Adresse nicht automatisch erkennen ('%s' erhalten)"
+#: diff.c:5432
+msgid "generate diff using the \"histogram diff\" algorithm"
+msgstr "Erzeuge Änderungen durch Nutzung des Algorithmus \"Histogram Diff\""
 
-#: ident.c:381
-msgid "no name was given and auto-detection is disabled"
-msgstr "kein Name angegeben und automatische Erkennung ist deaktiviert"
+#: diff.c:5434
+msgid "<algorithm>"
+msgstr "<Algorithmus>"
 
-#: ident.c:387
-#, c-format
-msgid "unable to auto-detect name (got '%s')"
-msgstr "konnte Namen nicht automatisch erkennen ('%s' erhalten)"
+#: diff.c:5435
+msgid "choose a diff algorithm"
+msgstr "Ein Algorithmus für Änderungen wählen"
 
-#: ident.c:395
-#, c-format
-msgid "empty ident name (for <%s>) not allowed"
-msgstr "Leerer Name in Identifikation (für <%s>) nicht erlaubt."
+#: diff.c:5437
+msgid "<text>"
+msgstr "<Text>"
 
-#: ident.c:401
-#, c-format
-msgid "name consists only of disallowed characters: %s"
-msgstr "Name besteht nur aus nicht erlaubten Zeichen: %s"
+#: diff.c:5438
+msgid "generate diff using the \"anchored diff\" algorithm"
+msgstr "Erzeuge Änderungen durch Nutzung des Algorithmus \"Anchored Diff\""
 
-#: ident.c:416 builtin/commit.c:582
-#, c-format
-msgid "invalid date format: %s"
-msgstr "Ungültiges Datumsformat: %s"
+#: diff.c:5440 diff.c:5449 diff.c:5452
+msgid "<mode>"
+msgstr "<Modus>"
 
-#: list-objects-filter-options.c:36
-msgid "multiple filter-specs cannot be combined"
-msgstr "Mehrere filter-specs können nicht kombiniert werden."
+#: diff.c:5441
+msgid "show word diff, using <mode> to delimit changed words"
+msgstr "Zeige Wort-Änderungen, nutze <Modus>, um Wörter abzugrenzen"
 
-#: list-objects-filter-options.c:126
-msgid "cannot change partial clone promisor remote"
-msgstr "Kann Remote-Repository für partielles Klonen nicht ändern."
+#: diff.c:5443 diff.c:5446 diff.c:5491
+msgid "<regex>"
+msgstr "<Regex>"
 
-#: lockfile.c:151
-#, c-format
-msgid ""
-"Unable to create '%s.lock': %s.\n"
-"\n"
-"Another git process seems to be running in this repository, e.g.\n"
-"an editor opened by 'git commit'. Please make sure all processes\n"
-"are terminated then try again. If it still fails, a git process\n"
-"may have crashed in this repository earlier:\n"
-"remove the file manually to continue."
-msgstr ""
-"Konnte '%s.lock' nicht erstellen: %s.\n"
-"\n"
-"Ein anderer Git-Prozess scheint in diesem Repository ausgeführt\n"
-"zu werden, zum Beispiel ein noch offener Editor von 'git commit'.\n"
-"Bitte stellen Sie sicher, dass alle Prozesse beendet wurden und\n"
-"versuchen Sie es erneut. Falls es immer noch fehlschlägt, könnte\n"
-"ein früherer Git-Prozess in diesem Repository abgestürzt sein:\n"
-"Löschen Sie die Datei manuell um fortzufahren."
+#: diff.c:5444
+msgid "use <regex> to decide what a word is"
+msgstr "Nutze <Regex>, um zu entscheiden, was ein Wort ist"
 
-#: lockfile.c:159
-#, c-format
-msgid "Unable to create '%s.lock': %s"
-msgstr "Konnte '%s.lock' nicht erstellen: %s"
+#: diff.c:5447
+msgid "equivalent to --word-diff=color --word-diff-regex=<regex>"
+msgstr "Entsprechend wie --word-diff=color --word-diff-regex=<Regex>"
 
-#: merge.c:74
-msgid "failed to read the cache"
-msgstr "Lesen des Zwischenspeichers fehlgeschlagen"
+#: diff.c:5450
+msgid "moved lines of code are colored differently"
+msgstr "Verschobene Codezeilen sind andersfarbig"
 
-#: merge.c:134 builtin/am.c:1946 builtin/am.c:1980 builtin/checkout.c:378
-#: builtin/checkout.c:599 builtin/clone.c:759
-msgid "unable to write new index file"
-msgstr "Konnte neue Index-Datei nicht schreiben."
+#: diff.c:5453
+msgid "how white spaces are ignored in --color-moved"
+msgstr "Wie Whitespaces in --color-moved ignoriert werden"
 
-#: merge-recursive.c:235
-msgid "(bad commit)\n"
-msgstr "(ungültiger Commit)\n"
+#: diff.c:5456
+msgid "Other diff options"
+msgstr "Andere Diff-Optionen"
 
-#: merge-recursive.c:257 merge-recursive.c:265
-#, c-format
-msgid "addinfo_cache failed for path '%s'"
-msgstr "addinfo_cache für Pfad '%s' fehlgeschlagen"
+#: diff.c:5458
+msgid "when run from subdir, exclude changes outside and show relative paths"
+msgstr ""
+"Wenn vom Unterverzeichnis aufgerufen, schließe Änderungen außerhalb aus und "
+"zeige relative Pfade an"
 
-#: merge-recursive.c:329
-msgid "error building trees"
-msgstr "Fehler beim Erstellen der \"Tree\"-Objekte"
+#: diff.c:5462
+msgid "treat all files as text"
+msgstr "alle Dateien als Text behandeln"
 
-#: merge-recursive.c:771
-#, c-format
-msgid "failed to create path '%s'%s"
-msgstr "Fehler beim Erstellen des Pfades '%s'%s"
+#: diff.c:5464
+msgid "swap two inputs, reverse the diff"
+msgstr "Vertausche die beiden Eingaben und drehe die Änderungen um"
 
-#: merge-recursive.c:782
-#, c-format
-msgid "Removing %s to make room for subdirectory\n"
-msgstr "Entferne %s, um Platz für Unterverzeichnis zu schaffen\n"
+#: diff.c:5466
+msgid "exit with 1 if there were differences, 0 otherwise"
+msgstr ""
+"Beende mit Exit-Status 1, wenn Änderungen vorhanden sind, andernfalls mit 0"
 
-#: merge-recursive.c:796 merge-recursive.c:815
-msgid ": perhaps a D/F conflict?"
-msgstr ": vielleicht ein Verzeichnis/Datei-Konflikt?"
+#: diff.c:5468
+msgid "disable all output of the program"
+msgstr "Keine Ausgaben vom Programm"
 
-#: merge-recursive.c:805
-#, c-format
-msgid "refusing to lose untracked file at '%s'"
-msgstr "verweigere, da unversionierte Dateien in '%s' verloren gehen würden"
+#: diff.c:5470
+msgid "allow an external diff helper to be executed"
+msgstr "Erlaube die Ausführung eines externes Programms für Änderungen"
 
-#: merge-recursive.c:847 builtin/cat-file.c:37
-#, c-format
-msgid "cannot read object %s '%s'"
-msgstr "kann Objekt %s '%s' nicht lesen"
+#: diff.c:5472
+msgid "run external text conversion filters when comparing binary files"
+msgstr ""
+"Führe externe Text-Konvertierungsfilter aus, wenn binäre Dateien vergleicht "
+"werden"
 
-#: merge-recursive.c:849
-#, c-format
-msgid "blob expected for %s '%s'"
-msgstr "Blob erwartet für %s '%s'"
+#: diff.c:5474
+msgid "<when>"
+msgstr "<wann>"
 
-#: merge-recursive.c:873
-#, c-format
-msgid "failed to open '%s': %s"
-msgstr "Fehler beim Öffnen von '%s': %s"
+#: diff.c:5475
+msgid "ignore changes to submodules in the diff generation"
+msgstr ""
+"Änderungen in Submodulen während der Erstellung der Unterschiede ignorieren"
 
-#: merge-recursive.c:884
-#, c-format
-msgid "failed to symlink '%s': %s"
-msgstr "Fehler beim Erstellen einer symbolischen Verknüpfung für '%s': %s"
+#: diff.c:5478
+msgid "<format>"
+msgstr "<Format>"
 
-#: merge-recursive.c:889
-#, c-format
-msgid "do not know what to do with %06o %s '%s'"
-msgstr "weiß nicht was mit %06o %s '%s' zu machen ist"
+#: diff.c:5479
+msgid "specify how differences in submodules are shown"
+msgstr "Angeben, wie Unterschiede in Submodulen gezeigt werden"
 
-#: merge-recursive.c:1029
-msgid "Failed to execute internal merge"
-msgstr "Fehler bei Ausführung des internen Merges"
+#: diff.c:5483
+msgid "hide 'git add -N' entries from the index"
+msgstr "verstecke 'git add -N' Einträge vom Index"
 
-#: merge-recursive.c:1034
-#, c-format
-msgid "Unable to add %s to database"
-msgstr "Konnte %s nicht zur Datenbank hinzufügen"
+#: diff.c:5486
+msgid "treat 'git add -N' entries as real in the index"
+msgstr "Behandle 'git add -N' Einträge im Index als echt"
 
-#: merge-recursive.c:1146
-#, c-format
+#: diff.c:5488
+msgid "<string>"
+msgstr "<Zeichenkette>"
+
+#: diff.c:5489
 msgid ""
-"CONFLICT (%s/delete): %s deleted in %s and %s in %s. Version %s of %s left "
-"in tree."
+"look for differences that change the number of occurrences of the specified "
+"string"
 msgstr ""
-"KONFLIKT (%s/löschen): %s gelöscht in %s und %s in %s. Stand %s von %s wurde "
-"im Arbeitsbereich gelassen."
+"Suche nach Unterschieden, welche die Anzahl des Vorkommens der angegebenen "
+"Zeichenkette verändern"
 
-#: merge-recursive.c:1151
-#, c-format
+#: diff.c:5492
 msgid ""
-"CONFLICT (%s/delete): %s deleted in %s and %s to %s in %s. Version %s of %s "
-"left in tree."
+"look for differences that change the number of occurrences of the specified "
+"regex"
 msgstr ""
-"KONFLIKT (%s/löschen): %s gelöscht in %s und %s nach %s in %s. Stand %s von "
-"%s wurde im Arbeitsbereich gelassen."
+"Suche nach Unterschieden, welche die Anzahl des Vorkommens des angegebenen "
+"regulären Ausdrucks verändern"
 
-#: merge-recursive.c:1158
-#, c-format
-msgid ""
-"CONFLICT (%s/delete): %s deleted in %s and %s in %s. Version %s of %s left "
-"in tree at %s."
+#: diff.c:5495
+msgid "show all changes in the changeset with -S or -G"
+msgstr "zeige alle Änderungen im Changeset mit -S oder -G"
+
+#: diff.c:5498
+msgid "treat <string> in -S as extended POSIX regular expression"
 msgstr ""
-"KONFLIKT (%s/löschen): %s gelöscht in %s und %s in %s. Stand %s von %s wurde "
-"im Arbeitsbereich bei %s gelassen."
+"behandle <Zeichenkette> bei -S als erweiterten POSIX regulären Ausdruck"
 
-#: merge-recursive.c:1163
-#, c-format
+#: diff.c:5501
+msgid "control the order in which files appear in the output"
+msgstr ""
+"kontrolliere die Reihenfolge, in der die Dateien in der Ausgabe erscheinen"
+
+#: diff.c:5502
+msgid "<object-id>"
+msgstr "<Objekt-ID>"
+
+#: diff.c:5503
 msgid ""
-"CONFLICT (%s/delete): %s deleted in %s and %s to %s in %s. Version %s of %s "
-"left in tree at %s."
+"look for differences that change the number of occurrences of the specified "
+"object"
 msgstr ""
-"KONFLIKT (%s/löschen): %s gelöscht in %s und %s nach %s in %s. Stand %s von "
-"%s wurde im Arbeitsbereich bei %s gelassen."
+"Suche nach Unterschieden, welche die Anzahl des Vorkommens des angegebenen "
+"Objektes verändern"
 
-#: merge-recursive.c:1197
-msgid "rename"
-msgstr "umbenennen"
+#: diff.c:5505
+msgid "[(A|C|D|M|R|T|U|X|B)...[*]]"
+msgstr "[(A|C|D|M|R|T|U|X|B)...[*]]"
 
-#: merge-recursive.c:1197
-msgid "renamed"
-msgstr "umbenannt"
+#: diff.c:5506
+msgid "select files by diff type"
+msgstr "Wähle Dateien anhand der Art der Änderung"
 
-#: merge-recursive.c:1254
-#, c-format
-msgid "%s is a directory in %s adding as %s instead"
-msgstr "%s ist ein Verzeichnis in %s, füge es stattdessen als %s hinzu"
+#: diff.c:5508
+msgid "<file>"
+msgstr "<Datei>"
+
+#: diff.c:5509
+msgid "Output to a specific file"
+msgstr "Ausgabe zu einer bestimmten Datei"
+
+#: diff.c:6164
+msgid "inexact rename detection was skipped due to too many files."
+msgstr ""
+"Ungenaue Erkennung für Umbenennungen wurde aufgrund zu vieler Dateien\n"
+"übersprungen."
 
-#: merge-recursive.c:1279
+#: diff.c:6167
+msgid "only found copies from modified paths due to too many files."
+msgstr "nur Kopien von geänderten Pfaden, aufgrund zu vieler Dateien, gefunden"
+
+#: diff.c:6170
 #, c-format
 msgid ""
-"CONFLICT (rename/rename): Rename \"%s\"->\"%s\" in branch \"%s\" rename \"%s"
-"\"->\"%s\" in \"%s\"%s"
+"you may want to set your %s variable to at least %d and retry the command."
 msgstr ""
-"KONFLIKT (umbenennen/umbenennen): Benenne um \"%s\"->\"%s\" in Branch \"%s\" "
-"und \"%s\"->\"%s\" in Branch \"%s\"%s"
-
-#: merge-recursive.c:1284
-msgid " (left unresolved)"
-msgstr " (bleibt unaufgelöst)"
+"Sie könnten die Variable %s auf mindestens %d setzen und den Befehl\n"
+"erneut versuchen."
 
-#: merge-recursive.c:1346
+#: dir.c:554
 #, c-format
-msgid "CONFLICT (rename/rename): Rename %s->%s in %s. Rename %s->%s in %s"
+msgid "pathspec '%s' did not match any file(s) known to git"
 msgstr ""
-"KONFLIKT (umbenennen/umbenennen): Benenne um %s->%s in %s. Benenne um %s->%s "
-"in %s"
+"Pfadspezifikation '%s' stimmt mit keinen git-bekannten Dateien überein."
 
-#: merge-recursive.c:1379
+#: dir.c:664
 #, c-format
-msgid "Renaming %s to %s and %s to %s instead"
-msgstr "Benenne stattdessen %s nach %s und %s nach %s um"
+msgid "unrecognized pattern: '%s'"
+msgstr "Unbekanntes Muster: '%s'"
 
-#: merge-recursive.c:1582
+#: dir.c:682 dir.c:696
 #, c-format
-msgid "CONFLICT (rename/add): Rename %s->%s in %s. %s added in %s"
-msgstr ""
-"KONFLIKT (umbenennen/hinzufügen): Benenne um %s->%s in %s. %s hinzugefügt in "
-"%s"
+msgid "unrecognized negative pattern: '%s'"
+msgstr "Unbekanntes verneinendes Muster: '%s'"
 
-#: merge-recursive.c:1597
+#: dir.c:714
 #, c-format
-msgid "Adding merged %s"
-msgstr "Füge zusammengeführte Datei %s hinzu"
+msgid "your sparse-checkout file may have issues: pattern '%s' is repeated"
+msgstr ""
+"Ihre Datei für den partiellen Checkout hat eventuell Probleme:\n"
+"Muster '%s' wiederholt sich."
 
-#: merge-recursive.c:1604 merge-recursive.c:1834
-#, c-format
-msgid "Adding as %s instead"
-msgstr "Füge stattdessen als %s hinzu"
+#: dir.c:724
+msgid "disabling cone pattern matching"
+msgstr "Deaktiviere Cone-Muster-Übereinstimmung"
 
-#: merge-recursive.c:1661
+#: dir.c:1101
 #, c-format
-msgid "cannot read object %s"
-msgstr "kann Objekt %s nicht lesen"
+msgid "cannot use %s as an exclude file"
+msgstr "Kann %s nicht als exclude-Filter benutzen."
 
-#: merge-recursive.c:1664
+#: dir.c:2078
 #, c-format
-msgid "object %s is not a blob"
-msgstr "Objekt %s ist kein Blob"
-
-#: merge-recursive.c:1733
-msgid "modify"
-msgstr "ändern"
-
-#: merge-recursive.c:1733
-msgid "modified"
-msgstr "geändert"
+msgid "could not open directory '%s'"
+msgstr "Konnte Verzeichnis '%s' nicht öffnen."
 
-#: merge-recursive.c:1743
-msgid "content"
-msgstr "Inhalt"
+#: dir.c:2415
+msgid "failed to get kernel name and information"
+msgstr "Fehler beim Sammeln von Namen und Informationen zum Kernel"
 
-#: merge-recursive.c:1750
-msgid "add/add"
-msgstr "hinzufügen/hinzufügen"
+#: dir.c:2539
+msgid "untracked cache is disabled on this system or location"
+msgstr ""
+"Cache für unversionierte Dateien ist auf diesem System oder\n"
+"für dieses Verzeichnis deaktiviert."
 
-#: merge-recursive.c:1786
+#: dir.c:3343
 #, c-format
-msgid "Skipped %s (merged same as existing)"
-msgstr "%s ausgelassen (Ergebnis des Merges existiert bereits)"
+msgid "index file corrupt in repo %s"
+msgstr "Index-Datei in Repository %s beschädigt."
 
-#: merge-recursive.c:1800
+#: dir.c:3388 dir.c:3393
 #, c-format
-msgid "Auto-merging %s"
-msgstr "automatischer Merge von %s"
-
-#: merge-recursive.c:1804 git-submodule.sh:879
-msgid "submodule"
-msgstr "Submodul"
+msgid "could not create directories for %s"
+msgstr "Konnte Verzeichnisse für '%s' nicht erstellen."
 
-#: merge-recursive.c:1805
+#: dir.c:3422
 #, c-format
-msgid "CONFLICT (%s): Merge conflict in %s"
-msgstr "KONFLIKT (%s): Merge-Konflikt in %s"
+msgid "could not migrate git directory from '%s' to '%s'"
+msgstr "Konnte Git-Verzeichnis nicht von '%s' nach '%s' migrieren."
 
-#: merge-recursive.c:1899
+#: editor.c:73
 #, c-format
-msgid "Removing %s"
-msgstr "Entferne %s"
+msgid "hint: Waiting for your editor to close the file...%c"
+msgstr "Hinweis: Warte auf das Schließen der Datei durch Ihren Editor...%c"
 
-#: merge-recursive.c:1925
-msgid "file/directory"
-msgstr "Datei/Verzeichnis"
+#: entry.c:178
+msgid "Filtering content"
+msgstr "Filtere Inhalt"
 
-#: merge-recursive.c:1931
-msgid "directory/file"
-msgstr "Verzeichnis/Datei"
+#: entry.c:476
+#, c-format
+msgid "could not stat file '%s'"
+msgstr "Konnte Datei '%s' nicht lesen."
 
-#: merge-recursive.c:1938
+#: environment.c:149
 #, c-format
-msgid "CONFLICT (%s): There is a directory with name %s in %s. Adding %s as %s"
-msgstr ""
-"KONFLIKT (%s): Es existiert bereits ein Verzeichnis %s in %s. Füge %s als %s "
-"hinzu."
+msgid "bad git namespace path \"%s\""
+msgstr "Ungültiger Git-Namespace-Pfad \"%s\""
 
-#: merge-recursive.c:1947
+#: environment.c:331
 #, c-format
-msgid "Adding %s"
-msgstr "Füge %s hinzu"
+msgid "could not set GIT_DIR to '%s'"
+msgstr "Konnte GIT_DIR nicht zu '%s' setzen."
 
-#: merge-recursive.c:1987
+#: exec-cmd.c:363
 #, c-format
-msgid "Dirty index: cannot merge (dirty: %s)"
-msgstr "Geänderter Index: kann nicht mergen (geändert: %s)"
+msgid "too many args to run %s"
+msgstr "Zu viele Argumente angegeben, um %s auszuführen."
 
-#: merge-recursive.c:1991
-msgid "Already up to date!"
-msgstr "Bereits aktuell!"
+#: fetch-pack.c:150
+msgid "git fetch-pack: expected shallow list"
+msgstr "git fetch-pack: erwartete shallow-Liste"
 
-#: merge-recursive.c:2000
-#, c-format
-msgid "merging of trees %s and %s failed"
-msgstr "Zusammenführen der \"Tree\"-Objekte %s und %s fehlgeschlagen"
+#: fetch-pack.c:153
+msgid "git fetch-pack: expected a flush packet after shallow list"
+msgstr "git fetch-pack: erwartete ein Flush-Paket nach der shallow-Liste"
 
-#: merge-recursive.c:2097
-msgid "Merging:"
-msgstr "Merge:"
+#: fetch-pack.c:164
+msgid "git fetch-pack: expected ACK/NAK, got a flush packet"
+msgstr "git fetch-pack: ACK/NAK erwartet, Flush-Paket bekommen"
 
-#: merge-recursive.c:2110
+#: fetch-pack.c:184
 #, c-format
-msgid "found %u common ancestor:"
-msgid_plural "found %u common ancestors:"
-msgstr[0] "%u gemeinsamen Vorgänger-Commit gefunden"
-msgstr[1] "%u gemeinsame Vorgänger-Commits gefunden"
+msgid "git fetch-pack: expected ACK/NAK, got '%s'"
+msgstr "git fetch-pack: ACK/NAK erwartet, '%s' bekommen"
 
-#: merge-recursive.c:2149
-msgid "merge returned no commit"
-msgstr "Merge hat keinen Commit zurückgegeben"
+#: fetch-pack.c:195
+msgid "unable to write to remote"
+msgstr "konnte nicht zum Remote schreiben"
 
-#: merge-recursive.c:2212
-#, c-format
-msgid "Could not parse object '%s'"
-msgstr "Konnte Objekt '%s' nicht parsen."
+#: fetch-pack.c:257
+msgid "--stateless-rpc requires multi_ack_detailed"
+msgstr "--stateless-rpc benötigt multi_ack_detailed"
 
-#: merge-recursive.c:2228 builtin/merge.c:657 builtin/merge.c:816
-msgid "Unable to write index."
-msgstr "Konnte Index nicht schreiben."
+#: fetch-pack.c:356 fetch-pack.c:1340
+#, c-format
+msgid "invalid shallow line: %s"
+msgstr "Ungültige shallow-Zeile: %s"
 
-#: notes-merge.c:272
+#: fetch-pack.c:362 fetch-pack.c:1346
 #, c-format
-msgid ""
-"You have not concluded your previous notes merge (%s exists).\n"
-"Please, use 'git notes merge --commit' or 'git notes merge --abort' to "
-"commit/abort the previous merge before you start a new notes merge."
-msgstr ""
-"Sie haben Ihren vorherigen Merge von Notizen nicht abgeschlossen (%s "
-"existiert).\n"
-"Bitte benutzen Sie 'git notes merge --commit' oder 'git notes merge --"
-"abort', um\n"
-"den vorherigen Merge zu committen bzw. abzubrechen, bevor Sie einen neuen "
-"Merge\n"
-"von Notizen beginnen."
+msgid "invalid unshallow line: %s"
+msgstr "Ungültige unshallow-Zeile: %s"
 
-#: notes-merge.c:279
+#: fetch-pack.c:364 fetch-pack.c:1348
 #, c-format
-msgid "You have not concluded your notes merge (%s exists)."
-msgstr "Sie haben Ihren Merge von Notizen nicht abgeschlossen (%s existiert)."
+msgid "object not found: %s"
+msgstr "Objekt nicht gefunden: %s"
 
-#: notes-utils.c:43
-msgid "Cannot commit uninitialized/unreferenced notes tree"
-msgstr ""
-"Kann uninitialisiertes/unreferenziertes Notiz-Verzeichnis nicht committen."
+#: fetch-pack.c:367 fetch-pack.c:1351
+#, c-format
+msgid "error in object: %s"
+msgstr "Fehler in Objekt: %s"
 
-#: notes-utils.c:102
+#: fetch-pack.c:369 fetch-pack.c:1353
 #, c-format
-msgid "Bad notes.rewriteMode value: '%s'"
-msgstr "Ungültiger notes.rewriteMode Wert: '%s'"
+msgid "no shallow found: %s"
+msgstr "Kein shallow-Objekt gefunden: %s"
 
-#: notes-utils.c:112
+#: fetch-pack.c:372 fetch-pack.c:1357
 #, c-format
-msgid "Refusing to rewrite notes in %s (outside of refs/notes/)"
-msgstr ""
-"Umschreiben der Notizen in %s zurückgewiesen (außerhalb von refs/notes/)"
+msgid "expected shallow/unshallow, got %s"
+msgstr "shallow/unshallow erwartet, %s bekommen"
 
-#. TRANSLATORS: The first %s is the name of
-#. the environment variable, the second %s is
-#. its value.
-#.
-#: notes-utils.c:142
+#: fetch-pack.c:414
 #, c-format
-msgid "Bad %s value: '%s'"
-msgstr "Ungültiger %s Wert: '%s'"
+msgid "got %s %d %s"
+msgstr "%s %d %s bekommen"
 
-#: object.c:239
+#: fetch-pack.c:431
 #, c-format
-msgid "unable to parse object: %s"
-msgstr "Konnte Objekt '%s' nicht parsen."
+msgid "invalid commit %s"
+msgstr "Ungültiger Commit %s"
 
-#: packfile.c:561
-msgid "offset before end of packfile (broken .idx?)"
-msgstr "Offset vor Ende der Packdatei (fehlerhafte Indexdatei?)"
+#: fetch-pack.c:462
+msgid "giving up"
+msgstr "Gebe auf"
 
-#: packfile.c:1694
-#, c-format
-msgid "offset before start of pack index for %s (corrupt index?)"
-msgstr "Offset vor Beginn des Pack-Index für %s (beschädigter Index?)"
+#: fetch-pack.c:475 progress.c:323
+msgid "done"
+msgstr "Fertig"
 
-#: packfile.c:1698
+#: fetch-pack.c:487
 #, c-format
-msgid "offset beyond end of pack index for %s (truncated index?)"
-msgstr "Offset hinter Ende des Pack-Index für %s (abgeschnittener Index?)"
+msgid "got %s (%d) %s"
+msgstr "%s (%d) %s bekommen"
 
-#: parse-options.c:619
-msgid "..."
-msgstr "..."
+#: fetch-pack.c:533
+#, c-format
+msgid "Marking %s as complete"
+msgstr "Markiere %s als vollständig"
 
-#: parse-options.c:638
+#: fetch-pack.c:754
 #, c-format
-msgid "usage: %s"
-msgstr "Verwendung: %s"
+msgid "already have %s (%s)"
+msgstr "habe %s (%s) bereits"
 
-#. TRANSLATORS: the colon here should align with the
-#. one in "usage: %s" translation.
-#.
-#: parse-options.c:644
+#: fetch-pack.c:818
+msgid "fetch-pack: unable to fork off sideband demultiplexer"
+msgstr "fetch-pack: Fehler beim Starten des sideband demultiplexer"
+
+#: fetch-pack.c:826
+msgid "protocol error: bad pack header"
+msgstr "Protokollfehler: ungültiger Pack-Header"
+
+#: fetch-pack.c:900
 #, c-format
-msgid "   or: %s"
-msgstr "      oder: %s"
+msgid "fetch-pack: unable to fork off %s"
+msgstr "fetch-pack: konnte %s nicht starten"
 
-#: parse-options.c:647
+#: fetch-pack.c:916
 #, c-format
-msgid "    %s"
-msgstr "    %s"
+msgid "%s failed"
+msgstr "%s fehlgeschlagen"
 
-#: parse-options.c:686
-msgid "-NUM"
-msgstr "-NUM"
+#: fetch-pack.c:918
+msgid "error in sideband demultiplexer"
+msgstr "Fehler in sideband demultiplexer"
 
-#: parse-options-cb.c:108
+#: fetch-pack.c:965
 #, c-format
-msgid "malformed object name '%s'"
-msgstr "fehlerhafter Objekt-Name '%s'"
+msgid "Server version is %.*s"
+msgstr "Server-Version ist %.*s"
 
-#: path.c:891
+#: fetch-pack.c:970 fetch-pack.c:976 fetch-pack.c:979 fetch-pack.c:985
+#: fetch-pack.c:989 fetch-pack.c:993 fetch-pack.c:997 fetch-pack.c:1001
+#: fetch-pack.c:1005 fetch-pack.c:1009 fetch-pack.c:1013 fetch-pack.c:1017
+#: fetch-pack.c:1023 fetch-pack.c:1029 fetch-pack.c:1034 fetch-pack.c:1039
 #, c-format
-msgid "Could not make %s writable by group"
-msgstr "Konnte Gruppenschreibrecht für %s nicht setzen."
+msgid "Server supports %s"
+msgstr "Server unterstützt %s"
 
-#: pathspec.c:129
-msgid "Escape character '\\' not allowed as last character in attr value"
-msgstr "Escape-Zeichen '\\' als letztes Zeichen in Attributwert nicht erlaubt"
+#: fetch-pack.c:972
+msgid "Server does not support shallow clients"
+msgstr "Server unterstützt keine shallow-Clients"
 
-#: pathspec.c:147
-msgid "Only one 'attr:' specification is allowed."
-msgstr "Es ist nur eine Angabe von 'attr:' erlaubt."
+#: fetch-pack.c:1032
+msgid "Server does not support --shallow-since"
+msgstr "Server unterstützt kein --shallow-since"
 
-#: pathspec.c:150
-msgid "attr spec must not be empty"
-msgstr "Angabe von 'attr:' darf nicht leer sein"
+#: fetch-pack.c:1037
+msgid "Server does not support --shallow-exclude"
+msgstr "Server unterstützt kein --shallow-exclude"
 
-#: pathspec.c:193
-#, c-format
-msgid "invalid attribute name %s"
-msgstr "Ungültiger Attributname %s"
+#: fetch-pack.c:1041
+msgid "Server does not support --deepen"
+msgstr "Server unterstützt kein --deepen"
 
-#: pathspec.c:258
-msgid "global 'glob' and 'noglob' pathspec settings are incompatible"
-msgstr ""
-"Globale Einstellungen zur Pfadspezifikation 'glob' und 'noglob' sind "
-"inkompatibel."
+#: fetch-pack.c:1058
+msgid "no common commits"
+msgstr "keine gemeinsamen Commits"
 
-#: pathspec.c:265
-msgid ""
-"global 'literal' pathspec setting is incompatible with all other global "
-"pathspec settings"
-msgstr ""
-"Globale Einstellung zur Pfadspezifikation 'literal' ist inkompatibel\n"
-"mit allen anderen Optionen."
+#: fetch-pack.c:1070 fetch-pack.c:1536
+msgid "git fetch-pack: fetch failed."
+msgstr "git fetch-pack: Abholen fehlgeschlagen."
 
-#: pathspec.c:305
-msgid "invalid parameter for pathspec magic 'prefix'"
-msgstr "ungültiger Parameter für Pfadspezifikationsangabe 'prefix'"
+#: fetch-pack.c:1209
+msgid "Server does not support shallow requests"
+msgstr "Server unterstützt keine shallow-Anfragen."
+
+#: fetch-pack.c:1216
+msgid "Server supports filter"
+msgstr "Server unterstützt Filter"
 
-#: pathspec.c:326
+#: fetch-pack.c:1239
+msgid "unable to write request to remote"
+msgstr "konnte Anfrage nicht zum Remote schreiben"
+
+#: fetch-pack.c:1257
 #, c-format
-msgid "Invalid pathspec magic '%.*s' in '%s'"
-msgstr "ungültige Pfadspezifikationsangabe '%.*s' in '%s'"
+msgid "error reading section header '%s'"
+msgstr "Fehler beim Lesen von Sektionskopf '%s'."
 
-#: pathspec.c:331
+#: fetch-pack.c:1263
 #, c-format
-msgid "Missing ')' at the end of pathspec magic in '%s'"
-msgstr "Fehlendes ')' am Ende der Pfadspezifikationsangabe in '%s'"
+msgid "expected '%s', received '%s'"
+msgstr "'%s' erwartet, '%s' empfangen"
 
-#: pathspec.c:369
+#: fetch-pack.c:1303
 #, c-format
-msgid "Unimplemented pathspec magic '%c' in '%s'"
-msgstr "nicht unterstützte Pfadspezifikationsangabe '%c' in '%s'"
+msgid "unexpected acknowledgment line: '%s'"
+msgstr "Unerwartete Acknowledgment-Zeile: '%s'"
 
-#: pathspec.c:428
+#: fetch-pack.c:1308
 #, c-format
-msgid "%s: 'literal' and 'glob' are incompatible"
-msgstr "%s: 'literal' und 'glob' sind inkompatibel"
+msgid "error processing acks: %d"
+msgstr "Fehler beim Verarbeiten von ACKS: %d"
+
+#: fetch-pack.c:1318
+msgid "expected packfile to be sent after 'ready'"
+msgstr "Erwartete Versand einer Packdatei nach 'ready'."
 
-#: pathspec.c:441
+#: fetch-pack.c:1320
+msgid "expected no other sections to be sent after no 'ready'"
+msgstr "Erwartete keinen Versand einer anderen Sektion ohne 'ready'."
+
+#: fetch-pack.c:1362
 #, c-format
-msgid "%s: '%s' is outside repository"
-msgstr "%s: '%s' liegt außerhalb des Repositories"
+msgid "error processing shallow info: %d"
+msgstr "Fehler beim Verarbeiten von Shallow-Informationen: %d"
 
-#: pathspec.c:515
+#: fetch-pack.c:1409
 #, c-format
-msgid "'%s' (mnemonic: '%c')"
-msgstr "'%s' (Kürzel: '%c')"
+msgid "expected wanted-ref, got '%s'"
+msgstr "wanted-ref erwartet, '%s' bekommen"
 
-#: pathspec.c:525
+#: fetch-pack.c:1414
 #, c-format
-msgid "%s: pathspec magic not supported by this command: %s"
-msgstr ""
-"%s: Pfadspezifikationsangabe wird von diesem Befehl nicht unterstützt: %s"
+msgid "unexpected wanted-ref: '%s'"
+msgstr "Unerwartetes wanted-ref: '%s'"
 
-#: pathspec.c:592
+#: fetch-pack.c:1419
 #, c-format
-msgid "pathspec '%s' is beyond a symbolic link"
-msgstr "Pfadspezifikation '%s' ist hinter einer symbolischen Verknüpfung"
+msgid "error processing wanted refs: %d"
+msgstr "Fehler beim Verarbeiten von wanted-refs: %d"
 
-#: pretty.c:962
-msgid "unable to parse --pretty format"
-msgstr "Konnte --pretty Format nicht parsen."
+#: fetch-pack.c:1762
+msgid "no matching remote head"
+msgstr "kein übereinstimmender Remote-Branch"
 
-#: read-cache.c:1473
+#: fetch-pack.c:1785 builtin/clone.c:688
+msgid "remote did not send all necessary objects"
+msgstr "Remote-Repository hat nicht alle erforderlichen Objekte gesendet."
+
+#: fetch-pack.c:1812
 #, c-format
-msgid ""
-"index.version set, but the value is invalid.\n"
-"Using version %i"
-msgstr ""
-"index.version gesetzt, aber Wert ungültig.\n"
-"Verwende Version %i"
+msgid "no such remote ref %s"
+msgstr "keine solche Remote-Referenz %s"
 
-#: read-cache.c:1483
+#: fetch-pack.c:1815
 #, c-format
-msgid ""
-"GIT_INDEX_VERSION set, but the value is invalid.\n"
-"Using version %i"
-msgstr ""
-"GIT_INDEX_VERSION gesetzt, aber Wert ungültig.\n"
-"Verwende Version %i"
-
-#: read-cache.c:2375 sequencer.c:3248 wrapper.c:658 builtin/merge.c:1049
-#, c-format
-msgid "could not close '%s'"
-msgstr "Konnte '%s' nicht schließen"
+msgid "Server does not allow request for unadvertised object %s"
+msgstr "Der Server lehnt Anfrage nach nicht angebotenem Objekt %s ab."
 
-#: read-cache.c:2448 sequencer.c:1900 sequencer.c:2627
-#, c-format
-msgid "could not stat '%s'"
-msgstr "Konnte '%s' nicht lesen."
+#: gpg-interface.c:223
+msgid "could not create temporary file"
+msgstr "konnte temporäre Datei nicht erstellen"
 
-#: read-cache.c:2461
+#: gpg-interface.c:226
 #, c-format
-msgid "unable to open git dir: %s"
-msgstr "konnte Git-Verzeichnis nicht öffnen: %s"
+msgid "failed writing detached signature to '%s'"
+msgstr "Fehler beim Schreiben der losgelösten Signatur nach '%s'"
 
-#: read-cache.c:2473
-#, c-format
-msgid "unable to unlink: %s"
-msgstr "Konnte '%s' nicht entfernen."
+#: gpg-interface.c:390
+msgid "gpg failed to sign the data"
+msgstr "gpg beim Signieren der Daten fehlgeschlagen"
 
-#: refs.c:706
+#: graph.c:98
 #, c-format
-msgid "Could not open '%s' for writing"
-msgstr "Konnte '%s' nicht zum Schreiben öffnen."
+msgid "ignore invalid color '%.*s' in log.graphColors"
+msgstr "Ignoriere ungültige Farbe '%.*s' in log.graphColors"
 
-#: refs.c:1850
-msgid "ref updates forbidden inside quarantine environment"
+#: grep.c:668
+msgid ""
+"given pattern contains NULL byte (via -f <file>). This is only supported "
+"with -P under PCRE v2"
 msgstr ""
-"Aktualisierungen von Referenzen ist innerhalb der Quarantäne-Umgebung "
-"verboten."
+"Angegebenes Muster enthält NULL Byte (über -f <Datei>). Das wird nur mit -"
+"Punter PCRE v2 unterstützt."
 
-#: refs/files-backend.c:1189
+#: grep.c:2124
 #, c-format
-msgid "could not remove reference %s"
-msgstr "Konnte Referenz %s nicht löschen"
+msgid "'%s': unable to read %s"
+msgstr "'%s': konnte %s nicht lesen"
 
-#: refs/files-backend.c:1203 refs/packed-backend.c:1528
-#: refs/packed-backend.c:1538
+#: grep.c:2141 setup.c:165 builtin/clone.c:411 builtin/diff.c:82
+#: builtin/rm.c:135
 #, c-format
-msgid "could not delete reference %s: %s"
-msgstr "Konnte Referenz %s nicht entfernen: %s"
+msgid "failed to stat '%s'"
+msgstr "Konnte '%s' nicht lesen"
 
-#: refs/files-backend.c:1206 refs/packed-backend.c:1541
+#: grep.c:2152
 #, c-format
-msgid "could not delete references: %s"
-msgstr "Konnte Referenzen nicht entfernen: %s"
-
-#: ref-filter.c:35 wt-status.c:1842
-msgid "gone"
-msgstr "entfernt"
+msgid "'%s': short read"
+msgstr "'%s': read() zu kurz"
 
-#: ref-filter.c:36
-#, c-format
-msgid "ahead %d"
-msgstr "%d voraus"
+#: help.c:23
+msgid "start a working area (see also: git help tutorial)"
+msgstr "Arbeitsverzeichnis anlegen (siehe auch: git help tutorial)"
 
-#: ref-filter.c:37
-#, c-format
-msgid "behind %d"
-msgstr "%d hinterher"
+#: help.c:24
+msgid "work on the current change (see also: git help everyday)"
+msgstr "an aktuellen Änderungen arbeiten (siehe auch: git help everyday)"
 
-#: ref-filter.c:38
-#, c-format
-msgid "ahead %d, behind %d"
-msgstr "%d voraus, %d hinterher"
+#: help.c:25
+msgid "examine the history and state (see also: git help revisions)"
+msgstr "Historie und Status untersuchen (siehe auch: git help revisions)"
 
-#: ref-filter.c:107
-#, c-format
-msgid "expected format: %%(color:<color>)"
-msgstr "Erwartetes Format: %%(color:<Farbe>)"
+#: help.c:26
+msgid "grow, mark and tweak your common history"
+msgstr "Historie erweitern und bearbeiten"
 
-#: ref-filter.c:109
-#, c-format
-msgid "unrecognized color: %%(color:%s)"
-msgstr "nicht erkannte Farbe: %%(color:%s)"
+#: help.c:27
+msgid "collaborate (see also: git help workflows)"
+msgstr "mit anderen zusammenarbeiten (siehe auch: git help workflows)"
 
-#: ref-filter.c:129
-#, c-format
-msgid "Integer value expected refname:lstrip=%s"
-msgstr "Positiver Wert erwartet refname:lstrip=%s"
+#: help.c:31
+msgid "Main Porcelain Commands"
+msgstr "Hauptbefehle"
+
+#: help.c:32
+msgid "Ancillary Commands / Manipulators"
+msgstr "Nebenbefehle / Manipulationen"
+
+#: help.c:33
+msgid "Ancillary Commands / Interrogators"
+msgstr "Nebenbefehle / Abfragen"
+
+#: help.c:34
+msgid "Interacting with Others"
+msgstr "mit anderen interagieren"
+
+#: help.c:35
+msgid "Low-level Commands / Manipulators"
+msgstr "Systembefehle / Manipulationen"
+
+#: help.c:36
+msgid "Low-level Commands / Interrogators"
+msgstr "Systembefehle / Abfragen"
+
+#: help.c:37
+msgid "Low-level Commands / Syncing Repositories"
+msgstr "Systembefehle / Repositories synchronisieren"
+
+#: help.c:38
+msgid "Low-level Commands / Internal Helpers"
+msgstr "Systembefehle / Interne Hilfsbefehle"
 
-#: ref-filter.c:133
+#: help.c:298
 #, c-format
-msgid "Integer value expected refname:rstrip=%s"
-msgstr "Positiver Wert erwartet refname:rstrip=%s"
+msgid "available git commands in '%s'"
+msgstr "Vorhandene Git-Befehle in '%s'"
 
-#: ref-filter.c:135
-#, c-format
-msgid "unrecognized %%(%s) argument: %s"
-msgstr "nicht erkanntes %%(%s) Argument: %s"
+#: help.c:305
+msgid "git commands available from elsewhere on your $PATH"
+msgstr "Vorhandene Git-Befehle anderswo in Ihrem $PATH"
 
-#: ref-filter.c:184
-#, c-format
-msgid "%%(body) does not take arguments"
-msgstr "%%(body) akzeptiert keine Argumente"
+#: help.c:314
+msgid "These are common Git commands used in various situations:"
+msgstr "Allgemeine Git-Befehle, verwendet in verschiedenen Situationen:"
 
-#: ref-filter.c:191
+#: help.c:363 git.c:98
 #, c-format
-msgid "%%(subject) does not take arguments"
-msgstr "%%(subject) akzeptiert keine Argumente"
+msgid "unsupported command listing type '%s'"
+msgstr "Nicht unterstützte Art zur Befehlsauflistung '%s'."
 
-#: ref-filter.c:209
-#, c-format
-msgid "unknown %%(trailers) argument: %s"
-msgstr "unbekanntes %%(trailers) Argument: %s"
+#: help.c:403
+msgid "The common Git guides are:"
+msgstr "Die allgemeinen Git-Anleitungen sind:"
 
-#: ref-filter.c:232
-#, c-format
-msgid "positive value expected contents:lines=%s"
-msgstr "Positiver Wert erwartet contents:lines=%s"
+#: help.c:512
+msgid "See 'git help <command>' to read about a specific subcommand"
+msgstr ""
+"Siehe 'git help <Befehl>', um mehr über einen spezifischen Unterbefehl zu "
+"lesen."
 
-#: ref-filter.c:234
-#, c-format
-msgid "unrecognized %%(contents) argument: %s"
-msgstr "nicht erkanntes %%(contents) Argument: %s"
+#: help.c:517
+msgid "External commands"
+msgstr "Externe Befehle"
 
-#: ref-filter.c:247
-#, c-format
-msgid "positive value expected objectname:short=%s"
-msgstr "Positiver Wert erwartet objectname:short=%s"
+#: help.c:532
+msgid "Command aliases"
+msgstr "Alias-Befehle"
 
-#: ref-filter.c:251
+#: help.c:596
 #, c-format
-msgid "unrecognized %%(objectname) argument: %s"
-msgstr "nicht erkanntes %%(objectname) Argument: %s"
+msgid ""
+"'%s' appears to be a git command, but we were not\n"
+"able to execute it. Maybe git-%s is broken?"
+msgstr ""
+"'%s' scheint ein git-Befehl zu sein, konnte aber\n"
+"nicht ausgeführt werden. Vielleicht ist git-%s fehlerhaft?"
 
-#: ref-filter.c:278
-#, c-format
-msgid "expected format: %%(align:<width>,<position>)"
-msgstr "Erwartetes Format: %%(align:<Breite>,<Position>)"
+#: help.c:655
+msgid "Uh oh. Your system reports no Git commands at all."
+msgstr "Uh oh. Keine Git-Befehle auf Ihrem System vorhanden."
 
-#: ref-filter.c:290
+#: help.c:677
 #, c-format
-msgid "unrecognized position:%s"
-msgstr "nicht erkannte Position:%s"
+msgid "WARNING: You called a Git command named '%s', which does not exist."
+msgstr ""
+"WARNUNG: Sie haben Git-Befehl '%s' ausgeführt, welcher nicht existiert."
 
-#: ref-filter.c:294
+#: help.c:682
 #, c-format
-msgid "unrecognized width:%s"
-msgstr "nicht erkannte Breite:%s"
+msgid "Continuing under the assumption that you meant '%s'."
+msgstr "Setze fort unter der Annahme, dass Sie '%s' meinten."
 
-#: ref-filter.c:300
+#: help.c:687
 #, c-format
-msgid "unrecognized %%(align) argument: %s"
-msgstr "nicht erkanntes %%(align) Argument: %s"
+msgid "Continuing in %0.1f seconds, assuming that you meant '%s'."
+msgstr "Setze in %0.1f Sekunden fort unter der Annahme, dass Sie '%s' meinten."
 
-#: ref-filter.c:304
+#: help.c:695
 #, c-format
-msgid "positive width expected with the %%(align) atom"
-msgstr "Positive Breitenangabe für %%(align) erwartet"
+msgid "git: '%s' is not a git command. See 'git --help'."
+msgstr "git: '%s' ist kein Git-Befehl. Siehe 'git --help'."
 
-#: ref-filter.c:319
-#, c-format
-msgid "unrecognized %%(if) argument: %s"
-msgstr "nicht erkanntes %%(if) Argument: %s"
+#: help.c:699
+msgid ""
+"\n"
+"The most similar command is"
+msgid_plural ""
+"\n"
+"The most similar commands are"
+msgstr[0] ""
+"\n"
+"Der ähnlichste Befehl ist"
+msgstr[1] ""
+"\n"
+"Die ähnlichsten Befehle sind"
 
-#: ref-filter.c:409
-#, c-format
-msgid "malformed field name: %.*s"
-msgstr "Fehlerhafter Feldname: %.*s"
+#: help.c:714
+msgid "git version [<options>]"
+msgstr "git version [<Optionen>]"
 
-#: ref-filter.c:435
+#: help.c:783
 #, c-format
-msgid "unknown field name: %.*s"
-msgstr "Unbekannter Feldname: %.*s"
+msgid "%s: %s - %s"
+msgstr "%s: %s - %s"
 
-#: ref-filter.c:547
-#, c-format
-msgid "format: %%(if) atom used without a %%(then) atom"
-msgstr "format: %%(if) Atom ohne ein %%(then) Atom verwendet"
+#: help.c:787
+msgid ""
+"\n"
+"Did you mean this?"
+msgid_plural ""
+"\n"
+"Did you mean one of these?"
+msgstr[0] ""
+"\n"
+"Haben Sie das gemeint?"
+msgstr[1] ""
+"\n"
+"Haben Sie eines von diesen gemeint?"
 
-#: ref-filter.c:607
-#, c-format
-msgid "format: %%(then) atom used without an %%(if) atom"
-msgstr "format: %%(then) Atom ohne ein %%(if) Atom verwendet"
+#: ident.c:349
+msgid ""
+"\n"
+"*** Please tell me who you are.\n"
+"\n"
+"Run\n"
+"\n"
+"  git config --global user.email \"you@example.com\"\n"
+"  git config --global user.name \"Your Name\"\n"
+"\n"
+"to set your account's default identity.\n"
+"Omit --global to set the identity only in this repository.\n"
+"\n"
+msgstr ""
+"\n"
+"*** Bitte geben Sie an, wer Sie sind.\n"
+"\n"
+"Führen Sie\n"
+"\n"
+"  git config --global user.email \"you@example.com\"\n"
+"  git config --global user.name \"Your Name\"\n"
+"\n"
+"aus, um das als Ihre standardmäßige Identität zu setzen.\n"
+"Lassen Sie die Option \"--global\" weg, um die Identität nur\n"
+"für dieses Repository zu setzen.\n"
 
-#: ref-filter.c:609
-#, c-format
-msgid "format: %%(then) atom used more than once"
-msgstr "format: %%(then) Atom mehr als einmal verwendet"
+#: ident.c:379
+msgid "no email was given and auto-detection is disabled"
+msgstr "keine E-Mail angegeben und automatische Erkennung ist deaktiviert"
 
-#: ref-filter.c:611
+#: ident.c:384
 #, c-format
-msgid "format: %%(then) atom used after %%(else)"
-msgstr "format: %%(then) Atom nach %%(else) verwendet"
+msgid "unable to auto-detect email address (got '%s')"
+msgstr "Konnte die E-Mail-Adresse nicht automatisch erkennen ('%s' erhalten)"
 
-#: ref-filter.c:637
-#, c-format
-msgid "format: %%(else) atom used without an %%(if) atom"
-msgstr "format: %%(else) Atom ohne ein %%(if) Atom verwendet"
+#: ident.c:401
+msgid "no name was given and auto-detection is disabled"
+msgstr "kein Name angegeben und automatische Erkennung ist deaktiviert"
 
-#: ref-filter.c:639
+#: ident.c:407
 #, c-format
-msgid "format: %%(else) atom used without a %%(then) atom"
-msgstr "Format: %%(else) Atom ohne ein %%(then) Atom verwendet"
+msgid "unable to auto-detect name (got '%s')"
+msgstr "konnte Namen nicht automatisch erkennen ('%s' erhalten)"
 
-#: ref-filter.c:641
+#: ident.c:415
 #, c-format
-msgid "format: %%(else) atom used more than once"
-msgstr "Format: %%(end) Atom mehr als einmal verwendet"
+msgid "empty ident name (for <%s>) not allowed"
+msgstr "Leerer Name in Identifikation (für <%s>) nicht erlaubt."
 
-#: ref-filter.c:654
+#: ident.c:421
 #, c-format
-msgid "format: %%(end) atom used without corresponding atom"
-msgstr "Format: %%(end) Atom ohne zugehöriges Atom verwendet"
+msgid "name consists only of disallowed characters: %s"
+msgstr "Name besteht nur aus nicht erlaubten Zeichen: %s"
 
-#: ref-filter.c:709
+#: ident.c:436 builtin/commit.c:631
 #, c-format
-msgid "malformed format string %s"
-msgstr "Fehlerhafter Formatierungsstring %s"
+msgid "invalid date format: %s"
+msgstr "Ungültiges Datumsformat: %s"
 
-#: ref-filter.c:1313
+#: list-objects.c:127
 #, c-format
-msgid "(no branch, rebasing %s)"
-msgstr "(kein Branch, Rebase von Branch %s im Gange)"
+msgid "entry '%s' in tree %s has tree mode, but is not a tree"
+msgstr ""
+"Eintrag '%s' im Tree-Objekt %s hat Tree-Modus, aber ist kein Tree-Objekt"
 
-#: ref-filter.c:1316
+#: list-objects.c:140
 #, c-format
-msgid "(no branch, bisect started on %s)"
-msgstr "(kein Branch, binäre Suche begonnen bei %s)"
+msgid "entry '%s' in tree %s has blob mode, but is not a blob"
+msgstr "Eintrag '%s' im Tree-Objekt %s hat Blob-Modus, aber ist kein Blob"
 
-#. TRANSLATORS: make sure this matches "HEAD
-#. detached at " in wt-status.c
-#.
-#: ref-filter.c:1324
+#: list-objects.c:375
 #, c-format
-msgid "(HEAD detached at %s)"
-msgstr "(HEAD losgelöst bei %s)"
+msgid "unable to load root tree for commit %s"
+msgstr "Konnte Root-Tree-Objekt für Commit %s nicht laden."
 
-#. TRANSLATORS: make sure this matches "HEAD
-#. detached from " in wt-status.c
-#.
-#: ref-filter.c:1331
+#: list-objects-filter.c:492
 #, c-format
-msgid "(HEAD detached from %s)"
-msgstr "(HEAD losgelöst von %s)"
-
-#: ref-filter.c:1335
-msgid "(no branch)"
-msgstr "(kein Branch)"
+msgid "unable to access sparse blob in '%s'"
+msgstr "konnte nicht auf partiellen Blob '%s' zugreifen"
 
-#: ref-filter.c:1364
+#: list-objects-filter.c:495
 #, c-format
-msgid "missing object %s for %s"
-msgstr "Objekt %s fehlt für %s"
+msgid "unable to parse sparse filter data in %s"
+msgstr "Konnte partielle Filter-Daten in %s nicht parsen."
 
-#: ref-filter.c:1367
-#, c-format
-msgid "parse_object_buffer failed on %s for %s"
-msgstr "parse_object_buffer bei %s für %s fehlgeschlagen"
+#: list-objects-filter-options.c:58
+msgid "expected 'tree:<depth>'"
+msgstr "'tree:<Tiefe>' erwartet"
 
-#: ref-filter.c:1819
-#, c-format
-msgid "malformed object at '%s'"
-msgstr "fehlerhaftes Objekt bei '%s'"
+#: list-objects-filter-options.c:73
+msgid "sparse:path filters support has been dropped"
+msgstr "Keine Unterstützung für sparse:path Filter mehr"
 
-#: ref-filter.c:1886
+#: list-objects-filter-options.c:86
 #, c-format
-msgid "ignoring ref with broken name %s"
-msgstr "Ignoriere Referenz mit fehlerhaftem Namen %s"
+msgid "invalid filter-spec '%s'"
+msgstr "Ungültige filter-spec '%s'"
 
-#: ref-filter.c:1891
+#: list-objects-filter-options.c:102
 #, c-format
-msgid "ignoring broken ref %s"
-msgstr "Ignoriere fehlerhafte Referenz %s"
+msgid "must escape char in sub-filter-spec: '%c'"
+msgstr "Zeichen in sub-filter-spec muss maskiert werden: '%c'"
 
-#: ref-filter.c:2152
-#, c-format
-msgid "format: %%(end) atom missing"
-msgstr "Format: %%(end) Atom fehlt"
+#: list-objects-filter-options.c:144
+msgid "expected something after combine:"
+msgstr "erwartete etwas nach 'combine:'"
 
-#: ref-filter.c:2246
-#, c-format
-msgid "malformed object name %s"
-msgstr "Missgebildeter Objektname %s"
+#: list-objects-filter-options.c:226
+msgid "multiple filter-specs cannot be combined"
+msgstr "Mehrere filter-specs können nicht kombiniert werden."
 
-#: remote.c:795
+#: lockfile.c:151
 #, c-format
-msgid "Cannot fetch both %s and %s to %s"
-msgstr "Kann 'fetch' nicht für sowohl %s als auch %s nach %s ausführen."
+msgid ""
+"Unable to create '%s.lock': %s.\n"
+"\n"
+"Another git process seems to be running in this repository, e.g.\n"
+"an editor opened by 'git commit'. Please make sure all processes\n"
+"are terminated then try again. If it still fails, a git process\n"
+"may have crashed in this repository earlier:\n"
+"remove the file manually to continue."
+msgstr ""
+"Konnte '%s.lock' nicht erstellen: %s.\n"
+"\n"
+"Ein anderer Git-Prozess scheint in diesem Repository ausgeführt\n"
+"zu werden, zum Beispiel ein noch offener Editor von 'git commit'.\n"
+"Bitte stellen Sie sicher, dass alle Prozesse beendet wurden und\n"
+"versuchen Sie es erneut. Falls es immer noch fehlschlägt, könnte\n"
+"ein früherer Git-Prozess in diesem Repository abgestürzt sein:\n"
+"Löschen Sie die Datei manuell um fortzufahren."
 
-#: remote.c:799
+#: lockfile.c:159
 #, c-format
-msgid "%s usually tracks %s, not %s"
-msgstr "%s folgt üblicherweise %s, nicht %s"
+msgid "Unable to create '%s.lock': %s"
+msgstr "Konnte '%s.lock' nicht erstellen: %s"
 
-#: remote.c:803
-#, c-format
-msgid "%s tracks both %s and %s"
-msgstr "%s folgt sowohl %s als auch %s"
+#: merge.c:41
+msgid "failed to read the cache"
+msgstr "Lesen des Zwischenspeichers fehlgeschlagen"
 
-#: remote.c:811
-msgid "Internal error"
-msgstr "Interner Fehler"
+#: merge.c:107 rerere.c:720 builtin/am.c:1874 builtin/am.c:1908
+#: builtin/checkout.c:539 builtin/checkout.c:798 builtin/clone.c:809
+#: builtin/stash.c:264
+msgid "unable to write new index file"
+msgstr "Konnte neue Index-Datei nicht schreiben."
 
-#: remote.c:1726 remote.c:1828
-msgid "HEAD does not point to a branch"
-msgstr "HEAD zeigt auf keinen Branch"
+#: merge-recursive.c:367
+msgid "(bad commit)\n"
+msgstr "(ungültiger Commit)\n"
 
-#: remote.c:1735
+#: merge-recursive.c:390
 #, c-format
-msgid "no such branch: '%s'"
-msgstr "Kein solcher Branch: '%s'"
+msgid "add_cacheinfo failed for path '%s'; merge aborting."
+msgstr "add_cacheinfo für Pfad '%s' fehlgeschlagen; Merge wird abgebrochen."
 
-#: remote.c:1738
+#: merge-recursive.c:399
 #, c-format
-msgid "no upstream configured for branch '%s'"
-msgstr "Kein Upstream-Branch für Branch '%s' konfiguriert."
+msgid "add_cacheinfo failed to refresh for path '%s'; merge aborting."
+msgstr ""
+"add_cacheinfo zur Aktualisierung für Pfad '%s' fehlgeschlagen;\n"
+"Merge wird abgebrochen."
 
-#: remote.c:1744
+#: merge-recursive.c:885
 #, c-format
-msgid "upstream branch '%s' not stored as a remote-tracking branch"
-msgstr "Upstream-Branch '%s' nicht als Remote-Tracking-Branch gespeichert"
+msgid "failed to create path '%s'%s"
+msgstr "Fehler beim Erstellen des Pfades '%s'%s"
 
-#: remote.c:1759
+#: merge-recursive.c:896
 #, c-format
-msgid "push destination '%s' on remote '%s' has no local tracking branch"
-msgstr ""
-"Ziel für \"push\" '%s' auf Remote-Repository '%s' hat keinen lokal gefolgten "
-"Branch"
+msgid "Removing %s to make room for subdirectory\n"
+msgstr "Entferne %s, um Platz für Unterverzeichnis zu schaffen\n"
 
-#: remote.c:1771
-#, c-format
-msgid "branch '%s' has no remote for pushing"
-msgstr "Branch '%s' hat keinen Upstream-Branch gesetzt"
+#: merge-recursive.c:910 merge-recursive.c:929
+msgid ": perhaps a D/F conflict?"
+msgstr ": vielleicht ein Verzeichnis/Datei-Konflikt?"
 
-#: remote.c:1782
+#: merge-recursive.c:919
 #, c-format
-msgid "push refspecs for '%s' do not include '%s'"
-msgstr "Push-Refspecs für '%s' beinhalten nicht '%s'"
+msgid "refusing to lose untracked file at '%s'"
+msgstr "verweigere, da unversionierte Dateien in '%s' verloren gehen würden"
 
-#: remote.c:1795
-msgid "push has no destination (push.default is 'nothing')"
-msgstr "kein Ziel für \"push\" (push.default ist 'nothing')"
+#: merge-recursive.c:960 builtin/cat-file.c:41
+#, c-format
+msgid "cannot read object %s '%s'"
+msgstr "kann Objekt %s '%s' nicht lesen"
 
-#: remote.c:1817
-msgid "cannot resolve 'simple' push to a single destination"
-msgstr "kann einzelnes Ziel für \"push\" im Modus 'simple' nicht auflösen"
+#: merge-recursive.c:965
+#, c-format
+msgid "blob expected for %s '%s'"
+msgstr "Blob erwartet für %s '%s'"
 
-#: remote.c:2132
+#: merge-recursive.c:990
 #, c-format
-msgid "Your branch is based on '%s', but the upstream is gone.\n"
-msgstr ""
-"Ihr Branch basiert auf '%s', aber der Upstream-Branch wurde entfernt.\n"
+msgid "failed to open '%s': %s"
+msgstr "Fehler beim Öffnen von '%s': %s"
 
-#: remote.c:2136
-msgid "  (use \"git branch --unset-upstream\" to fixup)\n"
-msgstr "  (benutzen Sie \"git branch --unset-upstream\" zum Beheben)\n"
+#: merge-recursive.c:1001
+#, c-format
+msgid "failed to symlink '%s': %s"
+msgstr "Fehler beim Erstellen einer symbolischen Verknüpfung für '%s': %s"
 
-#: remote.c:2139
+#: merge-recursive.c:1006
 #, c-format
-msgid "Your branch is up to date with '%s'.\n"
-msgstr "Ihr Branch ist auf demselben Stand wie '%s'.\n"
+msgid "do not know what to do with %06o %s '%s'"
+msgstr "weiß nicht was mit %06o %s '%s' zu machen ist"
 
-#: remote.c:2143
+#: merge-recursive.c:1199
 #, c-format
-msgid "Your branch and '%s' refer to different commits.\n"
-msgstr "Ihr Branch und '%s' zeigen auf unterschiedliche Commits.\n"
+msgid "Failed to merge submodule %s (not checked out)"
+msgstr "Fehler beim Merge von Submodul %s (nicht ausgecheckt)."
 
-#: remote.c:2146
+#: merge-recursive.c:1206
 #, c-format
-msgid "  (use \"%s\" for details)\n"
-msgstr "  (benutzen Sie \"%s\" für Details)\n"
+msgid "Failed to merge submodule %s (commits not present)"
+msgstr "Fehler beim Merge von Submodul %s (Commits nicht vorhanden)."
 
-#: remote.c:2150
+#: merge-recursive.c:1213
 #, c-format
-msgid "Your branch is ahead of '%s' by %d commit.\n"
-msgid_plural "Your branch is ahead of '%s' by %d commits.\n"
-msgstr[0] "Ihr Branch ist %2$d Commit vor '%1$s'.\n"
-msgstr[1] "Ihr Branch ist %2$d Commits vor '%1$s'.\n"
+msgid "Failed to merge submodule %s (commits don't follow merge-base)"
+msgstr "Fehler beim Merge von Submodul %s (Commits folgen keiner Merge-Basis)"
 
-#: remote.c:2156
-msgid "  (use \"git push\" to publish your local commits)\n"
-msgstr "  (benutzen Sie \"git push\", um lokale Commits zu publizieren)\n"
+#: merge-recursive.c:1221 merge-recursive.c:1233
+#, c-format
+msgid "Fast-forwarding submodule %s to the following commit:"
+msgstr "Spule Submodul %s zu dem folgenden Commit vor:"
 
-#: remote.c:2159
+#: merge-recursive.c:1224 merge-recursive.c:1236
 #, c-format
-msgid "Your branch is behind '%s' by %d commit, and can be fast-forwarded.\n"
-msgid_plural ""
-"Your branch is behind '%s' by %d commits, and can be fast-forwarded.\n"
-msgstr[0] ""
-"Ihr Branch ist %2$d Commit hinter '%1$s', und kann vorgespult werden.\n"
-msgstr[1] ""
-"Ihr Branch ist %2$d Commits hinter '%1$s', und kann vorgespult werden.\n"
+msgid "Fast-forwarding submodule %s"
+msgstr "Spule Submodul %s vor"
 
-#: remote.c:2167
-msgid "  (use \"git pull\" to update your local branch)\n"
+#: merge-recursive.c:1259
+#, c-format
+msgid "Failed to merge submodule %s (merge following commits not found)"
 msgstr ""
-"  (benutzen Sie \"git pull\", um Ihren lokalen Branch zu aktualisieren)\n"
+"Fehler beim Merge von Submodule %s (dem Merge nachfolgende Commits nicht "
+"gefunden)"
 
-#: remote.c:2170
+#: merge-recursive.c:1263
 #, c-format
-msgid ""
-"Your branch and '%s' have diverged,\n"
-"and have %d and %d different commit each, respectively.\n"
-msgid_plural ""
-"Your branch and '%s' have diverged,\n"
-"and have %d and %d different commits each, respectively.\n"
-msgstr[0] ""
-"Ihr Branch und '%s' sind divergiert,\n"
-"und haben jeweils %d und %d unterschiedliche Commits.\n"
-msgstr[1] ""
-"Ihr Branch und '%s' sind divergiert,\n"
-"und haben jeweils %d und %d unterschiedliche Commits.\n"
+msgid "Failed to merge submodule %s (not fast-forward)"
+msgstr "Fehler beim Merge von Submodul %s (kein Vorspulen)"
 
-#: remote.c:2180
-msgid "  (use \"git pull\" to merge the remote branch into yours)\n"
+#: merge-recursive.c:1264
+msgid "Found a possible merge resolution for the submodule:\n"
+msgstr "Mögliche Auflösung des Merges für Submodul gefunden:\n"
+
+#: merge-recursive.c:1267
+#, c-format
+msgid ""
+"If this is correct simply add it to the index for example\n"
+"by using:\n"
+"\n"
+"  git update-index --cacheinfo 160000 %s \"%s\"\n"
+"\n"
+"which will accept this suggestion.\n"
 msgstr ""
-"  (benutzen Sie \"git pull\", um Ihren Branch mit dem Remote-Branch "
-"zusammenzuführen)\n"
+"Falls das korrekt ist, fügen Sie es einfach der Staging-Area, zum Beispiel "
+"mit:\n"
+"\n"
+"  git update-index --cacheinfo 160000 %s \"%s\"\n"
+"\n"
+"hinzu, um diesen Vorschlag zu akzeptieren.\n"
 
-#: revision.c:2277
-msgid "your current branch appears to be broken"
-msgstr "Ihr aktueller Branch scheint fehlerhaft zu sein."
+#: merge-recursive.c:1276
+#, c-format
+msgid "Failed to merge submodule %s (multiple merges found)"
+msgstr "Fehler beim Merge von Submodul %s (mehrere Merges gefunden)"
 
-#: revision.c:2280
+#: merge-recursive.c:1349
+msgid "Failed to execute internal merge"
+msgstr "Fehler bei Ausführung des internen Merges"
+
+#: merge-recursive.c:1354
 #, c-format
-msgid "your current branch '%s' does not have any commits yet"
-msgstr "Ihr aktueller Branch '%s' hat noch keine Commits."
+msgid "Unable to add %s to database"
+msgstr "Konnte %s nicht zur Datenbank hinzufügen"
 
-#: revision.c:2477
-msgid "--first-parent is incompatible with --bisect"
-msgstr "Die Optionen --first-parent und --bisect sind inkompatibel."
+#: merge-recursive.c:1386
+#, c-format
+msgid "Auto-merging %s"
+msgstr "automatischer Merge von %s"
 
-#: run-command.c:731
-msgid "open /dev/null failed"
-msgstr "Öffnen von /dev/null fehlgeschlagen"
+#: merge-recursive.c:1410
+#, c-format
+msgid "Error: Refusing to lose untracked file at %s; writing to %s instead."
+msgstr ""
+"Fehler: Verweigere unversionierte Datei bei %s zu verlieren;\n"
+"schreibe stattdessen nach %s."
 
-#: run-command.c:1274
+#: merge-recursive.c:1482
 #, c-format
 msgid ""
-"The '%s' hook was ignored because it's not set as executable.\n"
-"You can disable this warning with `git config advice.ignoredHook false`."
+"CONFLICT (%s/delete): %s deleted in %s and %s in %s. Version %s of %s left "
+"in tree."
 msgstr ""
-"Der '%s' Hook wurde ignoriert, weil er nicht als ausführbar markiert ist.\n"
-"Sie können diese Warnung mit `git config advice.ignoredHook false` "
-"deaktivieren."
-
-#: send-pack.c:141
-msgid "unexpected flush packet while reading remote unpack status"
-msgstr "Unerwartetes Flush-Paket beim Lesen des Remote-Unpack-Status."
+"KONFLIKT (%s/löschen): %s gelöscht in %s und %s in %s. Stand %s von %s wurde "
+"im Arbeitsbereich gelassen."
 
-#: send-pack.c:143
+#: merge-recursive.c:1487
 #, c-format
-msgid "unable to parse remote unpack status: %s"
-msgstr "Konnte Status des Entpackens der Gegenseite nicht parsen: %s"
+msgid ""
+"CONFLICT (%s/delete): %s deleted in %s and %s to %s in %s. Version %s of %s "
+"left in tree."
+msgstr ""
+"KONFLIKT (%s/löschen): %s gelöscht in %s und %s nach %s in %s. Stand %s von "
+"%s wurde im Arbeitsbereich gelassen."
 
-#: send-pack.c:145
+#: merge-recursive.c:1494
 #, c-format
-msgid "remote unpack failed: %s"
-msgstr "Entpacken auf der Gegenseite fehlgeschlagen: %s"
-
-#: send-pack.c:308
-msgid "failed to sign the push certificate"
-msgstr "Fehler beim Signieren des \"push\"-Zertifikates"
-
-#: send-pack.c:421
-msgid "the receiving end does not support --signed push"
+msgid ""
+"CONFLICT (%s/delete): %s deleted in %s and %s in %s. Version %s of %s left "
+"in tree at %s."
 msgstr ""
-"die Gegenseite unterstützt keinen signierten Versand (\"--signed push\")"
+"KONFLIKT (%s/löschen): %s gelöscht in %s und %s in %s. Stand %s von %s wurde "
+"im Arbeitsbereich bei %s gelassen."
 
-#: send-pack.c:423
+#: merge-recursive.c:1499
+#, c-format
 msgid ""
-"not sending a push certificate since the receiving end does not support --"
-"signed push"
+"CONFLICT (%s/delete): %s deleted in %s and %s to %s in %s. Version %s of %s "
+"left in tree at %s."
 msgstr ""
-"kein Versand des \"push\"-Zertifikates, da die Gegenseite keinen signierten\n"
-"Versand (\"--signed push\") unterstützt"
+"KONFLIKT (%s/löschen): %s gelöscht in %s und %s nach %s in %s. Stand %s von "
+"%s wurde im Arbeitsbereich bei %s gelassen."
 
-#: send-pack.c:435
-msgid "the receiving end does not support --atomic push"
-msgstr "die Gegenseite unterstützt keinen atomaren Versand (\"--atomic push\")"
+#: merge-recursive.c:1534
+msgid "rename"
+msgstr "umbenennen"
 
-#: send-pack.c:440
-msgid "the receiving end does not support push options"
-msgstr "die Gegenseite unterstützt keine Push-Optionen"
+#: merge-recursive.c:1534
+msgid "renamed"
+msgstr "umbenannt"
 
-#: sequencer.c:158
+#: merge-recursive.c:1614 merge-recursive.c:2530 merge-recursive.c:3175
 #, c-format
-msgid "invalid commit message cleanup mode '%s'"
-msgstr "Ungültiger \"cleanup\"-Modus '%s' für Commit-Beschreibungen."
-
-#: sequencer.c:267
-msgid "revert"
-msgstr "Revert"
+msgid "Refusing to lose dirty file at %s"
+msgstr "Verweigere geänderte Datei bei %s zu verlieren."
 
-#: sequencer.c:269
-msgid "cherry-pick"
-msgstr "Cherry-Pick"
+#: merge-recursive.c:1624
+#, c-format
+msgid "Refusing to lose untracked file at %s, even though it's in the way."
+msgstr ""
+"Verweigere unversionierte Datei bei %s zu verlieren, auch wenn diese im Weg "
+"ist."
 
-#: sequencer.c:271
-msgid "rebase -i"
-msgstr "interaktives Rebase"
+#: merge-recursive.c:1682
+#, c-format
+msgid "CONFLICT (rename/add): Rename %s->%s in %s.  Added %s in %s"
+msgstr ""
+"KONFLIKT (umbenennen/hinzufügen): Benenne um %s->%s in %s. %s hinzugefügt in "
+"%s"
 
-#: sequencer.c:273
+#: merge-recursive.c:1713
 #, c-format
-msgid "Unknown action: %d"
-msgstr "Unbekannte Aktion: %d"
+msgid "%s is a directory in %s adding as %s instead"
+msgstr "%s ist ein Verzeichnis in %s, füge es stattdessen als %s hinzu"
 
-#: sequencer.c:330
-msgid ""
-"after resolving the conflicts, mark the corrected paths\n"
-"with 'git add <paths>' or 'git rm <paths>'"
+#: merge-recursive.c:1718
+#, c-format
+msgid "Refusing to lose untracked file at %s; adding as %s instead"
 msgstr ""
-"nach Auflösung der Konflikte markieren Sie die korrigierten Pfade\n"
-"mit 'git add <Pfade>' oder 'git rm <Pfade>'"
+"Verweigere unversionierte Datei bei %s zu verlieren; füge stattdessen %s "
+"hinzu"
 
-#: sequencer.c:333
+#: merge-recursive.c:1737
+#, c-format
 msgid ""
-"after resolving the conflicts, mark the corrected paths\n"
-"with 'git add <paths>' or 'git rm <paths>'\n"
-"and commit the result with 'git commit'"
+"CONFLICT (rename/rename): Rename \"%s\"->\"%s\" in branch \"%s\" rename \"%s"
+"\"->\"%s\" in \"%s\"%s"
 msgstr ""
-"nach Auflösung der Konflikte markieren Sie die korrigierten Pfade\n"
-"mit 'git add <Pfade>' oder 'git rm <Pfade>' und tragen Sie das Ergebnis mit\n"
-"'git commit' ein"
+"KONFLIKT (umbenennen/umbenennen): Benenne um \"%s\"->\"%s\" in Branch \"%s\" "
+"und \"%s\"->\"%s\" in Branch \"%s\"%s"
+
+#: merge-recursive.c:1742
+msgid " (left unresolved)"
+msgstr " (bleibt unaufgelöst)"
 
-#: sequencer.c:346 sequencer.c:2245
+#: merge-recursive.c:1851
 #, c-format
-msgid "could not lock '%s'"
-msgstr "Konnte '%s' nicht sperren"
+msgid "CONFLICT (rename/rename): Rename %s->%s in %s. Rename %s->%s in %s"
+msgstr ""
+"KONFLIKT (umbenennen/umbenennen): Benenne um %s->%s in %s. Benenne um %s->%s "
+"in %s"
 
-#: sequencer.c:349 sequencer.c:2124 sequencer.c:2250 sequencer.c:2264
-#: sequencer.c:3246 sequencer.c:3310 wrapper.c:656
+#: merge-recursive.c:2114
 #, c-format
-msgid "could not write to '%s'"
-msgstr "Konnte nicht nach '%s' schreiben."
+msgid ""
+"CONFLICT (directory rename split): Unclear where to place %s because "
+"directory %s was renamed to multiple other directories, with no destination "
+"getting a majority of the files."
+msgstr ""
+"KONFLIKT (Aufteilung Verzeichnisumbenennung): Unklar, wo %s zu platzieren "
+"ist,\n"
+"weil Verzeichnis %s zu mehreren anderen Verzeichnissen umbenannt wurde, "
+"wobei\n"
+"keines dieser Ziele die Mehrheit der Dateien erhielt."
 
-#: sequencer.c:353
+#: merge-recursive.c:2146
 #, c-format
-msgid "could not write eol to '%s'"
-msgstr "Konnte EOL nicht nach '%s' schreiben."
+msgid ""
+"CONFLICT (implicit dir rename): Existing file/dir at %s in the way of "
+"implicit directory rename(s) putting the following path(s) there: %s."
+msgstr ""
+"KONFLIKT (implizite Verzeichnisumbenennung): Existierende Datei/Pfad bei %s "
+"im\n"
+"Weg von impliziter Verzeichnisumbenennung, die versucht, einen oder mehrere\n"
+"Pfade dahin zu setzen: %s."
 
-#: sequencer.c:356 sequencer.c:2128 sequencer.c:2252
+#: merge-recursive.c:2156
 #, c-format
-msgid "failed to finalize '%s'"
-msgstr "Fehler beim Fertigstellen von '%s'."
+msgid ""
+"CONFLICT (implicit dir rename): Cannot map more than one path to %s; "
+"implicit directory renames tried to put these paths there: %s"
+msgstr ""
+"KONFLIKT (implizite Verzeichnisumbenennung): Kann nicht mehr als ein Pfad "
+"zu\n"
+"%s mappen; implizite Verzeichnisumbenennungen versuchten diese Pfade dahin\n"
+"zu setzen: %s"
 
-#: sequencer.c:379 sequencer.c:1340 sequencer.c:2148 builtin/am.c:259
-#: builtin/commit.c:722 builtin/merge.c:1047
+#: merge-recursive.c:2248
 #, c-format
-msgid "could not read '%s'"
-msgstr "Konnte '%s' nicht lesen"
+msgid ""
+"CONFLICT (rename/rename): Rename directory %s->%s in %s. Rename directory %s-"
+">%s in %s"
+msgstr ""
+"KONFLIKT (umbenennen/umbenennen): Benenne Verzeichnis um %s->%s in %s.\n"
+"Benenne Verzeichnis um %s->%s in %s"
 
-#: sequencer.c:405
+#: merge-recursive.c:2493
 #, c-format
-msgid "your local changes would be overwritten by %s."
-msgstr "Ihre lokalen Änderungen würden durch den %s überschrieben werden."
-
-#: sequencer.c:409
-msgid "commit your changes or stash them to proceed."
+msgid ""
+"WARNING: Avoiding applying %s -> %s rename to %s, because %s itself was "
+"renamed."
 msgstr ""
-"Committen Sie Ihre Änderungen oder benutzen Sie \"stash\", um fortzufahren."
+"WARNUNG: Vermeide Umbenennung %s -> %s von %s, weil %s selbst umbenannt "
+"wurde."
 
-#: sequencer.c:438
+#: merge-recursive.c:3019
 #, c-format
-msgid "%s: fast-forward"
-msgstr "%s: Vorspulen"
+msgid "cannot read object %s"
+msgstr "kann Objekt %s nicht lesen"
 
-#. TRANSLATORS: %s will be "revert", "cherry-pick" or
-#. "rebase -i".
-#.
-#: sequencer.c:526
+#: merge-recursive.c:3022
 #, c-format
-msgid "%s: Unable to write new index file"
-msgstr "%s: Konnte neue Index-Datei nicht schreiben"
+msgid "object %s is not a blob"
+msgstr "Objekt %s ist kein Blob"
 
-#: sequencer.c:542
-msgid "could not resolve HEAD commit"
-msgstr "Konnte HEAD-Commit nicht auflösen."
+#: merge-recursive.c:3086
+msgid "modify"
+msgstr "ändern"
 
-#: sequencer.c:562
-msgid "unable to update cache tree"
-msgstr "Konnte Cache-Verzeichnis nicht aktualisieren."
+#: merge-recursive.c:3086
+msgid "modified"
+msgstr "geändert"
+
+#: merge-recursive.c:3098
+msgid "content"
+msgstr "Inhalt"
+
+#: merge-recursive.c:3102
+msgid "add/add"
+msgstr "hinzufügen/hinzufügen"
+
+#: merge-recursive.c:3125
+#, c-format
+msgid "Skipped %s (merged same as existing)"
+msgstr "%s ausgelassen (Ergebnis des Merges existiert bereits)"
+
+#: merge-recursive.c:3147 git-submodule.sh:993
+msgid "submodule"
+msgstr "Submodul"
+
+#: merge-recursive.c:3148
+#, c-format
+msgid "CONFLICT (%s): Merge conflict in %s"
+msgstr "KONFLIKT (%s): Merge-Konflikt in %s"
+
+#: merge-recursive.c:3178
+#, c-format
+msgid "Adding as %s instead"
+msgstr "Füge stattdessen als %s hinzu"
 
-#: sequencer.c:658
+#: merge-recursive.c:3261
 #, c-format
 msgid ""
-"you have staged changes in your working tree\n"
-"If these changes are meant to be squashed into the previous commit, run:\n"
-"\n"
-"  git commit --amend %s\n"
-"\n"
-"If they are meant to go into a new commit, run:\n"
-"\n"
-"  git commit %s\n"
-"\n"
-"In both cases, once you're done, continue with:\n"
-"\n"
-"  git rebase --continue\n"
+"Path updated: %s added in %s inside a directory that was renamed in %s; "
+"moving it to %s."
 msgstr ""
-"Es befinden sich zum Commit vorgemerkte Änderungen in Ihrem "
-"Arbeitsverzeichnis.\n"
-"Wenn diese Änderungen in den vorherigen Commit aufgenommen werden sollen,\n"
-"führen Sie aus:\n"
-"\n"
-"  git commit --amend %s\n"
-"\n"
-"Wenn daraus ein neuer Commit erzeugt werden soll, führen Sie aus:\n"
-"\n"
-"  git commit %s\n"
-"\n"
-"Im Anschluss führen Sie zum Fortfahren aus:\n"
-"\n"
-"  git rebase --continue\n"
-
-#: sequencer.c:915
-msgid "'prepare-commit-msg' hook failed"
-msgstr "'prepare-commit-msg' Hook fehlgeschlagen."
+"Pfad aktualisiert: %s hinzugefügt in %s innerhalb eines Verzeichnisses, das "
+"umbenannt wurde in %s; Verschiebe es nach %s."
 
-#: sequencer.c:922
+#: merge-recursive.c:3264
+#, c-format
 msgid ""
-"Your name and email address were configured automatically based\n"
-"on your username and hostname. Please check that they are accurate.\n"
-"You can suppress this message by setting them explicitly. Run the\n"
-"following command and follow the instructions in your editor to edit\n"
-"your configuration file:\n"
-"\n"
-"    git config --global --edit\n"
-"\n"
-"After doing this, you may fix the identity used for this commit with:\n"
-"\n"
-"    git commit --amend --reset-author\n"
+"CONFLICT (file location): %s added in %s inside a directory that was renamed "
+"in %s, suggesting it should perhaps be moved to %s."
 msgstr ""
-"Ihr Name und E-Mail Adresse wurden automatisch auf Basis\n"
-"Ihres Benutzer- und Rechnernamens konfiguriert. Bitte prüfen Sie, dass\n"
-"diese zutreffend sind. Sie können diese Meldung unterdrücken, indem Sie\n"
-"diese explizit setzen. Führen Sie dazu den folgenden Befehl aus und folgen\n"
-"Sie den Anweisungen in Ihrem Editor, um die Konfigurationsdatei zu "
-"bearbeiten:\n"
-"\n"
-"    git config --global --edit\n"
-"\n"
-"Nachdem Sie das getan haben, können Sie Ihre Identität für diesen Commit\n"
-"ändern mit:\n"
-"\n"
-"    git commit --amend --reset-author\n"
+"KONFLIKT (Speicherort): %s hinzugefügt in %s innerhalb eines Verzeichnisses, "
+"das umbenannt wurde in %s, es sollte vielleicht nach %s verschoben werden."
 
-#: sequencer.c:935
+#: merge-recursive.c:3268
+#, c-format
 msgid ""
-"Your name and email address were configured automatically based\n"
-"on your username and hostname. Please check that they are accurate.\n"
-"You can suppress this message by setting them explicitly:\n"
-"\n"
-"    git config --global user.name \"Your Name\"\n"
-"    git config --global user.email you@example.com\n"
-"\n"
-"After doing this, you may fix the identity used for this commit with:\n"
-"\n"
-"    git commit --amend --reset-author\n"
+"Path updated: %s renamed to %s in %s, inside a directory that was renamed in "
+"%s; moving it to %s."
 msgstr ""
-"Ihr Name und E-Mail Adresse wurden automatisch auf Basis\n"
-"Ihres Benutzer- und Rechnernamens konfiguriert. Bitte prüfen Sie, dass\n"
-"diese zutreffend sind. Sie können diese Meldung unterdrücken, indem Sie\n"
-"diese explizit setzen:\n"
-"\n"
-"    git config --global user.name \"Ihr Name\"\n"
-"    git config --global user.email ihre@emailadresse.de\n"
-"\n"
-"Nachdem Sie das getan haben, können Sie Ihre Identität für diesen Commit "
-"ändern:\n"
-"\n"
-"    git commit --amend --reset-author\n"
+"Pfad aktualisiert: %s umbenannt nach %s in %s, innerhalb eines "
+"Verzeichnisses, das umbenannt wurde in %s; Verschiebe es nach %s."
 
-#: sequencer.c:975
-msgid "couldn't look up newly created commit"
-msgstr "Konnte neu erstellten Commit nicht nachschlagen."
+#: merge-recursive.c:3271
+#, c-format
+msgid ""
+"CONFLICT (file location): %s renamed to %s in %s, inside a directory that "
+"was renamed in %s, suggesting it should perhaps be moved to %s."
+msgstr ""
+"KONFLIKT (Speicherort): %s umbenannt nach %s in %s, innerhalb eines "
+"Verzeichnisses, das umbenannt wurde in %s, es sollte vielleicht nach %s "
+"verschoben werden."
 
-#: sequencer.c:977
-msgid "could not parse newly created commit"
-msgstr "Konnte neu erstellten Commit nicht analysieren."
+#: merge-recursive.c:3385
+#, c-format
+msgid "Removing %s"
+msgstr "Entferne %s"
 
-#: sequencer.c:1023
-msgid "unable to resolve HEAD after creating commit"
-msgstr "Konnte HEAD nicht auflösen, nachdem der Commit erstellt wurde."
+#: merge-recursive.c:3408
+msgid "file/directory"
+msgstr "Datei/Verzeichnis"
 
-#: sequencer.c:1025
-msgid "detached HEAD"
-msgstr "losgelöster HEAD"
+#: merge-recursive.c:3413
+msgid "directory/file"
+msgstr "Verzeichnis/Datei"
 
-#: sequencer.c:1029
-msgid " (root-commit)"
-msgstr " (Basis-Commit)"
+#: merge-recursive.c:3420
+#, c-format
+msgid "CONFLICT (%s): There is a directory with name %s in %s. Adding %s as %s"
+msgstr ""
+"KONFLIKT (%s): Es existiert bereits ein Verzeichnis %s in %s. Füge %s als %s "
+"hinzu."
 
-#: sequencer.c:1050
-msgid "could not parse HEAD"
-msgstr "Konnte HEAD nicht parsen."
+#: merge-recursive.c:3429
+#, c-format
+msgid "Adding %s"
+msgstr "Füge %s hinzu"
 
-#: sequencer.c:1052
+#: merge-recursive.c:3438
 #, c-format
-msgid "HEAD %s is not a commit!"
-msgstr "HEAD %s ist kein Commit!"
+msgid "CONFLICT (add/add): Merge conflict in %s"
+msgstr "KONFLIKT (hinzufügen/hinzufügen): Merge-Konflikt in %s"
 
-#: sequencer.c:1056 builtin/commit.c:1491
-msgid "could not parse HEAD commit"
-msgstr "Konnte Commit von HEAD nicht analysieren."
+#: merge-recursive.c:3482
+msgid "Already up to date!"
+msgstr "Bereits aktuell!"
 
-#: sequencer.c:1107 sequencer.c:1673
-msgid "unable to parse commit author"
-msgstr "Konnte Commit-Autor nicht parsen."
+#: merge-recursive.c:3491
+#, c-format
+msgid "merging of trees %s and %s failed"
+msgstr "Zusammenführen der \"Tree\"-Objekte %s und %s fehlgeschlagen"
 
-#: sequencer.c:1117 builtin/am.c:1630 builtin/merge.c:643
-msgid "git write-tree failed to write a tree"
-msgstr "\"git write-tree\" schlug beim Schreiben eines \"Tree\"-Objektes fehl"
+#: merge-recursive.c:3595
+msgid "Merging:"
+msgstr "Merge:"
 
-#: sequencer.c:1134 sequencer.c:1186
+#: merge-recursive.c:3608
 #, c-format
-msgid "unable to read commit message from '%s'"
-msgstr "Konnte Commit-Beschreibung von '%s' nicht lesen."
+msgid "found %u common ancestor:"
+msgid_plural "found %u common ancestors:"
+msgstr[0] "%u gemeinsamen Vorgänger-Commit gefunden"
+msgstr[1] "%u gemeinsame Vorgänger-Commits gefunden"
 
-#: sequencer.c:1154 builtin/am.c:1650 builtin/commit.c:1594 builtin/merge.c:826
-#: builtin/merge.c:851
-msgid "failed to write commit object"
-msgstr "Fehler beim Schreiben des Commit-Objektes."
+#: merge-recursive.c:3658
+msgid "merge returned no commit"
+msgstr "Merge hat keinen Commit zurückgegeben"
 
-#: sequencer.c:1213
+#: merge-recursive.c:3717
 #, c-format
-msgid "could not parse commit %s"
-msgstr "Konnte Commit %s nicht parsen."
+msgid ""
+"Your local changes to the following files would be overwritten by merge:\n"
+"  %s"
+msgstr ""
+"Ihre lokalen Änderungen in den folgenden Dateien würden durch den Merge\n"
+"überschrieben werden:\n"
+"  %s"
 
-#: sequencer.c:1218
+#: merge-recursive.c:3814
 #, c-format
-msgid "could not parse parent commit %s"
-msgstr "Konnte Eltern-Commit %s nicht parsen."
+msgid "Could not parse object '%s'"
+msgstr "Konnte Objekt '%s' nicht parsen."
 
-#: sequencer.c:1347
+#: merge-recursive.c:3832 builtin/merge.c:694 builtin/merge.c:874
+msgid "Unable to write index."
+msgstr "Konnte Index nicht schreiben."
+
+#: midx.c:68
 #, c-format
-msgid ""
-"unexpected 1st line of squash message:\n"
-"\n"
-"\t%.*s"
-msgstr ""
-"unerwartete erste Zeile der Squash-Beschreibung:\n"
-"\n"
-"\t%.*s"
+msgid "multi-pack-index file %s is too small"
+msgstr "multi-pack-index-Datei %s ist zu klein."
 
-#: sequencer.c:1353
+#: midx.c:84
 #, c-format
-msgid ""
-"invalid 1st line of squash message:\n"
-"\n"
-"\t%.*s"
+msgid "multi-pack-index signature 0x%08x does not match signature 0x%08x"
 msgstr ""
-"ungültige erste Zeile der Squash-Beschreibung:\n"
-"\n"
-"\t%.*s"
+"multi-pack-index-Signatur 0x%08x stimmt nicht mit Signatur 0x%08x überein."
 
-#: sequencer.c:1359 sequencer.c:1384
+#: midx.c:89
 #, c-format
-msgid "This is a combination of %d commits."
-msgstr "Das ist eine Kombination aus %d Commits."
+msgid "multi-pack-index version %d not recognized"
+msgstr "multi-pack-index-Version %d nicht erkannt."
 
-#: sequencer.c:1368 sequencer.c:3265
-msgid "need a HEAD to fixup"
-msgstr "benötige HEAD für fixup"
+#: midx.c:94
+#, c-format
+msgid "hash version %u does not match"
+msgstr "Hash-Version %u stimmt nicht überein."
 
-#: sequencer.c:1370
-msgid "could not read HEAD"
-msgstr "Konnte HEAD nicht lesen"
+#: midx.c:108
+msgid "invalid chunk offset (too large)"
+msgstr "Ungültiger Chunk-Offset (zu groß)"
 
-#: sequencer.c:1372
-msgid "could not read HEAD's commit message"
-msgstr "Konnte Commit-Beschreibung von HEAD nicht lesen"
+#: midx.c:132
+msgid "terminating multi-pack-index chunk id appears earlier than expected"
+msgstr "Abschließende multi-pack-index Chunk-Id erscheint eher als erwartet."
 
-#: sequencer.c:1378
-#, c-format
-msgid "cannot write '%s'"
-msgstr "kann '%s' nicht schreiben"
+#: midx.c:145
+msgid "multi-pack-index missing required pack-name chunk"
+msgstr "multi-pack-index fehlt erforderlicher pack-name Chunk."
 
-#: sequencer.c:1387 git-rebase--interactive.sh:452
-msgid "This is the 1st commit message:"
-msgstr "Das ist die erste Commit-Beschreibung:"
+#: midx.c:147
+msgid "multi-pack-index missing required OID fanout chunk"
+msgstr "multi-pack-index fehlt erforderlicher OID fanout Chunk."
 
-#: sequencer.c:1395
-#, c-format
-msgid "could not read commit message of %s"
-msgstr "Konnte Commit-Beschreibung von %s nicht lesen."
+#: midx.c:149
+msgid "multi-pack-index missing required OID lookup chunk"
+msgstr "multi-pack-index fehlt erforderlicher OID lookup Chunk."
 
-#: sequencer.c:1402
-#, c-format
-msgid "This is the commit message #%d:"
-msgstr "Das ist Commit-Beschreibung #%d:"
+#: midx.c:151
+msgid "multi-pack-index missing required object offsets chunk"
+msgstr "multi-pack-index fehlt erforderlicher object offset Chunk."
 
-#: sequencer.c:1407
+#: midx.c:165
 #, c-format
-msgid "The commit message #%d will be skipped:"
-msgstr "Die Commit-Beschreibung #%d wird ausgelassen:"
+msgid "multi-pack-index pack names out of order: '%s' before '%s'"
+msgstr "Falsche Reihenfolge bei multi-pack-index Pack-Namen: '%s' vor '%s'"
 
-#: sequencer.c:1412
+#: midx.c:210
 #, c-format
-msgid "unknown command: %d"
-msgstr "Unbekannter Befehl: %d"
+msgid "bad pack-int-id: %u (%u total packs)"
+msgstr "Ungültige pack-int-id: %u (%u Pakete insgesamt)"
 
-#: sequencer.c:1479
-msgid "your index file is unmerged."
-msgstr "Ihre Index-Datei ist nicht zusammengeführt."
+#: midx.c:260
+msgid "multi-pack-index stores a 64-bit offset, but off_t is too small"
+msgstr ""
+"multi-pack-index speichert einen 64-Bit Offset, aber off_t ist zu klein."
 
-#: sequencer.c:1498
-#, c-format
-msgid "commit %s is a merge but no -m option was given."
-msgstr "Commit %s ist ein Merge, aber die Option -m wurde nicht angegeben."
+#: midx.c:288
+msgid "error preparing packfile from multi-pack-index"
+msgstr "Fehler bei Vorbereitung der Packdatei aus multi-pack-index."
 
-#: sequencer.c:1506
+#: midx.c:472
 #, c-format
-msgid "commit %s does not have parent %d"
-msgstr "Commit %s hat keinen Eltern-Commit %d"
+msgid "failed to add packfile '%s'"
+msgstr "Fehler beim Hinzufügen von Packdatei '%s'."
 
-#: sequencer.c:1510
+#: midx.c:478
 #, c-format
-msgid "mainline was specified but commit %s is not a merge."
-msgstr "Hauptlinie wurde spezifiziert, aber Commit %s ist kein Merge."
+msgid "failed to open pack-index '%s'"
+msgstr "Fehler beim Öffnen von pack-index '%s'"
 
-#: sequencer.c:1516
+#: midx.c:538
 #, c-format
-msgid "cannot get commit message for %s"
-msgstr "Kann keine Commit-Beschreibung für %s bekommen."
+msgid "failed to locate object %d in packfile"
+msgstr "Fehler beim Lokalisieren von Objekt %d in Packdatei."
 
-#. TRANSLATORS: The first %s will be a "todo" command like
-#. "revert" or "pick", the second %s a SHA1.
-#: sequencer.c:1535
+#: midx.c:842
+msgid "Adding packfiles to multi-pack-index"
+msgstr "Packdateien zum multi-pack-index hinzufügen"
+
+#: midx.c:875
 #, c-format
-msgid "%s: cannot parse parent commit %s"
-msgstr "%s: kann Eltern-Commit %s nicht parsen"
+msgid "did not see pack-file %s to drop"
+msgstr "Pack-Datei %s zum Weglassen nicht gefunden"
+
+#: midx.c:973
+msgid "Writing chunks to multi-pack-index"
+msgstr "Chunks zum multi-pack-index schreiben"
 
-#: sequencer.c:1600 sequencer.c:2397
+#: midx.c:1052
 #, c-format
-msgid "could not rename '%s' to '%s'"
-msgstr "Konnte '%s' nicht zu '%s' umbenennen."
+msgid "failed to clear multi-pack-index at %s"
+msgstr "Fehler beim Löschen des multi-pack-index bei %s"
 
-#: sequencer.c:1654
+#: midx.c:1108
+msgid "Looking for referenced packfiles"
+msgstr "Suche nach referenzierten Pack-Dateien"
+
+#: midx.c:1123
 #, c-format
-msgid "could not revert %s... %s"
-msgstr "Konnte \"revert\" nicht auf %s... (%s) ausführen"
+msgid ""
+"oid fanout out of order: fanout[%d] = %<PRIx32> > %<PRIx32> = fanout[%d]"
+msgstr ""
+"Ungültige oid fanout Reihenfolge: fanout[%d] = %<PRIx32> > %<PRIx32> = "
+"fanout[%d]"
+
+#: midx.c:1128
+msgid "Verifying OID order in multi-pack-index"
+msgstr "Verifiziere OID-Reihenfolge im multi-pack-index"
 
-#: sequencer.c:1655
+#: midx.c:1137
 #, c-format
-msgid "could not apply %s... %s"
-msgstr "Konnte %s... (%s) nicht anwenden"
+msgid "oid lookup out of order: oid[%d] = %s >= %s = oid[%d]"
+msgstr "Ungültige oid lookup Reihenfolge: oid[%d] = %s >= %s = oid[%d]"
 
-#: sequencer.c:1702
-msgid "empty commit set passed"
-msgstr "leere Menge von Commits übergeben"
+#: midx.c:1157
+msgid "Sorting objects by packfile"
+msgstr "Sortiere Objekte nach Pack-Datei"
 
-#: sequencer.c:1712
+#: midx.c:1164
+msgid "Verifying object offsets"
+msgstr "Überprüfe Objekt-Offsets"
+
+#: midx.c:1180
 #, c-format
-msgid "git %s: failed to read the index"
-msgstr "git %s: Fehler beim Lesen des Index"
+msgid "failed to load pack entry for oid[%d] = %s"
+msgstr "Fehler beim Laden des Pack-Eintrags für oid[%d] = %s"
 
-#: sequencer.c:1718
+#: midx.c:1186
 #, c-format
-msgid "git %s: failed to refresh the index"
-msgstr "git %s: Fehler beim Aktualisieren des Index"
+msgid "failed to load pack-index for packfile %s"
+msgstr "Fehler beim Laden des Pack-Index für Packdatei %s"
 
-#: sequencer.c:1792
+#: midx.c:1195
 #, c-format
-msgid "%s does not accept arguments: '%s'"
-msgstr "%s akzeptiert keine Argumente: '%s'"
+msgid "incorrect object offset for oid[%d] = %s: %<PRIx64> != %<PRIx64>"
+msgstr "Falscher Objekt-Offset für oid[%d] = %s: %<PRIx64> != %<PRIx64>"
 
-#: sequencer.c:1801
-#, c-format
-msgid "missing arguments for %s"
-msgstr "Fehlende Argumente für %s."
+#: midx.c:1220
+msgid "Counting referenced objects"
+msgstr "Referenzierte Objekte zählen"
 
-#: sequencer.c:1844
+#: midx.c:1230
+msgid "Finding and deleting unreferenced packfiles"
+msgstr "Suchen und Löschen von unreferenzierten Pack-Dateien"
+
+#: midx.c:1388
+msgid "could not start pack-objects"
+msgstr "Konnte 'pack-objects' nicht ausführen"
+
+#: midx.c:1407
+msgid "could not finish pack-objects"
+msgstr "Konnte 'pack-objects' nicht beenden"
+
+#: name-hash.c:537
 #, c-format
-msgid "invalid line %d: %.*s"
-msgstr "Ungültige Zeile %d: %.*s"
+msgid "unable to create lazy_dir thread: %s"
+msgstr "Kann lazy_dir Thread nicht erzeugen: %s"
 
-#: sequencer.c:1852
+#: name-hash.c:559
 #, c-format
-msgid "cannot '%s' without a previous commit"
-msgstr "Kann '%s' nicht ohne vorherigen Commit ausführen"
+msgid "unable to create lazy_name thread: %s"
+msgstr "Kann lazy_name Thread nicht erzeugen: %s"
 
-#: sequencer.c:1883 sequencer.c:3056 sequencer.c:3091
+#: name-hash.c:565
 #, c-format
-msgid "could not read '%s'."
-msgstr "Konnte '%s' nicht lesen."
+msgid "unable to join lazy_name thread: %s"
+msgstr "Kann lazy_name Thread nicht beitreten: %s"
 
-#: sequencer.c:1906
-msgid "please fix this using 'git rebase --edit-todo'."
+#: notes-merge.c:277
+#, c-format
+msgid ""
+"You have not concluded your previous notes merge (%s exists).\n"
+"Please, use 'git notes merge --commit' or 'git notes merge --abort' to "
+"commit/abort the previous merge before you start a new notes merge."
 msgstr ""
-"Bitte beheben Sie dieses, indem Sie 'git rebase --edit-todo' ausführen."
+"Sie haben Ihren vorherigen Merge von Notizen nicht abgeschlossen (%s "
+"existiert).\n"
+"Bitte benutzen Sie 'git notes merge --commit' oder 'git notes merge --"
+"abort', um\n"
+"den vorherigen Merge zu committen bzw. abzubrechen, bevor Sie einen neuen "
+"Merge\n"
+"von Notizen beginnen."
 
-#: sequencer.c:1908
+#: notes-merge.c:284
 #, c-format
-msgid "unusable instruction sheet: '%s'"
-msgstr "Unbenutzbares Instruktionsblatt: '%s'"
+msgid "You have not concluded your notes merge (%s exists)."
+msgstr "Sie haben Ihren Merge von Notizen nicht abgeschlossen (%s existiert)."
 
-#: sequencer.c:1913
-msgid "no commits parsed."
-msgstr "Keine Commits geparst."
+#: notes-utils.c:46
+msgid "Cannot commit uninitialized/unreferenced notes tree"
+msgstr ""
+"Kann uninitialisiertes/unreferenziertes Notiz-Verzeichnis nicht committen."
 
-#: sequencer.c:1924
-msgid "cannot cherry-pick during a revert."
-msgstr "Kann Cherry-Pick nicht während eines Reverts ausführen."
+#: notes-utils.c:105
+#, c-format
+msgid "Bad notes.rewriteMode value: '%s'"
+msgstr "Ungültiger notes.rewriteMode Wert: '%s'"
 
-#: sequencer.c:1926
-msgid "cannot revert during a cherry-pick."
-msgstr "Kann Revert nicht während eines Cherry-Picks ausführen."
+#: notes-utils.c:115
+#, c-format
+msgid "Refusing to rewrite notes in %s (outside of refs/notes/)"
+msgstr ""
+"Umschreiben der Notizen in %s zurückgewiesen (außerhalb von refs/notes/)"
 
-#: sequencer.c:1993
+#. TRANSLATORS: The first %s is the name of
+#. the environment variable, the second %s is
+#. its value.
+#.
+#: notes-utils.c:145
 #, c-format
-msgid "invalid key: %s"
-msgstr "Ungültiger Schlüssel: %s"
+msgid "Bad %s value: '%s'"
+msgstr "Ungültiger %s Wert: '%s'"
 
-#: sequencer.c:1996
+#: object.c:53
 #, c-format
-msgid "invalid value for %s: %s"
-msgstr "Ungültiger Wert für %s: %s"
+msgid "invalid object type \"%s\""
+msgstr "Ungültiger Objekttyp \"%s\""
 
-#: sequencer.c:2062
+#: object.c:173
 #, c-format
-msgid "malformed options sheet: '%s'"
-msgstr "Fehlerhaftes Optionsblatt: '%s'"
+msgid "object %s is a %s, not a %s"
+msgstr "Objekt %s ist ein %s, kein %s"
 
-#: sequencer.c:2100
-msgid "a cherry-pick or revert is already in progress"
-msgstr "\"cherry-pick\" oder \"revert\" ist bereits im Gang"
-
-#: sequencer.c:2101
-msgid "try \"git cherry-pick (--continue | --quit | --abort)\""
-msgstr "versuchen Sie \"git cherry-pick (--continue | --quit | --abort)\""
+#: object.c:233
+#, c-format
+msgid "object %s has unknown type id %d"
+msgstr "Objekt %s hat eine unbekannte Typ-Identifikation %d"
 
-#: sequencer.c:2104
+#: object.c:246
 #, c-format
-msgid "could not create sequencer directory '%s'"
-msgstr "Konnte \"sequencer\"-Verzeichnis '%s' nicht erstellen."
+msgid "unable to parse object: %s"
+msgstr "Konnte Objekt '%s' nicht parsen."
 
-#: sequencer.c:2118
-msgid "could not lock HEAD"
-msgstr "Konnte HEAD nicht sperren"
+#: object.c:266 object.c:277
+#, c-format
+msgid "hash mismatch %s"
+msgstr "Hash stimmt nicht mit %s überein."
 
-#: sequencer.c:2173 sequencer.c:2761
-msgid "no cherry-pick or revert in progress"
-msgstr "kein \"cherry-pick\" oder \"revert\" im Gang"
+#: packfile.c:641
+msgid "offset before end of packfile (broken .idx?)"
+msgstr "Offset vor Ende der Packdatei (fehlerhafte Indexdatei?)"
 
-#: sequencer.c:2175
-msgid "cannot resolve HEAD"
-msgstr "kann HEAD nicht auflösen"
+#: packfile.c:1888
+#, c-format
+msgid "offset before start of pack index for %s (corrupt index?)"
+msgstr "Offset vor Beginn des Pack-Index für %s (beschädigter Index?)"
 
-#: sequencer.c:2177 sequencer.c:2212
-msgid "cannot abort from a branch yet to be born"
-msgstr "kann nicht abbrechen: bin auf einem Branch, der noch nicht geboren ist"
+#: packfile.c:1892
+#, c-format
+msgid "offset beyond end of pack index for %s (truncated index?)"
+msgstr "Offset hinter Ende des Pack-Index für %s (abgeschnittener Index?)"
 
-#: sequencer.c:2198 builtin/grep.c:720
+#: parse-options.c:38
 #, c-format
-msgid "cannot open '%s'"
-msgstr "kann '%s' nicht öffnen"
+msgid "%s requires a value"
+msgstr "%s erfordert einen Wert."
 
-#: sequencer.c:2200
+#: parse-options.c:73
 #, c-format
-msgid "cannot read '%s': %s"
-msgstr "Kann '%s' nicht lesen: %s"
+msgid "%s is incompatible with %s"
+msgstr "%s ist inkompatibel mit %s."
 
-#: sequencer.c:2201
-msgid "unexpected end of file"
-msgstr "Unerwartetes Dateiende"
+#: parse-options.c:78
+#, c-format
+msgid "%s : incompatible with something else"
+msgstr "%s: inkompatibel mit etwas anderem"
 
-#: sequencer.c:2207
+#: parse-options.c:92 parse-options.c:96 parse-options.c:319
 #, c-format
-msgid "stored pre-cherry-pick HEAD file '%s' is corrupt"
-msgstr "gespeicherte \"pre-cherry-pick\" HEAD Datei '%s' ist beschädigt"
+msgid "%s takes no value"
+msgstr "%s erwartet keinen Wert"
 
-#: sequencer.c:2218
-msgid "You seem to have moved HEAD. Not rewinding, check your HEAD!"
+#: parse-options.c:94
+#, c-format
+msgid "%s isn't available"
+msgstr "%s ist nicht verfügbar."
+
+#: parse-options.c:219
+#, c-format
+msgid "%s expects a non-negative integer value with an optional k/m/g suffix"
 msgstr ""
-"Sie scheinen HEAD verändert zu haben. Keine Rückspulung, prüfen Sie HEAD."
+"%s erwartet einen nicht-negativen Integer-Wert mit einem optionalen k/m/g "
+"Suffix"
 
-#: sequencer.c:2324 sequencer.c:2679
+#: parse-options.c:389
 #, c-format
-msgid "could not update %s"
-msgstr "Konnte %s nicht aktualisieren."
+msgid "ambiguous option: %s (could be --%s%s or --%s%s)"
+msgstr "Mehrdeutige Option: %s (kann --%s%s oder --%s%s sein)"
 
-#: sequencer.c:2362 sequencer.c:2659
-msgid "cannot read HEAD"
-msgstr "Kann HEAD nicht lesen"
+#: parse-options.c:423 parse-options.c:431
+#, c-format
+msgid "did you mean `--%s` (with two dashes ?)"
+msgstr "Meinten Sie `--%s` (mit zwei Strichen?)"
 
-#: sequencer.c:2402 builtin/difftool.c:639
+#: parse-options.c:860
 #, c-format
-msgid "could not copy '%s' to '%s'"
-msgstr "Konnte '%s' nicht nach '%s' kopieren."
+msgid "unknown option `%s'"
+msgstr "Unbekannte Option: `%s'"
 
-#: sequencer.c:2421
-msgid "could not read index"
-msgstr "Konnte den Index nicht lesen."
+#: parse-options.c:862
+#, c-format
+msgid "unknown switch `%c'"
+msgstr "Unbekannter Schalter `%c'"
 
-#: sequencer.c:2426
+#: parse-options.c:864
 #, c-format
-msgid ""
-"execution failed: %s\n"
-"%sYou can fix the problem, and then run\n"
-"\n"
-"  git rebase --continue\n"
-"\n"
-msgstr ""
-"Ausführung fehlgeschlagen: %s\n"
-"%sSie können das Problem beheben, und dann\n"
-"\n"
-"\tgit rebase --continue\n"
-"\n"
-"ausführen.\n"
+msgid "unknown non-ascii option in string: `%s'"
+msgstr "Unbekannte nicht-Ascii Option in String: `%s'"
 
-#: sequencer.c:2432
-msgid "and made changes to the index and/or the working tree\n"
-msgstr "Der Index und/oder das Arbeitsverzeichnis wurde geändert.\n"
+#: parse-options.c:888
+msgid "..."
+msgstr "..."
 
-#: sequencer.c:2438
+#: parse-options.c:907
 #, c-format
-msgid ""
-"execution succeeded: %s\n"
-"but left changes to the index and/or the working tree\n"
-"Commit or stash your changes, and then run\n"
-"\n"
-"  git rebase --continue\n"
-"\n"
-msgstr ""
-"Ausführung erfolgreich: %s\n"
-"Aber Änderungen in Index oder Arbeitsverzeichnis verblieben.\n"
-"Committen Sie Ihre Änderungen oder benutzen Sie \"stash\".\n"
-"Führen Sie dann aus:\n"
-"\n"
-"  git rebase --continue\n"
-"\n"
+msgid "usage: %s"
+msgstr "Verwendung: %s"
 
-#: sequencer.c:2497
+#. TRANSLATORS: the colon here should align with the
+#. one in "usage: %s" translation.
+#.
+#: parse-options.c:913
 #, c-format
-msgid "Applied autostash.\n"
-msgstr "Automatischen Stash angewendet.\n"
+msgid "   or: %s"
+msgstr "      oder: %s"
 
-#: sequencer.c:2509
+#: parse-options.c:916
 #, c-format
-msgid "cannot store %s"
-msgstr "kann %s nicht speichern"
+msgid "    %s"
+msgstr "    %s"
+
+#: parse-options.c:955
+msgid "-NUM"
+msgstr "-NUM"
 
-#: sequencer.c:2512 git-rebase.sh:178
+#: parse-options.c:969
 #, c-format
-msgid ""
-"Applying autostash resulted in conflicts.\n"
-"Your changes are safe in the stash.\n"
-"You can run \"git stash pop\" or \"git stash drop\" at any time.\n"
-msgstr ""
-"Anwendung des automatischen Stash resultierte in Konflikten.\n"
-"Ihre Änderungen sind im Stash sicher.\n"
-"Sie können jederzeit \"git stash pop\" oder \"git stash drop\" ausführen.\n"
+msgid "alias of --%s"
+msgstr "Alias für --%s"
 
-#: sequencer.c:2595
+#: parse-options-cb.c:20 parse-options-cb.c:24
 #, c-format
-msgid "Stopped at %s...  %.*s\n"
-msgstr "Angehalten bei %s... %.*s\n"
+msgid "option `%s' expects a numerical value"
+msgstr "Option `%s' erwartet einen numerischen Wert."
 
-#: sequencer.c:2637
+#: parse-options-cb.c:41
 #, c-format
-msgid "unknown command %d"
-msgstr "Unbekannter Befehl %d"
+msgid "malformed expiration date '%s'"
+msgstr "Fehlerhaftes Ablaufdatum '%s'"
 
-#: sequencer.c:2667
-msgid "could not read orig-head"
-msgstr "Konnte orig-head nicht lesen."
+#: parse-options-cb.c:54
+#, c-format
+msgid "option `%s' expects \"always\", \"auto\", or \"never\""
+msgstr "Option `%s' erwartet \"always\", \"auto\" oder \"never\"."
 
-#: sequencer.c:2672 sequencer.c:3262
-msgid "could not read 'onto'"
-msgstr "Konnte 'onto' nicht lesen."
+#: parse-options-cb.c:130 parse-options-cb.c:147
+#, c-format
+msgid "malformed object name '%s'"
+msgstr "fehlerhafter Objekt-Name '%s'"
 
-#: sequencer.c:2686
+#: path.c:915
 #, c-format
-msgid "could not update HEAD to %s"
-msgstr "Konnte HEAD nicht auf %s aktualisieren."
+msgid "Could not make %s writable by group"
+msgstr "Konnte Gruppenschreibrecht für %s nicht setzen."
 
-#: sequencer.c:2770
-msgid "cannot rebase: You have unstaged changes."
-msgstr ""
-"Rebase nicht möglich: Sie haben Änderungen, die nicht zum Commit\n"
-"vorgemerkt sind."
+#: pathspec.c:130
+msgid "Escape character '\\' not allowed as last character in attr value"
+msgstr "Escape-Zeichen '\\' als letztes Zeichen in Attributwert nicht erlaubt"
 
-#: sequencer.c:2775
-msgid "could not remove CHERRY_PICK_HEAD"
-msgstr "Konnte CHERRY_PICK_HEAD nicht löschen."
+#: pathspec.c:148
+msgid "Only one 'attr:' specification is allowed."
+msgstr "Es ist nur eine Angabe von 'attr:' erlaubt."
 
-#: sequencer.c:2784
-msgid "cannot amend non-existing commit"
-msgstr "Kann nicht existierenden Commit nicht nachbessern."
+#: pathspec.c:151
+msgid "attr spec must not be empty"
+msgstr "Angabe von 'attr:' darf nicht leer sein"
 
-#: sequencer.c:2786
+#: pathspec.c:194
 #, c-format
-msgid "invalid file: '%s'"
-msgstr "Ungültige Datei: '%s'"
+msgid "invalid attribute name %s"
+msgstr "Ungültiger Attributname %s"
 
-#: sequencer.c:2788
-#, c-format
-msgid "invalid contents: '%s'"
-msgstr "Ungültige Inhalte: '%s'"
+#: pathspec.c:259
+msgid "global 'glob' and 'noglob' pathspec settings are incompatible"
+msgstr ""
+"Globale Einstellungen zur Pfadspezifikation 'glob' und 'noglob' sind "
+"inkompatibel."
 
-#: sequencer.c:2791
+#: pathspec.c:266
 msgid ""
-"\n"
-"You have uncommitted changes in your working tree. Please, commit them\n"
-"first and then run 'git rebase --continue' again."
+"global 'literal' pathspec setting is incompatible with all other global "
+"pathspec settings"
 msgstr ""
-"\n"
-"Sie haben nicht committete Änderungen in Ihrem Arbeitsverzeichnis. Bitte\n"
-"committen Sie diese zuerst und führen Sie dann 'git rebase --continue'\n"
-"erneut aus."
+"Globale Einstellung zur Pfadspezifikation 'literal' ist inkompatibel\n"
+"mit allen anderen Optionen."
 
-#: sequencer.c:2801
-msgid "could not commit staged changes."
-msgstr "Konnte Änderungen aus der Staging-Area nicht committen."
+#: pathspec.c:306
+msgid "invalid parameter for pathspec magic 'prefix'"
+msgstr "ungültiger Parameter für Pfadspezifikationsangabe 'prefix'"
 
-#: sequencer.c:2881
+#: pathspec.c:327
 #, c-format
-msgid "%s: can't cherry-pick a %s"
-msgstr "%s: %s kann nicht in \"cherry-pick\" benutzt werden"
+msgid "Invalid pathspec magic '%.*s' in '%s'"
+msgstr "ungültige Pfadspezifikationsangabe '%.*s' in '%s'"
 
-#: sequencer.c:2885
+#: pathspec.c:332
 #, c-format
-msgid "%s: bad revision"
-msgstr "%s: ungültiger Commit"
+msgid "Missing ')' at the end of pathspec magic in '%s'"
+msgstr "Fehlendes ')' am Ende der Pfadspezifikationsangabe in '%s'"
 
-#: sequencer.c:2918
-msgid "can't revert as initial commit"
-msgstr "Kann nicht als allerersten Commit einen Revert ausführen."
+#: pathspec.c:370
+#, c-format
+msgid "Unimplemented pathspec magic '%c' in '%s'"
+msgstr "nicht unterstützte Pfadspezifikationsangabe '%c' in '%s'"
 
-#: sequencer.c:3023
-msgid "make_script: unhandled options"
-msgstr "make_script: unbehandelte Optionen"
+#: pathspec.c:429
+#, c-format
+msgid "%s: 'literal' and 'glob' are incompatible"
+msgstr "%s: 'literal' und 'glob' sind inkompatibel"
 
-#: sequencer.c:3026
-msgid "make_script: error preparing revisions"
-msgstr "make_script: Fehler beim Vorbereiten der Commits"
+#: pathspec.c:442
+#, c-format
+msgid "%s: '%s' is outside repository"
+msgstr "%s: '%s' liegt außerhalb des Repositories"
 
-#: sequencer.c:3060 sequencer.c:3095
+#: pathspec.c:516
 #, c-format
-msgid "unusable todo list: '%s'"
-msgstr "Unbenutzbare TODO-Liste: '%s'"
+msgid "'%s' (mnemonic: '%c')"
+msgstr "'%s' (Kürzel: '%c')"
 
-#: sequencer.c:3146
+#: pathspec.c:526
 #, c-format
-msgid ""
-"unrecognized setting %s for option rebase.missingCommitsCheck. Ignoring."
+msgid "%s: pathspec magic not supported by this command: %s"
 msgstr ""
-"Nicht erkannte Einstellung %s für Option rebase.missingCommitsCheck. "
-"Ignoriere."
+"%s: Pfadspezifikationsangabe wird von diesem Befehl nicht unterstützt: %s"
 
-#: sequencer.c:3212
+#: pathspec.c:593
 #, c-format
-msgid ""
-"Warning: some commits may have been dropped accidentally.\n"
-"Dropped commits (newer to older):\n"
-msgstr ""
-"Warnung: Einige Commits könnten aus Versehen entfernt worden sein.\n"
-"Entfernte Commits (neu zu alt):\n"
+msgid "pathspec '%s' is beyond a symbolic link"
+msgstr "Pfadspezifikation '%s' ist hinter einer symbolischen Verknüpfung"
 
-#: sequencer.c:3219
+#: pathspec.c:638
 #, c-format
-msgid ""
-"To avoid this message, use \"drop\" to explicitly remove a commit.\n"
-"\n"
-"Use 'git config rebase.missingCommitsCheck' to change the level of "
-"warnings.\n"
-"The possible behaviours are: ignore, warn, error.\n"
-"\n"
-msgstr ""
-"Um diese Meldung zu vermeiden, benutzen Sie \"drop\", um exlizit Commits zu\n"
-"entfernen.\n"
-"\n"
-"Benutzen Sie 'git config rebase.missingCommitsCheck', um die Stufe der\n"
-"Warnungen zu ändern.\n"
-"Die möglichen Verhaltensweisen sind: ignore, warn, error.\n"
+msgid "line is badly quoted: %s"
+msgstr "Zeile enthält falsche Anführungszeichen: %s"
 
-#: sequencer.c:3231
-#, c-format
-msgid ""
-"You can fix this with 'git rebase --edit-todo' and then run 'git rebase --"
-"continue'.\n"
-"Or you can abort the rebase with 'git rebase --abort'.\n"
+#: pkt-line.c:92
+msgid "unable to write flush packet"
+msgstr "Konnte Flush-Paket nicht schreiben."
+
+#: pkt-line.c:99
+msgid "unable to write delim packet"
+msgstr "Konnte Delim-Paket nicht schreiben."
+
+#: pkt-line.c:106
+msgid "flush packet write failed"
+msgstr "Flush beim Schreiben des Pakets fehlgeschlagen."
+
+#: pkt-line.c:146 pkt-line.c:232
+msgid "protocol error: impossibly long line"
+msgstr "Protokollfehler: unmöglich lange Zeile"
+
+#: pkt-line.c:162 pkt-line.c:164
+msgid "packet write with format failed"
+msgstr "Schreiben des Pakets mit Format fehlgeschlagen."
+
+#: pkt-line.c:196
+msgid "packet write failed - data exceeds max packet size"
 msgstr ""
-"Sie können das mit 'git rebase --edit-todo' beheben. Führen Sie danach\n"
-"'git rebase --continue' aus.\n"
-"Oder Sie können den Rebase mit 'git rebase --abort' abbrechen.\n"
+"Schreiben des Pakets fehlgeschlagen - Daten überschreiten maximale Paketgröße"
 
-#: sequencer.c:3244 sequencer.c:3304 wrapper.c:225 wrapper.c:395
-#: builtin/am.c:779
-#, c-format
-msgid "could not open '%s' for writing"
-msgstr "Konnte '%s' nicht zum Schreiben öffnen."
+#: pkt-line.c:203 pkt-line.c:210
+msgid "packet write failed"
+msgstr "Schreiben des Pakets fehlgeschlagen."
 
-#: sequencer.c:3285
-#, c-format
-msgid "could not parse commit '%s'"
-msgstr "Konnte Commit '%s' nicht parsen."
+#: pkt-line.c:295
+msgid "read error"
+msgstr "Lesefehler"
 
-#: sequencer.c:3401
-msgid "the script was already rearranged."
-msgstr "Das Script wurde bereits umgeordnet."
+#: pkt-line.c:303
+msgid "the remote end hung up unexpectedly"
+msgstr "Die Gegenseite hat unerwartet abgebrochen."
 
-#: setup.c:122
+#: pkt-line.c:331
 #, c-format
-msgid "'%s' is outside repository"
-msgstr "'%s' liegt außerhalb des Repositories."
+msgid "protocol error: bad line length character: %.4s"
+msgstr "Protokollfehler: ungültiges Zeichen für Zeilenlänge: %.4s"
 
-#: setup.c:171
+#: pkt-line.c:341 pkt-line.c:346
 #, c-format
-msgid ""
-"%s: no such path in the working tree.\n"
-"Use 'git <command> -- <path>...' to specify paths that do not exist locally."
-msgstr ""
-"%s: kein solcher Pfad im Arbeitsverzeichnis.\n"
-"Benutzen Sie 'git <Befehl> -- <Pfad>...' zur Angabe von Pfaden, die lokal\n"
-"nicht existieren."
+msgid "protocol error: bad line length %d"
+msgstr "Protokollfehler: ungültige Zeilenlänge %d"
 
-#: setup.c:184
+#: pkt-line.c:362
 #, c-format
-msgid ""
-"ambiguous argument '%s': unknown revision or path not in the working tree.\n"
-"Use '--' to separate paths from revisions, like this:\n"
-"'git <command> [<revision>...] -- [<file>...]'"
-msgstr ""
-"mehrdeutiges Argument '%s': unbekannter Commit oder Pfad existiert nicht\n"
-"im Arbeitsverzeichnis\n"
-"Benutzen Sie '--', um Pfade und Commits zu trennen, ähnlich wie:\n"
-"'git <Befehl> [<Commit>...] -- [<Datei>...]'"
+msgid "remote error: %s"
+msgstr "Fehler am anderen Ende: %s"
 
-#: setup.c:233
-#, c-format
-msgid "option '%s' must come before non-option arguments"
-msgstr "Die Option '%s' muss vor den Argumenten kommen, die keine Optionen sind."
+#: preload-index.c:119
+msgid "Refreshing index"
+msgstr "Aktualisiere Index"
 
-#: setup.c:252
+#: preload-index.c:138
 #, c-format
-msgid ""
-"ambiguous argument '%s': both revision and filename\n"
-"Use '--' to separate paths from revisions, like this:\n"
-"'git <command> [<revision>...] -- [<file>...]'"
-msgstr ""
-"mehrdeutiges Argument '%s': sowohl Commit als auch Dateiname\n"
-"Benutzen Sie '--', um Pfade und Commits zu trennen, ähnlich wie:\n"
-"'git <Befehl> [<Commit>...] -- [<Datei>...]'"
+msgid "unable to create threaded lstat: %s"
+msgstr "Kann Thread für lstat nicht erzeugen: %s"
 
-#: setup.c:388
-msgid "unable to set up work tree using invalid config"
-msgstr "Konnte Arbeitsverzeichnis mit ungültiger Konfiguration nicht einrichten."
+#: pretty.c:981
+msgid "unable to parse --pretty format"
+msgstr "Konnte --pretty Format nicht parsen."
 
-#: setup.c:395
-msgid "this operation must be run in a work tree"
-msgstr "Diese Operation muss in einem Arbeitsverzeichnis ausgeführt werden."
+#: promisor-remote.c:23
+msgid "Remote with no URL"
+msgstr "Remote-Repository ohne URL"
 
-#: setup.c:506
+#: promisor-remote.c:58
 #, c-format
-msgid "Expected git repo version <= %d, found %d"
-msgstr "Erwartete Git-Repository-Version <= %d, %d gefunden"
+msgid "promisor remote name cannot begin with '/': %s"
+msgstr "Promisor-Remote-Name kann nicht mit '/' beginnen: %s"
 
-#: setup.c:514
-msgid "unknown repository extensions found:"
-msgstr "Unbekannte Repository-Erweiterungen gefunden:"
+#: range-diff.c:75
+msgid "could not start `log`"
+msgstr "Konnte `log` nicht starten."
 
-#: setup.c:533
-#, c-format
-msgid "error opening '%s'"
-msgstr "Fehler beim Öffnen von '%s'."
+#: range-diff.c:77
+msgid "could not read `log` output"
+msgstr "Konnte Ausgabe von `log` nicht lesen."
 
-#: setup.c:535
+#: range-diff.c:96 sequencer.c:5163
 #, c-format
-msgid "too large to be a .git file: '%s'"
-msgstr "Zu groß, um eine .git-Datei zu sein: '%s'"
+msgid "could not parse commit '%s'"
+msgstr "Konnte Commit '%s' nicht parsen."
 
-#: setup.c:537
+#: range-diff.c:122
 #, c-format
-msgid "error reading %s"
-msgstr "Fehler beim Lesen von '%s'."
+msgid "could not parse git header '%.*s'"
+msgstr "Konnte Git-Header '%.*s' nicht parsen."
 
-#: setup.c:539
-#, c-format
-msgid "invalid gitfile format: %s"
-msgstr "Ungültiges gitfile-Format: %s"
+#: range-diff.c:285
+msgid "failed to generate diff"
+msgstr "Fehler beim Generieren des Diffs."
 
-#: setup.c:541
+#: range-diff.c:518 range-diff.c:520
 #, c-format
-msgid "no path in gitfile: %s"
-msgstr "Kein Pfad in gitfile: %s"
+msgid "could not parse log for '%s'"
+msgstr "Konnte Log für '%s' nicht parsen."
 
-#: setup.c:543
+#: read-cache.c:680
 #, c-format
-msgid "not a git repository: %s"
-msgstr "Kein Git-Repository: %s"
+msgid "will not add file alias '%s' ('%s' already exists in index)"
+msgstr ""
+"Dateialias '%s' wird nicht hinzugefügt ('%s' existiert bereits im Index)."
 
-#: setup.c:642
-#, c-format
-msgid "'$%s' too big"
-msgstr "'$%s' zu groß"
+#: read-cache.c:696
+msgid "cannot create an empty blob in the object database"
+msgstr "Kann keinen leeren Blob in die Objektdatenbank schreiben."
 
-#: setup.c:656
+#: read-cache.c:718
 #, c-format
-msgid "not a git repository: '%s'"
-msgstr "Kein Git-Repository: '%s'"
+msgid "%s: can only add regular files, symbolic links or git-directories"
+msgstr ""
+"%s: Kann nur reguläre Dateien, symbolische Links oder Git-Verzeichnisse "
+"hinzufügen."
 
-#: setup.c:685 setup.c:687 setup.c:718
+#: read-cache.c:723
 #, c-format
-msgid "cannot chdir to '%s'"
-msgstr "Kann nicht in Verzeichnis '%s' wechseln."
-
-#: setup.c:690 setup.c:746 setup.c:756 setup.c:795 setup.c:803 setup.c:818
-msgid "cannot come back to cwd"
-msgstr "Kann nicht zum aktuellen Arbeitsverzeichnis zurückwechseln."
+msgid "'%s' does not have a commit checked out"
+msgstr "'%s' hat keinen Commit ausgecheckt"
 
-#: setup.c:816
+#: read-cache.c:775
 #, c-format
-msgid "not a git repository (or any of the parent directories): %s"
-msgstr "Kein Git-Repository (oder irgendeines der Elternverzeichnisse): %s"
+msgid "unable to index file '%s'"
+msgstr "Konnte Datei '%s' nicht indizieren."
 
-#: setup.c:827
+#: read-cache.c:794
 #, c-format
-msgid "failed to stat '%*s%s%s'"
-msgstr "Konnte '%*s%s%s' nicht lesen."
+msgid "unable to add '%s' to index"
+msgstr "Konnte '%s' nicht dem Index hinzufügen."
 
-#: setup.c:1057
-msgid "Unable to read current working directory"
-msgstr "Konnte aktuelles Arbeitsverzeichnis nicht lesen."
+#: read-cache.c:805
+#, c-format
+msgid "unable to stat '%s'"
+msgstr "Konnte '%s' nicht lesen."
 
-#: setup.c:1069 setup.c:1075
+#: read-cache.c:1325
 #, c-format
-msgid "cannot change to '%s'"
-msgstr "Kann nicht nach '%s' wechseln."
+msgid "'%s' appears as both a file and as a directory"
+msgstr "'%s' scheint eine Datei und ein Verzeichnis zu sein."
+
+#: read-cache.c:1531
+msgid "Refresh index"
+msgstr "Aktualisiere Index"
 
-#: setup.c:1088
+#: read-cache.c:1646
 #, c-format
 msgid ""
-"not a git repository (or any parent up to mount point %s)\n"
-"Stopping at filesystem boundary (GIT_DISCOVERY_ACROSS_FILESYSTEM not set)."
+"index.version set, but the value is invalid.\n"
+"Using version %i"
 msgstr ""
-"Kein Git-Repository (oder irgendein Elternverzeichnis bis zum Einhängepunkt "
-"%s)\n"
-"Stoppe bei Dateisystemgrenze (GIT_DISCOVERY_ACROSS_FILESYSTEM nicht gesetzt)."
+"index.version gesetzt, aber Wert ungültig.\n"
+"Verwende Version %i"
 
-#: setup.c:1172
+#: read-cache.c:1656
 #, c-format
 msgid ""
-"problem with core.sharedRepository filemode value (0%.3o).\n"
-"The owner of files must always have read and write permissions."
+"GIT_INDEX_VERSION set, but the value is invalid.\n"
+"Using version %i"
 msgstr ""
-"Problem mit Wert für Dateimodus (0%.3o) von core.sharedRepository.\n"
-"Der Besitzer der Dateien muss immer Lese- und Schreibrechte haben."
+"GIT_INDEX_VERSION gesetzt, aber Wert ungültig.\n"
+"Verwende Version %i"
 
-#: setup.c:1215
-msgid "open /dev/null or dup failed"
-msgstr "Öffnen von /dev/null oder dup fehlgeschlagen."
+#: read-cache.c:1712
+#, c-format
+msgid "bad signature 0x%08x"
+msgstr "Ungültige Signatur 0x%08x"
 
-#: setup.c:1230
-msgid "fork failed"
-msgstr "fork fehlgeschlagen"
+#: read-cache.c:1715
+#, c-format
+msgid "bad index version %d"
+msgstr "Ungültige Index-Version %d"
 
-#: setup.c:1235
-msgid "setsid failed"
-msgstr "setsid fehlgeschlagen"
+#: read-cache.c:1724
+msgid "bad index file sha1 signature"
+msgstr "Ungültige SHA1-Signatur der Index-Datei."
 
-#: sha1_file.c:592
+#: read-cache.c:1754
 #, c-format
-msgid "path '%s' does not exist"
-msgstr "Pfad '%s' existiert nicht"
+msgid "index uses %.4s extension, which we do not understand"
+msgstr "Index verwendet Erweiterung %.4s, welche wir nicht unterstützen."
 
-#: sha1_file.c:618
+#: read-cache.c:1756
 #, c-format
-msgid "reference repository '%s' as a linked checkout is not supported yet."
-msgstr ""
-"Referenziertes Repository '%s' wird noch nicht als verknüpftes\n"
-"Arbeitsverzeichnis unterstützt."
+msgid "ignoring %.4s extension"
+msgstr "Ignoriere Erweiterung %.4s"
 
-#: sha1_file.c:624
+#: read-cache.c:1793
 #, c-format
-msgid "reference repository '%s' is not a local repository."
-msgstr "Referenziertes Repository '%s' ist kein lokales Repository."
+msgid "unknown index entry format 0x%08x"
+msgstr "Unbekanntes Format für Index-Eintrag 0x%08x"
 
-#: sha1_file.c:630
+#: read-cache.c:1809
 #, c-format
-msgid "reference repository '%s' is shallow"
-msgstr ""
-"Referenziertes Repository '%s' hat eine unvollständige Historie (shallow)."
+msgid "malformed name field in the index, near path '%s'"
+msgstr "Ungültiges Namensfeld im Index, in der Nähe von Pfad '%s'."
 
-#: sha1_file.c:638
-#, c-format
-msgid "reference repository '%s' is grafted"
-msgstr ""
-"Referenziertes Repository '%s' ist mit künstlichen Vorgängern (\"grafts\") "
-"eingehängt."
+#: read-cache.c:1866
+msgid "unordered stage entries in index"
+msgstr "Ungeordnete Stage-Einträge im Index."
 
-#: sha1_name.c:422
+#: read-cache.c:1869
 #, c-format
-msgid "short SHA1 %s is ambiguous"
-msgstr "Kurzer SHA-1 %s ist mehrdeutig."
-
-#: sha1_name.c:433
-msgid "The candidates are:"
-msgstr "Die Kandidaten sind:"
+msgid "multiple stage entries for merged file '%s'"
+msgstr "Mehrere Stage-Einträge für zusammengeführte Datei '%s'."
 
-#: sha1_name.c:693
-msgid ""
-"Git normally never creates a ref that ends with 40 hex characters\n"
-"because it will be ignored when you just specify 40-hex. These refs\n"
-"may be created by mistake. For example,\n"
-"\n"
-"  git checkout -b $br $(git rev-parse ...)\n"
-"\n"
-"where \"$br\" is somehow empty and a 40-hex ref is created. Please\n"
-"examine these refs and maybe delete them. Turn this message off by\n"
-"running \"git config advice.objectNameWarning false\""
-msgstr ""
-"Git erzeugt normalerweise keine Referenzen die mit\n"
-"40 Hex-Zeichen enden, da diese ignoriert werden wenn\n"
-"Sie diese angeben. Diese Referenzen könnten aus Versehen\n"
-"erzeugt worden sein. Zum Beispiel,\n"
-"\n"
-"  git checkout -b $br $(git rev-parse ...)\n"
-"\n"
-"wobei \"$br\" leer ist und eine 40-Hex-Referenz erzeugt\n"
-"wurde. Bitte prüfen Sie diese Referenzen und löschen\n"
-"Sie sie gegebenenfalls. Unterdrücken Sie diese Meldung\n"
-"indem Sie \"git config advice.objectNameWarning false\"\n"
-"ausführen."
+#: read-cache.c:1872
+#, c-format
+msgid "unordered stage entries for '%s'"
+msgstr "Ungeordnete Stage-Einträge für '%s'."
 
-#: submodule.c:96 submodule.c:130
-msgid "Cannot change unmerged .gitmodules, resolve merge conflicts first"
-msgstr ""
-"Kann nicht zusammengeführte .gitmodules-Datei nicht ändern, lösen\n"
-"Sie zuerst die Konflikte auf"
+#: read-cache.c:1978 read-cache.c:2266 rerere.c:565 rerere.c:599 rerere.c:1111
+#: builtin/add.c:499 builtin/check-ignore.c:178 builtin/checkout.c:470
+#: builtin/checkout.c:654 builtin/clean.c:967 builtin/commit.c:367
+#: builtin/diff-tree.c:120 builtin/grep.c:499 builtin/mv.c:145
+#: builtin/reset.c:246 builtin/rm.c:271 builtin/submodule--helper.c:332
+msgid "index file corrupt"
+msgstr "Index-Datei beschädigt"
 
-#: submodule.c:100 submodule.c:134
+#: read-cache.c:2119
 #, c-format
-msgid "Could not find section in .gitmodules where path=%s"
-msgstr "Konnte keine Sektion in .gitmodules mit Pfad \"%s\" finden"
+msgid "unable to create load_cache_entries thread: %s"
+msgstr "Kann Thread für load_cache_entries nicht erzeugen: %s"
 
-#: submodule.c:108
+#: read-cache.c:2132
 #, c-format
-msgid "Could not update .gitmodules entry %s"
-msgstr "Konnte Eintrag '%s' in .gitmodules nicht aktualisieren"
+msgid "unable to join load_cache_entries thread: %s"
+msgstr "Kann Thread für load_cache_entries nicht erzeugen: %s"
 
-#: submodule.c:141
+#: read-cache.c:2165
 #, c-format
-msgid "Could not remove .gitmodules entry for %s"
-msgstr "Konnte Eintrag '%s' nicht aus .gitmodules entfernen"
+msgid "%s: index file open failed"
+msgstr "%s: Öffnen der Index-Datei fehlgeschlagen."
 
-#: submodule.c:152
-msgid "staging updated .gitmodules failed"
-msgstr "Konnte aktualisierte .gitmodules-Datei nicht zum Commit vormerken"
-
-#: submodule.c:312
+#: read-cache.c:2169
 #, c-format
-msgid "in unpopulated submodule '%s'"
-msgstr "In nicht ausgechecktem Submodul '%s'."
+msgid "%s: cannot stat the open index"
+msgstr "%s: Kann geöffneten Index nicht lesen."
 
-#: submodule.c:343
+#: read-cache.c:2173
 #, c-format
-msgid "Pathspec '%s' is in submodule '%.*s'"
-msgstr "Pfadspezifikation '%s' befindet sich in Submodul '%.*s'"
+msgid "%s: index file smaller than expected"
+msgstr "%s: Index-Datei ist kleiner als erwartet."
 
-#: submodule.c:833
+#: read-cache.c:2177
 #, c-format
-msgid "submodule entry '%s' (%s) is a %s, not a commit"
-msgstr "Submodul-Eintrag '%s' (%s) ist ein %s, kein Commit."
-
-#: submodule.c:1065 builtin/branch.c:648 builtin/submodule--helper.c:1724
-msgid "Failed to resolve HEAD as a valid ref."
-msgstr "Konnte HEAD nicht als gültige Referenz auflösen."
+msgid "%s: unable to map index file"
+msgstr "%s: Konnte Index-Datei nicht einlesen."
 
-#: submodule.c:1370
+#: read-cache.c:2219
 #, c-format
-msgid "'%s' not recognized as a git repository"
-msgstr "'%s' nicht als Git-Repository erkannt"
+msgid "unable to create load_index_extensions thread: %s"
+msgstr "Kann Thread für load_index_extensions nicht erzeugen: %s"
 
-#: submodule.c:1508
+#: read-cache.c:2246
 #, c-format
-msgid "could not start 'git status' in submodule '%s'"
-msgstr "Konnte 'git status' in Submodul '%s' nicht starten."
+msgid "unable to join load_index_extensions thread: %s"
+msgstr "Kann Thread für load_index_extensions nicht beitreten: %s"
 
-#: submodule.c:1521
+#: read-cache.c:2278
 #, c-format
-msgid "could not run 'git status' in submodule '%s'"
-msgstr "Konnte 'git status' in Submodul '%s' nicht ausführen."
+msgid "could not freshen shared index '%s'"
+msgstr "Konnte geteilten Index '%s' nicht aktualisieren."
 
-#: submodule.c:1614
+#: read-cache.c:2325
 #, c-format
-msgid "submodule '%s' has dirty index"
-msgstr "Submodul '%s' hat einen geänderten Index."
+msgid "broken index, expect %s in %s, got %s"
+msgstr "Fehlerhafter Index. Erwartete %s in %s, erhielt %s."
 
-#: submodule.c:1878
+#: read-cache.c:3021 strbuf.c:1145 wrapper.c:622 builtin/merge.c:1119
 #, c-format
-msgid ""
-"relocate_gitdir for submodule '%s' with more than one worktree not supported"
-msgstr ""
-"relocate_gitdir für Submodul '%s' mit mehr als einem Arbeitsverzeichnis\n"
-"wird nicht unterstützt"
+msgid "could not close '%s'"
+msgstr "Konnte '%s' nicht schließen."
 
-#: submodule.c:1890 submodule.c:1946
+#: read-cache.c:3124 sequencer.c:2429 sequencer.c:4069
 #, c-format
-msgid "could not lookup name for submodule '%s'"
-msgstr "konnte Name für Submodul '%s' nicht nachschlagen"
+msgid "could not stat '%s'"
+msgstr "Konnte '%s' nicht lesen."
 
-#: submodule.c:1894 builtin/submodule--helper.c:1246
-#: builtin/submodule--helper.c:1256
+#: read-cache.c:3137
 #, c-format
-msgid "could not create directory '%s'"
-msgstr "Konnte Verzeichnis '%s' nicht erstellen."
+msgid "unable to open git dir: %s"
+msgstr "konnte Git-Verzeichnis nicht öffnen: %s"
 
-#: submodule.c:1897
+#: read-cache.c:3149
 #, c-format
-msgid ""
-"Migrating git directory of '%s%s' from\n"
-"'%s' to\n"
-"'%s'\n"
-msgstr ""
-"Migriere Git-Verzeichnis von '%s%s' von\n"
-"'%s' nach\n"
-"'%s'\n"
+msgid "unable to unlink: %s"
+msgstr "Konnte '%s' nicht entfernen."
 
-#: submodule.c:1981
+#: read-cache.c:3174
 #, c-format
-msgid "could not recurse into submodule '%s'"
-msgstr "Fehler bei Rekursion in Submodul-Pfad '%s'"
-
-#: submodule.c:2025
-msgid "could not start ls-files in .."
-msgstr "Konnte 'ls-files' nicht in .. starten"
+msgid "cannot fix permission bits on '%s'"
+msgstr "Konnte Zugriffsberechtigung auf '%s' nicht setzen."
 
-#: submodule.c:2045
-msgid "BUG: returned path string doesn't match cwd?"
-msgstr "FEHLER: zurückgegebene Zeichenkette für Pfad entspricht nicht cwd?"
-
-#: submodule.c:2064
+#: read-cache.c:3323
 #, c-format
-msgid "ls-tree returned unexpected return code %d"
-msgstr "ls-tree mit unerwartetem Rückgabewert %d beendet"
+msgid "%s: cannot drop to stage #0"
+msgstr "%s: Kann nicht auf Stufe #0 wechseln."
 
-#: submodule-config.c:263
-msgid "negative values not allowed for submodule.fetchjobs"
-msgstr "Negative Werte für submodule.fetchjobs nicht erlaubt."
-
-#: submodule-config.c:436
+#: rebase-interactive.c:26
 #, c-format
-msgid "invalid value for %s"
-msgstr "Ungültiger Wert für %s"
-
-#: trailer.c:238
-#, c-format
-msgid "running trailer command '%s' failed"
-msgstr "Ausführen des Anhang-Befehls '%s' fehlgeschlagen"
-
-#: trailer.c:485 trailer.c:490 trailer.c:495 trailer.c:549 trailer.c:553
-#: trailer.c:557
-#, c-format
-msgid "unknown value '%s' for key '%s'"
-msgstr "unbekannter Wert '%s' für Schlüssel %s"
-
-#: trailer.c:539 trailer.c:544 builtin/remote.c:290
-#, c-format
-msgid "more than one %s"
-msgstr "mehr als ein %s"
-
-#: trailer.c:730
-#, c-format
-msgid "empty trailer token in trailer '%.*s'"
-msgstr "leerer Anhang-Token in Anhang '%.*s'"
-
-#: trailer.c:750
-#, c-format
-msgid "could not read input file '%s'"
-msgstr "Konnte Eingabe-Datei '%s' nicht lesen"
-
-#: trailer.c:753
-msgid "could not read from stdin"
-msgstr "konnte nicht von der Standard-Eingabe lesen"
-
-#: trailer.c:1008 builtin/am.c:46
-#, c-format
-msgid "could not stat %s"
-msgstr "Konnte '%s' nicht lesen"
-
-#: trailer.c:1010
-#, c-format
-msgid "file %s is not a regular file"
-msgstr "Datei '%s' ist keine reguläre Datei"
-
-#: trailer.c:1012
-#, c-format
-msgid "file %s is not writable by user"
-msgstr "Datei %s ist vom Benutzer nicht beschreibbar."
-
-#: trailer.c:1024
-msgid "could not open temporary file"
-msgstr "konnte temporäre Datei '%s' nicht öffnen"
-
-#: trailer.c:1064
-#, c-format
-msgid "could not rename temporary file to %s"
-msgstr "konnte temporäre Datei nicht zu %s umbenennen"
-
-#: transport.c:63
-#, c-format
-msgid "Would set upstream of '%s' to '%s' of '%s'\n"
-msgstr "Würde Upstream-Branch von '%s' zu '%s' von '%s' setzen\n"
-
-#: transport.c:152
-#, c-format
-msgid "transport: invalid depth option '%s'"
-msgstr "transport: ungültige --depth Option '%s'"
+msgid ""
+"unrecognized setting %s for option rebase.missingCommitsCheck. Ignoring."
+msgstr ""
+"Nicht erkannte Einstellung %s für Option rebase.missingCommitsCheck. "
+"Ignoriere."
 
-#: transport.c:916
-#, c-format
+#: rebase-interactive.c:35
 msgid ""
-"The following submodule paths contain changes that can\n"
-"not be found on any remote:\n"
+"\n"
+"Commands:\n"
+"p, pick <commit> = use commit\n"
+"r, reword <commit> = use commit, but edit the commit message\n"
+"e, edit <commit> = use commit, but stop for amending\n"
+"s, squash <commit> = use commit, but meld into previous commit\n"
+"f, fixup <commit> = like \"squash\", but discard this commit's log message\n"
+"x, exec <command> = run command (the rest of the line) using shell\n"
+"b, break = stop here (continue rebase later with 'git rebase --continue')\n"
+"d, drop <commit> = remove commit\n"
+"l, label <label> = label current HEAD with a name\n"
+"t, reset <label> = reset HEAD to a label\n"
+"m, merge [-C <commit> | -c <commit>] <label> [# <oneline>]\n"
+".       create a merge commit using the original merge commit's\n"
+".       message (or the oneline, if no original merge commit was\n"
+".       specified). Use -c <commit> to reword the commit message.\n"
+"\n"
+"These lines can be re-ordered; they are executed from top to bottom.\n"
 msgstr ""
-"Die folgenden Submodul-Pfade enthalten Änderungen, die in keinem\n"
-"Remote-Repository gefunden wurden:\n"
+"\n"
+"Befehle:\n"
+"p, pick <Commit> = Commit verwenden\n"
+"r, reword <Commit> = Commit verwenden, aber Commit-Beschreibung bearbeiten\n"
+"e, edit <Commit> = Commit verwenden, aber zum Nachbessern anhalten\n"
+"s, squash <Commit> = Commit verwenden, aber mit vorherigem Commit vereinen\n"
+"f, fixup <Commit> = wie \"squash\", aber diese Commit-Beschreibung "
+"verwerfen\n"
+"x, exec <Commit> = Befehl (Rest der Zeile) mittels Shell ausführen\n"
+"b, break = hier anhalten (Rebase später mit 'git rebase --continue' "
+"fortsetzen)\n"
+"d, drop <Commit> = Commit entfernen\n"
+"l, label <Label> = aktuellen HEAD mit Label versehen\n"
+"t, reset <Label> = HEAD zu einem Label umsetzen\n"
+"m, merge [-C <Commit> | -c <Commit>] <Label> [# <eineZeile>]\n"
+".       Merge-Commit mit der originalen Merge-Commit-Beschreibung erstellen\n"
+".       (oder die eine Zeile, wenn keine originale Merge-Commit-"
+"Beschreibung\n"
+".       spezifiziert ist). Benutzen Sie -c <Commit> zum Bearbeiten der\n"
+".       Commit-Beschreibung.\n"
+"\n"
+"Diese Zeilen können umsortiert werden; Sie werden von oben nach unten\n"
+"ausgeführt.\n"
 
-#: transport.c:920
+#: rebase-interactive.c:56
 #, c-format
+msgid "Rebase %s onto %s (%d command)"
+msgid_plural "Rebase %s onto %s (%d commands)"
+msgstr[0] "Rebase von %s auf %s (%d Kommando)"
+msgstr[1] "Rebase von %s auf %s (%d Kommandos)"
+
+#: rebase-interactive.c:65 git-rebase--preserve-merges.sh:228
 msgid ""
 "\n"
-"Please try\n"
+"Do not remove any line. Use 'drop' explicitly to remove a commit.\n"
+msgstr ""
 "\n"
-"\tgit push --recurse-submodules=on-demand\n"
+"Keine Zeile entfernen. Benutzen Sie 'drop', um explizit einen Commit zu\n"
+"entfernen.\n"
+
+#: rebase-interactive.c:68 git-rebase--preserve-merges.sh:232
+msgid ""
 "\n"
-"or cd to the path and use\n"
+"If you remove a line here THAT COMMIT WILL BE LOST.\n"
+msgstr ""
 "\n"
-"\tgit push\n"
+"Wenn Sie hier eine Zeile entfernen, wird DIESER COMMIT VERLOREN GEHEN.\n"
+
+#: rebase-interactive.c:74 git-rebase--preserve-merges.sh:871
+msgid ""
 "\n"
-"to push them to a remote.\n"
+"You are editing the todo file of an ongoing interactive rebase.\n"
+"To continue rebase after editing, run:\n"
+"    git rebase --continue\n"
 "\n"
 msgstr ""
 "\n"
-"Bitte versuchen Sie\n"
+"Sie bearbeiten gerade die TODO-Datei eines laufenden interaktiven Rebase.\n"
+"Um den Rebase nach dem Editieren fortzusetzen, führen Sie aus:\n"
+"    git rebase --continue\n"
 "\n"
-"\tgit push --recurse-submodules=on-demand\n"
+
+#: rebase-interactive.c:79 git-rebase--preserve-merges.sh:948
+msgid ""
 "\n"
-"oder wechseln Sie in das Verzeichnis und benutzen Sie\n"
+"However, if you remove everything, the rebase will be aborted.\n"
 "\n"
-"\tgit push\n"
+msgstr ""
 "\n"
-"zum Versenden zu einem Remote-Repository.\n"
+"Wenn Sie jedoch alles löschen, wird der Rebase abgebrochen.\n"
 "\n"
 
-#: transport.c:928
-msgid "Aborting."
-msgstr "Abbruch."
+#: rebase-interactive.c:85 git-rebase--preserve-merges.sh:955
+msgid "Note that empty commits are commented out"
+msgstr "Leere Commits sind auskommentiert."
 
-#: transport-helper.c:1079
+#: rebase-interactive.c:105 rerere.c:485 rerere.c:692 sequencer.c:3536
+#: sequencer.c:3562 sequencer.c:5263 builtin/fsck.c:346 builtin/rebase.c:254
 #, c-format
-msgid "Could not read ref %s"
-msgstr "Konnte Referenz %s nicht lesen."
-
-#: tree-walk.c:31
-msgid "too-short tree object"
-msgstr "zu kurzes Tree-Objekt"
-
-#: tree-walk.c:37
-msgid "malformed mode in tree entry"
-msgstr "fehlerhafter Modus in Tree-Eintrag"
-
-#: tree-walk.c:41
-msgid "empty filename in tree entry"
-msgstr "leerer Dateiname in Tree-Eintrag"
+msgid "could not write '%s'"
+msgstr "Konnte '%s' nicht schreiben."
 
-#: tree-walk.c:114
-msgid "too-short tree file"
-msgstr "zu kurze Tree-Datei"
+#: rebase-interactive.c:108
+#, c-format
+msgid "could not copy '%s' to '%s'."
+msgstr "Konnte '%s' nicht nach '%s' kopieren."
 
-#: unpack-trees.c:108
+#: rebase-interactive.c:173
 #, c-format
 msgid ""
-"Your local changes to the following files would be overwritten by checkout:\n"
-"%%sPlease commit your changes or stash them before you switch branches."
+"Warning: some commits may have been dropped accidentally.\n"
+"Dropped commits (newer to older):\n"
 msgstr ""
-"Ihre lokalen Änderungen in den folgenden Dateien würden beim Auschecken\n"
-"überschrieben werden:\n"
-"%%sBitte committen oder stashen Sie Ihre Änderungen, bevor Sie Branches\n"
-"wechseln."
+"Warnung: Einige Commits könnten aus Versehen entfernt worden sein.\n"
+"Entfernte Commits (neu zu alt):\n"
 
-#: unpack-trees.c:110
+#: rebase-interactive.c:180
 #, c-format
 msgid ""
-"Your local changes to the following files would be overwritten by checkout:\n"
-"%%s"
+"To avoid this message, use \"drop\" to explicitly remove a commit.\n"
+"\n"
+"Use 'git config rebase.missingCommitsCheck' to change the level of "
+"warnings.\n"
+"The possible behaviours are: ignore, warn, error.\n"
+"\n"
 msgstr ""
-"Ihre lokalen Änderungen in den folgenden Dateien würden beim Auschecken\n"
-"überschrieben werden:\n"
-"%%s"
+"Um diese Meldung zu vermeiden, benutzen Sie \"drop\", um exlizit Commits zu\n"
+"entfernen.\n"
+"\n"
+"Benutzen Sie 'git config rebase.missingCommitsCheck', um die Stufe der\n"
+"Warnungen zu ändern.\n"
+"Die möglichen Verhaltensweisen sind: ignore, warn, error.\n"
 
-#: unpack-trees.c:113
+#: refs.c:262
 #, c-format
-msgid ""
-"Your local changes to the following files would be overwritten by merge:\n"
-"%%sPlease commit your changes or stash them before you merge."
-msgstr ""
-"Ihre lokalen Änderungen in den folgenden Dateien würden durch den Merge\n"
-"überschrieben werden:\n"
-"%%sBitte committen oder stashen Sie Ihre Änderungen, bevor Sie mergen."
+msgid "%s does not point to a valid object!"
+msgstr "%s zeigt auf kein gültiges Objekt!"
 
-#: unpack-trees.c:115
+#: refs.c:667
 #, c-format
-msgid ""
-"Your local changes to the following files would be overwritten by merge:\n"
-"%%s"
-msgstr ""
-"Ihre lokalen Änderungen in den folgenden Dateien würden durch den Merge\n"
-"überschrieben werden:\n"
-"%%s"
+msgid "ignoring dangling symref %s"
+msgstr "Ignoriere unreferenzierte symbolische Referenz %s"
 
-#: unpack-trees.c:118
+#: refs.c:669 ref-filter.c:2098
 #, c-format
-msgid ""
-"Your local changes to the following files would be overwritten by %s:\n"
-"%%sPlease commit your changes or stash them before you %s."
-msgstr ""
-"Ihre lokalen Änderungen in den folgenden Dateien würden durch %s\n"
-"überschrieben werden:\n"
-"%%sBitte committen oder stashen Sie Ihre Änderungen, bevor Sie %s ausführen."
+msgid "ignoring broken ref %s"
+msgstr "Ignoriere fehlerhafte Referenz %s"
 
-#: unpack-trees.c:120
+#: refs.c:804
 #, c-format
-msgid ""
-"Your local changes to the following files would be overwritten by %s:\n"
-"%%s"
-msgstr ""
-"Ihre lokalen Änderungen würden durch %s überschrieben werden.\n"
-"%%s"
+msgid "could not open '%s' for writing: %s"
+msgstr "Konnte '%s' nicht zum Schreiben öffnen: %s"
 
-#: unpack-trees.c:125
+#: refs.c:814 refs.c:865
 #, c-format
-msgid ""
-"Updating the following directories would lose untracked files in them:\n"
-"%s"
-msgstr ""
-"Durch die Aktualisierung der folgenden Verzeichnisse würden unversionierte\n"
-"Dateien in diesen Verzeichnissen verloren gehen:\n"
-"%s"
+msgid "could not read ref '%s'"
+msgstr "Konnte Referenz '%s' nicht lesen."
 
-#: unpack-trees.c:129
+#: refs.c:820
 #, c-format
-msgid ""
-"The following untracked working tree files would be removed by checkout:\n"
-"%%sPlease move or remove them before you switch branches."
-msgstr ""
-"Die folgenden unversionierten Dateien im Arbeitsverzeichnis würden durch\n"
-"den Checkout entfernt werden:\n"
-"%%sBitte verschieben oder entfernen Sie diese, bevor Sie Branches wechseln."
+msgid "ref '%s' already exists"
+msgstr "Referenz '%s' existiert bereits."
 
-#: unpack-trees.c:131
+#: refs.c:825
 #, c-format
-msgid ""
-"The following untracked working tree files would be removed by checkout:\n"
-"%%s"
-msgstr ""
-"Die folgenden unversionierten Dateien im Arbeitsverzeichnis würden durch "
-"den\n"
-"Checkout entfernt werden:\n"
-"%%s"
+msgid "unexpected object ID when writing '%s'"
+msgstr "Unerwartete Objekt-ID beim Schreiben von '%s'."
 
-#: unpack-trees.c:134
+#: refs.c:833 sequencer.c:405 sequencer.c:2793 sequencer.c:2997
+#: sequencer.c:3011 sequencer.c:3269 sequencer.c:5179 strbuf.c:1142
+#: wrapper.c:620
 #, c-format
-msgid ""
-"The following untracked working tree files would be removed by merge:\n"
-"%%sPlease move or remove them before you merge."
-msgstr ""
-"Die folgenden unversionierten Dateien im Arbeitsverzeichnis würden durch\n"
-"den Merge entfernt werden:\n"
-"%%sBitte verschieben oder entfernen Sie diese, bevor sie mergen."
+msgid "could not write to '%s'"
+msgstr "Konnte nicht nach '%s' schreiben."
 
-#: unpack-trees.c:136
+#: refs.c:860 strbuf.c:1140 wrapper.c:188 wrapper.c:358 builtin/am.c:714
+#: builtin/rebase.c:1031
 #, c-format
-msgid ""
-"The following untracked working tree files would be removed by merge:\n"
-"%%s"
-msgstr ""
-"Die folgenden unversionierten Dateien im Arbeitsverzeichnis würden durch "
-"den\n"
-"Merge entfernt werden:\n"
-"%%s"
+msgid "could not open '%s' for writing"
+msgstr "Konnte '%s' nicht zum Schreiben öffnen."
 
-#: unpack-trees.c:139
+#: refs.c:867
 #, c-format
-msgid ""
-"The following untracked working tree files would be removed by %s:\n"
-"%%sPlease move or remove them before you %s."
-msgstr ""
-"Die folgenden unversionierten Dateien im Arbeitsverzeichnis würden durch\n"
-"den %s entfernt werden:\n"
-"%%sBitte verschieben oder entfernen Sie diese, bevor sie %s ausführen."
+msgid "unexpected object ID when deleting '%s'"
+msgstr "Unerwartete Objekt-ID beim Löschen von '%s'."
 
-#: unpack-trees.c:141
+#: refs.c:998
 #, c-format
-msgid ""
-"The following untracked working tree files would be removed by %s:\n"
-"%%s"
-msgstr ""
-"Die folgenden unversionierten Dateien im Arbeitsverzeichnis würden durch\n"
-"den %s entfernt werden:\n"
-"%%s"
+msgid "log for ref %s has gap after %s"
+msgstr "Log für Referenz %s hat eine Lücke nach %s."
 
-#: unpack-trees.c:146
+#: refs.c:1004
 #, c-format
-msgid ""
-"The following untracked working tree files would be overwritten by "
-"checkout:\n"
-"%%sPlease move or remove them before you switch branches."
-msgstr ""
-"Die folgenden unversionierten Dateien im Arbeitsverzeichnis würden durch\n"
-"den Checkout überschrieben werden:\n"
-"%%sBitte verschieben oder entfernen Sie diese, bevor Sie Branches wechseln."
+msgid "log for ref %s unexpectedly ended on %s"
+msgstr "Log für Referenz %s unerwartet bei %s beendet."
 
-#: unpack-trees.c:148
+#: refs.c:1063
 #, c-format
-msgid ""
-"The following untracked working tree files would be overwritten by "
-"checkout:\n"
-"%%s"
-msgstr ""
-"Die folgenden unversionierten Dateien im Arbeitsverzeichnis würden durch "
-"den\n"
-"Checkout überschrieben werden:\n"
-"%%s"
+msgid "log for %s is empty"
+msgstr "Log für %s ist leer."
 
-#: unpack-trees.c:151
+#: refs.c:1155
 #, c-format
-msgid ""
-"The following untracked working tree files would be overwritten by merge:\n"
-"%%sPlease move or remove them before you merge."
-msgstr ""
-"Die folgenden unversionierten Dateien im Arbeitsverzeichnis würden durch\n"
-"den Merge überschrieben werden:\n"
-"%%sBitte verschieben oder entfernen Sie diese, bevor Sie mergen."
+msgid "refusing to update ref with bad name '%s'"
+msgstr "Verweigere Aktualisierung einer Referenz mit fehlerhaftem Namen '%s'."
 
-#: unpack-trees.c:153
+#: refs.c:1231
 #, c-format
-msgid ""
-"The following untracked working tree files would be overwritten by merge:\n"
-"%%s"
-msgstr ""
-"Die folgenden unversionierten Dateien im Arbeitsverzeichnis würden durch\n"
-"den Merge überschrieben werden:\n"
-"%%s"
+msgid "update_ref failed for ref '%s': %s"
+msgstr "update_ref für Referenz '%s' fehlgeschlagen: %s"
 
-#: unpack-trees.c:156
+#: refs.c:2023
 #, c-format
-msgid ""
-"The following untracked working tree files would be overwritten by %s:\n"
-"%%sPlease move or remove them before you %s."
-msgstr ""
-"Die folgenden unversionierten Dateien im Arbeitsverzeichnis würden durch\n"
-"den %s überschrieben werden:\n"
-"%%sBitte verschieben oder entfernen Sie diese, bevor sie %s ausführen."
+msgid "multiple updates for ref '%s' not allowed"
+msgstr "Mehrere Aktualisierungen für Referenz '%s' nicht erlaubt."
 
-#: unpack-trees.c:158
-#, c-format
-msgid ""
-"The following untracked working tree files would be overwritten by %s:\n"
-"%%s"
+#: refs.c:2055
+msgid "ref updates forbidden inside quarantine environment"
 msgstr ""
-"Die folgenden unversionierten Dateien im Arbeitsverzeichnis würden durch "
-"den\n"
-"%s überschrieben werden:\n"
-"%%s"
+"Aktualisierungen von Referenzen ist innerhalb der Quarantäne-Umgebung "
+"verboten."
 
-#: unpack-trees.c:165
+#: refs.c:2151 refs.c:2181
 #, c-format
-msgid "Entry '%s' overlaps with '%s'.  Cannot bind."
-msgstr "Eintrag '%s' überschneidet sich mit '%s'. Kann nicht verbinden."
+msgid "'%s' exists; cannot create '%s'"
+msgstr "'%s' existiert; kann '%s' nicht erstellen"
 
-#: unpack-trees.c:168
+#: refs.c:2157 refs.c:2192
 #, c-format
-msgid ""
-"Cannot update sparse checkout: the following entries are not up to date:\n"
-"%s"
-msgstr ""
-"Kann partiellen Checkout nicht aktualisieren: die folgenden Einträge\n"
-"sind nicht aktuell:\n"
-"%s"
+msgid "cannot process '%s' and '%s' at the same time"
+msgstr "Kann '%s' und '%s' nicht zur selben Zeit verarbeiten."
 
-#: unpack-trees.c:170
+#: refs/files-backend.c:1234
 #, c-format
-msgid ""
-"The following working tree files would be overwritten by sparse checkout "
-"update:\n"
-"%s"
-msgstr ""
-"Die folgenden Dateien im Arbeitsverzeichnis würden durch die Aktualisierung\n"
-"über einen partiellen Checkout überschrieben werden:\n"
-"%s"
+msgid "could not remove reference %s"
+msgstr "Konnte Referenz %s nicht löschen"
 
-#: unpack-trees.c:172
+#: refs/files-backend.c:1248 refs/packed-backend.c:1541
+#: refs/packed-backend.c:1551
 #, c-format
-msgid ""
-"The following working tree files would be removed by sparse checkout "
-"update:\n"
-"%s"
-msgstr ""
-"Die folgenden Dateien im Arbeitsverzeichnis würden durch die Aktualisierung\n"
-"über einen partiellen Checkout entfernt werden:\n"
-"%s"
+msgid "could not delete reference %s: %s"
+msgstr "Konnte Referenz %s nicht entfernen: %s"
 
-#: unpack-trees.c:174
+#: refs/files-backend.c:1251 refs/packed-backend.c:1554
 #, c-format
-msgid ""
-"Cannot update submodule:\n"
-"%s"
-msgstr ""
-"Kann Submodul nicht aktualisieren:\n"
-"%s"
+msgid "could not delete references: %s"
+msgstr "Konnte Referenzen nicht entfernen: %s"
 
-#: unpack-trees.c:251
+#: refspec.c:137
 #, c-format
-msgid "Aborting\n"
-msgstr "Abbruch\n"
-
-#: unpack-trees.c:333
-msgid "Checking out files"
-msgstr "Checke Dateien aus"
+msgid "invalid refspec '%s'"
+msgstr "Ungültige Refspec '%s'"
 
-#: urlmatch.c:163
-msgid "invalid URL scheme name or missing '://' suffix"
-msgstr "Ungültiges URL-Schema oder Suffix '://' fehlt"
+#: ref-filter.c:42 wt-status.c:1938
+msgid "gone"
+msgstr "entfernt"
 
-#: urlmatch.c:187 urlmatch.c:346 urlmatch.c:405
+#: ref-filter.c:43
 #, c-format
-msgid "invalid %XX escape sequence"
-msgstr "ungültige Escape-Sequenz %XX"
+msgid "ahead %d"
+msgstr "%d voraus"
 
-#: urlmatch.c:215
-msgid "missing host and scheme is not 'file:'"
-msgstr "fehlender Host und Schema ist nicht 'file:'"
+#: ref-filter.c:44
+#, c-format
+msgid "behind %d"
+msgstr "%d hinterher"
 
-#: urlmatch.c:232
-msgid "a 'file:' URL may not have a port number"
-msgstr "eine 'file:' URL darf keine Portnummer enthalten"
+#: ref-filter.c:45
+#, c-format
+msgid "ahead %d, behind %d"
+msgstr "%d voraus, %d hinterher"
 
-#: urlmatch.c:247
-msgid "invalid characters in host name"
-msgstr "Hostname enthält ungültige Zeichen"
+#: ref-filter.c:165
+#, c-format
+msgid "expected format: %%(color:<color>)"
+msgstr "Erwartetes Format: %%(color:<Farbe>)"
 
-#: urlmatch.c:292 urlmatch.c:303
-msgid "invalid port number"
-msgstr "ungültige Portnummer"
+#: ref-filter.c:167
+#, c-format
+msgid "unrecognized color: %%(color:%s)"
+msgstr "nicht erkannte Farbe: %%(color:%s)"
 
-#: urlmatch.c:371
-msgid "invalid '..' path segment"
-msgstr "ungültiges '..' Pfadsegment"
+#: ref-filter.c:189
+#, c-format
+msgid "Integer value expected refname:lstrip=%s"
+msgstr "Positiver Wert erwartet refname:lstrip=%s"
 
-#: worktree.c:245 builtin/am.c:2147
+#: ref-filter.c:193
 #, c-format
-msgid "failed to read '%s'"
-msgstr "Fehler beim Lesen von '%s'"
+msgid "Integer value expected refname:rstrip=%s"
+msgstr "Positiver Wert erwartet refname:rstrip=%s"
 
-#: worktree.c:291
+#: ref-filter.c:195
 #, c-format
-msgid "'%s' at main working tree is not the repository directory"
-msgstr "'%s' im Hauptarbeitsverzeichnis ist nicht das Repository-Verzeichnis."
+msgid "unrecognized %%(%s) argument: %s"
+msgstr "nicht erkanntes %%(%s) Argument: %s"
 
-#: worktree.c:302
+#: ref-filter.c:250
 #, c-format
-msgid "'%s' file does not contain absolute path to the working tree location"
-msgstr "'%s' Datei enthält nicht den absoluten Pfad zum Arbeitsverzeichnis."
+msgid "%%(objecttype) does not take arguments"
+msgstr "%%(objecttype) akzeptiert keine Argumente"
 
-#: worktree.c:314
+#: ref-filter.c:272
 #, c-format
-msgid "'%s' does not exist"
-msgstr "'%s' existiert nicht."
+msgid "unrecognized %%(objectsize) argument: %s"
+msgstr "nicht erkanntes %%(objectsize) Argument: %s"
 
-#: worktree.c:320
+#: ref-filter.c:280
 #, c-format
-msgid "'%s' is not a .git file, error code %d"
-msgstr "'%s' ist keine .git-Datei, Fehlercode %d"
+msgid "%%(deltabase) does not take arguments"
+msgstr "%%(deltabase) akzeptiert keine Argumente"
 
-#: worktree.c:328
+#: ref-filter.c:292
 #, c-format
-msgid "'%s' does not point back to '%s'"
-msgstr "'%s' zeigt nicht zurück auf '%s'"
+msgid "%%(body) does not take arguments"
+msgstr "%%(body) akzeptiert keine Argumente"
 
-#: wrapper.c:223 wrapper.c:393
+#: ref-filter.c:301
 #, c-format
-msgid "could not open '%s' for reading and writing"
-msgstr "Konnte '%s' nicht zum Lesen und Schreiben öffnen."
+msgid "%%(subject) does not take arguments"
+msgstr "%%(subject) akzeptiert keine Argumente"
 
-#: wrapper.c:227 wrapper.c:397 builtin/am.c:320 builtin/am.c:770
-#: builtin/am.c:862 builtin/merge.c:1044
+#: ref-filter.c:323
 #, c-format
-msgid "could not open '%s' for reading"
-msgstr "Konnte '%s' nicht zum Lesen öffnen."
+msgid "unknown %%(trailers) argument: %s"
+msgstr "unbekanntes %%(trailers) Argument: %s"
 
-#: wrapper.c:424 wrapper.c:624
+#: ref-filter.c:352
 #, c-format
-msgid "unable to access '%s'"
-msgstr "konnte nicht auf '%s' zugreifen"
+msgid "positive value expected contents:lines=%s"
+msgstr "Positiver Wert erwartet contents:lines=%s"
 
-#: wrapper.c:632
-msgid "unable to get current working directory"
-msgstr "Konnte aktuelles Arbeitsverzeichnis nicht bekommen."
+#: ref-filter.c:354
+#, c-format
+msgid "unrecognized %%(contents) argument: %s"
+msgstr "nicht erkanntes %%(contents) Argument: %s"
 
-#: wt-status.c:151
-msgid "Unmerged paths:"
-msgstr "Nicht zusammengeführte Pfade:"
+#: ref-filter.c:369
+#, c-format
+msgid "positive value expected objectname:short=%s"
+msgstr "Positiver Wert erwartet objectname:short=%s"
 
-#: wt-status.c:178 wt-status.c:205
+#: ref-filter.c:373
 #, c-format
-msgid "  (use \"git reset %s <file>...\" to unstage)"
-msgstr ""
-"  (benutzen Sie \"git reset %s <Datei>...\" zum Entfernen aus der Staging-"
-"Area)"
+msgid "unrecognized %%(objectname) argument: %s"
+msgstr "nicht erkanntes %%(objectname) Argument: %s"
 
-#: wt-status.c:180 wt-status.c:207
-msgid "  (use \"git rm --cached <file>...\" to unstage)"
-msgstr ""
-"  (benutzen Sie \"git rm --cached <Datei>...\" zum Entfernen aus der Staging-"
-"Area)"
+#: ref-filter.c:403
+#, c-format
+msgid "expected format: %%(align:<width>,<position>)"
+msgstr "Erwartetes Format: %%(align:<Breite>,<Position>)"
 
-#: wt-status.c:184
-msgid "  (use \"git add <file>...\" to mark resolution)"
-msgstr ""
-"  (benutzen Sie \"git add/rm <Datei>...\", um die Auflösung zu markieren)"
+#: ref-filter.c:415
+#, c-format
+msgid "unrecognized position:%s"
+msgstr "nicht erkannte Position:%s"
 
-#: wt-status.c:186 wt-status.c:190
-msgid "  (use \"git add/rm <file>...\" as appropriate to mark resolution)"
-msgstr ""
-"  (benutzen Sie \"git add/rm <Datei>...\", um die Auflösung entsprechend zu "
-"markieren)"
+#: ref-filter.c:422
+#, c-format
+msgid "unrecognized width:%s"
+msgstr "nicht erkannte Breite:%s"
 
-#: wt-status.c:188
-msgid "  (use \"git rm <file>...\" to mark resolution)"
-msgstr ""
-"  (benutzen Sie \"git add/rm <Datei>...\", um die Auflösung zu markieren)"
+#: ref-filter.c:431
+#, c-format
+msgid "unrecognized %%(align) argument: %s"
+msgstr "nicht erkanntes %%(align) Argument: %s"
 
-#: wt-status.c:199 wt-status.c:1007
-msgid "Changes to be committed:"
-msgstr "zum Commit vorgemerkte Änderungen:"
+#: ref-filter.c:439
+#, c-format
+msgid "positive width expected with the %%(align) atom"
+msgstr "Positive Breitenangabe für %%(align) erwartet"
 
-#: wt-status.c:217 wt-status.c:1016
-msgid "Changes not staged for commit:"
-msgstr "Änderungen, die nicht zum Commit vorgemerkt sind:"
+#: ref-filter.c:457
+#, c-format
+msgid "unrecognized %%(if) argument: %s"
+msgstr "nicht erkanntes %%(if) Argument: %s"
 
-#: wt-status.c:221
-msgid "  (use \"git add <file>...\" to update what will be committed)"
-msgstr ""
-"  (benutzen Sie \"git add <Datei>...\", um die Änderungen zum Commit "
-"vorzumerken)"
+#: ref-filter.c:559
+#, c-format
+msgid "malformed field name: %.*s"
+msgstr "Fehlerhafter Feldname: %.*s"
 
-#: wt-status.c:223
-msgid "  (use \"git add/rm <file>...\" to update what will be committed)"
-msgstr ""
-"  (benutzen Sie \"git add/rm <Datei>...\", um die Änderungen zum Commit "
-"vorzumerken)"
+#: ref-filter.c:586
+#, c-format
+msgid "unknown field name: %.*s"
+msgstr "Unbekannter Feldname: %.*s"
 
-#: wt-status.c:224
+#: ref-filter.c:590
+#, c-format
 msgid ""
-"  (use \"git checkout -- <file>...\" to discard changes in working directory)"
+"not a git repository, but the field '%.*s' requires access to object data"
 msgstr ""
-"  (benutzen Sie \"git checkout -- <Datei>...\", um die Änderungen im "
-"Arbeitsverzeichnis zu verwerfen)"
+"Kein Git-Repository, aber das Feld '%.*s' erfordert Zugriff auf Objektdaten."
 
-#: wt-status.c:226
-msgid "  (commit or discard the untracked or modified content in submodules)"
-msgstr ""
-"  (committen oder verwerfen Sie den unversionierten oder geänderten Inhalt "
-"in den Submodulen)"
+#: ref-filter.c:714
+#, c-format
+msgid "format: %%(if) atom used without a %%(then) atom"
+msgstr "format: %%(if) Atom ohne ein %%(then) Atom verwendet"
 
-#: wt-status.c:238
+#: ref-filter.c:777
 #, c-format
-msgid "  (use \"git %s <file>...\" to include in what will be committed)"
-msgstr ""
-"  (benutzen Sie \"git %s <Datei>...\", um die Änderungen zum Commit "
-"vorzumerken)"
+msgid "format: %%(then) atom used without an %%(if) atom"
+msgstr "format: %%(then) Atom ohne ein %%(if) Atom verwendet"
 
-#: wt-status.c:253
-msgid "both deleted:"
-msgstr "beide gelöscht:"
+#: ref-filter.c:779
+#, c-format
+msgid "format: %%(then) atom used more than once"
+msgstr "format: %%(then) Atom mehr als einmal verwendet"
 
-#: wt-status.c:255
-msgid "added by us:"
-msgstr "von uns hinzugefügt:"
+#: ref-filter.c:781
+#, c-format
+msgid "format: %%(then) atom used after %%(else)"
+msgstr "format: %%(then) Atom nach %%(else) verwendet"
 
-#: wt-status.c:257
-msgid "deleted by them:"
-msgstr "von denen gelöscht:"
+#: ref-filter.c:809
+#, c-format
+msgid "format: %%(else) atom used without an %%(if) atom"
+msgstr "format: %%(else) Atom ohne ein %%(if) Atom verwendet"
 
-#: wt-status.c:259
-msgid "added by them:"
-msgstr "von denen hinzugefügt:"
+#: ref-filter.c:811
+#, c-format
+msgid "format: %%(else) atom used without a %%(then) atom"
+msgstr "Format: %%(else) Atom ohne ein %%(then) Atom verwendet"
 
-#: wt-status.c:261
-msgid "deleted by us:"
-msgstr "von uns gelöscht:"
+#: ref-filter.c:813
+#, c-format
+msgid "format: %%(else) atom used more than once"
+msgstr "Format: %%(end) Atom mehr als einmal verwendet"
 
-#: wt-status.c:263
-msgid "both added:"
-msgstr "von beiden hinzugefügt:"
-
-#: wt-status.c:265
-msgid "both modified:"
-msgstr "von beiden geändert:"
+#: ref-filter.c:828
+#, c-format
+msgid "format: %%(end) atom used without corresponding atom"
+msgstr "Format: %%(end) Atom ohne zugehöriges Atom verwendet"
 
-#: wt-status.c:275
-msgid "new file:"
-msgstr "neue Datei:"
+#: ref-filter.c:885
+#, c-format
+msgid "malformed format string %s"
+msgstr "Fehlerhafter Formatierungsstring %s"
 
-#: wt-status.c:277
-msgid "copied:"
-msgstr "kopiert:"
+#: ref-filter.c:1488
+#, c-format
+msgid "no branch, rebasing %s"
+msgstr "kein Branch, Rebase von %s"
 
-#: wt-status.c:279
-msgid "deleted:"
-msgstr "gelöscht:"
+#: ref-filter.c:1491
+#, c-format
+msgid "no branch, rebasing detached HEAD %s"
+msgstr "kein Branch, Rebase von losgelöstem HEAD %s"
 
-#: wt-status.c:281
-msgid "modified:"
-msgstr "geändert:"
+#: ref-filter.c:1494
+#, c-format
+msgid "no branch, bisect started on %s"
+msgstr "kein Branch, binäre Suche begonnen bei %s"
 
-#: wt-status.c:283
-msgid "renamed:"
-msgstr "umbenannt:"
+#: ref-filter.c:1504
+msgid "no branch"
+msgstr "kein Branch"
 
-#: wt-status.c:285
-msgid "typechange:"
-msgstr "Typänderung:"
+#: ref-filter.c:1540 ref-filter.c:1749
+#, c-format
+msgid "missing object %s for %s"
+msgstr "Objekt %s fehlt für %s"
 
-#: wt-status.c:287
-msgid "unknown:"
-msgstr "unbekannt:"
+#: ref-filter.c:1550
+#, c-format
+msgid "parse_object_buffer failed on %s for %s"
+msgstr "parse_object_buffer bei %s für %s fehlgeschlagen"
 
-#: wt-status.c:289
-msgid "unmerged:"
-msgstr "nicht gemerged:"
+#: ref-filter.c:2004
+#, c-format
+msgid "malformed object at '%s'"
+msgstr "fehlerhaftes Objekt bei '%s'"
 
-#: wt-status.c:369
-msgid "new commits, "
-msgstr "neue Commits, "
+#: ref-filter.c:2093
+#, c-format
+msgid "ignoring ref with broken name %s"
+msgstr "Ignoriere Referenz mit fehlerhaftem Namen %s"
 
-#: wt-status.c:371
-msgid "modified content, "
-msgstr "geänderter Inhalt, "
+#: ref-filter.c:2389
+#, c-format
+msgid "format: %%(end) atom missing"
+msgstr "Format: %%(end) Atom fehlt"
 
-#: wt-status.c:373
-msgid "untracked content, "
-msgstr "unversionierter Inhalt, "
+#: ref-filter.c:2489
+#, c-format
+msgid "option `%s' is incompatible with --merged"
+msgstr "Die Option `%s' ist inkompatibel mit --merged."
 
-#: wt-status.c:847
+#: ref-filter.c:2492
 #, c-format
-msgid "Your stash currently has %d entry"
-msgid_plural "Your stash currently has %d entries"
-msgstr[0] "Ihr Stash hat gerade %d Eintrag"
-msgstr[1] "Ihr Stash hat gerade %d Einträge"
+msgid "option `%s' is incompatible with --no-merged"
+msgstr "Die Option `%s' ist inkompatibel mit --no-merged."
 
-#: wt-status.c:879
-msgid "Submodules changed but not updated:"
-msgstr "Submodule geändert, aber nicht aktualisiert:"
+#: ref-filter.c:2502
+#, c-format
+msgid "malformed object name %s"
+msgstr "Missgebildeter Objektname %s"
 
-#: wt-status.c:881
-msgid "Submodule changes to be committed:"
-msgstr "Änderungen in Submodul zum Committen:"
+#: ref-filter.c:2507
+#, c-format
+msgid "option `%s' must point to a commit"
+msgstr "Die Option `%s' muss auf einen Commit zeigen."
 
-#: wt-status.c:963
-msgid ""
-"Do not modify or remove the line above.\n"
-"Everything below it will be ignored."
+#: remote.c:366
+#, c-format
+msgid "config remote shorthand cannot begin with '/': %s"
 msgstr ""
-"Ändern oder entfernen Sie nicht die obige Zeile.\n"
-"Alles unterhalb von ihr wird ignoriert."
+"Kürzel für Remote-Repository in der Konfiguration kann nicht mit '/' "
+"beginnen: %s"
 
-#: wt-status.c:1076
-msgid "You have unmerged paths."
-msgstr "Sie haben nicht zusammengeführte Pfade."
+#: remote.c:413
+msgid "more than one receivepack given, using the first"
+msgstr "Mehr als ein receivepack-Befehl angegeben, benutze den ersten."
 
-#: wt-status.c:1079
-msgid "  (fix conflicts and run \"git commit\")"
-msgstr " (beheben Sie die Konflikte und führen Sie \"git commit\" aus)"
+#: remote.c:421
+msgid "more than one uploadpack given, using the first"
+msgstr "Mehr als ein uploadpack-Befehl angegeben, benutze den ersten."
 
-#: wt-status.c:1081
-msgid "  (use \"git merge --abort\" to abort the merge)"
-msgstr "  (benutzen Sie \"git merge --abort\", um den Merge abzubrechen)"
+#: remote.c:611
+#, c-format
+msgid "Cannot fetch both %s and %s to %s"
+msgstr "Kann 'fetch' nicht für sowohl %s als auch %s nach %s ausführen."
 
-#: wt-status.c:1086
-msgid "All conflicts fixed but you are still merging."
-msgstr "Alle Konflikte sind behoben, aber Sie sind immer noch beim Merge."
+#: remote.c:615
+#, c-format
+msgid "%s usually tracks %s, not %s"
+msgstr "%s folgt üblicherweise %s, nicht %s"
 
-#: wt-status.c:1089
-msgid "  (use \"git commit\" to conclude merge)"
-msgstr "  (benutzen Sie \"git commit\", um den Merge abzuschließen)"
+#: remote.c:619
+#, c-format
+msgid "%s tracks both %s and %s"
+msgstr "%s folgt sowohl %s als auch %s"
 
-#: wt-status.c:1099
-msgid "You are in the middle of an am session."
-msgstr "Eine \"am\"-Sitzung ist im Gange."
+#: remote.c:687
+#, c-format
+msgid "key '%s' of pattern had no '*'"
+msgstr "Schlüssel '%s' des Musters hatte kein '*'."
 
-#: wt-status.c:1102
-msgid "The current patch is empty."
-msgstr "Der aktuelle Patch ist leer."
+#: remote.c:697
+#, c-format
+msgid "value '%s' of pattern has no '*'"
+msgstr "Wert '%s' des Musters hat kein '*'."
 
-#: wt-status.c:1106
-msgid "  (fix conflicts and then run \"git am --continue\")"
-msgstr ""
-"  (beheben Sie die Konflikte und führen Sie dann \"git am --continue\" aus)"
+#: remote.c:1003
+#, c-format
+msgid "src refspec %s does not match any"
+msgstr "Src-Refspec %s entspricht keiner Referenz."
 
-#: wt-status.c:1108
-msgid "  (use \"git am --skip\" to skip this patch)"
-msgstr "  (benutzen Sie \"git am --skip\", um diesen Patch auszulassen)"
+#: remote.c:1008
+#, c-format
+msgid "src refspec %s matches more than one"
+msgstr "Src-Refspec %s entspricht mehr als einer Referenz."
 
-#: wt-status.c:1110
-msgid "  (use \"git am --abort\" to restore the original branch)"
+#. TRANSLATORS: "matches '%s'%" is the <dst> part of "git push
+#. <remote> <src>:<dst>" push, and "being pushed ('%s')" is
+#. the <src>.
+#.
+#: remote.c:1023
+#, c-format
+msgid ""
+"The destination you provided is not a full refname (i.e.,\n"
+"starting with \"refs/\"). We tried to guess what you meant by:\n"
+"\n"
+"- Looking for a ref that matches '%s' on the remote side.\n"
+"- Checking if the <src> being pushed ('%s')\n"
+"  is a ref in \"refs/{heads,tags}/\". If so we add a corresponding\n"
+"  refs/{heads,tags}/ prefix on the remote side.\n"
+"\n"
+"Neither worked, so we gave up. You must fully qualify the ref."
 msgstr ""
-"  (benutzen Sie \"git am --abort\", um den ursprünglichen Branch "
-"wiederherzustellen)"
-
-#: wt-status.c:1242
-msgid "git-rebase-todo is missing."
-msgstr "git-rebase-todo fehlt."
+"Das angegebene Ziel ist kein vollständiger Referenzname (startet mit \"refs/"
+"\").\n"
+"Wir versuchten zu erraten, was Sie meinten, mit:\n"
+"\n"
+"- Suche einer Referenz, die mit '%s' übereinstimmt, auf der Remote-Seite\n"
+"- Prüfung, ob die versendete <Quelle> ('%s') eine Referenz in \"refs/{heads,"
+"tags}\"\n"
+"  ist, in dessen Falle wir einen entsprechenden refs/{heads,tags} Präfix "
+"auf\n"
+"  der Remote-Seite hinzufügen würden.\n"
+"\n"
+"Keines hat funktioniert, sodass wir aufgegeben haben. Sie müssen die\n"
+"Referenz mit vollqualifizierten Namen angeben."
 
-#: wt-status.c:1244
-msgid "No commands done."
-msgstr "Keine Befehle ausgeführt."
+#: remote.c:1043
+#, c-format
+msgid ""
+"The <src> part of the refspec is a commit object.\n"
+"Did you mean to create a new branch by pushing to\n"
+"'%s:refs/heads/%s'?"
+msgstr ""
+"Der <Quelle> Teil der Refspec ist ein Commit-Objekt.\n"
+"Meinten Sie, einen neuen Branch mittels Push nach\n"
+"'%s:refs/heads/%s' zu erstellen?"
 
-#: wt-status.c:1247
+#: remote.c:1048
 #, c-format
-msgid "Last command done (%d command done):"
-msgid_plural "Last commands done (%d commands done):"
-msgstr[0] "Zuletzt ausgeführter Befehl (%d Befehl ausgeführt):"
-msgstr[1] "Zuletzt ausgeführte Befehle (%d Befehle ausgeführt):"
+msgid ""
+"The <src> part of the refspec is a tag object.\n"
+"Did you mean to create a new tag by pushing to\n"
+"'%s:refs/tags/%s'?"
+msgstr ""
+"Der <Quelle> Teil der Refspec ist ein Tag-Objekt.\n"
+"Meinten Sie, einen neuen Tag mittels Push nach\n"
+"'%s:refs/tags/%s' zu erstellen?"
 
-#: wt-status.c:1258
+#: remote.c:1053
 #, c-format
-msgid "  (see more in file %s)"
-msgstr "  (mehr Informationen in Datei %s)"
+msgid ""
+"The <src> part of the refspec is a tree object.\n"
+"Did you mean to tag a new tree by pushing to\n"
+"'%s:refs/tags/%s'?"
+msgstr ""
+"Der <Quelle> Teil der Refspec ist ein Tree-Objekt.\n"
+"Meinten Sie, einen Tag für ein neues Tree-Objekt\n"
+"mittels Push nach '%s:refs/tags/'%s' zu erstellen?"
 
-#: wt-status.c:1263
-msgid "No commands remaining."
-msgstr "Keine Befehle verbleibend."
+#: remote.c:1058
+#, c-format
+msgid ""
+"The <src> part of the refspec is a blob object.\n"
+"Did you mean to tag a new blob by pushing to\n"
+"'%s:refs/tags/%s'?"
+msgstr ""
+"Der <Quelle> Teil der Refspec ist ein Blob-Objekt.\n"
+"Meinten Sie, einen Tag für ein neues Blob-Objekt\n"
+"mittels Push nach '%s:refs/tags/%s' zu erstellen?"
 
-#: wt-status.c:1266
+#: remote.c:1094
 #, c-format
-msgid "Next command to do (%d remaining command):"
-msgid_plural "Next commands to do (%d remaining commands):"
-msgstr[0] "Nächster auszuführender Befehl (%d Befehle verbleibend):"
-msgstr[1] "Nächste auszuführende Befehle (%d Befehle verbleibend):"
+msgid "%s cannot be resolved to branch"
+msgstr "%s kann nicht zu Branch aufgelöst werden."
 
-#: wt-status.c:1274
-msgid "  (use \"git rebase --edit-todo\" to view and edit)"
-msgstr "  (benutzen Sie \"git rebase --edit-todo\" zum Ansehen und Bearbeiten)"
+#: remote.c:1105
+#, c-format
+msgid "unable to delete '%s': remote ref does not exist"
+msgstr "Konnte '%s' nicht löschen: Remote-Referenz existiert nicht."
 
-#: wt-status.c:1287
+#: remote.c:1117
 #, c-format
-msgid "You are currently rebasing branch '%s' on '%s'."
-msgstr "Sie sind gerade beim Rebase von Branch '%s' auf '%s'."
+msgid "dst refspec %s matches more than one"
+msgstr "Dst-Refspec %s entspricht mehr als einer Referenz."
 
-#: wt-status.c:1292
-msgid "You are currently rebasing."
-msgstr "Sie sind gerade beim Rebase."
+#: remote.c:1124
+#, c-format
+msgid "dst ref %s receives from more than one src"
+msgstr "Dst-Referenz %s empfängt von mehr als einer Quelle"
 
-#: wt-status.c:1306
-msgid "  (fix conflicts and then run \"git rebase --continue\")"
-msgstr ""
-"  (beheben Sie die Konflikte und führen Sie dann \"git rebase --continue\" "
-"aus)"
+#: remote.c:1627 remote.c:1728
+msgid "HEAD does not point to a branch"
+msgstr "HEAD zeigt auf keinen Branch"
 
-#: wt-status.c:1308
-msgid "  (use \"git rebase --skip\" to skip this patch)"
-msgstr "  (benutzen Sie \"git rebase --skip\", um diesen Patch auszulassen)"
+#: remote.c:1636
+#, c-format
+msgid "no such branch: '%s'"
+msgstr "Kein solcher Branch: '%s'"
 
-#: wt-status.c:1310
-msgid "  (use \"git rebase --abort\" to check out the original branch)"
-msgstr ""
-"  (benutzen Sie \"git rebase --abort\", um den ursprünglichen Branch "
-"auszuchecken)"
+#: remote.c:1639
+#, c-format
+msgid "no upstream configured for branch '%s'"
+msgstr "Kein Upstream-Branch für Branch '%s' konfiguriert."
 
-#: wt-status.c:1316
-msgid "  (all conflicts fixed: run \"git rebase --continue\")"
-msgstr "  (alle Konflikte behoben: führen Sie \"git rebase --continue\" aus)"
+#: remote.c:1645
+#, c-format
+msgid "upstream branch '%s' not stored as a remote-tracking branch"
+msgstr "Upstream-Branch '%s' nicht als Remote-Tracking-Branch gespeichert"
 
-#: wt-status.c:1320
+#: remote.c:1660
 #, c-format
-msgid ""
-"You are currently splitting a commit while rebasing branch '%s' on '%s'."
+msgid "push destination '%s' on remote '%s' has no local tracking branch"
 msgstr ""
-"Sie teilen gerade einen Commit auf, während ein Rebase von Branch '%s' auf "
-"'%s' im Gange ist."
-
-#: wt-status.c:1325
-msgid "You are currently splitting a commit during a rebase."
-msgstr "Sie teilen gerade einen Commit während eines Rebase auf."
+"Ziel für \"push\" '%s' auf Remote-Repository '%s' hat keinen lokal gefolgten "
+"Branch"
 
-#: wt-status.c:1328
-msgid "  (Once your working directory is clean, run \"git rebase --continue\")"
-msgstr ""
-"  (Sobald Ihr Arbeitsverzeichnis unverändert ist, führen Sie \"git rebase --"
-"continue\" aus)"
+#: remote.c:1672
+#, c-format
+msgid "branch '%s' has no remote for pushing"
+msgstr "Branch '%s' hat keinen Upstream-Branch gesetzt"
 
-#: wt-status.c:1332
+#: remote.c:1682
 #, c-format
-msgid "You are currently editing a commit while rebasing branch '%s' on '%s'."
-msgstr ""
-"Sie editieren gerade einen Commit während eines Rebase von Branch '%s' auf "
-"'%s'."
+msgid "push refspecs for '%s' do not include '%s'"
+msgstr "Push-Refspecs für '%s' beinhalten nicht '%s'"
 
-#: wt-status.c:1337
-msgid "You are currently editing a commit during a rebase."
-msgstr "Sie editieren gerade einen Commit während eines Rebase."
+#: remote.c:1695
+msgid "push has no destination (push.default is 'nothing')"
+msgstr "kein Ziel für \"push\" (push.default ist 'nothing')"
 
-#: wt-status.c:1340
-msgid "  (use \"git commit --amend\" to amend the current commit)"
-msgstr ""
-"  (benutzen Sie \"git commit --amend\", um den aktuellen Commit "
-"nachzubessern)"
+#: remote.c:1717
+msgid "cannot resolve 'simple' push to a single destination"
+msgstr "kann einzelnes Ziel für \"push\" im Modus 'simple' nicht auflösen"
 
-#: wt-status.c:1342
-msgid ""
-"  (use \"git rebase --continue\" once you are satisfied with your changes)"
-msgstr ""
-"  (benutzen Sie \"git rebase --continue\" sobald Ihre Änderungen "
-"abgeschlossen sind)"
+#: remote.c:1843
+#, c-format
+msgid "couldn't find remote ref %s"
+msgstr "Konnte Remote-Referenz %s nicht finden."
 
-#: wt-status.c:1352
+#: remote.c:1856
 #, c-format
-msgid "You are currently cherry-picking commit %s."
-msgstr "Sie führen gerade \"cherry-pick\" von Commit %s aus."
+msgid "* Ignoring funny ref '%s' locally"
+msgstr "* Ignoriere sonderbare Referenz '%s' lokal"
 
-#: wt-status.c:1357
-msgid "  (fix conflicts and run \"git cherry-pick --continue\")"
+#: remote.c:2019
+#, c-format
+msgid "Your branch is based on '%s', but the upstream is gone.\n"
 msgstr ""
-"  (beheben Sie die Konflikte und führen Sie dann \"git cherry-pick --continue"
-"\" aus)"
+"Ihr Branch basiert auf '%s', aber der Upstream-Branch wurde entfernt.\n"
 
-#: wt-status.c:1360
-msgid "  (all conflicts fixed: run \"git cherry-pick --continue\")"
-msgstr ""
-"  (alle Konflikte behoben: führen Sie \"git cherry-pick --continue\" aus)"
+#: remote.c:2023
+msgid "  (use \"git branch --unset-upstream\" to fixup)\n"
+msgstr "  (benutzen Sie \"git branch --unset-upstream\" zum Beheben)\n"
 
-#: wt-status.c:1362
-msgid "  (use \"git cherry-pick --abort\" to cancel the cherry-pick operation)"
-msgstr ""
-"  (benutzen Sie \"git cherry-pick --abort\", um die Cherry-Pick-Operation "
-"abzubrechen)"
+#: remote.c:2026
+#, c-format
+msgid "Your branch is up to date with '%s'.\n"
+msgstr "Ihr Branch ist auf demselben Stand wie '%s'.\n"
 
-#: wt-status.c:1371
+#: remote.c:2030
 #, c-format
-msgid "You are currently reverting commit %s."
-msgstr "Sie sind gerade an einem Revert von Commit '%s'."
+msgid "Your branch and '%s' refer to different commits.\n"
+msgstr "Ihr Branch und '%s' zeigen auf unterschiedliche Commits.\n"
 
-#: wt-status.c:1376
-msgid "  (fix conflicts and run \"git revert --continue\")"
-msgstr ""
-"  (beheben Sie die Konflikte und führen Sie dann \"git revert --continue\" "
-"aus)"
+#: remote.c:2033
+#, c-format
+msgid "  (use \"%s\" for details)\n"
+msgstr "  (benutzen Sie \"%s\" für Details)\n"
 
-#: wt-status.c:1379
-msgid "  (all conflicts fixed: run \"git revert --continue\")"
-msgstr "  (alle Konflikte behoben: führen Sie \"git revert --continue\" aus)"
+#: remote.c:2037
+#, c-format
+msgid "Your branch is ahead of '%s' by %d commit.\n"
+msgid_plural "Your branch is ahead of '%s' by %d commits.\n"
+msgstr[0] "Ihr Branch ist %2$d Commit vor '%1$s'.\n"
+msgstr[1] "Ihr Branch ist %2$d Commits vor '%1$s'.\n"
 
-#: wt-status.c:1381
-msgid "  (use \"git revert --abort\" to cancel the revert operation)"
-msgstr ""
-"  (benutzen Sie \"git revert --abort\", um die Revert-Operation abzubrechen)"
+#: remote.c:2043
+msgid "  (use \"git push\" to publish your local commits)\n"
+msgstr "  (benutzen Sie \"git push\", um lokale Commits zu publizieren)\n"
 
-#: wt-status.c:1392
+#: remote.c:2046
 #, c-format
-msgid "You are currently bisecting, started from branch '%s'."
-msgstr "Sie sind gerade bei einer binären Suche, gestartet von Branch '%s'."
-
-#: wt-status.c:1396
-msgid "You are currently bisecting."
-msgstr "Sie sind gerade bei einer binären Suche."
+msgid "Your branch is behind '%s' by %d commit, and can be fast-forwarded.\n"
+msgid_plural ""
+"Your branch is behind '%s' by %d commits, and can be fast-forwarded.\n"
+msgstr[0] ""
+"Ihr Branch ist %2$d Commit hinter '%1$s', und kann vorgespult werden.\n"
+msgstr[1] ""
+"Ihr Branch ist %2$d Commits hinter '%1$s', und kann vorgespult werden.\n"
 
-#: wt-status.c:1399
-msgid "  (use \"git bisect reset\" to get back to the original branch)"
+#: remote.c:2054
+msgid "  (use \"git pull\" to update your local branch)\n"
 msgstr ""
-"  (benutzen Sie \"git bisect reset\", um zum ursprünglichen Branch "
-"zurückzukehren)"
-
-#: wt-status.c:1596
-msgid "On branch "
-msgstr "Auf Branch "
+"  (benutzen Sie \"git pull\", um Ihren lokalen Branch zu aktualisieren)\n"
 
-#: wt-status.c:1602
-msgid "interactive rebase in progress; onto "
-msgstr "interaktives Rebase im Gange; auf "
+#: remote.c:2057
+#, c-format
+msgid ""
+"Your branch and '%s' have diverged,\n"
+"and have %d and %d different commit each, respectively.\n"
+msgid_plural ""
+"Your branch and '%s' have diverged,\n"
+"and have %d and %d different commits each, respectively.\n"
+msgstr[0] ""
+"Ihr Branch und '%s' sind divergiert,\n"
+"und haben jeweils %d und %d unterschiedliche Commits.\n"
+msgstr[1] ""
+"Ihr Branch und '%s' sind divergiert,\n"
+"und haben jeweils %d und %d unterschiedliche Commits.\n"
 
-#: wt-status.c:1604
-msgid "rebase in progress; onto "
-msgstr "Rebase im Gange; auf "
+#: remote.c:2067
+msgid "  (use \"git pull\" to merge the remote branch into yours)\n"
+msgstr ""
+"  (benutzen Sie \"git pull\", um Ihren Branch mit dem Remote-Branch "
+"zusammenzuführen)\n"
 
-#: wt-status.c:1609
-msgid "HEAD detached at "
-msgstr "HEAD losgelöst bei "
+#: remote.c:2250
+#, c-format
+msgid "cannot parse expected object name '%s'"
+msgstr "Kann erwarteten Objektnamen '%s' nicht parsen."
 
-#: wt-status.c:1611
-msgid "HEAD detached from "
-msgstr "HEAD losgelöst von "
+#: replace-object.c:21
+#, c-format
+msgid "bad replace ref name: %s"
+msgstr "ungültiger Name für ersetzende Referenz: %s"
 
-#: wt-status.c:1614
-msgid "Not currently on any branch."
-msgstr "Im Moment auf keinem Branch."
+#: replace-object.c:30
+#, c-format
+msgid "duplicate replace ref: %s"
+msgstr "doppelte ersetzende Referenz: %s"
 
-#: wt-status.c:1634
-msgid "Initial commit"
-msgstr "Initialer Commit"
+#: replace-object.c:73
+#, c-format
+msgid "replace depth too high for object %s"
+msgstr "Ersetzungstiefe zu hoch für Objekt %s"
 
-#: wt-status.c:1635
-msgid "No commits yet"
-msgstr "Noch keine Commits"
+#: rerere.c:217 rerere.c:226 rerere.c:229
+msgid "corrupt MERGE_RR"
+msgstr "Fehlerhaftes MERGE_RR"
 
-#: wt-status.c:1649
-msgid "Untracked files"
-msgstr "Unversionierte Dateien"
+#: rerere.c:264 rerere.c:269
+msgid "unable to write rerere record"
+msgstr "Konnte Rerere-Eintrag nicht schreiben."
 
-#: wt-status.c:1651
-msgid "Ignored files"
-msgstr "Ignorierte Dateien"
+#: rerere.c:495
+#, c-format
+msgid "there were errors while writing '%s' (%s)"
+msgstr "Fehler beim Schreiben von '%s' (%s)."
 
-#: wt-status.c:1655
+#: rerere.c:498
 #, c-format
-msgid ""
-"It took %.2f seconds to enumerate untracked files. 'status -uno'\n"
-"may speed it up, but you have to be careful not to forget to add\n"
-"new files yourself (see 'git help status')."
-msgstr ""
-"Es dauerte %.2f Sekunden die unversionierten Dateien zu bestimmen.\n"
-"'status -uno' könnte das beschleunigen, aber Sie müssen darauf achten,\n"
-"neue Dateien selbstständig hinzuzufügen (siehe 'git help status')."
+msgid "failed to flush '%s'"
+msgstr "Flush bei '%s' fehlgeschlagen."
 
-#: wt-status.c:1661
+#: rerere.c:503 rerere.c:1039
 #, c-format
-msgid "Untracked files not listed%s"
-msgstr "Unversionierte Dateien nicht aufgelistet%s"
+msgid "could not parse conflict hunks in '%s'"
+msgstr "Konnte Konflikt-Blöcke in '%s' nicht parsen."
 
-#: wt-status.c:1663
-msgid " (use -u option to show untracked files)"
-msgstr " (benutzen Sie die Option -u, um unversionierte Dateien anzuzeigen)"
+#: rerere.c:684
+#, c-format
+msgid "failed utime() on '%s'"
+msgstr "Fehler beim Aufruf von utime() auf '%s'."
 
-#: wt-status.c:1669
-msgid "No changes"
-msgstr "Keine Änderungen"
+#: rerere.c:694
+#, c-format
+msgid "writing '%s' failed"
+msgstr "Schreiben von '%s' fehlgeschlagen."
 
-#: wt-status.c:1674
+#: rerere.c:714
 #, c-format
-msgid "no changes added to commit (use \"git add\" and/or \"git commit -a\")\n"
-msgstr ""
-"keine Änderungen zum Commit vorgemerkt (benutzen Sie \"git add\" und/oder "
-"\"git commit -a\")\n"
+msgid "Staged '%s' using previous resolution."
+msgstr "'%s' mit vorheriger Konfliktauflösung zum Commit vorgemerkt."
 
-#: wt-status.c:1677
+#: rerere.c:753
 #, c-format
-msgid "no changes added to commit\n"
-msgstr "keine Änderungen zum Commit vorgemerkt\n"
+msgid "Recorded resolution for '%s'."
+msgstr "Konfliktauflösung für '%s' aufgezeichnet."
 
-#: wt-status.c:1680
+#: rerere.c:788
 #, c-format
-msgid ""
-"nothing added to commit but untracked files present (use \"git add\" to "
-"track)\n"
-msgstr ""
-"nichts zum Commit vorgemerkt, aber es gibt unversionierte Dateien\n"
-"(benutzen Sie \"git add\" zum Versionieren)\n"
+msgid "Resolved '%s' using previous resolution."
+msgstr "Konflikte in '%s' mit vorheriger Konfliktauflösung beseitigt."
 
-#: wt-status.c:1683
+#: rerere.c:803
 #, c-format
-msgid "nothing added to commit but untracked files present\n"
-msgstr "nichts zum Commit vorgemerkt, aber es gibt unversionierte Dateien\n"
+msgid "cannot unlink stray '%s'"
+msgstr "Kann '%s' nicht löschen."
 
-#: wt-status.c:1686
+#: rerere.c:807
 #, c-format
-msgid "nothing to commit (create/copy files and use \"git add\" to track)\n"
-msgstr ""
-"nichts zu committen (erstellen/kopieren Sie Dateien und benutzen\n"
-"Sie \"git add\" zum Versionieren)\n"
+msgid "Recorded preimage for '%s'"
+msgstr "Preimage für '%s' aufgezeichnet."
 
-#: wt-status.c:1689 wt-status.c:1694
+#: rerere.c:881 submodule.c:2067 builtin/log.c:1871
+#: builtin/submodule--helper.c:1436 builtin/submodule--helper.c:1448
 #, c-format
-msgid "nothing to commit\n"
-msgstr "nichts zu committen\n"
+msgid "could not create directory '%s'"
+msgstr "Konnte Verzeichnis '%s' nicht erstellen."
 
-#: wt-status.c:1692
+#: rerere.c:1057
 #, c-format
-msgid "nothing to commit (use -u to show untracked files)\n"
-msgstr ""
-"nichts zu committen (benutzen Sie die Option -u, um unversionierte Dateien "
-"anzuzeigen)\n"
+msgid "failed to update conflicted state in '%s'"
+msgstr "Fehler beim Aktualisieren des Konflikt-Status in '%s'."
 
-#: wt-status.c:1696
+#: rerere.c:1068 rerere.c:1075
 #, c-format
-msgid "nothing to commit, working tree clean\n"
-msgstr "nichts zu committen, Arbeitsverzeichnis unverändert\n"
+msgid "no remembered resolution for '%s'"
+msgstr "Keine aufgezeichnete Konfliktauflösung für '%s'."
 
-#: wt-status.c:1809
-msgid "No commits yet on "
-msgstr "Noch keine Commits in "
+#: rerere.c:1077
+#, c-format
+msgid "cannot unlink '%s'"
+msgstr "Kann '%s' nicht löschen."
 
-#: wt-status.c:1813
-msgid "HEAD (no branch)"
-msgstr "HEAD (kein Branch)"
+#: rerere.c:1087
+#, c-format
+msgid "Updated preimage for '%s'"
+msgstr "Preimage für '%s' aktualisiert."
 
-#: wt-status.c:1844
-msgid "different"
-msgstr "unterschiedlich"
+#: rerere.c:1096
+#, c-format
+msgid "Forgot resolution for '%s'\n"
+msgstr "Aufgezeichnete Konfliktauflösung für '%s' gelöscht.\n"
 
-#: wt-status.c:1846 wt-status.c:1854
-msgid "behind "
-msgstr "hinterher "
+#: rerere.c:1199
+msgid "unable to open rr-cache directory"
+msgstr "Konnte rr-cache Verzeichnis nicht öffnen."
 
-#: wt-status.c:1849 wt-status.c:1852
-msgid "ahead "
-msgstr "voraus "
+#: revision.c:2497
+msgid "your current branch appears to be broken"
+msgstr "Ihr aktueller Branch scheint fehlerhaft zu sein."
 
-#. TRANSLATORS: the action is e.g. "pull with rebase"
-#: wt-status.c:2358
+#: revision.c:2500
 #, c-format
-msgid "cannot %s: You have unstaged changes."
-msgstr ""
-"%s nicht möglich: Sie haben Änderungen, die nicht zum Commit vorgemerkt sind."
+msgid "your current branch '%s' does not have any commits yet"
+msgstr "Ihr aktueller Branch '%s' hat noch keine Commits."
 
-#: wt-status.c:2364
-msgid "additionally, your index contains uncommitted changes."
-msgstr "Zusätzlich enthält die Staging-Area nicht committete Änderungen."
+#: revision.c:2708
+msgid "--first-parent is incompatible with --bisect"
+msgstr "Die Optionen --first-parent und --bisect sind inkompatibel."
+
+#: revision.c:2712
+msgid "-L does not yet support diff formats besides -p and -s"
+msgstr "-L unterstützt noch keine anderen Diff-Formate außer -p und -s"
+
+#: run-command.c:762
+msgid "open /dev/null failed"
+msgstr "Öffnen von /dev/null fehlgeschlagen"
 
-#: wt-status.c:2366
+#: run-command.c:1268
 #, c-format
-msgid "cannot %s: Your index contains uncommitted changes."
-msgstr ""
-"%s nicht möglich: Die Staging-Area enthält nicht committete Änderungen."
+msgid "cannot create async thread: %s"
+msgstr "Konnte Thread für async nicht erzeugen: %s"
 
-#: compat/precompose_utf8.c:58 builtin/clone.c:440
+#: run-command.c:1332
 #, c-format
-msgid "failed to unlink '%s'"
-msgstr "Konnte '%s' nicht entfernen."
+msgid ""
+"The '%s' hook was ignored because it's not set as executable.\n"
+"You can disable this warning with `git config advice.ignoredHook false`."
+msgstr ""
+"Der '%s' Hook wurde ignoriert, weil er nicht als ausführbar markiert ist.\n"
+"Sie können diese Warnung mit `git config advice.ignoredHook false` "
+"deaktivieren."
 
-#: builtin/add.c:24
-msgid "git add [<options>] [--] <pathspec>..."
-msgstr "git add [<Optionen>] [--] <Pfadspezifikation>..."
+#: send-pack.c:144
+msgid "unexpected flush packet while reading remote unpack status"
+msgstr "Unerwartetes Flush-Paket beim Lesen des Remote-Unpack-Status."
 
-#: builtin/add.c:83
+#: send-pack.c:146
 #, c-format
-msgid "unexpected diff status %c"
-msgstr "unerwarteter Differenz-Status %c"
-
-#: builtin/add.c:88 builtin/commit.c:257
-msgid "updating files failed"
-msgstr "Aktualisierung der Dateien fehlgeschlagen"
+msgid "unable to parse remote unpack status: %s"
+msgstr "Konnte Status des Entpackens der Gegenseite nicht parsen: %s"
 
-#: builtin/add.c:98
+#: send-pack.c:148
 #, c-format
-msgid "remove '%s'\n"
-msgstr "lösche '%s'\n"
+msgid "remote unpack failed: %s"
+msgstr "Entpacken auf der Gegenseite fehlgeschlagen: %s"
 
-#: builtin/add.c:173
-msgid "Unstaged changes after refreshing the index:"
+#: send-pack.c:309
+msgid "failed to sign the push certificate"
+msgstr "Fehler beim Signieren des \"push\"-Zertifikates"
+
+#: send-pack.c:423
+msgid "the receiving end does not support --signed push"
 msgstr ""
-"Nicht zum Commit vorgemerkte Änderungen nach Aktualisierung der Staging-Area:"
+"die Gegenseite unterstützt keinen signierten Versand (\"--signed push\")"
 
-#: builtin/add.c:233 builtin/rev-parse.c:888
-msgid "Could not read the index"
-msgstr "Konnte den Index nicht lesen"
+#: send-pack.c:425
+msgid ""
+"not sending a push certificate since the receiving end does not support --"
+"signed push"
+msgstr ""
+"kein Versand des \"push\"-Zertifikates, da die Gegenseite keinen signierten\n"
+"Versand (\"--signed push\") unterstützt"
 
-#: builtin/add.c:244
-#, c-format
-msgid "Could not open '%s' for writing."
-msgstr "Konnte '%s' nicht zum Schreiben öffnen."
+#: send-pack.c:437
+msgid "the receiving end does not support --atomic push"
+msgstr "die Gegenseite unterstützt keinen atomaren Versand (\"--atomic push\")"
 
-#: builtin/add.c:248
-msgid "Could not write patch"
-msgstr "Konnte Patch nicht schreiben"
+#: send-pack.c:442
+msgid "the receiving end does not support push options"
+msgstr "die Gegenseite unterstützt keine Push-Optionen"
 
-#: builtin/add.c:251
-msgid "editing patch failed"
-msgstr "Bearbeitung des Patches fehlgeschlagen"
+#: sequencer.c:189
+#, c-format
+msgid "invalid commit message cleanup mode '%s'"
+msgstr "Ungültiger \"cleanup\"-Modus '%s' für Commit-Beschreibungen."
 
-#: builtin/add.c:254
+#: sequencer.c:294
 #, c-format
-msgid "Could not stat '%s'"
-msgstr "Konnte Verzeichnis '%s' nicht lesen"
+msgid "could not delete '%s'"
+msgstr "Konnte '%s' nicht löschen."
 
-#: builtin/add.c:256
-msgid "Empty patch. Aborted."
-msgstr "Leerer Patch. Abgebrochen."
+#: sequencer.c:313 builtin/rebase.c:781 builtin/rebase.c:1706 builtin/rm.c:369
+#, c-format
+msgid "could not remove '%s'"
+msgstr "Konnte '%s' nicht löschen"
+
+#: sequencer.c:323
+msgid "revert"
+msgstr "Revert"
+
+#: sequencer.c:325
+msgid "cherry-pick"
+msgstr "Cherry-Pick"
 
-#: builtin/add.c:261
+#: sequencer.c:327
+msgid "rebase -i"
+msgstr "interaktives Rebase"
+
+#: sequencer.c:329
 #, c-format
-msgid "Could not apply '%s'"
-msgstr "Konnte '%s' nicht anwenden."
+msgid "unknown action: %d"
+msgstr "Unbekannte Aktion: %d"
 
-#: builtin/add.c:271
-msgid "The following paths are ignored by one of your .gitignore files:\n"
+#: sequencer.c:387
+msgid ""
+"after resolving the conflicts, mark the corrected paths\n"
+"with 'git add <paths>' or 'git rm <paths>'"
 msgstr ""
-"Die folgenden Pfade werden durch eine Ihrer \".gitignore\" Dateien "
-"ignoriert:\n"
+"nach Auflösung der Konflikte markieren Sie die korrigierten Pfade\n"
+"mit 'git add <Pfade>' oder 'git rm <Pfade>'"
 
-#: builtin/add.c:291 builtin/clean.c:911 builtin/fetch.c:146 builtin/mv.c:124
-#: builtin/prune-packed.c:55 builtin/pull.c:207 builtin/push.c:541
-#: builtin/remote.c:1333 builtin/rm.c:242 builtin/send-pack.c:164
-msgid "dry run"
-msgstr "Probelauf"
+#: sequencer.c:390
+msgid ""
+"after resolving the conflicts, mark the corrected paths\n"
+"with 'git add <paths>' or 'git rm <paths>'\n"
+"and commit the result with 'git commit'"
+msgstr ""
+"nach Auflösung der Konflikte markieren Sie die korrigierten Pfade\n"
+"mit 'git add <Pfade>' oder 'git rm <Pfade>' und tragen Sie das Ergebnis mit\n"
+"'git commit' ein"
 
-#: builtin/add.c:294
-msgid "interactive picking"
-msgstr "interaktives Auswählen"
+#: sequencer.c:403 sequencer.c:2993
+#, c-format
+msgid "could not lock '%s'"
+msgstr "Konnte '%s' nicht sperren"
 
-#: builtin/add.c:295 builtin/checkout.c:1128 builtin/reset.c:302
-msgid "select hunks interactively"
-msgstr "Blöcke interaktiv auswählen"
+#: sequencer.c:410
+#, c-format
+msgid "could not write eol to '%s'"
+msgstr "Konnte EOL nicht nach '%s' schreiben."
 
-#: builtin/add.c:296
-msgid "edit current diff and apply"
-msgstr "aktuelle Unterschiede editieren und anwenden"
+#: sequencer.c:415 sequencer.c:2798 sequencer.c:2999 sequencer.c:3013
+#: sequencer.c:3277
+#, c-format
+msgid "failed to finalize '%s'"
+msgstr "Fehler beim Fertigstellen von '%s'."
 
-#: builtin/add.c:297
-msgid "allow adding otherwise ignored files"
-msgstr "das Hinzufügen andernfalls ignorierter Dateien erlauben"
+#: sequencer.c:438 sequencer.c:1707 sequencer.c:2818 sequencer.c:3259
+#: sequencer.c:3368 builtin/am.c:244 builtin/commit.c:783 builtin/merge.c:1117
+#: builtin/rebase.c:589
+#, c-format
+msgid "could not read '%s'"
+msgstr "Konnte '%s' nicht lesen"
 
-#: builtin/add.c:298
-msgid "update tracked files"
-msgstr "versionierte Dateien aktualisieren"
+#: sequencer.c:464
+#, c-format
+msgid "your local changes would be overwritten by %s."
+msgstr "Ihre lokalen Änderungen würden durch den %s überschrieben werden."
 
-#: builtin/add.c:299
-msgid "renormalize EOL of tracked files (implies -u)"
+#: sequencer.c:468
+msgid "commit your changes or stash them to proceed."
 msgstr ""
-"erneutes Normalisieren der Zeilenenden von versionierten Dateien (impliziert "
-"-u)"
+"Committen Sie Ihre Änderungen oder benutzen Sie \"stash\", um fortzufahren."
 
-#: builtin/add.c:300
-msgid "record only the fact that the path will be added later"
-msgstr "nur speichern, dass der Pfad später hinzugefügt werden soll"
+#: sequencer.c:500
+#, c-format
+msgid "%s: fast-forward"
+msgstr "%s: Vorspulen"
 
-#: builtin/add.c:301
-msgid "add changes from all tracked and untracked files"
-msgstr ""
-"Änderungen von allen versionierten und unversionierten Dateien hinzufügen"
+#: sequencer.c:539 builtin/tag.c:565
+#, c-format
+msgid "Invalid cleanup mode %s"
+msgstr "Ungültiger \"cleanup\" Modus %s"
 
-#: builtin/add.c:304
-msgid "ignore paths removed in the working tree (same as --no-all)"
-msgstr "gelöschte Pfade im Arbeitsverzeichnis ignorieren (genau wie --no-all)"
+#. TRANSLATORS: %s will be "revert", "cherry-pick" or
+#. "rebase -i".
+#.
+#: sequencer.c:633
+#, c-format
+msgid "%s: Unable to write new index file"
+msgstr "%s: Konnte neue Index-Datei nicht schreiben"
 
-#: builtin/add.c:306
-msgid "don't add, only refresh the index"
-msgstr "nichts hinzufügen, nur den Index aktualisieren"
+#: sequencer.c:650
+msgid "unable to update cache tree"
+msgstr "Konnte Cache-Verzeichnis nicht aktualisieren."
 
-#: builtin/add.c:307
-msgid "just skip files which cannot be added because of errors"
-msgstr ""
-"Dateien überspringen, die aufgrund von Fehlern nicht hinzugefügt werden "
-"konnten"
+#: sequencer.c:664
+msgid "could not resolve HEAD commit"
+msgstr "Konnte HEAD-Commit nicht auflösen."
 
-#: builtin/add.c:308
-msgid "check if - even missing - files are ignored in dry run"
-msgstr "prüfen ob - auch fehlende - Dateien im Probelauf ignoriert werden"
+#: sequencer.c:744
+#, c-format
+msgid "no key present in '%.*s'"
+msgstr "Kein Schlüssel in '%.*s' vorhanden."
 
-#: builtin/add.c:309 builtin/update-index.c:964
-msgid "(+/-)x"
-msgstr "(+/-)x"
+#: sequencer.c:755
+#, c-format
+msgid "unable to dequote value of '%s'"
+msgstr "Konnte Anführungszeichen von '%s' nicht entfernen."
 
-#: builtin/add.c:309 builtin/update-index.c:965
-msgid "override the executable bit of the listed files"
-msgstr "das \"ausführbar\"-Bit der aufgelisteten Dateien überschreiben"
+#: sequencer.c:792 wrapper.c:190 wrapper.c:360 builtin/am.c:705
+#: builtin/am.c:797 builtin/merge.c:1114 builtin/rebase.c:1074
+#, c-format
+msgid "could not open '%s' for reading"
+msgstr "Konnte '%s' nicht zum Lesen öffnen."
 
-#: builtin/add.c:311
-msgid "warn when adding an embedded repository"
-msgstr "warnen wenn eingebettetes Repository hinzugefügt wird"
+#: sequencer.c:802
+msgid "'GIT_AUTHOR_NAME' already given"
+msgstr "'GIT_AUTHOR_NAME' bereits angegeben."
+
+#: sequencer.c:807
+msgid "'GIT_AUTHOR_EMAIL' already given"
+msgstr "'GIT_AUTHOR_EMAIL' bereits angegeben."
 
-#: builtin/add.c:326
+#: sequencer.c:812
+msgid "'GIT_AUTHOR_DATE' already given"
+msgstr "'GIT_AUTHOR_DATE' bereits angegeben."
+
+#: sequencer.c:816
+#, c-format
+msgid "unknown variable '%s'"
+msgstr "Unbekannte Variable '%s'"
+
+#: sequencer.c:821
+msgid "missing 'GIT_AUTHOR_NAME'"
+msgstr "'GIT_AUTHOR_NAME' fehlt."
+
+#: sequencer.c:823
+msgid "missing 'GIT_AUTHOR_EMAIL'"
+msgstr "'GIT_AUTHOR_EMAIL' fehlt."
+
+#: sequencer.c:825
+msgid "missing 'GIT_AUTHOR_DATE'"
+msgstr "'GIT_AUTHOR_DATE' fehlt."
+
+#: sequencer.c:902 sequencer.c:1427
+msgid "malformed ident line"
+msgstr "Fehlerhafte Identifikationszeile."
+
+#: sequencer.c:925
 #, c-format
 msgid ""
-"You've added another git repository inside your current repository.\n"
-"Clones of the outer repository will not contain the contents of\n"
-"the embedded repository and will not know how to obtain it.\n"
-"If you meant to add a submodule, use:\n"
+"you have staged changes in your working tree\n"
+"If these changes are meant to be squashed into the previous commit, run:\n"
 "\n"
-"\tgit submodule add <url> %s\n"
+"  git commit --amend %s\n"
 "\n"
-"If you added this path by mistake, you can remove it from the\n"
-"index with:\n"
+"If they are meant to go into a new commit, run:\n"
 "\n"
-"\tgit rm --cached %s\n"
+"  git commit %s\n"
 "\n"
-"See \"git help submodule\" for more information."
+"In both cases, once you're done, continue with:\n"
+"\n"
+"  git rebase --continue\n"
 msgstr ""
-"Sie haben ein Git-Repository innerhalb ihres aktuellen Repositories "
-"hinzugefügt.\n"
-"Klone des äußeren Repositories werden die Inhalte des eingebetteten "
-"Repositories\n"
-"weder enthalten, noch wissen, wie diese zu beschaffen sind.\n"
-"Wenn Sie ein Submodul hinzufügen wollten, benutzen Sie:\n"
+"Es befinden sich zum Commit vorgemerkte Änderungen in Ihrem "
+"Arbeitsverzeichnis.\n"
+"Wenn diese Änderungen in den vorherigen Commit aufgenommen werden sollen,\n"
+"führen Sie aus:\n"
 "\n"
-"\tgit submodule add <URL> %s\n"
+"  git commit --amend %s\n"
 "\n"
-"Wenn Sie diesen Pfad aus Versehen hinzugefügt haben, können Sie diesen mit\n"
+"Wenn daraus ein neuer Commit erzeugt werden soll, führen Sie aus:\n"
 "\n"
-"\tgit rm --cached %s\n"
+"  git commit %s\n"
 "\n"
-"vom Index entfernen.\n"
+"Im Anschluss führen Sie zum Fortfahren aus:\n"
 "\n"
-"Siehe \"git help submodule\" für weitere Informationen."
+"  git rebase --continue\n"
 
-#: builtin/add.c:354
-#, c-format
-msgid "adding embedded git repository: %s"
-msgstr "Füge eingebettetes Repository hinzu: %s"
+#: sequencer.c:1218
+msgid "'prepare-commit-msg' hook failed"
+msgstr "'prepare-commit-msg' Hook fehlgeschlagen."
 
-#: builtin/add.c:372
-#, c-format
-msgid "Use -f if you really want to add them.\n"
-msgstr "Verwenden Sie -f wenn Sie diese wirklich hinzufügen möchten.\n"
+#: sequencer.c:1224
+msgid ""
+"Your name and email address were configured automatically based\n"
+"on your username and hostname. Please check that they are accurate.\n"
+"You can suppress this message by setting them explicitly. Run the\n"
+"following command and follow the instructions in your editor to edit\n"
+"your configuration file:\n"
+"\n"
+"    git config --global --edit\n"
+"\n"
+"After doing this, you may fix the identity used for this commit with:\n"
+"\n"
+"    git commit --amend --reset-author\n"
+msgstr ""
+"Ihr Name und E-Mail Adresse wurden automatisch auf Basis\n"
+"Ihres Benutzer- und Rechnernamens konfiguriert. Bitte prüfen Sie, dass\n"
+"diese zutreffend sind. Sie können diese Meldung unterdrücken, indem Sie\n"
+"diese explizit setzen. Führen Sie dazu den folgenden Befehl aus und folgen\n"
+"Sie den Anweisungen in Ihrem Editor, um die Konfigurationsdatei zu "
+"bearbeiten:\n"
+"\n"
+"    git config --global --edit\n"
+"\n"
+"Nachdem Sie das getan haben, können Sie Ihre Identität für diesen Commit\n"
+"ändern mit:\n"
+"\n"
+"    git commit --amend --reset-author\n"
 
-#: builtin/add.c:380
-msgid "adding files failed"
-msgstr "Hinzufügen von Dateien fehlgeschlagen"
+#: sequencer.c:1237
+msgid ""
+"Your name and email address were configured automatically based\n"
+"on your username and hostname. Please check that they are accurate.\n"
+"You can suppress this message by setting them explicitly:\n"
+"\n"
+"    git config --global user.name \"Your Name\"\n"
+"    git config --global user.email you@example.com\n"
+"\n"
+"After doing this, you may fix the identity used for this commit with:\n"
+"\n"
+"    git commit --amend --reset-author\n"
+msgstr ""
+"Ihr Name und E-Mail Adresse wurden automatisch auf Basis\n"
+"Ihres Benutzer- und Rechnernamens konfiguriert. Bitte prüfen Sie, dass\n"
+"diese zutreffend sind. Sie können diese Meldung unterdrücken, indem Sie\n"
+"diese explizit setzen:\n"
+"\n"
+"    git config --global user.name \"Ihr Name\"\n"
+"    git config --global user.email ihre@emailadresse.de\n"
+"\n"
+"Nachdem Sie das getan haben, können Sie Ihre Identität für diesen Commit "
+"ändern:\n"
+"\n"
+"    git commit --amend --reset-author\n"
 
-#: builtin/add.c:417
-msgid "-A and -u are mutually incompatible"
-msgstr "Die Optionen -A und -u sind zueinander inkompatibel."
+#: sequencer.c:1279
+msgid "couldn't look up newly created commit"
+msgstr "Konnte neu erstellten Commit nicht nachschlagen."
 
-#: builtin/add.c:424
-msgid "Option --ignore-missing can only be used together with --dry-run"
-msgstr ""
-"Die Option --ignore-missing kann nur zusammen mit --dry-run verwendet werden."
+#: sequencer.c:1281
+msgid "could not parse newly created commit"
+msgstr "Konnte neu erstellten Commit nicht analysieren."
 
-#: builtin/add.c:428
-#, c-format
-msgid "--chmod param '%s' must be either -x or +x"
-msgstr "--chmod Parameter '%s' muss entweder -x oder +x sein"
+#: sequencer.c:1327
+msgid "unable to resolve HEAD after creating commit"
+msgstr "Konnte HEAD nicht auflösen, nachdem der Commit erstellt wurde."
 
-#: builtin/add.c:443
-#, c-format
-msgid "Nothing specified, nothing added.\n"
-msgstr "Nichts spezifiziert, nichts hinzugefügt.\n"
+#: sequencer.c:1329
+msgid "detached HEAD"
+msgstr "losgelöster HEAD"
+
+#: sequencer.c:1333
+msgid " (root-commit)"
+msgstr " (Root-Commit)"
+
+#: sequencer.c:1354
+msgid "could not parse HEAD"
+msgstr "Konnte HEAD nicht parsen."
 
-#: builtin/add.c:444
+#: sequencer.c:1356
 #, c-format
-msgid "Maybe you wanted to say 'git add .'?\n"
-msgstr "Meinten Sie vielleicht 'git add .'?\n"
+msgid "HEAD %s is not a commit!"
+msgstr "HEAD %s ist kein Commit!"
 
-#: builtin/add.c:449 builtin/check-ignore.c:177 builtin/checkout.c:280
-#: builtin/checkout.c:483 builtin/clean.c:958 builtin/commit.c:316
-#: builtin/diff-tree.c:114 builtin/mv.c:144 builtin/reset.c:241
-#: builtin/rm.c:271 builtin/submodule--helper.c:326
-msgid "index file corrupt"
-msgstr "Index-Datei beschädigt"
+#: sequencer.c:1360 sequencer.c:1458 builtin/commit.c:1569
+msgid "could not parse HEAD commit"
+msgstr "Konnte Commit von HEAD nicht analysieren."
 
-#: builtin/am.c:414
-msgid "could not parse author script"
-msgstr "konnte Autor-Skript nicht parsen"
+#: sequencer.c:1411 sequencer.c:2055
+msgid "unable to parse commit author"
+msgstr "Konnte Commit-Autor nicht parsen."
 
-#: builtin/am.c:498
-#, c-format
-msgid "'%s' was deleted by the applypatch-msg hook"
-msgstr "'%s' wurde durch den applypatch-msg Hook entfernt"
+#: sequencer.c:1431
+msgid "corrupted author without date information"
+msgstr "Fehlerhafter Autor ohne Datumsinformationen."
 
-#: builtin/am.c:539
-#, c-format
-msgid "Malformed input line: '%s'."
-msgstr "Fehlerhafte Eingabezeile: '%s'."
+#: sequencer.c:1447 builtin/am.c:1561 builtin/merge.c:684
+msgid "git write-tree failed to write a tree"
+msgstr "\"git write-tree\" schlug beim Schreiben eines \"Tree\"-Objektes fehl"
 
-#: builtin/am.c:576
+#: sequencer.c:1480 sequencer.c:1550
 #, c-format
-msgid "Failed to copy notes from '%s' to '%s'"
-msgstr "Fehler beim Kopieren der Notizen von '%s' nach '%s'"
+msgid "unable to read commit message from '%s'"
+msgstr "Konnte Commit-Beschreibung von '%s' nicht lesen."
 
-#: builtin/am.c:602
-msgid "fseek failed"
-msgstr "\"fseek\" fehlgeschlagen"
+#: sequencer.c:1516 builtin/am.c:1583 builtin/commit.c:1668 builtin/merge.c:883
+#: builtin/merge.c:908
+msgid "failed to write commit object"
+msgstr "Fehler beim Schreiben des Commit-Objektes."
 
-#: builtin/am.c:790
+#: sequencer.c:1577
 #, c-format
-msgid "could not parse patch '%s'"
-msgstr "konnte Patch '%s' nicht parsen"
+msgid "could not parse commit %s"
+msgstr "Konnte Commit %s nicht parsen."
 
-#: builtin/am.c:855
-msgid "Only one StGIT patch series can be applied at once"
-msgstr "Es kann nur eine StGIT Patch-Serie auf einmal angewendet werden."
+#: sequencer.c:1582
+#, c-format
+msgid "could not parse parent commit %s"
+msgstr "Konnte Eltern-Commit %s nicht parsen."
 
-#: builtin/am.c:903
-msgid "invalid timestamp"
-msgstr "ungültiger Zeitstempel"
+#: sequencer.c:1656 sequencer.c:1767
+#, c-format
+msgid "unknown command: %d"
+msgstr "Unbekannter Befehl: %d"
 
-#: builtin/am.c:908 builtin/am.c:920
-msgid "invalid Date line"
-msgstr "Ungültige \"Date\"-Zeile"
+#: sequencer.c:1714 sequencer.c:1739
+#, c-format
+msgid "This is a combination of %d commits."
+msgstr "Das ist eine Kombination aus %d Commits."
 
-#: builtin/am.c:915
-msgid "invalid timezone offset"
-msgstr "Ungültiger Offset in der Zeitzone"
+#: sequencer.c:1724
+msgid "need a HEAD to fixup"
+msgstr "benötige HEAD für fixup"
 
-#: builtin/am.c:1008
-msgid "Patch format detection failed."
-msgstr "Patch-Formaterkennung fehlgeschlagen."
+#: sequencer.c:1726 sequencer.c:3304
+msgid "could not read HEAD"
+msgstr "Konnte HEAD nicht lesen"
 
-#: builtin/am.c:1013 builtin/clone.c:405
-#, c-format
-msgid "failed to create directory '%s'"
-msgstr "Fehler beim Erstellen von Verzeichnis '%s'"
+#: sequencer.c:1728
+msgid "could not read HEAD's commit message"
+msgstr "Konnte Commit-Beschreibung von HEAD nicht lesen"
 
-#: builtin/am.c:1018
-msgid "Failed to split patches."
-msgstr "Fehler beim Aufteilen der Patches."
+#: sequencer.c:1734
+#, c-format
+msgid "cannot write '%s'"
+msgstr "kann '%s' nicht schreiben"
 
-#: builtin/am.c:1148 builtin/commit.c:342
-msgid "unable to write index file"
-msgstr "Konnte Index-Datei nicht schreiben."
+#: sequencer.c:1741 git-rebase--preserve-merges.sh:496
+msgid "This is the 1st commit message:"
+msgstr "Das ist die erste Commit-Beschreibung:"
 
-#: builtin/am.c:1162
+#: sequencer.c:1749
 #, c-format
-msgid "When you have resolved this problem, run \"%s --continue\"."
-msgstr ""
-"Wenn Sie das Problem aufgelöst haben, führen Sie \"%s --continue\" aus."
+msgid "could not read commit message of %s"
+msgstr "Konnte Commit-Beschreibung von %s nicht lesen."
 
-#: builtin/am.c:1163
+#: sequencer.c:1756
 #, c-format
-msgid "If you prefer to skip this patch, run \"%s --skip\" instead."
-msgstr ""
-"Falls Sie diesen Patch auslassen möchten, führen Sie stattdessen \"%s --skip"
-"\" aus."
+msgid "This is the commit message #%d:"
+msgstr "Das ist Commit-Beschreibung #%d:"
 
-#: builtin/am.c:1164
+#: sequencer.c:1762
 #, c-format
-msgid "To restore the original branch and stop patching, run \"%s --abort\"."
-msgstr ""
-"Um den ursprünglichen Branch wiederherzustellen und die Anwendung der "
-"Patches abzubrechen, führen Sie \"%s --abort\" aus."
+msgid "The commit message #%d will be skipped:"
+msgstr "Die Commit-Beschreibung #%d wird ausgelassen:"
 
-#: builtin/am.c:1271
-msgid "Patch is empty."
-msgstr "Patch ist leer."
+#: sequencer.c:1850
+msgid "your index file is unmerged."
+msgstr "Ihre Index-Datei ist nicht zusammengeführt."
 
-#: builtin/am.c:1337
-#, c-format
-msgid "invalid ident line: %.*s"
-msgstr "Ungültige Identifikationszeile: %.*s"
+#: sequencer.c:1857
+msgid "cannot fixup root commit"
+msgstr "kann fixup nicht auf Root-Commit anwenden"
 
-#: builtin/am.c:1359
+#: sequencer.c:1876
 #, c-format
-msgid "unable to parse commit %s"
-msgstr "Konnte Commit '%s' nicht parsen."
-
-#: builtin/am.c:1554
-msgid "Repository lacks necessary blobs to fall back on 3-way merge."
-msgstr ""
-"Dem Repository fehlen notwendige Blobs um auf einen 3-Wege-Merge "
-"zurückzufallen."
-
-#: builtin/am.c:1556
-msgid "Using index info to reconstruct a base tree..."
-msgstr ""
-"Verwende Informationen aus der Staging-Area, um ein Basisverzeichnis "
-"nachzustellen ..."
-
-#: builtin/am.c:1575
-msgid ""
-"Did you hand edit your patch?\n"
-"It does not apply to blobs recorded in its index."
-msgstr ""
-"Haben Sie den Patch per Hand editiert?\n"
-"Er kann nicht auf die Blobs in seiner 'index' Zeile angewendet werden."
-
-#: builtin/am.c:1581
-msgid "Falling back to patching base and 3-way merge..."
-msgstr "Falle zurück zum Patchen der Basis und zum 3-Wege-Merge ..."
+msgid "commit %s is a merge but no -m option was given."
+msgstr "Commit %s ist ein Merge, aber die Option -m wurde nicht angegeben."
 
-#: builtin/am.c:1606
-msgid "Failed to merge in the changes."
-msgstr "Merge der Änderungen fehlgeschlagen."
+#: sequencer.c:1884 sequencer.c:1892
+#, c-format
+msgid "commit %s does not have parent %d"
+msgstr "Commit %s hat keinen Eltern-Commit %d"
 
-#: builtin/am.c:1637
-msgid "applying to an empty history"
-msgstr "auf leere Historie anwenden"
+#: sequencer.c:1898
+#, c-format
+msgid "cannot get commit message for %s"
+msgstr "Kann keine Commit-Beschreibung für %s bekommen."
 
-#: builtin/am.c:1683 builtin/am.c:1687
+#. TRANSLATORS: The first %s will be a "todo" command like
+#. "revert" or "pick", the second %s a SHA1.
+#: sequencer.c:1917
 #, c-format
-msgid "cannot resume: %s does not exist."
-msgstr "Kann nicht fortsetzen: %s existiert nicht"
+msgid "%s: cannot parse parent commit %s"
+msgstr "%s: kann Eltern-Commit %s nicht parsen"
 
-#: builtin/am.c:1703
-msgid "cannot be interactive without stdin connected to a terminal."
-msgstr ""
-"Kann nicht interaktiv sein, ohne dass die Standard-Eingabe mit einem "
-"Terminal verbunden ist."
+#: sequencer.c:1982
+#, c-format
+msgid "could not rename '%s' to '%s'"
+msgstr "Konnte '%s' nicht zu '%s' umbenennen."
 
-#: builtin/am.c:1708
-msgid "Commit Body is:"
-msgstr "Commit-Beschreibung ist:"
+#: sequencer.c:2037
+#, c-format
+msgid "could not revert %s... %s"
+msgstr "Konnte \"revert\" nicht auf %s... (%s) ausführen"
 
-#. TRANSLATORS: Make sure to include [y], [n], [e], [v] and [a]
-#. in your translation. The program will only accept English
-#. input at this point.
-#.
-#: builtin/am.c:1718
-msgid "Apply? [y]es/[n]o/[e]dit/[v]iew patch/[a]ccept all: "
-msgstr "Anwenden? [y]es/[n]o/[e]dit/[v]iew patch/[a]ccept all: "
+#: sequencer.c:2038
+#, c-format
+msgid "could not apply %s... %s"
+msgstr "Konnte %s... (%s) nicht anwenden"
 
-#: builtin/am.c:1768
+#: sequencer.c:2105
 #, c-format
-msgid "Dirty index: cannot apply patches (dirty: %s)"
-msgstr "Geänderter Index: kann Patches nicht anwenden (geändert: %s)"
+msgid "git %s: failed to read the index"
+msgstr "git %s: Fehler beim Lesen des Index"
 
-#: builtin/am.c:1808 builtin/am.c:1879
+#: sequencer.c:2112
 #, c-format
-msgid "Applying: %.*s"
-msgstr "Wende an: %.*s"
+msgid "git %s: failed to refresh the index"
+msgstr "git %s: Fehler beim Aktualisieren des Index"
 
-#: builtin/am.c:1824
-msgid "No changes -- Patch already applied."
-msgstr "Keine Änderungen -- Patches bereits angewendet."
+#: sequencer.c:2189
+#, c-format
+msgid "%s does not accept arguments: '%s'"
+msgstr "%s akzeptiert keine Argumente: '%s'"
 
-#: builtin/am.c:1832
+#: sequencer.c:2198
 #, c-format
-msgid "Patch failed at %s %.*s"
-msgstr "Anwendung des Patches fehlgeschlagen bei %s %.*s"
+msgid "missing arguments for %s"
+msgstr "Fehlende Argumente für %s."
 
-#: builtin/am.c:1838
-msgid "Use 'git am --show-current-patch' to see the failed patch"
-msgstr ""
-"Benutzen Sie 'git am --show-current-patch', um den\n"
-"fehlgeschlagenen Patch zu sehen."
+#: sequencer.c:2235
+#, c-format
+msgid "could not parse '%.*s'"
+msgstr "Konnte '%.*s' nicht parsen."
 
-#: builtin/am.c:1882
-msgid ""
-"No changes - did you forget to use 'git add'?\n"
-"If there is nothing left to stage, chances are that something else\n"
-"already introduced the same changes; you might want to skip this patch."
-msgstr ""
-"Keine Änderungen - haben Sie vergessen 'git add' zu benutzen?\n"
-"Wenn keine Änderungen mehr zum Commit vorzumerken sind, könnten\n"
-"diese bereits anderweitig eingefügt worden sein; Sie könnten diesen Patch\n"
-"auslassen."
+#: sequencer.c:2289
+#, c-format
+msgid "invalid line %d: %.*s"
+msgstr "Ungültige Zeile %d: %.*s"
 
-#: builtin/am.c:1889
-msgid ""
-"You still have unmerged paths in your index.\n"
-"You should 'git add' each file with resolved conflicts to mark them as "
-"such.\n"
-"You might run `git rm` on a file to accept \"deleted by them\" for it."
-msgstr ""
-"Sie haben noch immer nicht zusammengeführte Pfade in Ihrem Index.\n"
-"Sie sollten 'git add' für jede Datei mit aufgelösten Konflikten ausführen,\n"
-"um diese als solche zu markieren.\n"
-"Sie können 'git rm' auf Dateien ausführen, um \"von denen gelöscht\" für\n"
-"diese zu akzeptieren."
+#: sequencer.c:2300
+#, c-format
+msgid "cannot '%s' without a previous commit"
+msgstr "Kann '%s' nicht ohne vorherigen Commit ausführen"
 
-#: builtin/am.c:1996 builtin/am.c:2000 builtin/am.c:2012 builtin/reset.c:324
-#: builtin/reset.c:332
+#: sequencer.c:2348 builtin/rebase.c:172 builtin/rebase.c:197
+#: builtin/rebase.c:223 builtin/rebase.c:248
 #, c-format
-msgid "Could not parse object '%s'."
-msgstr "Konnte Objekt '%s' nicht parsen."
+msgid "could not read '%s'."
+msgstr "Konnte '%s' nicht lesen."
 
-#: builtin/am.c:2048
-msgid "failed to clean index"
-msgstr "Fehler beim Bereinigen des Index"
+#: sequencer.c:2384
+msgid "cancelling a cherry picking in progress"
+msgstr "Abbrechen eines laufenden \"cherry-pick\""
+
+#: sequencer.c:2391
+msgid "cancelling a revert in progress"
+msgstr "Abbrechen eines laufenden \"revert\""
 
-#: builtin/am.c:2083
-msgid ""
-"You seem to have moved HEAD since the last 'am' failure.\n"
-"Not rewinding to ORIG_HEAD"
+#: sequencer.c:2435
+msgid "please fix this using 'git rebase --edit-todo'."
 msgstr ""
-"Sie scheinen seit dem letzten gescheiterten 'am' HEAD geändert zu haben.\n"
-"Keine Zurücksetzung zu ORIG_HEAD."
+"Bitte beheben Sie dieses, indem Sie 'git rebase --edit-todo' ausführen."
 
-#: builtin/am.c:2174
+#: sequencer.c:2437
 #, c-format
-msgid "Invalid value for --patch-format: %s"
-msgstr "Ungültiger Wert für --patch-format: %s"
-
-#: builtin/am.c:2210
-msgid "git am [<options>] [(<mbox> | <Maildir>)...]"
-msgstr "git am [<Optionen>] [(<mbox> | <E-Mail-Verzeichnis>)...]"
-
-#: builtin/am.c:2211
-msgid "git am [<options>] (--continue | --skip | --abort)"
-msgstr "git am [<Optionen>] (--continue | --skip | --abort)"
+msgid "unusable instruction sheet: '%s'"
+msgstr "Unbenutzbares Instruktionsblatt: '%s'"
 
-#: builtin/am.c:2217
-msgid "run interactively"
-msgstr "interaktiv ausführen"
+#: sequencer.c:2442
+msgid "no commits parsed."
+msgstr "Keine Commits geparst."
 
-#: builtin/am.c:2219
-msgid "historical option -- no-op"
-msgstr "historische Option -- kein Effekt"
+#: sequencer.c:2453
+msgid "cannot cherry-pick during a revert."
+msgstr "Kann Cherry-Pick nicht während eines Reverts ausführen."
 
-#: builtin/am.c:2221
-msgid "allow fall back on 3way merging if needed"
-msgstr "erlaube, falls notwendig, das Zurückfallen auf einen 3-Wege-Merge"
+#: sequencer.c:2455
+msgid "cannot revert during a cherry-pick."
+msgstr "Kann Revert nicht während eines Cherry-Picks ausführen."
 
-#: builtin/am.c:2222 builtin/init-db.c:484 builtin/prune-packed.c:57
-#: builtin/repack.c:182
-msgid "be quiet"
-msgstr "weniger Ausgaben"
+#: sequencer.c:2533
+#, c-format
+msgid "invalid value for %s: %s"
+msgstr "Ungültiger Wert für %s: %s"
 
-#: builtin/am.c:2224
-msgid "add a Signed-off-by line to the commit message"
-msgstr "der Commit-Beschreibung eine Signed-off-by Zeile hinzufügen"
+#: sequencer.c:2630
+msgid "unusable squash-onto"
+msgstr "Unbenutzbares squash-onto."
 
-#: builtin/am.c:2227
-msgid "recode into utf8 (default)"
-msgstr "nach UTF-8 umkodieren (Standard)"
+#: sequencer.c:2646
+#, c-format
+msgid "malformed options sheet: '%s'"
+msgstr "Fehlerhaftes Optionsblatt: '%s'"
 
-#: builtin/am.c:2229
-msgid "pass -k flag to git-mailinfo"
-msgstr "-k an git-mailinfo übergeben"
+#: sequencer.c:2736 sequencer.c:4463
+msgid "empty commit set passed"
+msgstr "leere Menge von Commits übergeben"
 
-#: builtin/am.c:2231
-msgid "pass -b flag to git-mailinfo"
-msgstr "-b an git-mailinfo übergeben"
+#: sequencer.c:2752
+msgid "revert is already in progress"
+msgstr "\"revert\" ist bereits im Gange"
 
-#: builtin/am.c:2233
-msgid "pass -m flag to git-mailinfo"
-msgstr "-m an git-mailinfo übergeben"
+#: sequencer.c:2754
+#, c-format
+msgid "try \"git revert (--continue | %s--abort | --quit)\""
+msgstr "Versuchen Sie \"git revert (--continue | %s--abort | --quit)\""
 
-#: builtin/am.c:2235
-msgid "pass --keep-cr flag to git-mailsplit for mbox format"
-msgstr "--keep-cr an git-mailsplit für mbox-Format übergeben"
+#: sequencer.c:2757
+msgid "cherry-pick is already in progress"
+msgstr "\"cherry-pick\" wird bereits durchgeführt"
 
-#: builtin/am.c:2238
-msgid "do not pass --keep-cr flag to git-mailsplit independent of am.keepcr"
-msgstr "kein --keep-cr an git-mailsplit übergeben, unabhängig von am.keepcr"
+#: sequencer.c:2759
+#, c-format
+msgid "try \"git cherry-pick (--continue | %s--abort | --quit)\""
+msgstr "Versuchen Sie \"git cherry-pick (--continue | %s--abort | --quit)\""
 
-#: builtin/am.c:2241
-msgid "strip everything before a scissors line"
-msgstr "alles vor einer Scheren-Zeile entfernen"
+#: sequencer.c:2773
+#, c-format
+msgid "could not create sequencer directory '%s'"
+msgstr "Konnte \"sequencer\"-Verzeichnis '%s' nicht erstellen."
 
-#: builtin/am.c:2243 builtin/am.c:2246 builtin/am.c:2249 builtin/am.c:2252
-#: builtin/am.c:2255 builtin/am.c:2258 builtin/am.c:2261 builtin/am.c:2264
-#: builtin/am.c:2270
-msgid "pass it through git-apply"
-msgstr "an git-apply übergeben"
+#: sequencer.c:2788
+msgid "could not lock HEAD"
+msgstr "Konnte HEAD nicht sperren"
 
-#: builtin/am.c:2260 builtin/fmt-merge-msg.c:665 builtin/fmt-merge-msg.c:668
-#: builtin/grep.c:853 builtin/merge.c:206 builtin/pull.c:145 builtin/pull.c:203
-#: builtin/repack.c:191 builtin/repack.c:195 builtin/repack.c:197
-#: builtin/show-branch.c:631 builtin/show-ref.c:169 builtin/tag.c:382
-#: parse-options.h:144 parse-options.h:146 parse-options.h:257
-msgid "n"
-msgstr "Anzahl"
+#: sequencer.c:2848 sequencer.c:4209
+msgid "no cherry-pick or revert in progress"
+msgstr "kein \"cherry-pick\" oder \"revert\" im Gange"
 
-#: builtin/am.c:2266 builtin/branch.c:629 builtin/for-each-ref.c:38
-#: builtin/replace.c:445 builtin/tag.c:418 builtin/verify-tag.c:39
-msgid "format"
-msgstr "Format"
+#: sequencer.c:2850 sequencer.c:2861
+msgid "cannot resolve HEAD"
+msgstr "kann HEAD nicht auflösen"
 
-#: builtin/am.c:2267
-msgid "format the patch(es) are in"
-msgstr "Patch-Format"
+#: sequencer.c:2852 sequencer.c:2896
+msgid "cannot abort from a branch yet to be born"
+msgstr "kann nicht abbrechen: bin auf einem Branch, der noch nicht geboren ist"
 
-#: builtin/am.c:2273
-msgid "override error message when patch failure occurs"
-msgstr "Meldung bei fehlerhafter Patch-Anwendung überschreiben"
+#: sequencer.c:2882 builtin/grep.c:736
+#, c-format
+msgid "cannot open '%s'"
+msgstr "kann '%s' nicht öffnen"
 
-#: builtin/am.c:2275
-msgid "continue applying patches after resolving a conflict"
-msgstr "Anwendung der Patches nach Auflösung eines Konfliktes fortsetzen"
+#: sequencer.c:2884
+#, c-format
+msgid "cannot read '%s': %s"
+msgstr "Kann '%s' nicht lesen: %s"
 
-#: builtin/am.c:2278
-msgid "synonyms for --continue"
-msgstr "Synonyme für --continue"
+#: sequencer.c:2885
+msgid "unexpected end of file"
+msgstr "Unerwartetes Dateiende"
 
-#: builtin/am.c:2281
-msgid "skip the current patch"
-msgstr "den aktuellen Patch auslassen"
+#: sequencer.c:2891
+#, c-format
+msgid "stored pre-cherry-pick HEAD file '%s' is corrupt"
+msgstr "gespeicherte \"pre-cherry-pick\" HEAD Datei '%s' ist beschädigt"
 
-#: builtin/am.c:2284
-msgid "restore the original branch and abort the patching operation."
+#: sequencer.c:2902
+msgid "You seem to have moved HEAD. Not rewinding, check your HEAD!"
 msgstr ""
-"ursprünglichen Branch wiederherstellen und Anwendung der Patches abbrechen"
-
-#: builtin/am.c:2287
-msgid "abort the patching operation but keep HEAD where it is."
-msgstr "Patch-Operation abbrechen, aber HEAD an aktueller Stelle belassen"
-
-#: builtin/am.c:2290
-msgid "show the patch being applied."
-msgstr "den Patch, der gerade angewendet wird, anzeigen"
-
-#: builtin/am.c:2294
-msgid "lie about committer date"
-msgstr "Autor-Datum als Commit-Datum verwenden"
+"Sie scheinen HEAD verändert zu haben. Keine Rückspulung, prüfen Sie HEAD."
 
-#: builtin/am.c:2296
-msgid "use current timestamp for author date"
-msgstr "aktuellen Zeitstempel als Autor-Datum verwenden"
+#: sequencer.c:2943
+msgid "no revert in progress"
+msgstr "Kein Revert im Gange"
 
-#: builtin/am.c:2298 builtin/commit.c:1431 builtin/merge.c:237
-#: builtin/pull.c:178 builtin/revert.c:112 builtin/tag.c:398
-msgid "key-id"
-msgstr "GPG-Schlüsselkennung"
+#: sequencer.c:2951
+msgid "no cherry-pick in progress"
+msgstr "kein \"cherry-pick\" im Gange"
 
-#: builtin/am.c:2299
-msgid "GPG-sign commits"
-msgstr "Commits mit GPG signieren"
+#: sequencer.c:2961
+msgid "failed to skip the commit"
+msgstr "Überspringen des Commits fehlgeschlagen"
 
-#: builtin/am.c:2302
-msgid "(internal use for git-rebase)"
-msgstr "(intern für git-rebase verwendet)"
+#: sequencer.c:2968
+msgid "there is nothing to skip"
+msgstr "Nichts zum Überspringen vorhanden"
 
-#: builtin/am.c:2320
+#: sequencer.c:2971
+#, c-format
 msgid ""
-"The -b/--binary option has been a no-op for long time, and\n"
-"it will be removed. Please do not use it anymore."
+"have you committed already?\n"
+"try \"git %s --continue\""
 msgstr ""
-"Die -b/--binary Option hat seit Langem keinen Effekt und wird\n"
-"entfernt. Bitte verwenden Sie diese nicht mehr."
+"Haben Sie bereits committet?\n"
+"Versuchen Sie \"git %s --continue\""
 
-#: builtin/am.c:2327
-msgid "failed to read the index"
-msgstr "Fehler beim Lesen des Index"
-
-#: builtin/am.c:2342
+#: sequencer.c:3095 sequencer.c:4121
 #, c-format
-msgid "previous rebase directory %s still exists but mbox given."
-msgstr "Vorheriges Rebase-Verzeichnis %s existiert noch, aber mbox gegeben."
+msgid "could not update %s"
+msgstr "Konnte %s nicht aktualisieren."
 
-#: builtin/am.c:2366
-#, c-format
+#: sequencer.c:3134 sequencer.c:4101
+msgid "cannot read HEAD"
+msgstr "Kann HEAD nicht lesen"
+
+#: sequencer.c:3151
+#, c-format
+msgid "unable to copy '%s' to '%s'"
+msgstr "Konnte '%s' nicht nach '%s' kopieren."
+
+#: sequencer.c:3159
+#, c-format
 msgid ""
-"Stray %s directory found.\n"
-"Use \"git am --abort\" to remove it."
+"You can amend the commit now, with\n"
+"\n"
+"  git commit --amend %s\n"
+"\n"
+"Once you are satisfied with your changes, run\n"
+"\n"
+"  git rebase --continue\n"
 msgstr ""
-"Stray %s Verzeichnis gefunden.\n"
-"Benutzen Sie \"git am --abort\", um es zu entfernen."
+"Sie können den Commit nun nachbessern mit:\n"
+"\n"
+"  git commit --amend %s\n"
+"\n"
+"Sobald Sie mit Ihren Änderungen zufrieden sind, führen Sie aus:\n"
+"\n"
+"  git rebase --continue\n"
 
-#: builtin/am.c:2372
-msgid "Resolve operation not in progress, we are not resuming."
-msgstr "Es ist keine Auflösung im Gange, es wird nicht fortgesetzt."
+#: sequencer.c:3169
+#, c-format
+msgid "Could not apply %s... %.*s"
+msgstr "Konnte %s... (%.*s) nicht anwenden"
 
-#: builtin/apply.c:8
-msgid "git apply [<options>] [<patch>...]"
-msgstr "git apply [<Optionen>] [<Patch>...]"
+#: sequencer.c:3176
+#, c-format
+msgid "Could not merge %.*s"
+msgstr "Konnte \"%.*s\" nicht zusammenführen."
 
-#: builtin/archive.c:17
+#: sequencer.c:3190 sequencer.c:3194 builtin/difftool.c:641
 #, c-format
-msgid "could not create archive file '%s'"
-msgstr "Konnte Archiv-Datei '%s' nicht erstellen."
+msgid "could not copy '%s' to '%s'"
+msgstr "Konnte '%s' nicht nach '%s' kopieren."
 
-#: builtin/archive.c:20
-msgid "could not redirect output"
-msgstr "Konnte Ausgabe nicht umleiten."
+#: sequencer.c:3221
+#, c-format
+msgid ""
+"execution failed: %s\n"
+"%sYou can fix the problem, and then run\n"
+"\n"
+"  git rebase --continue\n"
+"\n"
+msgstr ""
+"Ausführung fehlgeschlagen: %s\n"
+"%sSie können das Problem beheben, und dann\n"
+"\n"
+"\tgit rebase --continue\n"
+"\n"
+"ausführen.\n"
 
-#: builtin/archive.c:37
-msgid "git archive: Remote with no URL"
-msgstr "git archive: Externes Archiv ohne URL"
+#: sequencer.c:3227
+msgid "and made changes to the index and/or the working tree\n"
+msgstr "Der Index und/oder das Arbeitsverzeichnis wurde geändert.\n"
 
-#: builtin/archive.c:58
-msgid "git archive: expected ACK/NAK, got a flush packet"
-msgstr "git archive: ACK/NAK erwartet, Flush-Paket bekommen"
+#: sequencer.c:3233
+#, c-format
+msgid ""
+"execution succeeded: %s\n"
+"but left changes to the index and/or the working tree\n"
+"Commit or stash your changes, and then run\n"
+"\n"
+"  git rebase --continue\n"
+"\n"
+msgstr ""
+"Ausführung erfolgreich: %s\n"
+"Aber Änderungen in Index oder Arbeitsverzeichnis verblieben.\n"
+"Committen Sie Ihre Änderungen oder benutzen Sie \"stash\".\n"
+"Führen Sie dann aus:\n"
+"\n"
+"  git rebase --continue\n"
+"\n"
 
-#: builtin/archive.c:61
+#: sequencer.c:3294
 #, c-format
-msgid "git archive: NACK %s"
-msgstr "git archive: NACK %s"
+msgid "illegal label name: '%.*s'"
+msgstr "Unerlaubter Beschriftungsname: '%.*s'"
 
-#: builtin/archive.c:64
-msgid "git archive: protocol error"
-msgstr "git archive: Protokollfehler"
+#: sequencer.c:3348
+msgid "writing fake root commit"
+msgstr "unechten Root-Commit schreiben"
 
-#: builtin/archive.c:68
-msgid "git archive: expected a flush"
-msgstr "git archive: erwartete eine Spülung (flush)"
+#: sequencer.c:3353
+msgid "writing squash-onto"
+msgstr "squash-onto schreiben"
 
-#: builtin/bisect--helper.c:12
-msgid "git bisect--helper --next-all [--no-checkout]"
-msgstr "git bisect--helper --next-all [--no-checkout]"
+#: sequencer.c:3391 builtin/rebase.c:876 builtin/rebase.c:882
+#, c-format
+msgid "failed to find tree of %s"
+msgstr "Fehler beim Finden des \"Tree\"-Objektes von %s."
 
-#: builtin/bisect--helper.c:13
-msgid "git bisect--helper --write-terms <bad_term> <good_term>"
-msgstr "git bisect--helper --write-terms <bad_term> <good_term>"
+#: sequencer.c:3436
+#, c-format
+msgid "could not resolve '%s'"
+msgstr "Konnte '%s' nicht auflösen."
 
-#: builtin/bisect--helper.c:14
-msgid "git bisect--helper --bisect-clean-state"
-msgstr "git bisect--helper --bisect-clean-state"
+#: sequencer.c:3467
+msgid "cannot merge without a current revision"
+msgstr "Kann nicht ohne einen aktuellen Commit mergen."
 
-#: builtin/bisect--helper.c:46
+#: sequencer.c:3489
 #, c-format
-msgid "'%s' is not a valid term"
-msgstr "'%s' ist kein gültiger Begriff."
+msgid "unable to parse '%.*s'"
+msgstr "Konnte '%.*s' nicht parsen."
 
-#: builtin/bisect--helper.c:50
+#: sequencer.c:3498
 #, c-format
-msgid "can't use the builtin command '%s' as a term"
-msgstr "Kann den eingebauten Befehl '%s' nicht als Begriff verwenden."
+msgid "nothing to merge: '%.*s'"
+msgstr "Nichts zum Zusammenführen: '%.*s'"
 
-#: builtin/bisect--helper.c:60
-#, c-format
-msgid "can't change the meaning of the term '%s'"
-msgstr "Kann die Bedeutung von dem Begriff '%s' nicht ändern."
+#: sequencer.c:3510
+msgid "octopus merge cannot be executed on top of a [new root]"
+msgstr ""
+"Octupus-Merge kann nicht auf Basis von [neuem Root-Commit] ausgeführt werden."
 
-#: builtin/bisect--helper.c:71
-msgid "please use two different terms"
-msgstr "Bitte verwenden Sie zwei verschiedene Begriffe."
+#: sequencer.c:3526
+#, c-format
+msgid "could not get commit message of '%s'"
+msgstr "Konnte keine Commit-Beschreibung von '%s' bekommen."
 
-#: builtin/bisect--helper.c:78
-msgid "could not open the file BISECT_TERMS"
-msgstr "Konnte die Datei BISECT_TERMS nicht öffnen."
+#: sequencer.c:3688
+#, c-format
+msgid "could not even attempt to merge '%.*s'"
+msgstr "Konnte nicht einmal versuchen '%.*s' zu mergen."
 
-#: builtin/bisect--helper.c:120
-msgid "perform 'git bisect next'"
-msgstr "'git bisect next' ausführen"
+#: sequencer.c:3704
+msgid "merge: Unable to write new index file"
+msgstr "merge: Konnte neue Index-Datei nicht schreiben."
 
-#: builtin/bisect--helper.c:122
-msgid "write the terms to .git/BISECT_TERMS"
-msgstr "die Begriffe nach .git/BISECT_TERMS schreiben"
+#: sequencer.c:3773 builtin/rebase.c:733
+#, c-format
+msgid "Applied autostash.\n"
+msgstr "Automatischen Stash angewendet.\n"
 
-#: builtin/bisect--helper.c:124
-msgid "cleanup the bisection state"
-msgstr "den Zustand der binären Suche aufräumen"
+#: sequencer.c:3785
+#, c-format
+msgid "cannot store %s"
+msgstr "kann %s nicht speichern"
 
-#: builtin/bisect--helper.c:126
-msgid "check for expected revs"
-msgstr "auf erwartete Commits prüfen"
+#: sequencer.c:3788 builtin/rebase.c:749 git-rebase--preserve-merges.sh:113
+#, c-format
+msgid ""
+"Applying autostash resulted in conflicts.\n"
+"Your changes are safe in the stash.\n"
+"You can run \"git stash pop\" or \"git stash drop\" at any time.\n"
+msgstr ""
+"Anwendung des automatischen Stash resultierte in Konflikten.\n"
+"Ihre Änderungen sind im Stash sicher.\n"
+"Sie können jederzeit \"git stash pop\" oder \"git stash drop\" ausführen.\n"
 
-#: builtin/bisect--helper.c:128
-msgid "update BISECT_HEAD instead of checking out the current commit"
-msgstr "BISECT_HEAD aktualisieren, anstatt den aktuellen Commit auszuchecken"
+#: sequencer.c:3849
+#, c-format
+msgid "could not checkout %s"
+msgstr "Konnte %s nicht auschecken."
 
-#: builtin/bisect--helper.c:143
-msgid "--write-terms requires two arguments"
-msgstr "--write-terms benötigt zwei Argumente."
+#: sequencer.c:3863
+#, c-format
+msgid "%s: not a valid OID"
+msgstr "%s: keine gültige OID"
 
-#: builtin/bisect--helper.c:147
-msgid "--bisect-clean-state requires no arguments"
-msgstr "--bisect-clean-state erwartet keine Argumente."
+#: sequencer.c:3868 git-rebase--preserve-merges.sh:779
+msgid "could not detach HEAD"
+msgstr "Konnte HEAD nicht loslösen"
 
-#: builtin/blame.c:27
-msgid "git blame [<options>] [<rev-opts>] [<rev>] [--] <file>"
-msgstr "git blame [<Optionen>] [<rev-opts>] [<Commit>] [--] <Datei>"
+#: sequencer.c:3883
+#, c-format
+msgid "Stopped at HEAD\n"
+msgstr "Angehalten bei HEAD\n"
 
-#: builtin/blame.c:32
-msgid "<rev-opts> are documented in git-rev-list(1)"
-msgstr "<rev-opts> sind dokumentiert in git-rev-list(1)"
+#: sequencer.c:3885
+#, c-format
+msgid "Stopped at %s\n"
+msgstr "Angehalten bei %s\n"
 
-#: builtin/blame.c:677
-msgid "Show blame entries as we find them, incrementally"
-msgstr "\"blame\"-Einträge schrittweise anzeigen, während wir sie generieren"
+#: sequencer.c:3893
+#, c-format
+msgid ""
+"Could not execute the todo command\n"
+"\n"
+"    %.*s\n"
+"It has been rescheduled; To edit the command before continuing, please\n"
+"edit the todo list first:\n"
+"\n"
+"    git rebase --edit-todo\n"
+"    git rebase --continue\n"
+msgstr ""
+"Konnte TODO-Befehl nicht ausführen\n"
+"\n"
+"    %.*s\n"
+"Dieser wurde neu angesetzt; Um den Befehl zu bearbeiten, bevor fortgesetzt "
+"wird,\n"
+"bearbeiten Sie bitte zuerst die TODO-Liste:\n"
+"\n"
+"    git rebase --edit-todo\n"
+"    git rebase --continue\n"
 
-#: builtin/blame.c:678
-msgid "Show blank SHA-1 for boundary commits (Default: off)"
-msgstr "leere SHA-1 für Grenz-Commits anzeigen (Standard: aus)"
+#: sequencer.c:3979
+#, c-format
+msgid "Stopped at %s...  %.*s\n"
+msgstr "Angehalten bei %s... %.*s\n"
 
-#: builtin/blame.c:679
-msgid "Do not treat root commits as boundaries (Default: off)"
-msgstr "Ursprungs-Commits nicht als Grenzen behandeln (Standard: aus)"
+#: sequencer.c:4050
+#, c-format
+msgid "unknown command %d"
+msgstr "Unbekannter Befehl %d"
 
-#: builtin/blame.c:680
-msgid "Show work cost statistics"
-msgstr "Statistiken zum Arbeitsaufwand anzeigen"
+#: sequencer.c:4109
+msgid "could not read orig-head"
+msgstr "Konnte orig-head nicht lesen."
 
-#: builtin/blame.c:681
-msgid "Force progress reporting"
-msgstr "Fortschrittsanzeige erzwingen"
+#: sequencer.c:4114
+msgid "could not read 'onto'"
+msgstr "Konnte 'onto' nicht lesen."
 
-#: builtin/blame.c:682
-msgid "Show output score for blame entries"
-msgstr "Ausgabebewertung für \"blame\"-Einträge anzeigen"
+#: sequencer.c:4128
+#, c-format
+msgid "could not update HEAD to %s"
+msgstr "Konnte HEAD nicht auf %s aktualisieren."
 
-#: builtin/blame.c:683
-msgid "Show original filename (Default: auto)"
-msgstr "ursprünglichen Dateinamen anzeigen (Standard: auto)"
+#: sequencer.c:4221
+msgid "cannot rebase: You have unstaged changes."
+msgstr ""
+"Rebase nicht möglich: Sie haben Änderungen, die nicht zum Commit\n"
+"vorgemerkt sind."
 
-#: builtin/blame.c:684
-msgid "Show original linenumber (Default: off)"
-msgstr "ursprüngliche Zeilennummer anzeigen (Standard: aus)"
+#: sequencer.c:4230
+msgid "cannot amend non-existing commit"
+msgstr "Kann nicht existierenden Commit nicht nachbessern."
 
-#: builtin/blame.c:685
-msgid "Show in a format designed for machine consumption"
-msgstr "Anzeige in einem Format für maschinelle Auswertung"
+#: sequencer.c:4232
+#, c-format
+msgid "invalid file: '%s'"
+msgstr "Ungültige Datei: '%s'"
 
-#: builtin/blame.c:686
-msgid "Show porcelain format with per-line commit information"
-msgstr ""
-"Anzeige in Format für Fremdprogramme mit Commit-Informationen pro Zeile"
+#: sequencer.c:4234
+#, c-format
+msgid "invalid contents: '%s'"
+msgstr "Ungültige Inhalte: '%s'"
 
-#: builtin/blame.c:687
-msgid "Use the same output mode as git-annotate (Default: off)"
+#: sequencer.c:4237
+msgid ""
+"\n"
+"You have uncommitted changes in your working tree. Please, commit them\n"
+"first and then run 'git rebase --continue' again."
 msgstr ""
-"Den gleichen Ausgabemodus benutzen wie \"git-annotate\" (Standard: aus)"
+"\n"
+"Sie haben nicht committete Änderungen in Ihrem Arbeitsverzeichnis. Bitte\n"
+"committen Sie diese zuerst und führen Sie dann 'git rebase --continue'\n"
+"erneut aus."
 
-#: builtin/blame.c:688
-msgid "Show raw timestamp (Default: off)"
-msgstr "Unbearbeiteten Zeitstempel anzeigen (Standard: aus)"
+#: sequencer.c:4273 sequencer.c:4312
+#, c-format
+msgid "could not write file: '%s'"
+msgstr "Konnte Datei nicht schreiben: '%s'"
 
-#: builtin/blame.c:689
-msgid "Show long commit SHA1 (Default: off)"
-msgstr "Langen Commit-SHA1 anzeigen (Standard: aus)"
+#: sequencer.c:4327
+msgid "could not remove CHERRY_PICK_HEAD"
+msgstr "Konnte CHERRY_PICK_HEAD nicht löschen."
 
-#: builtin/blame.c:690
-msgid "Suppress author name and timestamp (Default: off)"
-msgstr "Den Namen des Autors und den Zeitstempel unterdrücken (Standard: aus)"
+#: sequencer.c:4334
+msgid "could not commit staged changes."
+msgstr "Konnte Änderungen aus der Staging-Area nicht committen."
 
-#: builtin/blame.c:691
-msgid "Show author email instead of name (Default: off)"
-msgstr ""
-"Anstatt des Namens die E-Mail-Adresse des Autors anzeigen (Standard: aus)"
+#: sequencer.c:4440
+#, c-format
+msgid "%s: can't cherry-pick a %s"
+msgstr "%s: %s kann nicht in \"cherry-pick\" benutzt werden"
 
-#: builtin/blame.c:692
-msgid "Ignore whitespace differences"
-msgstr "Unterschiede im Whitespace ignorieren"
+#: sequencer.c:4444
+#, c-format
+msgid "%s: bad revision"
+msgstr "%s: ungültiger Commit"
 
-#: builtin/blame.c:699
-msgid "Use an experimental heuristic to improve diffs"
-msgstr ""
-"eine experimentelle Heuristik zur Verbesserung der Darstellung\n"
-"von Unterschieden verwenden"
+#: sequencer.c:4479
+msgid "can't revert as initial commit"
+msgstr "Kann nicht als allerersten Commit einen Revert ausführen."
 
-#: builtin/blame.c:701
-msgid "Spend extra cycles to find better match"
-msgstr "Länger arbeiten, um bessere Übereinstimmungen zu finden"
+#: sequencer.c:4952
+msgid "make_script: unhandled options"
+msgstr "make_script: unbehandelte Optionen"
 
-#: builtin/blame.c:702
-msgid "Use revisions from <file> instead of calling git-rev-list"
-msgstr "Commits von <Datei> benutzen, anstatt \"git-rev-list\" aufzurufen"
+#: sequencer.c:4955
+msgid "make_script: error preparing revisions"
+msgstr "make_script: Fehler beim Vorbereiten der Commits"
 
-#: builtin/blame.c:703
-msgid "Use <file>'s contents as the final image"
-msgstr "Inhalte der <Datei>en als endgültiges Abbild benutzen"
+#: sequencer.c:5113
+msgid ""
+"You can fix this with 'git rebase --edit-todo' and then run 'git rebase --"
+"continue'.\n"
+"Or you can abort the rebase with 'git rebase --abort'.\n"
+msgstr ""
+"Sie können das mit 'git rebase --edit-todo' beheben. Führen Sie danach\n"
+"'git rebase --continue' aus.\n"
+"Oder Sie können den Rebase mit 'git rebase --abort' abbrechen.\n"
 
-#: builtin/blame.c:704 builtin/blame.c:705
-msgid "score"
-msgstr "Bewertung"
+#: sequencer.c:5226 sequencer.c:5243
+msgid "nothing to do"
+msgstr "Nichts zu tun."
+
+#: sequencer.c:5257
+msgid "could not skip unnecessary pick commands"
+msgstr "Konnte unnötige \"pick\"-Befehle nicht auslassen."
 
-#: builtin/blame.c:704
-msgid "Find line copies within and across files"
-msgstr "kopierte Zeilen innerhalb oder zwischen Dateien finden"
+#: sequencer.c:5351
+msgid "the script was already rearranged."
+msgstr "Das Script wurde bereits umgeordnet."
 
-#: builtin/blame.c:705
-msgid "Find line movements within and across files"
-msgstr "verschobene Zeilen innerhalb oder zwischen Dateien finden"
+#: setup.c:124
+#, c-format
+msgid "'%s' is outside repository"
+msgstr "'%s' liegt außerhalb des Repositories."
 
-#: builtin/blame.c:706
-msgid "n,m"
-msgstr "n,m"
+#: setup.c:174
+#, c-format
+msgid ""
+"%s: no such path in the working tree.\n"
+"Use 'git <command> -- <path>...' to specify paths that do not exist locally."
+msgstr ""
+"%s: kein solcher Pfad im Arbeitsverzeichnis.\n"
+"Benutzen Sie 'git <Befehl> -- <Pfad>...' zur Angabe von Pfaden, die lokal\n"
+"nicht existieren."
 
-#: builtin/blame.c:706
-msgid "Process only line range n,m, counting from 1"
-msgstr "nur Zeilen im Bereich n,m verarbeiten, gezählt von 1"
+#: setup.c:187
+#, c-format
+msgid ""
+"ambiguous argument '%s': unknown revision or path not in the working tree.\n"
+"Use '--' to separate paths from revisions, like this:\n"
+"'git <command> [<revision>...] -- [<file>...]'"
+msgstr ""
+"mehrdeutiges Argument '%s': unbekannter Commit oder Pfad existiert nicht\n"
+"im Arbeitsverzeichnis\n"
+"Benutzen Sie '--', um Pfade und Commits zu trennen, ähnlich wie:\n"
+"'git <Befehl> [<Commit>...] -- [<Datei>...]'"
 
-#: builtin/blame.c:753
-msgid "--progress can't be used with --incremental or porcelain formats"
+#: setup.c:236
+#, c-format
+msgid "option '%s' must come before non-option arguments"
 msgstr ""
-"--progress kann nicht mit --incremental oder Formaten für Fremdprogramme\n"
-"verwendet werden"
+"Die Option '%s' muss vor den Argumenten kommen, die keine Optionen sind."
 
-#. TRANSLATORS: This string is used to tell us the
-#. maximum display width for a relative timestamp in
-#. "git blame" output.  For C locale, "4 years, 11
-#. months ago", which takes 22 places, is the longest
-#. among various forms of relative timestamps, but
-#. your language may need more or fewer display
-#. columns.
-#.
-#: builtin/blame.c:804
-msgid "4 years, 11 months ago"
-msgstr "vor 4 Jahren und 11 Monaten"
+#: setup.c:255
+#, c-format
+msgid ""
+"ambiguous argument '%s': both revision and filename\n"
+"Use '--' to separate paths from revisions, like this:\n"
+"'git <command> [<revision>...] -- [<file>...]'"
+msgstr ""
+"mehrdeutiges Argument '%s': sowohl Commit als auch Dateiname\n"
+"Benutzen Sie '--', um Pfade und Commits zu trennen, ähnlich wie:\n"
+"'git <Befehl> [<Commit>...] -- [<Datei>...]'"
+
+#: setup.c:391
+msgid "unable to set up work tree using invalid config"
+msgstr ""
+"Konnte Arbeitsverzeichnis mit ungültiger Konfiguration nicht einrichten."
+
+#: setup.c:395
+msgid "this operation must be run in a work tree"
+msgstr "Diese Operation muss in einem Arbeitsverzeichnis ausgeführt werden."
 
-#: builtin/blame.c:890
+#: setup.c:541
 #, c-format
-msgid "file %s has only %lu line"
-msgid_plural "file %s has only %lu lines"
-msgstr[0] "Datei %s hat nur %lu Zeile"
-msgstr[1] "Datei %s hat nur %lu Zeilen"
+msgid "Expected git repo version <= %d, found %d"
+msgstr "Erwartete Git-Repository-Version <= %d, %d gefunden"
 
-#: builtin/blame.c:936
-msgid "Blaming lines"
-msgstr "Verarbeite Zeilen"
+#: setup.c:549
+msgid "unknown repository extensions found:"
+msgstr "Unbekannte Repository-Erweiterungen gefunden:"
 
-#: builtin/branch.c:27
-msgid "git branch [<options>] [-r | -a] [--merged | --no-merged]"
-msgstr "git branch [<Optionen>] [-r | -a] [--merged | --no-merged]"
+#: setup.c:568
+#, c-format
+msgid "error opening '%s'"
+msgstr "Fehler beim Öffnen von '%s'."
 
-#: builtin/branch.c:28
-msgid "git branch [<options>] [-l] [-f] <branch-name> [<start-point>]"
-msgstr "git branch [<Optionen>] [-l] [-f] <Branchname> [<Startpunkt>]"
+#: setup.c:570
+#, c-format
+msgid "too large to be a .git file: '%s'"
+msgstr "Zu groß, um eine .git-Datei zu sein: '%s'"
 
-#: builtin/branch.c:29
-msgid "git branch [<options>] [-r] (-d | -D) <branch-name>..."
-msgstr "git branch [<Optionen>] [-r] (-d | -D) <Branchname>..."
+#: setup.c:572
+#, c-format
+msgid "error reading %s"
+msgstr "Fehler beim Lesen von '%s'."
 
-#: builtin/branch.c:30
-msgid "git branch [<options>] (-m | -M) [<old-branch>] <new-branch>"
-msgstr "git branch [<Optionen>] (-m | -M) [<alter-Branch>] <neuer-Branch>"
+#: setup.c:574
+#, c-format
+msgid "invalid gitfile format: %s"
+msgstr "Ungültiges gitfile-Format: %s"
 
-#: builtin/branch.c:31
-msgid "git branch [<options>] (-c | -C) [<old-branch>] <new-branch>"
-msgstr "git branch [<Optionen>] (-c | -C) [<alter-Branch>] <neuer-Branch>"
+#: setup.c:576
+#, c-format
+msgid "no path in gitfile: %s"
+msgstr "Kein Pfad in gitfile: %s"
 
-#: builtin/branch.c:32
-msgid "git branch [<options>] [-r | -a] [--points-at]"
-msgstr "git branch [<Optionen>] [-r | -a] [--points-at]"
+#: setup.c:578
+#, c-format
+msgid "not a git repository: %s"
+msgstr "Kein Git-Repository: %s"
 
-#: builtin/branch.c:33
-msgid "git branch [<options>] [-r | -a] [--format]"
-msgstr "git branch [<Optionen>] [-r | -a] [--format]"
+#: setup.c:677
+#, c-format
+msgid "'$%s' too big"
+msgstr "'$%s' zu groß"
+
+#: setup.c:691
+#, c-format
+msgid "not a git repository: '%s'"
+msgstr "Kein Git-Repository: '%s'"
+
+#: setup.c:720 setup.c:722 setup.c:753
+#, c-format
+msgid "cannot chdir to '%s'"
+msgstr "Kann nicht in Verzeichnis '%s' wechseln."
+
+#: setup.c:725 setup.c:781 setup.c:791 setup.c:830 setup.c:838
+msgid "cannot come back to cwd"
+msgstr "Kann nicht zum aktuellen Arbeitsverzeichnis zurückwechseln."
+
+#: setup.c:852
+#, c-format
+msgid "failed to stat '%*s%s%s'"
+msgstr "Konnte '%*s%s%s' nicht lesen."
 
-#: builtin/branch.c:146
+#: setup.c:1090
+msgid "Unable to read current working directory"
+msgstr "Konnte aktuelles Arbeitsverzeichnis nicht lesen."
+
+#: setup.c:1099 setup.c:1105
+#, c-format
+msgid "cannot change to '%s'"
+msgstr "Kann nicht nach '%s' wechseln."
+
+#: setup.c:1110
+#, c-format
+msgid "not a git repository (or any of the parent directories): %s"
+msgstr "Kein Git-Repository (oder irgendeines der Elternverzeichnisse): %s"
+
+#: setup.c:1116
 #, c-format
 msgid ""
-"deleting branch '%s' that has been merged to\n"
-"         '%s', but not yet merged to HEAD."
+"not a git repository (or any parent up to mount point %s)\n"
+"Stopping at filesystem boundary (GIT_DISCOVERY_ACROSS_FILESYSTEM not set)."
 msgstr ""
-"entferne Branch '%s', der zusammengeführt wurde mit\n"
-"         '%s', aber noch nicht mit HEAD zusammengeführt wurde."
+"Kein Git-Repository (oder irgendein Elternverzeichnis bis zum Einhängepunkt "
+"%s)\n"
+"Stoppe bei Dateisystemgrenze (GIT_DISCOVERY_ACROSS_FILESYSTEM nicht gesetzt)."
 
-#: builtin/branch.c:150
+#: setup.c:1227
 #, c-format
 msgid ""
-"not deleting branch '%s' that is not yet merged to\n"
-"         '%s', even though it is merged to HEAD."
+"problem with core.sharedRepository filemode value (0%.3o).\n"
+"The owner of files must always have read and write permissions."
 msgstr ""
-"entferne Branch '%s' nicht, der noch nicht zusammengeführt wurde mit\n"
-"         '%s', obwohl er mit HEAD zusammengeführt wurde."
+"Problem mit Wert für Dateimodus (0%.3o) von core.sharedRepository.\n"
+"Der Besitzer der Dateien muss immer Lese- und Schreibrechte haben."
 
-#: builtin/branch.c:164
-#, c-format
-msgid "Couldn't look up commit object for '%s'"
-msgstr "Konnte Commit-Objekt für '%s' nicht nachschlagen."
+#: setup.c:1271
+msgid "open /dev/null or dup failed"
+msgstr "Öffnen von /dev/null oder dup fehlgeschlagen."
+
+#: setup.c:1286
+msgid "fork failed"
+msgstr "fork fehlgeschlagen"
 
-#: builtin/branch.c:168
+#: setup.c:1291
+msgid "setsid failed"
+msgstr "setsid fehlgeschlagen"
+
+#: sha1-file.c:452
 #, c-format
-msgid ""
-"The branch '%s' is not fully merged.\n"
-"If you are sure you want to delete it, run 'git branch -D %s'."
+msgid "object directory %s does not exist; check .git/objects/info/alternates"
 msgstr ""
-"Der Branch '%s' ist nicht vollständig zusammengeführt.\n"
-"Wenn Sie sicher sind diesen Branch zu entfernen, führen Sie 'git branch -D "
-"%s' aus."
+"Objektverzeichnis %s existiert nicht; prüfe .git/objects/info/alternates"
 
-#: builtin/branch.c:181
-msgid "Update of config-file failed"
-msgstr "Aktualisierung der Konfigurationsdatei fehlgeschlagen."
+#: sha1-file.c:503
+#, c-format
+msgid "unable to normalize alternate object path: %s"
+msgstr "Konnte alternativen Objektpfad '%s' nicht normalisieren."
 
-#: builtin/branch.c:212
-msgid "cannot use -a with -d"
-msgstr "kann -a nicht mit -d benutzen"
+#: sha1-file.c:575
+#, c-format
+msgid "%s: ignoring alternate object stores, nesting too deep"
+msgstr "%s: ignoriere alternative Objektspeicher - Verschachtelung zu tief"
 
-#: builtin/branch.c:218
-msgid "Couldn't look up commit object for HEAD"
-msgstr "Konnte Commit-Objekt für HEAD nicht nachschlagen."
+#: sha1-file.c:582
+#, c-format
+msgid "unable to normalize object directory: %s"
+msgstr "Konnte Objektverzeichnis '%s' nicht normalisieren."
+
+#: sha1-file.c:625
+msgid "unable to fdopen alternates lockfile"
+msgstr "Konnte fdopen nicht auf Lock-Datei für \"alternates\" aufrufen."
+
+#: sha1-file.c:643
+msgid "unable to read alternates file"
+msgstr "Konnte \"alternates\"-Datei nicht lesen."
 
-#: builtin/branch.c:232
+#: sha1-file.c:650
+msgid "unable to move new alternates file into place"
+msgstr "Konnte neue \"alternates\"-Datei nicht übernehmen."
+
+#: sha1-file.c:685
 #, c-format
-msgid "Cannot delete branch '%s' checked out at '%s'"
-msgstr "Kann Branch '%s' nicht entfernen, ausgecheckt in '%s'."
+msgid "path '%s' does not exist"
+msgstr "Pfad '%s' existiert nicht"
 
-#: builtin/branch.c:247
+#: sha1-file.c:711
 #, c-format
-msgid "remote-tracking branch '%s' not found."
-msgstr "Remote-Tracking-Branch '%s' nicht gefunden"
+msgid "reference repository '%s' as a linked checkout is not supported yet."
+msgstr ""
+"Referenziertes Repository '%s' wird noch nicht als verknüpftes\n"
+"Arbeitsverzeichnis unterstützt."
 
-#: builtin/branch.c:248
+#: sha1-file.c:717
 #, c-format
-msgid "branch '%s' not found."
-msgstr "Branch '%s' nicht gefunden."
+msgid "reference repository '%s' is not a local repository."
+msgstr "Referenziertes Repository '%s' ist kein lokales Repository."
 
-#: builtin/branch.c:263
+#: sha1-file.c:723
 #, c-format
-msgid "Error deleting remote-tracking branch '%s'"
-msgstr "Fehler beim Entfernen des Remote-Tracking-Branches '%s'"
+msgid "reference repository '%s' is shallow"
+msgstr ""
+"Referenziertes Repository '%s' hat eine unvollständige Historie (shallow)."
 
-#: builtin/branch.c:264
+#: sha1-file.c:731
 #, c-format
-msgid "Error deleting branch '%s'"
-msgstr "Fehler beim Entfernen des Branches '%s'"
+msgid "reference repository '%s' is grafted"
+msgstr ""
+"Referenziertes Repository '%s' ist mit künstlichen Vorgängern (\"grafts\") "
+"eingehängt."
 
-#: builtin/branch.c:271
+#: sha1-file.c:791
 #, c-format
-msgid "Deleted remote-tracking branch %s (was %s).\n"
-msgstr "Remote-Tracking-Branch %s entfernt (war %s).\n"
+msgid "invalid line while parsing alternate refs: %s"
+msgstr "Ungültige Zeile beim Parsen alternativer Referenzen: %s"
 
-#: builtin/branch.c:272
+#: sha1-file.c:943
 #, c-format
-msgid "Deleted branch %s (was %s).\n"
-msgstr "Branch %s entfernt (war %s).\n"
+msgid "attempting to mmap %<PRIuMAX> over limit %<PRIuMAX>"
+msgstr "Versuche mmap %<PRIuMAX> über Limit %<PRIuMAX>."
 
-#: builtin/branch.c:417 builtin/tag.c:58
-msgid "unable to parse format string"
-msgstr "Konnte Formatierungsstring nicht parsen."
+#: sha1-file.c:964
+msgid "mmap failed"
+msgstr "mmap fehlgeschlagen"
 
-#: builtin/branch.c:450
+#: sha1-file.c:1128
 #, c-format
-msgid "Branch %s is being rebased at %s"
-msgstr "Branch %s wird auf %s umgesetzt"
+msgid "object file %s is empty"
+msgstr "Objektdatei %s ist leer."
 
-#: builtin/branch.c:454
+#: sha1-file.c:1252 sha1-file.c:2392
 #, c-format
-msgid "Branch %s is being bisected at %s"
-msgstr "Binäre Suche von Branch %s zu %s im Gange"
+msgid "corrupt loose object '%s'"
+msgstr "Fehlerhaftes loses Objekt '%s'."
 
-#: builtin/branch.c:471
-msgid "cannot copy the current branch while not on any."
-msgstr ""
-"Kann den aktuellen Branch nicht kopieren, solange Sie sich auf keinem "
-"befinden."
+#: sha1-file.c:1254 sha1-file.c:2396
+#, c-format
+msgid "garbage at end of loose object '%s'"
+msgstr "Nutzlose Daten am Ende von losem Objekt '%s'."
 
-#: builtin/branch.c:473
-msgid "cannot rename the current branch while not on any."
-msgstr ""
-"Kann aktuellen Branch nicht umbenennen, solange Sie sich auf keinem befinden."
+#: sha1-file.c:1296
+msgid "invalid object type"
+msgstr "ungültiger Objekt-Typ"
 
-#: builtin/branch.c:484
+#: sha1-file.c:1380
 #, c-format
-msgid "Invalid branch name: '%s'"
-msgstr "Ungültiger Branchname: '%s'"
+msgid "unable to unpack %s header with --allow-unknown-type"
+msgstr "Konnte %s Kopfbereich nicht mit --allow-unknown-type entpacken."
 
-#: builtin/branch.c:511
-msgid "Branch rename failed"
-msgstr "Umbenennung des Branches fehlgeschlagen"
+#: sha1-file.c:1383
+#, c-format
+msgid "unable to unpack %s header"
+msgstr "Konnte %s Kopfbereich nicht entpacken."
 
-#: builtin/branch.c:513
-msgid "Branch copy failed"
-msgstr "Kopie des Branches fehlgeschlagen"
+#: sha1-file.c:1389
+#, c-format
+msgid "unable to parse %s header with --allow-unknown-type"
+msgstr "Konnte %s Kopfbereich mit --allow-unknown-type nicht parsen."
 
-#: builtin/branch.c:517
+#: sha1-file.c:1392
 #, c-format
-msgid "Created a copy of a misnamed branch '%s'"
-msgstr "Kopie eines falsch benannten Branches '%s' erstellt."
+msgid "unable to parse %s header"
+msgstr "Konnte %s Kopfbereich nicht parsen."
 
-#: builtin/branch.c:520
+#: sha1-file.c:1584
 #, c-format
-msgid "Renamed a misnamed branch '%s' away"
-msgstr "falsch benannten Branch '%s' umbenannt"
+msgid "failed to read object %s"
+msgstr "Konnte Objekt %s nicht lesen."
 
-#: builtin/branch.c:526
+#: sha1-file.c:1588
 #, c-format
-msgid "Branch renamed to %s, but HEAD is not updated!"
-msgstr "Branch umbenannt zu %s, aber HEAD ist nicht aktualisiert!"
+msgid "replacement %s not found for %s"
+msgstr "Ersetzung %s für %s nicht gefunden."
 
-#: builtin/branch.c:535
-msgid "Branch is renamed, but update of config-file failed"
-msgstr ""
-"Branch ist umbenannt, aber die Aktualisierung der Konfigurationsdatei ist "
-"fehlgeschlagen."
+#: sha1-file.c:1592
+#, c-format
+msgid "loose object %s (stored in %s) is corrupt"
+msgstr "Loses Objekt %s (gespeichert in %s) ist beschädigt."
 
-#: builtin/branch.c:537
-msgid "Branch is copied, but update of config-file failed"
-msgstr ""
-"Branch wurde kopiert, aber die Aktualisierung der Konfigurationsdatei ist\n"
-"fehlgeschlagen."
+#: sha1-file.c:1596
+#, c-format
+msgid "packed object %s (stored in %s) is corrupt"
+msgstr "Gepacktes Objekt %s (gespeichert in %s) ist beschädigt."
 
-#: builtin/branch.c:553
+#: sha1-file.c:1699
 #, c-format
-msgid ""
-"Please edit the description for the branch\n"
-"  %s\n"
-"Lines starting with '%c' will be stripped.\n"
-msgstr ""
-"Bitte ändern Sie die Beschreibung für den Branch\n"
-"  %s\n"
-"Zeilen, die mit '%c' beginnen, werden entfernt.\n"
+msgid "unable to write file %s"
+msgstr "Konnte Datei %s nicht schreiben."
 
-#: builtin/branch.c:586
-msgid "Generic options"
-msgstr "Allgemeine Optionen"
+#: sha1-file.c:1706
+#, c-format
+msgid "unable to set permission to '%s'"
+msgstr "Konnte Zugriffsberechtigung auf '%s' nicht setzen."
 
-#: builtin/branch.c:588
-msgid "show hash and subject, give twice for upstream branch"
-msgstr "Hash und Betreff anzeigen; -vv: zusätzlich Upstream-Branch"
+#: sha1-file.c:1713
+msgid "file write error"
+msgstr "Fehler beim Schreiben einer Datei."
 
-#: builtin/branch.c:589
-msgid "suppress informational messages"
-msgstr "Informationsmeldungen unterdrücken"
+#: sha1-file.c:1732
+msgid "error when closing loose object file"
+msgstr "Fehler beim Schließen der Datei für lose Objekte."
 
-#: builtin/branch.c:590
-msgid "set up tracking mode (see git-pull(1))"
-msgstr "Modus zum Folgen von Branches einstellen (siehe git-pull(1))"
+#: sha1-file.c:1797
+#, c-format
+msgid "insufficient permission for adding an object to repository database %s"
+msgstr ""
+"Unzureichende Berechtigung zum Hinzufügen eines Objektes zur Repository-"
+"Datenbank %s"
 
-#: builtin/branch.c:592
-msgid "do not use"
-msgstr "nicht verwenden"
+#: sha1-file.c:1799
+msgid "unable to create temporary file"
+msgstr "Konnte temporäre Datei nicht erstellen."
 
-#: builtin/branch.c:594
-msgid "upstream"
-msgstr "Upstream"
+#: sha1-file.c:1823
+msgid "unable to write loose object file"
+msgstr "Fehler beim Schreiben der Datei für lose Objekte."
 
-#: builtin/branch.c:594
-msgid "change the upstream info"
-msgstr "Informationen zum Upstream-Branch ändern"
+#: sha1-file.c:1829
+#, c-format
+msgid "unable to deflate new object %s (%d)"
+msgstr "Konnte neues Objekt %s (%d) nicht komprimieren."
 
-#: builtin/branch.c:595
-msgid "Unset the upstream info"
-msgstr "Informationen zum Upstream-Branch entfernen"
+#: sha1-file.c:1833
+#, c-format
+msgid "deflateEnd on object %s failed (%d)"
+msgstr "deflateEnd auf Objekt %s fehlgeschlagen (%d)"
 
-#: builtin/branch.c:596
-msgid "use colored output"
-msgstr "farbige Ausgaben verwenden"
+#: sha1-file.c:1837
+#, c-format
+msgid "confused by unstable object source data for %s"
+msgstr "Fehler wegen instabilen Objektquelldaten für %s"
 
-#: builtin/branch.c:597
-msgid "act on remote-tracking branches"
-msgstr "auf Remote-Tracking-Branches wirken"
+#: sha1-file.c:1847 builtin/pack-objects.c:925
+#, c-format
+msgid "failed utime() on %s"
+msgstr "Fehler beim Aufruf von utime() auf '%s'."
 
-#: builtin/branch.c:599 builtin/branch.c:601
-msgid "print only branches that contain the commit"
-msgstr "nur Branches ausgeben, die diesen Commit enthalten"
+#: sha1-file.c:1922
+#, c-format
+msgid "cannot read object for %s"
+msgstr "Kann Objekt für %s nicht lesen."
 
-#: builtin/branch.c:600 builtin/branch.c:602
-msgid "print only branches that don't contain the commit"
-msgstr "nur Branches ausgeben, die diesen Commit nicht enthalten"
+#: sha1-file.c:1962
+msgid "corrupt commit"
+msgstr "fehlerhafter Commit"
 
-#: builtin/branch.c:605
-msgid "Specific git-branch actions:"
-msgstr "spezifische Aktionen für \"git-branch\":"
+#: sha1-file.c:1970
+msgid "corrupt tag"
+msgstr "fehlerhaftes Tag"
 
-#: builtin/branch.c:606
-msgid "list both remote-tracking and local branches"
-msgstr "Remote-Tracking und lokale Branches auflisten"
+#: sha1-file.c:2069
+#, c-format
+msgid "read error while indexing %s"
+msgstr "Lesefehler beim Indizieren von '%s'."
 
-#: builtin/branch.c:608
-msgid "delete fully merged branch"
-msgstr "vollständig zusammengeführten Branch entfernen"
+#: sha1-file.c:2072
+#, c-format
+msgid "short read while indexing %s"
+msgstr "read() zu kurz beim Indizieren von '%s'."
 
-#: builtin/branch.c:609
-msgid "delete branch (even if not merged)"
-msgstr "Branch löschen (auch wenn nicht zusammengeführt)"
+#: sha1-file.c:2145 sha1-file.c:2154
+#, c-format
+msgid "%s: failed to insert into database"
+msgstr "%s: Fehler beim Einfügen in die Datenbank"
 
-#: builtin/branch.c:610
-msgid "move/rename a branch and its reflog"
-msgstr "einen Branch und dessen Reflog verschieben/umbenennen"
+#: sha1-file.c:2160
+#, c-format
+msgid "%s: unsupported file type"
+msgstr "%s: nicht unterstützte Dateiart"
 
-#: builtin/branch.c:611
-msgid "move/rename a branch, even if target exists"
-msgstr ""
-"einen Branch verschieben/umbenennen, auch wenn das Ziel bereits existiert"
+#: sha1-file.c:2184
+#, c-format
+msgid "%s is not a valid object"
+msgstr "%s ist kein gültiges Objekt"
 
-#: builtin/branch.c:612
-msgid "copy a branch and its reflog"
-msgstr "einen Branch und dessen Reflog kopieren"
+#: sha1-file.c:2186
+#, c-format
+msgid "%s is not a valid '%s' object"
+msgstr "%s ist kein gültiges '%s' Objekt"
 
-#: builtin/branch.c:613
-msgid "copy a branch, even if target exists"
-msgstr "einen Branch kopieren, auch wenn das Ziel bereits existiert"
+#: sha1-file.c:2213 builtin/index-pack.c:155
+#, c-format
+msgid "unable to open %s"
+msgstr "kann %s nicht öffnen"
 
-#: builtin/branch.c:614
-msgid "list branch names"
-msgstr "Branchnamen auflisten"
+#: sha1-file.c:2403 sha1-file.c:2455
+#, c-format
+msgid "hash mismatch for %s (expected %s)"
+msgstr "Hash für %s stimmt nicht überein (%s erwartet)."
 
-#: builtin/branch.c:615
-msgid "create the branch's reflog"
-msgstr "das Reflog des Branches erzeugen"
+#: sha1-file.c:2427
+#, c-format
+msgid "unable to mmap %s"
+msgstr "Konnte mmap nicht auf %s ausführen."
 
-#: builtin/branch.c:617
-msgid "edit the description for the branch"
-msgstr "die Beschreibung für den Branch bearbeiten"
+#: sha1-file.c:2432
+#, c-format
+msgid "unable to unpack header of %s"
+msgstr "Konnte Kopfbereich von %s nicht entpacken."
 
-#: builtin/branch.c:618
-msgid "force creation, move/rename, deletion"
-msgstr "Erstellung, Verschiebung/Umbenennung oder Löschung erzwingen"
+#: sha1-file.c:2438
+#, c-format
+msgid "unable to parse header of %s"
+msgstr "Konnte Kopfbereich von %s nicht parsen."
 
-#: builtin/branch.c:619
-msgid "print only branches that are merged"
-msgstr "nur zusammengeführte Branches ausgeben"
+#: sha1-file.c:2449
+#, c-format
+msgid "unable to unpack contents of %s"
+msgstr "Konnte Inhalt von %s nicht entpacken."
 
-#: builtin/branch.c:620
-msgid "print only branches that are not merged"
-msgstr "nur nicht zusammengeführte Branches ausgeben"
+#: sha1-name.c:487
+#, c-format
+msgid "short SHA1 %s is ambiguous"
+msgstr "Kurzer SHA-1 %s ist mehrdeutig."
 
-#: builtin/branch.c:621
-msgid "list branches in columns"
-msgstr "Branches in Spalten auflisten"
+#: sha1-name.c:498
+msgid "The candidates are:"
+msgstr "Die Kandidaten sind:"
 
-#: builtin/branch.c:622 builtin/for-each-ref.c:40 builtin/tag.c:411
-msgid "key"
-msgstr "Schüssel"
+#: sha1-name.c:797
+msgid ""
+"Git normally never creates a ref that ends with 40 hex characters\n"
+"because it will be ignored when you just specify 40-hex. These refs\n"
+"may be created by mistake. For example,\n"
+"\n"
+"  git switch -c $br $(git rev-parse ...)\n"
+"\n"
+"where \"$br\" is somehow empty and a 40-hex ref is created. Please\n"
+"examine these refs and maybe delete them. Turn this message off by\n"
+"running \"git config advice.objectNameWarning false\""
+msgstr ""
+"Git erzeugt normalerweise keine Referenzen die mit\n"
+"40 Hex-Zeichen enden, da diese ignoriert werden wenn\n"
+"Sie diese angeben. Diese Referenzen könnten aus Versehen\n"
+"erzeugt worden sein. Zum Beispiel,\n"
+"\n"
+"  git switch -c $br $(git rev-parse ...)\n"
+"\n"
+"wobei \"$br\" leer ist und eine 40-Hex-Referenz erzeugt\n"
+"wurde. Bitte prüfen Sie diese Referenzen und löschen\n"
+"Sie sie gegebenenfalls. Unterdrücken Sie diese Meldung\n"
+"indem Sie \"git config advice.objectNameWarning false\"\n"
+"ausführen."
 
-#: builtin/branch.c:623 builtin/for-each-ref.c:41 builtin/tag.c:412
-msgid "field name to sort on"
-msgstr "sortiere nach diesem Feld"
+#. TRANSLATORS: IEC 80000-13:2008 gibibyte
+#: strbuf.c:822
+#, c-format
+msgid "%u.%2.2u GiB"
+msgstr "%u.%2.2u GiB"
 
-#: builtin/branch.c:625 builtin/for-each-ref.c:43 builtin/notes.c:408
-#: builtin/notes.c:411 builtin/notes.c:571 builtin/notes.c:574
-#: builtin/tag.c:414
-msgid "object"
-msgstr "Objekt"
+#. TRANSLATORS: IEC 80000-13:2008 gibibyte/second
+#: strbuf.c:824
+#, c-format
+msgid "%u.%2.2u GiB/s"
+msgstr "%u.%2.2u GiB/s"
 
-#: builtin/branch.c:626
-msgid "print only branches of the object"
-msgstr "nur Branches von diesem Objekt ausgeben"
+#. TRANSLATORS: IEC 80000-13:2008 mebibyte
+#: strbuf.c:832
+#, c-format
+msgid "%u.%2.2u MiB"
+msgstr "%u.%2.2u MiB"
 
-#: builtin/branch.c:628 builtin/for-each-ref.c:49 builtin/tag.c:421
-msgid "sorting and filtering are case insensitive"
-msgstr "Sortierung und Filterung sind unabhängig von Groß- und Kleinschreibung"
+#. TRANSLATORS: IEC 80000-13:2008 mebibyte/second
+#: strbuf.c:834
+#, c-format
+msgid "%u.%2.2u MiB/s"
+msgstr "%u.%2.2u MiB/s"
 
-#: builtin/branch.c:629 builtin/for-each-ref.c:38 builtin/tag.c:419
-#: builtin/verify-tag.c:39
-msgid "format to use for the output"
-msgstr "für die Ausgabe zu verwendendes Format"
+#. TRANSLATORS: IEC 80000-13:2008 kibibyte
+#: strbuf.c:841
+#, c-format
+msgid "%u.%2.2u KiB"
+msgstr "%u.%2.2u KiB"
 
-#: builtin/branch.c:652 builtin/clone.c:735
-msgid "HEAD not found below refs/heads!"
-msgstr "HEAD wurde nicht unter \"refs/heads\" gefunden!"
+#. TRANSLATORS: IEC 80000-13:2008 kibibyte/second
+#: strbuf.c:843
+#, c-format
+msgid "%u.%2.2u KiB/s"
+msgstr "%u.%2.2u KiB/s"
 
-#: builtin/branch.c:675
-msgid "--column and --verbose are incompatible"
-msgstr "Die Optionen --column und --verbose sind inkompatibel."
+#. TRANSLATORS: IEC 80000-13:2008 byte
+#: strbuf.c:849
+#, c-format
+msgid "%u byte"
+msgid_plural "%u bytes"
+msgstr[0] "%u Byte"
+msgstr[1] "%u Bytes"
 
-#: builtin/branch.c:690 builtin/branch.c:742 builtin/branch.c:751
-msgid "branch name required"
-msgstr "Branchname erforderlich"
+#. TRANSLATORS: IEC 80000-13:2008 byte/second
+#: strbuf.c:851
+#, c-format
+msgid "%u byte/s"
+msgid_plural "%u bytes/s"
+msgstr[0] "%u Byte/s"
+msgstr[1] "%u Bytes/s"
 
-#: builtin/branch.c:718
-msgid "Cannot give description to detached HEAD"
-msgstr "zu losgelöstem HEAD kann keine Beschreibung hinterlegt werden"
+#: strbuf.c:1149
+#, c-format
+msgid "could not edit '%s'"
+msgstr "Konnte '%s' nicht editieren."
 
-#: builtin/branch.c:723
-msgid "cannot edit description of more than one branch"
-msgstr "Beschreibung von mehr als einem Branch kann nicht bearbeitet werden"
+#: submodule.c:114 submodule.c:143
+msgid "Cannot change unmerged .gitmodules, resolve merge conflicts first"
+msgstr ""
+"Kann nicht zusammengeführte .gitmodules-Datei nicht ändern, lösen\n"
+"Sie zuerst die Konflikte auf"
 
-#: builtin/branch.c:730
+#: submodule.c:118 submodule.c:147
 #, c-format
-msgid "No commit on branch '%s' yet."
-msgstr "Noch kein Commit in Branch '%s'."
+msgid "Could not find section in .gitmodules where path=%s"
+msgstr "Konnte keine Sektion in .gitmodules mit Pfad \"%s\" finden"
 
-#: builtin/branch.c:733
+#: submodule.c:154
 #, c-format
-msgid "No branch named '%s'."
-msgstr "Branch '%s' nicht vorhanden."
+msgid "Could not remove .gitmodules entry for %s"
+msgstr "Konnte Eintrag '%s' nicht aus .gitmodules entfernen"
 
-#: builtin/branch.c:748
-msgid "too many branches for a copy operation"
-msgstr "zu viele Branches für eine Kopieroperation angegeben"
+#: submodule.c:165
+msgid "staging updated .gitmodules failed"
+msgstr "Konnte aktualisierte .gitmodules-Datei nicht zum Commit vormerken"
 
-#: builtin/branch.c:757
-msgid "too many arguments for a rename operation"
-msgstr "zu viele Argumente für eine Umbenennen-Operation angegeben"
+#: submodule.c:327
+#, c-format
+msgid "in unpopulated submodule '%s'"
+msgstr "In nicht ausgechecktem Submodul '%s'."
 
-#: builtin/branch.c:762
-msgid "too many arguments to set new upstream"
-msgstr "zu viele Argumente angegeben, um Upstream-Branch zu setzen"
+#: submodule.c:358
+#, c-format
+msgid "Pathspec '%s' is in submodule '%.*s'"
+msgstr "Pfadspezifikation '%s' befindet sich in Submodul '%.*s'"
 
-#: builtin/branch.c:766
+#: submodule.c:910
 #, c-format
-msgid ""
-"could not set upstream of HEAD to %s when it does not point to any branch."
-msgstr ""
-"Konnte keinen neuen Upstream-Branch von HEAD zu %s setzen, da dieser auf\n"
-"keinen Branch zeigt."
+msgid "submodule entry '%s' (%s) is a %s, not a commit"
+msgstr "Submodul-Eintrag '%s' (%s) ist ein %s, kein Commit."
+
+#: submodule.c:1147 builtin/branch.c:680 builtin/submodule--helper.c:2016
+msgid "Failed to resolve HEAD as a valid ref."
+msgstr "Konnte HEAD nicht als gültige Referenz auflösen."
 
-#: builtin/branch.c:769 builtin/branch.c:791 builtin/branch.c:807
+#: submodule.c:1481
 #, c-format
-msgid "no such branch '%s'"
-msgstr "Kein solcher Branch '%s'"
+msgid "Could not access submodule '%s'"
+msgstr "Konnte nicht auf Submodul '%s' zugreifen."
 
-#: builtin/branch.c:773
+#: submodule.c:1651
 #, c-format
-msgid "branch '%s' does not exist"
-msgstr "Branch '%s' existiert nicht"
+msgid "'%s' not recognized as a git repository"
+msgstr "'%s' nicht als Git-Repository erkannt"
 
-#: builtin/branch.c:785
-msgid "too many arguments to unset upstream"
-msgstr ""
-"zu viele Argumente angegeben, um Konfiguration zu Upstream-Branch zu "
-"entfernen"
+#: submodule.c:1789
+#, c-format
+msgid "could not start 'git status' in submodule '%s'"
+msgstr "Konnte 'git status' in Submodul '%s' nicht starten."
 
-#: builtin/branch.c:789
-msgid "could not unset upstream of HEAD when it does not point to any branch."
-msgstr ""
-"Konnte Konfiguration zu Upstream-Branch von HEAD nicht entfernen, da dieser\n"
-"auf keinen Branch zeigt."
+#: submodule.c:1802
+#, c-format
+msgid "could not run 'git status' in submodule '%s'"
+msgstr "Konnte 'git status' in Submodul '%s' nicht ausführen."
 
-#: builtin/branch.c:795
+#: submodule.c:1817
 #, c-format
-msgid "Branch '%s' has no upstream information"
-msgstr "Branch '%s' hat keinen Upstream-Branch gesetzt"
+msgid "Could not unset core.worktree setting in submodule '%s'"
+msgstr "Konnte core.worktree Einstellung in Submodul '%s' nicht aufheben."
+
+#: submodule.c:1907
+#, c-format
+msgid "submodule '%s' has dirty index"
+msgstr "Submodul '%s' hat einen geänderten Index."
+
+#: submodule.c:1959
+#, c-format
+msgid "Submodule '%s' could not be updated."
+msgstr "Submodule '%s' konnte nicht aktualisiert werden."
 
-#: builtin/branch.c:810
-msgid "-a and -r options to 'git branch' do not make sense with a branch name"
+#: submodule.c:2027
+#, c-format
+msgid "submodule git dir '%s' is inside git dir '%.*s'"
 msgstr ""
-"Die Optionen -a und -r bei 'git branch' können nicht gemeimsam mit einem "
-"Branchnamen verwendet werden."
+"Git-Verzeichnis des Submoduls '%s' ist im Git-Verzeichnis '%.*s' enthalten."
 
-#: builtin/branch.c:813
+#: submodule.c:2048
+#, c-format
 msgid ""
-"the '--set-upstream' option is no longer supported. Please use '--track' or "
-"'--set-upstream-to' instead."
+"relocate_gitdir for submodule '%s' with more than one worktree not supported"
 msgstr ""
-"Die '--set-upstream' Option wird nicht länger unterstützt.\n"
-"Bitte benutzen Sie stattdessen '--track' oder '--set-upstream-to'."
+"relocate_gitdir für Submodul '%s' mit mehr als einem Arbeitsverzeichnis\n"
+"wird nicht unterstützt"
 
-#: builtin/bundle.c:45
+#: submodule.c:2060 submodule.c:2119
 #, c-format
-msgid "%s is okay\n"
-msgstr "%s ist in Ordnung\n"
-
-#: builtin/bundle.c:58
-msgid "Need a repository to create a bundle."
-msgstr "Um ein Paket zu erstellen wird ein Repository benötigt."
+msgid "could not lookup name for submodule '%s'"
+msgstr "Konnte Name für Submodul '%s' nicht nachschlagen."
 
-#: builtin/bundle.c:62
-msgid "Need a repository to unbundle."
-msgstr "Zum Entpacken wird ein Repository benötigt."
+#: submodule.c:2064
+#, c-format
+msgid "refusing to move '%s' into an existing git dir"
+msgstr "Verschieben von '%s' in ein existierendes Git-Verzeichnis verweigert."
 
-#: builtin/cat-file.c:523
+#: submodule.c:2071
+#, c-format
 msgid ""
-"git cat-file (-t [--allow-unknown-type] | -s [--allow-unknown-type] | -e | -"
-"p | <type> | --textconv | --filters) [--path=<path>] <object>"
+"Migrating git directory of '%s%s' from\n"
+"'%s' to\n"
+"'%s'\n"
 msgstr ""
-"git cat-file (-t [--allow-unknown-type] | -s [--allow-unknown-type] | -e | -"
-"p | <Art> | --textconv | --filters) [--path=<Pfad>] <Objekt>"
+"Migriere Git-Verzeichnis von '%s%s' von\n"
+"'%s' nach\n"
+"'%s'\n"
 
-#: builtin/cat-file.c:524
-msgid ""
-"git cat-file (--batch | --batch-check) [--follow-symlinks] [--textconv | --"
-"filters]"
-msgstr ""
-"git cat-file (--batch | --batch-check) [--follow-symlinks] [--textconv | --"
-"filters]"
+#: submodule.c:2154
+#, c-format
+msgid "could not recurse into submodule '%s'"
+msgstr "Fehler bei Rekursion in Submodul-Pfad '%s'"
 
-#: builtin/cat-file.c:561
-msgid "<type> can be one of: blob, tree, commit, tag"
-msgstr "<Art> kann sein: blob, tree, commit, tag"
+#: submodule.c:2198
+msgid "could not start ls-files in .."
+msgstr "Konnte 'ls-files' nicht in .. starten"
 
-#: builtin/cat-file.c:562
-msgid "show object type"
-msgstr "Objektart anzeigen"
+#: submodule.c:2237
+#, c-format
+msgid "ls-tree returned unexpected return code %d"
+msgstr "ls-tree mit unerwartetem Rückgabewert %d beendet"
 
-#: builtin/cat-file.c:563
-msgid "show object size"
-msgstr "Objektgröße anzeigen"
+#: submodule-config.c:236
+#, c-format
+msgid "ignoring suspicious submodule name: %s"
+msgstr "Ignoriere verdächtigen Submodulnamen: %s"
 
-#: builtin/cat-file.c:565
-msgid "exit with zero when there's no error"
-msgstr "mit Rückgabewert 0 beenden, wenn kein Fehler aufgetreten ist"
+#: submodule-config.c:303
+msgid "negative values not allowed for submodule.fetchjobs"
+msgstr "Negative Werte für submodule.fetchjobs nicht erlaubt."
 
-#: builtin/cat-file.c:566
-msgid "pretty-print object's content"
-msgstr "ansprechende Anzeige des Objektinhaltes"
+#: submodule-config.c:401
+#, c-format
+msgid "ignoring '%s' which may be interpreted as a command-line option: %s"
+msgstr ""
+"Ignoriere '%s', was als eine Befehlszeilenoption '%s' interpretiert werden "
+"würde."
 
-#: builtin/cat-file.c:568
-msgid "for blob objects, run textconv on object's content"
-msgstr "eine Textkonvertierung auf den Inhalt von Blob-Objekten ausführen"
+#: submodule-config.c:498
+#, c-format
+msgid "invalid value for %s"
+msgstr "Ungültiger Wert für %s"
 
-#: builtin/cat-file.c:570
-msgid "for blob objects, run filters on object's content"
-msgstr "für Blob-Objekte, Filter auf Objekt-Inhalte ausführen"
+#: submodule-config.c:769
+#, c-format
+msgid "Could not update .gitmodules entry %s"
+msgstr "Konnte Eintrag '%s' in .gitmodules nicht aktualisieren"
 
-#: builtin/cat-file.c:571 git-submodule.sh:878
-msgid "blob"
-msgstr "Blob"
+#: trailer.c:238
+#, c-format
+msgid "running trailer command '%s' failed"
+msgstr "Ausführen des Anhang-Befehls '%s' fehlgeschlagen"
 
-#: builtin/cat-file.c:572
-msgid "use a specific path for --textconv/--filters"
-msgstr "einen bestimmten Pfad für --textconv/--filters verwenden"
+#: trailer.c:485 trailer.c:490 trailer.c:495 trailer.c:549 trailer.c:553
+#: trailer.c:557
+#, c-format
+msgid "unknown value '%s' for key '%s'"
+msgstr "unbekannter Wert '%s' für Schlüssel %s"
 
-#: builtin/cat-file.c:574
-msgid "allow -s and -t to work with broken/corrupt objects"
-msgstr "-s und -t mit beschädigten Objekten erlauben"
+#: trailer.c:539 trailer.c:544 builtin/remote.c:295
+#, c-format
+msgid "more than one %s"
+msgstr "mehr als ein %s"
 
-#: builtin/cat-file.c:575
-msgid "buffer --batch output"
-msgstr "Ausgabe von --batch puffern"
+#: trailer.c:730
+#, c-format
+msgid "empty trailer token in trailer '%.*s'"
+msgstr "leerer Anhang-Token in Anhang '%.*s'"
 
-#: builtin/cat-file.c:577
-msgid "show info and content of objects fed from the standard input"
-msgstr ""
-"Anzeige von Informationen und Inhalt von Objekten, gelesen von der Standard-"
-"Eingabe"
+#: trailer.c:750
+#, c-format
+msgid "could not read input file '%s'"
+msgstr "Konnte Eingabe-Datei '%s' nicht lesen"
 
-#: builtin/cat-file.c:580
-msgid "show info about objects fed from the standard input"
-msgstr ""
-"Anzeige von Informationen über Objekte, gelesen von der Standard-Eingabe"
+#: trailer.c:753
+msgid "could not read from stdin"
+msgstr "konnte nicht von der Standard-Eingabe lesen"
 
-#: builtin/cat-file.c:583
-msgid "follow in-tree symlinks (used with --batch or --batch-check)"
-msgstr ""
-"symbolischen Verknüpfungen innerhalb des Repositories folgen (verwendet mit "
-"--batch oder --batch-check)"
+#: trailer.c:1011 wrapper.c:665
+#, c-format
+msgid "could not stat %s"
+msgstr "Konnte '%s' nicht lesen"
 
-#: builtin/cat-file.c:585
-msgid "show all objects with --batch or --batch-check"
-msgstr "alle Objekte mit --batch oder --batch-check anzeigen"
+#: trailer.c:1013
+#, c-format
+msgid "file %s is not a regular file"
+msgstr "Datei '%s' ist keine reguläre Datei"
 
-#: builtin/check-attr.c:12
-msgid "git check-attr [-a | --all | <attr>...] [--] <pathname>..."
-msgstr "git check-attr [-a | --all | <Attribut>...] [--] <Pfadname>..."
+#: trailer.c:1015
+#, c-format
+msgid "file %s is not writable by user"
+msgstr "Datei %s ist vom Benutzer nicht beschreibbar."
 
-#: builtin/check-attr.c:13
-msgid "git check-attr --stdin [-z] [-a | --all | <attr>...]"
-msgstr "git check-attr --stdin [-z] [-a | --all | <Attribut>...]"
+#: trailer.c:1027
+msgid "could not open temporary file"
+msgstr "konnte temporäre Datei '%s' nicht öffnen"
 
-#: builtin/check-attr.c:20
-msgid "report all attributes set on file"
-msgstr "alle Attribute einer Datei ausgeben"
+#: trailer.c:1067
+#, c-format
+msgid "could not rename temporary file to %s"
+msgstr "konnte temporäre Datei nicht zu %s umbenennen"
 
-#: builtin/check-attr.c:21
-msgid "use .gitattributes only from the index"
-msgstr "nur .gitattributes vom Index verwenden"
+#: transport.c:116
+#, c-format
+msgid "Would set upstream of '%s' to '%s' of '%s'\n"
+msgstr "Würde Upstream-Branch von '%s' zu '%s' von '%s' setzen\n"
 
-#: builtin/check-attr.c:22 builtin/check-ignore.c:24 builtin/hash-object.c:100
-msgid "read file names from stdin"
-msgstr "Dateinamen von der Standard-Eingabe lesen"
+#: transport.c:145
+#, c-format
+msgid "could not read bundle '%s'"
+msgstr "Konnte Paket '%s' nicht lesen."
 
-#: builtin/check-attr.c:24 builtin/check-ignore.c:26
-msgid "terminate input and output records by a NUL character"
-msgstr "Einträge von Ein- und Ausgabe mit NUL-Zeichen abschließen"
+#: transport.c:214
+#, c-format
+msgid "transport: invalid depth option '%s'"
+msgstr "transport: ungültige --depth Option '%s'"
 
-#: builtin/check-ignore.c:20 builtin/checkout.c:1106 builtin/gc.c:358
-msgid "suppress progress reporting"
-msgstr "Fortschrittsanzeige unterdrücken"
+#: transport.c:266
+msgid "see protocol.version in 'git help config' for more details"
+msgstr "Siehe protocol.version in 'git help config' für weitere Informationen"
 
-#: builtin/check-ignore.c:28
-msgid "show non-matching input paths"
-msgstr "Eingabe-Pfade ohne Übereinstimmungen anzeigen"
+#: transport.c:267
+msgid "server options require protocol version 2 or later"
+msgstr "Server-Optionen benötigen Protokoll-Version 2 oder höher"
 
-#: builtin/check-ignore.c:30
-msgid "ignore index when checking"
-msgstr "Index bei der Prüfung ignorieren"
+#: transport.c:632
+msgid "could not parse transport.color.* config"
+msgstr "Konnte transport.color.* Konfiguration nicht parsen."
 
-#: builtin/check-ignore.c:159
-msgid "cannot specify pathnames with --stdin"
-msgstr "Angabe von Pfadnamen kann nicht gemeinsam mit --stdin verwendet werden"
+#: transport.c:705
+msgid "support for protocol v2 not implemented yet"
+msgstr "Unterstützung für Protokoll v2 noch nicht implementiert."
 
-#: builtin/check-ignore.c:162
-msgid "-z only makes sense with --stdin"
-msgstr "Die Option -z kann nur mit --stdin verwendet werden."
+#: transport.c:831
+#, c-format
+msgid "unknown value for config '%s': %s"
+msgstr "Unbekannter Wert für Konfiguration '%s': %s"
 
-#: builtin/check-ignore.c:164
-msgid "no path specified"
-msgstr "kein Pfad angegeben"
+#: transport.c:897
+#, c-format
+msgid "transport '%s' not allowed"
+msgstr "Übertragungsart '%s' nicht erlaubt."
 
-#: builtin/check-ignore.c:168
-msgid "--quiet is only valid with a single pathname"
-msgstr "Die Option --quiet ist nur mit einem einzelnen Pfadnamen gültig."
+#: transport.c:949
+msgid "git-over-rsync is no longer supported"
+msgstr "git-over-rsync wird nicht länger unterstützt."
 
-#: builtin/check-ignore.c:170
-msgid "cannot have both --quiet and --verbose"
+#: transport.c:1044
+#, c-format
+msgid ""
+"The following submodule paths contain changes that can\n"
+"not be found on any remote:\n"
 msgstr ""
-"Die Optionen --quiet und --verbose können nicht gemeinsam verwendet werden."
-
-#: builtin/check-ignore.c:173
-msgid "--non-matching is only valid with --verbose"
-msgstr "--non-matching ist nur mit --verbose zulässig"
-
-#: builtin/check-mailmap.c:9
-msgid "git check-mailmap [<options>] <contact>..."
-msgstr "git check-mailmap [<Optionen>] <Kontakt>..."
-
-#: builtin/check-mailmap.c:14
-msgid "also read contacts from stdin"
-msgstr "ebenfalls Kontakte von der Standard-Eingabe lesen"
+"Die folgenden Submodul-Pfade enthalten Änderungen, die in keinem\n"
+"Remote-Repository gefunden wurden:\n"
 
-#: builtin/check-mailmap.c:25
+#: transport.c:1048
 #, c-format
-msgid "unable to parse contact: %s"
-msgstr "Konnte Kontakt '%s' nicht parsen."
+msgid ""
+"\n"
+"Please try\n"
+"\n"
+"\tgit push --recurse-submodules=on-demand\n"
+"\n"
+"or cd to the path and use\n"
+"\n"
+"\tgit push\n"
+"\n"
+"to push them to a remote.\n"
+"\n"
+msgstr ""
+"\n"
+"Bitte versuchen Sie\n"
+"\n"
+"\tgit push --recurse-submodules=on-demand\n"
+"\n"
+"oder wechseln Sie in das Verzeichnis und benutzen Sie\n"
+"\n"
+"\tgit push\n"
+"\n"
+"zum Versenden zu einem Remote-Repository.\n"
+"\n"
 
-#: builtin/check-mailmap.c:48
-msgid "no contacts specified"
-msgstr "keine Kontakte angegeben"
+#: transport.c:1056
+msgid "Aborting."
+msgstr "Abbruch."
 
-#: builtin/checkout-index.c:128
-msgid "git checkout-index [<options>] [--] [<file>...]"
-msgstr "git checkout-index [<Optionen>] [--] [<Datei>...]"
+#: transport.c:1201
+msgid "failed to push all needed submodules"
+msgstr "Fehler beim Versand aller erforderlichen Submodule."
 
-#: builtin/checkout-index.c:143
-msgid "stage should be between 1 and 3 or all"
-msgstr "--stage sollte zwischen 1 und 3 oder 'all' sein"
+#: transport.c:1345 transport-helper.c:656
+msgid "operation not supported by protocol"
+msgstr "Die Operation wird von dem Protokoll nicht unterstützt."
 
-#: builtin/checkout-index.c:159
-msgid "check out all files in the index"
-msgstr "alle Dateien im Index auschecken"
+#: transport-helper.c:61 transport-helper.c:90
+msgid "full write to remote helper failed"
+msgstr "Vollständiges Schreiben zu Remote-Helper fehlgeschlagen."
 
-#: builtin/checkout-index.c:160
-msgid "force overwrite of existing files"
-msgstr "das Überschreiben bereits existierender Dateien erzwingen"
+#: transport-helper.c:144
+#, c-format
+msgid "unable to find remote helper for '%s'"
+msgstr "Konnte Remote-Helper für '%s' nicht finden."
 
-#: builtin/checkout-index.c:162
-msgid "no warning for existing files and files not in index"
+#: transport-helper.c:160 transport-helper.c:570
+msgid "can't dup helper output fd"
 msgstr ""
-"keine Warnung für existierende Dateien, und Dateien, die sich nicht im Index "
-"befinden"
-
-#: builtin/checkout-index.c:164
-msgid "don't checkout new files"
-msgstr "keine neuen Dateien auschecken"
-
-#: builtin/checkout-index.c:166
-msgid "update stat information in the index file"
-msgstr "Dateiinformationen in der Index-Datei aktualisieren"
-
-#: builtin/checkout-index.c:170
-msgid "read list of paths from the standard input"
-msgstr "eine Liste von Pfaden von der Standard-Eingabe lesen"
+"Konnte dup() auf Dateideskriptor für Ausgaben des Remote-Helpers nicht "
+"ausführen."
 
-#: builtin/checkout-index.c:172
-msgid "write the content to temporary files"
-msgstr "den Inhalt in temporäre Dateien schreiben"
+#: transport-helper.c:211
+#, c-format
+msgid ""
+"unknown mandatory capability %s; this remote helper probably needs newer "
+"version of Git"
+msgstr ""
+"Unbekannte erforderliche Fähigkeit %s; dieser Remote-Helper benötigt\n"
+"wahrscheinlich eine neuere Version von Git."
 
-#: builtin/checkout-index.c:173 builtin/column.c:31
-#: builtin/submodule--helper.c:1203 builtin/submodule--helper.c:1206
-#: builtin/submodule--helper.c:1212 builtin/submodule--helper.c:1574
-#: builtin/worktree.c:570
-msgid "string"
-msgstr "Zeichenkette"
+#: transport-helper.c:217
+msgid "this remote helper should implement refspec capability"
+msgstr "Dieser Remote-Helper sollte die \"refspec\"-Fähigkeit implementieren."
 
-#: builtin/checkout-index.c:174
-msgid "when creating files, prepend <string>"
-msgstr ""
-"wenn Dateien erzeugt werden, stelle <Zeichenkette> dem Dateinamen voran"
+#: transport-helper.c:284 transport-helper.c:424
+#, c-format
+msgid "%s unexpectedly said: '%s'"
+msgstr "unerwartete Ausgabe von %s: '%s'"
 
-#: builtin/checkout-index.c:176
-msgid "copy out the files from named stage"
-msgstr "Dateien von dem benannten Stand kopieren"
+#: transport-helper.c:413
+#, c-format
+msgid "%s also locked %s"
+msgstr "%s sperrte auch %s"
 
-#: builtin/checkout.c:27
-msgid "git checkout [<options>] <branch>"
-msgstr "git checkout [<Optionen>] <Branch>"
+#: transport-helper.c:492
+msgid "couldn't run fast-import"
+msgstr "Konnte \"fast-import\" nicht ausführen."
 
-#: builtin/checkout.c:28
-msgid "git checkout [<options>] [<branch>] -- <file>..."
-msgstr "git checkout [<Optionen>] [<Branch>] -- <Datei>..."
+#: transport-helper.c:515
+msgid "error while running fast-import"
+msgstr "Fehler beim Ausführen von 'fast-import'."
 
-#: builtin/checkout.c:136 builtin/checkout.c:169
+#: transport-helper.c:544 transport-helper.c:1133
 #, c-format
-msgid "path '%s' does not have our version"
-msgstr "Pfad '%s' hat nicht unsere Version."
+msgid "could not read ref %s"
+msgstr "Konnte Referenz %s nicht lesen."
 
-#: builtin/checkout.c:138 builtin/checkout.c:171
+#: transport-helper.c:589
 #, c-format
-msgid "path '%s' does not have their version"
-msgstr "Pfad '%s' hat nicht deren Version."
+msgid "unknown response to connect: %s"
+msgstr "Unbekannte Antwort auf 'connect': %s"
+
+#: transport-helper.c:611
+msgid "setting remote service path not supported by protocol"
+msgstr ""
+"Setzen des Remote-Service Pfads wird von dem Protokoll nicht unterstützt."
+
+#: transport-helper.c:613
+msgid "invalid remote service path"
+msgstr "Ungültiger Remote-Service Pfad."
 
-#: builtin/checkout.c:154
+#: transport-helper.c:659
 #, c-format
-msgid "path '%s' does not have all necessary versions"
-msgstr "Pfad '%s' hat nicht alle notwendigen Versionen."
+msgid "can't connect to subservice %s"
+msgstr "Kann keine Verbindung zu Subservice %s herstellen."
 
-#: builtin/checkout.c:198
+#: transport-helper.c:735
 #, c-format
-msgid "path '%s' does not have necessary versions"
-msgstr "Pfad '%s' hat nicht die notwendigen Versionen."
+msgid "expected ok/error, helper said '%s'"
+msgstr "Erwartete ok/error, Remote-Helper gab '%s' aus."
 
-#: builtin/checkout.c:215
+#: transport-helper.c:788
 #, c-format
-msgid "path '%s': cannot merge"
-msgstr "Pfad '%s': kann nicht zusammenführen"
+msgid "helper reported unexpected status of %s"
+msgstr "Remote-Helper meldete unerwarteten Status von %s."
 
-#: builtin/checkout.c:231
+#: transport-helper.c:849
 #, c-format
-msgid "Unable to add merge result for '%s'"
-msgstr "Konnte Merge-Ergebnis von '%s' nicht hinzufügen."
+msgid "helper %s does not support dry-run"
+msgstr "Remote-Helper %s unterstützt kein Trockenlauf."
 
-#: builtin/checkout.c:253 builtin/checkout.c:256 builtin/checkout.c:259
-#: builtin/checkout.c:262
+#: transport-helper.c:852
 #, c-format
-msgid "'%s' cannot be used with updating paths"
-msgstr "'%s' kann nicht mit der Aktualisierung von Pfaden verwendet werden"
+msgid "helper %s does not support --signed"
+msgstr "Remote-Helper %s unterstützt kein --signed."
 
-#: builtin/checkout.c:265 builtin/checkout.c:268
+#: transport-helper.c:855
 #, c-format
-msgid "'%s' cannot be used with %s"
-msgstr "'%s' kann nicht mit '%s' verwendet werden"
+msgid "helper %s does not support --signed=if-asked"
+msgstr "Remote-Helper %s unterstützt kein --signed=if-asked."
 
-#: builtin/checkout.c:271
+#: transport-helper.c:860
 #, c-format
-msgid "Cannot update paths and switch to branch '%s' at the same time."
-msgstr ""
-"Kann nicht gleichzeitig Pfade aktualisieren und zu Branch '%s' wechseln"
+msgid "helper %s does not support --atomic"
+msgstr "Remote-Helper %s unterstützt kein --atomic."
 
-#: builtin/checkout.c:340 builtin/checkout.c:347
+#: transport-helper.c:866
 #, c-format
-msgid "path '%s' is unmerged"
-msgstr "Pfad '%s' ist nicht zusammengeführt."
+msgid "helper %s does not support 'push-option'"
+msgstr "Remote-Helper %s unterstützt nicht 'push-option'."
 
-#: builtin/checkout.c:505
-msgid "you need to resolve your current index first"
-msgstr "Sie müssen zuerst die Konflikte in Ihrem aktuellen Index auflösen."
+#: transport-helper.c:964
+msgid "remote-helper doesn't support push; refspec needed"
+msgstr "Remote-Helper unterstützt kein Push; Refspec benötigt"
 
-#: builtin/checkout.c:636
+#: transport-helper.c:969
 #, c-format
-msgid "Can not do reflog for '%s': %s\n"
-msgstr "Kann \"reflog\" für '%s' nicht durchführen: %s\n"
+msgid "helper %s does not support 'force'"
+msgstr "Remote-Helper %s unterstützt kein 'force'."
 
-#: builtin/checkout.c:677
-msgid "HEAD is now at"
-msgstr "HEAD ist jetzt bei"
+#: transport-helper.c:1016
+msgid "couldn't run fast-export"
+msgstr "Konnte \"fast-export\" nicht ausführen."
 
-#: builtin/checkout.c:681 builtin/clone.c:689
-msgid "unable to update HEAD"
-msgstr "Konnte HEAD nicht aktualisieren."
+#: transport-helper.c:1021
+msgid "error while running fast-export"
+msgstr "Fehler beim Ausführen von \"fast-export\"."
 
-#: builtin/checkout.c:685
+#: transport-helper.c:1046
 #, c-format
-msgid "Reset branch '%s'\n"
-msgstr "Setze Branch '%s' neu\n"
+msgid ""
+"No refs in common and none specified; doing nothing.\n"
+"Perhaps you should specify a branch such as 'master'.\n"
+msgstr ""
+"Keine gemeinsamen Referenzen und nichts spezifiziert; keine Ausführung.\n"
+"Vielleicht sollten Sie einen Branch wie 'master' angeben.\n"
 
-#: builtin/checkout.c:688
+#: transport-helper.c:1119
 #, c-format
-msgid "Already on '%s'\n"
-msgstr "Bereits auf '%s'\n"
+msgid "malformed response in ref list: %s"
+msgstr "Ungültige Antwort in Referenzliste: %s"
 
-#: builtin/checkout.c:692
+#: transport-helper.c:1271
 #, c-format
-msgid "Switched to and reset branch '%s'\n"
-msgstr "Zu umgesetztem Branch '%s' gewechselt\n"
+msgid "read(%s) failed"
+msgstr "Lesen von %s fehlgeschlagen."
 
-#: builtin/checkout.c:694 builtin/checkout.c:1039
+#: transport-helper.c:1298
 #, c-format
-msgid "Switched to a new branch '%s'\n"
-msgstr "Zu neuem Branch '%s' gewechselt\n"
+msgid "write(%s) failed"
+msgstr "Schreiben von %s fehlgeschlagen."
 
-#: builtin/checkout.c:696
+#: transport-helper.c:1347
 #, c-format
-msgid "Switched to branch '%s'\n"
-msgstr "Zu Branch '%s' gewechselt\n"
+msgid "%s thread failed"
+msgstr "Thread %s fehlgeschlagen."
 
-#: builtin/checkout.c:747
+#: transport-helper.c:1351
 #, c-format
-msgid " ... and %d more.\n"
-msgstr " ... und %d weitere.\n"
+msgid "%s thread failed to join: %s"
+msgstr "Fehler beim Beitreten zu Thread %s: %s"
 
-#: builtin/checkout.c:753
+#: transport-helper.c:1370 transport-helper.c:1374
 #, c-format
-msgid ""
-"Warning: you are leaving %d commit behind, not connected to\n"
-"any of your branches:\n"
-"\n"
-"%s\n"
-msgid_plural ""
-"Warning: you are leaving %d commits behind, not connected to\n"
-"any of your branches:\n"
-"\n"
-"%s\n"
-msgstr[0] ""
-"Warnung: Sie lassen %d Commit zurück. Folgender Commit ist in\n"
-"keinem Ihrer Branches enthalten:\n"
-"\n"
-"%s\n"
-msgstr[1] ""
-"Warnung: Sie lassen %d Commits zurück. Folgende Commits sind in\n"
-"keinem Ihrer Branches enthalten:\n"
-"\n"
-"%s\n"
+msgid "can't start thread for copying data: %s"
+msgstr "Kann Thread zum Kopieren von Daten nicht starten: %s"
 
-#: builtin/checkout.c:772
+#: transport-helper.c:1411
 #, c-format
-msgid ""
-"If you want to keep it by creating a new branch, this may be a good time\n"
-"to do so with:\n"
-"\n"
-" git branch <new-branch-name> %s\n"
-"\n"
-msgid_plural ""
-"If you want to keep them by creating a new branch, this may be a good time\n"
-"to do so with:\n"
-"\n"
-" git branch <new-branch-name> %s\n"
-"\n"
-msgstr[0] ""
-"Wenn Sie diese durch einen neuen Branch behalten möchten, dann könnte jetzt\n"
-"ein guter Zeitpunkt sein, dies zu tun mit:\n"
-"\n"
-" git branch <neuer-Branchname> %s\n"
-"\n"
-msgstr[1] ""
-"Wenn Sie diese durch einen neuen Branch behalten möchten, dann könnte jetzt\n"
-"ein guter Zeitpunkt sein, dies zu tun mit:\n"
-"\n"
-" git branch <neuer-Branchname> %s\n"
-"\n"
+msgid "%s process failed to wait"
+msgstr "Fehler beim Warten von Prozess %s."
 
-#: builtin/checkout.c:804
-msgid "internal error in revision walk"
-msgstr "interner Fehler im Revisionsgang"
+#: transport-helper.c:1415
+#, c-format
+msgid "%s process failed"
+msgstr "Prozess %s fehlgeschlagen"
 
-#: builtin/checkout.c:808
-msgid "Previous HEAD position was"
-msgstr "Vorherige Position von HEAD war"
+#: transport-helper.c:1433 transport-helper.c:1442
+msgid "can't start thread for copying data"
+msgstr "Kann Thread zum Kopieren von Daten nicht starten."
 
-#: builtin/checkout.c:836 builtin/checkout.c:1034
-msgid "You are on a branch yet to be born"
-msgstr "Sie sind auf einem Branch, der noch nicht geboren ist"
+#: tree-walk.c:33
+msgid "too-short tree object"
+msgstr "zu kurzes Tree-Objekt"
 
-#: builtin/checkout.c:940
-#, c-format
-msgid "only one reference expected, %d given."
-msgstr "nur eine Referenz erwartet, %d gegeben."
+#: tree-walk.c:39
+msgid "malformed mode in tree entry"
+msgstr "fehlerhafter Modus in Tree-Eintrag"
 
-#: builtin/checkout.c:980 builtin/worktree.c:249
-#, c-format
-msgid "invalid reference: %s"
-msgstr "Ungültige Referenz: %s"
+#: tree-walk.c:43
+msgid "empty filename in tree entry"
+msgstr "leerer Dateiname in Tree-Eintrag"
 
-#: builtin/checkout.c:1009
+#: tree-walk.c:48
 #, c-format
-msgid "reference is not a tree: %s"
-msgstr "Referenz ist kein \"Tree\"-Objekt: %s"
+msgid "filename in tree entry contains backslash: '%s'"
+msgstr "Dateiname im Tree-Eintrag enthält Backslash: '%s'"
 
-#: builtin/checkout.c:1048
-msgid "paths cannot be used with switching branches"
-msgstr "Pfade können nicht beim Wechseln von Branches verwendet werden"
-
-#: builtin/checkout.c:1051 builtin/checkout.c:1055
-#, c-format
-msgid "'%s' cannot be used with switching branches"
-msgstr "'%s' kann nicht beim Wechseln von Branches verwendet werden"
+#: tree-walk.c:124
+msgid "too-short tree file"
+msgstr "zu kurze Tree-Datei"
 
-#: builtin/checkout.c:1059 builtin/checkout.c:1062 builtin/checkout.c:1067
-#: builtin/checkout.c:1070
+#: unpack-trees.c:110
 #, c-format
-msgid "'%s' cannot be used with '%s'"
-msgstr "'%s' kann nicht mit '%s' verwendet werden"
+msgid ""
+"Your local changes to the following files would be overwritten by checkout:\n"
+"%%sPlease commit your changes or stash them before you switch branches."
+msgstr ""
+"Ihre lokalen Änderungen in den folgenden Dateien würden beim Auschecken\n"
+"überschrieben werden:\n"
+"%%sBitte committen oder stashen Sie Ihre Änderungen, bevor Sie Branches\n"
+"wechseln."
 
-#: builtin/checkout.c:1075
+#: unpack-trees.c:112
 #, c-format
-msgid "Cannot switch branch to a non-commit '%s'"
-msgstr "Kann Branch nicht zu Nicht-Commit '%s' wechseln"
-
-#: builtin/checkout.c:1107 builtin/checkout.c:1109 builtin/clone.c:116
-#: builtin/remote.c:166 builtin/remote.c:168 builtin/worktree.c:387
-#: builtin/worktree.c:389
-msgid "branch"
-msgstr "Branch"
-
-#: builtin/checkout.c:1108
-msgid "create and checkout a new branch"
-msgstr "einen neuen Branch erzeugen und auschecken"
-
-#: builtin/checkout.c:1110
-msgid "create/reset and checkout a branch"
-msgstr "einen Branch erstellen/umsetzen und auschecken"
-
-#: builtin/checkout.c:1111
-msgid "create reflog for new branch"
-msgstr "das Reflog für den neuen Branch erzeugen"
-
-#: builtin/checkout.c:1112 builtin/worktree.c:391
-msgid "detach HEAD at named commit"
-msgstr "HEAD bei benanntem Commit loslösen"
-
-#: builtin/checkout.c:1113
-msgid "set upstream info for new branch"
-msgstr "Informationen zum Upstream-Branch für den neuen Branch setzen"
-
-#: builtin/checkout.c:1115
-msgid "new-branch"
-msgstr "neuer Branch"
-
-#: builtin/checkout.c:1115
-msgid "new unparented branch"
-msgstr "neuer Branch ohne Eltern-Commit"
-
-#: builtin/checkout.c:1116
-msgid "checkout our version for unmerged files"
-msgstr "unsere Variante für nicht zusammengeführte Dateien auschecken"
-
-#: builtin/checkout.c:1118
-msgid "checkout their version for unmerged files"
-msgstr "ihre Variante für nicht zusammengeführte Dateien auschecken"
-
-#: builtin/checkout.c:1120
-msgid "force checkout (throw away local modifications)"
-msgstr "Auschecken erzwingen (verwirft lokale Änderungen)"
-
-#: builtin/checkout.c:1122
-msgid "perform a 3-way merge with the new branch"
-msgstr "einen 3-Wege-Merge mit dem neuen Branch ausführen"
-
-#: builtin/checkout.c:1124 builtin/merge.c:239
-msgid "update ignored files (default)"
-msgstr "ignorierte Dateien aktualisieren (Standard)"
-
-#: builtin/checkout.c:1126 builtin/log.c:1499 parse-options.h:263
-msgid "style"
-msgstr "Stil"
-
-#: builtin/checkout.c:1127
-msgid "conflict style (merge or diff3)"
-msgstr "Konfliktstil (merge oder diff3)"
-
-#: builtin/checkout.c:1130
-msgid "do not limit pathspecs to sparse entries only"
-msgstr "keine Einschränkung bei Pfadspezifikationen zum partiellen Auschecken"
-
-#: builtin/checkout.c:1132
-msgid "second guess 'git checkout <no-such-branch>'"
-msgstr "second guess 'git checkout <no-such-branch>'"
-
-#: builtin/checkout.c:1134
-msgid "do not check if another worktree is holding the given ref"
+msgid ""
+"Your local changes to the following files would be overwritten by checkout:\n"
+"%%s"
 msgstr ""
-"Prüfung, ob die Referenz bereits in einem anderen Arbeitsverzeichnis "
-"ausgecheckt wurde, deaktivieren"
-
-#: builtin/checkout.c:1138 builtin/clone.c:83 builtin/fetch.c:150
-#: builtin/merge.c:236 builtin/pull.c:123 builtin/push.c:556
-#: builtin/send-pack.c:173
-msgid "force progress reporting"
-msgstr "Fortschrittsanzeige erzwingen"
-
-#: builtin/checkout.c:1168
-msgid "-b, -B and --orphan are mutually exclusive"
-msgstr "Die Optionen -b, -B und --orphan schließen sich gegenseitig aus."
-
-#: builtin/checkout.c:1185
-msgid "--track needs a branch name"
-msgstr "Bei der Option --track muss ein Branchname angegeben werden."
-
-#: builtin/checkout.c:1190
-msgid "Missing branch name; try -b"
-msgstr "Vermisse Branchnamen; versuchen Sie -b"
-
-#: builtin/checkout.c:1226
-msgid "invalid path specification"
-msgstr "ungültige Pfadspezifikation"
+"Ihre lokalen Änderungen in den folgenden Dateien würden beim Auschecken\n"
+"überschrieben werden:\n"
+"%%s"
 
-#: builtin/checkout.c:1233
+#: unpack-trees.c:115
 #, c-format
-msgid "'%s' is not a commit and a branch '%s' cannot be created from it"
+msgid ""
+"Your local changes to the following files would be overwritten by merge:\n"
+"%%sPlease commit your changes or stash them before you merge."
 msgstr ""
-"'%s' ist kein Commit und es kann kein Branch '%s' aus diesem erstellt werden."
+"Ihre lokalen Änderungen in den folgenden Dateien würden durch den Merge\n"
+"überschrieben werden:\n"
+"%%sBitte committen oder stashen Sie Ihre Änderungen, bevor Sie mergen."
 
-#: builtin/checkout.c:1237
+#: unpack-trees.c:117
 #, c-format
-msgid "git checkout: --detach does not take a path argument '%s'"
-msgstr "git checkout: --detach nimmt kein Pfad-Argument '%s'"
-
-#: builtin/checkout.c:1241
 msgid ""
-"git checkout: --ours/--theirs, --force and --merge are incompatible when\n"
-"checking out of the index."
+"Your local changes to the following files would be overwritten by merge:\n"
+"%%s"
 msgstr ""
-"git checkout: --ours/--theirs, --force und --merge sind inkompatibel wenn\n"
-"Sie aus dem Index auschecken."
+"Ihre lokalen Änderungen in den folgenden Dateien würden durch den Merge\n"
+"überschrieben werden:\n"
+"%%s"
 
-#: builtin/clean.c:26
+#: unpack-trees.c:120
+#, c-format
 msgid ""
-"git clean [-d] [-f] [-i] [-n] [-q] [-e <pattern>] [-x | -X] [--] <paths>..."
+"Your local changes to the following files would be overwritten by %s:\n"
+"%%sPlease commit your changes or stash them before you %s."
 msgstr ""
-"git clean [-d] [-f] [-i] [-n] [-q] [-e <Muster>] [-x | -X] [--] <Pfade>..."
+"Ihre lokalen Änderungen in den folgenden Dateien würden durch %s\n"
+"überschrieben werden:\n"
+"%%sBitte committen oder stashen Sie Ihre Änderungen, bevor Sie %s ausführen."
 
-#: builtin/clean.c:30
+#: unpack-trees.c:122
 #, c-format
-msgid "Removing %s\n"
-msgstr "Lösche %s\n"
+msgid ""
+"Your local changes to the following files would be overwritten by %s:\n"
+"%%s"
+msgstr ""
+"Ihre lokalen Änderungen würden durch %s überschrieben werden.\n"
+"%%s"
 
-#: builtin/clean.c:31
+#: unpack-trees.c:127
 #, c-format
-msgid "Would remove %s\n"
-msgstr "Würde %s löschen\n"
+msgid ""
+"Updating the following directories would lose untracked files in them:\n"
+"%s"
+msgstr ""
+"Durch die Aktualisierung der folgenden Verzeichnisse würden unversionierte\n"
+"Dateien in diesen Verzeichnissen verloren gehen:\n"
+"%s"
 
-#: builtin/clean.c:32
+#: unpack-trees.c:131
 #, c-format
-msgid "Skipping repository %s\n"
-msgstr "Überspringe Repository %s\n"
+msgid ""
+"The following untracked working tree files would be removed by checkout:\n"
+"%%sPlease move or remove them before you switch branches."
+msgstr ""
+"Die folgenden unversionierten Dateien im Arbeitsverzeichnis würden durch\n"
+"den Checkout entfernt werden:\n"
+"%%sBitte verschieben oder entfernen Sie diese, bevor Sie Branches wechseln."
 
-#: builtin/clean.c:33
+#: unpack-trees.c:133
 #, c-format
-msgid "Would skip repository %s\n"
-msgstr "Würde Repository %s überspringen\n"
+msgid ""
+"The following untracked working tree files would be removed by checkout:\n"
+"%%s"
+msgstr ""
+"Die folgenden unversionierten Dateien im Arbeitsverzeichnis würden durch "
+"den\n"
+"Checkout entfernt werden:\n"
+"%%s"
 
-#: builtin/clean.c:34
+#: unpack-trees.c:136
 #, c-format
-msgid "failed to remove %s"
-msgstr "Fehler beim Löschen von %s"
+msgid ""
+"The following untracked working tree files would be removed by merge:\n"
+"%%sPlease move or remove them before you merge."
+msgstr ""
+"Die folgenden unversionierten Dateien im Arbeitsverzeichnis würden durch\n"
+"den Merge entfernt werden:\n"
+"%%sBitte verschieben oder entfernen Sie diese, bevor sie mergen."
 
-#: builtin/clean.c:302 git-add--interactive.perl:572
+#: unpack-trees.c:138
 #, c-format
 msgid ""
-"Prompt help:\n"
-"1          - select a numbered item\n"
-"foo        - select item based on unique prefix\n"
-"           - (empty) select nothing\n"
+"The following untracked working tree files would be removed by merge:\n"
+"%%s"
 msgstr ""
-"Eingabehilfe:\n"
-"1          - nummeriertes Element auswählen\n"
-"foo        - Element anhand eines eindeutigen Präfix auswählen\n"
-"           - (leer) nichts auswählen\n"
+"Die folgenden unversionierten Dateien im Arbeitsverzeichnis würden durch "
+"den\n"
+"Merge entfernt werden:\n"
+"%%s"
 
-#: builtin/clean.c:306 git-add--interactive.perl:581
+#: unpack-trees.c:141
 #, c-format
 msgid ""
-"Prompt help:\n"
-"1          - select a single item\n"
-"3-5        - select a range of items\n"
-"2-3,6-9    - select multiple ranges\n"
+"The following untracked working tree files would be removed by %s:\n"
+"%%sPlease move or remove them before you %s."
+msgstr ""
+"Die folgenden unversionierten Dateien im Arbeitsverzeichnis würden durch\n"
+"den %s entfernt werden:\n"
+"%%sBitte verschieben oder entfernen Sie diese, bevor sie %s ausführen."
+
+#: unpack-trees.c:143
+#, c-format
+msgid ""
+"The following untracked working tree files would be removed by %s:\n"
+"%%s"
+msgstr ""
+"Die folgenden unversionierten Dateien im Arbeitsverzeichnis würden durch\n"
+"den %s entfernt werden:\n"
+"%%s"
+
+#: unpack-trees.c:149
+#, c-format
+msgid ""
+"The following untracked working tree files would be overwritten by "
+"checkout:\n"
+"%%sPlease move or remove them before you switch branches."
+msgstr ""
+"Die folgenden unversionierten Dateien im Arbeitsverzeichnis würden durch\n"
+"den Checkout überschrieben werden:\n"
+"%%sBitte verschieben oder entfernen Sie diese, bevor Sie Branches wechseln."
+
+#: unpack-trees.c:151
+#, c-format
+msgid ""
+"The following untracked working tree files would be overwritten by "
+"checkout:\n"
+"%%s"
+msgstr ""
+"Die folgenden unversionierten Dateien im Arbeitsverzeichnis würden durch "
+"den\n"
+"Checkout überschrieben werden:\n"
+"%%s"
+
+#: unpack-trees.c:154
+#, c-format
+msgid ""
+"The following untracked working tree files would be overwritten by merge:\n"
+"%%sPlease move or remove them before you merge."
+msgstr ""
+"Die folgenden unversionierten Dateien im Arbeitsverzeichnis würden durch\n"
+"den Merge überschrieben werden:\n"
+"%%sBitte verschieben oder entfernen Sie diese, bevor Sie mergen."
+
+#: unpack-trees.c:156
+#, c-format
+msgid ""
+"The following untracked working tree files would be overwritten by merge:\n"
+"%%s"
+msgstr ""
+"Die folgenden unversionierten Dateien im Arbeitsverzeichnis würden durch\n"
+"den Merge überschrieben werden:\n"
+"%%s"
+
+#: unpack-trees.c:159
+#, c-format
+msgid ""
+"The following untracked working tree files would be overwritten by %s:\n"
+"%%sPlease move or remove them before you %s."
+msgstr ""
+"Die folgenden unversionierten Dateien im Arbeitsverzeichnis würden durch\n"
+"den %s überschrieben werden:\n"
+"%%sBitte verschieben oder entfernen Sie diese, bevor sie %s ausführen."
+
+#: unpack-trees.c:161
+#, c-format
+msgid ""
+"The following untracked working tree files would be overwritten by %s:\n"
+"%%s"
+msgstr ""
+"Die folgenden unversionierten Dateien im Arbeitsverzeichnis würden durch "
+"den\n"
+"%s überschrieben werden:\n"
+"%%s"
+
+#: unpack-trees.c:169
+#, c-format
+msgid "Entry '%s' overlaps with '%s'.  Cannot bind."
+msgstr "Eintrag '%s' überschneidet sich mit '%s'. Kann nicht verbinden."
+
+#: unpack-trees.c:172
+#, c-format
+msgid ""
+"Cannot update sparse checkout: the following entries are not up to date:\n"
+"%s"
+msgstr ""
+"Kann partiellen Checkout nicht aktualisieren: die folgenden Einträge\n"
+"sind nicht aktuell:\n"
+"%s"
+
+#: unpack-trees.c:174
+#, c-format
+msgid ""
+"The following working tree files would be overwritten by sparse checkout "
+"update:\n"
+"%s"
+msgstr ""
+"Die folgenden Dateien im Arbeitsverzeichnis würden durch die Aktualisierung\n"
+"über einen partiellen Checkout überschrieben werden:\n"
+"%s"
+
+#: unpack-trees.c:176
+#, c-format
+msgid ""
+"The following working tree files would be removed by sparse checkout "
+"update:\n"
+"%s"
+msgstr ""
+"Die folgenden Dateien im Arbeitsverzeichnis würden durch die Aktualisierung\n"
+"über einen partiellen Checkout entfernt werden:\n"
+"%s"
+
+#: unpack-trees.c:178
+#, c-format
+msgid ""
+"Cannot update submodule:\n"
+"%s"
+msgstr ""
+"Kann Submodul nicht aktualisieren:\n"
+"%s"
+
+#: unpack-trees.c:255
+#, c-format
+msgid "Aborting\n"
+msgstr "Abbruch\n"
+
+#: unpack-trees.c:317
+msgid "Updating files"
+msgstr "Aktualisiere Dateien"
+
+#: unpack-trees.c:349
+msgid ""
+"the following paths have collided (e.g. case-sensitive paths\n"
+"on a case-insensitive filesystem) and only one from the same\n"
+"colliding group is in the working tree:\n"
+msgstr ""
+"Die folgenden Pfade haben kollidiert (z.B. case-sensitive Pfade\n"
+"auf einem case-insensitiven Dateisystem) und nur einer von der\n"
+"selben Kollissionsgruppe ist im Arbeitsverzeichnis:\n"
+
+#: unpack-trees.c:1441
+msgid "Updating index flags"
+msgstr "Aktualisiere Index-Markierungen"
+
+#: urlmatch.c:163
+msgid "invalid URL scheme name or missing '://' suffix"
+msgstr "Ungültiges URL-Schema oder Suffix '://' fehlt"
+
+#: urlmatch.c:187 urlmatch.c:346 urlmatch.c:405
+#, c-format
+msgid "invalid %XX escape sequence"
+msgstr "ungültige Escape-Sequenz %XX"
+
+#: urlmatch.c:215
+msgid "missing host and scheme is not 'file:'"
+msgstr "fehlender Host und Schema ist nicht 'file:'"
+
+#: urlmatch.c:232
+msgid "a 'file:' URL may not have a port number"
+msgstr "eine 'file:' URL darf keine Portnummer enthalten"
+
+#: urlmatch.c:247
+msgid "invalid characters in host name"
+msgstr "Hostname enthält ungültige Zeichen"
+
+#: urlmatch.c:292 urlmatch.c:303
+msgid "invalid port number"
+msgstr "ungültige Portnummer"
+
+#: urlmatch.c:371
+msgid "invalid '..' path segment"
+msgstr "ungültiges '..' Pfadsegment"
+
+#: worktree.c:258 builtin/am.c:2084
+#, c-format
+msgid "failed to read '%s'"
+msgstr "Fehler beim Lesen von '%s'"
+
+#: worktree.c:304
+#, c-format
+msgid "'%s' at main working tree is not the repository directory"
+msgstr "'%s' im Hauptarbeitsverzeichnis ist nicht das Repository-Verzeichnis."
+
+#: worktree.c:315
+#, c-format
+msgid "'%s' file does not contain absolute path to the working tree location"
+msgstr "'%s' Datei enthält nicht den absoluten Pfad zum Arbeitsverzeichnis."
+
+#: worktree.c:327
+#, c-format
+msgid "'%s' does not exist"
+msgstr "'%s' existiert nicht."
+
+#: worktree.c:333
+#, c-format
+msgid "'%s' is not a .git file, error code %d"
+msgstr "'%s' ist keine .git-Datei, Fehlercode %d"
+
+#: worktree.c:341
+#, c-format
+msgid "'%s' does not point back to '%s'"
+msgstr "'%s' zeigt nicht zurück auf '%s'"
+
+#: wrapper.c:186 wrapper.c:356
+#, c-format
+msgid "could not open '%s' for reading and writing"
+msgstr "Konnte '%s' nicht zum Lesen und Schreiben öffnen."
+
+#: wrapper.c:387 wrapper.c:588
+#, c-format
+msgid "unable to access '%s'"
+msgstr "konnte nicht auf '%s' zugreifen"
+
+#: wrapper.c:596
+msgid "unable to get current working directory"
+msgstr "Konnte aktuelles Arbeitsverzeichnis nicht bekommen."
+
+#: wt-status.c:158
+msgid "Unmerged paths:"
+msgstr "Nicht zusammengeführte Pfade:"
+
+#: wt-status.c:187 wt-status.c:219
+msgid "  (use \"git restore --staged <file>...\" to unstage)"
+msgstr ""
+"  (benutzen Sie \"git restore --staged <Datei>...\" zum Entfernen aus der "
+"Staging-Area)"
+
+#: wt-status.c:190 wt-status.c:222
+#, c-format
+msgid "  (use \"git restore --source=%s --staged <file>...\" to unstage)"
+msgstr ""
+"  (benutzen Sie \"git restore --source=%s --staged <Datei>...\" zum "
+"Entfernen aus der Staging-Area)"
+
+#: wt-status.c:193 wt-status.c:225
+msgid "  (use \"git rm --cached <file>...\" to unstage)"
+msgstr ""
+"  (benutzen Sie \"git rm --cached <Datei>...\" zum Entfernen aus der Staging-"
+"Area)"
+
+#: wt-status.c:197
+msgid "  (use \"git add <file>...\" to mark resolution)"
+msgstr ""
+"  (benutzen Sie \"git add/rm <Datei>...\", um die Auflösung zu markieren)"
+
+#: wt-status.c:199 wt-status.c:203
+msgid "  (use \"git add/rm <file>...\" as appropriate to mark resolution)"
+msgstr ""
+"  (benutzen Sie \"git add/rm <Datei>...\", um die Auflösung entsprechend zu "
+"markieren)"
+
+#: wt-status.c:201
+msgid "  (use \"git rm <file>...\" to mark resolution)"
+msgstr ""
+"  (benutzen Sie \"git add/rm <Datei>...\", um die Auflösung zu markieren)"
+
+#: wt-status.c:211 wt-status.c:1074
+msgid "Changes to be committed:"
+msgstr "Zum Commit vorgemerkte Änderungen:"
+
+#: wt-status.c:234 wt-status.c:1083
+msgid "Changes not staged for commit:"
+msgstr "Änderungen, die nicht zum Commit vorgemerkt sind:"
+
+#: wt-status.c:238
+msgid "  (use \"git add <file>...\" to update what will be committed)"
+msgstr ""
+"  (benutzen Sie \"git add <Datei>...\", um die Änderungen zum Commit "
+"vorzumerken)"
+
+#: wt-status.c:240
+msgid "  (use \"git add/rm <file>...\" to update what will be committed)"
+msgstr ""
+"  (benutzen Sie \"git add/rm <Datei>...\", um die Änderungen zum Commit "
+"vorzumerken)"
+
+#: wt-status.c:241
+msgid ""
+"  (use \"git restore <file>...\" to discard changes in working directory)"
+msgstr ""
+"  (benutzen Sie \"git restore <Datei>...\", um die Änderungen im "
+"Arbeitsverzeichnis zu verwerfen)"
+
+#: wt-status.c:243
+msgid "  (commit or discard the untracked or modified content in submodules)"
+msgstr ""
+"  (committen oder verwerfen Sie den unversionierten oder geänderten Inhalt "
+"in den Submodulen)"
+
+#: wt-status.c:254
+#, c-format
+msgid "  (use \"git %s <file>...\" to include in what will be committed)"
+msgstr ""
+"  (benutzen Sie \"git %s <Datei>...\", um die Änderungen zum Commit "
+"vorzumerken)"
+
+#: wt-status.c:268
+msgid "both deleted:"
+msgstr "beide gelöscht:"
+
+#: wt-status.c:270
+msgid "added by us:"
+msgstr "von uns hinzugefügt:"
+
+#: wt-status.c:272
+msgid "deleted by them:"
+msgstr "von denen gelöscht:"
+
+#: wt-status.c:274
+msgid "added by them:"
+msgstr "von denen hinzugefügt:"
+
+#: wt-status.c:276
+msgid "deleted by us:"
+msgstr "von uns gelöscht:"
+
+#: wt-status.c:278
+msgid "both added:"
+msgstr "von beiden hinzugefügt:"
+
+#: wt-status.c:280
+msgid "both modified:"
+msgstr "von beiden geändert:"
+
+#: wt-status.c:290
+msgid "new file:"
+msgstr "neue Datei:"
+
+#: wt-status.c:292
+msgid "copied:"
+msgstr "kopiert:"
+
+#: wt-status.c:294
+msgid "deleted:"
+msgstr "gelöscht:"
+
+#: wt-status.c:296
+msgid "modified:"
+msgstr "geändert:"
+
+#: wt-status.c:298
+msgid "renamed:"
+msgstr "umbenannt:"
+
+#: wt-status.c:300
+msgid "typechange:"
+msgstr "Typänderung:"
+
+#: wt-status.c:302
+msgid "unknown:"
+msgstr "unbekannt:"
+
+#: wt-status.c:304
+msgid "unmerged:"
+msgstr "nicht gemerged:"
+
+#: wt-status.c:384
+msgid "new commits, "
+msgstr "neue Commits, "
+
+#: wt-status.c:386
+msgid "modified content, "
+msgstr "geänderter Inhalt, "
+
+#: wt-status.c:388
+msgid "untracked content, "
+msgstr "unversionierter Inhalt, "
+
+#: wt-status.c:906
+#, c-format
+msgid "Your stash currently has %d entry"
+msgid_plural "Your stash currently has %d entries"
+msgstr[0] "Ihr Stash hat gerade %d Eintrag"
+msgstr[1] "Ihr Stash hat gerade %d Einträge"
+
+#: wt-status.c:938
+msgid "Submodules changed but not updated:"
+msgstr "Submodule geändert, aber nicht aktualisiert:"
+
+#: wt-status.c:940
+msgid "Submodule changes to be committed:"
+msgstr "Änderungen in Submodul zum Committen:"
+
+#: wt-status.c:1022
+msgid ""
+"Do not modify or remove the line above.\n"
+"Everything below it will be ignored."
+msgstr ""
+"Ändern oder entfernen Sie nicht die obige Zeile.\n"
+"Alles unterhalb von ihr wird ignoriert."
+
+#: wt-status.c:1114
+#, c-format
+msgid ""
+"\n"
+"It took %.2f seconds to compute the branch ahead/behind values.\n"
+"You can use '--no-ahead-behind' to avoid this.\n"
+msgstr ""
+"\n"
+"Es wurden %.2f Sekunden benötigt, um die voraus/hinterher-Werte zu "
+"berechnen.\n"
+"Sie können '--no-ahead-behind' benutzen, um das zu verhindern.\n"
+
+#: wt-status.c:1144
+msgid "You have unmerged paths."
+msgstr "Sie haben nicht zusammengeführte Pfade."
+
+#: wt-status.c:1147
+msgid "  (fix conflicts and run \"git commit\")"
+msgstr " (beheben Sie die Konflikte und führen Sie \"git commit\" aus)"
+
+#: wt-status.c:1149
+msgid "  (use \"git merge --abort\" to abort the merge)"
+msgstr "  (benutzen Sie \"git merge --abort\", um den Merge abzubrechen)"
+
+#: wt-status.c:1153
+msgid "All conflicts fixed but you are still merging."
+msgstr "Alle Konflikte sind behoben, aber Sie sind immer noch beim Merge."
+
+#: wt-status.c:1156
+msgid "  (use \"git commit\" to conclude merge)"
+msgstr "  (benutzen Sie \"git commit\", um den Merge abzuschließen)"
+
+#: wt-status.c:1165
+msgid "You are in the middle of an am session."
+msgstr "Eine \"am\"-Sitzung ist im Gange."
+
+#: wt-status.c:1168
+msgid "The current patch is empty."
+msgstr "Der aktuelle Patch ist leer."
+
+#: wt-status.c:1172
+msgid "  (fix conflicts and then run \"git am --continue\")"
+msgstr ""
+"  (beheben Sie die Konflikte und führen Sie dann \"git am --continue\" aus)"
+
+#: wt-status.c:1174
+msgid "  (use \"git am --skip\" to skip this patch)"
+msgstr "  (benutzen Sie \"git am --skip\", um diesen Patch auszulassen)"
+
+#: wt-status.c:1176
+msgid "  (use \"git am --abort\" to restore the original branch)"
+msgstr ""
+"  (benutzen Sie \"git am --abort\", um den ursprünglichen Branch "
+"wiederherzustellen)"
+
+#: wt-status.c:1309
+msgid "git-rebase-todo is missing."
+msgstr "git-rebase-todo fehlt."
+
+#: wt-status.c:1311
+msgid "No commands done."
+msgstr "Keine Befehle ausgeführt."
+
+#: wt-status.c:1314
+#, c-format
+msgid "Last command done (%d command done):"
+msgid_plural "Last commands done (%d commands done):"
+msgstr[0] "Zuletzt ausgeführter Befehl (%d Befehl ausgeführt):"
+msgstr[1] "Zuletzt ausgeführte Befehle (%d Befehle ausgeführt):"
+
+#: wt-status.c:1325
+#, c-format
+msgid "  (see more in file %s)"
+msgstr "  (mehr Informationen in Datei %s)"
+
+#: wt-status.c:1330
+msgid "No commands remaining."
+msgstr "Keine Befehle verbleibend."
+
+#: wt-status.c:1333
+#, c-format
+msgid "Next command to do (%d remaining command):"
+msgid_plural "Next commands to do (%d remaining commands):"
+msgstr[0] "Nächster auszuführender Befehl (%d Befehle verbleibend):"
+msgstr[1] "Nächste auszuführende Befehle (%d Befehle verbleibend):"
+
+#: wt-status.c:1341
+msgid "  (use \"git rebase --edit-todo\" to view and edit)"
+msgstr "  (benutzen Sie \"git rebase --edit-todo\" zum Ansehen und Bearbeiten)"
+
+#: wt-status.c:1353
+#, c-format
+msgid "You are currently rebasing branch '%s' on '%s'."
+msgstr "Sie sind gerade beim Rebase von Branch '%s' auf '%s'."
+
+#: wt-status.c:1358
+msgid "You are currently rebasing."
+msgstr "Sie sind gerade beim Rebase."
+
+#: wt-status.c:1371
+msgid "  (fix conflicts and then run \"git rebase --continue\")"
+msgstr ""
+"  (beheben Sie die Konflikte und führen Sie dann \"git rebase --continue\" "
+"aus)"
+
+#: wt-status.c:1373
+msgid "  (use \"git rebase --skip\" to skip this patch)"
+msgstr "  (benutzen Sie \"git rebase --skip\", um diesen Patch auszulassen)"
+
+#: wt-status.c:1375
+msgid "  (use \"git rebase --abort\" to check out the original branch)"
+msgstr ""
+"  (benutzen Sie \"git rebase --abort\", um den ursprünglichen Branch "
+"auszuchecken)"
+
+#: wt-status.c:1382
+msgid "  (all conflicts fixed: run \"git rebase --continue\")"
+msgstr "  (alle Konflikte behoben: führen Sie \"git rebase --continue\" aus)"
+
+#: wt-status.c:1386
+#, c-format
+msgid ""
+"You are currently splitting a commit while rebasing branch '%s' on '%s'."
+msgstr ""
+"Sie teilen gerade einen Commit auf, während ein Rebase von Branch '%s' auf "
+"'%s' im Gange ist."
+
+#: wt-status.c:1391
+msgid "You are currently splitting a commit during a rebase."
+msgstr "Sie teilen gerade einen Commit während eines Rebase auf."
+
+#: wt-status.c:1394
+msgid "  (Once your working directory is clean, run \"git rebase --continue\")"
+msgstr ""
+"  (Sobald Ihr Arbeitsverzeichnis unverändert ist, führen Sie \"git rebase --"
+"continue\" aus)"
+
+#: wt-status.c:1398
+#, c-format
+msgid "You are currently editing a commit while rebasing branch '%s' on '%s'."
+msgstr ""
+"Sie editieren gerade einen Commit während eines Rebase von Branch '%s' auf "
+"'%s'."
+
+#: wt-status.c:1403
+msgid "You are currently editing a commit during a rebase."
+msgstr "Sie editieren gerade einen Commit während eines Rebase."
+
+#: wt-status.c:1406
+msgid "  (use \"git commit --amend\" to amend the current commit)"
+msgstr ""
+"  (benutzen Sie \"git commit --amend\", um den aktuellen Commit "
+"nachzubessern)"
+
+#: wt-status.c:1408
+msgid ""
+"  (use \"git rebase --continue\" once you are satisfied with your changes)"
+msgstr ""
+"  (benutzen Sie \"git rebase --continue\" sobald Ihre Änderungen "
+"abgeschlossen sind)"
+
+#: wt-status.c:1419
+msgid "Cherry-pick currently in progress."
+msgstr "Cherry-pick zurzeit im Gange."
+
+#: wt-status.c:1422
+#, c-format
+msgid "You are currently cherry-picking commit %s."
+msgstr "Sie führen gerade \"cherry-pick\" von Commit %s aus."
+
+#: wt-status.c:1429
+msgid "  (fix conflicts and run \"git cherry-pick --continue\")"
+msgstr ""
+"  (beheben Sie die Konflikte und führen Sie dann \"git cherry-pick --continue"
+"\" aus)"
+
+#: wt-status.c:1432
+msgid "  (run \"git cherry-pick --continue\" to continue)"
+msgstr "  (Führen Sie \"git cherry-pick --continue\" aus, um weiterzumachen)"
+
+#: wt-status.c:1435
+msgid "  (all conflicts fixed: run \"git cherry-pick --continue\")"
+msgstr ""
+"  (alle Konflikte behoben: führen Sie \"git cherry-pick --continue\" aus)"
+
+#: wt-status.c:1437
+msgid "  (use \"git cherry-pick --skip\" to skip this patch)"
+msgstr ""
+"  (benutzen Sie \"git cherry-pick --skip\", um diesen Patch auszulassen)"
+
+#: wt-status.c:1439
+msgid "  (use \"git cherry-pick --abort\" to cancel the cherry-pick operation)"
+msgstr ""
+"  (benutzen Sie \"git cherry-pick --abort\", um die Cherry-Pick-Operation "
+"abzubrechen)"
+
+#: wt-status.c:1449
+msgid "Revert currently in progress."
+msgstr "Revert zurzeit im Gange."
+
+#: wt-status.c:1452
+#, c-format
+msgid "You are currently reverting commit %s."
+msgstr "Sie sind gerade beim Revert von Commit '%s'."
+
+#: wt-status.c:1458
+msgid "  (fix conflicts and run \"git revert --continue\")"
+msgstr ""
+"  (beheben Sie die Konflikte und führen Sie dann \"git revert --continue\" "
+"aus)"
+
+#: wt-status.c:1461
+msgid "  (run \"git revert --continue\" to continue)"
+msgstr "  (Führen Sie \"git revert --continue\", um weiterzumachen)"
+
+#: wt-status.c:1464
+msgid "  (all conflicts fixed: run \"git revert --continue\")"
+msgstr "  (alle Konflikte behoben: führen Sie \"git revert --continue\" aus)"
+
+#: wt-status.c:1466
+msgid "  (use \"git revert --skip\" to skip this patch)"
+msgstr "  (benutzen Sie \"git revert --skip\", um diesen Patch auszulassen)"
+
+#: wt-status.c:1468
+msgid "  (use \"git revert --abort\" to cancel the revert operation)"
+msgstr ""
+"  (benutzen Sie \"git revert --abort\", um die Revert-Operation abzubrechen)"
+
+#: wt-status.c:1478
+#, c-format
+msgid "You are currently bisecting, started from branch '%s'."
+msgstr "Sie sind gerade bei einer binären Suche, gestartet von Branch '%s'."
+
+#: wt-status.c:1482
+msgid "You are currently bisecting."
+msgstr "Sie sind gerade bei einer binären Suche."
+
+#: wt-status.c:1485
+msgid "  (use \"git bisect reset\" to get back to the original branch)"
+msgstr ""
+"  (benutzen Sie \"git bisect reset\", um zum ursprünglichen Branch "
+"zurückzukehren)"
+
+#: wt-status.c:1694
+msgid "On branch "
+msgstr "Auf Branch "
+
+#: wt-status.c:1701
+msgid "interactive rebase in progress; onto "
+msgstr "interaktives Rebase im Gange; auf "
+
+#: wt-status.c:1703
+msgid "rebase in progress; onto "
+msgstr "Rebase im Gange; auf "
+
+#: wt-status.c:1713
+msgid "Not currently on any branch."
+msgstr "Im Moment auf keinem Branch."
+
+#: wt-status.c:1730
+msgid "Initial commit"
+msgstr "Initialer Commit"
+
+#: wt-status.c:1731
+msgid "No commits yet"
+msgstr "Noch keine Commits"
+
+#: wt-status.c:1745
+msgid "Untracked files"
+msgstr "Unversionierte Dateien"
+
+#: wt-status.c:1747
+msgid "Ignored files"
+msgstr "Ignorierte Dateien"
+
+#: wt-status.c:1751
+#, c-format
+msgid ""
+"It took %.2f seconds to enumerate untracked files. 'status -uno'\n"
+"may speed it up, but you have to be careful not to forget to add\n"
+"new files yourself (see 'git help status')."
+msgstr ""
+"Es dauerte %.2f Sekunden die unversionierten Dateien zu bestimmen.\n"
+"'status -uno' könnte das beschleunigen, aber Sie müssen darauf achten,\n"
+"neue Dateien selbstständig hinzuzufügen (siehe 'git help status')."
+
+#: wt-status.c:1757
+#, c-format
+msgid "Untracked files not listed%s"
+msgstr "Unversionierte Dateien nicht aufgelistet%s"
+
+#: wt-status.c:1759
+msgid " (use -u option to show untracked files)"
+msgstr " (benutzen Sie die Option -u, um unversionierte Dateien anzuzeigen)"
+
+#: wt-status.c:1765
+msgid "No changes"
+msgstr "Keine Änderungen"
+
+#: wt-status.c:1770
+#, c-format
+msgid "no changes added to commit (use \"git add\" and/or \"git commit -a\")\n"
+msgstr ""
+"keine Änderungen zum Commit vorgemerkt (benutzen Sie \"git add\" und/oder "
+"\"git commit -a\")\n"
+
+#: wt-status.c:1773
+#, c-format
+msgid "no changes added to commit\n"
+msgstr "keine Änderungen zum Commit vorgemerkt\n"
+
+#: wt-status.c:1776
+#, c-format
+msgid ""
+"nothing added to commit but untracked files present (use \"git add\" to "
+"track)\n"
+msgstr ""
+"nichts zum Commit vorgemerkt, aber es gibt unversionierte Dateien\n"
+"(benutzen Sie \"git add\" zum Versionieren)\n"
+
+#: wt-status.c:1779
+#, c-format
+msgid "nothing added to commit but untracked files present\n"
+msgstr "nichts zum Commit vorgemerkt, aber es gibt unversionierte Dateien\n"
+
+#: wt-status.c:1782
+#, c-format
+msgid "nothing to commit (create/copy files and use \"git add\" to track)\n"
+msgstr ""
+"nichts zu committen (erstellen/kopieren Sie Dateien und benutzen\n"
+"Sie \"git add\" zum Versionieren)\n"
+
+#: wt-status.c:1785 wt-status.c:1790
+#, c-format
+msgid "nothing to commit\n"
+msgstr "nichts zu committen\n"
+
+#: wt-status.c:1788
+#, c-format
+msgid "nothing to commit (use -u to show untracked files)\n"
+msgstr ""
+"nichts zu committen (benutzen Sie die Option -u, um unversionierte Dateien "
+"anzuzeigen)\n"
+
+#: wt-status.c:1792
+#, c-format
+msgid "nothing to commit, working tree clean\n"
+msgstr "nichts zu committen, Arbeitsverzeichnis unverändert\n"
+
+#: wt-status.c:1905
+msgid "No commits yet on "
+msgstr "Noch keine Commits in "
+
+#: wt-status.c:1909
+msgid "HEAD (no branch)"
+msgstr "HEAD (kein Branch)"
+
+#: wt-status.c:1940
+msgid "different"
+msgstr "unterschiedlich"
+
+#: wt-status.c:1942 wt-status.c:1950
+msgid "behind "
+msgstr "hinterher "
+
+#: wt-status.c:1945 wt-status.c:1948
+msgid "ahead "
+msgstr "voraus "
+
+#. TRANSLATORS: the action is e.g. "pull with rebase"
+#: wt-status.c:2470
+#, c-format
+msgid "cannot %s: You have unstaged changes."
+msgstr ""
+"%s nicht möglich: Sie haben Änderungen, die nicht zum Commit vorgemerkt sind."
+
+#: wt-status.c:2476
+msgid "additionally, your index contains uncommitted changes."
+msgstr "Zusätzlich enthält die Staging-Area nicht committete Änderungen."
+
+#: wt-status.c:2478
+#, c-format
+msgid "cannot %s: Your index contains uncommitted changes."
+msgstr ""
+"%s nicht möglich: Die Staging-Area enthält nicht committete Änderungen."
+
+#: compat/precompose_utf8.c:58 builtin/clone.c:455
+#, c-format
+msgid "failed to unlink '%s'"
+msgstr "Konnte '%s' nicht entfernen."
+
+#: builtin/add.c:26
+msgid "git add [<options>] [--] <pathspec>..."
+msgstr "git add [<Optionen>] [--] <Pfadspezifikation>..."
+
+#: builtin/add.c:87
+#, c-format
+msgid "unexpected diff status %c"
+msgstr "unerwarteter Differenz-Status %c"
+
+#: builtin/add.c:92 builtin/commit.c:288
+msgid "updating files failed"
+msgstr "Aktualisierung der Dateien fehlgeschlagen"
+
+#: builtin/add.c:102
+#, c-format
+msgid "remove '%s'\n"
+msgstr "lösche '%s'\n"
+
+#: builtin/add.c:177
+msgid "Unstaged changes after refreshing the index:"
+msgstr ""
+"Nicht zum Commit vorgemerkte Änderungen nach Aktualisierung der Staging-Area:"
+
+#: builtin/add.c:252 builtin/rev-parse.c:899
+msgid "Could not read the index"
+msgstr "Konnte den Index nicht lesen"
+
+#: builtin/add.c:263
+#, c-format
+msgid "Could not open '%s' for writing."
+msgstr "Konnte '%s' nicht zum Schreiben öffnen."
+
+#: builtin/add.c:267
+msgid "Could not write patch"
+msgstr "Konnte Patch nicht schreiben"
+
+#: builtin/add.c:270
+msgid "editing patch failed"
+msgstr "Bearbeitung des Patches fehlgeschlagen"
+
+#: builtin/add.c:273
+#, c-format
+msgid "Could not stat '%s'"
+msgstr "Konnte Verzeichnis '%s' nicht lesen"
+
+#: builtin/add.c:275
+msgid "Empty patch. Aborted."
+msgstr "Leerer Patch. Abgebrochen."
+
+#: builtin/add.c:280
+#, c-format
+msgid "Could not apply '%s'"
+msgstr "Konnte '%s' nicht anwenden."
+
+#: builtin/add.c:288
+msgid "The following paths are ignored by one of your .gitignore files:\n"
+msgstr ""
+"Die folgenden Pfade werden durch eine Ihrer \".gitignore\" Dateien "
+"ignoriert:\n"
+
+#: builtin/add.c:308 builtin/clean.c:910 builtin/fetch.c:163 builtin/mv.c:124
+#: builtin/prune-packed.c:56 builtin/pull.c:223 builtin/push.c:548
+#: builtin/remote.c:1344 builtin/rm.c:241 builtin/send-pack.c:165
+msgid "dry run"
+msgstr "Probelauf"
+
+#: builtin/add.c:311
+msgid "interactive picking"
+msgstr "interaktives Auswählen"
+
+#: builtin/add.c:312 builtin/checkout.c:1482 builtin/reset.c:307
+msgid "select hunks interactively"
+msgstr "Blöcke interaktiv auswählen"
+
+#: builtin/add.c:313
+msgid "edit current diff and apply"
+msgstr "aktuelle Unterschiede editieren und anwenden"
+
+#: builtin/add.c:314
+msgid "allow adding otherwise ignored files"
+msgstr "das Hinzufügen andernfalls ignorierter Dateien erlauben"
+
+#: builtin/add.c:315
+msgid "update tracked files"
+msgstr "versionierte Dateien aktualisieren"
+
+#: builtin/add.c:316
+msgid "renormalize EOL of tracked files (implies -u)"
+msgstr ""
+"erneutes Normalisieren der Zeilenenden von versionierten Dateien (impliziert "
+"-u)"
+
+#: builtin/add.c:317
+msgid "record only the fact that the path will be added later"
+msgstr "nur speichern, dass der Pfad später hinzugefügt werden soll"
+
+#: builtin/add.c:318
+msgid "add changes from all tracked and untracked files"
+msgstr ""
+"Änderungen von allen versionierten und unversionierten Dateien hinzufügen"
+
+#: builtin/add.c:321
+msgid "ignore paths removed in the working tree (same as --no-all)"
+msgstr "gelöschte Pfade im Arbeitsverzeichnis ignorieren (genau wie --no-all)"
+
+#: builtin/add.c:323
+msgid "don't add, only refresh the index"
+msgstr "nichts hinzufügen, nur den Index aktualisieren"
+
+#: builtin/add.c:324
+msgid "just skip files which cannot be added because of errors"
+msgstr ""
+"Dateien überspringen, die aufgrund von Fehlern nicht hinzugefügt werden "
+"konnten"
+
+#: builtin/add.c:325
+msgid "check if - even missing - files are ignored in dry run"
+msgstr "prüfen ob - auch fehlende - Dateien im Probelauf ignoriert werden"
+
+#: builtin/add.c:327 builtin/update-index.c:1004
+msgid "override the executable bit of the listed files"
+msgstr "das \"ausführbar\"-Bit der aufgelisteten Dateien überschreiben"
+
+#: builtin/add.c:329
+msgid "warn when adding an embedded repository"
+msgstr "warnen wenn eingebettetes Repository hinzugefügt wird"
+
+#: builtin/add.c:347
+#, c-format
+msgid ""
+"You've added another git repository inside your current repository.\n"
+"Clones of the outer repository will not contain the contents of\n"
+"the embedded repository and will not know how to obtain it.\n"
+"If you meant to add a submodule, use:\n"
+"\n"
+"\tgit submodule add <url> %s\n"
+"\n"
+"If you added this path by mistake, you can remove it from the\n"
+"index with:\n"
+"\n"
+"\tgit rm --cached %s\n"
+"\n"
+"See \"git help submodule\" for more information."
+msgstr ""
+"Sie haben ein Git-Repository innerhalb ihres aktuellen Repositories "
+"hinzugefügt.\n"
+"Klone des äußeren Repositories werden die Inhalte des eingebetteten "
+"Repositories\n"
+"weder enthalten, noch wissen, wie diese zu beschaffen sind.\n"
+"Wenn Sie ein Submodul hinzufügen wollten, benutzen Sie:\n"
+"\n"
+"\tgit submodule add <URL> %s\n"
+"\n"
+"Wenn Sie diesen Pfad aus Versehen hinzugefügt haben, können Sie diesen mit\n"
+"\n"
+"\tgit rm --cached %s\n"
+"\n"
+"vom Index entfernen.\n"
+"\n"
+"Siehe \"git help submodule\" für weitere Informationen."
+
+#: builtin/add.c:375
+#, c-format
+msgid "adding embedded git repository: %s"
+msgstr "Füge eingebettetes Repository hinzu: %s"
+
+#: builtin/add.c:393
+#, c-format
+msgid "Use -f if you really want to add them.\n"
+msgstr "Verwenden Sie -f wenn Sie diese wirklich hinzufügen möchten.\n"
+
+#: builtin/add.c:400
+msgid "adding files failed"
+msgstr "Hinzufügen von Dateien fehlgeschlagen"
+
+#: builtin/add.c:428 builtin/commit.c:348
+msgid "--pathspec-from-file is incompatible with --interactive/--patch"
+msgstr ""
+"Die Optionen --pathspec-from-file und --interactive/--patch sind "
+"inkompatibel."
+
+#: builtin/add.c:434
+msgid "--pathspec-from-file is incompatible with --edit"
+msgstr "Die Optionen --pathspec-from-file und --edit sind inkompatibel."
+
+#: builtin/add.c:446
+msgid "-A and -u are mutually incompatible"
+msgstr "Die Optionen -A und -u sind zueinander inkompatibel."
+
+#: builtin/add.c:449
+msgid "Option --ignore-missing can only be used together with --dry-run"
+msgstr ""
+"Die Option --ignore-missing kann nur zusammen mit --dry-run verwendet werden."
+
+#: builtin/add.c:453
+#, c-format
+msgid "--chmod param '%s' must be either -x or +x"
+msgstr "--chmod Parameter '%s' muss entweder -x oder +x sein"
+
+#: builtin/add.c:471 builtin/checkout.c:1648 builtin/commit.c:354
+#: builtin/reset.c:327
+msgid "--pathspec-from-file is incompatible with pathspec arguments"
+msgstr ""
+"Die Option --pathspec-from-file ist inkompatibel mit\n"
+"Pfadspezifikation-Argumenten."
+
+#: builtin/add.c:478 builtin/checkout.c:1660 builtin/commit.c:360
+#: builtin/reset.c:333
+msgid "--pathspec-file-nul requires --pathspec-from-file"
+msgstr "Die Option --pathspec-file-nul benötigt --pathspec-from-file"
+
+#: builtin/add.c:482
+#, c-format
+msgid "Nothing specified, nothing added.\n"
+msgstr "Nichts spezifiziert, nichts hinzugefügt.\n"
+
+#: builtin/add.c:483
+#, c-format
+msgid "Maybe you wanted to say 'git add .'?\n"
+msgstr "Meinten Sie vielleicht 'git add .'?\n"
+
+#: builtin/am.c:347
+msgid "could not parse author script"
+msgstr "konnte Autor-Skript nicht parsen"
+
+#: builtin/am.c:431
+#, c-format
+msgid "'%s' was deleted by the applypatch-msg hook"
+msgstr "'%s' wurde durch den applypatch-msg Hook entfernt"
+
+#: builtin/am.c:473
+#, c-format
+msgid "Malformed input line: '%s'."
+msgstr "Fehlerhafte Eingabezeile: '%s'."
+
+#: builtin/am.c:511
+#, c-format
+msgid "Failed to copy notes from '%s' to '%s'"
+msgstr "Fehler beim Kopieren der Notizen von '%s' nach '%s'"
+
+#: builtin/am.c:537
+msgid "fseek failed"
+msgstr "\"fseek\" fehlgeschlagen"
+
+#: builtin/am.c:725
+#, c-format
+msgid "could not parse patch '%s'"
+msgstr "konnte Patch '%s' nicht parsen"
+
+#: builtin/am.c:790
+msgid "Only one StGIT patch series can be applied at once"
+msgstr "Es kann nur eine StGIT Patch-Serie auf einmal angewendet werden."
+
+#: builtin/am.c:838
+msgid "invalid timestamp"
+msgstr "ungültiger Zeitstempel"
+
+#: builtin/am.c:843 builtin/am.c:855
+msgid "invalid Date line"
+msgstr "Ungültige \"Date\"-Zeile"
+
+#: builtin/am.c:850
+msgid "invalid timezone offset"
+msgstr "Ungültiger Offset in der Zeitzone"
+
+#: builtin/am.c:943
+msgid "Patch format detection failed."
+msgstr "Patch-Formaterkennung fehlgeschlagen."
+
+#: builtin/am.c:948 builtin/clone.c:409
+#, c-format
+msgid "failed to create directory '%s'"
+msgstr "Fehler beim Erstellen von Verzeichnis '%s'"
+
+#: builtin/am.c:953
+msgid "Failed to split patches."
+msgstr "Fehler beim Aufteilen der Patches."
+
+#: builtin/am.c:1084
+#, c-format
+msgid "When you have resolved this problem, run \"%s --continue\"."
+msgstr ""
+"Wenn Sie das Problem aufgelöst haben, führen Sie \"%s --continue\" aus."
+
+#: builtin/am.c:1085
+#, c-format
+msgid "If you prefer to skip this patch, run \"%s --skip\" instead."
+msgstr ""
+"Falls Sie diesen Patch auslassen möchten, führen Sie stattdessen \"%s --skip"
+"\" aus."
+
+#: builtin/am.c:1086
+#, c-format
+msgid "To restore the original branch and stop patching, run \"%s --abort\"."
+msgstr ""
+"Um den ursprünglichen Branch wiederherzustellen und die Anwendung der "
+"Patches abzubrechen, führen Sie \"%s --abort\" aus."
+
+#: builtin/am.c:1169
+msgid "Patch sent with format=flowed; space at the end of lines might be lost."
+msgstr ""
+"Patch mit format=flowed versendet; Leerzeichen am Ende von Zeilen könnte "
+"verloren gehen."
+
+#: builtin/am.c:1197
+msgid "Patch is empty."
+msgstr "Patch ist leer."
+
+#: builtin/am.c:1262
+#, c-format
+msgid "missing author line in commit %s"
+msgstr "Autor-Zeile fehlt in Commit %s"
+
+#: builtin/am.c:1265
+#, c-format
+msgid "invalid ident line: %.*s"
+msgstr "Ungültige Identifikationszeile: %.*s"
+
+#: builtin/am.c:1484
+msgid "Repository lacks necessary blobs to fall back on 3-way merge."
+msgstr ""
+"Dem Repository fehlen notwendige Blobs um auf einen 3-Wege-Merge "
+"zurückzufallen."
+
+#: builtin/am.c:1486
+msgid "Using index info to reconstruct a base tree..."
+msgstr ""
+"Verwende Informationen aus der Staging-Area, um ein Basisverzeichnis "
+"nachzustellen ..."
+
+#: builtin/am.c:1505
+msgid ""
+"Did you hand edit your patch?\n"
+"It does not apply to blobs recorded in its index."
+msgstr ""
+"Haben Sie den Patch per Hand editiert?\n"
+"Er kann nicht auf die Blobs in seiner 'index' Zeile angewendet werden."
+
+#: builtin/am.c:1511
+msgid "Falling back to patching base and 3-way merge..."
+msgstr "Falle zurück zum Patchen der Basis und zum 3-Wege-Merge ..."
+
+#: builtin/am.c:1537
+msgid "Failed to merge in the changes."
+msgstr "Merge der Änderungen fehlgeschlagen."
+
+#: builtin/am.c:1569
+msgid "applying to an empty history"
+msgstr "auf leere Historie anwenden"
+
+#: builtin/am.c:1616 builtin/am.c:1620
+#, c-format
+msgid "cannot resume: %s does not exist."
+msgstr "Kann nicht fortsetzen: %s existiert nicht"
+
+#: builtin/am.c:1638
+msgid "Commit Body is:"
+msgstr "Commit-Beschreibung ist:"
+
+#. TRANSLATORS: Make sure to include [y], [n], [e], [v] and [a]
+#. in your translation. The program will only accept English
+#. input at this point.
+#.
+#: builtin/am.c:1648
+#, c-format
+msgid "Apply? [y]es/[n]o/[e]dit/[v]iew patch/[a]ccept all: "
+msgstr "Anwenden? [y]es/[n]o/[e]dit/[v]iew patch/[a]ccept all: "
+
+#: builtin/am.c:1695 builtin/commit.c:394
+msgid "unable to write index file"
+msgstr "Konnte Index-Datei nicht schreiben."
+
+#: builtin/am.c:1699
+#, c-format
+msgid "Dirty index: cannot apply patches (dirty: %s)"
+msgstr "Geänderter Index: kann Patches nicht anwenden (geändert: %s)"
+
+#: builtin/am.c:1739 builtin/am.c:1807
+#, c-format
+msgid "Applying: %.*s"
+msgstr "Wende an: %.*s"
+
+#: builtin/am.c:1756
+msgid "No changes -- Patch already applied."
+msgstr "Keine Änderungen -- Patches bereits angewendet."
+
+#: builtin/am.c:1762
+#, c-format
+msgid "Patch failed at %s %.*s"
+msgstr "Anwendung des Patches fehlgeschlagen bei %s %.*s"
+
+#: builtin/am.c:1766
+msgid "Use 'git am --show-current-patch' to see the failed patch"
+msgstr ""
+"Benutzen Sie 'git am --show-current-patch', um den\n"
+"fehlgeschlagenen Patch zu sehen."
+
+#: builtin/am.c:1810
+msgid ""
+"No changes - did you forget to use 'git add'?\n"
+"If there is nothing left to stage, chances are that something else\n"
+"already introduced the same changes; you might want to skip this patch."
+msgstr ""
+"Keine Änderungen - haben Sie vergessen 'git add' zu benutzen?\n"
+"Wenn keine Änderungen mehr zum Commit vorzumerken sind, könnten\n"
+"diese bereits anderweitig eingefügt worden sein; Sie könnten diesen Patch\n"
+"auslassen."
+
+#: builtin/am.c:1817
+msgid ""
+"You still have unmerged paths in your index.\n"
+"You should 'git add' each file with resolved conflicts to mark them as "
+"such.\n"
+"You might run `git rm` on a file to accept \"deleted by them\" for it."
+msgstr ""
+"Sie haben noch immer nicht zusammengeführte Pfade in Ihrem Index.\n"
+"Sie sollten 'git add' für jede Datei mit aufgelösten Konflikten ausführen,\n"
+"um diese als solche zu markieren.\n"
+"Sie können 'git rm' auf Dateien ausführen, um \"von denen gelöscht\" für\n"
+"diese zu akzeptieren."
+
+#: builtin/am.c:1924 builtin/am.c:1928 builtin/am.c:1940 builtin/reset.c:346
+#: builtin/reset.c:354
+#, c-format
+msgid "Could not parse object '%s'."
+msgstr "Konnte Objekt '%s' nicht parsen."
+
+#: builtin/am.c:1976
+msgid "failed to clean index"
+msgstr "Fehler beim Bereinigen des Index"
+
+#: builtin/am.c:2020
+msgid ""
+"You seem to have moved HEAD since the last 'am' failure.\n"
+"Not rewinding to ORIG_HEAD"
+msgstr ""
+"Sie scheinen seit dem letzten gescheiterten 'am' HEAD geändert zu haben.\n"
+"Keine Zurücksetzung zu ORIG_HEAD."
+
+#: builtin/am.c:2117
+#, c-format
+msgid "Invalid value for --patch-format: %s"
+msgstr "Ungültiger Wert für --patch-format: %s"
+
+#: builtin/am.c:2153
+msgid "git am [<options>] [(<mbox> | <Maildir>)...]"
+msgstr "git am [<Optionen>] [(<mbox> | <E-Mail-Verzeichnis>)...]"
+
+#: builtin/am.c:2154
+msgid "git am [<options>] (--continue | --skip | --abort)"
+msgstr "git am [<Optionen>] (--continue | --skip | --abort)"
+
+#: builtin/am.c:2160
+msgid "run interactively"
+msgstr "interaktiv ausführen"
+
+#: builtin/am.c:2162
+msgid "historical option -- no-op"
+msgstr "historische Option -- kein Effekt"
+
+#: builtin/am.c:2164
+msgid "allow fall back on 3way merging if needed"
+msgstr "erlaube, falls notwendig, das Zurückfallen auf einen 3-Wege-Merge"
+
+#: builtin/am.c:2165 builtin/init-db.c:494 builtin/prune-packed.c:58
+#: builtin/repack.c:304 builtin/stash.c:811
+msgid "be quiet"
+msgstr "weniger Ausgaben"
+
+#: builtin/am.c:2167
+msgid "add a Signed-off-by line to the commit message"
+msgstr "der Commit-Beschreibung eine Signed-off-by Zeile hinzufügen"
+
+#: builtin/am.c:2170
+msgid "recode into utf8 (default)"
+msgstr "nach UTF-8 umkodieren (Standard)"
+
+#: builtin/am.c:2172
+msgid "pass -k flag to git-mailinfo"
+msgstr "-k an git-mailinfo übergeben"
+
+#: builtin/am.c:2174
+msgid "pass -b flag to git-mailinfo"
+msgstr "-b an git-mailinfo übergeben"
+
+#: builtin/am.c:2176
+msgid "pass -m flag to git-mailinfo"
+msgstr "-m an git-mailinfo übergeben"
+
+#: builtin/am.c:2178
+msgid "pass --keep-cr flag to git-mailsplit for mbox format"
+msgstr "--keep-cr an git-mailsplit für mbox-Format übergeben"
+
+#: builtin/am.c:2181
+msgid "do not pass --keep-cr flag to git-mailsplit independent of am.keepcr"
+msgstr "kein --keep-cr an git-mailsplit übergeben, unabhängig von am.keepcr"
+
+#: builtin/am.c:2184
+msgid "strip everything before a scissors line"
+msgstr "alles vor einer Scheren-Zeile entfernen"
+
+#: builtin/am.c:2186 builtin/am.c:2189 builtin/am.c:2192 builtin/am.c:2195
+#: builtin/am.c:2198 builtin/am.c:2201 builtin/am.c:2204 builtin/am.c:2207
+#: builtin/am.c:2213
+msgid "pass it through git-apply"
+msgstr "an git-apply übergeben"
+
+#: builtin/am.c:2203 builtin/commit.c:1386 builtin/fmt-merge-msg.c:673
+#: builtin/fmt-merge-msg.c:676 builtin/grep.c:883 builtin/merge.c:249
+#: builtin/pull.c:160 builtin/pull.c:219 builtin/rebase.c:1469
+#: builtin/repack.c:315 builtin/repack.c:319 builtin/repack.c:321
+#: builtin/show-branch.c:650 builtin/show-ref.c:172 builtin/tag.c:403
+#: parse-options.h:154 parse-options.h:175 parse-options.h:316
+msgid "n"
+msgstr "Anzahl"
+
+#: builtin/am.c:2209 builtin/branch.c:661 builtin/for-each-ref.c:38
+#: builtin/replace.c:555 builtin/tag.c:437 builtin/verify-tag.c:38
+msgid "format"
+msgstr "Format"
+
+#: builtin/am.c:2210
+msgid "format the patch(es) are in"
+msgstr "Patch-Format"
+
+#: builtin/am.c:2216
+msgid "override error message when patch failure occurs"
+msgstr "Meldung bei fehlerhafter Patch-Anwendung überschreiben"
+
+#: builtin/am.c:2218
+msgid "continue applying patches after resolving a conflict"
+msgstr "Anwendung der Patches nach Auflösung eines Konfliktes fortsetzen"
+
+#: builtin/am.c:2221
+msgid "synonyms for --continue"
+msgstr "Synonyme für --continue"
+
+#: builtin/am.c:2224
+msgid "skip the current patch"
+msgstr "den aktuellen Patch auslassen"
+
+#: builtin/am.c:2227
+msgid "restore the original branch and abort the patching operation."
+msgstr ""
+"ursprünglichen Branch wiederherstellen und Anwendung der Patches abbrechen"
+
+#: builtin/am.c:2230
+msgid "abort the patching operation but keep HEAD where it is."
+msgstr "Patch-Operation abbrechen, aber HEAD an aktueller Stelle belassen"
+
+#: builtin/am.c:2233
+msgid "show the patch being applied."
+msgstr "den Patch, der gerade angewendet wird, anzeigen"
+
+#: builtin/am.c:2237
+msgid "lie about committer date"
+msgstr "Autor-Datum als Commit-Datum verwenden"
+
+#: builtin/am.c:2239
+msgid "use current timestamp for author date"
+msgstr "aktuellen Zeitstempel als Autor-Datum verwenden"
+
+#: builtin/am.c:2241 builtin/commit-tree.c:120 builtin/commit.c:1507
+#: builtin/merge.c:286 builtin/pull.c:194 builtin/rebase.c:509
+#: builtin/rebase.c:1513 builtin/revert.c:117 builtin/tag.c:418
+msgid "key-id"
+msgstr "GPG-Schlüsselkennung"
+
+#: builtin/am.c:2242 builtin/rebase.c:510 builtin/rebase.c:1514
+msgid "GPG-sign commits"
+msgstr "Commits mit GPG signieren"
+
+#: builtin/am.c:2245
+msgid "(internal use for git-rebase)"
+msgstr "(intern für git-rebase verwendet)"
+
+#: builtin/am.c:2263
+msgid ""
+"The -b/--binary option has been a no-op for long time, and\n"
+"it will be removed. Please do not use it anymore."
+msgstr ""
+"Die -b/--binary Option hat seit Langem keinen Effekt und wird\n"
+"entfernt. Bitte verwenden Sie diese nicht mehr."
+
+#: builtin/am.c:2270
+msgid "failed to read the index"
+msgstr "Fehler beim Lesen des Index"
+
+#: builtin/am.c:2285
+#, c-format
+msgid "previous rebase directory %s still exists but mbox given."
+msgstr "Vorheriges Rebase-Verzeichnis %s existiert noch, aber mbox gegeben."
+
+#: builtin/am.c:2309
+#, c-format
+msgid ""
+"Stray %s directory found.\n"
+"Use \"git am --abort\" to remove it."
+msgstr ""
+"Stray %s Verzeichnis gefunden.\n"
+"Benutzen Sie \"git am --abort\", um es zu entfernen."
+
+#: builtin/am.c:2315
+msgid "Resolve operation not in progress, we are not resuming."
+msgstr "Es ist keine Auflösung im Gange, es wird nicht fortgesetzt."
+
+#: builtin/am.c:2325
+msgid "interactive mode requires patches on the command line"
+msgstr "Interaktiver Modus benötigt Patches über die Kommandozeile"
+
+#: builtin/apply.c:8
+msgid "git apply [<options>] [<patch>...]"
+msgstr "git apply [<Optionen>] [<Patch>...]"
+
+#: builtin/archive.c:17
+#, c-format
+msgid "could not create archive file '%s'"
+msgstr "Konnte Archiv-Datei '%s' nicht erstellen."
+
+#: builtin/archive.c:20
+msgid "could not redirect output"
+msgstr "Konnte Ausgabe nicht umleiten."
+
+#: builtin/archive.c:37
+msgid "git archive: Remote with no URL"
+msgstr "git archive: Externes Archiv ohne URL"
+
+#: builtin/archive.c:61
+msgid "git archive: expected ACK/NAK, got a flush packet"
+msgstr "git archive: ACK/NAK erwartet, Flush-Paket bekommen"
+
+#: builtin/archive.c:64
+#, c-format
+msgid "git archive: NACK %s"
+msgstr "git archive: NACK %s"
+
+#: builtin/archive.c:65
+msgid "git archive: protocol error"
+msgstr "git archive: Protokollfehler"
+
+#: builtin/archive.c:69
+msgid "git archive: expected a flush"
+msgstr "git archive: erwartete eine Spülung (flush)"
+
+#: builtin/bisect--helper.c:22
+msgid "git bisect--helper --next-all [--no-checkout]"
+msgstr "git bisect--helper --next-all [--no-checkout]"
+
+#: builtin/bisect--helper.c:23
+msgid "git bisect--helper --write-terms <bad_term> <good_term>"
+msgstr "git bisect--helper --write-terms <bad_term> <good_term>"
+
+#: builtin/bisect--helper.c:24
+msgid "git bisect--helper --bisect-clean-state"
+msgstr "git bisect--helper --bisect-clean-state"
+
+#: builtin/bisect--helper.c:25
+msgid "git bisect--helper --bisect-reset [<commit>]"
+msgstr "git bisect--helper --bisect-reset [<Commit>]"
+
+#: builtin/bisect--helper.c:26
+msgid ""
+"git bisect--helper --bisect-write [--no-log] <state> <revision> <good_term> "
+"<bad_term>"
+msgstr ""
+"git bisect--helper --bisect-write [--no-log] <Zustand> <Revision> "
+"<Begriff_gut> <Begriff_schlecht>"
+
+#: builtin/bisect--helper.c:27
+msgid ""
+"git bisect--helper --bisect-check-and-set-terms <command> <good_term> "
+"<bad_term>"
+msgstr ""
+"git bisect--helper --bisect-check-and-set-terms <Befehl> <Begriff_gut> "
+"<Begriff_schlecht>"
+
+#: builtin/bisect--helper.c:28
+msgid "git bisect--helper --bisect-next-check <good_term> <bad_term> [<term>]"
+msgstr ""
+"git bisect--helper --bisect-next-check <Begriff_gut> <Begriff_schlecht> "
+"[<Begriff>]"
+
+#: builtin/bisect--helper.c:29
+msgid ""
+"git bisect--helper --bisect-terms [--term-good | --term-old | --term-bad | --"
+"term-new]"
+msgstr ""
+"git bisect--helper --bisect-terms [--term-good | --term-old | --term-bad | --"
+"term-new]"
+
+#: builtin/bisect--helper.c:30
+msgid ""
+"git bisect--helper --bisect-start [--term-{old,good}=<term> --term-{new,bad}"
+"=<term>][--no-checkout] [<bad> [<good>...]] [--] [<paths>...]"
+msgstr ""
+"git bisect--helper --bisect-start [--term-{old,good}=<Begriff> --term-{new,"
+"bad}=<Begriff>][--no-checkout] [<schlecht> [<gut>...]] [--] [<Pfade>...]"
+
+#: builtin/bisect--helper.c:86
+#, c-format
+msgid "'%s' is not a valid term"
+msgstr "'%s' ist kein gültiger Begriff."
+
+#: builtin/bisect--helper.c:90
+#, c-format
+msgid "can't use the builtin command '%s' as a term"
+msgstr "Kann den eingebauten Befehl '%s' nicht als Begriff verwenden."
+
+#: builtin/bisect--helper.c:100
+#, c-format
+msgid "can't change the meaning of the term '%s'"
+msgstr "Kann die Bedeutung von dem Begriff '%s' nicht ändern."
+
+#: builtin/bisect--helper.c:111
+msgid "please use two different terms"
+msgstr "Bitte verwenden Sie zwei verschiedene Begriffe."
+
+#: builtin/bisect--helper.c:118
+msgid "could not open the file BISECT_TERMS"
+msgstr "Konnte die Datei BISECT_TERMS nicht öffnen."
+
+#: builtin/bisect--helper.c:155
+#, c-format
+msgid "We are not bisecting.\n"
+msgstr "Keine binäre Suche im Gange.\n"
+
+#: builtin/bisect--helper.c:163
+#, c-format
+msgid "'%s' is not a valid commit"
+msgstr "'%s' ist kein gültiger Commit."
+
+#: builtin/bisect--helper.c:172
+#, c-format
+msgid ""
+"could not check out original HEAD '%s'. Try 'git bisect reset <commit>'."
+msgstr ""
+"Konnte den ursprünglichen HEAD '%s' nicht auschecken.\n"
+"Versuchen Sie 'git bisect reset <Commit>'."
+
+#: builtin/bisect--helper.c:216
+#, c-format
+msgid "Bad bisect_write argument: %s"
+msgstr "Ungültiges \"bisect_write\" Argument: %s"
+
+#: builtin/bisect--helper.c:221
+#, c-format
+msgid "couldn't get the oid of the rev '%s'"
+msgstr "Konnte die OID der Revision '%s' nicht erhalten."
+
+#: builtin/bisect--helper.c:233
+#, c-format
+msgid "couldn't open the file '%s'"
+msgstr "Konnte die Datei '%s' nicht öffnen."
+
+#: builtin/bisect--helper.c:259
+#, c-format
+msgid "Invalid command: you're currently in a %s/%s bisect"
+msgstr "Ungültiger Befehl: Sie sind gerade bei einer binären %s/%s Suche."
+
+#: builtin/bisect--helper.c:286
+#, c-format
+msgid ""
+"You need to give me at least one %s and %s revision.\n"
+"You can use \"git bisect %s\" and \"git bisect %s\" for that."
+msgstr ""
+"Sie müssen mindestens einen \"%s\" und einen \"%s\" Commit angeben.\n"
+"Sie können dafür \"git bisect %s\" und \"git bisect %s\" benutzen."
+
+#: builtin/bisect--helper.c:290
+#, c-format
+msgid ""
+"You need to start by \"git bisect start\".\n"
+"You then need to give me at least one %s and %s revision.\n"
+"You can use \"git bisect %s\" and \"git bisect %s\" for that."
+msgstr ""
+"Sie müssen mit \"git bisect start\" beginnen.\n"
+"Danach müssen Sie mindestens einen \"%s\" und einen \"%s\" Commit angeben.\n"
+"Sie können dafür \"git bisect %s\" und \"git bisect %s\" benutzen."
+
+#: builtin/bisect--helper.c:322
+#, c-format
+msgid "bisecting only with a %s commit"
+msgstr "Binäre Suche nur mit einem %s Commit."
+
+#. TRANSLATORS: Make sure to include [Y] and [n] in your
+#. translation. The program will only accept English input
+#. at this point.
+#.
+#: builtin/bisect--helper.c:330
+msgid "Are you sure [Y/n]? "
+msgstr "Sind Sie sicher [Y/n]? "
+
+#: builtin/bisect--helper.c:377
+msgid "no terms defined"
+msgstr "Keine Begriffe definiert."
+
+#: builtin/bisect--helper.c:380
+#, c-format
+msgid ""
+"Your current terms are %s for the old state\n"
+"and %s for the new state.\n"
+msgstr ""
+"Ihre aktuellen Begriffe sind %s für den alten Zustand\n"
+"und %s für den neuen Zustand.\n"
+
+#: builtin/bisect--helper.c:390
+#, c-format
+msgid ""
+"invalid argument %s for 'git bisect terms'.\n"
+"Supported options are: --term-good|--term-old and --term-bad|--term-new."
+msgstr ""
+"Ungültiges Argument %s für 'git bisect terms'.\n"
+"Unterstützte Optionen sind: --term-good|--term-old und --term-bad|--term-new."
+
+#: builtin/bisect--helper.c:476
+#, c-format
+msgid "unrecognized option: '%s'"
+msgstr "Nicht erkannte Position: '%s'"
+
+#: builtin/bisect--helper.c:480
+#, c-format
+msgid "'%s' does not appear to be a valid revision"
+msgstr "'%s' scheint kein gültiger Commit zu sein."
+
+#: builtin/bisect--helper.c:512
+msgid "bad HEAD - I need a HEAD"
+msgstr "Ungültiger HEAD - HEAD wird benötigt."
+
+#: builtin/bisect--helper.c:527
+#, c-format
+msgid "checking out '%s' failed. Try 'git bisect start <valid-branch>'."
+msgstr ""
+"Auschecken von '%s' fehlgeschlagen. Versuchen Sie 'git bisect start "
+"<gültiger-Branch>'."
+
+#: builtin/bisect--helper.c:548
+msgid "won't bisect on cg-seek'ed tree"
+msgstr ""
+"binäre Suche auf einem durch 'cg-seek' geändertem Verzeichnis nicht möglich"
+
+#: builtin/bisect--helper.c:551
+msgid "bad HEAD - strange symbolic ref"
+msgstr "Ungültiger HEAD - merkwürdige symbolische Referenz."
+
+#: builtin/bisect--helper.c:575
+#, c-format
+msgid "invalid ref: '%s'"
+msgstr "Ungültige Referenz: '%s'"
+
+#: builtin/bisect--helper.c:631
+msgid "perform 'git bisect next'"
+msgstr "'git bisect next' ausführen"
+
+#: builtin/bisect--helper.c:633
+msgid "write the terms to .git/BISECT_TERMS"
+msgstr "die Begriffe nach .git/BISECT_TERMS schreiben"
+
+#: builtin/bisect--helper.c:635
+msgid "cleanup the bisection state"
+msgstr "den Zustand der binären Suche aufräumen"
+
+#: builtin/bisect--helper.c:637
+msgid "check for expected revs"
+msgstr "auf erwartete Commits prüfen"
+
+#: builtin/bisect--helper.c:639
+msgid "reset the bisection state"
+msgstr "den Zustand der binären Suche zurücksetzen"
+
+#: builtin/bisect--helper.c:641
+msgid "write out the bisection state in BISECT_LOG"
+msgstr "den Zustand der binären Suche nach BISECT_LOG schreiben"
+
+#: builtin/bisect--helper.c:643
+msgid "check and set terms in a bisection state"
+msgstr "Begriffe innerhalb einer binären Suche prüfen und setzen"
+
+#: builtin/bisect--helper.c:645
+msgid "check whether bad or good terms exist"
+msgstr "prüfen, ob Begriffe für gute und schlechte Commits existieren"
+
+#: builtin/bisect--helper.c:647
+msgid "print out the bisect terms"
+msgstr "die Begriffe für die binäre Suche ausgeben"
+
+#: builtin/bisect--helper.c:649
+msgid "start the bisect session"
+msgstr "Sitzung für binäre Suche starten"
+
+#: builtin/bisect--helper.c:651
+msgid "update BISECT_HEAD instead of checking out the current commit"
+msgstr "BISECT_HEAD aktualisieren, anstatt den aktuellen Commit auszuchecken"
+
+#: builtin/bisect--helper.c:653
+msgid "no log for BISECT_WRITE"
+msgstr "kein Log für BISECT_WRITE"
+
+#: builtin/bisect--helper.c:670
+msgid "--write-terms requires two arguments"
+msgstr "--write-terms benötigt zwei Argumente."
+
+#: builtin/bisect--helper.c:674
+msgid "--bisect-clean-state requires no arguments"
+msgstr "--bisect-clean-state erwartet keine Argumente."
+
+#: builtin/bisect--helper.c:681
+msgid "--bisect-reset requires either no argument or a commit"
+msgstr "--bisect-reset benötigt entweder kein Argument oder ein Commit."
+
+#: builtin/bisect--helper.c:685
+msgid "--bisect-write requires either 4 or 5 arguments"
+msgstr "--bisect-write benötigt entweder 4 oder 5 Argumente."
+
+#: builtin/bisect--helper.c:691
+msgid "--check-and-set-terms requires 3 arguments"
+msgstr "--check-and-set-terms benötigt 3 Argumente."
+
+#: builtin/bisect--helper.c:697
+msgid "--bisect-next-check requires 2 or 3 arguments"
+msgstr "--bisect-next-check benötigt 2 oder 3 Argumente."
+
+#: builtin/bisect--helper.c:703
+msgid "--bisect-terms requires 0 or 1 argument"
+msgstr "--bisect-terms benötigt 0 oder 1 Argument."
+
+#: builtin/blame.c:31
+msgid "git blame [<options>] [<rev-opts>] [<rev>] [--] <file>"
+msgstr "git blame [<Optionen>] [<rev-opts>] [<Commit>] [--] <Datei>"
+
+#: builtin/blame.c:36
+msgid "<rev-opts> are documented in git-rev-list(1)"
+msgstr "<rev-opts> sind dokumentiert in git-rev-list(1)"
+
+#: builtin/blame.c:409
+#, c-format
+msgid "expecting a color: %s"
+msgstr "Erwarte eine Farbe: %s"
+
+#: builtin/blame.c:416
+msgid "must end with a color"
+msgstr "Muss mit einer Farbe enden."
+
+#: builtin/blame.c:729
+#, c-format
+msgid "invalid color '%s' in color.blame.repeatedLines"
+msgstr "Ungültige Farbe '%s' in color.blame.repeatedLines."
+
+#: builtin/blame.c:747
+msgid "invalid value for blame.coloring"
+msgstr "Ungültiger Wert für blame.coloring."
+
+#: builtin/blame.c:822
+#, c-format
+msgid "cannot find revision %s to ignore"
+msgstr "Konnte Commit %s zum Ignorieren nicht finden"
+
+#: builtin/blame.c:844
+msgid "Show blame entries as we find them, incrementally"
+msgstr "\"blame\"-Einträge schrittweise anzeigen, während wir sie generieren"
+
+#: builtin/blame.c:845
+msgid "Show blank SHA-1 for boundary commits (Default: off)"
+msgstr "leere SHA-1 für Grenz-Commits anzeigen (Standard: aus)"
+
+#: builtin/blame.c:846
+msgid "Do not treat root commits as boundaries (Default: off)"
+msgstr "Root-Commits nicht als Grenzen behandeln (Standard: aus)"
+
+#: builtin/blame.c:847
+msgid "Show work cost statistics"
+msgstr "Statistiken zum Arbeitsaufwand anzeigen"
+
+#: builtin/blame.c:848
+msgid "Force progress reporting"
+msgstr "Fortschrittsanzeige erzwingen"
+
+#: builtin/blame.c:849
+msgid "Show output score for blame entries"
+msgstr "Ausgabebewertung für \"blame\"-Einträge anzeigen"
+
+#: builtin/blame.c:850
+msgid "Show original filename (Default: auto)"
+msgstr "ursprünglichen Dateinamen anzeigen (Standard: auto)"
+
+#: builtin/blame.c:851
+msgid "Show original linenumber (Default: off)"
+msgstr "ursprüngliche Zeilennummer anzeigen (Standard: aus)"
+
+#: builtin/blame.c:852
+msgid "Show in a format designed for machine consumption"
+msgstr "Anzeige in einem Format für maschinelle Auswertung"
+
+#: builtin/blame.c:853
+msgid "Show porcelain format with per-line commit information"
+msgstr ""
+"Anzeige in Format für Fremdprogramme mit Commit-Informationen pro Zeile"
+
+#: builtin/blame.c:854
+msgid "Use the same output mode as git-annotate (Default: off)"
+msgstr ""
+"Den gleichen Ausgabemodus benutzen wie \"git-annotate\" (Standard: aus)"
+
+#: builtin/blame.c:855
+msgid "Show raw timestamp (Default: off)"
+msgstr "Unbearbeiteten Zeitstempel anzeigen (Standard: aus)"
+
+#: builtin/blame.c:856
+msgid "Show long commit SHA1 (Default: off)"
+msgstr "Langen Commit-SHA1 anzeigen (Standard: aus)"
+
+#: builtin/blame.c:857
+msgid "Suppress author name and timestamp (Default: off)"
+msgstr "Den Namen des Autors und den Zeitstempel unterdrücken (Standard: aus)"
+
+#: builtin/blame.c:858
+msgid "Show author email instead of name (Default: off)"
+msgstr ""
+"Anstatt des Namens die E-Mail-Adresse des Autors anzeigen (Standard: aus)"
+
+#: builtin/blame.c:859
+msgid "Ignore whitespace differences"
+msgstr "Unterschiede im Whitespace ignorieren"
+
+#: builtin/blame.c:860 builtin/log.c:1702
+msgid "rev"
+msgstr "Commit"
+
+#: builtin/blame.c:860
+msgid "Ignore <rev> when blaming"
+msgstr "Ignoriere <rev> beim Ausführen von 'blame'"
+
+#: builtin/blame.c:861
+msgid "Ignore revisions from <file>"
+msgstr "Ignoriere Commits aus <Datei>"
+
+#: builtin/blame.c:862
+msgid "color redundant metadata from previous line differently"
+msgstr "redundante Metadaten der vorherigen Zeile unterschiedlich einfärben"
+
+#: builtin/blame.c:863
+msgid "color lines by age"
+msgstr "Zeilen nach Alter einfärben"
+
+#: builtin/blame.c:864
+msgid "Spend extra cycles to find better match"
+msgstr "Länger arbeiten, um bessere Übereinstimmungen zu finden"
+
+#: builtin/blame.c:865
+msgid "Use revisions from <file> instead of calling git-rev-list"
+msgstr "Commits von <Datei> benutzen, anstatt \"git-rev-list\" aufzurufen"
+
+#: builtin/blame.c:866
+msgid "Use <file>'s contents as the final image"
+msgstr "Inhalte der <Datei>en als endgültiges Abbild benutzen"
+
+#: builtin/blame.c:867 builtin/blame.c:868
+msgid "score"
+msgstr "Bewertung"
+
+#: builtin/blame.c:867
+msgid "Find line copies within and across files"
+msgstr "kopierte Zeilen innerhalb oder zwischen Dateien finden"
+
+#: builtin/blame.c:868
+msgid "Find line movements within and across files"
+msgstr "verschobene Zeilen innerhalb oder zwischen Dateien finden"
+
+#: builtin/blame.c:869
+msgid "n,m"
+msgstr "n,m"
+
+#: builtin/blame.c:869
+msgid "Process only line range n,m, counting from 1"
+msgstr "nur Zeilen im Bereich n,m verarbeiten, gezählt von 1"
+
+#: builtin/blame.c:921
+msgid "--progress can't be used with --incremental or porcelain formats"
+msgstr ""
+"--progress kann nicht mit --incremental oder Formaten für Fremdprogramme\n"
+"verwendet werden"
+
+#. TRANSLATORS: This string is used to tell us the
+#. maximum display width for a relative timestamp in
+#. "git blame" output.  For C locale, "4 years, 11
+#. months ago", which takes 22 places, is the longest
+#. among various forms of relative timestamps, but
+#. your language may need more or fewer display
+#. columns.
+#.
+#: builtin/blame.c:972
+msgid "4 years, 11 months ago"
+msgstr "vor 4 Jahren und 11 Monaten"
+
+#: builtin/blame.c:1079
+#, c-format
+msgid "file %s has only %lu line"
+msgid_plural "file %s has only %lu lines"
+msgstr[0] "Datei %s hat nur %lu Zeile"
+msgstr[1] "Datei %s hat nur %lu Zeilen"
+
+#: builtin/blame.c:1125
+msgid "Blaming lines"
+msgstr "Verarbeite Zeilen"
+
+#: builtin/branch.c:29
+msgid "git branch [<options>] [-r | -a] [--merged | --no-merged]"
+msgstr "git branch [<Optionen>] [-r | -a] [--merged | --no-merged]"
+
+#: builtin/branch.c:30
+msgid "git branch [<options>] [-l] [-f] <branch-name> [<start-point>]"
+msgstr "git branch [<Optionen>] [-l] [-f] <Branchname> [<Startpunkt>]"
+
+#: builtin/branch.c:31
+msgid "git branch [<options>] [-r] (-d | -D) <branch-name>..."
+msgstr "git branch [<Optionen>] [-r] (-d | -D) <Branchname>..."
+
+#: builtin/branch.c:32
+msgid "git branch [<options>] (-m | -M) [<old-branch>] <new-branch>"
+msgstr "git branch [<Optionen>] (-m | -M) [<alter-Branch>] <neuer-Branch>"
+
+#: builtin/branch.c:33
+msgid "git branch [<options>] (-c | -C) [<old-branch>] <new-branch>"
+msgstr "git branch [<Optionen>] (-c | -C) [<alter-Branch>] <neuer-Branch>"
+
+#: builtin/branch.c:34
+msgid "git branch [<options>] [-r | -a] [--points-at]"
+msgstr "git branch [<Optionen>] [-r | -a] [--points-at]"
+
+#: builtin/branch.c:35
+msgid "git branch [<options>] [-r | -a] [--format]"
+msgstr "git branch [<Optionen>] [-r | -a] [--format]"
+
+#: builtin/branch.c:154
+#, c-format
+msgid ""
+"deleting branch '%s' that has been merged to\n"
+"         '%s', but not yet merged to HEAD."
+msgstr ""
+"entferne Branch '%s', der zusammengeführt wurde mit\n"
+"         '%s', aber noch nicht mit HEAD zusammengeführt wurde."
+
+#: builtin/branch.c:158
+#, c-format
+msgid ""
+"not deleting branch '%s' that is not yet merged to\n"
+"         '%s', even though it is merged to HEAD."
+msgstr ""
+"entferne Branch '%s' nicht, der noch nicht zusammengeführt wurde mit\n"
+"         '%s', obwohl er mit HEAD zusammengeführt wurde."
+
+#: builtin/branch.c:172
+#, c-format
+msgid "Couldn't look up commit object for '%s'"
+msgstr "Konnte Commit-Objekt für '%s' nicht nachschlagen."
+
+#: builtin/branch.c:176
+#, c-format
+msgid ""
+"The branch '%s' is not fully merged.\n"
+"If you are sure you want to delete it, run 'git branch -D %s'."
+msgstr ""
+"Der Branch '%s' ist nicht vollständig zusammengeführt.\n"
+"Wenn Sie sicher sind diesen Branch zu entfernen, führen Sie 'git branch -D "
+"%s' aus."
+
+#: builtin/branch.c:189
+msgid "Update of config-file failed"
+msgstr "Aktualisierung der Konfigurationsdatei fehlgeschlagen."
+
+#: builtin/branch.c:220
+msgid "cannot use -a with -d"
+msgstr "kann -a nicht mit -d benutzen"
+
+#: builtin/branch.c:226
+msgid "Couldn't look up commit object for HEAD"
+msgstr "Konnte Commit-Objekt für HEAD nicht nachschlagen."
+
+#: builtin/branch.c:240
+#, c-format
+msgid "Cannot delete branch '%s' checked out at '%s'"
+msgstr "Kann Branch '%s' nicht entfernen, ausgecheckt in '%s'."
+
+#: builtin/branch.c:255
+#, c-format
+msgid "remote-tracking branch '%s' not found."
+msgstr "Remote-Tracking-Branch '%s' nicht gefunden"
+
+#: builtin/branch.c:256
+#, c-format
+msgid "branch '%s' not found."
+msgstr "Branch '%s' nicht gefunden."
+
+#: builtin/branch.c:271
+#, c-format
+msgid "Error deleting remote-tracking branch '%s'"
+msgstr "Fehler beim Entfernen des Remote-Tracking-Branches '%s'"
+
+#: builtin/branch.c:272
+#, c-format
+msgid "Error deleting branch '%s'"
+msgstr "Fehler beim Entfernen des Branches '%s'"
+
+#: builtin/branch.c:279
+#, c-format
+msgid "Deleted remote-tracking branch %s (was %s).\n"
+msgstr "Remote-Tracking-Branch %s entfernt (war %s).\n"
+
+#: builtin/branch.c:280
+#, c-format
+msgid "Deleted branch %s (was %s).\n"
+msgstr "Branch %s entfernt (war %s).\n"
+
+#: builtin/branch.c:429 builtin/tag.c:61
+msgid "unable to parse format string"
+msgstr "Konnte Formatierungsstring nicht parsen."
+
+#: builtin/branch.c:460
+msgid "could not resolve HEAD"
+msgstr "Konnte HEAD-Commit nicht auflösen."
+
+#: builtin/branch.c:466
+#, c-format
+msgid "HEAD (%s) points outside of refs/heads/"
+msgstr "HEAD (%s) wurde nicht unter \"refs/heads/\" gefunden!"
+
+#: builtin/branch.c:481
+#, c-format
+msgid "Branch %s is being rebased at %s"
+msgstr "Branch %s wird auf %s umgesetzt"
+
+#: builtin/branch.c:485
+#, c-format
+msgid "Branch %s is being bisected at %s"
+msgstr "Binäre Suche von Branch %s zu %s im Gange"
+
+#: builtin/branch.c:502
+msgid "cannot copy the current branch while not on any."
+msgstr ""
+"Kann den aktuellen Branch nicht kopieren, solange Sie sich auf keinem "
+"befinden."
+
+#: builtin/branch.c:504
+msgid "cannot rename the current branch while not on any."
+msgstr ""
+"Kann aktuellen Branch nicht umbenennen, solange Sie sich auf keinem befinden."
+
+#: builtin/branch.c:515
+#, c-format
+msgid "Invalid branch name: '%s'"
+msgstr "Ungültiger Branchname: '%s'"
+
+#: builtin/branch.c:542
+msgid "Branch rename failed"
+msgstr "Umbenennung des Branches fehlgeschlagen"
+
+#: builtin/branch.c:544
+msgid "Branch copy failed"
+msgstr "Kopie des Branches fehlgeschlagen"
+
+#: builtin/branch.c:548
+#, c-format
+msgid "Created a copy of a misnamed branch '%s'"
+msgstr "Kopie eines falsch benannten Branches '%s' erstellt."
+
+#: builtin/branch.c:551
+#, c-format
+msgid "Renamed a misnamed branch '%s' away"
+msgstr "falsch benannten Branch '%s' umbenannt"
+
+#: builtin/branch.c:557
+#, c-format
+msgid "Branch renamed to %s, but HEAD is not updated!"
+msgstr "Branch umbenannt zu %s, aber HEAD ist nicht aktualisiert!"
+
+#: builtin/branch.c:566
+msgid "Branch is renamed, but update of config-file failed"
+msgstr ""
+"Branch ist umbenannt, aber die Aktualisierung der Konfigurationsdatei ist "
+"fehlgeschlagen."
+
+#: builtin/branch.c:568
+msgid "Branch is copied, but update of config-file failed"
+msgstr ""
+"Branch wurde kopiert, aber die Aktualisierung der Konfigurationsdatei ist\n"
+"fehlgeschlagen."
+
+#: builtin/branch.c:584
+#, c-format
+msgid ""
+"Please edit the description for the branch\n"
+"  %s\n"
+"Lines starting with '%c' will be stripped.\n"
+msgstr ""
+"Bitte ändern Sie die Beschreibung für den Branch\n"
+"  %s\n"
+"Zeilen, die mit '%c' beginnen, werden entfernt.\n"
+
+#: builtin/branch.c:618
+msgid "Generic options"
+msgstr "Allgemeine Optionen"
+
+#: builtin/branch.c:620
+msgid "show hash and subject, give twice for upstream branch"
+msgstr "Hash und Betreff anzeigen; -vv: zusätzlich Upstream-Branch"
+
+#: builtin/branch.c:621
+msgid "suppress informational messages"
+msgstr "Informationsmeldungen unterdrücken"
+
+#: builtin/branch.c:622
+msgid "set up tracking mode (see git-pull(1))"
+msgstr "Modus zum Folgen von Branches einstellen (siehe git-pull(1))"
+
+#: builtin/branch.c:624
+msgid "do not use"
+msgstr "nicht verwenden"
+
+#: builtin/branch.c:626 builtin/rebase.c:505
+msgid "upstream"
+msgstr "Upstream"
+
+#: builtin/branch.c:626
+msgid "change the upstream info"
+msgstr "Informationen zum Upstream-Branch ändern"
+
+#: builtin/branch.c:627
+msgid "unset the upstream info"
+msgstr "Informationen zum Upstream-Branch entfernen"
+
+#: builtin/branch.c:628
+msgid "use colored output"
+msgstr "farbige Ausgaben verwenden"
+
+#: builtin/branch.c:629
+msgid "act on remote-tracking branches"
+msgstr "auf Remote-Tracking-Branches wirken"
+
+#: builtin/branch.c:631 builtin/branch.c:633
+msgid "print only branches that contain the commit"
+msgstr "nur Branches ausgeben, die diesen Commit enthalten"
+
+#: builtin/branch.c:632 builtin/branch.c:634
+msgid "print only branches that don't contain the commit"
+msgstr "nur Branches ausgeben, die diesen Commit nicht enthalten"
+
+#: builtin/branch.c:637
+msgid "Specific git-branch actions:"
+msgstr "spezifische Aktionen für \"git-branch\":"
+
+#: builtin/branch.c:638
+msgid "list both remote-tracking and local branches"
+msgstr "Remote-Tracking und lokale Branches auflisten"
+
+#: builtin/branch.c:640
+msgid "delete fully merged branch"
+msgstr "vollständig zusammengeführten Branch entfernen"
+
+#: builtin/branch.c:641
+msgid "delete branch (even if not merged)"
+msgstr "Branch löschen (auch wenn nicht zusammengeführt)"
+
+#: builtin/branch.c:642
+msgid "move/rename a branch and its reflog"
+msgstr "einen Branch und dessen Reflog verschieben/umbenennen"
+
+#: builtin/branch.c:643
+msgid "move/rename a branch, even if target exists"
+msgstr ""
+"einen Branch verschieben/umbenennen, auch wenn das Ziel bereits existiert"
+
+#: builtin/branch.c:644
+msgid "copy a branch and its reflog"
+msgstr "einen Branch und dessen Reflog kopieren"
+
+#: builtin/branch.c:645
+msgid "copy a branch, even if target exists"
+msgstr "einen Branch kopieren, auch wenn das Ziel bereits existiert"
+
+#: builtin/branch.c:646
+msgid "list branch names"
+msgstr "Branchnamen auflisten"
+
+#: builtin/branch.c:647
+msgid "show current branch name"
+msgstr "Zeige aktuellen Branch-Namen."
+
+#: builtin/branch.c:648
+msgid "create the branch's reflog"
+msgstr "das Reflog des Branches erzeugen"
+
+#: builtin/branch.c:650
+msgid "edit the description for the branch"
+msgstr "die Beschreibung für den Branch bearbeiten"
+
+#: builtin/branch.c:651
+msgid "force creation, move/rename, deletion"
+msgstr "Erstellung, Verschiebung/Umbenennung oder Löschung erzwingen"
+
+#: builtin/branch.c:652
+msgid "print only branches that are merged"
+msgstr "nur zusammengeführte Branches ausgeben"
+
+#: builtin/branch.c:653
+msgid "print only branches that are not merged"
+msgstr "nur nicht zusammengeführte Branches ausgeben"
+
+#: builtin/branch.c:654
+msgid "list branches in columns"
+msgstr "Branches in Spalten auflisten"
+
+#: builtin/branch.c:657 builtin/for-each-ref.c:42 builtin/notes.c:415
+#: builtin/notes.c:418 builtin/notes.c:581 builtin/notes.c:584
+#: builtin/tag.c:433
+msgid "object"
+msgstr "Objekt"
+
+#: builtin/branch.c:658
+msgid "print only branches of the object"
+msgstr "nur Branches von diesem Objekt ausgeben"
+
+#: builtin/branch.c:660 builtin/for-each-ref.c:48 builtin/tag.c:440
+msgid "sorting and filtering are case insensitive"
+msgstr "Sortierung und Filterung sind unabhängig von Groß- und Kleinschreibung"
+
+#: builtin/branch.c:661 builtin/for-each-ref.c:38 builtin/tag.c:438
+#: builtin/verify-tag.c:38
+msgid "format to use for the output"
+msgstr "für die Ausgabe zu verwendendes Format"
+
+#: builtin/branch.c:684 builtin/clone.c:784
+msgid "HEAD not found below refs/heads!"
+msgstr "HEAD wurde nicht unter \"refs/heads\" gefunden!"
+
+#: builtin/branch.c:708
+msgid "--column and --verbose are incompatible"
+msgstr "Die Optionen --column und --verbose sind inkompatibel."
+
+#: builtin/branch.c:723 builtin/branch.c:777 builtin/branch.c:786
+msgid "branch name required"
+msgstr "Branchname erforderlich"
+
+#: builtin/branch.c:753
+msgid "Cannot give description to detached HEAD"
+msgstr "zu losgelöstem HEAD kann keine Beschreibung hinterlegt werden"
+
+#: builtin/branch.c:758
+msgid "cannot edit description of more than one branch"
+msgstr "Beschreibung von mehr als einem Branch kann nicht bearbeitet werden"
+
+#: builtin/branch.c:765
+#, c-format
+msgid "No commit on branch '%s' yet."
+msgstr "Noch kein Commit in Branch '%s'."
+
+#: builtin/branch.c:768
+#, c-format
+msgid "No branch named '%s'."
+msgstr "Branch '%s' nicht vorhanden."
+
+#: builtin/branch.c:783
+msgid "too many branches for a copy operation"
+msgstr "zu viele Branches für eine Kopieroperation angegeben"
+
+#: builtin/branch.c:792
+msgid "too many arguments for a rename operation"
+msgstr "zu viele Argumente für eine Umbenennen-Operation angegeben"
+
+#: builtin/branch.c:797
+msgid "too many arguments to set new upstream"
+msgstr "zu viele Argumente angegeben, um Upstream-Branch zu setzen"
+
+#: builtin/branch.c:801
+#, c-format
+msgid ""
+"could not set upstream of HEAD to %s when it does not point to any branch."
+msgstr ""
+"Konnte keinen neuen Upstream-Branch von HEAD zu %s setzen, da dieser auf\n"
+"keinen Branch zeigt."
+
+#: builtin/branch.c:804 builtin/branch.c:827
+#, c-format
+msgid "no such branch '%s'"
+msgstr "Kein solcher Branch '%s'"
+
+#: builtin/branch.c:808
+#, c-format
+msgid "branch '%s' does not exist"
+msgstr "Branch '%s' existiert nicht"
+
+#: builtin/branch.c:821
+msgid "too many arguments to unset upstream"
+msgstr ""
+"zu viele Argumente angegeben, um Konfiguration zu Upstream-Branch zu "
+"entfernen"
+
+#: builtin/branch.c:825
+msgid "could not unset upstream of HEAD when it does not point to any branch."
+msgstr ""
+"Konnte Konfiguration zu Upstream-Branch von HEAD nicht entfernen, da dieser\n"
+"auf keinen Branch zeigt."
+
+#: builtin/branch.c:831
+#, c-format
+msgid "Branch '%s' has no upstream information"
+msgstr "Branch '%s' hat keinen Upstream-Branch gesetzt"
+
+#: builtin/branch.c:841
+msgid ""
+"The -a, and -r, options to 'git branch' do not take a branch name.\n"
+"Did you mean to use: -a|-r --list <pattern>?"
+msgstr ""
+"Die Optionen -a und -r bei 'git branch' können nicht mit einem Branchnamen "
+"verwendet werden.\n"
+"Wollten Sie -a|-r --list <Muster> benutzen?"
+
+#: builtin/branch.c:845
+msgid ""
+"the '--set-upstream' option is no longer supported. Please use '--track' or "
+"'--set-upstream-to' instead."
+msgstr ""
+"Die '--set-upstream' Option wird nicht länger unterstützt.\n"
+"Bitte benutzen Sie stattdessen '--track' oder '--set-upstream-to'."
+
+#: builtin/bundle.c:15 builtin/bundle.c:23
+msgid "git bundle create [<options>] <file> <git-rev-list args>"
+msgstr "git bundle create [<Optionen>] <Datei> <git-rev-list Argumente>"
+
+#: builtin/bundle.c:16 builtin/bundle.c:28
+msgid "git bundle verify [<options>] <file>"
+msgstr "git bundle verify [<Optionen>] <Datei>"
+
+#: builtin/bundle.c:17 builtin/bundle.c:33
+msgid "git bundle list-heads <file> [<refname>...]"
+msgstr "git bundle list-heads <Datei> [<Referenzname>...]"
+
+#: builtin/bundle.c:18 builtin/bundle.c:38
+msgid "git bundle unbundle <file> [<refname>...]"
+msgstr "git bundle unbundle <Datei> [<Referenzname>...]"
+
+#: builtin/bundle.c:66 builtin/pack-objects.c:3228
+msgid "do not show progress meter"
+msgstr "keine Fortschrittsanzeige anzeigen"
+
+#: builtin/bundle.c:68 builtin/pack-objects.c:3230
+msgid "show progress meter"
+msgstr "Fortschrittsanzeige anzeigen"
+
+#: builtin/bundle.c:70 builtin/pack-objects.c:3232
+msgid "show progress meter during object writing phase"
+msgstr "Forschrittsanzeige während des Schreibens von Objekten anzeigen"
+
+#: builtin/bundle.c:73 builtin/pack-objects.c:3235
+msgid "similar to --all-progress when progress meter is shown"
+msgstr "ähnlich zu --all-progress wenn Fortschrittsanzeige darstellt wird"
+
+#: builtin/bundle.c:93
+msgid "Need a repository to create a bundle."
+msgstr "Um ein Paket zu erstellen wird ein Repository benötigt."
+
+#: builtin/bundle.c:104
+msgid "do not show bundle details"
+msgstr "Keine Bundle-Details anzeigen"
+
+#: builtin/bundle.c:119
+#, c-format
+msgid "%s is okay\n"
+msgstr "%s ist in Ordnung\n"
+
+#: builtin/bundle.c:160
+msgid "Need a repository to unbundle."
+msgstr "Zum Entpacken wird ein Repository benötigt."
+
+#: builtin/bundle.c:168 builtin/remote.c:1609
+msgid "be verbose; must be placed before a subcommand"
+msgstr "erweiterte Ausgaben; muss vor einem Unterbefehl angegeben werden"
+
+#: builtin/bundle.c:190 builtin/remote.c:1640
+#, c-format
+msgid "Unknown subcommand: %s"
+msgstr "Unbekannter Unterbefehl: %s"
+
+#: builtin/cat-file.c:595
+msgid ""
+"git cat-file (-t [--allow-unknown-type] | -s [--allow-unknown-type] | -e | -"
+"p | <type> | --textconv | --filters) [--path=<path>] <object>"
+msgstr ""
+"git cat-file (-t [--allow-unknown-type] | -s [--allow-unknown-type] | -e | -"
+"p | <Art> | --textconv | --filters) [--path=<Pfad>] <Objekt>"
+
+#: builtin/cat-file.c:596
+msgid ""
+"git cat-file (--batch | --batch-check) [--follow-symlinks] [--textconv | --"
+"filters]"
+msgstr ""
+"git cat-file (--batch | --batch-check) [--follow-symlinks] [--textconv | --"
+"filters]"
+
+#: builtin/cat-file.c:617
+msgid "only one batch option may be specified"
+msgstr "Nur eine Batch-Option erlaubt."
+
+#: builtin/cat-file.c:635
+msgid "<type> can be one of: blob, tree, commit, tag"
+msgstr "<Art> kann sein: blob, tree, commit, tag"
+
+#: builtin/cat-file.c:636
+msgid "show object type"
+msgstr "Objektart anzeigen"
+
+#: builtin/cat-file.c:637
+msgid "show object size"
+msgstr "Objektgröße anzeigen"
+
+#: builtin/cat-file.c:639
+msgid "exit with zero when there's no error"
+msgstr "mit Rückgabewert 0 beenden, wenn kein Fehler aufgetreten ist"
+
+#: builtin/cat-file.c:640
+msgid "pretty-print object's content"
+msgstr "ansprechende Anzeige des Objektinhaltes"
+
+#: builtin/cat-file.c:642
+msgid "for blob objects, run textconv on object's content"
+msgstr "eine Textkonvertierung auf den Inhalt von Blob-Objekten ausführen"
+
+#: builtin/cat-file.c:644
+msgid "for blob objects, run filters on object's content"
+msgstr "für Blob-Objekte, Filter auf Objekt-Inhalte ausführen"
+
+#: builtin/cat-file.c:645 git-submodule.sh:992
+msgid "blob"
+msgstr "Blob"
+
+#: builtin/cat-file.c:646
+msgid "use a specific path for --textconv/--filters"
+msgstr "einen bestimmten Pfad für --textconv/--filters verwenden"
+
+#: builtin/cat-file.c:648
+msgid "allow -s and -t to work with broken/corrupt objects"
+msgstr "-s und -t mit beschädigten Objekten erlauben"
+
+#: builtin/cat-file.c:649
+msgid "buffer --batch output"
+msgstr "Ausgabe von --batch puffern"
+
+#: builtin/cat-file.c:651
+msgid "show info and content of objects fed from the standard input"
+msgstr ""
+"Anzeige von Informationen und Inhalt von Objekten, gelesen von der Standard-"
+"Eingabe"
+
+#: builtin/cat-file.c:655
+msgid "show info about objects fed from the standard input"
+msgstr ""
+"Anzeige von Informationen über Objekte, gelesen von der Standard-Eingabe"
+
+#: builtin/cat-file.c:659
+msgid "follow in-tree symlinks (used with --batch or --batch-check)"
+msgstr ""
+"symbolischen Verknüpfungen innerhalb des Repositories folgen (verwendet mit "
+"--batch oder --batch-check)"
+
+#: builtin/cat-file.c:661
+msgid "show all objects with --batch or --batch-check"
+msgstr "alle Objekte mit --batch oder --batch-check anzeigen"
+
+#: builtin/cat-file.c:663
+msgid "do not order --batch-all-objects output"
+msgstr "Ausgabe von --batch-all-objects nicht ordnen"
+
+#: builtin/check-attr.c:13
+msgid "git check-attr [-a | --all | <attr>...] [--] <pathname>..."
+msgstr "git check-attr [-a | --all | <Attribut>...] [--] <Pfadname>..."
+
+#: builtin/check-attr.c:14
+msgid "git check-attr --stdin [-z] [-a | --all | <attr>...]"
+msgstr "git check-attr --stdin [-z] [-a | --all | <Attribut>...]"
+
+#: builtin/check-attr.c:21
+msgid "report all attributes set on file"
+msgstr "alle Attribute einer Datei ausgeben"
+
+#: builtin/check-attr.c:22
+msgid "use .gitattributes only from the index"
+msgstr "nur .gitattributes vom Index verwenden"
+
+#: builtin/check-attr.c:23 builtin/check-ignore.c:25 builtin/hash-object.c:102
+msgid "read file names from stdin"
+msgstr "Dateinamen von der Standard-Eingabe lesen"
+
+#: builtin/check-attr.c:25 builtin/check-ignore.c:27
+msgid "terminate input and output records by a NUL character"
+msgstr "Einträge von Ein- und Ausgabe mit NUL-Zeichen abschließen"
+
+#: builtin/check-ignore.c:21 builtin/checkout.c:1435 builtin/gc.c:537
+#: builtin/worktree.c:506
+msgid "suppress progress reporting"
+msgstr "Fortschrittsanzeige unterdrücken"
+
+#: builtin/check-ignore.c:29
+msgid "show non-matching input paths"
+msgstr "Eingabe-Pfade ohne Übereinstimmungen anzeigen"
+
+#: builtin/check-ignore.c:31
+msgid "ignore index when checking"
+msgstr "Index bei der Prüfung ignorieren"
+
+#: builtin/check-ignore.c:160
+msgid "cannot specify pathnames with --stdin"
+msgstr "Angabe von Pfadnamen kann nicht gemeinsam mit --stdin verwendet werden"
+
+#: builtin/check-ignore.c:163
+msgid "-z only makes sense with --stdin"
+msgstr "Die Option -z kann nur mit --stdin verwendet werden."
+
+#: builtin/check-ignore.c:165
+msgid "no path specified"
+msgstr "kein Pfad angegeben"
+
+#: builtin/check-ignore.c:169
+msgid "--quiet is only valid with a single pathname"
+msgstr "Die Option --quiet ist nur mit einem einzelnen Pfadnamen gültig."
+
+#: builtin/check-ignore.c:171
+msgid "cannot have both --quiet and --verbose"
+msgstr ""
+"Die Optionen --quiet und --verbose können nicht gemeinsam verwendet werden."
+
+#: builtin/check-ignore.c:174
+msgid "--non-matching is only valid with --verbose"
+msgstr "--non-matching ist nur mit --verbose zulässig"
+
+#: builtin/check-mailmap.c:9
+msgid "git check-mailmap [<options>] <contact>..."
+msgstr "git check-mailmap [<Optionen>] <Kontakt>..."
+
+#: builtin/check-mailmap.c:14
+msgid "also read contacts from stdin"
+msgstr "ebenfalls Kontakte von der Standard-Eingabe lesen"
+
+#: builtin/check-mailmap.c:25
+#, c-format
+msgid "unable to parse contact: %s"
+msgstr "Konnte Kontakt '%s' nicht parsen."
+
+#: builtin/check-mailmap.c:48
+msgid "no contacts specified"
+msgstr "keine Kontakte angegeben"
+
+#: builtin/checkout-index.c:131
+msgid "git checkout-index [<options>] [--] [<file>...]"
+msgstr "git checkout-index [<Optionen>] [--] [<Datei>...]"
+
+#: builtin/checkout-index.c:148
+msgid "stage should be between 1 and 3 or all"
+msgstr "--stage sollte zwischen 1 und 3 oder 'all' sein"
+
+#: builtin/checkout-index.c:164
+msgid "check out all files in the index"
+msgstr "alle Dateien im Index auschecken"
+
+#: builtin/checkout-index.c:165
+msgid "force overwrite of existing files"
+msgstr "das Überschreiben bereits existierender Dateien erzwingen"
+
+#: builtin/checkout-index.c:167
+msgid "no warning for existing files and files not in index"
+msgstr ""
+"keine Warnung für existierende Dateien, und Dateien, die sich nicht im Index "
+"befinden"
+
+#: builtin/checkout-index.c:169
+msgid "don't checkout new files"
+msgstr "keine neuen Dateien auschecken"
+
+#: builtin/checkout-index.c:171
+msgid "update stat information in the index file"
+msgstr "Dateiinformationen in der Index-Datei aktualisieren"
+
+#: builtin/checkout-index.c:175
+msgid "read list of paths from the standard input"
+msgstr "eine Liste von Pfaden von der Standard-Eingabe lesen"
+
+#: builtin/checkout-index.c:177
+msgid "write the content to temporary files"
+msgstr "den Inhalt in temporäre Dateien schreiben"
+
+#: builtin/checkout-index.c:178 builtin/column.c:31
+#: builtin/submodule--helper.c:1385 builtin/submodule--helper.c:1388
+#: builtin/submodule--helper.c:1396 builtin/submodule--helper.c:1882
+#: builtin/worktree.c:679
+msgid "string"
+msgstr "Zeichenkette"
+
+#: builtin/checkout-index.c:179
+msgid "when creating files, prepend <string>"
+msgstr ""
+"wenn Dateien erzeugt werden, stelle <Zeichenkette> dem Dateinamen voran"
+
+#: builtin/checkout-index.c:181
+msgid "copy out the files from named stage"
+msgstr "Dateien von dem benannten Stand kopieren"
+
+#: builtin/checkout.c:31
+msgid "git checkout [<options>] <branch>"
+msgstr "git checkout [<Optionen>] <Branch>"
+
+#: builtin/checkout.c:32
+msgid "git checkout [<options>] [<branch>] -- <file>..."
+msgstr "git checkout [<Optionen>] [<Branch>] -- <Datei>..."
+
+#: builtin/checkout.c:37
+msgid "git switch [<options>] [<branch>]"
+msgstr "git switch [<Optionen>] [<Branch>]"
+
+#: builtin/checkout.c:42
+msgid "git restore [<options>] [--source=<branch>] <file>..."
+msgstr "git restore [<Optionen>] [--source=<Branch>] <Datei>..."
+
+#: builtin/checkout.c:175 builtin/checkout.c:214
+#, c-format
+msgid "path '%s' does not have our version"
+msgstr "Pfad '%s' hat nicht unsere Version."
+
+#: builtin/checkout.c:177 builtin/checkout.c:216
+#, c-format
+msgid "path '%s' does not have their version"
+msgstr "Pfad '%s' hat nicht deren Version."
+
+#: builtin/checkout.c:193
+#, c-format
+msgid "path '%s' does not have all necessary versions"
+msgstr "Pfad '%s' hat nicht alle notwendigen Versionen."
+
+#: builtin/checkout.c:243
+#, c-format
+msgid "path '%s' does not have necessary versions"
+msgstr "Pfad '%s' hat nicht die notwendigen Versionen."
+
+#: builtin/checkout.c:261
+#, c-format
+msgid "path '%s': cannot merge"
+msgstr "Pfad '%s': kann nicht zusammenführen"
+
+#: builtin/checkout.c:277
+#, c-format
+msgid "Unable to add merge result for '%s'"
+msgstr "Konnte Merge-Ergebnis von '%s' nicht hinzufügen."
+
+#: builtin/checkout.c:377
+#, c-format
+msgid "Recreated %d merge conflict"
+msgid_plural "Recreated %d merge conflicts"
+msgstr[0] "%d Merge-Konflikt wieder erstellt"
+msgstr[1] "%d Merge-Konflikte wieder erstellt"
+
+#: builtin/checkout.c:382
+#, c-format
+msgid "Updated %d path from %s"
+msgid_plural "Updated %d paths from %s"
+msgstr[0] "%d Pfad von %s aktualisiert"
+msgstr[1] "%d Pfade von %s aktualisiert"
+
+#: builtin/checkout.c:389
+#, c-format
+msgid "Updated %d path from the index"
+msgid_plural "Updated %d paths from the index"
+msgstr[0] "%d Pfad vom Index aktualisiert"
+msgstr[1] "%d Pfade vom Index aktualisiert"
+
+#: builtin/checkout.c:412 builtin/checkout.c:415 builtin/checkout.c:418
+#: builtin/checkout.c:422
+#, c-format
+msgid "'%s' cannot be used with updating paths"
+msgstr "'%s' kann nicht mit der Aktualisierung von Pfaden verwendet werden"
+
+#: builtin/checkout.c:425 builtin/checkout.c:428
+#, c-format
+msgid "'%s' cannot be used with %s"
+msgstr "'%s' kann nicht mit '%s' verwendet werden"
+
+#: builtin/checkout.c:432
+#, c-format
+msgid "Cannot update paths and switch to branch '%s' at the same time."
+msgstr ""
+"Kann nicht gleichzeitig Pfade aktualisieren und zu Branch '%s' wechseln"
+
+#: builtin/checkout.c:436
+#, c-format
+msgid "neither '%s' or '%s' is specified"
+msgstr "Weder '%s' noch '%s' ist angegeben"
+
+#: builtin/checkout.c:440
+#, c-format
+msgid "'%s' must be used when '%s' is not specified"
+msgstr "'%s' kann nur genutzt werden, wenn '%s' nicht verwendet wird"
+
+#: builtin/checkout.c:445 builtin/checkout.c:450
+#, c-format
+msgid "'%s' or '%s' cannot be used with %s"
+msgstr "'%s' oder '%s' kann nicht mit %s verwendet werden"
+
+#: builtin/checkout.c:509 builtin/checkout.c:516
+#, c-format
+msgid "path '%s' is unmerged"
+msgstr "Pfad '%s' ist nicht zusammengeführt."
+
+#: builtin/checkout.c:682 builtin/sparse-checkout.c:82
+msgid "you need to resolve your current index first"
+msgstr "Sie müssen zuerst die Konflikte in Ihrem aktuellen Index auflösen."
+
+#: builtin/checkout.c:732
+#, c-format
+msgid ""
+"cannot continue with staged changes in the following files:\n"
+"%s"
+msgstr ""
+"Kann nicht mit vorgemerkten Änderungen in folgenden Dateien fortsetzen:\n"
+"%s"
+
+#: builtin/checkout.c:835
+#, c-format
+msgid "Can not do reflog for '%s': %s\n"
+msgstr "Kann \"reflog\" für '%s' nicht durchführen: %s\n"
+
+#: builtin/checkout.c:877
+msgid "HEAD is now at"
+msgstr "HEAD ist jetzt bei"
+
+#: builtin/checkout.c:881 builtin/clone.c:716
+msgid "unable to update HEAD"
+msgstr "Konnte HEAD nicht aktualisieren."
+
+#: builtin/checkout.c:885
+#, c-format
+msgid "Reset branch '%s'\n"
+msgstr "Setze Branch '%s' neu\n"
+
+#: builtin/checkout.c:888
+#, c-format
+msgid "Already on '%s'\n"
+msgstr "Bereits auf '%s'\n"
+
+#: builtin/checkout.c:892
+#, c-format
+msgid "Switched to and reset branch '%s'\n"
+msgstr "Zu umgesetztem Branch '%s' gewechselt\n"
+
+#: builtin/checkout.c:894 builtin/checkout.c:1291
+#, c-format
+msgid "Switched to a new branch '%s'\n"
+msgstr "Zu neuem Branch '%s' gewechselt\n"
+
+#: builtin/checkout.c:896
+#, c-format
+msgid "Switched to branch '%s'\n"
+msgstr "Zu Branch '%s' gewechselt\n"
+
+#: builtin/checkout.c:947
+#, c-format
+msgid " ... and %d more.\n"
+msgstr " ... und %d weitere.\n"
+
+#: builtin/checkout.c:953
+#, c-format
+msgid ""
+"Warning: you are leaving %d commit behind, not connected to\n"
+"any of your branches:\n"
+"\n"
+"%s\n"
+msgid_plural ""
+"Warning: you are leaving %d commits behind, not connected to\n"
+"any of your branches:\n"
+"\n"
+"%s\n"
+msgstr[0] ""
+"Warnung: Sie lassen %d Commit zurück. Folgender Commit ist in\n"
+"keinem Ihrer Branches enthalten:\n"
+"\n"
+"%s\n"
+msgstr[1] ""
+"Warnung: Sie lassen %d Commits zurück. Folgende Commits sind in\n"
+"keinem Ihrer Branches enthalten:\n"
+"\n"
+"%s\n"
+
+#: builtin/checkout.c:972
+#, c-format
+msgid ""
+"If you want to keep it by creating a new branch, this may be a good time\n"
+"to do so with:\n"
+"\n"
+" git branch <new-branch-name> %s\n"
+"\n"
+msgid_plural ""
+"If you want to keep them by creating a new branch, this may be a good time\n"
+"to do so with:\n"
+"\n"
+" git branch <new-branch-name> %s\n"
+"\n"
+msgstr[0] ""
+"Wenn Sie diese durch einen neuen Branch behalten möchten, dann könnte jetzt\n"
+"ein guter Zeitpunkt sein, dies zu tun mit:\n"
+"\n"
+" git branch <neuer-Branchname> %s\n"
+"\n"
+msgstr[1] ""
+"Wenn Sie diese durch einen neuen Branch behalten möchten, dann könnte jetzt\n"
+"ein guter Zeitpunkt sein, dies zu tun mit:\n"
+"\n"
+" git branch <neuer-Branchname> %s\n"
+"\n"
+
+#: builtin/checkout.c:1007
+msgid "internal error in revision walk"
+msgstr "interner Fehler im Revisionsgang"
+
+#: builtin/checkout.c:1011
+msgid "Previous HEAD position was"
+msgstr "Vorherige Position von HEAD war"
+
+#: builtin/checkout.c:1051 builtin/checkout.c:1286
+msgid "You are on a branch yet to be born"
+msgstr "Sie sind auf einem Branch, der noch nicht geboren ist"
+
+#: builtin/checkout.c:1178
+msgid "only one reference expected"
+msgstr "nur eine Referenz erwartet"
+
+#: builtin/checkout.c:1195
+#, c-format
+msgid "only one reference expected, %d given."
+msgstr "nur eine Referenz erwartet, %d gegeben."
+
+#: builtin/checkout.c:1232
+#, c-format
+msgid ""
+"'%s' could be both a local file and a tracking branch.\n"
+"Please use -- (and optionally --no-guess) to disambiguate"
+msgstr ""
+"'%s' könnte eine lokale Datei und ein Tracking-Branch sein.\n"
+"Bitte benutzen Sie -- (und optional --no-guess), um diese\n"
+"eindeutig voneinander zu unterscheiden."
+
+#: builtin/checkout.c:1245 builtin/worktree.c:290 builtin/worktree.c:455
+#, c-format
+msgid "invalid reference: %s"
+msgstr "Ungültige Referenz: %s"
+
+#: builtin/checkout.c:1258 builtin/checkout.c:1622
+#, c-format
+msgid "reference is not a tree: %s"
+msgstr "Referenz ist kein \"Tree\"-Objekt: %s"
+
+#: builtin/checkout.c:1305
+#, c-format
+msgid "a branch is expected, got tag '%s'"
+msgstr "Ein Branch wird erwartet, Tag '%s' bekommen"
+
+#: builtin/checkout.c:1307
+#, c-format
+msgid "a branch is expected, got remote branch '%s'"
+msgstr "Ein Branch wird erwartet, Remote-Branch '%s' bekommen"
+
+#: builtin/checkout.c:1308 builtin/checkout.c:1316
+#, c-format
+msgid "a branch is expected, got '%s'"
+msgstr "Ein Branch wird erwartet, '%s' bekommen"
+
+#: builtin/checkout.c:1311
+#, c-format
+msgid "a branch is expected, got commit '%s'"
+msgstr "Ein Branch wird erwartet, Commit '%s' bekommen"
+
+#: builtin/checkout.c:1327
+msgid ""
+"cannot switch branch while merging\n"
+"Consider \"git merge --quit\" or \"git worktree add\"."
+msgstr ""
+"Der Branch kann nicht während eines Merges gewechselt werden.\n"
+"Ziehen Sie \"git merge --quit\" oder \"git worktree add\" in Betracht."
+
+#: builtin/checkout.c:1331
+msgid ""
+"cannot switch branch in the middle of an am session\n"
+"Consider \"git am --quit\" or \"git worktree add\"."
+msgstr ""
+"Der Branch kann nicht während eines laufenden 'am'-Befehls gewechselt "
+"werden.\n"
+"Ziehen Sie \"git am --quit\" oder \"git worktree add\" in Betracht."
+
+#: builtin/checkout.c:1335
+msgid ""
+"cannot switch branch while rebasing\n"
+"Consider \"git rebase --quit\" or \"git worktree add\"."
+msgstr ""
+"Der Branch kann nicht während eines laufenden 'revert'-Befehls gewechselt "
+"werden.\n"
+"Ziehen Sie \"git rebase --quit\" oder \"git worktree add\" in Betracht."
+
+#: builtin/checkout.c:1339
+msgid ""
+"cannot switch branch while cherry-picking\n"
+"Consider \"git cherry-pick --quit\" or \"git worktree add\"."
+msgstr ""
+"Der Branch kann nicht während eines laufenden 'cherry-pick'-Befehls "
+"gewechselt werden.\n"
+"Ziehen Sie \"git cherry-pick --quit\" oder \"git worktree add\" in Betracht."
+
+#: builtin/checkout.c:1343
+msgid ""
+"cannot switch branch while reverting\n"
+"Consider \"git revert --quit\" or \"git worktree add\"."
+msgstr ""
+"Der Branch kann nicht während eines laufenden 'revert'-Befehls gewechselt "
+"werden.\n"
+"Ziehen Sie \"git revert --quit\" oder \"git worktree add\" in Betracht."
+
+#: builtin/checkout.c:1347
+msgid "you are switching branch while bisecting"
+msgstr "Sie wechseln den Branch während einer binären Suche"
+
+#: builtin/checkout.c:1354
+msgid "paths cannot be used with switching branches"
+msgstr "Pfade können nicht beim Wechseln von Branches verwendet werden"
+
+#: builtin/checkout.c:1357 builtin/checkout.c:1361 builtin/checkout.c:1365
+#, c-format
+msgid "'%s' cannot be used with switching branches"
+msgstr "'%s' kann nicht beim Wechseln von Branches verwendet werden"
+
+#: builtin/checkout.c:1369 builtin/checkout.c:1372 builtin/checkout.c:1375
+#: builtin/checkout.c:1380 builtin/checkout.c:1385
+#, c-format
+msgid "'%s' cannot be used with '%s'"
+msgstr "'%s' kann nicht mit '%s' verwendet werden"
+
+#: builtin/checkout.c:1382
+#, c-format
+msgid "'%s' cannot take <start-point>"
+msgstr "'%s' kann nicht <Startpunkt> bekommen"
+
+#: builtin/checkout.c:1390
+#, c-format
+msgid "Cannot switch branch to a non-commit '%s'"
+msgstr "Kann Branch nicht zu Nicht-Commit '%s' wechseln"
+
+#: builtin/checkout.c:1397
+msgid "missing branch or commit argument"
+msgstr "Branch- oder Commit-Argument fehlt"
+
+#: builtin/checkout.c:1439 builtin/clone.c:91 builtin/commit-graph.c:52
+#: builtin/commit-graph.c:113 builtin/fetch.c:167 builtin/merge.c:285
+#: builtin/multi-pack-index.c:27 builtin/pull.c:138 builtin/push.c:563
+#: builtin/send-pack.c:174
+msgid "force progress reporting"
+msgstr "Fortschrittsanzeige erzwingen"
+
+#: builtin/checkout.c:1440
+msgid "perform a 3-way merge with the new branch"
+msgstr "einen 3-Wege-Merge mit dem neuen Branch ausführen"
+
+#: builtin/checkout.c:1441 builtin/log.c:1690 parse-options.h:322
+msgid "style"
+msgstr "Stil"
+
+#: builtin/checkout.c:1442
+msgid "conflict style (merge or diff3)"
+msgstr "Konfliktstil (merge oder diff3)"
+
+#: builtin/checkout.c:1454 builtin/worktree.c:503
+msgid "detach HEAD at named commit"
+msgstr "HEAD bei benanntem Commit loslösen"
+
+#: builtin/checkout.c:1455
+msgid "set upstream info for new branch"
+msgstr "Informationen zum Upstream-Branch für den neuen Branch setzen"
+
+#: builtin/checkout.c:1457
+msgid "force checkout (throw away local modifications)"
+msgstr "Auschecken erzwingen (verwirft lokale Änderungen)"
+
+#: builtin/checkout.c:1459
+msgid "new-branch"
+msgstr "neuer Branch"
+
+#: builtin/checkout.c:1459
+msgid "new unparented branch"
+msgstr "neuer Branch ohne Eltern-Commit"
+
+#: builtin/checkout.c:1461 builtin/merge.c:288
+msgid "update ignored files (default)"
+msgstr "ignorierte Dateien aktualisieren (Standard)"
+
+#: builtin/checkout.c:1464
+msgid "do not check if another worktree is holding the given ref"
+msgstr ""
+"Prüfung, ob die Referenz bereits in einem anderen Arbeitsverzeichnis "
+"ausgecheckt wurde, deaktivieren"
+
+#: builtin/checkout.c:1477
+msgid "checkout our version for unmerged files"
+msgstr "unsere Variante für nicht zusammengeführte Dateien auschecken"
+
+#: builtin/checkout.c:1480
+msgid "checkout their version for unmerged files"
+msgstr "ihre Variante für nicht zusammengeführte Dateien auschecken"
+
+#: builtin/checkout.c:1484
+msgid "do not limit pathspecs to sparse entries only"
+msgstr "keine Einschränkung bei Pfadspezifikationen zum partiellen Auschecken"
+
+#: builtin/checkout.c:1537
+msgid "-b, -B and --orphan are mutually exclusive"
+msgstr "Die Optionen -b, -B und --orphan schließen sich gegenseitig aus."
+
+#: builtin/checkout.c:1540
+msgid "-p and --overlay are mutually exclusive"
+msgstr "-p und --overlay schließen sich gegenseitig aus."
+
+#: builtin/checkout.c:1577
+msgid "--track needs a branch name"
+msgstr "Bei der Option --track muss ein Branchname angegeben werden."
+
+#: builtin/checkout.c:1582
+msgid "missing branch name; try -b"
+msgstr "Kein Branchname; versuchen Sie -b."
+
+#: builtin/checkout.c:1615
+#, c-format
+msgid "could not resolve %s"
+msgstr "Konnte %s nicht auflösen."
+
+#: builtin/checkout.c:1631
+msgid "invalid path specification"
+msgstr "ungültige Pfadspezifikation"
+
+#: builtin/checkout.c:1638
+#, c-format
+msgid "'%s' is not a commit and a branch '%s' cannot be created from it"
+msgstr ""
+"'%s' ist kein Commit und es kann kein Branch '%s' aus diesem erstellt werden."
+
+#: builtin/checkout.c:1642
+#, c-format
+msgid "git checkout: --detach does not take a path argument '%s'"
+msgstr "git checkout: --detach nimmt kein Pfad-Argument '%s'"
+
+#: builtin/checkout.c:1651
+msgid "--pathspec-from-file is incompatible with --detach"
+msgstr "Die Optionen --pathspec-from-file und --detach sind inkompatibel."
+
+#: builtin/checkout.c:1654 builtin/reset.c:324
+msgid "--pathspec-from-file is incompatible with --patch"
+msgstr "Die Optionen --pathspec-from-file und --patch sind inkompatibel."
+
+#: builtin/checkout.c:1665
+msgid ""
+"git checkout: --ours/--theirs, --force and --merge are incompatible when\n"
+"checking out of the index."
+msgstr ""
+"git checkout: --ours/--theirs, --force und --merge sind inkompatibel wenn\n"
+"Sie aus dem Index auschecken."
+
+#: builtin/checkout.c:1670
+msgid "you must specify path(s) to restore"
+msgstr "Sie müssen Pfad(e) zur Wiederherstellung angeben."
+
+#: builtin/checkout.c:1689
+#, c-format
+msgid ""
+"'%s' matched more than one remote tracking branch.\n"
+"We found %d remotes with a reference that matched. So we fell back\n"
+"on trying to resolve the argument as a path, but failed there too!\n"
+"\n"
+"If you meant to check out a remote tracking branch on, e.g. 'origin',\n"
+"you can do so by fully qualifying the name with the --track option:\n"
+"\n"
+"    git checkout --track origin/<name>\n"
+"\n"
+"If you'd like to always have checkouts of an ambiguous <name> prefer\n"
+"one remote, e.g. the 'origin' remote, consider setting\n"
+"checkout.defaultRemote=origin in your config."
+msgstr ""
+"'%s' entspricht mehr als einem Remote-Tracking-Branch.\n"
+"Wir fanden %d Remote-Repositories mit einer entsprechenden Referenz, also\n"
+"haben wir versucht, das Argument als Pfad aufzulösen, was auch schief ging!\n"
+"\n"
+"Falls Sie einen Remote-Tracking-Branch, z.B. von 'origin', auschecken "
+"wollten,\n"
+"können Sie das tun, indem Sie den vollständig qualifizierten Namen mit der\n"
+"--track Option angeben:\n"
+"\n"
+"    git checkout --track origin/<Name>\n"
+"\n"
+"Falls Sie beim Auschecken mit mehrdeutigen <Namen> immer ein Remote-"
+"Repository\n"
+"bevorzugen möchten, z.B. 'origin', könnten Sie die Einstellung\n"
+"checkout.defaultRemote=origin in Ihrer Konfiguration setzen."
+
+#: builtin/checkout.c:1714 builtin/checkout.c:1716 builtin/checkout.c:1765
+#: builtin/checkout.c:1767 builtin/clone.c:121 builtin/remote.c:169
+#: builtin/remote.c:171 builtin/worktree.c:499 builtin/worktree.c:501
+msgid "branch"
+msgstr "Branch"
+
+#: builtin/checkout.c:1715
+msgid "create and checkout a new branch"
+msgstr "einen neuen Branch erzeugen und auschecken"
+
+#: builtin/checkout.c:1717
+msgid "create/reset and checkout a branch"
+msgstr "einen Branch erstellen/umsetzen und auschecken"
+
+#: builtin/checkout.c:1718
+msgid "create reflog for new branch"
+msgstr "das Reflog für den neuen Branch erzeugen"
+
+#: builtin/checkout.c:1720
+msgid "second guess 'git checkout <no-such-branch>' (default)"
+msgstr "Zweite Vermutung 'git checkout <kein-solcher-Branch>' (Standard)"
+
+#: builtin/checkout.c:1721
+msgid "use overlay mode (default)"
+msgstr "benutze Overlay-Modus (Standard)"
+
+#: builtin/checkout.c:1766
+msgid "create and switch to a new branch"
+msgstr "einen neuen Branch erzeugen und dahin wechseln"
+
+#: builtin/checkout.c:1768
+msgid "create/reset and switch to a branch"
+msgstr "einen Branch erstellen/umsetzen und dahin wechseln"
+
+#: builtin/checkout.c:1770
+msgid "second guess 'git switch <no-such-branch>'"
+msgstr "Zweite Vermutung 'git switch <kein-solcher-Branch>'"
+
+#: builtin/checkout.c:1772
+msgid "throw away local modifications"
+msgstr "lokale Änderungen verwerfen"
+
+#: builtin/checkout.c:1804
+msgid "which tree-ish to checkout from"
+msgstr "Von welcher Commit-Referenz ausgecheckt werden soll"
+
+#: builtin/checkout.c:1806
+msgid "restore the index"
+msgstr "Index wiederherstellen"
+
+#: builtin/checkout.c:1808
+msgid "restore the working tree (default)"
+msgstr "das Arbeitsverzeichnis wiederherstellen (Standard)"
+
+#: builtin/checkout.c:1810
+msgid "ignore unmerged entries"
+msgstr "ignoriere nicht zusammengeführte Einträge"
+
+#: builtin/checkout.c:1811
+msgid "use overlay mode"
+msgstr "benutze Overlay-Modus"
+
+#: builtin/clean.c:28
+msgid ""
+"git clean [-d] [-f] [-i] [-n] [-q] [-e <pattern>] [-x | -X] [--] <paths>..."
+msgstr ""
+"git clean [-d] [-f] [-i] [-n] [-q] [-e <Muster>] [-x | -X] [--] <Pfade>..."
+
+#: builtin/clean.c:32
+#, c-format
+msgid "Removing %s\n"
+msgstr "Lösche %s\n"
+
+#: builtin/clean.c:33
+#, c-format
+msgid "Would remove %s\n"
+msgstr "Würde %s löschen\n"
+
+#: builtin/clean.c:34
+#, c-format
+msgid "Skipping repository %s\n"
+msgstr "Überspringe Repository %s\n"
+
+#: builtin/clean.c:35
+#, c-format
+msgid "Would skip repository %s\n"
+msgstr "Würde Repository %s überspringen\n"
+
+#: builtin/clean.c:36
+#, c-format
+msgid "failed to remove %s"
+msgstr "Fehler beim Löschen von %s"
+
+#: builtin/clean.c:37
+#, c-format
+msgid "could not lstat %s\n"
+msgstr "Konnte 'lstat' nicht für %s ausführen\n"
+
+#: builtin/clean.c:301 git-add--interactive.perl:595
+#, c-format
+msgid ""
+"Prompt help:\n"
+"1          - select a numbered item\n"
+"foo        - select item based on unique prefix\n"
+"           - (empty) select nothing\n"
+msgstr ""
+"Eingabehilfe:\n"
+"1          - nummeriertes Element auswählen\n"
+"foo        - Element anhand eines eindeutigen Präfix auswählen\n"
+"           - (leer) nichts auswählen\n"
+
+#: builtin/clean.c:305 git-add--interactive.perl:604
+#, c-format
+msgid ""
+"Prompt help:\n"
+"1          - select a single item\n"
+"3-5        - select a range of items\n"
+"2-3,6-9    - select multiple ranges\n"
 "foo        - select item based on unique prefix\n"
 "-...       - unselect specified items\n"
 "*          - choose all items\n"
 "           - (empty) finish selecting\n"
 msgstr ""
-"Eingabehilfe:\n"
-"1          - einzelnes Element auswählen\n"
-"3-5        - Bereich von Elementen auswählen\n"
-"2-3,6-9    - mehrere Bereiche auswählen\n"
-"foo        - Element anhand eines eindeutigen Präfix auswählen\n"
-"-...       - angegebenes Element abwählen\n"
-"*          - alle Elemente auswählen\n"
-"           - (leer) Auswahl beenden\n"
+"Eingabehilfe:\n"
+"1          - einzelnes Element auswählen\n"
+"3-5        - Bereich von Elementen auswählen\n"
+"2-3,6-9    - mehrere Bereiche auswählen\n"
+"foo        - Element anhand eines eindeutigen Präfix auswählen\n"
+"-...       - angegebenes Element abwählen\n"
+"*          - alle Elemente auswählen\n"
+"           - (leer) Auswahl beenden\n"
+
+#: builtin/clean.c:521 git-add--interactive.perl:570
+#: git-add--interactive.perl:575
+#, c-format, perl-format
+msgid "Huh (%s)?\n"
+msgstr "Wie bitte (%s)?\n"
+
+#: builtin/clean.c:663
+#, c-format
+msgid "Input ignore patterns>> "
+msgstr "Ignorier-Muster eingeben>> "
+
+#: builtin/clean.c:700
+#, c-format
+msgid "WARNING: Cannot find items matched by: %s"
+msgstr "WARNUNG: Kann keine Einträge finden die Muster entsprechen: %s"
+
+#: builtin/clean.c:721
+msgid "Select items to delete"
+msgstr "Wählen Sie Einträge zum Löschen"
+
+#. TRANSLATORS: Make sure to keep [y/N] as is
+#: builtin/clean.c:762
+#, c-format
+msgid "Remove %s [y/N]? "
+msgstr "'%s' löschen [y/N]? "
+
+#: builtin/clean.c:795
+msgid ""
+"clean               - start cleaning\n"
+"filter by pattern   - exclude items from deletion\n"
+"select by numbers   - select items to be deleted by numbers\n"
+"ask each            - confirm each deletion (like \"rm -i\")\n"
+"quit                - stop cleaning\n"
+"help                - this screen\n"
+"?                   - help for prompt selection"
+msgstr ""
+"clean               - Clean starten\n"
+"filter by pattern   - Einträge von Löschung ausschließen\n"
+"select by numbers   - Auswahl von Einträgen über Nummern\n"
+"ask each            - jede Löschung bestätigen (wie \"rm -i\")\n"
+"quit                - Clean beenden\n"
+"help                - diese Meldung anzeigen\n"
+"?                   - Hilfe zur Auswahl mittels Eingabe anzeigen"
+
+#: builtin/clean.c:831
+msgid "Would remove the following item:"
+msgid_plural "Would remove the following items:"
+msgstr[0] "Würde das folgende Element entfernen:"
+msgstr[1] "Würde die folgenden Elemente entfernen:"
+
+#: builtin/clean.c:847
+msgid "No more files to clean, exiting."
+msgstr "Keine Dateien mehr zum Löschen, beende."
+
+#: builtin/clean.c:909
+msgid "do not print names of files removed"
+msgstr "keine Namen von gelöschten Dateien ausgeben"
+
+#: builtin/clean.c:911
+msgid "force"
+msgstr "Aktion erzwingen"
+
+#: builtin/clean.c:912
+msgid "interactive cleaning"
+msgstr "interaktives Clean"
+
+#: builtin/clean.c:914
+msgid "remove whole directories"
+msgstr "ganze Verzeichnisse löschen"
+
+#: builtin/clean.c:915 builtin/describe.c:548 builtin/describe.c:550
+#: builtin/grep.c:901 builtin/log.c:177 builtin/log.c:179
+#: builtin/ls-files.c:557 builtin/name-rev.c:464 builtin/name-rev.c:466
+#: builtin/show-ref.c:179
+msgid "pattern"
+msgstr "Muster"
+
+#: builtin/clean.c:916
+msgid "add <pattern> to ignore rules"
+msgstr "<Muster> zu den Regeln für ignorierte Pfade hinzufügen"
+
+#: builtin/clean.c:917
+msgid "remove ignored files, too"
+msgstr "auch ignorierte Dateien löschen"
+
+#: builtin/clean.c:919
+msgid "remove only ignored files"
+msgstr "nur ignorierte Dateien löschen"
+
+#: builtin/clean.c:937
+msgid "-x and -X cannot be used together"
+msgstr "Die Optionen -x und -X können nicht gemeinsam verwendet werden."
+
+#: builtin/clean.c:941
+msgid ""
+"clean.requireForce set to true and neither -i, -n, nor -f given; refusing to "
+"clean"
+msgstr ""
+"clean.requireForce auf \"true\" gesetzt und weder -i, -n noch -f gegeben; "
+"\"clean\" verweigert"
+
+#: builtin/clean.c:944
+msgid ""
+"clean.requireForce defaults to true and neither -i, -n, nor -f given; "
+"refusing to clean"
+msgstr ""
+"clean.requireForce standardmäßig auf \"true\" gesetzt und weder -i, -n noch -"
+"f gegeben; \"clean\" verweigert"
+
+#: builtin/clone.c:45
+msgid "git clone [<options>] [--] <repo> [<dir>]"
+msgstr "git clone [<Optionen>] [--] <Repository> [<Verzeichnis>]"
+
+#: builtin/clone.c:93
+msgid "don't create a checkout"
+msgstr "kein Auschecken"
+
+#: builtin/clone.c:94 builtin/clone.c:96 builtin/init-db.c:489
+msgid "create a bare repository"
+msgstr "ein Bare-Repository erstellen"
+
+#: builtin/clone.c:98
+msgid "create a mirror repository (implies bare)"
+msgstr "ein Spiegelarchiv erstellen (impliziert --bare)"
+
+#: builtin/clone.c:100
+msgid "to clone from a local repository"
+msgstr "von einem lokalen Repository klonen"
+
+#: builtin/clone.c:102
+msgid "don't use local hardlinks, always copy"
+msgstr "lokal keine harten Verweise verwenden, immer Kopien"
+
+#: builtin/clone.c:104
+msgid "setup as shared repository"
+msgstr "als verteiltes Repository einrichten"
+
+#: builtin/clone.c:107
+msgid "pathspec"
+msgstr "Pfadspezifikation"
+
+#: builtin/clone.c:107
+msgid "initialize submodules in the clone"
+msgstr "Submodule im Klon initialisieren"
+
+#: builtin/clone.c:110
+msgid "number of submodules cloned in parallel"
+msgstr "Anzahl der parallel zu klonenden Submodule"
+
+#: builtin/clone.c:111 builtin/init-db.c:486
+msgid "template-directory"
+msgstr "Vorlagenverzeichnis"
+
+#: builtin/clone.c:112 builtin/init-db.c:487
+msgid "directory from which templates will be used"
+msgstr "Verzeichnis, von welchem die Vorlagen verwendet werden"
+
+#: builtin/clone.c:114 builtin/clone.c:116 builtin/submodule--helper.c:1392
+#: builtin/submodule--helper.c:1885
+msgid "reference repository"
+msgstr "Repository referenzieren"
+
+#: builtin/clone.c:118 builtin/submodule--helper.c:1394
+#: builtin/submodule--helper.c:1887
+msgid "use --reference only while cloning"
+msgstr "--reference nur während des Klonens benutzen"
+
+#: builtin/clone.c:119 builtin/column.c:27 builtin/merge-file.c:46
+#: builtin/pack-objects.c:3294 builtin/repack.c:327
+msgid "name"
+msgstr "Name"
+
+#: builtin/clone.c:120
+msgid "use <name> instead of 'origin' to track upstream"
+msgstr "<Name> statt 'origin' für Upstream-Repository verwenden"
+
+#: builtin/clone.c:122
+msgid "checkout <branch> instead of the remote's HEAD"
+msgstr "<Branch> auschecken, anstatt HEAD des Remote-Repositories"
+
+#: builtin/clone.c:124
+msgid "path to git-upload-pack on the remote"
+msgstr "Pfad zu \"git-upload-pack\" auf der Gegenseite"
+
+#: builtin/clone.c:125 builtin/fetch.c:168 builtin/grep.c:840
+#: builtin/pull.c:227
+msgid "depth"
+msgstr "Tiefe"
+
+#: builtin/clone.c:126
+msgid "create a shallow clone of that depth"
+msgstr ""
+"einen Klon mit unvollständiger Historie (shallow) in dieser Tiefe erstellen"
+
+#: builtin/clone.c:127 builtin/fetch.c:170 builtin/pack-objects.c:3283
+msgid "time"
+msgstr "Zeit"
+
+#: builtin/clone.c:128
+msgid "create a shallow clone since a specific time"
+msgstr ""
+"einen Klon mit unvollständiger Historie (shallow) seit einer bestimmten "
+"Zeit\n"
+"erstellen"
+
+#: builtin/clone.c:129 builtin/fetch.c:172 builtin/fetch.c:195
+#: builtin/rebase.c:1445
+msgid "revision"
+msgstr "Commit"
+
+#: builtin/clone.c:130 builtin/fetch.c:173
+msgid "deepen history of shallow clone, excluding rev"
+msgstr ""
+"die Historie eines Klons mit unvollständiger Historie (shallow) mittels\n"
+"Ausschluss eines Commits vertiefen"
+
+#: builtin/clone.c:132
+msgid "clone only one branch, HEAD or --branch"
+msgstr "nur einen Branch klonen, HEAD oder --branch"
+
+#: builtin/clone.c:134
+msgid "don't clone any tags, and make later fetches not to follow them"
+msgstr "keine Tags klonen, und auch bei späteren Abrufen nicht beachten"
+
+#: builtin/clone.c:136
+msgid "any cloned submodules will be shallow"
+msgstr "jedes geklonte Submodul mit unvollständiger Historie (shallow)"
+
+#: builtin/clone.c:137 builtin/init-db.c:495
+msgid "gitdir"
+msgstr ".git-Verzeichnis"
+
+#: builtin/clone.c:138 builtin/init-db.c:496
+msgid "separate git dir from working tree"
+msgstr "Git-Verzeichnis vom Arbeitsverzeichnis separieren"
+
+#: builtin/clone.c:139
+msgid "key=value"
+msgstr "Schlüssel=Wert"
+
+#: builtin/clone.c:140
+msgid "set config inside the new repository"
+msgstr "Konfiguration innerhalb des neuen Repositories setzen"
+
+#: builtin/clone.c:142 builtin/fetch.c:190 builtin/ls-remote.c:76
+#: builtin/push.c:573 builtin/send-pack.c:172
+msgid "server-specific"
+msgstr "serverspezifisch"
+
+#: builtin/clone.c:142 builtin/fetch.c:190 builtin/ls-remote.c:76
+#: builtin/push.c:573 builtin/send-pack.c:173
+msgid "option to transmit"
+msgstr "Option übertragen"
+
+#: builtin/clone.c:143 builtin/fetch.c:191 builtin/pull.c:240
+#: builtin/push.c:574
+msgid "use IPv4 addresses only"
+msgstr "nur IPv4-Adressen benutzen"
+
+#: builtin/clone.c:145 builtin/fetch.c:193 builtin/pull.c:243
+#: builtin/push.c:576
+msgid "use IPv6 addresses only"
+msgstr "nur IPv6-Adressen benutzen"
+
+#: builtin/clone.c:149
+msgid "any cloned submodules will use their remote-tracking branch"
+msgstr "jedes geklonte Submodul nutzt seinen Remote-Tracking-Branch"
+
+#: builtin/clone.c:151
+msgid "initialize sparse-checkout file to include only files at root"
+msgstr ""
+"Initialisiere Datei für partiellen Checkout, um nur Dateien im\n"
+"Root-Verzeichnis einzubeziehen"
+
+#: builtin/clone.c:287
+msgid ""
+"No directory name could be guessed.\n"
+"Please specify a directory on the command line"
+msgstr ""
+"Konnte keinen Verzeichnisnamen erraten.\n"
+"Bitte geben Sie ein Verzeichnis auf der Befehlszeile an."
+
+#: builtin/clone.c:340
+#, c-format
+msgid "info: Could not add alternate for '%s': %s\n"
+msgstr "info: Konnte Alternative für '%s' nicht hinzufügen: %s\n"
+
+#: builtin/clone.c:413
+#, c-format
+msgid "%s exists and is not a directory"
+msgstr "%s existiert und ist kein Verzeichnis"
+
+#: builtin/clone.c:430
+#, c-format
+msgid "failed to start iterator over '%s'"
+msgstr "Fehler beim Starten der Iteration über '%s'"
+
+#: builtin/clone.c:460
+#, c-format
+msgid "failed to create link '%s'"
+msgstr "Konnte Verweis '%s' nicht erstellen"
+
+#: builtin/clone.c:464
+#, c-format
+msgid "failed to copy file to '%s'"
+msgstr "Konnte Datei nicht nach '%s' kopieren"
+
+#: builtin/clone.c:469
+#, c-format
+msgid "failed to iterate over '%s'"
+msgstr "Fehler beim Iterieren über '%s'"
+
+#: builtin/clone.c:494
+#, c-format
+msgid "done.\n"
+msgstr "Fertig.\n"
+
+#: builtin/clone.c:508
+msgid ""
+"Clone succeeded, but checkout failed.\n"
+"You can inspect what was checked out with 'git status'\n"
+"and retry with 'git restore --source=HEAD :/'\n"
+msgstr ""
+"Klonen erfolgreich, Auschecken ist aber fehlgeschlagen.\n"
+"Sie können mit 'git status' prüfen, was ausgecheckt worden ist\n"
+"und das Auschecken mit 'git restore --source=HEAD :/' erneut versuchen.\n"
+
+#: builtin/clone.c:585
+#, c-format
+msgid "Could not find remote branch %s to clone."
+msgstr "Konnte zu klonenden Remote-Branch %s nicht finden."
+
+#: builtin/clone.c:704
+#, c-format
+msgid "unable to update %s"
+msgstr "kann %s nicht aktualisieren"
+
+#: builtin/clone.c:752
+msgid "failed to initialize sparse-checkout"
+msgstr "Fehler beim Initialisieren vom partiellen Checkout."
+
+#: builtin/clone.c:775
+msgid "remote HEAD refers to nonexistent ref, unable to checkout.\n"
+msgstr ""
+"Externer HEAD bezieht sich auf eine nicht existierende Referenz und kann "
+"nicht ausgecheckt werden.\n"
+
+#: builtin/clone.c:806
+msgid "unable to checkout working tree"
+msgstr "Arbeitsverzeichnis konnte nicht ausgecheckt werden"
+
+#: builtin/clone.c:856
+msgid "unable to write parameters to config file"
+msgstr "konnte Parameter nicht in Konfigurationsdatei schreiben"
+
+#: builtin/clone.c:919
+msgid "cannot repack to clean up"
+msgstr "Kann \"repack\" zum Aufräumen nicht aufrufen"
+
+#: builtin/clone.c:921
+msgid "cannot unlink temporary alternates file"
+msgstr "Kann temporäre \"alternates\"-Datei nicht entfernen"
+
+#: builtin/clone.c:959 builtin/receive-pack.c:1948
+msgid "Too many arguments."
+msgstr "Zu viele Argumente."
+
+#: builtin/clone.c:963
+msgid "You must specify a repository to clone."
+msgstr "Sie müssen ein Repository zum Klonen angeben."
+
+#: builtin/clone.c:976
+#, c-format
+msgid "--bare and --origin %s options are incompatible."
+msgstr "Die Optionen --bare und --origin %s sind inkompatibel."
+
+#: builtin/clone.c:979
+msgid "--bare and --separate-git-dir are incompatible."
+msgstr "Die Optionen --bare und --separate-git-dir sind inkompatibel."
+
+#: builtin/clone.c:992
+#, c-format
+msgid "repository '%s' does not exist"
+msgstr "Repository '%s' existiert nicht."
+
+#: builtin/clone.c:998 builtin/fetch.c:1787
+#, c-format
+msgid "depth %s is not a positive number"
+msgstr "Tiefe %s ist keine positive Zahl"
+
+#: builtin/clone.c:1008
+#, c-format
+msgid "destination path '%s' already exists and is not an empty directory."
+msgstr "Zielpfad '%s' existiert bereits und ist kein leeres Verzeichnis."
+
+#: builtin/clone.c:1018
+#, c-format
+msgid "working tree '%s' already exists."
+msgstr "Arbeitsverzeichnis '%s' existiert bereits."
+
+#: builtin/clone.c:1033 builtin/clone.c:1054 builtin/difftool.c:271
+#: builtin/log.c:1866 builtin/worktree.c:302 builtin/worktree.c:334
+#, c-format
+msgid "could not create leading directories of '%s'"
+msgstr "Konnte führende Verzeichnisse von '%s' nicht erstellen."
+
+#: builtin/clone.c:1038
+#, c-format
+msgid "could not create work tree dir '%s'"
+msgstr "Konnte Arbeitsverzeichnis '%s' nicht erstellen"
+
+#: builtin/clone.c:1058
+#, c-format
+msgid "Cloning into bare repository '%s'...\n"
+msgstr "Klone in Bare-Repository '%s' ...\n"
+
+#: builtin/clone.c:1060
+#, c-format
+msgid "Cloning into '%s'...\n"
+msgstr "Klone nach '%s' ...\n"
+
+#: builtin/clone.c:1084
+msgid ""
+"clone --recursive is not compatible with both --reference and --reference-if-"
+"able"
+msgstr ""
+"'clone --recursive' ist nicht kompatibel mit --reference und --reference-if-"
+"able"
+
+#: builtin/clone.c:1148
+msgid "--depth is ignored in local clones; use file:// instead."
+msgstr ""
+"Die Option --depth wird in lokalen Klonen ignoriert; benutzen Sie "
+"stattdessen file://"
+
+#: builtin/clone.c:1150
+msgid "--shallow-since is ignored in local clones; use file:// instead."
+msgstr ""
+"--shallow-since wird in lokalen Klonen ignoriert; benutzen Sie stattdessen "
+"file://"
+
+#: builtin/clone.c:1152
+msgid "--shallow-exclude is ignored in local clones; use file:// instead."
+msgstr ""
+"--shallow-exclude wird in lokalen Klonen ignoriert; benutzen Sie stattdessen "
+"file://"
+
+#: builtin/clone.c:1154
+msgid "--filter is ignored in local clones; use file:// instead."
+msgstr ""
+"--filter wird in lokalen Klonen ignoriert; benutzen Sie stattdessen file://"
+
+#: builtin/clone.c:1157
+msgid "source repository is shallow, ignoring --local"
+msgstr ""
+"Quelle ist ein Repository mit unvollständiger Historie (shallow),\n"
+"ignoriere --local"
+
+#: builtin/clone.c:1162
+msgid "--local is ignored"
+msgstr "--local wird ignoriert"
+
+#: builtin/clone.c:1237 builtin/clone.c:1245
+#, c-format
+msgid "Remote branch %s not found in upstream %s"
+msgstr "Remote-Branch %s nicht im Upstream-Repository %s gefunden"
+
+#: builtin/clone.c:1248
+msgid "You appear to have cloned an empty repository."
+msgstr "Sie scheinen ein leeres Repository geklont zu haben."
+
+#: builtin/column.c:10
+msgid "git column [<options>]"
+msgstr "git column [<Optionen>]"
+
+#: builtin/column.c:27
+msgid "lookup config vars"
+msgstr "Konfigurationsvariablen nachschlagen"
+
+#: builtin/column.c:28 builtin/column.c:29
+msgid "layout to use"
+msgstr "zu verwendende Anordnung"
+
+#: builtin/column.c:30
+msgid "Maximum width"
+msgstr "maximale Breite"
+
+#: builtin/column.c:31
+msgid "Padding space on left border"
+msgstr "Abstand zum linken Rand"
+
+#: builtin/column.c:32
+msgid "Padding space on right border"
+msgstr "Abstand zum rechten Rand"
+
+#: builtin/column.c:33
+msgid "Padding space between columns"
+msgstr "Abstand zwischen Spalten"
+
+#: builtin/column.c:51
+msgid "--command must be the first argument"
+msgstr "Die Option --command muss an erster Stelle stehen."
+
+#: builtin/commit-tree.c:18
+msgid ""
+"git commit-tree [(-p <parent>)...] [-S[<keyid>]] [(-m <message>)...] [(-F "
+"<file>)...] <tree>"
+msgstr ""
+"git commit-tree [(-p <Eltern-Commit>)...] [-S[<Key-ID>]] [(-m "
+"<Nachricht>)...] [(-F <Datei>)...] <Tree-Objekt>"
+
+#: builtin/commit-tree.c:31
+#, c-format
+msgid "duplicate parent %s ignored"
+msgstr "doppelter Vorgänger %s ignoriert"
+
+#: builtin/commit-tree.c:56 builtin/commit-tree.c:136 builtin/log.c:526
+#, c-format
+msgid "not a valid object name %s"
+msgstr "Kein gültiger Objektname: %s"
+
+#: builtin/commit-tree.c:93
+#, c-format
+msgid "git commit-tree: failed to open '%s'"
+msgstr "git commit-tree: Fehler beim Öffnen von '%s'"
+
+#: builtin/commit-tree.c:96
+#, c-format
+msgid "git commit-tree: failed to read '%s'"
+msgstr "git commit-tree: Fehler beim Lesen von '%s'"
+
+#: builtin/commit-tree.c:98
+#, c-format
+msgid "git commit-tree: failed to close '%s'"
+msgstr "git commit-tree: Fehler beim Schließen von '%s'"
+
+#: builtin/commit-tree.c:111
+msgid "parent"
+msgstr "Eltern-Commit"
+
+#: builtin/commit-tree.c:112
+msgid "id of a parent commit object"
+msgstr "ID eines Eltern-Commit-Objektes."
+
+#: builtin/commit-tree.c:114 builtin/commit.c:1496 builtin/merge.c:270
+#: builtin/notes.c:409 builtin/notes.c:575 builtin/stash.c:1469
+#: builtin/tag.c:412
+msgid "message"
+msgstr "Beschreibung"
+
+#: builtin/commit-tree.c:115 builtin/commit.c:1496
+msgid "commit message"
+msgstr "Commit-Beschreibung"
+
+#: builtin/commit-tree.c:118
+msgid "read commit log message from file"
+msgstr "Commit-Beschreibung von Datei lesen"
+
+#: builtin/commit-tree.c:121 builtin/commit.c:1508 builtin/merge.c:287
+#: builtin/pull.c:195 builtin/revert.c:118
+msgid "GPG sign commit"
+msgstr "Commit mit GPG signieren"
+
+#: builtin/commit-tree.c:133
+msgid "must give exactly one tree"
+msgstr "Brauche genau ein Tree-Objekt."
+
+#: builtin/commit-tree.c:140
+msgid "git commit-tree: failed to read"
+msgstr "git commit-tree: Fehler beim Lesen"
+
+#: builtin/commit.c:41
+msgid "git commit [<options>] [--] <pathspec>..."
+msgstr "git commit [<Optionen>] [--] <Pfadspezifikation>..."
+
+#: builtin/commit.c:46
+msgid "git status [<options>] [--] <pathspec>..."
+msgstr "git status [<Optionen>] [--] <Pfadspezifikation>..."
+
+#: builtin/commit.c:51
+msgid ""
+"You asked to amend the most recent commit, but doing so would make\n"
+"it empty. You can repeat your command with --allow-empty, or you can\n"
+"remove the commit entirely with \"git reset HEAD^\".\n"
+msgstr ""
+"Sie fragten den jüngsten Commit nachzubessern, aber das würde diesen leer\n"
+"machen. Sie können Ihren Befehl mit --allow-empty wiederholen, oder diesen\n"
+"Commit mit \"git reset HEAD^\" vollständig entfernen.\n"
+
+#: builtin/commit.c:56
+msgid ""
+"The previous cherry-pick is now empty, possibly due to conflict resolution.\n"
+"If you wish to commit it anyway, use:\n"
+"\n"
+"    git commit --allow-empty\n"
+"\n"
+msgstr ""
+"Der letzte \"cherry-pick\" ist jetzt leer, möglicherweise durch eine "
+"Konfliktauflösung.\n"
+"Wenn Sie dies trotzdem committen wollen, benutzen Sie:\n"
+"\n"
+"    git commit --allow-empty\n"
+"\n"
+
+#: builtin/commit.c:63
+msgid "Otherwise, please use 'git cherry-pick --skip'\n"
+msgstr "Andernfalls benutzen Sie bitte 'git cherry-pick --skip'\n"
+
+#: builtin/commit.c:66
+msgid ""
+"and then use:\n"
+"\n"
+"    git cherry-pick --continue\n"
+"\n"
+"to resume cherry-picking the remaining commits.\n"
+"If you wish to skip this commit, use:\n"
+"\n"
+"    git cherry-pick --skip\n"
+"\n"
+msgstr ""
+"Und dann nutzen Sie:\n"
+"\n"
+"    git cherry-pick --continue\n"
+"\n"
+"um das Cherry-Picking mit den übrigen Commits fortzusetzen.\n"
+"Wenn dieser Commit übersprungen werden soll, nutzen Sie:\n"
+"\n"
+"    git cherry-pick --skip\n"
+"\n"
+
+#: builtin/commit.c:315
+msgid "failed to unpack HEAD tree object"
+msgstr "Fehler beim Entpacken des Tree-Objektes von HEAD."
+
+#: builtin/commit.c:351
+msgid "--pathspec-from-file with -a does not make sense"
+msgstr "Option --pathspec-from-file mit -a ist nicht sinnvoll."
+
+#: builtin/commit.c:364
+msgid "No paths with --include/--only does not make sense."
+msgstr "Keine Pfade mit der Option --include/--only ist nicht sinnvoll."
+
+#: builtin/commit.c:376
+msgid "unable to create temporary index"
+msgstr "Konnte temporären Index nicht erstellen."
+
+#: builtin/commit.c:382
+msgid "interactive add failed"
+msgstr "interaktives Hinzufügen fehlgeschlagen"
+
+#: builtin/commit.c:396
+msgid "unable to update temporary index"
+msgstr "Konnte temporären Index nicht aktualisieren."
+
+#: builtin/commit.c:398
+msgid "Failed to update main cache tree"
+msgstr "Konnte Haupt-Cache-Verzeichnis nicht aktualisieren"
+
+#: builtin/commit.c:423 builtin/commit.c:446 builtin/commit.c:492
+msgid "unable to write new_index file"
+msgstr "Konnte new_index Datei nicht schreiben"
+
+#: builtin/commit.c:475
+msgid "cannot do a partial commit during a merge."
+msgstr "Kann keinen Teil-Commit durchführen, während ein Merge im Gange ist."
+
+#: builtin/commit.c:477
+msgid "cannot do a partial commit during a cherry-pick."
+msgstr ""
+"Kann keinen Teil-Commit durchführen, während \"cherry-pick\" im Gange ist."
+
+#: builtin/commit.c:485
+msgid "cannot read the index"
+msgstr "Kann Index nicht lesen"
+
+#: builtin/commit.c:504
+msgid "unable to write temporary index file"
+msgstr "Konnte temporäre Index-Datei nicht schreiben."
+
+#: builtin/commit.c:602
+#, c-format
+msgid "commit '%s' lacks author header"
+msgstr "Commit '%s' fehlt Autor-Kopfbereich"
+
+#: builtin/commit.c:604
+#, c-format
+msgid "commit '%s' has malformed author line"
+msgstr "Commit '%s' hat fehlerhafte Autor-Zeile"
+
+#: builtin/commit.c:623
+msgid "malformed --author parameter"
+msgstr "Fehlerhafter --author Parameter"
+
+#: builtin/commit.c:676
+msgid ""
+"unable to select a comment character that is not used\n"
+"in the current commit message"
+msgstr ""
+"Konnte kein Kommentar-Zeichen auswählen, das nicht in\n"
+"der aktuellen Commit-Beschreibung verwendet wird."
+
+#: builtin/commit.c:714 builtin/commit.c:747 builtin/commit.c:1092
+#, c-format
+msgid "could not lookup commit %s"
+msgstr "Konnte Commit %s nicht nachschlagen"
+
+#: builtin/commit.c:726 builtin/shortlog.c:319
+#, c-format
+msgid "(reading log message from standard input)\n"
+msgstr "(lese Log-Nachricht von Standard-Eingabe)\n"
+
+#: builtin/commit.c:728
+msgid "could not read log from standard input"
+msgstr "Konnte Log nicht von Standard-Eingabe lesen."
+
+#: builtin/commit.c:732
+#, c-format
+msgid "could not read log file '%s'"
+msgstr "Konnte Log-Datei '%s' nicht lesen"
+
+#: builtin/commit.c:763 builtin/commit.c:779
+msgid "could not read SQUASH_MSG"
+msgstr "Konnte SQUASH_MSG nicht lesen"
+
+#: builtin/commit.c:770
+msgid "could not read MERGE_MSG"
+msgstr "Konnte MERGE_MSG nicht lesen"
+
+#: builtin/commit.c:830
+msgid "could not write commit template"
+msgstr "Konnte Commit-Vorlage nicht schreiben"
+
+#: builtin/commit.c:849
+#, c-format
+msgid ""
+"\n"
+"It looks like you may be committing a merge.\n"
+"If this is not correct, please remove the file\n"
+"\t%s\n"
+"and try again.\n"
+msgstr ""
+"\n"
+"Es sieht so aus, als committen Sie einen Merge.\n"
+"Falls das nicht korrekt ist, löschen Sie bitte die Datei\n"
+"\t%s\n"
+"und versuchen Sie es erneut.\n"
+
+#: builtin/commit.c:854
+#, c-format
+msgid ""
+"\n"
+"It looks like you may be committing a cherry-pick.\n"
+"If this is not correct, please remove the file\n"
+"\t%s\n"
+"and try again.\n"
+msgstr ""
+"\n"
+"Es sieht so aus, als committen Sie einen \"cherry-pick\".\n"
+"Falls das nicht korrekt ist, löschen Sie bitte die Datei\n"
+"\t%s\n"
+"und versuchen Sie es erneut.\n"
+
+#: builtin/commit.c:867
+#, c-format
+msgid ""
+"Please enter the commit message for your changes. Lines starting\n"
+"with '%c' will be ignored, and an empty message aborts the commit.\n"
+msgstr ""
+"Bitte geben Sie eine Commit-Beschreibung für Ihre Änderungen ein. Zeilen,\n"
+"die mit '%c' beginnen, werden ignoriert, und eine leere Beschreibung\n"
+"bricht den Commit ab.\n"
+
+#: builtin/commit.c:875
+#, c-format
+msgid ""
+"Please enter the commit message for your changes. Lines starting\n"
+"with '%c' will be kept; you may remove them yourself if you want to.\n"
+"An empty message aborts the commit.\n"
+msgstr ""
+"Bitte geben Sie eine Commit-Beschreibung für Ihre Änderungen ein. Zeilen, "
+"die\n"
+"mit '%c' beginnen, werden beibehalten; wenn Sie möchten, können Sie diese "
+"entfernen.\n"
+"Eine leere Beschreibung bricht den Commit ab.\n"
+
+#: builtin/commit.c:892
+#, c-format
+msgid "%sAuthor:    %.*s <%.*s>"
+msgstr "%sAutor:           %.*s <%.*s>"
+
+#: builtin/commit.c:900
+#, c-format
+msgid "%sDate:      %s"
+msgstr "%sDatum:            %s"
+
+#: builtin/commit.c:907
+#, c-format
+msgid "%sCommitter: %.*s <%.*s>"
+msgstr "%sCommit-Ersteller: %.*s <%.*s>"
+
+#: builtin/commit.c:925
+msgid "Cannot read index"
+msgstr "Kann Index nicht lesen"
+
+#: builtin/commit.c:992
+msgid "Error building trees"
+msgstr "Fehler beim Erzeugen der \"Tree\"-Objekte"
+
+#: builtin/commit.c:1006 builtin/tag.c:275
+#, c-format
+msgid "Please supply the message using either -m or -F option.\n"
+msgstr ""
+"Bitte liefern Sie eine Beschreibung entweder mit der Option -m oder -F.\n"
+
+#: builtin/commit.c:1050
+#, c-format
+msgid "--author '%s' is not 'Name <email>' and matches no existing author"
+msgstr ""
+"--author '%s' ist nicht im Format 'Name <E-Mail>' und stimmt mit keinem "
+"vorhandenen Autor überein"
+
+#: builtin/commit.c:1064
+#, c-format
+msgid "Invalid ignored mode '%s'"
+msgstr "Ungültiger ignored-Modus '%s'."
+
+#: builtin/commit.c:1082 builtin/commit.c:1322
+#, c-format
+msgid "Invalid untracked files mode '%s'"
+msgstr "Ungültiger Modus '%s' für unversionierte Dateien"
+
+#: builtin/commit.c:1122
+msgid "--long and -z are incompatible"
+msgstr "Die Optionen --long und -z sind inkompatibel."
+
+#: builtin/commit.c:1166
+msgid "Using both --reset-author and --author does not make sense"
+msgstr ""
+"Die Optionen --reset-author und --author können nicht gemeinsam verwendet "
+"werden."
+
+#: builtin/commit.c:1175
+msgid "You have nothing to amend."
+msgstr "Sie haben nichts für \"--amend\"."
+
+#: builtin/commit.c:1178
+msgid "You are in the middle of a merge -- cannot amend."
+msgstr "Ein Merge ist im Gange -- kann \"--amend\" nicht ausführen."
+
+#: builtin/commit.c:1180
+msgid "You are in the middle of a cherry-pick -- cannot amend."
+msgstr "\"cherry-pick\" ist im Gange -- kann \"--amend\" nicht ausführen."
+
+#: builtin/commit.c:1183
+msgid "Options --squash and --fixup cannot be used together"
+msgstr ""
+"Die Optionen --squash und --fixup können nicht gemeinsam verwendet werden."
+
+#: builtin/commit.c:1193
+msgid "Only one of -c/-C/-F/--fixup can be used."
+msgstr "Es kann nur eine Option von -c/-C/-F/--fixup verwendet werden."
+
+#: builtin/commit.c:1195
+msgid "Option -m cannot be combined with -c/-C/-F."
+msgstr "Die Option -m kann nicht mit -c/-C/-F kombiniert werden."
+
+#: builtin/commit.c:1203
+msgid "--reset-author can be used only with -C, -c or --amend."
+msgstr ""
+"Die Option --reset--author kann nur mit -C, -c oder --amend verwendet werden."
+
+#: builtin/commit.c:1220
+msgid "Only one of --include/--only/--all/--interactive/--patch can be used."
+msgstr ""
+"Es kann nur eine Option von --include/--only/--all/--interactive/--patch "
+"verwendet werden."
+
+#: builtin/commit.c:1226
+#, c-format
+msgid "paths '%s ...' with -a does not make sense"
+msgstr "Pfade '%s ...' mit -a sind nicht sinnvoll"
+
+#: builtin/commit.c:1357 builtin/commit.c:1519
+msgid "show status concisely"
+msgstr "Status im Kurzformat anzeigen"
+
+#: builtin/commit.c:1359 builtin/commit.c:1521
+msgid "show branch information"
+msgstr "Branchinformationen anzeigen"
+
+#: builtin/commit.c:1361
+msgid "show stash information"
+msgstr "Stashinformationen anzeigen"
+
+#: builtin/commit.c:1363 builtin/commit.c:1523
+msgid "compute full ahead/behind values"
+msgstr "voraus/hinterher-Werte berechnen"
+
+#: builtin/commit.c:1365
+msgid "version"
+msgstr "Version"
+
+#: builtin/commit.c:1365 builtin/commit.c:1525 builtin/push.c:549
+#: builtin/worktree.c:650
+msgid "machine-readable output"
+msgstr "maschinenlesbare Ausgabe"
+
+#: builtin/commit.c:1368 builtin/commit.c:1527
+msgid "show status in long format (default)"
+msgstr "Status im Langformat anzeigen (Standard)"
+
+#: builtin/commit.c:1371 builtin/commit.c:1530
+msgid "terminate entries with NUL"
+msgstr "Einträge mit NUL-Zeichen abschließen"
+
+#: builtin/commit.c:1373 builtin/commit.c:1377 builtin/commit.c:1533
+#: builtin/fast-export.c:1153 builtin/fast-export.c:1156
+#: builtin/fast-export.c:1159 builtin/rebase.c:1525 parse-options.h:336
+msgid "mode"
+msgstr "Modus"
+
+#: builtin/commit.c:1374 builtin/commit.c:1533
+msgid "show untracked files, optional modes: all, normal, no. (Default: all)"
+msgstr ""
+"unversionierte Dateien anzeigen, optionale Modi: all, normal, no. (Standard: "
+"all)"
+
+#: builtin/commit.c:1378
+msgid ""
+"show ignored files, optional modes: traditional, matching, no. (Default: "
+"traditional)"
+msgstr ""
+"ignorierte Dateien anzeigen, optionale Modi: traditional, matching, no. "
+"(Standard: traditional)"
+
+#: builtin/commit.c:1380 parse-options.h:192
+msgid "when"
+msgstr "wann"
+
+#: builtin/commit.c:1381
+msgid ""
+"ignore changes to submodules, optional when: all, dirty, untracked. "
+"(Default: all)"
+msgstr ""
+"Änderungen in Submodulen ignorieren, optional wenn: all, dirty, untracked. "
+"(Standard: all)"
+
+#: builtin/commit.c:1383
+msgid "list untracked files in columns"
+msgstr "unversionierte Dateien in Spalten auflisten"
+
+#: builtin/commit.c:1384
+msgid "do not detect renames"
+msgstr "keine Umbenennungen ermitteln"
+
+#: builtin/commit.c:1386
+msgid "detect renames, optionally set similarity index"
+msgstr "Umbenennungen erkennen, optional Index für Gleichheit setzen"
+
+#: builtin/commit.c:1406
+msgid "Unsupported combination of ignored and untracked-files arguments"
+msgstr ""
+"Nicht unterstützte Kombination von ignored und untracked-files Argumenten."
+
+#: builtin/commit.c:1489
+msgid "suppress summary after successful commit"
+msgstr "Zusammenfassung nach erfolgreichem Commit unterdrücken"
+
+#: builtin/commit.c:1490
+msgid "show diff in commit message template"
+msgstr "Unterschiede in Commit-Beschreibungsvorlage anzeigen"
+
+#: builtin/commit.c:1492
+msgid "Commit message options"
+msgstr "Optionen für Commit-Beschreibung"
+
+#: builtin/commit.c:1493 builtin/merge.c:274 builtin/tag.c:414
+msgid "read message from file"
+msgstr "Beschreibung von Datei lesen"
+
+#: builtin/commit.c:1494
+msgid "author"
+msgstr "Autor"
+
+#: builtin/commit.c:1494
+msgid "override author for commit"
+msgstr "Autor eines Commits überschreiben"
+
+#: builtin/commit.c:1495 builtin/gc.c:538
+msgid "date"
+msgstr "Datum"
+
+#: builtin/commit.c:1495
+msgid "override date for commit"
+msgstr "Datum eines Commits überschreiben"
+
+#: builtin/commit.c:1497 builtin/commit.c:1498 builtin/commit.c:1499
+#: builtin/commit.c:1500 parse-options.h:328 ref-filter.h:92
+msgid "commit"
+msgstr "Commit"
+
+#: builtin/commit.c:1497
+msgid "reuse and edit message from specified commit"
+msgstr "Beschreibung des angegebenen Commits wiederverwenden und editieren"
+
+#: builtin/commit.c:1498
+msgid "reuse message from specified commit"
+msgstr "Beschreibung des angegebenen Commits wiederverwenden"
+
+#: builtin/commit.c:1499
+msgid "use autosquash formatted message to fixup specified commit"
+msgstr ""
+"eine automatisch zusammengesetzte Beschreibung zum Nachbessern des "
+"angegebenen Commits verwenden"
 
-#: builtin/clean.c:522 git-add--interactive.perl:547
-#: git-add--interactive.perl:552
-#, c-format, perl-format
-msgid "Huh (%s)?\n"
-msgstr "Wie bitte (%s)?\n"
+#: builtin/commit.c:1500
+msgid "use autosquash formatted message to squash specified commit"
+msgstr ""
+"eine automatisch zusammengesetzte Beschreibung beim \"squash\" des "
+"angegebenen Commits verwenden"
 
-#: builtin/clean.c:664
-#, c-format
-msgid "Input ignore patterns>> "
-msgstr "Ignorier-Muster eingeben>> "
+#: builtin/commit.c:1501
+msgid "the commit is authored by me now (used with -C/-c/--amend)"
+msgstr "Sie als Autor des Commits setzen (verwendet mit -C/-c/--amend)"
+
+#: builtin/commit.c:1502 builtin/log.c:1634 builtin/merge.c:289
+#: builtin/pull.c:164 builtin/revert.c:110
+msgid "add Signed-off-by:"
+msgstr "'Signed-off-by:'-Zeile hinzufügen"
+
+#: builtin/commit.c:1503
+msgid "use specified template file"
+msgstr "angegebene Vorlagendatei verwenden"
+
+#: builtin/commit.c:1504
+msgid "force edit of commit"
+msgstr "Bearbeitung des Commits erzwingen"
+
+#: builtin/commit.c:1506
+msgid "include status in commit message template"
+msgstr "Status in die Commit-Beschreibungsvorlage einfügen"
+
+#: builtin/commit.c:1511
+msgid "Commit contents options"
+msgstr "Optionen für Commit-Inhalt"
+
+#: builtin/commit.c:1512
+msgid "commit all changed files"
+msgstr "alle geänderten Dateien committen"
+
+#: builtin/commit.c:1513
+msgid "add specified files to index for commit"
+msgstr "die angegebenen Dateien zusätzlich zum Commit vormerken"
+
+#: builtin/commit.c:1514
+msgid "interactively add files"
+msgstr "interaktives Hinzufügen von Dateien"
+
+#: builtin/commit.c:1515
+msgid "interactively add changes"
+msgstr "interaktives Hinzufügen von Änderungen"
+
+#: builtin/commit.c:1516
+msgid "commit only specified files"
+msgstr "nur die angegebenen Dateien committen"
+
+#: builtin/commit.c:1517
+msgid "bypass pre-commit and commit-msg hooks"
+msgstr "Hooks pre-commit und commit-msg umgehen"
+
+#: builtin/commit.c:1518
+msgid "show what would be committed"
+msgstr "anzeigen, was committet werden würde"
+
+#: builtin/commit.c:1531
+msgid "amend previous commit"
+msgstr "vorherigen Commit ändern"
+
+#: builtin/commit.c:1532
+msgid "bypass post-rewrite hook"
+msgstr "\"post-rewrite hook\" umgehen"
 
-#: builtin/clean.c:701
+#: builtin/commit.c:1539
+msgid "ok to record an empty change"
+msgstr "Aufzeichnung einer leeren Änderung erlauben"
+
+#: builtin/commit.c:1541
+msgid "ok to record a change with an empty message"
+msgstr "Aufzeichnung einer Änderung mit einer leeren Beschreibung erlauben"
+
+#: builtin/commit.c:1614
 #, c-format
-msgid "WARNING: Cannot find items matched by: %s"
-msgstr "WARNUNG: Kann keine Einträge finden die Muster entsprechen: %s"
+msgid "Corrupt MERGE_HEAD file (%s)"
+msgstr "Beschädigte MERGE_HEAD-Datei (%s)"
 
-#: builtin/clean.c:722
-msgid "Select items to delete"
-msgstr "Wählen Sie Einträge zum Löschen"
+#: builtin/commit.c:1621
+msgid "could not read MERGE_MODE"
+msgstr "Konnte MERGE_MODE nicht lesen"
 
-#. TRANSLATORS: Make sure to keep [y/N] as is
-#: builtin/clean.c:763
+#: builtin/commit.c:1640
 #, c-format
-msgid "Remove %s [y/N]? "
-msgstr "'%s' löschen [y/N]? "
+msgid "could not read commit message: %s"
+msgstr "Konnte Commit-Beschreibung nicht lesen: %s"
 
-#: builtin/clean.c:788 git-add--interactive.perl:1710
+#: builtin/commit.c:1647
 #, c-format
-msgid "Bye.\n"
-msgstr "Tschüss.\n"
+msgid "Aborting commit due to empty commit message.\n"
+msgstr "Commit aufgrund leerer Beschreibung abgebrochen.\n"
+
+#: builtin/commit.c:1652
+#, c-format
+msgid "Aborting commit; you did not edit the message.\n"
+msgstr "Commit abgebrochen; Sie haben die Beschreibung nicht editiert.\n"
 
-#: builtin/clean.c:796
+#: builtin/commit.c:1686
 msgid ""
-"clean               - start cleaning\n"
-"filter by pattern   - exclude items from deletion\n"
-"select by numbers   - select items to be deleted by numbers\n"
-"ask each            - confirm each deletion (like \"rm -i\")\n"
-"quit                - stop cleaning\n"
-"help                - this screen\n"
-"?                   - help for prompt selection"
+"repository has been updated, but unable to write\n"
+"new_index file. Check that disk is not full and quota is\n"
+"not exceeded, and then \"git restore --staged :/\" to recover."
 msgstr ""
-"clean               - Clean starten\n"
-"filter by pattern   - Einträge von Löschung ausschließen\n"
-"select by numbers   - Auswahl von Einträgen über Nummern\n"
-"ask each            - jede Löschung bestätigen (wie \"rm -i\")\n"
-"quit                - Clean beenden\n"
-"help                - diese Meldung anzeigen\n"
-"?                   - Hilfe zur Auswahl mittels Eingabe anzeigen"
-
-#: builtin/clean.c:823 git-add--interactive.perl:1786
-msgid "*** Commands ***"
-msgstr "*** Befehle ***"
+"Das Repository wurde aktualisiert, aber die \"new_index\"-Datei\n"
+"konnte nicht geschrieben werden. Prüfen Sie, dass Ihre Festplatte nicht\n"
+"voll und Ihr Kontingent nicht aufgebraucht ist und führen Sie\n"
+"anschließend \"git restore HEAD --staged :/\" zur Wiederherstellung aus."
 
-#: builtin/clean.c:824 git-add--interactive.perl:1783
-msgid "What now"
-msgstr "Was nun"
+#: builtin/commit-graph.c:11 builtin/commit-graph.c:17
+msgid ""
+"git commit-graph verify [--object-dir <objdir>] [--shallow] [--[no-]progress]"
+msgstr ""
+"git commit-graph verify [--object-dir <Objektverzeichnis>] [--shallow] [--"
+"[no-]progress]"
 
-#: builtin/clean.c:832
-msgid "Would remove the following item:"
-msgid_plural "Would remove the following items:"
-msgstr[0] "Würde das folgende Element entfernen:"
-msgstr[1] "Würde die folgenden Elemente entfernen:"
+#: builtin/commit-graph.c:12 builtin/commit-graph.c:22
+msgid ""
+"git commit-graph write [--object-dir <objdir>] [--append|--split] [--"
+"reachable|--stdin-packs|--stdin-commits] [--[no-]progress] <split options>"
+msgstr ""
+"git commit-graph write [--object-dir <Objektverzeichnis>] [--append|split] "
+"[--reachable|--stdin-packs|--stdin-commits] [--[no-]progress] <Split-"
+"Optionen>"
 
-#: builtin/clean.c:848
-msgid "No more files to clean, exiting."
-msgstr "Keine Dateien mehr zum Löschen, beende."
+#: builtin/commit-graph.c:48 builtin/commit-graph.c:103
+#: builtin/commit-graph.c:187 builtin/fetch.c:179 builtin/log.c:1657
+msgid "dir"
+msgstr "Verzeichnis"
 
-#: builtin/clean.c:910
-msgid "do not print names of files removed"
-msgstr "keine Namen von gelöschten Dateien ausgeben"
+#: builtin/commit-graph.c:49 builtin/commit-graph.c:104
+#: builtin/commit-graph.c:188
+msgid "The object directory to store the graph"
+msgstr "Das Objektverzeichnis zum Speichern des Graphen."
 
-#: builtin/clean.c:912
-msgid "force"
-msgstr "Aktion erzwingen"
+#: builtin/commit-graph.c:51
+msgid "if the commit-graph is split, only verify the tip file"
+msgstr ""
+"Wenn der Commit-Graph aufgeteilt ist, nur die Datei an der Spitze überprüfen"
 
-#: builtin/clean.c:913
-msgid "interactive cleaning"
-msgstr "interaktives Clean"
+#: builtin/commit-graph.c:73 t/helper/test-read-graph.c:23
+#, c-format
+msgid "Could not open commit-graph '%s'"
+msgstr "Konnte Commit-Graph '%s' nicht öffnen."
 
-#: builtin/clean.c:915
-msgid "remove whole directories"
-msgstr "ganze Verzeichnisse löschen"
+#: builtin/commit-graph.c:106
+msgid "start walk at all refs"
+msgstr "Durchlauf auf allen Referenzen beginnen"
 
-#: builtin/clean.c:916 builtin/describe.c:533 builtin/describe.c:535
-#: builtin/grep.c:871 builtin/log.c:157 builtin/log.c:159
-#: builtin/ls-files.c:548 builtin/name-rev.c:397 builtin/name-rev.c:399
-#: builtin/show-ref.c:176
-msgid "pattern"
-msgstr "Muster"
+#: builtin/commit-graph.c:108
+msgid "scan pack-indexes listed by stdin for commits"
+msgstr "durch Standard-Eingabe gelistete Pack-Indexe nach Commits scannen"
 
-#: builtin/clean.c:917
-msgid "add <pattern> to ignore rules"
-msgstr "<Muster> zu den Regeln für ignorierte Pfade hinzufügen"
+#: builtin/commit-graph.c:110
+msgid "start walk at commits listed by stdin"
+msgstr "Lauf bei Commits beginnen, die über die Standard-Eingabe gelistet sind"
 
-#: builtin/clean.c:918
-msgid "remove ignored files, too"
-msgstr "auch ignorierte Dateien löschen"
+#: builtin/commit-graph.c:112
+msgid "include all commits already in the commit-graph file"
+msgstr ""
+"alle Commits einschließen, die sich bereits in der Commit-Graph-Datei "
+"befinden"
 
-#: builtin/clean.c:920
-msgid "remove only ignored files"
-msgstr "nur ignorierte Dateien löschen"
+#: builtin/commit-graph.c:115
+msgid "allow writing an incremental commit-graph file"
+msgstr "Erlaube das Schreiben einer inkrementellen Commit-Graph-Datei"
 
-#: builtin/clean.c:938
-msgid "-x and -X cannot be used together"
-msgstr "Die Optionen -x und -X können nicht gemeinsam verwendet werden."
+#: builtin/commit-graph.c:117 builtin/commit-graph.c:121
+msgid "maximum number of commits in a non-base split commit-graph"
+msgstr ""
+"Maximale Anzahl von Commits in einem aufgeteilten Commit-Graph ohne Basis"
 
-#: builtin/clean.c:942
-msgid ""
-"clean.requireForce set to true and neither -i, -n, nor -f given; refusing to "
-"clean"
+#: builtin/commit-graph.c:119
+msgid "maximum ratio between two levels of a split commit-graph"
 msgstr ""
-"clean.requireForce auf \"true\" gesetzt und weder -i, -n noch -f gegeben; "
-"\"clean\" verweigert"
+"Maximales Verhältnis zwischen zwei Ebenen eines aufgeteilten Commit-Graph"
 
-#: builtin/clean.c:945
-msgid ""
-"clean.requireForce defaults to true and neither -i, -n, nor -f given; "
-"refusing to clean"
+#: builtin/commit-graph.c:137
+msgid "use at most one of --reachable, --stdin-commits, or --stdin-packs"
 msgstr ""
-"clean.requireForce standardmäßig auf \"true\" gesetzt und weder -i, -n noch -"
-"f gegeben; \"clean\" verweigert"
+"Benutzen Sie mindestens eins von --reachable, --stdin-commits, oder --stdin-"
+"packs."
 
-#: builtin/clone.c:40
-msgid "git clone [<options>] [--] <repo> [<dir>]"
-msgstr "git clone [<Optionen>] [--] <Repository> [<Verzeichnis>]"
+#: builtin/config.c:11
+msgid "git config [<options>]"
+msgstr "git config [<Optionen>]"
 
-#: builtin/clone.c:85
-msgid "don't create a checkout"
-msgstr "kein Auschecken"
+#: builtin/config.c:103 builtin/env--helper.c:23
+#, c-format
+msgid "unrecognized --type argument, %s"
+msgstr "nicht erkanntes --type Argument, %s"
 
-#: builtin/clone.c:86 builtin/clone.c:88 builtin/init-db.c:479
-msgid "create a bare repository"
-msgstr "ein Bare-Repository erstellen"
+#: builtin/config.c:115
+msgid "only one type at a time"
+msgstr "nur ein Typ erlaubt"
 
-#: builtin/clone.c:90
-msgid "create a mirror repository (implies bare)"
-msgstr "ein Spiegelarchiv erstellen (impliziert --bare)"
+#: builtin/config.c:124
+msgid "Config file location"
+msgstr "Ort der Konfigurationsdatei"
 
-#: builtin/clone.c:92
-msgid "to clone from a local repository"
-msgstr "von einem lokalen Repository klonen"
+#: builtin/config.c:125
+msgid "use global config file"
+msgstr "globale Konfigurationsdatei verwenden"
 
-#: builtin/clone.c:94
-msgid "don't use local hardlinks, always copy"
-msgstr "lokal keine harten Verweise verwenden, immer Kopien"
+#: builtin/config.c:126
+msgid "use system config file"
+msgstr "systemweite Konfigurationsdatei verwenden"
 
-#: builtin/clone.c:96
-msgid "setup as shared repository"
-msgstr "als verteiltes Repository einrichten"
+#: builtin/config.c:127
+msgid "use repository config file"
+msgstr "Konfigurationsdatei des Repositories verwenden"
 
-#: builtin/clone.c:98 builtin/clone.c:102
-msgid "pathspec"
-msgstr "Pfadspezifikation"
+#: builtin/config.c:128
+msgid "use per-worktree config file"
+msgstr "Konfigurationsdatei pro Arbeitsverzeichnis verwenden"
 
-#: builtin/clone.c:98 builtin/clone.c:102
-msgid "initialize submodules in the clone"
-msgstr "Submodule im Klon initialisieren"
+#: builtin/config.c:129
+msgid "use given config file"
+msgstr "die angegebene Konfigurationsdatei verwenden"
 
-#: builtin/clone.c:105
-msgid "number of submodules cloned in parallel"
-msgstr "Anzahl der parallel zu klonenden Submodule"
+#: builtin/config.c:130
+msgid "blob-id"
+msgstr "Blob-Id"
 
-#: builtin/clone.c:106 builtin/init-db.c:476
-msgid "template-directory"
-msgstr "Vorlagenverzeichnis"
+#: builtin/config.c:130
+msgid "read config from given blob object"
+msgstr "Konfiguration von angegebenem Blob-Objekt lesen"
+
+#: builtin/config.c:131
+msgid "Action"
+msgstr "Aktion"
+
+#: builtin/config.c:132
+msgid "get value: name [value-regex]"
+msgstr "Wert zurückgeben: Name [Wert-regex]"
+
+#: builtin/config.c:133
+msgid "get all values: key [value-regex]"
+msgstr "alle Werte zurückgeben: Schlüssel [Wert-regex]"
+
+#: builtin/config.c:134
+msgid "get values for regexp: name-regex [value-regex]"
+msgstr "Werte für den regulären Ausdruck zurückgeben: Name-regex [Wert-regex]"
+
+#: builtin/config.c:135
+msgid "get value specific for the URL: section[.var] URL"
+msgstr "Wert spezifisch für eine URL zurückgeben: section[.var] URL"
+
+#: builtin/config.c:136
+msgid "replace all matching variables: name value [value_regex]"
+msgstr "alle passenden Variablen ersetzen: Name Wert [Wert-regex] "
+
+#: builtin/config.c:137
+msgid "add a new variable: name value"
+msgstr "neue Variable hinzufügen: Name Wert"
+
+#: builtin/config.c:138
+msgid "remove a variable: name [value-regex]"
+msgstr "eine Variable entfernen: Name [Wert-regex]"
+
+#: builtin/config.c:139
+msgid "remove all matches: name [value-regex]"
+msgstr "alle Übereinstimmungen entfernen: Name [Wert-regex]"
+
+#: builtin/config.c:140
+msgid "rename section: old-name new-name"
+msgstr "eine Sektion umbenennen: alter-Name neuer-Name"
+
+#: builtin/config.c:141
+msgid "remove a section: name"
+msgstr "eine Sektion entfernen: Name"
+
+#: builtin/config.c:142
+msgid "list all"
+msgstr "alles auflisten"
+
+#: builtin/config.c:143
+msgid "open an editor"
+msgstr "einen Editor öffnen"
+
+#: builtin/config.c:144
+msgid "find the color configured: slot [default]"
+msgstr "die konfigurierte Farbe finden: Slot [Standard]"
+
+#: builtin/config.c:145
+msgid "find the color setting: slot [stdout-is-tty]"
+msgstr "die Farbeinstellung finden: Slot [Standard-Ausgabe-ist-Terminal]"
+
+#: builtin/config.c:146
+msgid "Type"
+msgstr "Typ"
 
-#: builtin/clone.c:107 builtin/init-db.c:477
-msgid "directory from which templates will be used"
-msgstr "Verzeichnis, von welchem die Vorlagen verwendet werden"
+#: builtin/config.c:147 builtin/env--helper.c:38
+msgid "value is given this type"
+msgstr "Wert ist mit diesem Typ angegeben"
 
-#: builtin/clone.c:109 builtin/clone.c:111 builtin/submodule--helper.c:1210
-#: builtin/submodule--helper.c:1577
-msgid "reference repository"
-msgstr "Repository referenzieren"
+#: builtin/config.c:148
+msgid "value is \"true\" or \"false\""
+msgstr "Wert ist \"true\" oder \"false\""
 
-#: builtin/clone.c:113
-msgid "use --reference only while cloning"
-msgstr "--reference nur während des Klonens benutzen"
+#: builtin/config.c:149
+msgid "value is decimal number"
+msgstr "Wert ist eine Dezimalzahl"
 
-#: builtin/clone.c:114 builtin/column.c:27 builtin/merge-file.c:44
-msgid "name"
-msgstr "Name"
+#: builtin/config.c:150
+msgid "value is --bool or --int"
+msgstr "Wert ist --bool oder --int"
 
-#: builtin/clone.c:115
-msgid "use <name> instead of 'origin' to track upstream"
-msgstr "<Name> statt 'origin' für Upstream-Repository verwenden"
+#: builtin/config.c:151
+msgid "value is a path (file or directory name)"
+msgstr "Wert ist ein Pfad (Datei oder Verzeichnisname)"
 
-#: builtin/clone.c:117
-msgid "checkout <branch> instead of the remote's HEAD"
-msgstr "<Branch> auschecken, anstatt HEAD des Remote-Repositories"
+#: builtin/config.c:152
+msgid "value is an expiry date"
+msgstr "Wert ist ein Verfallsdatum"
 
-#: builtin/clone.c:119
-msgid "path to git-upload-pack on the remote"
-msgstr "Pfad zu \"git-upload-pack\" auf der Gegenseite"
+#: builtin/config.c:153
+msgid "Other"
+msgstr "Sonstiges"
 
-#: builtin/clone.c:120 builtin/fetch.c:151 builtin/grep.c:813
-#: builtin/pull.c:211
-msgid "depth"
-msgstr "Tiefe"
+#: builtin/config.c:154
+msgid "terminate values with NUL byte"
+msgstr "schließt Werte mit NUL-Byte ab"
 
-#: builtin/clone.c:121
-msgid "create a shallow clone of that depth"
-msgstr ""
-"einen Klon mit unvollständiger Historie (shallow) in dieser Tiefe erstellen"
+#: builtin/config.c:155
+msgid "show variable names only"
+msgstr "nur Variablennamen anzeigen"
 
-#: builtin/clone.c:122 builtin/fetch.c:153 builtin/pack-objects.c:3017
-#: parse-options.h:154
-msgid "time"
-msgstr "Zeit"
+#: builtin/config.c:156
+msgid "respect include directives on lookup"
+msgstr "beachtet \"include\"-Direktiven beim Nachschlagen"
 
-#: builtin/clone.c:123
-msgid "create a shallow clone since a specific time"
+#: builtin/config.c:157
+msgid "show origin of config (file, standard input, blob, command line)"
 msgstr ""
-"einen Klon mit unvollständiger Historie (shallow) seit einer bestimmten "
-"Zeit\n"
-"erstellen"
+"Ursprung der Konfiguration anzeigen (Datei, Standard-Eingabe, Blob, "
+"Befehlszeile)"
 
-#: builtin/clone.c:124 builtin/fetch.c:155
-msgid "revision"
-msgstr "Commit"
+#: builtin/config.c:158 builtin/env--helper.c:40
+msgid "value"
+msgstr "Wert"
 
-#: builtin/clone.c:125 builtin/fetch.c:156
-msgid "deepen history of shallow clone, excluding rev"
-msgstr ""
-"die Historie eines Klons mit unvollständiger Historie (shallow) mittels\n"
-"Ausschluss eines Commits vertiefen"
+#: builtin/config.c:158
+msgid "with --get, use default value when missing entry"
+msgstr "mit --get, benutze den Standardwert, wenn der Eintrag fehlt"
 
-#: builtin/clone.c:127
-msgid "clone only one branch, HEAD or --branch"
-msgstr "nur einen Branch klonen, HEAD oder --branch"
+#: builtin/config.c:172
+#, c-format
+msgid "wrong number of arguments, should be %d"
+msgstr "Falsche Anzahl von Argumenten - sollte %d sein."
 
-#: builtin/clone.c:129
-msgid "don't clone any tags, and make later fetches not to follow them"
-msgstr "keine Tags klonen, und auch bei späteren Abrufen nicht beachten"
+#: builtin/config.c:174
+#, c-format
+msgid "wrong number of arguments, should be from %d to %d"
+msgstr "Falsche Anzahl von Argumenten - sollte zwischen %d und %d sein."
 
-#: builtin/clone.c:131
-msgid "any cloned submodules will be shallow"
-msgstr "jedes geklonte Submodul mit unvollständiger Historie (shallow)"
+#: builtin/config.c:308
+#, c-format
+msgid "invalid key pattern: %s"
+msgstr "Ungültiges Schlüsselmuster: %s"
 
-#: builtin/clone.c:132 builtin/init-db.c:485
-msgid "gitdir"
-msgstr ".git-Verzeichnis"
+#: builtin/config.c:344
+#, c-format
+msgid "failed to format default config value: %s"
+msgstr "Fehler beim Formatieren des Standardkonfigurationswertes: %s"
 
-#: builtin/clone.c:133 builtin/init-db.c:486
-msgid "separate git dir from working tree"
-msgstr "Git-Verzeichnis vom Arbeitsverzeichnis separieren"
+#: builtin/config.c:401
+#, c-format
+msgid "cannot parse color '%s'"
+msgstr "Kann Farbe '%s' nicht parsen."
 
-#: builtin/clone.c:134
-msgid "key=value"
-msgstr "Schlüssel=Wert"
+#: builtin/config.c:443
+msgid "unable to parse default color value"
+msgstr "konnte Standard-Farbwert nicht parsen"
 
-#: builtin/clone.c:135
-msgid "set config inside the new repository"
-msgstr "Konfiguration innerhalb des neuen Repositories setzen"
+#: builtin/config.c:496 builtin/config.c:742
+msgid "not in a git directory"
+msgstr "Nicht in einem Git-Repository."
 
-#: builtin/clone.c:136 builtin/fetch.c:173 builtin/pull.c:224
-#: builtin/push.c:567
-msgid "use IPv4 addresses only"
-msgstr "nur IPv4-Adressen benutzen"
+#: builtin/config.c:499
+msgid "writing to stdin is not supported"
+msgstr "Das Schreiben in die Standard-Eingabe wird nicht unterstützt."
 
-#: builtin/clone.c:138 builtin/fetch.c:175 builtin/pull.c:227
-#: builtin/push.c:569
-msgid "use IPv6 addresses only"
-msgstr "nur IPv6-Adressen benutzen"
+#: builtin/config.c:502
+msgid "writing config blobs is not supported"
+msgstr ""
+"Das Schreiben von Blob-Objekten für Konfigurationen wird nicht unterstützt."
 
-#: builtin/clone.c:276
+#: builtin/config.c:587
+#, c-format
 msgid ""
-"No directory name could be guessed.\n"
-"Please specify a directory on the command line"
+"# This is Git's per-user configuration file.\n"
+"[user]\n"
+"# Please adapt and uncomment the following lines:\n"
+"#\tname = %s\n"
+"#\temail = %s\n"
 msgstr ""
-"Konnte keinen Verzeichnisnamen erraten.\n"
-"Bitte geben Sie ein Verzeichnis auf der Befehlszeile an."
+"# Das ist Git's benutzerspezifische Konfigurationsdatei.\n"
+"[user]\n"
+"# Bitte passen Sie die folgenden Zeilen an und kommentieren Sie diese aus:\n"
+"#\tname = %s\n"
+"#\temail = %s\n"
 
-#: builtin/clone.c:329
-#, c-format
-msgid "info: Could not add alternate for '%s': %s\n"
-msgstr "info: Konnte Alternative für '%s' nicht hinzufügen: %s\n"
+#: builtin/config.c:611
+msgid "only one config file at a time"
+msgstr "Nur eine Konfigurationsdatei zu einer Zeit möglich."
 
-#: builtin/clone.c:401
-#, c-format
-msgid "failed to open '%s'"
-msgstr "Fehler beim Öffnen von '%s'"
+#: builtin/config.c:616
+msgid "--local can only be used inside a git repository"
+msgstr "--local kann nur innerhalb eines Git-Repositories verwendet werden."
 
-#: builtin/clone.c:409
-#, c-format
-msgid "%s exists and is not a directory"
-msgstr "%s existiert und ist kein Verzeichnis"
+#: builtin/config.c:619
+msgid "--blob can only be used inside a git repository"
+msgstr "--blob kann nur innerhalb eines Git-Repositories verwendet werden."
 
-#: builtin/clone.c:423
-#, c-format
-msgid "failed to stat %s\n"
-msgstr "Konnte %s nicht lesen\n"
+#: builtin/config.c:638
+msgid "$HOME not set"
+msgstr "$HOME nicht gesetzt."
 
-#: builtin/clone.c:445
-#, c-format
-msgid "failed to create link '%s'"
-msgstr "Konnte Verweis '%s' nicht erstellen"
+#: builtin/config.c:658
+msgid ""
+"--worktree cannot be used with multiple working trees unless the config\n"
+"extension worktreeConfig is enabled. Please read \"CONFIGURATION FILE\"\n"
+"section in \"git help worktree\" for details"
+msgstr ""
+"--worktree kann nicht mit mehreren Arbeitsverzeichnissen verwendet werden,\n"
+"außer die Konfigurationserweiterung worktreeConfig ist aktiviert. Bitte\n"
+"lesen Sie die Sektion \"CONFIGURATION_FILE\" in \"git help worktree\" für "
+"Details"
 
-#: builtin/clone.c:449
-#, c-format
-msgid "failed to copy file to '%s'"
-msgstr "Konnte Datei nicht nach '%s' kopieren"
+#: builtin/config.c:688
+msgid "--get-color and variable type are incoherent"
+msgstr "Angabe von --get-color und Variablentyp sind ungültig."
 
-#: builtin/clone.c:475
-#, c-format
-msgid "done.\n"
-msgstr "Fertig.\n"
+#: builtin/config.c:693
+msgid "only one action at a time"
+msgstr "Nur eine Aktion erlaubt."
 
-#: builtin/clone.c:489
+#: builtin/config.c:706
+msgid "--name-only is only applicable to --list or --get-regexp"
+msgstr "--name-only ist nur anwendbar auf --list oder --get-regexp"
+
+#: builtin/config.c:712
 msgid ""
-"Clone succeeded, but checkout failed.\n"
-"You can inspect what was checked out with 'git status'\n"
-"and retry the checkout with 'git checkout -f HEAD'\n"
+"--show-origin is only applicable to --get, --get-all, --get-regexp, and --"
+"list"
 msgstr ""
-"Klonen erfolgreich, Auschecken ist aber fehlgeschlagen.\n"
-"Sie können mit 'git status' prüfen, was ausgecheckt worden ist\n"
-"und das Auschecken mit 'git checkout -f HEAD' erneut versuchen.\n"
+"--show-origin ist nur anwendbar auf --get, --get-all, --get-regexp und --list"
+
+#: builtin/config.c:718
+msgid "--default is only applicable to --get"
+msgstr "--default ist nur anwendbar auf --get"
 
-#: builtin/clone.c:566
+#: builtin/config.c:731
 #, c-format
-msgid "Could not find remote branch %s to clone."
-msgstr "Konnte zu klonenden Remote-Branch %s nicht finden."
+msgid "unable to read config file '%s'"
+msgstr "Konnte Konfigurationsdatei '%s' nicht lesen."
 
-#: builtin/clone.c:661
-msgid "remote did not send all necessary objects"
-msgstr "Remote-Repository hat nicht alle erforderlichen Objekte gesendet."
+#: builtin/config.c:734
+msgid "error processing config file(s)"
+msgstr "Fehler beim Verarbeiten der Konfigurationsdatei(en)."
 
-#: builtin/clone.c:677
+#: builtin/config.c:744
+msgid "editing stdin is not supported"
+msgstr "Das Bearbeiten der Standard-Eingabe wird nicht unterstützt."
+
+#: builtin/config.c:746
+msgid "editing blobs is not supported"
+msgstr "Das Bearbeiten von Blobs wird nicht unterstützt."
+
+#: builtin/config.c:760
 #, c-format
-msgid "unable to update %s"
-msgstr "kann %s nicht aktualisieren"
+msgid "cannot create configuration file %s"
+msgstr "Konnte Konfigurationsdatei '%s' nicht erstellen."
 
-#: builtin/clone.c:726
-msgid "remote HEAD refers to nonexistent ref, unable to checkout.\n"
+#: builtin/config.c:773
+#, c-format
+msgid ""
+"cannot overwrite multiple values with a single value\n"
+"       Use a regexp, --add or --replace-all to change %s."
 msgstr ""
-"Externer HEAD bezieht sich auf eine nicht existierende Referenz und kann "
-"nicht ausgecheckt werden.\n"
-
-#: builtin/clone.c:756
-msgid "unable to checkout working tree"
-msgstr "Arbeitsverzeichnis konnte nicht ausgecheckt werden"
+"kann nicht mehrere Werte mit einem einzigen Wert überschreiben\n"
+"       Benutzen Sie einen regulären Ausdruck, --add oder --replace, um %s\n"
+"       zu ändern."
 
-#: builtin/clone.c:801
-msgid "unable to write parameters to config file"
-msgstr "konnte Parameter nicht in Konfigurationsdatei schreiben"
+#: builtin/config.c:847 builtin/config.c:858
+#, c-format
+msgid "no such section: %s"
+msgstr "Keine solche Sektion: %s"
 
-#: builtin/clone.c:864
-msgid "cannot repack to clean up"
-msgstr "Kann \"repack\" zum Aufräumen nicht aufrufen"
+#: builtin/count-objects.c:90
+msgid "git count-objects [-v] [-H | --human-readable]"
+msgstr "git count-objects [-v] [-H | --human-readable]"
 
-#: builtin/clone.c:866
-msgid "cannot unlink temporary alternates file"
-msgstr "Kann temporäre \"alternates\"-Datei nicht entfernen"
+#: builtin/count-objects.c:100
+msgid "print sizes in human readable format"
+msgstr "gibt Größenangaben in menschenlesbaren Format aus"
 
-#: builtin/clone.c:906 builtin/receive-pack.c:1946
-msgid "Too many arguments."
-msgstr "Zu viele Argumente."
+#: builtin/describe.c:26
+msgid "git describe [<options>] [<commit-ish>...]"
+msgstr "git describe [<Optionen>] [<Commit-Angabe>...]"
 
-#: builtin/clone.c:910
-msgid "You must specify a repository to clone."
-msgstr "Sie müssen ein Repository zum Klonen angeben."
+#: builtin/describe.c:27
+msgid "git describe [<options>] --dirty"
+msgstr "git describe [<Optionen>] --dirty"
 
-#: builtin/clone.c:923
-#, c-format
-msgid "--bare and --origin %s options are incompatible."
-msgstr "Die Optionen --bare und --origin %s sind inkompatibel."
+#: builtin/describe.c:62
+msgid "head"
+msgstr "Branch"
 
-#: builtin/clone.c:926
-msgid "--bare and --separate-git-dir are incompatible."
-msgstr "Die Optionen --bare und --separate-git-dir sind inkompatibel."
+#: builtin/describe.c:62
+msgid "lightweight"
+msgstr "nicht-annotiert"
 
-#: builtin/clone.c:939
-#, c-format
-msgid "repository '%s' does not exist"
-msgstr "Repository '%s' existiert nicht."
+#: builtin/describe.c:62
+msgid "annotated"
+msgstr "annotiert"
 
-#: builtin/clone.c:945 builtin/fetch.c:1455
+#: builtin/describe.c:275
 #, c-format
-msgid "depth %s is not a positive number"
-msgstr "Tiefe %s ist keine positive Zahl"
+msgid "annotated tag %s not available"
+msgstr "annotiertes Tag %s ist nicht verfügbar"
 
-#: builtin/clone.c:955
+#: builtin/describe.c:279
 #, c-format
-msgid "destination path '%s' already exists and is not an empty directory."
-msgstr "Zielpfad '%s' existiert bereits und ist kein leeres Verzeichnis."
+msgid "annotated tag %s has no embedded name"
+msgstr "annotiertes Tag %s hat keinen eingebetteten Namen"
 
-#: builtin/clone.c:965
+#: builtin/describe.c:281
 #, c-format
-msgid "working tree '%s' already exists."
-msgstr "Arbeitsverzeichnis '%s' existiert bereits."
+msgid "tag '%s' is really '%s' here"
+msgstr "Tag '%s' ist eigentlich '%s' hier"
 
-#: builtin/clone.c:980 builtin/clone.c:1001 builtin/difftool.c:270
-#: builtin/worktree.c:255 builtin/worktree.c:285
+#: builtin/describe.c:325
 #, c-format
-msgid "could not create leading directories of '%s'"
-msgstr "Konnte führende Verzeichnisse von '%s' nicht erstellen."
+msgid "no tag exactly matches '%s'"
+msgstr "kein Tag entspricht exakt '%s'"
 
-#: builtin/clone.c:985
+#: builtin/describe.c:327
 #, c-format
-msgid "could not create work tree dir '%s'"
-msgstr "Konnte Arbeitsverzeichnis '%s' nicht erstellen"
+msgid "No exact match on refs or tags, searching to describe\n"
+msgstr ""
+"Keine exakte Übereinstimmung bei Referenzen oder Tags, Suche zum "
+"Beschreiben\n"
 
-#: builtin/clone.c:1005
+#: builtin/describe.c:381
 #, c-format
-msgid "Cloning into bare repository '%s'...\n"
-msgstr "Klone in Bare-Repository '%s' ...\n"
+msgid "finished search at %s\n"
+msgstr "beendete Suche bei %s\n"
 
-#: builtin/clone.c:1007
+#: builtin/describe.c:407
 #, c-format
-msgid "Cloning into '%s'...\n"
-msgstr "Klone nach '%s' ...\n"
-
-#: builtin/clone.c:1031
 msgid ""
-"clone --recursive is not compatible with both --reference and --reference-if-"
-"able"
+"No annotated tags can describe '%s'.\n"
+"However, there were unannotated tags: try --tags."
 msgstr ""
-"'clone --recursive' ist nicht kompatibel mit --reference und --reference-if-"
-"able"
+"Keine annotierten Tags können '%s' beschreiben.\n"
+"Jedoch gab es nicht-annotierte Tags: versuchen Sie --tags."
 
-#: builtin/clone.c:1093
-msgid "--depth is ignored in local clones; use file:// instead."
+#: builtin/describe.c:411
+#, c-format
+msgid ""
+"No tags can describe '%s'.\n"
+"Try --always, or create some tags."
 msgstr ""
-"Die Option --depth wird in lokalen Klonen ignoriert; benutzen Sie "
-"stattdessen file://"
+"Keine Tags können '%s' beschreiben.\n"
+"Versuchen Sie --always oder erstellen Sie einige Tags."
 
-#: builtin/clone.c:1095
-msgid "--shallow-since is ignored in local clones; use file:// instead."
-msgstr ""
-"--shallow-since wird in lokalen Klonen ignoriert; benutzen Sie stattdessen "
-"file://"
+#: builtin/describe.c:441
+#, c-format
+msgid "traversed %lu commits\n"
+msgstr "%lu Commits durchlaufen\n"
 
-#: builtin/clone.c:1097
-msgid "--shallow-exclude is ignored in local clones; use file:// instead."
+#: builtin/describe.c:444
+#, c-format
+msgid ""
+"more than %i tags found; listed %i most recent\n"
+"gave up search at %s\n"
 msgstr ""
-"--shallow-exclude wird in lokalen Klonen ignoriert; benutzen Sie stattdessen "
-"file://"
-
-#: builtin/clone.c:1099
-msgid "--filter is ignored in local clones; use file:// instead."
-msgstr "--filter wird in lokalen Klonen ignoriert; benutzen Sie stattdessen file://"
+"mehr als %i Tags gefunden; führe die ersten %i auf\n"
+"Suche bei %s aufgegeben\n"
 
-#: builtin/clone.c:1102
-msgid "source repository is shallow, ignoring --local"
-msgstr ""
-"Quelle ist ein Repository mit unvollständiger Historie (shallow),\n"
-"ignoriere --local"
+#: builtin/describe.c:512
+#, c-format
+msgid "describe %s\n"
+msgstr "Beschreibe %s\n"
 
-#: builtin/clone.c:1107
-msgid "--local is ignored"
-msgstr "--local wird ignoriert"
+#: builtin/describe.c:515
+#, c-format
+msgid "Not a valid object name %s"
+msgstr "%s ist kein gültiger Objekt-Name"
 
-#: builtin/clone.c:1169 builtin/clone.c:1177
+#: builtin/describe.c:523
 #, c-format
-msgid "Remote branch %s not found in upstream %s"
-msgstr "Remote-Branch %s nicht im Upstream-Repository %s gefunden"
+msgid "%s is neither a commit nor blob"
+msgstr "%s ist weder ein Commit, noch ein Blob."
 
-#: builtin/clone.c:1180
-msgid "You appear to have cloned an empty repository."
-msgstr "Sie scheinen ein leeres Repository geklont zu haben."
+#: builtin/describe.c:537
+msgid "find the tag that comes after the commit"
+msgstr "das Tag finden, das nach dem Commit kommt"
 
-#: builtin/column.c:10
-msgid "git column [<options>]"
-msgstr "git column [<Optionen>]"
+#: builtin/describe.c:538
+msgid "debug search strategy on stderr"
+msgstr "die Suchstrategie in der Standard-Fehlerausgabe protokollieren"
 
-#: builtin/column.c:27
-msgid "lookup config vars"
-msgstr "Konfigurationsvariablen nachschlagen"
+#: builtin/describe.c:539
+msgid "use any ref"
+msgstr "alle Referenzen verwenden"
 
-#: builtin/column.c:28 builtin/column.c:29
-msgid "layout to use"
-msgstr "zu verwendende Anordnung"
+#: builtin/describe.c:540
+msgid "use any tag, even unannotated"
+msgstr "jedes Tag verwenden, auch nicht-annotierte"
 
-#: builtin/column.c:30
-msgid "Maximum width"
-msgstr "maximale Breite"
+#: builtin/describe.c:541
+msgid "always use long format"
+msgstr "immer langes Format verwenden"
 
-#: builtin/column.c:31
-msgid "Padding space on left border"
-msgstr "Abstand zum linken Rand"
+#: builtin/describe.c:542
+msgid "only follow first parent"
+msgstr "nur erstem Elternteil folgen"
 
-#: builtin/column.c:32
-msgid "Padding space on right border"
-msgstr "Abstand zum rechten Rand"
+#: builtin/describe.c:545
+msgid "only output exact matches"
+msgstr "nur exakte Übereinstimmungen ausgeben"
 
-#: builtin/column.c:33
-msgid "Padding space between columns"
-msgstr "Abstand zwischen Spalten"
+#: builtin/describe.c:547
+msgid "consider <n> most recent tags (default: 10)"
+msgstr "die jüngsten <n> Tags betrachten (Standard: 10)"
 
-#: builtin/column.c:52
-msgid "--command must be the first argument"
-msgstr "Die Option --command muss an erster Stelle stehen."
+#: builtin/describe.c:549
+msgid "only consider tags matching <pattern>"
+msgstr "nur Tags, die <Muster> entsprechen, betrachten"
 
-#: builtin/commit.c:37
-msgid "git commit [<options>] [--] <pathspec>..."
-msgstr "git commit [<Optionen>] [--] <Pfadspezifikation>..."
+#: builtin/describe.c:551
+msgid "do not consider tags matching <pattern>"
+msgstr "keine Tags betrachten, die <Muster> entsprechen"
 
-#: builtin/commit.c:42
-msgid "git status [<options>] [--] <pathspec>..."
-msgstr "git status [<Optionen>] [--] <Pfadspezifikation>..."
+#: builtin/describe.c:553 builtin/name-rev.c:473
+msgid "show abbreviated commit object as fallback"
+msgstr "gekürztes Commit-Objekt anzeigen, wenn sonst nichts zutrifft"
 
-#: builtin/commit.c:47
-msgid ""
-"You asked to amend the most recent commit, but doing so would make\n"
-"it empty. You can repeat your command with --allow-empty, or you can\n"
-"remove the commit entirely with \"git reset HEAD^\".\n"
+#: builtin/describe.c:554 builtin/describe.c:557
+msgid "mark"
+msgstr "Markierung"
+
+#: builtin/describe.c:555
+msgid "append <mark> on dirty working tree (default: \"-dirty\")"
 msgstr ""
-"Sie fragten den jüngsten Commit nachzubessern, aber das würde diesen leer\n"
-"machen. Sie können Ihren Befehl mit --allow-empty wiederholen, oder diesen\n"
-"Commit mit \"git reset HEAD^\" vollständig entfernen.\n"
+"<Markierung> bei geändertem Arbeitsverzeichnis anhängen (Standard: \"-dirty"
+"\")"
 
-#: builtin/commit.c:52
-msgid ""
-"The previous cherry-pick is now empty, possibly due to conflict resolution.\n"
-"If you wish to commit it anyway, use:\n"
-"\n"
-"    git commit --allow-empty\n"
-"\n"
+#: builtin/describe.c:558
+msgid "append <mark> on broken working tree (default: \"-broken\")"
 msgstr ""
-"Der letzte \"cherry-pick\" ist jetzt leer, möglicherweise durch eine "
-"Konfliktauflösung.\n"
-"Wenn Sie dies trotzdem committen wollen, benutzen Sie:\n"
-"\n"
-"    git commit --allow-empty\n"
-"\n"
+"<Markierung> bei defektem Arbeitsverzeichnis anhängen (Standard: \"-broken\")"
 
-#: builtin/commit.c:59
-msgid "Otherwise, please use 'git reset'\n"
-msgstr "Andernfalls benutzen Sie bitte 'git reset'\n"
+#: builtin/describe.c:576
+msgid "--long is incompatible with --abbrev=0"
+msgstr "Die Optionen --long und --abbrev=0 sind inkompatibel."
 
-#: builtin/commit.c:62
-msgid ""
-"If you wish to skip this commit, use:\n"
-"\n"
-"    git reset\n"
-"\n"
-"Then \"git cherry-pick --continue\" will resume cherry-picking\n"
-"the remaining commits.\n"
-msgstr ""
-"Wenn Sie diesen Commit auslassen möchten, benutzen Sie:\n"
-"\n"
-"    git reset\n"
-"\n"
-"Benutzen Sie anschließend \"git cherry-pick --continue\", um die\n"
-"Cherry-Pick-Operation mit den verbleibenden Commits fortzusetzen.\n"
+#: builtin/describe.c:605
+msgid "No names found, cannot describe anything."
+msgstr "Keine Namen gefunden, kann nichts beschreiben."
 
-#: builtin/commit.c:284
-msgid "failed to unpack HEAD tree object"
-msgstr "Fehler beim Entpacken des \"Tree\"-Objektes von HEAD."
+#: builtin/describe.c:656
+msgid "--dirty is incompatible with commit-ishes"
+msgstr "Die Option --dirty kann nicht mit Commits verwendet werden."
 
-#: builtin/commit.c:325
-msgid "unable to create temporary index"
-msgstr "Konnte temporären Index nicht erstellen."
+#: builtin/describe.c:658
+msgid "--broken is incompatible with commit-ishes"
+msgstr "Die Option --broken kann nicht mit Commits verwendet werden."
 
-#: builtin/commit.c:331
-msgid "interactive add failed"
-msgstr "interaktives Hinzufügen fehlgeschlagen"
+#: builtin/diff.c:84
+#, c-format
+msgid "'%s': not a regular file or symlink"
+msgstr "'%s': keine reguläre Datei oder symbolische Verknüpfung"
 
-#: builtin/commit.c:344
-msgid "unable to update temporary index"
-msgstr "Konnte temporären Index nicht aktualisieren."
+#: builtin/diff.c:235
+#, c-format
+msgid "invalid option: %s"
+msgstr "Ungültige Option: %s"
 
-#: builtin/commit.c:346
-msgid "Failed to update main cache tree"
-msgstr "Konnte Haupt-Cache-Verzeichnis nicht aktualisieren"
+#: builtin/diff.c:350
+msgid "Not a git repository"
+msgstr "Kein Git-Repository"
 
-#: builtin/commit.c:371 builtin/commit.c:395 builtin/commit.c:444
-msgid "unable to write new_index file"
-msgstr "Konnte new_index Datei nicht schreiben"
+#: builtin/diff.c:394
+#, c-format
+msgid "invalid object '%s' given."
+msgstr "Objekt '%s' ist ungültig."
 
-#: builtin/commit.c:427
-msgid "cannot do a partial commit during a merge."
-msgstr "Kann keinen Teil-Commit durchführen, während ein Merge im Gange ist."
+#: builtin/diff.c:403
+#, c-format
+msgid "more than two blobs given: '%s'"
+msgstr "Mehr als zwei Blobs angegeben: '%s'"
 
-#: builtin/commit.c:429
-msgid "cannot do a partial commit during a cherry-pick."
-msgstr ""
-"Kann keinen Teil-Commit durchführen, während \"cherry-pick\" im Gange ist."
+#: builtin/diff.c:408
+#, c-format
+msgid "unhandled object '%s' given."
+msgstr "unbehandeltes Objekt '%s' angegeben"
 
-#: builtin/commit.c:437
-msgid "cannot read the index"
-msgstr "Kann Index nicht lesen"
+#: builtin/difftool.c:30
+msgid "git difftool [<options>] [<commit> [<commit>]] [--] [<path>...]"
+msgstr "git difftool [<Optionen>] [<Commit> [<Commit>]] [--] [<Pfad>...]"
 
-#: builtin/commit.c:456
-msgid "unable to write temporary index file"
-msgstr "Konnte temporäre Index-Datei nicht schreiben."
+#: builtin/difftool.c:260
+#, c-format
+msgid "failed: %d"
+msgstr "fehlgeschlagen: %d"
 
-#: builtin/commit.c:553
+#: builtin/difftool.c:302
 #, c-format
-msgid "commit '%s' lacks author header"
-msgstr "Commit '%s' fehlt Autor-Kopfbereich"
+msgid "could not read symlink %s"
+msgstr "konnte symbolische Verknüpfung %s nicht lesen"
 
-#: builtin/commit.c:555
+#: builtin/difftool.c:304
 #, c-format
-msgid "commit '%s' has malformed author line"
-msgstr "Commit '%s' hat fehlerhafte Autor-Zeile"
+msgid "could not read symlink file %s"
+msgstr "Konnte Datei von symbolischer Verknüpfung '%s' nicht lesen."
 
-#: builtin/commit.c:574
-msgid "malformed --author parameter"
-msgstr "Fehlerhafter --author Parameter"
+#: builtin/difftool.c:312
+#, c-format
+msgid "could not read object %s for symlink %s"
+msgstr "Konnte Objekt '%s' für symbolische Verknüpfung '%s' nicht lesen."
 
-#: builtin/commit.c:626
+#: builtin/difftool.c:413
 msgid ""
-"unable to select a comment character that is not used\n"
-"in the current commit message"
+"combined diff formats('-c' and '--cc') are not supported in\n"
+"directory diff mode('-d' and '--dir-diff')."
 msgstr ""
-"Konnte kein Kommentar-Zeichen auswählen, das nicht in\n"
-"der aktuellen Commit-Beschreibung verwendet wird."
+"Kombinierte Diff-Formate('-c' und '--cc') werden im Verzeichnis-\n"
+"Diff-Modus('-d' und '--dir-diff') nicht unterstützt."
 
-#: builtin/commit.c:663 builtin/commit.c:696 builtin/commit.c:1024
+#: builtin/difftool.c:634
 #, c-format
-msgid "could not lookup commit %s"
-msgstr "Konnte Commit %s nicht nachschlagen"
+msgid "both files modified: '%s' and '%s'."
+msgstr "beide Dateien geändert: '%s' und '%s'."
+
+#: builtin/difftool.c:636
+msgid "working tree file has been left."
+msgstr "Datei im Arbeitsverzeichnis belassen."
 
-#: builtin/commit.c:675 builtin/shortlog.c:309
+#: builtin/difftool.c:647
 #, c-format
-msgid "(reading log message from standard input)\n"
-msgstr "(lese Log-Nachricht von Standard-Eingabe)\n"
+msgid "temporary files exist in '%s'."
+msgstr "Es existieren temporäre Dateien in '%s'."
 
-#: builtin/commit.c:677
-msgid "could not read log from standard input"
-msgstr "Konnte Log nicht von Standard-Eingabe lesen."
+#: builtin/difftool.c:648
+msgid "you may want to cleanup or recover these."
+msgstr "Sie könnten diese aufräumen oder wiederherstellen."
 
-#: builtin/commit.c:681
-#, c-format
-msgid "could not read log file '%s'"
-msgstr "Konnte Log-Datei '%s' nicht lesen"
+#: builtin/difftool.c:697
+msgid "use `diff.guitool` instead of `diff.tool`"
+msgstr "`diff.guitool` anstatt `diff.tool` benutzen"
 
-#: builtin/commit.c:710 builtin/commit.c:718
-msgid "could not read SQUASH_MSG"
-msgstr "Konnte SQUASH_MSG nicht lesen"
+#: builtin/difftool.c:699
+msgid "perform a full-directory diff"
+msgstr "Diff über ganzes Verzeichnis ausführen"
 
-#: builtin/commit.c:715
-msgid "could not read MERGE_MSG"
-msgstr "Konnte MERGE_MSG nicht lesen"
+#: builtin/difftool.c:701
+msgid "do not prompt before launching a diff tool"
+msgstr "keine Eingabeaufforderung vor Ausführung eines Diff-Tools"
 
-#: builtin/commit.c:769
-msgid "could not write commit template"
-msgstr "Konnte Commit-Vorlage nicht schreiben"
+#: builtin/difftool.c:706
+msgid "use symlinks in dir-diff mode"
+msgstr "symbolische Verknüpfungen im dir-diff Modus verwenden"
 
-#: builtin/commit.c:787
-#, c-format
-msgid ""
-"\n"
-"It looks like you may be committing a merge.\n"
-"If this is not correct, please remove the file\n"
-"\t%s\n"
-"and try again.\n"
-msgstr ""
-"\n"
-"Es sieht so aus, als committen Sie einen Merge.\n"
-"Falls das nicht korrekt ist, löschen Sie bitte die Datei\n"
-"\t%s\n"
-"und versuchen Sie es erneut.\n"
+#: builtin/difftool.c:707
+msgid "tool"
+msgstr "Tool"
 
-#: builtin/commit.c:792
-#, c-format
-msgid ""
-"\n"
-"It looks like you may be committing a cherry-pick.\n"
-"If this is not correct, please remove the file\n"
-"\t%s\n"
-"and try again.\n"
-msgstr ""
-"\n"
-"Es sieht so aus, als committen Sie einen \"cherry-pick\".\n"
-"Falls das nicht korrekt ist, löschen Sie bitte die Datei\n"
-"\t%s\n"
-"und versuchen Sie es erneut.\n"
+#: builtin/difftool.c:708
+msgid "use the specified diff tool"
+msgstr "das angegebene Diff-Tool benutzen"
 
-#: builtin/commit.c:805
-#, c-format
-msgid ""
-"Please enter the commit message for your changes. Lines starting\n"
-"with '%c' will be ignored, and an empty message aborts the commit.\n"
+#: builtin/difftool.c:710
+msgid "print a list of diff tools that may be used with `--tool`"
 msgstr ""
-"Bitte geben Sie eine Commit-Beschreibung für Ihre Änderungen ein. Zeilen,\n"
-"die mit '%c' beginnen, werden ignoriert, und eine leere Beschreibung\n"
-"bricht den Commit ab.\n"
+"eine Liste mit Diff-Tools darstellen, die mit `--tool` benutzt werden können"
 
-#: builtin/commit.c:813
-#, c-format
+#: builtin/difftool.c:713
 msgid ""
-"Please enter the commit message for your changes. Lines starting\n"
-"with '%c' will be kept; you may remove them yourself if you want to.\n"
-"An empty message aborts the commit.\n"
+"make 'git-difftool' exit when an invoked diff tool returns a non - zero exit "
+"code"
 msgstr ""
-"Bitte geben Sie eine Commit-Beschreibung für Ihre Änderungen ein. Zeilen, "
-"die\n"
-"mit '%c' beginnen, werden beibehalten; wenn Sie möchten, können Sie diese "
-"entfernen.\n"
-"Eine leere Beschreibung bricht den Commit ab.\n"
+"'git-difftool' beenden, wenn das aufgerufene Diff-Tool mit einem "
+"Rückkehrwert\n"
+"verschieden 0 ausgeführt wurde"
+
+#: builtin/difftool.c:716
+msgid "specify a custom command for viewing diffs"
+msgstr "eigenen Befehl zur Anzeige von Unterschieden angeben"
+
+#: builtin/difftool.c:717
+msgid "passed to `diff`"
+msgstr "an 'diff' übergeben"
+
+#: builtin/difftool.c:732
+msgid "difftool requires worktree or --no-index"
+msgstr "difftool benötigt Arbeitsverzeichnis oder --no-index"
+
+#: builtin/difftool.c:739
+msgid "--dir-diff is incompatible with --no-index"
+msgstr "--dir-diff kann nicht mit --no-index verwendet werden"
+
+#: builtin/difftool.c:742
+msgid "--gui, --tool and --extcmd are mutually exclusive"
+msgstr "--gui, --tool und --extcmd schließen sich gegenseitig aus"
+
+#: builtin/difftool.c:750
+msgid "no <tool> given for --tool=<tool>"
+msgstr "kein <Tool> für --tool=<Tool> angegeben"
 
-#: builtin/commit.c:830
-#, c-format
-msgid "%sAuthor:    %.*s <%.*s>"
-msgstr "%sAutor:           %.*s <%.*s>"
+#: builtin/difftool.c:757
+msgid "no <cmd> given for --extcmd=<cmd>"
+msgstr "kein <Programm> für --extcmd=<Programm> angegeben"
 
-#: builtin/commit.c:838
-#, c-format
-msgid "%sDate:      %s"
-msgstr "%sDatum:            %s"
+#: builtin/env--helper.c:6
+msgid "git env--helper --type=[bool|ulong] <options> <env-var>"
+msgstr "git env--helper --type=[bool|ulong] <Optionen> <Umgebungsvariable>"
 
-#: builtin/commit.c:845
-#, c-format
-msgid "%sCommitter: %.*s <%.*s>"
-msgstr "%sCommit-Ersteller: %.*s <%.*s>"
+#: builtin/env--helper.c:37 builtin/hash-object.c:98
+msgid "type"
+msgstr "Art"
 
-#: builtin/commit.c:862
-msgid "Cannot read index"
-msgstr "Kann Index nicht lesen"
+#: builtin/env--helper.c:41
+msgid "default for git_env_*(...) to fall back on"
+msgstr "Standard für git_env_*(...), um darauf zurückzugreifen"
 
-#: builtin/commit.c:928
-msgid "Error building trees"
-msgstr "Fehler beim Erzeugen der \"Tree\"-Objekte"
+#: builtin/env--helper.c:43
+msgid "be quiet only use git_env_*() value as exit code"
+msgstr "Ausgaben unterdrücken; nur git_env_*() Werte als Exit-Code verwenden"
 
-#: builtin/commit.c:942 builtin/tag.c:256
+#: builtin/env--helper.c:62
 #, c-format
-msgid "Please supply the message using either -m or -F option.\n"
+msgid "option `--default' expects a boolean value with `--type=bool`, not `%s`"
 msgstr ""
-"Bitte liefern Sie eine Beschreibung entweder mit der Option -m oder -F.\n"
+"Option `--default' erwartet einen booleschen Wert bei `--type=bool', nicht `"
+"%s`"
 
-#: builtin/commit.c:986
+#: builtin/env--helper.c:77
 #, c-format
-msgid "--author '%s' is not 'Name <email>' and matches no existing author"
+msgid ""
+"option `--default' expects an unsigned long value with `--type=ulong`, not `"
+"%s`"
 msgstr ""
-"--author '%s' ist nicht im Format 'Name <E-Mail>' und stimmt mit keinem "
-"vorhandenen Autor überein"
+"Option `--default' erwartet einen vorzeichenlosen Long-Wert bei `--"
+"type=ulong`, nicht `%s`"
 
-#: builtin/commit.c:1000
-#, c-format
-msgid "Invalid ignored mode '%s'"
-msgstr "Ungültiger ignored-Modus '%s'."
+#: builtin/fast-export.c:29
+msgid "git fast-export [rev-list-opts]"
+msgstr "git fast-export [rev-list-opts]"
 
-#: builtin/commit.c:1014 builtin/commit.c:1264
-#, c-format
-msgid "Invalid untracked files mode '%s'"
-msgstr "Ungültiger Modus '%s' für unversionierte Dateien"
+#: builtin/fast-export.c:852
+msgid "Error: Cannot export nested tags unless --mark-tags is specified."
+msgstr ""
+"Fehler: Verschachtelte Tags können nicht exportiert werden, außer --mark-"
+"tags wurde angegeben."
 
-#: builtin/commit.c:1052
-msgid "--long and -z are incompatible"
-msgstr "Die Optionen --long und -z sind inkompatibel."
+#: builtin/fast-export.c:1152
+msgid "show progress after <n> objects"
+msgstr "Fortschritt nach <n> Objekten anzeigen"
 
-#: builtin/commit.c:1085
-msgid "Using both --reset-author and --author does not make sense"
+#: builtin/fast-export.c:1154
+msgid "select handling of signed tags"
+msgstr "Behandlung von signierten Tags wählen"
+
+#: builtin/fast-export.c:1157
+msgid "select handling of tags that tag filtered objects"
+msgstr "Behandlung von Tags wählen, die gefilterte Objekte markieren"
+
+#: builtin/fast-export.c:1160
+msgid "select handling of commit messages in an alternate encoding"
 msgstr ""
-"Die Optionen --reset-author und --author können nicht gemeinsam verwendet "
-"werden."
+"Auswählen der Behandlung von Commit-Beschreibungen bei wechselndem Encoding"
 
-#: builtin/commit.c:1094
-msgid "You have nothing to amend."
-msgstr "Sie haben nichts für \"--amend\"."
+#: builtin/fast-export.c:1163
+msgid "Dump marks to this file"
+msgstr "Markierungen in diese Datei schreiben"
 
-#: builtin/commit.c:1097
-msgid "You are in the middle of a merge -- cannot amend."
-msgstr "Ein Merge ist im Gange -- kann \"--amend\" nicht ausführen."
+#: builtin/fast-export.c:1165
+msgid "Import marks from this file"
+msgstr "Markierungen von dieser Datei importieren"
 
-#: builtin/commit.c:1099
-msgid "You are in the middle of a cherry-pick -- cannot amend."
-msgstr "\"cherry-pick\" ist im Gange -- kann \"--amend\" nicht ausführen."
+#: builtin/fast-export.c:1169
+msgid "Import marks from this file if it exists"
+msgstr "Markierungen von dieser Datei importieren, wenn diese existiert"
 
-#: builtin/commit.c:1102
-msgid "Options --squash and --fixup cannot be used together"
-msgstr ""
-"Die Optionen --squash und --fixup können nicht gemeinsam verwendet werden."
+#: builtin/fast-export.c:1171
+msgid "Fake a tagger when tags lack one"
+msgstr "künstlich einen Tag-Ersteller erzeugen, wenn das Tag keinen hat"
 
-#: builtin/commit.c:1112
-msgid "Only one of -c/-C/-F/--fixup can be used."
-msgstr "Es kann nur eine Option von -c/-C/-F/--fixup verwendet werden."
+#: builtin/fast-export.c:1173
+msgid "Output full tree for each commit"
+msgstr "für jeden Commit das gesamte Verzeichnis ausgeben"
 
-#: builtin/commit.c:1114
-msgid "Option -m cannot be combined with -c/-C/-F."
-msgstr "Die Option -m kann nicht mit -c/-C/-F kombiniert werden."
+#: builtin/fast-export.c:1175
+msgid "Use the done feature to terminate the stream"
+msgstr "die \"done\"-Funktion benutzen, um den Datenstrom abzuschließen"
 
-#: builtin/commit.c:1122
-msgid "--reset-author can be used only with -C, -c or --amend."
-msgstr ""
-"Die Option --reset--author kann nur mit -C, -c oder --amend verwendet werden."
+#: builtin/fast-export.c:1176
+msgid "Skip output of blob data"
+msgstr "Ausgabe von Blob-Daten überspringen"
 
-#: builtin/commit.c:1139
-msgid "Only one of --include/--only/--all/--interactive/--patch can be used."
+#: builtin/fast-export.c:1177 builtin/log.c:1705
+msgid "refspec"
+msgstr "Refspec"
+
+#: builtin/fast-export.c:1178
+msgid "Apply refspec to exported refs"
+msgstr "Refspec auf exportierte Referenzen anwenden"
+
+#: builtin/fast-export.c:1179
+msgid "anonymize output"
+msgstr "Ausgabe anonymisieren"
+
+#: builtin/fast-export.c:1181
+msgid "Reference parents which are not in fast-export stream by object id"
 msgstr ""
-"Es kann nur eine Option von --include/--only/--all/--interactive/--patch "
-"verwendet werden."
+"Eltern, die nicht im Fast-Export-Stream sind, anhand ihrer Objekt-ID "
+"referenzieren"
 
-#: builtin/commit.c:1141
-msgid "No paths with --include/--only does not make sense."
+#: builtin/fast-export.c:1183
+msgid "Show original object ids of blobs/commits"
+msgstr "originale Objekt-IDs von Blobs/Commits anzeigen"
+
+#: builtin/fast-export.c:1185
+msgid "Label tags with mark ids"
+msgstr "Tags mit Markierungs-IDs beschriften"
+
+#: builtin/fast-export.c:1220
+msgid "Cannot pass both --import-marks and --import-marks-if-exists"
 msgstr ""
-"Die Optionen --include und --only können nur mit der Angabe von Pfaden "
-"verwendet werden."
+"--import-marks und --import-marks-if-exists können nicht zusammen "
+"weitergegeben werden"
 
-#: builtin/commit.c:1155 builtin/tag.c:542
-#, c-format
-msgid "Invalid cleanup mode %s"
-msgstr "Ungültiger \"cleanup\" Modus %s"
+#: builtin/fetch.c:34
+msgid "git fetch [<options>] [<repository> [<refspec>...]]"
+msgstr "git fetch [<Optionen>] [<Repository> [<Refspec>...]]"
 
-#: builtin/commit.c:1160
-msgid "Paths with -a does not make sense."
-msgstr "Die Option -a kann nicht mit der Angabe von Pfaden verwendet werden."
+#: builtin/fetch.c:35
+msgid "git fetch [<options>] <group>"
+msgstr "git fetch [<Optionen>] <Gruppe>"
 
-#: builtin/commit.c:1278 builtin/commit.c:1443
-msgid "show status concisely"
-msgstr "Status im Kurzformat anzeigen"
+#: builtin/fetch.c:36
+msgid "git fetch --multiple [<options>] [(<repository> | <group>)...]"
+msgstr "git fetch --multiple [<Optionen>] [(<Repository> | <Gruppe>)...]"
 
-#: builtin/commit.c:1280 builtin/commit.c:1445
-msgid "show branch information"
-msgstr "Branchinformationen anzeigen"
+#: builtin/fetch.c:37
+msgid "git fetch --all [<options>]"
+msgstr "git fetch --all [<Optionen>]"
 
-#: builtin/commit.c:1282
-msgid "show stash information"
-msgstr "Stashinformationen anzeigen"
+#: builtin/fetch.c:116
+msgid "fetch.parallel cannot be negative"
+msgstr "fetch.parallel kann nicht negativ sein"
 
-#: builtin/commit.c:1284 builtin/commit.c:1447
-msgid "compute full ahead/behind values"
-msgstr "voraus/hinterher-Werte berechnen"
+#: builtin/fetch.c:139 builtin/pull.c:204
+msgid "fetch from all remotes"
+msgstr "fordert von allen Remote-Repositories an"
 
-#: builtin/commit.c:1286
-msgid "version"
-msgstr "Version"
+#: builtin/fetch.c:141 builtin/pull.c:248
+msgid "set upstream for git pull/fetch"
+msgstr "Upstream für \"git pull/fetch\" setzen"
 
-#: builtin/commit.c:1286 builtin/commit.c:1449 builtin/push.c:542
-#: builtin/worktree.c:541
-msgid "machine-readable output"
-msgstr "maschinenlesbare Ausgabe"
+#: builtin/fetch.c:143 builtin/pull.c:207
+msgid "append to .git/FETCH_HEAD instead of overwriting"
+msgstr "an .git/FETCH_HEAD anhängen, anstatt zu überschreiben"
 
-#: builtin/commit.c:1289 builtin/commit.c:1451
-msgid "show status in long format (default)"
-msgstr "Status im Langformat anzeigen (Standard)"
+#: builtin/fetch.c:145 builtin/pull.c:210
+msgid "path to upload pack on remote end"
+msgstr "Pfad des Programms zum Hochladen von Paketen auf der Gegenseite"
 
-#: builtin/commit.c:1292 builtin/commit.c:1454
-msgid "terminate entries with NUL"
-msgstr "Einträge mit NUL-Zeichen abschließen"
+#: builtin/fetch.c:146
+msgid "force overwrite of local reference"
+msgstr "das Überschreiben einer lokalen Referenz erzwingen"
 
-#: builtin/commit.c:1294 builtin/commit.c:1298 builtin/commit.c:1457
-#: builtin/fast-export.c:999 builtin/fast-export.c:1002 builtin/tag.c:396
-msgid "mode"
-msgstr "Modus"
+#: builtin/fetch.c:148
+msgid "fetch from multiple remotes"
+msgstr "von mehreren Remote-Repositories anfordern"
 
-#: builtin/commit.c:1295 builtin/commit.c:1457
-msgid "show untracked files, optional modes: all, normal, no. (Default: all)"
+#: builtin/fetch.c:150 builtin/pull.c:214
+msgid "fetch all tags and associated objects"
+msgstr "alle Tags und verbundene Objekte anfordern"
+
+#: builtin/fetch.c:152
+msgid "do not fetch all tags (--no-tags)"
+msgstr "nicht alle Tags anfordern (--no-tags)"
+
+#: builtin/fetch.c:154
+msgid "number of submodules fetched in parallel"
+msgstr "Anzahl der parallel anzufordernden Submodule"
+
+#: builtin/fetch.c:156 builtin/pull.c:217
+msgid "prune remote-tracking branches no longer on remote"
 msgstr ""
-"unversionierte Dateien anzeigen, optionale Modi: all, normal, no. (Standard: "
-"all)"
+"Remote-Tracking-Branches entfernen, die sich nicht mehr im Remote-Repository "
+"befinden"
 
-#: builtin/commit.c:1299
-msgid ""
-"show ignored files, optional modes: traditional, matching, no. (Default: "
-"traditional)"
+#: builtin/fetch.c:158
+msgid "prune local tags no longer on remote and clobber changed tags"
 msgstr ""
-"ignorierte Dateien anzeigen, optionale Modi: traditional, matching, no. "
-"(Standard: traditional)"
+"lokale Tags entfernen, die sich nicht mehr im Remote-Repository befinden, "
+"und geänderte Tags aktualisieren"
 
-#: builtin/commit.c:1301 parse-options.h:167
-msgid "when"
-msgstr "wann"
+#: builtin/fetch.c:159 builtin/fetch.c:182 builtin/pull.c:141
+msgid "on-demand"
+msgstr "bei-Bedarf"
 
-#: builtin/commit.c:1302
-msgid ""
-"ignore changes to submodules, optional when: all, dirty, untracked. "
-"(Default: all)"
+#: builtin/fetch.c:160
+msgid "control recursive fetching of submodules"
+msgstr "rekursive Anforderungen von Submodulen kontrollieren"
+
+#: builtin/fetch.c:164 builtin/pull.c:225
+msgid "keep downloaded pack"
+msgstr "heruntergeladenes Paket behalten"
+
+#: builtin/fetch.c:166
+msgid "allow updating of HEAD ref"
+msgstr "Aktualisierung der \"HEAD\"-Referenz erlauben"
+
+#: builtin/fetch.c:169 builtin/fetch.c:175 builtin/pull.c:228
+msgid "deepen history of shallow clone"
 msgstr ""
-"Änderungen in Submodulen ignorieren, optional wenn: all, dirty, untracked. "
-"(Standard: all)"
+"die Historie eines Klons mit unvollständiger Historie (shallow) vertiefen"
 
-#: builtin/commit.c:1304
-msgid "list untracked files in columns"
-msgstr "unversionierte Dateien in Spalten auflisten"
+#: builtin/fetch.c:171
+msgid "deepen history of shallow repository based on time"
+msgstr ""
+"die Historie eines Klons mit unvollständiger Historie (shallow) auf "
+"Zeitbasis\n"
+"vertiefen"
 
-#: builtin/commit.c:1323
-msgid "Unsupported combination of ignored and untracked-files arguments"
+#: builtin/fetch.c:177 builtin/pull.c:231
+msgid "convert to a complete repository"
+msgstr "zu einem vollständigen Repository konvertieren"
+
+#: builtin/fetch.c:180
+msgid "prepend this to submodule path output"
+msgstr "dies an die Ausgabe der Submodul-Pfade voranstellen"
+
+#: builtin/fetch.c:183
+msgid ""
+"default for recursive fetching of submodules (lower priority than config "
+"files)"
 msgstr ""
-"Nicht unterstützte Kombination von ignored und untracked-files Argumenten."
+"Standard für die rekursive Anforderung von Submodulen (geringere Priorität\n"
+"als Konfigurationsdateien)"
 
-#: builtin/commit.c:1413
-msgid "suppress summary after successful commit"
-msgstr "Zusammenfassung nach erfolgreichem Commit unterdrücken"
+#: builtin/fetch.c:187 builtin/pull.c:234
+msgid "accept refs that update .git/shallow"
+msgstr "Referenzen, die .git/shallow aktualisieren, akzeptieren"
 
-#: builtin/commit.c:1414
-msgid "show diff in commit message template"
-msgstr "Unterschiede in Commit-Beschreibungsvorlage anzeigen"
+#: builtin/fetch.c:188 builtin/pull.c:236
+msgid "refmap"
+msgstr "Refmap"
 
-#: builtin/commit.c:1416
-msgid "Commit message options"
-msgstr "Optionen für Commit-Beschreibung"
+#: builtin/fetch.c:189 builtin/pull.c:237
+msgid "specify fetch refmap"
+msgstr "Refmap für 'fetch' angeben"
 
-#: builtin/commit.c:1417 builtin/tag.c:393
-msgid "read message from file"
-msgstr "Beschreibung von Datei lesen"
+#: builtin/fetch.c:196
+msgid "report that we have only objects reachable from this object"
+msgstr ""
+"ausgeben, dass wir nur Objekte haben, die von diesem Objekt aus erreichbar "
+"sind"
 
-#: builtin/commit.c:1418
-msgid "author"
-msgstr "Autor"
+#: builtin/fetch.c:199
+msgid "run 'gc --auto' after fetching"
+msgstr "Führe 'gc --auto' nach \"fetch\" aus"
 
-#: builtin/commit.c:1418
-msgid "override author for commit"
-msgstr "Autor eines Commits überschreiben"
+#: builtin/fetch.c:201 builtin/pull.c:246
+msgid "check for forced-updates on all updated branches"
+msgstr "Prüfe auf erzwungene Aktualisierungen in allen aktualisierten Branches"
 
-#: builtin/commit.c:1419 builtin/gc.c:359
-msgid "date"
-msgstr "Datum"
+#: builtin/fetch.c:203
+msgid "write the commit-graph after fetching"
+msgstr "Schreibe den Commit-Graph nach \"fetch\""
 
-#: builtin/commit.c:1419
-msgid "override date for commit"
-msgstr "Datum eines Commits überschreiben"
+#: builtin/fetch.c:513
+msgid "Couldn't find remote ref HEAD"
+msgstr "Konnte Remote-Referenz von HEAD nicht finden."
 
-#: builtin/commit.c:1420 builtin/merge.c:226 builtin/notes.c:402
-#: builtin/notes.c:565 builtin/tag.c:391
-msgid "message"
-msgstr "Beschreibung"
+#: builtin/fetch.c:653
+#, c-format
+msgid "configuration fetch.output contains invalid value %s"
+msgstr "Konfiguration fetch.output enthält ungültigen Wert %s"
 
-#: builtin/commit.c:1420
-msgid "commit message"
-msgstr "Commit-Beschreibung"
+#: builtin/fetch.c:751
+#, c-format
+msgid "object %s not found"
+msgstr "Objekt %s nicht gefunden"
 
-#: builtin/commit.c:1421 builtin/commit.c:1422 builtin/commit.c:1423
-#: builtin/commit.c:1424 parse-options.h:269 ref-filter.h:92
-msgid "commit"
-msgstr "Commit"
+#: builtin/fetch.c:755
+msgid "[up to date]"
+msgstr "[aktuell]"
 
-#: builtin/commit.c:1421
-msgid "reuse and edit message from specified commit"
-msgstr "Beschreibung des angegebenen Commits wiederverwenden und editieren"
+#: builtin/fetch.c:768 builtin/fetch.c:784 builtin/fetch.c:856
+msgid "[rejected]"
+msgstr "[zurückgewiesen]"
 
-#: builtin/commit.c:1422
-msgid "reuse message from specified commit"
-msgstr "Beschreibung des angegebenen Commits wiederverwenden"
+#: builtin/fetch.c:769
+msgid "can't fetch in current branch"
+msgstr "kann \"fetch\" im aktuellen Branch nicht ausführen"
 
-#: builtin/commit.c:1423
-msgid "use autosquash formatted message to fixup specified commit"
-msgstr ""
-"eine automatisch zusammengesetzte Beschreibung zum Nachbessern des "
-"angegebenen Commits verwenden"
+#: builtin/fetch.c:779
+msgid "[tag update]"
+msgstr "[Tag Aktualisierung]"
 
-#: builtin/commit.c:1424
-msgid "use autosquash formatted message to squash specified commit"
-msgstr ""
-"eine automatisch zusammengesetzte Beschreibung beim \"squash\" des "
-"angegebenen Commits verwenden"
+#: builtin/fetch.c:780 builtin/fetch.c:817 builtin/fetch.c:839
+#: builtin/fetch.c:851
+msgid "unable to update local ref"
+msgstr "kann lokale Referenz nicht aktualisieren"
 
-#: builtin/commit.c:1425
-msgid "the commit is authored by me now (used with -C/-c/--amend)"
-msgstr "Sie als Autor des Commits setzen (verwendet mit -C/-c/--amend)"
+#: builtin/fetch.c:784
+msgid "would clobber existing tag"
+msgstr "würde bestehende Tags verändern"
+
+#: builtin/fetch.c:806
+msgid "[new tag]"
+msgstr "[neues Tag]"
 
-#: builtin/commit.c:1426 builtin/log.c:1446 builtin/merge.c:240
-#: builtin/pull.c:149 builtin/revert.c:105
-msgid "add Signed-off-by:"
-msgstr "'Signed-off-by:'-Zeile hinzufügen"
+#: builtin/fetch.c:809
+msgid "[new branch]"
+msgstr "[neuer Branch]"
 
-#: builtin/commit.c:1427
-msgid "use specified template file"
-msgstr "angegebene Vorlagendatei verwenden"
+#: builtin/fetch.c:812
+msgid "[new ref]"
+msgstr "[neue Referenz]"
 
-#: builtin/commit.c:1428
-msgid "force edit of commit"
-msgstr "Bearbeitung des Commits erzwingen"
+#: builtin/fetch.c:851
+msgid "forced update"
+msgstr "Aktualisierung erzwungen"
 
-#: builtin/commit.c:1429
-msgid "default"
-msgstr "Standard"
+#: builtin/fetch.c:856
+msgid "non-fast-forward"
+msgstr "kein Vorspulen"
 
-#: builtin/commit.c:1429 builtin/tag.c:397
-msgid "how to strip spaces and #comments from message"
+#: builtin/fetch.c:877
+msgid ""
+"Fetch normally indicates which branches had a forced update,\n"
+"but that check has been disabled. To re-enable, use '--show-forced-updates'\n"
+"flag or run 'git config fetch.showForcedUpdates true'."
 msgstr ""
-"wie Leerzeichen und #Kommentare von der Beschreibung getrennt werden sollen"
+"Normalerweise zeigt 'fetch' welche Branches eine erzwungene Aktualisierung\n"
+"hatten, aber diese Überprüfung wurde deaktiviert. Um diese wieder zu\n"
+"aktivieren, nutzen Sie die Option '--show-forced-updated' oder führen\n"
+"Sie 'git config fetch.showForcedUpdates true' aus."
 
-#: builtin/commit.c:1430
-msgid "include status in commit message template"
-msgstr "Status in die Commit-Beschreibungsvorlage einfügen"
+#: builtin/fetch.c:881
+#, c-format
+msgid ""
+"It took %.2f seconds to check forced updates. You can use\n"
+"'--no-show-forced-updates' or run 'git config fetch.showForcedUpdates "
+"false'\n"
+" to avoid this check.\n"
+msgstr ""
+"Es brauchte %.2f Sekunden, um erzwungene Aktualisierungen zu überprüfen.\n"
+"Sie können die Option '--no-show-forced-updates' benutzen oder\n"
+"'git config fetch.showForcedUpdates false' ausführen, um diese Überprüfung\n"
+"zu umgehen.\n"
 
-#: builtin/commit.c:1432 builtin/merge.c:238 builtin/pull.c:179
-#: builtin/revert.c:113
-msgid "GPG sign commit"
-msgstr "Commit mit GPG signieren"
+#: builtin/fetch.c:911
+#, c-format
+msgid "%s did not send all necessary objects\n"
+msgstr "%s hat nicht alle erforderlichen Objekte gesendet\n"
 
-#: builtin/commit.c:1435
-msgid "Commit contents options"
-msgstr "Optionen für Commit-Inhalt"
+#: builtin/fetch.c:932
+#, c-format
+msgid "reject %s because shallow roots are not allowed to be updated"
+msgstr ""
+"%s wurde zurückgewiesen, da Root-Commits von Repositories mit "
+"unvollständiger\n"
+"Historie (shallow) nicht aktualisiert werden dürfen."
 
-#: builtin/commit.c:1436
-msgid "commit all changed files"
-msgstr "alle geänderten Dateien committen"
+#: builtin/fetch.c:1017 builtin/fetch.c:1155
+#, c-format
+msgid "From %.*s\n"
+msgstr "Von %.*s\n"
 
-#: builtin/commit.c:1437
-msgid "add specified files to index for commit"
-msgstr "die angegebenen Dateien zusätzlich zum Commit vormerken"
+#: builtin/fetch.c:1028
+#, c-format
+msgid ""
+"some local refs could not be updated; try running\n"
+" 'git remote prune %s' to remove any old, conflicting branches"
+msgstr ""
+"Einige lokale Referenzen konnten nicht aktualisiert werden; versuchen Sie\n"
+"'git remote prune %s', um jeden älteren, widersprüchlichen Branch zu löschen."
 
-#: builtin/commit.c:1438
-msgid "interactively add files"
-msgstr "interaktives Hinzufügen von Dateien"
+#: builtin/fetch.c:1125
+#, c-format
+msgid "   (%s will become dangling)"
+msgstr "   (%s wird unreferenziert)"
 
-#: builtin/commit.c:1439
-msgid "interactively add changes"
-msgstr "interaktives Hinzufügen von Änderungen"
+#: builtin/fetch.c:1126
+#, c-format
+msgid "   (%s has become dangling)"
+msgstr "   (%s wurde unreferenziert)"
 
-#: builtin/commit.c:1440
-msgid "commit only specified files"
-msgstr "nur die angegebenen Dateien committen"
+#: builtin/fetch.c:1158
+msgid "[deleted]"
+msgstr "[gelöscht]"
 
-#: builtin/commit.c:1441
-msgid "bypass pre-commit and commit-msg hooks"
-msgstr "Hooks pre-commit und commit-msg umgehen"
+#: builtin/fetch.c:1159 builtin/remote.c:1035
+msgid "(none)"
+msgstr "(nichts)"
 
-#: builtin/commit.c:1442
-msgid "show what would be committed"
-msgstr "anzeigen, was committet werden würde"
+#: builtin/fetch.c:1182
+#, c-format
+msgid "Refusing to fetch into current branch %s of non-bare repository"
+msgstr ""
+"Der \"fetch\" in den aktuellen Branch %s von einem Nicht-Bare-Repository "
+"wurde verweigert."
 
-#: builtin/commit.c:1455
-msgid "amend previous commit"
-msgstr "vorherigen Commit ändern"
+#: builtin/fetch.c:1201
+#, c-format
+msgid "Option \"%s\" value \"%s\" is not valid for %s"
+msgstr "Option \"%s\" Wert \"%s\" ist nicht gültig für %s"
 
-#: builtin/commit.c:1456
-msgid "bypass post-rewrite hook"
-msgstr "\"post-rewrite hook\" umgehen"
+#: builtin/fetch.c:1204
+#, c-format
+msgid "Option \"%s\" is ignored for %s\n"
+msgstr "Option \"%s\" wird ignoriert für %s\n"
 
-#: builtin/commit.c:1461
-msgid "ok to record an empty change"
-msgstr "Aufzeichnung einer leeren Änderung erlauben"
+#: builtin/fetch.c:1412
+msgid "multiple branches detected, incompatible with --set-upstream"
+msgstr "Mehrere Branches erkannt, inkompatibel mit --set-upstream"
 
-#: builtin/commit.c:1463
-msgid "ok to record a change with an empty message"
-msgstr "Aufzeichnung einer Änderung mit einer leeren Beschreibung erlauben"
+#: builtin/fetch.c:1427
+msgid "not setting upstream for a remote remote-tracking branch"
+msgstr "Setze keinen Upstream für einen entfernten Remote-Tracking-Branch."
 
-#: builtin/commit.c:1536
-#, c-format
-msgid "Corrupt MERGE_HEAD file (%s)"
-msgstr "Beschädigte MERGE_HEAD-Datei (%s)"
+#: builtin/fetch.c:1429
+msgid "not setting upstream for a remote tag"
+msgstr "Setze keinen Upstream für einen Tag eines Remote-Repositories."
 
-#: builtin/commit.c:1543
-msgid "could not read MERGE_MODE"
-msgstr "Konnte MERGE_MODE nicht lesen"
+#: builtin/fetch.c:1431
+msgid "unknown branch type"
+msgstr "Unbekannter Branch-Typ"
+
+#: builtin/fetch.c:1433
+msgid ""
+"no source branch found.\n"
+"you need to specify exactly one branch with the --set-upstream option."
+msgstr ""
+"Keinen Quell-Branch gefunden.\n"
+"Sie müssen bei der Option --set-upstream genau einen Branch angeben."
 
-#: builtin/commit.c:1562
+#: builtin/fetch.c:1559 builtin/fetch.c:1622
 #, c-format
-msgid "could not read commit message: %s"
-msgstr "Konnte Commit-Beschreibung nicht lesen: %s"
+msgid "Fetching %s\n"
+msgstr "Fordere an von %s\n"
 
-#: builtin/commit.c:1573
+#: builtin/fetch.c:1569 builtin/fetch.c:1624 builtin/remote.c:100
 #, c-format
-msgid "Aborting commit due to empty commit message.\n"
-msgstr "Commit aufgrund leerer Beschreibung abgebrochen.\n"
+msgid "Could not fetch %s"
+msgstr "Konnte nicht von %s anfordern"
 
-#: builtin/commit.c:1578
+#: builtin/fetch.c:1581
 #, c-format
-msgid "Aborting commit; you did not edit the message.\n"
-msgstr "Commit abgebrochen; Sie haben die Beschreibung nicht editiert.\n"
+msgid "could not fetch '%s' (exit code: %d)\n"
+msgstr "Konnte '%s' nicht anfordern (Exit-Code: %d)\n"
 
-#: builtin/commit.c:1613
+#: builtin/fetch.c:1684
 msgid ""
-"Repository has been updated, but unable to write\n"
-"new_index file. Check that disk is not full and quota is\n"
-"not exceeded, and then \"git reset HEAD\" to recover."
+"No remote repository specified.  Please, specify either a URL or a\n"
+"remote name from which new revisions should be fetched."
 msgstr ""
-"Das Repository wurde aktualisiert, aber die \"new_index\"-Datei\n"
-"konnte nicht geschrieben werden. Prüfen Sie, dass Ihre Festplatte nicht\n"
-"voll und Ihr Kontingent nicht aufgebraucht ist und führen Sie\n"
-"anschließend \"git reset HEAD\" zu Wiederherstellung aus."
+"Kein Remote-Repository angegeben. Bitte geben Sie entweder eine URL\n"
+"oder den Namen des Remote-Repositories an, von welchem neue\n"
+"Commits angefordert werden sollen."
 
-#: builtin/config.c:10
-msgid "git config [<options>]"
-msgstr "git config [<Optionen>]"
+#: builtin/fetch.c:1721
+msgid "You need to specify a tag name."
+msgstr "Sie müssen den Namen des Tags angeben."
 
-#: builtin/config.c:58
-msgid "Config file location"
-msgstr "Ort der Konfigurationsdatei"
+#: builtin/fetch.c:1771
+msgid "Negative depth in --deepen is not supported"
+msgstr "Negative Tiefe wird von --deepen nicht unterstützt."
 
-#: builtin/config.c:59
-msgid "use global config file"
-msgstr "globale Konfigurationsdatei verwenden"
+#: builtin/fetch.c:1773
+msgid "--deepen and --depth are mutually exclusive"
+msgstr "--deepen und --depth schließen sich gegenseitig aus"
 
-#: builtin/config.c:60
-msgid "use system config file"
-msgstr "systemweite Konfigurationsdatei verwenden"
+#: builtin/fetch.c:1778
+msgid "--depth and --unshallow cannot be used together"
+msgstr ""
+"Die Optionen --depth und --unshallow können nicht gemeinsam verwendet werden."
 
-#: builtin/config.c:61
-msgid "use repository config file"
-msgstr "Konfigurationsdatei des Repositories verwenden"
+#: builtin/fetch.c:1780
+msgid "--unshallow on a complete repository does not make sense"
+msgstr ""
+"Die Option --unshallow kann nicht in einem Repository mit vollständiger "
+"Historie verwendet werden."
 
-#: builtin/config.c:62
-msgid "use given config file"
-msgstr "die angegebene Konfigurationsdatei verwenden"
+#: builtin/fetch.c:1796
+msgid "fetch --all does not take a repository argument"
+msgstr "fetch --all akzeptiert kein Repository als Argument"
 
-#: builtin/config.c:63
-msgid "blob-id"
-msgstr "Blob-Id"
+#: builtin/fetch.c:1798
+msgid "fetch --all does not make sense with refspecs"
+msgstr "fetch --all kann nicht mit Refspecs verwendet werden."
 
-#: builtin/config.c:63
-msgid "read config from given blob object"
-msgstr "Konfiguration von angegebenem Blob-Objekt lesen"
+#: builtin/fetch.c:1807
+#, c-format
+msgid "No such remote or remote group: %s"
+msgstr "Kein Remote-Repository (einzeln oder Gruppe): %s"
 
-#: builtin/config.c:64
-msgid "Action"
-msgstr "Aktion"
+#: builtin/fetch.c:1814
+msgid "Fetching a group and specifying refspecs does not make sense"
+msgstr ""
+"Das Abholen einer Gruppe von Remote-Repositories kann nicht mit der Angabe\n"
+"von Refspecs verwendet werden."
 
-#: builtin/config.c:65
-msgid "get value: name [value-regex]"
-msgstr "Wert zurückgeben: Name [Wert-regex]"
+#: builtin/fetch.c:1832
+msgid ""
+"--filter can only be used with the remote configured in extensions."
+"partialclone"
+msgstr ""
+"--filter kann nur mit den Remote-Repositories verwendet werden,\n"
+"die in core.partialClone konfiguriert sind."
 
-#: builtin/config.c:66
-msgid "get all values: key [value-regex]"
-msgstr "alle Werte zurückgeben: Schlüssel [Wert-regex]"
+#: builtin/fmt-merge-msg.c:18
+msgid ""
+"git fmt-merge-msg [-m <message>] [--log[=<n>] | --no-log] [--file <file>]"
+msgstr ""
+"git fmt-merge-msg [-m <Beschreibung>] [--log[=<n>] | --no-log] [--file "
+"<Datei>]"
 
-#: builtin/config.c:67
-msgid "get values for regexp: name-regex [value-regex]"
-msgstr "Werte für den regulären Ausdruck zurückgeben: Name-regex [Wert-regex]"
+#: builtin/fmt-merge-msg.c:674
+msgid "populate log with at most <n> entries from shortlog"
+msgstr "Historie mit höchstens <n> Einträgen von \"shortlog\" hinzufügen"
 
-#: builtin/config.c:68
-msgid "get value specific for the URL: section[.var] URL"
-msgstr "Wert spezifisch für eine URL zurückgeben: section[.var] URL"
+#: builtin/fmt-merge-msg.c:677
+msgid "alias for --log (deprecated)"
+msgstr "Alias für --log (veraltet)"
 
-#: builtin/config.c:69
-msgid "replace all matching variables: name value [value_regex]"
-msgstr "alle passenden Variablen ersetzen: Name Wert [Wert-regex] "
+#: builtin/fmt-merge-msg.c:680
+msgid "text"
+msgstr "Text"
 
-#: builtin/config.c:70
-msgid "add a new variable: name value"
-msgstr "neue Variable hinzufügen: Name Wert"
+#: builtin/fmt-merge-msg.c:681
+msgid "use <text> as start of message"
+msgstr "<Text> als Beschreibungsanfang verwenden"
 
-#: builtin/config.c:71
-msgid "remove a variable: name [value-regex]"
-msgstr "eine Variable entfernen: Name [Wert-regex]"
+#: builtin/fmt-merge-msg.c:682
+msgid "file to read from"
+msgstr "Datei zum Einlesen"
 
-#: builtin/config.c:72
-msgid "remove all matches: name [value-regex]"
-msgstr "alle Übereinstimmungen entfernen: Name [Wert-regex]"
+#: builtin/for-each-ref.c:10
+msgid "git for-each-ref [<options>] [<pattern>]"
+msgstr "git for-each-ref [<Optionen>] [<Muster>]"
 
-#: builtin/config.c:73
-msgid "rename section: old-name new-name"
-msgstr "eine Sektion umbenennen: alter-Name neuer-Name"
+#: builtin/for-each-ref.c:11
+msgid "git for-each-ref [--points-at <object>]"
+msgstr "git for-each-ref [--points-at <Objekt>]"
 
-#: builtin/config.c:74
-msgid "remove a section: name"
-msgstr "eine Sektion entfernen: Name"
+#: builtin/for-each-ref.c:12
+msgid "git for-each-ref [(--merged | --no-merged) [<commit>]]"
+msgstr "git for-each-ref [(--merged | --no-merged) [<Commit>]]"
 
-#: builtin/config.c:75
-msgid "list all"
-msgstr "alles auflisten"
+#: builtin/for-each-ref.c:13
+msgid "git for-each-ref [--contains [<commit>]] [--no-contains [<commit>]]"
+msgstr "git for-each-ref [--contains [<Objekt>]] [--no-contains [<Commit>]]"
 
-#: builtin/config.c:76
-msgid "open an editor"
-msgstr "einen Editor öffnen"
+#: builtin/for-each-ref.c:28
+msgid "quote placeholders suitably for shells"
+msgstr "Platzhalter als Shell-String formatieren"
 
-#: builtin/config.c:77
-msgid "find the color configured: slot [default]"
-msgstr "die konfigurierte Farbe finden: Slot [Standard]"
+#: builtin/for-each-ref.c:30
+msgid "quote placeholders suitably for perl"
+msgstr "Platzhalter als Perl-String formatieren"
 
-#: builtin/config.c:78
-msgid "find the color setting: slot [stdout-is-tty]"
-msgstr "die Farbeinstellung finden: Slot [Standard-Ausgabe-ist-Terminal]"
+#: builtin/for-each-ref.c:32
+msgid "quote placeholders suitably for python"
+msgstr "Platzhalter als Python-String formatieren"
 
-#: builtin/config.c:79
-msgid "Type"
-msgstr "Typ"
+#: builtin/for-each-ref.c:34
+msgid "quote placeholders suitably for Tcl"
+msgstr "Platzhalter als Tcl-String formatieren"
 
-#: builtin/config.c:80
-msgid "value is \"true\" or \"false\""
-msgstr "Wert ist \"true\" oder \"false\""
+#: builtin/for-each-ref.c:37
+msgid "show only <n> matched refs"
+msgstr "nur <n> passende Referenzen anzeigen"
 
-#: builtin/config.c:81
-msgid "value is decimal number"
-msgstr "Wert ist eine Dezimalzahl"
+#: builtin/for-each-ref.c:39 builtin/tag.c:439
+msgid "respect format colors"
+msgstr "Formatfarben beachten"
 
-#: builtin/config.c:82
-msgid "value is --bool or --int"
-msgstr "Wert ist --bool oder --int"
+#: builtin/for-each-ref.c:42
+msgid "print only refs which points at the given object"
+msgstr "nur auf dieses Objekt zeigende Referenzen ausgeben"
 
-#: builtin/config.c:83
-msgid "value is a path (file or directory name)"
-msgstr "Wert ist ein Pfad (Datei oder Verzeichnisname)"
+#: builtin/for-each-ref.c:44
+msgid "print only refs that are merged"
+msgstr "nur zusammengeführte Referenzen ausgeben"
 
-#: builtin/config.c:84
-msgid "value is an expiry date"
-msgstr "Wert ist ein Verfallsdatum"
+#: builtin/for-each-ref.c:45
+msgid "print only refs that are not merged"
+msgstr "nur nicht zusammengeführte Referenzen ausgeben"
 
-#: builtin/config.c:85
-msgid "Other"
-msgstr "Sonstiges"
+#: builtin/for-each-ref.c:46
+msgid "print only refs which contain the commit"
+msgstr "nur Referenzen ausgeben, die diesen Commit enthalten"
+
+#: builtin/for-each-ref.c:47
+msgid "print only refs which don't contain the commit"
+msgstr "nur Referenzen ausgeben, die diesen Commit nicht enthalten"
 
-#: builtin/config.c:86
-msgid "terminate values with NUL byte"
-msgstr "schließt Werte mit NUL-Byte ab"
+#: builtin/fsck.c:68 builtin/fsck.c:147 builtin/fsck.c:148
+msgid "unknown"
+msgstr "unbekannt"
 
-#: builtin/config.c:87
-msgid "show variable names only"
-msgstr "nur Variablennamen anzeigen"
+#. TRANSLATORS: e.g. error in tree 01bfda: <more explanation>
+#: builtin/fsck.c:100 builtin/fsck.c:120
+#, c-format
+msgid "error in %s %s: %s"
+msgstr "Fehler in %s %s: %s"
 
-#: builtin/config.c:88
-msgid "respect include directives on lookup"
-msgstr "beachtet \"include\"-Direktiven beim Nachschlagen"
+#. TRANSLATORS: e.g. warning in tree 01bfda: <more explanation>
+#: builtin/fsck.c:114
+#, c-format
+msgid "warning in %s %s: %s"
+msgstr "Warnung in %s %s: %s"
 
-#: builtin/config.c:89
-msgid "show origin of config (file, standard input, blob, command line)"
-msgstr ""
-"Ursprung der Konfiguration anzeigen (Datei, Standard-Eingabe, Blob, "
-"Befehlszeile)"
+#: builtin/fsck.c:143 builtin/fsck.c:146
+#, c-format
+msgid "broken link from %7s %s"
+msgstr "Fehlerhafte Verknüpfung von %7s %s"
 
-#: builtin/config.c:335
-msgid "unable to parse default color value"
-msgstr "konnte Standard-Farbwert nicht parsen"
+#: builtin/fsck.c:155
+msgid "wrong object type in link"
+msgstr "Falscher Objekttyp in Verknüpfung."
 
-#: builtin/config.c:479
+#: builtin/fsck.c:171
 #, c-format
 msgid ""
-"# This is Git's per-user configuration file.\n"
-"[user]\n"
-"# Please adapt and uncomment the following lines:\n"
-"#\tname = %s\n"
-"#\temail = %s\n"
+"broken link from %7s %s\n"
+"              to %7s %s"
 msgstr ""
-"# Das ist Git's benutzerspezifische Konfigurationsdatei.\n"
-"[user]\n"
-"# Bitte passen Sie die folgenden Zeilen an und kommentieren Sie diese aus:\n"
-"#\tname = %s\n"
-"#\temail = %s\n"
+"Fehlerhafte Verknüpfung von %7s %s\n"
+"                       nach %7s %s"
 
-#: builtin/config.c:507
-msgid "--local can only be used inside a git repository"
-msgstr "--local kann nur innerhalb eines Git-Repositories verwendet werden."
+#: builtin/fsck.c:282
+#, c-format
+msgid "missing %s %s"
+msgstr "%s %s fehlt"
 
-#: builtin/config.c:632
+#: builtin/fsck.c:309
 #, c-format
-msgid "cannot create configuration file %s"
-msgstr "Konnte Konfigurationsdatei '%s' nicht erstellen."
+msgid "unreachable %s %s"
+msgstr "%s %s nicht erreichbar"
 
-#: builtin/config.c:645
+#: builtin/fsck.c:329
 #, c-format
-msgid ""
-"cannot overwrite multiple values with a single value\n"
-"       Use a regexp, --add or --replace-all to change %s."
-msgstr ""
-"kann nicht mehrere Werte mit einem einzigen Wert überschreiben\n"
-"       Benutzen Sie einen regulären Ausdruck, --add oder --replace, um %s\n"
-"       zu ändern."
+msgid "dangling %s %s"
+msgstr "%s %s unreferenziert"
 
-#: builtin/count-objects.c:88
-msgid "git count-objects [-v] [-H | --human-readable]"
-msgstr "git count-objects [-v] [-H | --human-readable]"
+#: builtin/fsck.c:339
+msgid "could not create lost-found"
+msgstr "Konnte lost-found nicht erstellen."
 
-#: builtin/count-objects.c:98
-msgid "print sizes in human readable format"
-msgstr "gibt Größenangaben in menschenlesbaren Format aus"
+#: builtin/fsck.c:350
+#, c-format
+msgid "could not finish '%s'"
+msgstr "Konnte '%s' nicht abschließen."
 
-#: builtin/describe.c:22
-msgid "git describe [<options>] [<commit-ish>...]"
-msgstr "git describe [<Optionen>] [<Commit-Angabe>...]"
+#: builtin/fsck.c:367
+#, c-format
+msgid "Checking %s"
+msgstr "Prüfe %s"
 
-#: builtin/describe.c:23
-msgid "git describe [<options>] --dirty"
-msgstr "git describe [<Optionen>] --dirty"
+#: builtin/fsck.c:405
+#, c-format
+msgid "Checking connectivity (%d objects)"
+msgstr "Prüfe Konnektivität (%d Objekte)"
 
-#: builtin/describe.c:57
-msgid "head"
-msgstr "Branch"
+#: builtin/fsck.c:424
+#, c-format
+msgid "Checking %s %s"
+msgstr "Prüfe %s %s"
 
-#: builtin/describe.c:57
-msgid "lightweight"
-msgstr "nicht-annotiert"
+#: builtin/fsck.c:429
+msgid "broken links"
+msgstr "Fehlerhafte Verknüpfungen"
 
-#: builtin/describe.c:57
-msgid "annotated"
-msgstr "annotiert"
+#: builtin/fsck.c:438
+#, c-format
+msgid "root %s"
+msgstr "Wurzel %s"
 
-#: builtin/describe.c:267
+#: builtin/fsck.c:446
 #, c-format
-msgid "annotated tag %s not available"
-msgstr "annotiertes Tag %s ist nicht verfügbar"
+msgid "tagged %s %s (%s) in %s"
+msgstr "%s %s (%s) in %s getaggt"
 
-#: builtin/describe.c:271
+#: builtin/fsck.c:475
 #, c-format
-msgid "annotated tag %s has no embedded name"
-msgstr "annotiertes Tag %s hat keinen eingebetteten Namen"
+msgid "%s: object corrupt or missing"
+msgstr "%s: Objekt fehlerhaft oder nicht vorhanden"
 
-#: builtin/describe.c:273
+#: builtin/fsck.c:500
 #, c-format
-msgid "tag '%s' is really '%s' here"
-msgstr "Tag '%s' ist eigentlich '%s' hier"
+msgid "%s: invalid reflog entry %s"
+msgstr "%s: Ungültiger Reflog-Eintrag %s"
 
-#: builtin/describe.c:317
+#: builtin/fsck.c:514
 #, c-format
-msgid "no tag exactly matches '%s'"
-msgstr "kein Tag entspricht exakt '%s'"
+msgid "Checking reflog %s->%s"
+msgstr "Prüfe Reflog %s->%s"
 
-#: builtin/describe.c:319
+#: builtin/fsck.c:548
 #, c-format
-msgid "No exact match on refs or tags, searching to describe\n"
-msgstr ""
-"Keine exakte Übereinstimmung bei Referenzen oder Tags, Suche zum "
-"Beschreiben\n"
+msgid "%s: invalid sha1 pointer %s"
+msgstr "%s: Ungültiger SHA1-Zeiger %s"
 
-#: builtin/describe.c:366
+#: builtin/fsck.c:555
 #, c-format
-msgid "finished search at %s\n"
-msgstr "beendete Suche bei %s\n"
+msgid "%s: not a commit"
+msgstr "%s: kein Commit"
 
-#: builtin/describe.c:392
+#: builtin/fsck.c:609
+msgid "notice: No default references"
+msgstr "Notiz: Keine Standardreferenzen"
+
+#: builtin/fsck.c:624
 #, c-format
-msgid ""
-"No annotated tags can describe '%s'.\n"
-"However, there were unannotated tags: try --tags."
-msgstr ""
-"Keine annotierten Tags können '%s' beschreiben.\n"
-"Jedoch gab es nicht-annotierte Tags: versuchen Sie --tags."
+msgid "%s: object corrupt or missing: %s"
+msgstr "%s: Objekt fehlerhaft oder nicht vorhanden: %s"
 
-#: builtin/describe.c:396
+#: builtin/fsck.c:637
 #, c-format
-msgid ""
-"No tags can describe '%s'.\n"
-"Try --always, or create some tags."
-msgstr ""
-"Keine Tags können '%s' beschreiben.\n"
-"Versuchen Sie --always oder erstellen Sie einige Tags."
+msgid "%s: object could not be parsed: %s"
+msgstr "%s: Objekt konnte nicht geparst werden: %s"
 
-#: builtin/describe.c:426
+#: builtin/fsck.c:657
 #, c-format
-msgid "traversed %lu commits\n"
-msgstr "%lu Commits durchlaufen\n"
+msgid "bad sha1 file: %s"
+msgstr "Ungültige SHA1-Datei: %s"
+
+#: builtin/fsck.c:672
+msgid "Checking object directory"
+msgstr "Prüfe Objekt-Verzeichnis"
+
+#: builtin/fsck.c:675
+msgid "Checking object directories"
+msgstr "Prüfe Objekt-Verzeichnisse"
 
-#: builtin/describe.c:429
+#: builtin/fsck.c:690
 #, c-format
-msgid ""
-"more than %i tags found; listed %i most recent\n"
-"gave up search at %s\n"
-msgstr ""
-"mehr als %i Tags gefunden; führe die ersten %i auf\n"
-"Suche bei %s aufgegeben\n"
+msgid "Checking %s link"
+msgstr "Prüfe %s Verknüpfung"
 
-#: builtin/describe.c:497
+#: builtin/fsck.c:695 builtin/index-pack.c:842
 #, c-format
-msgid "describe %s\n"
-msgstr "Beschreibe %s\n"
+msgid "invalid %s"
+msgstr "Ungültiger Objekt-Typ %s"
 
-#: builtin/describe.c:500 builtin/log.c:502
+#: builtin/fsck.c:702
 #, c-format
-msgid "Not a valid object name %s"
-msgstr "%s ist kein gültiger Objekt-Name"
+msgid "%s points to something strange (%s)"
+msgstr "%s zeigt auf etwas seltsames (%s)"
 
-#: builtin/describe.c:508
+#: builtin/fsck.c:708
 #, c-format
-msgid "%s is neither a commit nor blob"
-msgstr "%s ist weder ein Commit, noch ein Blob."
+msgid "%s: detached HEAD points at nothing"
+msgstr "%s: losgelöster HEAD zeigt auf nichts"
 
-#: builtin/describe.c:522
-msgid "find the tag that comes after the commit"
-msgstr "das Tag finden, das nach dem Commit kommt"
+#: builtin/fsck.c:712
+#, c-format
+msgid "notice: %s points to an unborn branch (%s)"
+msgstr "Notiz: %s zeigt auf einen ungeborenen Branch (%s)"
 
-#: builtin/describe.c:523
-msgid "debug search strategy on stderr"
-msgstr "die Suchstrategie in der Standard-Fehlerausgabe protokollieren"
+#: builtin/fsck.c:724
+msgid "Checking cache tree"
+msgstr "Prüfe Cache-Verzeichnis"
 
-#: builtin/describe.c:524
-msgid "use any ref"
-msgstr "alle Referenzen verwenden"
+#: builtin/fsck.c:729
+#, c-format
+msgid "%s: invalid sha1 pointer in cache-tree"
+msgstr "%s: Ungültiger SHA1-Zeiger in Cache-Verzeichnis"
 
-#: builtin/describe.c:525
-msgid "use any tag, even unannotated"
-msgstr "jedes Tag verwenden, auch nicht-annotierte"
+#: builtin/fsck.c:738
+msgid "non-tree in cache-tree"
+msgstr "non-tree in Cache-Verzeichnis"
 
-#: builtin/describe.c:526
-msgid "always use long format"
-msgstr "immer langes Format verwenden"
+#: builtin/fsck.c:769
+msgid "git fsck [<options>] [<object>...]"
+msgstr "git fsck [<Optionen>] [<Objekt>...]"
 
-#: builtin/describe.c:527
-msgid "only follow first parent"
-msgstr "nur erstem Elternteil folgen"
+#: builtin/fsck.c:775
+msgid "show unreachable objects"
+msgstr "unerreichbare Objekte anzeigen"
 
-#: builtin/describe.c:530
-msgid "only output exact matches"
-msgstr "nur exakte Übereinstimmungen ausgeben"
+#: builtin/fsck.c:776
+msgid "show dangling objects"
+msgstr "unreferenzierte Objekte anzeigen"
 
-#: builtin/describe.c:532
-msgid "consider <n> most recent tags (default: 10)"
-msgstr "die jüngsten <n> Tags betrachten (Standard: 10)"
+#: builtin/fsck.c:777
+msgid "report tags"
+msgstr "Tags melden"
 
-#: builtin/describe.c:534
-msgid "only consider tags matching <pattern>"
-msgstr "nur Tags, die <Muster> entsprechen, betrachten"
+#: builtin/fsck.c:778
+msgid "report root nodes"
+msgstr "Hauptwurzeln melden"
 
-#: builtin/describe.c:536
-msgid "do not consider tags matching <pattern>"
-msgstr "keine Tags betrachten, die <Muster> entsprechen"
+#: builtin/fsck.c:779
+msgid "make index objects head nodes"
+msgstr "Index-Objekte in Erreichbarkeitsprüfung einbeziehen"
 
-#: builtin/describe.c:538 builtin/name-rev.c:406
-msgid "show abbreviated commit object as fallback"
-msgstr "gekürztes Commit-Objekt anzeigen, wenn sonst nichts zutrifft"
+#: builtin/fsck.c:780
+msgid "make reflogs head nodes (default)"
+msgstr "Reflogs in Erreichbarkeitsprüfung einbeziehen (Standard)"
 
-#: builtin/describe.c:539 builtin/describe.c:542
-msgid "mark"
-msgstr "Kennzeichen"
+#: builtin/fsck.c:781
+msgid "also consider packs and alternate objects"
+msgstr "ebenso Pakete und alternative Objekte betrachten"
 
-#: builtin/describe.c:540
-msgid "append <mark> on dirty working tree (default: \"-dirty\")"
+#: builtin/fsck.c:782
+msgid "check only connectivity"
+msgstr "nur Konnektivität prüfen"
+
+#: builtin/fsck.c:783
+msgid "enable more strict checking"
+msgstr "genauere Prüfung aktivieren"
+
+#: builtin/fsck.c:785
+msgid "write dangling objects in .git/lost-found"
+msgstr "unreferenzierte Objekte nach .git/lost-found schreiben"
+
+#: builtin/fsck.c:786 builtin/prune.c:132
+msgid "show progress"
+msgstr "Fortschrittsanzeige anzeigen"
+
+#: builtin/fsck.c:787
+msgid "show verbose names for reachable objects"
+msgstr "ausführliche Namen für erreichbare Objekte anzeigen"
+
+#: builtin/fsck.c:846 builtin/index-pack.c:225
+msgid "Checking objects"
+msgstr "Prüfe Objekte"
+
+#: builtin/fsck.c:874
+#, c-format
+msgid "%s: object missing"
+msgstr "%s: Objekt nicht vorhanden"
+
+#: builtin/fsck.c:885
+#, c-format
+msgid "invalid parameter: expected sha1, got '%s'"
+msgstr "Ungültiger Parameter: SHA-1 erwartet, '%s' bekommen"
+
+#: builtin/gc.c:35
+msgid "git gc [<options>]"
+msgstr "git gc [<Optionen>]"
+
+#: builtin/gc.c:90
+#, c-format
+msgid "Failed to fstat %s: %s"
+msgstr "Konnte '%s' nicht lesen: %s"
+
+#: builtin/gc.c:126
+#, c-format
+msgid "failed to parse '%s' value '%s'"
+msgstr "Fehler beim Parsen von '%s' mit dem Wert '%s'"
+
+#: builtin/gc.c:475 builtin/init-db.c:55
+#, c-format
+msgid "cannot stat '%s'"
+msgstr "Kann '%s' nicht lesen"
+
+#: builtin/gc.c:484 builtin/notes.c:240 builtin/tag.c:529
+#, c-format
+msgid "cannot read '%s'"
+msgstr "kann '%s' nicht lesen"
+
+#: builtin/gc.c:491
+#, c-format
+msgid ""
+"The last gc run reported the following. Please correct the root cause\n"
+"and remove %s.\n"
+"Automatic cleanup will not be performed until the file is removed.\n"
+"\n"
+"%s"
 msgstr ""
-"<Kennzeichen> bei geändertem Arbeitsverzeichnis anhängen (Standard: \"-dirty"
-"\")"
+"Die letzte Ausführung von \"gc run\" enthielt die folgenden Meldungen.\n"
+"Bitte beheben Sie das Hauptproblem und löschen Sie %s.\n"
+"Ein automatischer Cleanup wird nicht ausgeführt, bis diese Datei entfernt\n"
+"wurde.\n"
+"\n"
+"%s"
 
-#: builtin/describe.c:543
-msgid "append <mark> on broken working tree (default: \"-broken\")"
+#: builtin/gc.c:539
+msgid "prune unreferenced objects"
+msgstr "unreferenzierte Objekte entfernen"
+
+#: builtin/gc.c:541
+msgid "be more thorough (increased runtime)"
+msgstr "mehr Gründlichkeit (erhöht Laufzeit)"
+
+#: builtin/gc.c:542
+msgid "enable auto-gc mode"
+msgstr "\"auto-gc\" Modus aktivieren"
+
+#: builtin/gc.c:545
+msgid "force running gc even if there may be another gc running"
 msgstr ""
-"<Kennzeichen> bei defektem Arbeitsverzeichnis anhängen (Standard: \"-broken"
-"\")"
+"Ausführung von \"git gc\" erzwingen, selbst wenn ein anderes\n"
+"\"git gc\" bereits ausgeführt wird"
 
-#: builtin/describe.c:561
-msgid "--long is incompatible with --abbrev=0"
-msgstr "Die Optionen --long und --abbrev=0 sind inkompatibel."
+#: builtin/gc.c:548
+msgid "repack all other packs except the largest pack"
+msgstr "alle anderen Pakete, außer das größte Paket, neu packen"
 
-#: builtin/describe.c:590
-msgid "No names found, cannot describe anything."
-msgstr "Keine Namen gefunden, kann nichts beschreiben."
+#: builtin/gc.c:565
+#, c-format
+msgid "failed to parse gc.logexpiry value %s"
+msgstr "Fehler beim Parsen des Wertes '%s' von gc.logexpiry."
 
-#: builtin/describe.c:640
-msgid "--dirty is incompatible with commit-ishes"
-msgstr "Die Option --dirty kann nicht mit Commits verwendet werden."
+#: builtin/gc.c:576
+#, c-format
+msgid "failed to parse prune expiry value %s"
+msgstr "Fehler beim Parsen des \"prune expiry\" Wertes %s"
 
-#: builtin/describe.c:642
-msgid "--broken is incompatible with commit-ishes"
-msgstr "Die Option --broken kann nicht mit Commits verwendet werden."
+#: builtin/gc.c:596
+#, c-format
+msgid "Auto packing the repository in background for optimum performance.\n"
+msgstr ""
+"Die Datenbank des Repositories wird für eine optimale Performance im\n"
+"Hintergrund komprimiert.\n"
 
-#: builtin/diff.c:83
+#: builtin/gc.c:598
 #, c-format
-msgid "'%s': not a regular file or symlink"
-msgstr "'%s': keine reguläre Datei oder symbolische Verknüpfung"
+msgid "Auto packing the repository for optimum performance.\n"
+msgstr ""
+"Die Datenbank des Projektarchivs wird für eine optimale Performance "
+"komprimiert.\n"
 
-#: builtin/diff.c:234
+#: builtin/gc.c:599
 #, c-format
-msgid "invalid option: %s"
-msgstr "Ungültige Option: %s"
+msgid "See \"git help gc\" for manual housekeeping.\n"
+msgstr "Siehe \"git help gc\" für manuelles Aufräumen.\n"
 
-#: builtin/diff.c:356
-msgid "Not a git repository"
-msgstr "Kein Git-Repository"
+#: builtin/gc.c:639
+#, c-format
+msgid ""
+"gc is already running on machine '%s' pid %<PRIuMAX> (use --force if not)"
+msgstr ""
+"\"git gc\" wird bereits auf Maschine '%s' pid %<PRIuMAX> ausgeführt\n"
+"(benutzen Sie --force falls nicht)"
+
+#: builtin/gc.c:694
+msgid ""
+"There are too many unreachable loose objects; run 'git prune' to remove them."
+msgstr ""
+"Es gibt zu viele unerreichbare lose Objekte; führen Sie 'git prune' aus, um "
+"diese zu löschen."
 
-#: builtin/diff.c:399
-#, c-format
-msgid "invalid object '%s' given."
-msgstr "Objekt '%s' ist ungültig."
+#: builtin/grep.c:29
+msgid "git grep [<options>] [-e] <pattern> [<rev>...] [[--] <path>...]"
+msgstr "git grep [<Optionen>] [-e] <Muster> [<Commit>...] [[--] <Pfad>...]"
 
-#: builtin/diff.c:408
+#: builtin/grep.c:225
 #, c-format
-msgid "more than two blobs given: '%s'"
-msgstr "Mehr als zwei Blobs angegeben: '%s'"
+msgid "grep: failed to create thread: %s"
+msgstr "grep: Fehler beim Erzeugen eines Thread: %s"
 
-#: builtin/diff.c:413
+#: builtin/grep.c:279
 #, c-format
-msgid "unhandled object '%s' given."
-msgstr "unbehandeltes Objekt '%s' angegeben"
-
-#: builtin/difftool.c:29
-msgid "git difftool [<options>] [<commit> [<commit>]] [--] [<path>...]"
-msgstr "git difftool [<Optionen>] [<Commit> [<Commit>]] [--] [<Pfad>...]"
+msgid "invalid number of threads specified (%d) for %s"
+msgstr "ungültige Anzahl von Threads (%d) für %s angegeben"
 
-#: builtin/difftool.c:259
+#. TRANSLATORS: %s is the configuration
+#. variable for tweaking threads, currently
+#. grep.threads
+#.
+#: builtin/grep.c:287 builtin/index-pack.c:1534 builtin/index-pack.c:1727
+#: builtin/pack-objects.c:2708
 #, c-format
-msgid "failed: %d"
-msgstr "fehlgeschlagen: %d"
+msgid "no threads support, ignoring %s"
+msgstr "keine Unterstützung von Threads, '%s' wird ignoriert"
 
-#: builtin/difftool.c:301
+#: builtin/grep.c:467 builtin/grep.c:592 builtin/grep.c:635
 #, c-format
-msgid "could not read symlink %s"
-msgstr "konnte symbolische Verknüpfung %s nicht lesen"
+msgid "unable to read tree (%s)"
+msgstr "konnte \"Tree\"-Objekt (%s) nicht lesen"
 
-#: builtin/difftool.c:303
+#: builtin/grep.c:650
 #, c-format
-msgid "could not read symlink file %s"
-msgstr "Konnte Datei von symbolischer Verknüpfung '%s' nicht lesen."
+msgid "unable to grep from object of type %s"
+msgstr "kann \"grep\" nicht mit Objekten des Typs %s durchführen"
 
-#: builtin/difftool.c:311
+#: builtin/grep.c:716
 #, c-format
-msgid "could not read object %s for symlink %s"
-msgstr "Konnte Objekt '%s' für symbolische Verknüpfung '%s' nicht lesen."
+msgid "switch `%c' expects a numerical value"
+msgstr "Schalter '%c' erwartet einen numerischen Wert"
 
-#: builtin/difftool.c:412
-msgid ""
-"combined diff formats('-c' and '--cc') are not supported in\n"
-"directory diff mode('-d' and '--dir-diff')."
-msgstr ""
-"Kombinierte Diff-Formate('-c' und '--cc') werden im Verzeichnis-\n"
-"Diff-Modus('-d' und '--dir-diff') nicht unterstützt."
+#: builtin/grep.c:815
+msgid "search in index instead of in the work tree"
+msgstr "im Index anstatt im Arbeitsverzeichnis suchen"
 
-#: builtin/difftool.c:632
-#, c-format
-msgid "both files modified: '%s' and '%s'."
-msgstr "beide Dateien geändert: '%s' und '%s'."
+#: builtin/grep.c:817
+msgid "find in contents not managed by git"
+msgstr "auch in Inhalten finden, die nicht von Git verwaltet werden"
 
-#: builtin/difftool.c:634
-msgid "working tree file has been left."
-msgstr "Datei im Arbeitsverzeichnis belassen."
+#: builtin/grep.c:819
+msgid "search in both tracked and untracked files"
+msgstr "in versionierten und unversionierten Dateien suchen"
 
-#: builtin/difftool.c:645
-#, c-format
-msgid "temporary files exist in '%s'."
-msgstr "Es existieren temporäre Dateien in '%s'."
+#: builtin/grep.c:821
+msgid "ignore files specified via '.gitignore'"
+msgstr "Dateien, die über '.gitignore' angegeben sind, ignorieren"
 
-#: builtin/difftool.c:646
-msgid "you may want to cleanup or recover these."
-msgstr "Sie könnten diese aufräumen oder wiederherstellen."
+#: builtin/grep.c:823
+msgid "recursively search in each submodule"
+msgstr "rekursive Suche in jedem Submodul"
 
-#: builtin/difftool.c:695
-msgid "use `diff.guitool` instead of `diff.tool`"
-msgstr "`diff.guitool` anstatt `diff.tool` benutzen"
+#: builtin/grep.c:826
+msgid "show non-matching lines"
+msgstr "Zeilen ohne Übereinstimmungen anzeigen"
 
-#: builtin/difftool.c:697
-msgid "perform a full-directory diff"
-msgstr "Diff über ganzes Verzeichnis ausführen"
+#: builtin/grep.c:828
+msgid "case insensitive matching"
+msgstr "Übereinstimmungen unabhängig von Groß- und Kleinschreibung finden"
 
-#: builtin/difftool.c:699
-msgid "do not prompt before launching a diff tool"
-msgstr "keine Eingabeaufforderung vor Ausführung eines Diff-Tools"
+#: builtin/grep.c:830
+msgid "match patterns only at word boundaries"
+msgstr "nur ganze Wörter suchen"
 
-#: builtin/difftool.c:705
-msgid "use symlinks in dir-diff mode"
-msgstr "symbolische Verknüpfungen im dir-diff Modus verwenden"
+#: builtin/grep.c:832
+msgid "process binary files as text"
+msgstr "binäre Dateien als Text verarbeiten"
 
-#: builtin/difftool.c:706
-msgid "<tool>"
-msgstr "<Tool>"
+#: builtin/grep.c:834
+msgid "don't match patterns in binary files"
+msgstr "keine Muster in Binärdateien finden"
 
-#: builtin/difftool.c:707
-msgid "use the specified diff tool"
-msgstr "das angegebene Diff-Tool benutzen"
+#: builtin/grep.c:837
+msgid "process binary files with textconv filters"
+msgstr "binäre Dateien mit \"textconv\"-Filtern verarbeiten"
 
-#: builtin/difftool.c:709
-msgid "print a list of diff tools that may be used with `--tool`"
-msgstr ""
-"eine Liste mit Diff-Tools darstellen, die mit `--tool` benutzt werden können"
+#: builtin/grep.c:839
+msgid "search in subdirectories (default)"
+msgstr "in Unterverzeichnissen suchen (Standard)"
 
-#: builtin/difftool.c:712
-msgid ""
-"make 'git-difftool' exit when an invoked diff tool returns a non - zero exit "
-"code"
-msgstr ""
-"'git-difftool' beenden, wenn das aufgerufene Diff-Tool mit einem "
-"Rückkehrwert\n"
-"verschieden 0 ausgeführt wurde"
+#: builtin/grep.c:841
+msgid "descend at most <depth> levels"
+msgstr "höchstens <Tiefe> Ebenen durchlaufen"
 
-#: builtin/difftool.c:714
-msgid "<command>"
-msgstr "<Programm>"
+#: builtin/grep.c:845
+msgid "use extended POSIX regular expressions"
+msgstr "erweiterte reguläre Ausdrücke aus POSIX verwenden"
 
-#: builtin/difftool.c:715
-msgid "specify a custom command for viewing diffs"
-msgstr "eigenen Befehl zur Anzeige von Unterschieden angeben"
+#: builtin/grep.c:848
+msgid "use basic POSIX regular expressions (default)"
+msgstr "grundlegende reguläre Ausdrücke aus POSIX verwenden (Standard)"
 
-#: builtin/difftool.c:739
-msgid "no <tool> given for --tool=<tool>"
-msgstr "kein <Tool> für --tool=<Tool> angegeben"
+#: builtin/grep.c:851
+msgid "interpret patterns as fixed strings"
+msgstr "Muster als feste Zeichenketten interpretieren"
 
-#: builtin/difftool.c:746
-msgid "no <cmd> given for --extcmd=<cmd>"
-msgstr "kein <Programm> für --extcmd=<Programm> angegeben"
+#: builtin/grep.c:854
+msgid "use Perl-compatible regular expressions"
+msgstr "Perl-kompatible reguläre Ausdrücke verwenden"
 
-#: builtin/fast-export.c:26
-msgid "git fast-export [rev-list-opts]"
-msgstr "git fast-export [rev-list-opts]"
+#: builtin/grep.c:857
+msgid "show line numbers"
+msgstr "Zeilennummern anzeigen"
 
-#: builtin/fast-export.c:998
-msgid "show progress after <n> objects"
-msgstr "Fortschritt nach <n> Objekten anzeigen"
+#: builtin/grep.c:858
+msgid "show column number of first match"
+msgstr "Nummer der Spalte des ersten Treffers anzeigen"
 
-#: builtin/fast-export.c:1000
-msgid "select handling of signed tags"
-msgstr "Behandlung von signierten Tags wählen"
+#: builtin/grep.c:859
+msgid "don't show filenames"
+msgstr "keine Dateinamen anzeigen"
 
-#: builtin/fast-export.c:1003
-msgid "select handling of tags that tag filtered objects"
-msgstr "Behandlung von Tags wählen, die gefilterte Objekte markieren"
+#: builtin/grep.c:860
+msgid "show filenames"
+msgstr "Dateinamen anzeigen"
 
-#: builtin/fast-export.c:1006
-msgid "Dump marks to this file"
-msgstr "Kennzeichen in diese Datei schreiben"
+#: builtin/grep.c:862
+msgid "show filenames relative to top directory"
+msgstr "Dateinamen relativ zum Projektverzeichnis anzeigen"
 
-#: builtin/fast-export.c:1008
-msgid "Import marks from this file"
-msgstr "Kennzeichen von dieser Datei importieren"
+#: builtin/grep.c:864
+msgid "show only filenames instead of matching lines"
+msgstr "nur Dateinamen anzeigen anstatt übereinstimmende Zeilen"
 
-#: builtin/fast-export.c:1010
-msgid "Fake a tagger when tags lack one"
-msgstr "künstlich einen Tag-Ersteller erzeugen, wenn das Tag keinen hat"
+#: builtin/grep.c:866
+msgid "synonym for --files-with-matches"
+msgstr "Synonym für --files-with-matches"
 
-#: builtin/fast-export.c:1012
-msgid "Output full tree for each commit"
-msgstr "für jeden Commit das gesamte Verzeichnis ausgeben"
+#: builtin/grep.c:869
+msgid "show only the names of files without match"
+msgstr "nur die Dateinamen ohne Übereinstimmungen anzeigen"
 
-#: builtin/fast-export.c:1014
-msgid "Use the done feature to terminate the stream"
-msgstr "die \"done\"-Funktion benutzen, um den Datenstrom abzuschließen"
+#: builtin/grep.c:871
+msgid "print NUL after filenames"
+msgstr "NUL-Zeichen nach Dateinamen ausgeben"
 
-#: builtin/fast-export.c:1015
-msgid "Skip output of blob data"
-msgstr "Ausgabe von Blob-Daten überspringen"
+#: builtin/grep.c:874
+msgid "show only matching parts of a line"
+msgstr "nur übereinstimmende Teile der Zeile anzeigen"
 
-#: builtin/fast-export.c:1016
-msgid "refspec"
-msgstr "Refspec"
+#: builtin/grep.c:876
+msgid "show the number of matches instead of matching lines"
+msgstr "anstatt der Zeilen, die Anzahl der übereinstimmenden Zeilen anzeigen"
 
-#: builtin/fast-export.c:1017
-msgid "Apply refspec to exported refs"
-msgstr "Refspec auf exportierte Referenzen anwenden"
+#: builtin/grep.c:877
+msgid "highlight matches"
+msgstr "Übereinstimmungen hervorheben"
 
-#: builtin/fast-export.c:1018
-msgid "anonymize output"
-msgstr "Ausgabe anonymisieren"
+#: builtin/grep.c:879
+msgid "print empty line between matches from different files"
+msgstr ""
+"eine Leerzeile zwischen Übereinstimmungen in verschiedenen Dateien ausgeben"
 
-#: builtin/fetch.c:25
-msgid "git fetch [<options>] [<repository> [<refspec>...]]"
-msgstr "git fetch [<Optionen>] [<Repository> [<Refspec>...]]"
+#: builtin/grep.c:881
+msgid "show filename only once above matches from same file"
+msgstr ""
+"den Dateinamen nur einmal oberhalb der Übereinstimmungen aus dieser Datei "
+"anzeigen"
 
-#: builtin/fetch.c:26
-msgid "git fetch [<options>] <group>"
-msgstr "git fetch [<Optionen>] <Gruppe>"
+#: builtin/grep.c:884
+msgid "show <n> context lines before and after matches"
+msgstr "<n> Zeilen vor und nach den Übereinstimmungen anzeigen"
 
-#: builtin/fetch.c:27
-msgid "git fetch --multiple [<options>] [(<repository> | <group>)...]"
-msgstr "git fetch --multiple [<Optionen>] [(<Repository> | <Gruppe>)...]"
+#: builtin/grep.c:887
+msgid "show <n> context lines before matches"
+msgstr "<n> Zeilen vor den Übereinstimmungen anzeigen"
 
-#: builtin/fetch.c:28
-msgid "git fetch --all [<options>]"
-msgstr "git fetch --all [<Optionen>]"
+#: builtin/grep.c:889
+msgid "show <n> context lines after matches"
+msgstr "<n> Zeilen nach den Übereinstimmungen anzeigen"
 
-#: builtin/fetch.c:124 builtin/pull.c:188
-msgid "fetch from all remotes"
-msgstr "fordert von allen Remote-Repositories an"
+#: builtin/grep.c:891
+msgid "use <n> worker threads"
+msgstr "<n> Threads benutzen"
 
-#: builtin/fetch.c:126 builtin/pull.c:191
-msgid "append to .git/FETCH_HEAD instead of overwriting"
-msgstr "an .git/FETCH_HEAD anhängen, anstatt zu überschreiben"
+#: builtin/grep.c:892
+msgid "shortcut for -C NUM"
+msgstr "Kurzform für -C NUM"
 
-#: builtin/fetch.c:128 builtin/pull.c:194
-msgid "path to upload pack on remote end"
-msgstr "Pfad des Programms zum Hochladen von Paketen auf der Gegenseite"
+#: builtin/grep.c:895
+msgid "show a line with the function name before matches"
+msgstr "eine Zeile mit dem Funktionsnamen vor Übereinstimmungen anzeigen"
 
-#: builtin/fetch.c:129 builtin/pull.c:196
-msgid "force overwrite of local branch"
-msgstr "das Überschreiben von lokalen Branches erzwingen"
+#: builtin/grep.c:897
+msgid "show the surrounding function"
+msgstr "die umgebende Funktion anzeigen"
 
-#: builtin/fetch.c:131
-msgid "fetch from multiple remotes"
-msgstr "von mehreren Remote-Repositories anfordern"
+#: builtin/grep.c:900
+msgid "read patterns from file"
+msgstr "Muster von einer Datei lesen"
 
-#: builtin/fetch.c:133 builtin/pull.c:198
-msgid "fetch all tags and associated objects"
-msgstr "alle Tags und verbundene Objekte anfordern"
+#: builtin/grep.c:902
+msgid "match <pattern>"
+msgstr "<Muster> finden"
 
-#: builtin/fetch.c:135
-msgid "do not fetch all tags (--no-tags)"
-msgstr "nicht alle Tags anfordern (--no-tags)"
+#: builtin/grep.c:904
+msgid "combine patterns specified with -e"
+msgstr "Muster kombinieren, die mit -e angegeben wurden"
 
-#: builtin/fetch.c:137
-msgid "number of submodules fetched in parallel"
-msgstr "Anzahl der parallel anzufordernden Submodule"
+#: builtin/grep.c:916
+msgid "indicate hit with exit status without output"
+msgstr "Übereinstimmungen nur durch Beendigungsstatus anzeigen"
 
-#: builtin/fetch.c:139 builtin/pull.c:201
-msgid "prune remote-tracking branches no longer on remote"
+#: builtin/grep.c:918
+msgid "show only matches from files that match all patterns"
 msgstr ""
-"Remote-Tracking-Branches entfernen, die sich nicht mehr im Remote-Repository "
-"befinden"
+"nur Übereinstimmungen von Dateien anzeigen, die allen Mustern entsprechen"
 
-#: builtin/fetch.c:141
-msgid "prune local tags no longer on remote and clobber changed tags"
-msgstr "lokale Tags entfernen, die sich nicht mehr im Remote-Repository befinden, und geänderte Tags aktualisieren"
+#: builtin/grep.c:920
+msgid "show parse tree for grep expression"
+msgstr "geparstes Verzeichnis für \"grep\"-Ausdruck anzeigen"
 
-#: builtin/fetch.c:142 builtin/fetch.c:165 builtin/pull.c:126
-msgid "on-demand"
-msgstr "bei-Bedarf"
+#: builtin/grep.c:924
+msgid "pager"
+msgstr "Anzeigeprogramm"
 
-#: builtin/fetch.c:143
-msgid "control recursive fetching of submodules"
-msgstr "rekursive Anforderungen von Submodulen kontrollieren"
+#: builtin/grep.c:924
+msgid "show matching files in the pager"
+msgstr "Dateien mit Übereinstimmungen im Anzeigeprogramm anzeigen"
 
-#: builtin/fetch.c:147 builtin/pull.c:209
-msgid "keep downloaded pack"
-msgstr "heruntergeladenes Paket behalten"
+#: builtin/grep.c:928
+msgid "allow calling of grep(1) (ignored by this build)"
+msgstr "den Aufruf von grep(1) erlauben (von dieser Programmversion ignoriert)"
 
-#: builtin/fetch.c:149
-msgid "allow updating of HEAD ref"
-msgstr "Aktualisierung der \"HEAD\"-Referenz erlauben"
+#: builtin/grep.c:992
+msgid "no pattern given"
+msgstr "Kein Muster angegeben."
+
+#: builtin/grep.c:1028
+msgid "--no-index or --untracked cannot be used with revs"
+msgstr "--no-index oder --untracked können nicht mit Commits verwendet werden"
+
+#: builtin/grep.c:1036
+#, c-format
+msgid "unable to resolve revision: %s"
+msgstr "Konnte Commit nicht auflösen: %s"
+
+#: builtin/grep.c:1067
+msgid "invalid option combination, ignoring --threads"
+msgstr "Ungültige Kombination von Optionen, --threads wird ignoriert."
 
-#: builtin/fetch.c:152 builtin/fetch.c:158 builtin/pull.c:212
-msgid "deepen history of shallow clone"
-msgstr ""
-"die Historie eines Klons mit unvollständiger Historie (shallow) vertiefen"
+#: builtin/grep.c:1070 builtin/pack-objects.c:3400
+msgid "no threads support, ignoring --threads"
+msgstr "Keine Unterstützung für Threads, --threads wird ignoriert."
 
-#: builtin/fetch.c:154
-msgid "deepen history of shallow repository based on time"
+#: builtin/grep.c:1073 builtin/index-pack.c:1531 builtin/pack-objects.c:2705
+#, c-format
+msgid "invalid number of threads specified (%d)"
+msgstr "ungültige Anzahl von Threads angegeben (%d)"
+
+#: builtin/grep.c:1096
+msgid "--open-files-in-pager only works on the worktree"
 msgstr ""
-"die Historie eines Klons mit unvollständiger Historie (shallow) auf "
-"Zeitbasis\n"
-"vertiefen"
+"Die Option --open-files-in-pager kann nur innerhalb des "
+"Arbeitsverzeichnisses verwendet werden."
 
-#: builtin/fetch.c:160 builtin/pull.c:215
-msgid "convert to a complete repository"
-msgstr "zu einem vollständigen Repository konvertieren"
+#: builtin/grep.c:1119
+msgid "option not supported with --recurse-submodules"
+msgstr "Die Option wird mit --recurse-submodules nicht unterstützt."
+
+#: builtin/grep.c:1125
+msgid "--cached or --untracked cannot be used with --no-index"
+msgstr "--cached und --untracked können nicht mit --no-index verwendet werden."
 
-#: builtin/fetch.c:162 builtin/log.c:1466
-msgid "dir"
-msgstr "Verzeichnis"
+#: builtin/grep.c:1131
+msgid "--[no-]exclude-standard cannot be used for tracked contents"
+msgstr ""
+"--[no-]exclude-standard kann nicht mit versionierten Inhalten verwendet "
+"werden."
 
-#: builtin/fetch.c:163
-msgid "prepend this to submodule path output"
-msgstr "dies an die Ausgabe der Submodul-Pfade voranstellen"
+#: builtin/grep.c:1139
+msgid "both --cached and trees are given"
+msgstr "--cached und \"Tree\"-Objekte angegeben"
 
-#: builtin/fetch.c:166
+#: builtin/hash-object.c:85
 msgid ""
-"default for recursive fetching of submodules (lower priority than config "
-"files)"
+"git hash-object [-t <type>] [-w] [--path=<file> | --no-filters] [--stdin] "
+"[--] <file>..."
 msgstr ""
-"Standard für die rekursive Anforderung von Submodulen (geringere Priorität\n"
-"als Konfigurationsdateien)"
+"git hash-object [-t <Art>] [-w] [--path=<Datei> | --no-filters] [--stdin] "
+"[--] <Datei>..."
 
-#: builtin/fetch.c:170 builtin/pull.c:218
-msgid "accept refs that update .git/shallow"
-msgstr "Referenzen, die .git/shallow aktualisieren, akzeptieren"
+#: builtin/hash-object.c:86
+msgid "git hash-object  --stdin-paths"
+msgstr "git hash-object  --stdin-paths"
 
-#: builtin/fetch.c:171 builtin/pull.c:220
-msgid "refmap"
-msgstr "Refmap"
+#: builtin/hash-object.c:98
+msgid "object type"
+msgstr "Art des Objektes"
 
-#: builtin/fetch.c:172 builtin/pull.c:221
-msgid "specify fetch refmap"
-msgstr "Refmap für 'fetch' angeben"
+#: builtin/hash-object.c:99
+msgid "write the object into the object database"
+msgstr "das Objekt in die Objektdatenbank schreiben"
 
-#: builtin/fetch.c:431
-msgid "Couldn't find remote ref HEAD"
-msgstr "Konnte Remote-Referenz von HEAD nicht finden."
+#: builtin/hash-object.c:101
+msgid "read the object from stdin"
+msgstr "das Objekt von der Standard-Eingabe lesen"
 
-#: builtin/fetch.c:549
-#, c-format
-msgid "configuration fetch.output contains invalid value %s"
-msgstr "Konfiguration fetch.output enthält ungültigen Wert %s"
+#: builtin/hash-object.c:103
+msgid "store file as is without filters"
+msgstr "Datei wie sie ist speichern, ohne Filter"
 
-#: builtin/fetch.c:642
-#, c-format
-msgid "object %s not found"
-msgstr "Objekt %s nicht gefunden"
+#: builtin/hash-object.c:104
+msgid ""
+"just hash any random garbage to create corrupt objects for debugging Git"
+msgstr ""
+"Hash über zufällige Daten, zur Erzeugung von beschädigten Objekten zur\n"
+"Fehlersuche in Git, erzeugen"
 
-#: builtin/fetch.c:646
-msgid "[up to date]"
-msgstr "[aktuell]"
+#: builtin/hash-object.c:105
+msgid "process file as it were from this path"
+msgstr "Datei verarbeiten, als ob sie von diesem Pfad wäre"
 
-#: builtin/fetch.c:659 builtin/fetch.c:739
-msgid "[rejected]"
-msgstr "[zurückgewiesen]"
+#: builtin/help.c:46
+msgid "print all available commands"
+msgstr "alle vorhandenen Befehle anzeigen"
 
-#: builtin/fetch.c:660
-msgid "can't fetch in current branch"
-msgstr "kann \"fetch\" im aktuellen Branch nicht ausführen"
+#: builtin/help.c:47
+msgid "exclude guides"
+msgstr "Anleitungen ausschließen"
 
-#: builtin/fetch.c:669
-msgid "[tag update]"
-msgstr "[Tag Aktualisierung]"
+#: builtin/help.c:48
+msgid "print list of useful guides"
+msgstr "Liste von allgemein verwendeten Anleitungen anzeigen"
 
-#: builtin/fetch.c:670 builtin/fetch.c:703 builtin/fetch.c:719
-#: builtin/fetch.c:734
-msgid "unable to update local ref"
-msgstr "kann lokale Referenz nicht aktualisieren"
+#: builtin/help.c:49
+msgid "print all configuration variable names"
+msgstr "alle Namen der Konfigurationsvariablen ausgeben"
 
-#: builtin/fetch.c:689
-msgid "[new tag]"
-msgstr "[neues Tag]"
+#: builtin/help.c:51
+msgid "show man page"
+msgstr "Handbuch anzeigen"
 
-#: builtin/fetch.c:692
-msgid "[new branch]"
-msgstr "[neuer Branch]"
+#: builtin/help.c:52
+msgid "show manual in web browser"
+msgstr "Handbuch in einem Webbrowser anzeigen"
 
-#: builtin/fetch.c:695
-msgid "[new ref]"
-msgstr "[neue Referenz]"
+#: builtin/help.c:54
+msgid "show info page"
+msgstr "Info-Seite anzeigen"
 
-#: builtin/fetch.c:734
-msgid "forced update"
-msgstr "Aktualisierung erzwungen"
+#: builtin/help.c:56
+msgid "print command description"
+msgstr "Beschreibung des Befehls ausgeben"
 
-#: builtin/fetch.c:739
-msgid "non-fast-forward"
-msgstr "kein Vorspulen"
+#: builtin/help.c:61
+msgid "git help [--all] [--guides] [--man | --web | --info] [<command>]"
+msgstr "git help [--all] [--guides] [--man | --web | --info] [<Befehl>]"
 
-#: builtin/fetch.c:784
+#: builtin/help.c:77
 #, c-format
-msgid "%s did not send all necessary objects\n"
-msgstr "%s hat nicht alle erforderlichen Objekte gesendet\n"
+msgid "unrecognized help format '%s'"
+msgstr "nicht erkanntes Hilfeformat: %s"
+
+#: builtin/help.c:104
+msgid "Failed to start emacsclient."
+msgstr "Konnte emacsclient nicht starten."
 
-#: builtin/fetch.c:804
+#: builtin/help.c:117
+msgid "Failed to parse emacsclient version."
+msgstr "Konnte Version des emacsclient nicht parsen."
+
+#: builtin/help.c:125
 #, c-format
-msgid "reject %s because shallow roots are not allowed to be updated"
-msgstr ""
-"%s wurde zurückgewiesen, da Ursprungs-Commits von Repositories mit "
-"unvollständiger Historie (shallow) nicht aktualisiert werden dürfen."
+msgid "emacsclient version '%d' too old (< 22)."
+msgstr "Version des emacsclient '%d' ist zu alt (< 22)."
 
-#: builtin/fetch.c:892 builtin/fetch.c:988
+#: builtin/help.c:143 builtin/help.c:165 builtin/help.c:175 builtin/help.c:183
 #, c-format
-msgid "From %.*s\n"
-msgstr "Von %.*s\n"
+msgid "failed to exec '%s'"
+msgstr "Fehler beim Ausführen von '%s'"
 
-#: builtin/fetch.c:903
+#: builtin/help.c:221
 #, c-format
 msgid ""
-"some local refs could not be updated; try running\n"
-" 'git remote prune %s' to remove any old, conflicting branches"
+"'%s': path for unsupported man viewer.\n"
+"Please consider using 'man.<tool>.cmd' instead."
 msgstr ""
-"Einige lokale Referenzen konnten nicht aktualisiert werden; versuchen Sie\n"
-"'git remote prune %s', um jeden älteren, widersprüchlichen Branch zu löschen."
+"'%s': Pfad für nicht unterstützten Handbuchbetrachter.\n"
+"Sie könnten stattdessen 'man.<Werkzeug>.cmd' benutzen."
 
-#: builtin/fetch.c:958
+#: builtin/help.c:233
 #, c-format
-msgid "   (%s will become dangling)"
-msgstr "   (%s wird unreferenziert)"
+msgid ""
+"'%s': cmd for supported man viewer.\n"
+"Please consider using 'man.<tool>.path' instead."
+msgstr ""
+"'%s': Programm für unterstützten Handbuchbetrachter.\n"
+"Sie könnten stattdessen 'man.<Werkzeug>.path' benutzen."
 
-#: builtin/fetch.c:959
+#: builtin/help.c:350
 #, c-format
-msgid "   (%s has become dangling)"
-msgstr "   (%s wurde unreferenziert)"
+msgid "'%s': unknown man viewer."
+msgstr "'%s': unbekannter Handbuch-Betrachter."
 
-#: builtin/fetch.c:991
-msgid "[deleted]"
-msgstr "[gelöscht]"
+#: builtin/help.c:367
+msgid "no man viewer handled the request"
+msgstr "kein Handbuch-Betrachter konnte mit dieser Anfrage umgehen"
 
-#: builtin/fetch.c:992 builtin/remote.c:1024
-msgid "(none)"
-msgstr "(nichts)"
+#: builtin/help.c:375
+msgid "no info viewer handled the request"
+msgstr "kein Informations-Betrachter konnte mit dieser Anfrage umgehen"
 
-#: builtin/fetch.c:1015
+#: builtin/help.c:434 builtin/help.c:445 git.c:336
 #, c-format
-msgid "Refusing to fetch into current branch %s of non-bare repository"
-msgstr ""
-"Der \"fetch\" in den aktuellen Branch %s von einem Nicht-Bare-Repository "
-"wurde verweigert."
+msgid "'%s' is aliased to '%s'"
+msgstr "Für '%s' wurde der Alias '%s' angelegt."
 
-#: builtin/fetch.c:1034
+#: builtin/help.c:448 git.c:365
 #, c-format
-msgid "Option \"%s\" value \"%s\" is not valid for %s"
-msgstr "Option \"%s\" Wert \"%s\" ist nicht gültig für %s"
+msgid "bad alias.%s string: %s"
+msgstr "Ungültiger alias.%s String: %s"
 
-#: builtin/fetch.c:1037
+#: builtin/help.c:477 builtin/help.c:507
 #, c-format
-msgid "Option \"%s\" is ignored for %s\n"
-msgstr "Option \"%s\" wird ignoriert für %s\n"
+msgid "usage: %s%s"
+msgstr "Verwendung: %s%s"
+
+#: builtin/help.c:491
+msgid "'git help config' for more information"
+msgstr "'git help config' für weitere Informationen"
 
-#: builtin/fetch.c:1277
+#: builtin/index-pack.c:185
 #, c-format
-msgid "Fetching %s\n"
-msgstr "Fordere an von %s\n"
+msgid "object type mismatch at %s"
+msgstr "Objekt-Typen passen bei %s nicht zusammen"
 
-#: builtin/fetch.c:1279 builtin/remote.c:97
+#: builtin/index-pack.c:205
 #, c-format
-msgid "Could not fetch %s"
-msgstr "Konnte nicht von %s anfordern"
+msgid "did not receive expected object %s"
+msgstr "konnte erwartetes Objekt %s nicht empfangen"
 
-#: builtin/fetch.c:1325 builtin/fetch.c:1498
-msgid ""
-"--filter can only be used with the remote configured in core.partialClone"
-msgstr ""
-"--filter kann nur mit den Remote-Repositories verwendet werden,\n"
-"die in core.partialClone konfiguriert sind."
+#: builtin/index-pack.c:208
+#, c-format
+msgid "object %s: expected type %s, found %s"
+msgstr "Objekt %s: erwarteter Typ %s, %s gefunden"
 
-#: builtin/fetch.c:1350
-msgid ""
-"No remote repository specified.  Please, specify either a URL or a\n"
-"remote name from which new revisions should be fetched."
-msgstr ""
-"Kein Remote-Repository angegeben. Bitte geben Sie entweder eine URL\n"
-"oder den Namen des Remote-Repositories an, von welchem neue\n"
-"Commits angefordert werden sollen."
+#: builtin/index-pack.c:258
+#, c-format
+msgid "cannot fill %d byte"
+msgid_plural "cannot fill %d bytes"
+msgstr[0] "kann %d Byte nicht lesen"
+msgstr[1] "kann %d Bytes nicht lesen"
 
-#: builtin/fetch.c:1394
-msgid "You need to specify a tag name."
-msgstr "Sie müssen den Namen des Tags angeben."
+#: builtin/index-pack.c:268
+msgid "early EOF"
+msgstr "zu frühes Dateiende"
 
-#: builtin/fetch.c:1439
-msgid "Negative depth in --deepen is not supported"
-msgstr "Negative Tiefe wird von --deepen nicht unterstützt."
+#: builtin/index-pack.c:269
+msgid "read error on input"
+msgstr "Fehler beim Lesen der Eingabe"
 
-#: builtin/fetch.c:1441
-msgid "--deepen and --depth are mutually exclusive"
-msgstr "--deepen und --depth schließen sich gegenseitig aus"
+#: builtin/index-pack.c:281
+msgid "used more bytes than were available"
+msgstr "verwendete mehr Bytes als verfügbar waren"
 
-#: builtin/fetch.c:1446
-msgid "--depth and --unshallow cannot be used together"
-msgstr ""
-"Die Optionen --depth und --unshallow können nicht gemeinsam verwendet werden."
+#: builtin/index-pack.c:288 builtin/pack-objects.c:604
+msgid "pack too large for current definition of off_t"
+msgstr "Paket ist zu groß für die aktuelle Definition von off_t"
 
-#: builtin/fetch.c:1448
-msgid "--unshallow on a complete repository does not make sense"
-msgstr ""
-"Die Option --unshallow kann nicht in einem Repository mit unvollständiger "
-"Historie verwendet werden."
+#: builtin/index-pack.c:291 builtin/unpack-objects.c:95
+msgid "pack exceeds maximum allowed size"
+msgstr "Paket überschreitet die maximal erlaubte Größe"
 
-#: builtin/fetch.c:1464
-msgid "fetch --all does not take a repository argument"
-msgstr "fetch --all akzeptiert kein Repository als Argument"
+#: builtin/index-pack.c:312
+#, c-format
+msgid "cannot open packfile '%s'"
+msgstr "Kann Paketdatei '%s' nicht öffnen"
 
-#: builtin/fetch.c:1466
-msgid "fetch --all does not make sense with refspecs"
-msgstr "fetch --all kann nicht mit Refspecs verwendet werden."
+#: builtin/index-pack.c:326
+msgid "pack signature mismatch"
+msgstr "Paketsignatur stimmt nicht überein"
 
-#: builtin/fetch.c:1475
+#: builtin/index-pack.c:328
 #, c-format
-msgid "No such remote or remote group: %s"
-msgstr "Kein Remote-Repository (einzeln oder Gruppe): %s"
+msgid "pack version %<PRIu32> unsupported"
+msgstr "Paketversion %<PRIu32> nicht unterstützt"
 
-#: builtin/fetch.c:1482
-msgid "Fetching a group and specifying refspecs does not make sense"
-msgstr ""
-"Das Abholen einer Gruppe von Remote-Repositories kann nicht mit der Angabe\n"
-"von Refspecs verwendet werden."
+#: builtin/index-pack.c:346
+#, c-format
+msgid "pack has bad object at offset %<PRIuMAX>: %s"
+msgstr "Paket hat ein ungültiges Objekt bei Versatz %<PRIuMAX>: %s"
 
-#: builtin/fmt-merge-msg.c:15
-msgid ""
-"git fmt-merge-msg [-m <message>] [--log[=<n>] | --no-log] [--file <file>]"
-msgstr ""
-"git fmt-merge-msg [-m <Beschreibung>] [--log[=<n>] | --no-log] [--file "
-"<Datei>]"
+#: builtin/index-pack.c:466
+#, c-format
+msgid "inflate returned %d"
+msgstr "Dekomprimierung gab %d zurück"
 
-#: builtin/fmt-merge-msg.c:666
-msgid "populate log with at most <n> entries from shortlog"
-msgstr "Historie mit höchstens <n> Einträgen von \"shortlog\" hinzufügen"
+#: builtin/index-pack.c:515
+msgid "offset value overflow for delta base object"
+msgstr "Wert für Versatz bei Differenzobjekt übergelaufen"
 
-#: builtin/fmt-merge-msg.c:669
-msgid "alias for --log (deprecated)"
-msgstr "Alias für --log (veraltet)"
+#: builtin/index-pack.c:523
+msgid "delta base offset is out of bound"
+msgstr ""
+"Wert für Versatz bei Differenzobjekt liegt außerhalb des gültigen Bereichs"
 
-#: builtin/fmt-merge-msg.c:672
-msgid "text"
-msgstr "Text"
+#: builtin/index-pack.c:531
+#, c-format
+msgid "unknown object type %d"
+msgstr "Unbekannter Objekt-Typ %d"
 
-#: builtin/fmt-merge-msg.c:673
-msgid "use <text> as start of message"
-msgstr "<Text> als Beschreibungsanfang verwenden"
+#: builtin/index-pack.c:562
+msgid "cannot pread pack file"
+msgstr "Kann Paketdatei %s nicht lesen"
 
-#: builtin/fmt-merge-msg.c:674
-msgid "file to read from"
-msgstr "Datei zum Einlesen"
+#: builtin/index-pack.c:564
+#, c-format
+msgid "premature end of pack file, %<PRIuMAX> byte missing"
+msgid_plural "premature end of pack file, %<PRIuMAX> bytes missing"
+msgstr[0] "frühzeitiges Ende der Paketdatei, vermisse %<PRIuMAX> Byte"
+msgstr[1] "frühzeitiges Ende der Paketdatei, vermisse %<PRIuMAX> Bytes"
 
-#: builtin/for-each-ref.c:10
-msgid "git for-each-ref [<options>] [<pattern>]"
-msgstr "git for-each-ref [<Optionen>] [<Muster>]"
+#: builtin/index-pack.c:590
+msgid "serious inflate inconsistency"
+msgstr "ernsthafte Inkonsistenz nach Dekomprimierung"
 
-#: builtin/for-each-ref.c:11
-msgid "git for-each-ref [--points-at <object>]"
-msgstr "git for-each-ref [--points-at <Objekt>]"
+#: builtin/index-pack.c:735 builtin/index-pack.c:741 builtin/index-pack.c:764
+#: builtin/index-pack.c:803 builtin/index-pack.c:812
+#, c-format
+msgid "SHA1 COLLISION FOUND WITH %s !"
+msgstr "SHA1 KOLLISION MIT %s GEFUNDEN !"
 
-#: builtin/for-each-ref.c:12
-msgid "git for-each-ref [(--merged | --no-merged) [<commit>]]"
-msgstr "git for-each-ref [(--merged | --no-merged) [<Commit>]]"
+#: builtin/index-pack.c:738 builtin/pack-objects.c:157
+#: builtin/pack-objects.c:217 builtin/pack-objects.c:311
+#, c-format
+msgid "unable to read %s"
+msgstr "kann %s nicht lesen"
 
-#: builtin/for-each-ref.c:13
-msgid "git for-each-ref [--contains [<commit>]] [--no-contains [<commit>]]"
-msgstr "git for-each-ref [--contains [<Objekt>]] [--no-contains [<Commit>]]"
+#: builtin/index-pack.c:801
+#, c-format
+msgid "cannot read existing object info %s"
+msgstr "Kann existierende Informationen zu Objekt %s nicht lesen."
 
-#: builtin/for-each-ref.c:28
-msgid "quote placeholders suitably for shells"
-msgstr "Platzhalter als Shell-String formatieren"
+#: builtin/index-pack.c:809
+#, c-format
+msgid "cannot read existing object %s"
+msgstr "Kann existierendes Objekt %s nicht lesen."
 
-#: builtin/for-each-ref.c:30
-msgid "quote placeholders suitably for perl"
-msgstr "Platzhalter als Perl-String formatieren"
+#: builtin/index-pack.c:823
+#, c-format
+msgid "invalid blob object %s"
+msgstr "ungültiges Blob-Objekt %s"
 
-#: builtin/for-each-ref.c:32
-msgid "quote placeholders suitably for python"
-msgstr "Platzhalter als Python-String formatieren"
+#: builtin/index-pack.c:826 builtin/index-pack.c:845
+msgid "fsck error in packed object"
+msgstr "fsck Fehler in gepacktem Objekt"
 
-#: builtin/for-each-ref.c:34
-msgid "quote placeholders suitably for Tcl"
-msgstr "Platzhalter als Tcl-String formatieren"
+#: builtin/index-pack.c:847
+#, c-format
+msgid "Not all child objects of %s are reachable"
+msgstr "Nicht alle Kind-Objekte von %s sind erreichbar"
 
-#: builtin/for-each-ref.c:37
-msgid "show only <n> matched refs"
-msgstr "nur <n> passende Referenzen anzeigen"
+#: builtin/index-pack.c:919 builtin/index-pack.c:950
+msgid "failed to apply delta"
+msgstr "Konnte Dateiunterschied nicht anwenden"
 
-#: builtin/for-each-ref.c:39 builtin/tag.c:420
-msgid "respect format colors"
-msgstr "Formatfarben beachten"
+#: builtin/index-pack.c:1118
+msgid "Receiving objects"
+msgstr "Empfange Objekte"
 
-#: builtin/for-each-ref.c:43
-msgid "print only refs which points at the given object"
-msgstr "nur auf dieses Objekt zeigende Referenzen ausgeben"
+#: builtin/index-pack.c:1118
+msgid "Indexing objects"
+msgstr "Indiziere Objekte"
 
-#: builtin/for-each-ref.c:45
-msgid "print only refs that are merged"
-msgstr "nur zusammengeführte Referenzen ausgeben"
+#: builtin/index-pack.c:1152
+msgid "pack is corrupted (SHA1 mismatch)"
+msgstr "Paket ist beschädigt (SHA1 unterschiedlich)"
 
-#: builtin/for-each-ref.c:46
-msgid "print only refs that are not merged"
-msgstr "nur nicht zusammengeführte Referenzen ausgeben"
+#: builtin/index-pack.c:1157
+msgid "cannot fstat packfile"
+msgstr "kann Paketdatei nicht lesen"
 
-#: builtin/for-each-ref.c:47
-msgid "print only refs which contain the commit"
-msgstr "nur Referenzen ausgeben, die diesen Commit enthalten"
+#: builtin/index-pack.c:1160
+msgid "pack has junk at the end"
+msgstr "Paketende enthält nicht verwendbaren Inhalt"
 
-#: builtin/for-each-ref.c:48
-msgid "print only refs which don't contain the commit"
-msgstr "nur Referenzen ausgeben, die diesen Commit nicht enthalten"
+#: builtin/index-pack.c:1172
+msgid "confusion beyond insanity in parse_pack_objects()"
+msgstr "Fehler beim Ausführen von \"parse_pack_objects()\""
 
-#: builtin/fsck.c:568
-msgid "Checking object directories"
-msgstr "Prüfe Objekt-Verzeichnisse"
+#: builtin/index-pack.c:1195
+msgid "Resolving deltas"
+msgstr "Löse Unterschiede auf"
 
-#: builtin/fsck.c:660
-msgid "git fsck [<options>] [<object>...]"
-msgstr "git fsck [<Optionen>] [<Objekt>...]"
+#: builtin/index-pack.c:1205 builtin/pack-objects.c:2481
+#, c-format
+msgid "unable to create thread: %s"
+msgstr "kann Thread nicht erzeugen: %s"
 
-#: builtin/fsck.c:666
-msgid "show unreachable objects"
-msgstr "unerreichbare Objekte anzeigen"
+#: builtin/index-pack.c:1246
+msgid "confusion beyond insanity"
+msgstr "Fehler beim Auflösen der Unterschiede"
 
-#: builtin/fsck.c:667
-msgid "show dangling objects"
-msgstr "unreferenzierte Objekte anzeigen"
+#: builtin/index-pack.c:1252
+#, c-format
+msgid "completed with %d local object"
+msgid_plural "completed with %d local objects"
+msgstr[0] "abgeschlossen mit %d lokalem Objekt"
+msgstr[1] "abgeschlossen mit %d lokalen Objekten"
 
-#: builtin/fsck.c:668
-msgid "report tags"
-msgstr "Tags melden"
+#: builtin/index-pack.c:1264
+#, c-format
+msgid "Unexpected tail checksum for %s (disk corruption?)"
+msgstr "Unerwartete Prüfsumme für %s (Festplattenfehler?)"
 
-#: builtin/fsck.c:669
-msgid "report root nodes"
-msgstr "Hauptwurzeln melden"
+#: builtin/index-pack.c:1268
+#, c-format
+msgid "pack has %d unresolved delta"
+msgid_plural "pack has %d unresolved deltas"
+msgstr[0] "Paket hat %d unaufgelösten Unterschied"
+msgstr[1] "Paket hat %d unaufgelöste Unterschiede"
 
-#: builtin/fsck.c:670
-msgid "make index objects head nodes"
-msgstr "Index-Objekte in Erreichbarkeitsprüfung einbeziehen"
+#: builtin/index-pack.c:1292
+#, c-format
+msgid "unable to deflate appended object (%d)"
+msgstr "Konnte angehängtes Objekt (%d) nicht komprimieren"
 
-#: builtin/fsck.c:671
-msgid "make reflogs head nodes (default)"
-msgstr "Reflogs in Erreichbarkeitsprüfung einbeziehen (Standard)"
+#: builtin/index-pack.c:1388
+#, c-format
+msgid "local object %s is corrupt"
+msgstr "lokales Objekt %s ist beschädigt"
 
-#: builtin/fsck.c:672
-msgid "also consider packs and alternate objects"
-msgstr "ebenso Pakete und alternative Objekte betrachten"
+#: builtin/index-pack.c:1402
+#, c-format
+msgid "packfile name '%s' does not end with '.pack'"
+msgstr "Name der Paketdatei '%s' endet nicht mit '.pack'"
 
-#: builtin/fsck.c:673
-msgid "check only connectivity"
-msgstr "nur Konnektivität prüfen"
+#: builtin/index-pack.c:1427
+#, c-format
+msgid "cannot write %s file '%s'"
+msgstr "Kann %s Datei '%s' nicht schreiben."
 
-#: builtin/fsck.c:674
-msgid "enable more strict checking"
-msgstr "genauere Prüfung aktivieren"
+#: builtin/index-pack.c:1435
+#, c-format
+msgid "cannot close written %s file '%s'"
+msgstr "Kann eben geschriebene %s Datei '%s' nicht schließen."
 
-#: builtin/fsck.c:676
-msgid "write dangling objects in .git/lost-found"
-msgstr "unreferenzierte Objekte nach .git/lost-found schreiben"
+#: builtin/index-pack.c:1459
+msgid "error while closing pack file"
+msgstr "Fehler beim Schließen der Paketdatei"
 
-#: builtin/fsck.c:677 builtin/prune.c:108
-msgid "show progress"
-msgstr "Fortschrittsanzeige anzeigen"
+#: builtin/index-pack.c:1473
+msgid "cannot store pack file"
+msgstr "Kann Paketdatei nicht speichern"
 
-#: builtin/fsck.c:678
-msgid "show verbose names for reachable objects"
-msgstr "ausführliche Namen für erreichbare Objekte anzeigen"
+#: builtin/index-pack.c:1481
+msgid "cannot store index file"
+msgstr "Kann Indexdatei nicht speichern"
 
-#: builtin/fsck.c:742
-msgid "Checking objects"
-msgstr "Prüfe Objekte"
+#: builtin/index-pack.c:1525 builtin/pack-objects.c:2716
+#, c-format
+msgid "bad pack.indexversion=%<PRIu32>"
+msgstr "\"pack.indexversion=%<PRIu32>\" ist ungültig"
 
-#: builtin/gc.c:27
-msgid "git gc [<options>]"
-msgstr "git gc [<Optionen>]"
+#: builtin/index-pack.c:1593
+#, c-format
+msgid "Cannot open existing pack file '%s'"
+msgstr "Kann existierende Paketdatei '%s' nicht öffnen"
 
-#: builtin/gc.c:80
+#: builtin/index-pack.c:1595
 #, c-format
-msgid "Failed to fstat %s: %s"
-msgstr "Konnte '%s' nicht lesen: %s"
+msgid "Cannot open existing pack idx file for '%s'"
+msgstr "Kann existierende Indexdatei für Paket '%s' nicht öffnen"
 
-#: builtin/gc.c:312
+#: builtin/index-pack.c:1643
 #, c-format
-msgid "Can't stat %s"
-msgstr "Kann '%s' nicht lesen."
+msgid "non delta: %d object"
+msgid_plural "non delta: %d objects"
+msgstr[0] "kein Unterschied: %d Objekt"
+msgstr[1] "kein Unterschied: %d Objekte"
 
-#: builtin/gc.c:321
+#: builtin/index-pack.c:1650
 #, c-format
-msgid ""
-"The last gc run reported the following. Please correct the root cause\n"
-"and remove %s.\n"
-"Automatic cleanup will not be performed until the file is removed.\n"
-"\n"
-"%s"
-msgstr ""
-"Die letzte Ausführung von \"gc run\" enthielt die folgenden Meldungen.\n"
-"Bitte beheben Sie das Hauptproblem und löschen Sie %s.\n"
-"Ein automatischer Cleanup wird nicht ausgeführt, bis diese Datei entfernt\n"
-"wurde.\n"
-"\n"
-"%s"
+msgid "chain length = %d: %lu object"
+msgid_plural "chain length = %d: %lu objects"
+msgstr[0] "Länge der Objekt-Liste = %d: %lu Objekt"
+msgstr[1] "Länge der Objekt-Liste = %d: %lu Objekte"
 
-#: builtin/gc.c:360
-msgid "prune unreferenced objects"
-msgstr "unreferenzierte Objekte entfernen"
+#: builtin/index-pack.c:1689
+msgid "Cannot come back to cwd"
+msgstr "Kann nicht zurück zum Arbeitsverzeichnis wechseln"
 
-#: builtin/gc.c:362
-msgid "be more thorough (increased runtime)"
-msgstr "mehr Gründlichkeit (erhöht Laufzeit)"
+#: builtin/index-pack.c:1738 builtin/index-pack.c:1741
+#: builtin/index-pack.c:1757 builtin/index-pack.c:1761
+#, c-format
+msgid "bad %s"
+msgstr "%s ist ungültig"
 
-#: builtin/gc.c:363
-msgid "enable auto-gc mode"
-msgstr "\"auto-gc\" Modus aktivieren"
+#: builtin/index-pack.c:1777
+msgid "--fix-thin cannot be used without --stdin"
+msgstr "Die Option --fix-thin kann nicht ohne --stdin verwendet werden."
 
-#: builtin/gc.c:366
-msgid "force running gc even if there may be another gc running"
-msgstr ""
-"Ausführung von \"git gc\" erzwingen, selbst wenn ein anderes\n"
-"\"git gc\" bereits ausgeführt wird"
+#: builtin/index-pack.c:1779
+msgid "--stdin requires a git repository"
+msgstr "--stdin erfordert ein Git-Repository"
 
-#: builtin/gc.c:384
-#, c-format
-msgid "Failed to parse gc.logexpiry value %s"
-msgstr "Fehler beim Parsen des Wertes '%s' von gc.logexpiry"
+#: builtin/index-pack.c:1785
+msgid "--verify with no packfile name given"
+msgstr "Die Option --verify wurde ohne Namen der Paketdatei angegeben."
 
-#: builtin/gc.c:412
-#, c-format
-msgid "Auto packing the repository in background for optimum performance.\n"
-msgstr ""
-"Die Datenbank des Repositories wird für eine optimale Performance im\n"
-"Hintergrund komprimiert.\n"
+#: builtin/index-pack.c:1833 builtin/unpack-objects.c:581
+msgid "fsck error in pack objects"
+msgstr "fsck Fehler beim Packen von Objekten"
 
-#: builtin/gc.c:414
+#: builtin/init-db.c:61
 #, c-format
-msgid "Auto packing the repository for optimum performance.\n"
-msgstr ""
-"Die Datenbank des Projektarchivs wird für eine optimale Performance "
-"komprimiert.\n"
+msgid "cannot stat template '%s'"
+msgstr "kann Vorlage '%s' nicht lesen"
 
-#: builtin/gc.c:415
+#: builtin/init-db.c:66
 #, c-format
-msgid "See \"git help gc\" for manual housekeeping.\n"
-msgstr "Siehe \"git help gc\" für manuelles Aufräumen.\n"
+msgid "cannot opendir '%s'"
+msgstr "kann Verzeichnis '%s' nicht öffnen"
 
-#: builtin/gc.c:440
+#: builtin/init-db.c:78
 #, c-format
-msgid ""
-"gc is already running on machine '%s' pid %<PRIuMAX> (use --force if not)"
-msgstr ""
-"\"git gc\" wird bereits auf Maschine '%s' pid %<PRIuMAX> ausgeführt\n"
-"(benutzen Sie --force falls nicht)"
+msgid "cannot readlink '%s'"
+msgstr "kann Verweis '%s' nicht lesen"
 
-#: builtin/gc.c:487
-msgid ""
-"There are too many unreachable loose objects; run 'git prune' to remove them."
-msgstr ""
-"Es gibt zu viele unerreichbare lose Objekte; führen Sie 'git prune' aus, um "
-"diese zu löschen."
+#: builtin/init-db.c:80
+#, c-format
+msgid "cannot symlink '%s' '%s'"
+msgstr "kann symbolische Verknüpfung '%s' auf '%s' nicht erstellen"
 
-#: builtin/grep.c:27
-msgid "git grep [<options>] [-e] <pattern> [<rev>...] [[--] <path>...]"
-msgstr "git grep [<Optionen>] [-e] <Muster> [<Commit>...] [[--] <Pfad>...]"
+#: builtin/init-db.c:86
+#, c-format
+msgid "cannot copy '%s' to '%s'"
+msgstr "kann '%s' nicht nach '%s' kopieren"
 
-#: builtin/grep.c:225
+#: builtin/init-db.c:90
 #, c-format
-msgid "grep: failed to create thread: %s"
-msgstr "grep: Fehler beim Erzeugen eines Thread: %s"
+msgid "ignoring template %s"
+msgstr "ignoriere Vorlage %s"
 
-#: builtin/grep.c:283
+#: builtin/init-db.c:121
 #, c-format
-msgid "invalid number of threads specified (%d) for %s"
-msgstr "ungültige Anzahl von Threads (%d) für %s angegeben"
+msgid "templates not found in %s"
+msgstr "Keine Vorlagen in %s gefunden."
 
-#. TRANSLATORS: %s is the configuration
-#. variable for tweaking threads, currently
-#. grep.threads
-#.
-#: builtin/grep.c:292 builtin/index-pack.c:1523 builtin/index-pack.c:1712
+#: builtin/init-db.c:136
 #, c-format
-msgid "no threads support, ignoring %s"
-msgstr "keine Unterstützung von Threads, '%s' wird ignoriert"
+msgid "not copying templates from '%s': %s"
+msgstr "kopiere keine Vorlagen von '%s': %s"
 
-#: builtin/grep.c:460 builtin/grep.c:580 builtin/grep.c:622
+#: builtin/init-db.c:334
 #, c-format
-msgid "unable to read tree (%s)"
-msgstr "konnte \"Tree\"-Objekt (%s) nicht lesen"
+msgid "unable to handle file type %d"
+msgstr "kann nicht mit Dateityp %d umgehen"
 
-#: builtin/grep.c:637
+#: builtin/init-db.c:337
 #, c-format
-msgid "unable to grep from object of type %s"
-msgstr "kann \"grep\" nicht mit Objekten des Typs %s durchführen"
+msgid "unable to move %s to %s"
+msgstr "Konnte %s nicht nach %s verschieben"
 
-#: builtin/grep.c:703
+#: builtin/init-db.c:354 builtin/init-db.c:357
 #, c-format
-msgid "switch `%c' expects a numerical value"
-msgstr "Schalter '%c' erwartet einen numerischen Wert"
+msgid "%s already exists"
+msgstr "%s existiert bereits"
 
-#: builtin/grep.c:790
-msgid "search in index instead of in the work tree"
-msgstr "im Index anstatt im Arbeitsverzeichnis suchen"
+#: builtin/init-db.c:413
+#, c-format
+msgid "Reinitialized existing shared Git repository in %s%s\n"
+msgstr "Bestehendes verteiltes Git-Repository in %s%s neuinitialisiert\n"
 
-#: builtin/grep.c:792
-msgid "find in contents not managed by git"
-msgstr "auch in Inhalten finden, die nicht von Git verwaltet werden"
+#: builtin/init-db.c:414
+#, c-format
+msgid "Reinitialized existing Git repository in %s%s\n"
+msgstr "Bestehendes Git-Repository in %s%s neuinitialisiert\n"
 
-#: builtin/grep.c:794
-msgid "search in both tracked and untracked files"
-msgstr "in versionierten und unversionierten Dateien suchen"
+#: builtin/init-db.c:418
+#, c-format
+msgid "Initialized empty shared Git repository in %s%s\n"
+msgstr "Leeres verteiltes Git-Repository in %s%s initialisiert\n"
 
-#: builtin/grep.c:796
-msgid "ignore files specified via '.gitignore'"
-msgstr "Dateien, die über '.gitignore' angegeben sind, ignorieren"
+#: builtin/init-db.c:419
+#, c-format
+msgid "Initialized empty Git repository in %s%s\n"
+msgstr "Leeres Git-Repository in %s%s initialisiert\n"
 
-#: builtin/grep.c:798
-msgid "recursively search in each submodule"
-msgstr "rekursive Suche in jedem Submodul"
+#: builtin/init-db.c:468
+msgid ""
+"git init [-q | --quiet] [--bare] [--template=<template-directory>] [--"
+"shared[=<permissions>]] [<directory>]"
+msgstr ""
+"git init [-q | --quiet] [--bare] [--template=<Vorlagenverzeichnis>] [--"
+"shared[=<Berechtigungen>]] [<Verzeichnis>]"
 
-#: builtin/grep.c:801
-msgid "show non-matching lines"
-msgstr "Zeilen ohne Übereinstimmungen anzeigen"
+#: builtin/init-db.c:491
+msgid "permissions"
+msgstr "Berechtigungen"
 
-#: builtin/grep.c:803
-msgid "case insensitive matching"
-msgstr "Übereinstimmungen unabhängig von Groß- und Kleinschreibung finden"
+#: builtin/init-db.c:492
+msgid "specify that the git repository is to be shared amongst several users"
+msgstr "angeben, dass das Git-Repository mit mehreren Benutzern geteilt wird"
 
-#: builtin/grep.c:805
-msgid "match patterns only at word boundaries"
-msgstr "nur ganze Wörter suchen"
+#: builtin/init-db.c:529 builtin/init-db.c:534
+#, c-format
+msgid "cannot mkdir %s"
+msgstr "kann Verzeichnis %s nicht erstellen"
 
-#: builtin/grep.c:807
-msgid "process binary files as text"
-msgstr "binäre Dateien als Text verarbeiten"
+#: builtin/init-db.c:538
+#, c-format
+msgid "cannot chdir to %s"
+msgstr "kann nicht in Verzeichnis %s wechseln"
 
-#: builtin/grep.c:809
-msgid "don't match patterns in binary files"
-msgstr "keine Muster in Binärdateien finden"
+#: builtin/init-db.c:559
+#, c-format
+msgid ""
+"%s (or --work-tree=<directory>) not allowed without specifying %s (or --git-"
+"dir=<directory>)"
+msgstr ""
+"%s (oder --work-tree=<Verzeichnis>) nicht erlaubt ohne Spezifizierung von %s "
+"(oder --git-dir=<Verzeichnis>)"
 
-#: builtin/grep.c:812
-msgid "process binary files with textconv filters"
-msgstr "binäre Dateien mit \"textconv\"-Filtern verarbeiten"
+#: builtin/init-db.c:587
+#, c-format
+msgid "Cannot access work tree '%s'"
+msgstr "Kann nicht auf Arbeitsverzeichnis '%s' zugreifen."
 
-#: builtin/grep.c:814
-msgid "descend at most <depth> levels"
-msgstr "höchstens <Tiefe> Ebenen durchlaufen"
+#: builtin/interpret-trailers.c:16
+msgid ""
+"git interpret-trailers [--in-place] [--trim-empty] [(--trailer "
+"<token>[(=|:)<value>])...] [<file>...]"
+msgstr ""
+"git interpret-trailers [--in-place] [--trim-empty] [(--trailer "
+"<Token>[(=|:)<Wert>])...] [<Datei>...]"
 
-#: builtin/grep.c:818
-msgid "use extended POSIX regular expressions"
-msgstr "erweiterte reguläre Ausdrücke aus POSIX verwenden"
+#: builtin/interpret-trailers.c:95
+msgid "edit files in place"
+msgstr "vorhandene Dateien direkt bearbeiten"
 
-#: builtin/grep.c:821
-msgid "use basic POSIX regular expressions (default)"
-msgstr "grundlegende reguläre Ausdrücke aus POSIX verwenden (Standard)"
+#: builtin/interpret-trailers.c:96
+msgid "trim empty trailers"
+msgstr "kürzt leere Anhänge"
 
-#: builtin/grep.c:824
-msgid "interpret patterns as fixed strings"
-msgstr "Muster als feste Zeichenketten interpretieren"
+#: builtin/interpret-trailers.c:99
+msgid "where to place the new trailer"
+msgstr "wo der neue Anhang platziert wird"
 
-#: builtin/grep.c:827
-msgid "use Perl-compatible regular expressions"
-msgstr "Perl-kompatible reguläre Ausdrücke verwenden"
+#: builtin/interpret-trailers.c:101
+msgid "action if trailer already exists"
+msgstr "Aktion, wenn Anhang bereits existiert"
 
-#: builtin/grep.c:830
-msgid "show line numbers"
-msgstr "Zeilennummern anzeigen"
+#: builtin/interpret-trailers.c:103
+msgid "action if trailer is missing"
+msgstr "Aktion, wenn Anhang fehlt"
 
-#: builtin/grep.c:831
-msgid "don't show filenames"
-msgstr "keine Dateinamen anzeigen"
+#: builtin/interpret-trailers.c:105
+msgid "output only the trailers"
+msgstr "nur Anhänge ausgeben"
 
-#: builtin/grep.c:832
-msgid "show filenames"
-msgstr "Dateinamen anzeigen"
+#: builtin/interpret-trailers.c:106
+msgid "do not apply config rules"
+msgstr "Regeln aus Konfiguration nicht anwenden"
 
-#: builtin/grep.c:834
-msgid "show filenames relative to top directory"
-msgstr "Dateinamen relativ zum Projektverzeichnis anzeigen"
+#: builtin/interpret-trailers.c:107
+msgid "join whitespace-continued values"
+msgstr "durch Leerzeichen fortgesetzte Werte verbinden"
 
-#: builtin/grep.c:836
-msgid "show only filenames instead of matching lines"
-msgstr "nur Dateinamen anzeigen anstatt übereinstimmende Zeilen"
+#: builtin/interpret-trailers.c:108
+msgid "set parsing options"
+msgstr "Optionen für das Parsen setzen"
 
-#: builtin/grep.c:838
-msgid "synonym for --files-with-matches"
-msgstr "Synonym für --files-with-matches"
+#: builtin/interpret-trailers.c:110
+msgid "do not treat --- specially"
+msgstr "--- nicht speziell behandeln"
 
-#: builtin/grep.c:841
-msgid "show only the names of files without match"
-msgstr "nur die Dateinamen ohne Übereinstimmungen anzeigen"
+#: builtin/interpret-trailers.c:111
+msgid "trailer"
+msgstr "Anhang"
 
-#: builtin/grep.c:843
-msgid "print NUL after filenames"
-msgstr "NUL-Zeichen nach Dateinamen ausgeben"
+#: builtin/interpret-trailers.c:112
+msgid "trailer(s) to add"
+msgstr "Anhang/Anhänge hinzufügen"
 
-#: builtin/grep.c:846
-msgid "show the number of matches instead of matching lines"
-msgstr "anstatt der Zeilen, die Anzahl der übereinstimmenden Zeilen anzeigen"
+#: builtin/interpret-trailers.c:123
+msgid "--trailer with --only-input does not make sense"
+msgstr ""
+"Die Optionen --trailer und --only-input können nicht gemeinsam verwendet "
+"werden."
 
-#: builtin/grep.c:847
-msgid "highlight matches"
-msgstr "Übereinstimmungen hervorheben"
+#: builtin/interpret-trailers.c:133
+msgid "no input file given for in-place editing"
+msgstr "keine Datei zur direkten Bearbeitung angegeben"
 
-#: builtin/grep.c:849
-msgid "print empty line between matches from different files"
-msgstr ""
-"eine Leerzeile zwischen Übereinstimmungen in verschiedenen Dateien ausgeben"
+#: builtin/log.c:56
+msgid "git log [<options>] [<revision-range>] [[--] <path>...]"
+msgstr "git log [<Optionen>] [<Commitbereich>] [[--] <Pfad>...]"
 
-#: builtin/grep.c:851
-msgid "show filename only once above matches from same file"
-msgstr ""
-"den Dateinamen nur einmal oberhalb der Übereinstimmungen aus dieser Datei "
-"anzeigen"
+#: builtin/log.c:57
+msgid "git show [<options>] <object>..."
+msgstr "git show [<Optionen>] <Objekt>..."
 
-#: builtin/grep.c:854
-msgid "show <n> context lines before and after matches"
-msgstr "<n> Zeilen vor und nach den Übereinstimmungen anzeigen"
+#: builtin/log.c:110
+#, c-format
+msgid "invalid --decorate option: %s"
+msgstr "Ungültige Option für --decorate: %s"
 
-#: builtin/grep.c:857
-msgid "show <n> context lines before matches"
-msgstr "<n> Zeilen vor den Übereinstimmungen anzeigen"
+#: builtin/log.c:174
+msgid "show source"
+msgstr "Quelle anzeigen"
 
-#: builtin/grep.c:859
-msgid "show <n> context lines after matches"
-msgstr "<n> Zeilen nach den Übereinstimmungen anzeigen"
+#: builtin/log.c:175
+msgid "Use mail map file"
+msgstr "\"mailmap\"-Datei verwenden"
 
-#: builtin/grep.c:861
-msgid "use <n> worker threads"
-msgstr "<n> Threads benutzen"
+#: builtin/log.c:177
+msgid "only decorate refs that match <pattern>"
+msgstr "\"decorate\" nur bei Referenzen anwenden, die <Muster> entsprechen"
 
-#: builtin/grep.c:862
-msgid "shortcut for -C NUM"
-msgstr "Kurzform für -C NUM"
+#: builtin/log.c:179
+msgid "do not decorate refs that match <pattern>"
+msgstr "\"decorate\" nicht bei Referenzen anwenden, die <Muster> entsprechen"
 
-#: builtin/grep.c:865
-msgid "show a line with the function name before matches"
-msgstr "eine Zeile mit dem Funktionsnamen vor Übereinstimmungen anzeigen"
+#: builtin/log.c:180
+msgid "decorate options"
+msgstr "decorate-Optionen"
 
-#: builtin/grep.c:867
-msgid "show the surrounding function"
-msgstr "die umgebende Funktion anzeigen"
+#: builtin/log.c:183
+msgid "Process line range n,m in file, counting from 1"
+msgstr "Verarbeitet nur Zeilen im Bereich n,m in der Datei, gezählt von 1"
 
-#: builtin/grep.c:870
-msgid "read patterns from file"
-msgstr "Muster von einer Datei lesen"
+#: builtin/log.c:281
+#, c-format
+msgid "Final output: %d %s\n"
+msgstr "letzte Ausgabe: %d %s\n"
 
-#: builtin/grep.c:872
-msgid "match <pattern>"
-msgstr "<Muster> finden"
+#: builtin/log.c:535
+#, c-format
+msgid "git show %s: bad file"
+msgstr "git show %s: ungültige Datei"
 
-#: builtin/grep.c:874
-msgid "combine patterns specified with -e"
-msgstr "Muster kombinieren, die mit -e angegeben wurden"
+#: builtin/log.c:550 builtin/log.c:645
+#, c-format
+msgid "could not read object %s"
+msgstr "Konnte Objekt %s nicht lesen."
 
-#: builtin/grep.c:886
-msgid "indicate hit with exit status without output"
-msgstr "Übereinstimmungen nur durch Beendigungsstatus anzeigen"
+#: builtin/log.c:670
+#, c-format
+msgid "unknown type: %d"
+msgstr "Unbekannter Typ: %d"
 
-#: builtin/grep.c:888
-msgid "show only matches from files that match all patterns"
+#: builtin/log.c:814
+#, c-format
+msgid "%s: invalid cover from description mode"
 msgstr ""
-"nur Übereinstimmungen von Dateien anzeigen, die allen Mustern entsprechen"
+"%s: Ungültiger Modus für Erstellung des Deckblattes aus der Beschreibung"
 
-#: builtin/grep.c:890
-msgid "show parse tree for grep expression"
-msgstr "geparstes Verzeichnis für \"grep\"-Ausdruck anzeigen"
+#: builtin/log.c:821
+msgid "format.headers without value"
+msgstr "format.headers ohne Wert"
 
-#: builtin/grep.c:894
-msgid "pager"
-msgstr "Anzeigeprogramm"
+#: builtin/log.c:936
+msgid "name of output directory is too long"
+msgstr "Name des Ausgabeverzeichnisses ist zu lang."
 
-#: builtin/grep.c:894
-msgid "show matching files in the pager"
-msgstr "Dateien mit Übereinstimmungen im Anzeigeprogramm anzeigen"
+#: builtin/log.c:952
+#, c-format
+msgid "cannot open patch file %s"
+msgstr "Kann Patch-Datei %s nicht öffnen"
 
-#: builtin/grep.c:898
-msgid "allow calling of grep(1) (ignored by this build)"
-msgstr "den Aufruf von grep(1) erlauben (von dieser Programmversion ignoriert)"
+#: builtin/log.c:969
+msgid "need exactly one range"
+msgstr "Brauche genau einen Commit-Bereich."
 
-#: builtin/grep.c:962
-msgid "no pattern given."
-msgstr "keine Muster angegeben"
+#: builtin/log.c:979
+msgid "not a range"
+msgstr "Kein Commit-Bereich."
 
-#: builtin/grep.c:994
-msgid "--no-index or --untracked cannot be used with revs"
-msgstr "--no-index oder --untracked können nicht mit Commits verwendet werden"
+#: builtin/log.c:1143
+msgid "cover letter needs email format"
+msgstr "Anschreiben benötigt E-Mail-Format"
 
-#: builtin/grep.c:1001
-#, c-format
-msgid "unable to resolve revision: %s"
-msgstr "Konnte Commit nicht auflösen: %s"
+#: builtin/log.c:1149
+msgid "failed to create cover-letter file"
+msgstr "Fehler beim Erstellen der Datei für das Anschreiben."
 
-#: builtin/grep.c:1036 builtin/index-pack.c:1519
+#: builtin/log.c:1228
 #, c-format
-msgid "invalid number of threads specified (%d)"
-msgstr "ungültige Anzahl von Threads angegeben (%d)"
-
-#: builtin/grep.c:1041
-msgid "no threads support, ignoring --threads"
-msgstr "keine Unterstützung von Threads, --threads wird ignoriert"
+msgid "insane in-reply-to: %s"
+msgstr "ungültiges in-reply-to: %s"
 
-#: builtin/grep.c:1065
-msgid "--open-files-in-pager only works on the worktree"
-msgstr ""
-"Die Option --open-files-in-pager kann nur innerhalb des "
-"Arbeitsverzeichnisses verwendet werden."
+#: builtin/log.c:1255
+msgid "git format-patch [<options>] [<since> | <revision-range>]"
+msgstr "git format-patch [<Optionen>] [<seit> | <Commitbereich>]"
 
-#: builtin/grep.c:1088
-msgid "option not supported with --recurse-submodules."
-msgstr "Option wird mit --recurse-submodules nicht unterstützt."
+#: builtin/log.c:1313
+msgid "two output directories?"
+msgstr "Zwei Ausgabeverzeichnisse?"
 
-#: builtin/grep.c:1094
-msgid "--cached or --untracked cannot be used with --no-index."
-msgstr ""
-"Die Optionen --cached und --untracked können nicht mit --no-index verwendet "
-"werden."
+#: builtin/log.c:1424 builtin/log.c:2197 builtin/log.c:2199 builtin/log.c:2211
+#, c-format
+msgid "unknown commit %s"
+msgstr "Unbekannter Commit %s"
 
-#: builtin/grep.c:1100
-msgid "--[no-]exclude-standard cannot be used for tracked contents."
-msgstr ""
-"Die Option --[no-]exclude-standard kann nicht mit versionierten Inhalten "
-"verwendet werden."
+#: builtin/log.c:1434 builtin/replace.c:58 builtin/replace.c:207
+#: builtin/replace.c:210
+#, c-format
+msgid "failed to resolve '%s' as a valid ref"
+msgstr "Konnte '%s' nicht als gültige Referenz auflösen."
 
-#: builtin/grep.c:1108
-msgid "both --cached and trees are given."
-msgstr "Die Option --cached kann nicht mit \"Tree\"-Objekten verwendet werden."
+#: builtin/log.c:1439
+msgid "could not find exact merge base"
+msgstr "Konnte keine exakte Merge-Basis finden."
 
-#: builtin/hash-object.c:83
+#: builtin/log.c:1443
 msgid ""
-"git hash-object [-t <type>] [-w] [--path=<file> | --no-filters] [--stdin] "
-"[--] <file>..."
+"failed to get upstream, if you want to record base commit automatically,\n"
+"please use git branch --set-upstream-to to track a remote branch.\n"
+"Or you could specify base commit by --base=<base-commit-id> manually"
 msgstr ""
-"git hash-object [-t <Art>] [-w] [--path=<Datei> | --no-filters] [--stdin] "
-"[--] <Datei>..."
+"Fehler beim Bestimmen des Upstream-Branches. Wenn Sie den Basis-Commit\n"
+"automatisch speichern lassen möchten, benutzen Sie bitte\n"
+"'git branch --set-upstream-to', um einem Remote-Branch zu folgen.\n"
+"Oder geben Sie den Basis-Commit mit '--base=<Basis-Commit-Id>' manuell an."
 
-#: builtin/hash-object.c:84
-msgid "git hash-object  --stdin-paths"
-msgstr "git hash-object  --stdin-paths"
+#: builtin/log.c:1463
+msgid "failed to find exact merge base"
+msgstr "Fehler beim Finden einer exakten Merge-Basis."
 
-#: builtin/hash-object.c:96
-msgid "type"
-msgstr "Art"
+#: builtin/log.c:1474
+msgid "base commit should be the ancestor of revision list"
+msgstr "Basis-Commit sollte der Vorgänger der Revisionsliste sein."
 
-#: builtin/hash-object.c:96
-msgid "object type"
-msgstr "Art des Objektes"
+#: builtin/log.c:1478
+msgid "base commit shouldn't be in revision list"
+msgstr "Basis-Commit sollte nicht in der Revisionsliste enthalten sein."
 
-#: builtin/hash-object.c:97
-msgid "write the object into the object database"
-msgstr "das Objekt in die Objektdatenbank schreiben"
+#: builtin/log.c:1531
+msgid "cannot get patch id"
+msgstr "kann Patch-Id nicht lesen"
 
-#: builtin/hash-object.c:99
-msgid "read the object from stdin"
-msgstr "das Objekt von der Standard-Eingabe lesen"
+#: builtin/log.c:1583
+msgid "failed to infer range-diff ranges"
+msgstr "Fehler beim Ableiten des range-diff-Bereichs."
 
-#: builtin/hash-object.c:101
-msgid "store file as is without filters"
-msgstr "Datei wie sie ist speichern, ohne Filter"
+#: builtin/log.c:1629
+msgid "use [PATCH n/m] even with a single patch"
+msgstr "[PATCH n/m] auch mit einzelnem Patch verwenden"
 
-#: builtin/hash-object.c:102
-msgid ""
-"just hash any random garbage to create corrupt objects for debugging Git"
-msgstr ""
-"Hash über zufällige Daten, zur Erzeugung von beschädigten Objekten zur\n"
-"Fehlersuche in Git, erzeugen"
+#: builtin/log.c:1632
+msgid "use [PATCH] even with multiple patches"
+msgstr "[PATCH] auch mit mehreren Patches verwenden"
 
-#: builtin/hash-object.c:103
-msgid "process file as it were from this path"
-msgstr "Datei verarbeiten, als ob sie von diesem Pfad wäre"
+#: builtin/log.c:1636
+msgid "print patches to standard out"
+msgstr "Ausgabe der Patches in Standard-Ausgabe"
 
-#: builtin/help.c:43
-msgid "print all available commands"
-msgstr "alle vorhandenen Befehle anzeigen"
+#: builtin/log.c:1638
+msgid "generate a cover letter"
+msgstr "ein Deckblatt erzeugen"
 
-#: builtin/help.c:44
-msgid "exclude guides"
-msgstr "Anleitungen ausschließen"
+#: builtin/log.c:1640
+msgid "use simple number sequence for output file names"
+msgstr "einfache Nummernfolge für die Namen der Ausgabedateien verwenden"
 
-#: builtin/help.c:45
-msgid "print list of useful guides"
-msgstr "Liste von allgemein verwendeten Anleitungen anzeigen"
+#: builtin/log.c:1641
+msgid "sfx"
+msgstr "Dateiendung"
 
-#: builtin/help.c:46
-msgid "show man page"
-msgstr "Handbuch anzeigen"
+#: builtin/log.c:1642
+msgid "use <sfx> instead of '.patch'"
+msgstr "<Dateiendung> anstatt '.patch' verwenden"
 
-#: builtin/help.c:47
-msgid "show manual in web browser"
-msgstr "Handbuch in einem Webbrowser anzeigen"
+#: builtin/log.c:1644
+msgid "start numbering patches at <n> instead of 1"
+msgstr "die Nummerierung der Patches bei <n> anstatt bei 1 beginnen"
 
-#: builtin/help.c:49
-msgid "show info page"
-msgstr "Info-Seite anzeigen"
+#: builtin/log.c:1646
+msgid "mark the series as Nth re-roll"
+msgstr "die Serie als n-te Fassung kennzeichnen"
 
-#: builtin/help.c:55
-msgid "git help [--all] [--guides] [--man | --web | --info] [<command>]"
-msgstr "git help [--all] [--guides] [--man | --web | --info] [<Befehl>]"
+#: builtin/log.c:1648
+msgid "Use [RFC PATCH] instead of [PATCH]"
+msgstr "[RFC PATCH] anstatt [PATCH] verwenden"
 
-#: builtin/help.c:67
-#, c-format
-msgid "unrecognized help format '%s'"
-msgstr "nicht erkanntes Hilfeformat: %s"
+#: builtin/log.c:1651
+msgid "cover-from-description-mode"
+msgstr "Modus für Erstellung des Deckblattes aus der Beschreibung"
 
-#: builtin/help.c:94
-msgid "Failed to start emacsclient."
-msgstr "Konnte emacsclient nicht starten."
+#: builtin/log.c:1652
+msgid "generate parts of a cover letter based on a branch's description"
+msgstr ""
+"Erzeuge Teile des Deckblattes basierend auf der Beschreibung des Branches"
 
-#: builtin/help.c:107
-msgid "Failed to parse emacsclient version."
-msgstr "Konnte Version des emacsclient nicht parsen."
+#: builtin/log.c:1654
+msgid "Use [<prefix>] instead of [PATCH]"
+msgstr "Nutze [<Präfix>] statt [PATCH]"
 
-#: builtin/help.c:115
-#, c-format
-msgid "emacsclient version '%d' too old (< 22)."
-msgstr "Version des emacsclient '%d' ist zu alt (< 22)."
+#: builtin/log.c:1657
+msgid "store resulting files in <dir>"
+msgstr "erzeugte Dateien in <Verzeichnis> speichern"
 
-#: builtin/help.c:133 builtin/help.c:155 builtin/help.c:165 builtin/help.c:173
-#, c-format
-msgid "failed to exec '%s'"
-msgstr "Fehler beim Ausführen von '%s'"
+#: builtin/log.c:1660
+msgid "don't strip/add [PATCH]"
+msgstr "[PATCH] nicht entfernen/hinzufügen"
 
-#: builtin/help.c:211
-#, c-format
-msgid ""
-"'%s': path for unsupported man viewer.\n"
-"Please consider using 'man.<tool>.cmd' instead."
-msgstr ""
-"'%s': Pfad für nicht unterstützten Handbuchbetrachter.\n"
-"Sie könnten stattdessen 'man.<Werkzeug>.cmd' benutzen."
+#: builtin/log.c:1663
+msgid "don't output binary diffs"
+msgstr "keine binären Unterschiede ausgeben"
 
-#: builtin/help.c:223
-#, c-format
-msgid ""
-"'%s': cmd for supported man viewer.\n"
-"Please consider using 'man.<tool>.path' instead."
+#: builtin/log.c:1665
+msgid "output all-zero hash in From header"
+msgstr "Hash mit Nullen in \"From\"-Header ausgeben"
+
+#: builtin/log.c:1667
+msgid "don't include a patch matching a commit upstream"
 msgstr ""
-"'%s': Programm für unterstützten Handbuchbetrachter.\n"
-"Sie könnten stattdessen 'man.<Werkzeug>.path' benutzen."
+"keine Patches einschließen, die einem Commit im Upstream-Branch entsprechen"
 
-#: builtin/help.c:340
-#, c-format
-msgid "'%s': unknown man viewer."
-msgstr "'%s': unbekannter Handbuch-Betrachter."
+#: builtin/log.c:1669
+msgid "show patch format instead of default (patch + stat)"
+msgstr "Patchformat anstatt des Standards anzeigen (Patch + Zusammenfassung)"
 
-#: builtin/help.c:357
-msgid "no man viewer handled the request"
-msgstr "kein Handbuch-Betrachter konnte mit dieser Anfrage umgehen"
+#: builtin/log.c:1671
+msgid "Messaging"
+msgstr "E-Mail-Einstellungen"
 
-#: builtin/help.c:365
-msgid "no info viewer handled the request"
-msgstr "kein Informations-Betrachter konnte mit dieser Anfrage umgehen"
+#: builtin/log.c:1672
+msgid "header"
+msgstr "Header"
 
-#: builtin/help.c:407
-msgid "Defining attributes per path"
-msgstr "Definition von Attributen pro Pfad"
+#: builtin/log.c:1673
+msgid "add email header"
+msgstr "E-Mail-Header hinzufügen"
 
-#: builtin/help.c:408
-msgid "Everyday Git With 20 Commands Or So"
-msgstr "Tägliche Benutzung von Git mit ungefähr 20 Befehlen"
-
-#: builtin/help.c:409
-msgid "A Git glossary"
-msgstr "Ein Git-Glossar"
+#: builtin/log.c:1674 builtin/log.c:1676
+msgid "email"
+msgstr "E-Mail"
 
-#: builtin/help.c:410
-msgid "Specifies intentionally untracked files to ignore"
-msgstr "Spezifikation von bewusst ignorierten, unversionierten Dateien"
+#: builtin/log.c:1674
+msgid "add To: header"
+msgstr "\"To:\"-Header hinzufügen"
 
-#: builtin/help.c:411
-msgid "Defining submodule properties"
-msgstr "Definition von Submodul-Eigenschaften"
+#: builtin/log.c:1676
+msgid "add Cc: header"
+msgstr "\"Cc:\"-Header hinzufügen"
 
-#: builtin/help.c:412
-msgid "Specifying revisions and ranges for Git"
-msgstr "Spezifikation von Commits und Bereichen für Git"
+#: builtin/log.c:1678
+msgid "ident"
+msgstr "Ident"
 
-#: builtin/help.c:413
-msgid "A tutorial introduction to Git (for version 1.5.1 or newer)"
-msgstr "Eine einführende Anleitung zu Git (für Version 1.5.1 oder neuer)"
+#: builtin/log.c:1679
+msgid "set From address to <ident> (or committer ident if absent)"
+msgstr ""
+"\"From\"-Adresse auf <Ident> setzen (oder Ident des Commit-Erstellers, wenn "
+"fehlend)"
 
-#: builtin/help.c:414
-msgid "An overview of recommended workflows with Git"
-msgstr "Eine Übersicht über empfohlene Arbeitsabläufe mit Git"
+#: builtin/log.c:1681
+msgid "message-id"
+msgstr "message-id"
 
-#: builtin/help.c:426
-msgid "The common Git guides are:\n"
-msgstr "Die allgemein verwendeten Git-Anleitungen sind:\n"
+#: builtin/log.c:1682
+msgid "make first mail a reply to <message-id>"
+msgstr "aus erster E-Mail eine Antwort zu <message-id> machen"
 
-#: builtin/help.c:444
-#, c-format
-msgid "'%s' is aliased to '%s'"
-msgstr "Für '%s' wurde der Alias '%s' angelegt."
+#: builtin/log.c:1683 builtin/log.c:1686
+msgid "boundary"
+msgstr "Grenze"
 
-#: builtin/help.c:466 builtin/help.c:483
-#, c-format
-msgid "usage: %s%s"
-msgstr "Verwendung: %s%s"
+#: builtin/log.c:1684
+msgid "attach the patch"
+msgstr "den Patch anhängen"
 
-#: builtin/index-pack.c:157
-#, c-format
-msgid "unable to open %s"
-msgstr "kann %s nicht öffnen"
+#: builtin/log.c:1687
+msgid "inline the patch"
+msgstr "den Patch direkt in die Nachricht einfügen"
 
-#: builtin/index-pack.c:207
-#, c-format
-msgid "object type mismatch at %s"
-msgstr "Objekt-Typen passen bei %s nicht zusammen"
+#: builtin/log.c:1691
+msgid "enable message threading, styles: shallow, deep"
+msgstr "Nachrichtenverkettung aktivieren, Stile: shallow, deep"
 
-#: builtin/index-pack.c:227
-#, c-format
-msgid "did not receive expected object %s"
-msgstr "konnte erwartetes Objekt %s nicht empfangen"
+#: builtin/log.c:1693
+msgid "signature"
+msgstr "Signatur"
 
-#: builtin/index-pack.c:230
-#, c-format
-msgid "object %s: expected type %s, found %s"
-msgstr "Objekt %s: erwarteter Typ %s, %s gefunden"
+#: builtin/log.c:1694
+msgid "add a signature"
+msgstr "eine Signatur hinzufügen"
 
-#: builtin/index-pack.c:272
-#, c-format
-msgid "cannot fill %d byte"
-msgid_plural "cannot fill %d bytes"
-msgstr[0] "kann %d Byte nicht lesen"
-msgstr[1] "kann %d Bytes nicht lesen"
+#: builtin/log.c:1695
+msgid "base-commit"
+msgstr "Basis-Commit"
 
-#: builtin/index-pack.c:282
-msgid "early EOF"
-msgstr "zu frühes Dateiende"
+#: builtin/log.c:1696
+msgid "add prerequisite tree info to the patch series"
+msgstr "erforderliche Revisions-Informationen der Patch-Serie hinzufügen"
 
-#: builtin/index-pack.c:283
-msgid "read error on input"
-msgstr "Fehler beim Lesen der Eingabe"
+#: builtin/log.c:1698
+msgid "add a signature from a file"
+msgstr "eine Signatur aus einer Datei hinzufügen"
 
-#: builtin/index-pack.c:295
-msgid "used more bytes than were available"
-msgstr "verwendete mehr Bytes als verfügbar waren"
+#: builtin/log.c:1699
+msgid "don't print the patch filenames"
+msgstr "keine Dateinamen der Patches anzeigen"
 
-#: builtin/index-pack.c:302
-msgid "pack too large for current definition of off_t"
-msgstr "Paket ist zu groß für die aktuelle Definition von off_t"
+#: builtin/log.c:1701
+msgid "show progress while generating patches"
+msgstr "Forschrittsanzeige während der Erzeugung der Patches"
 
-#: builtin/index-pack.c:305 builtin/unpack-objects.c:93
-msgid "pack exceeds maximum allowed size"
-msgstr "Paket überschreitet die maximal erlaubte Größe"
+#: builtin/log.c:1703
+msgid "show changes against <rev> in cover letter or single patch"
+msgstr ""
+"Änderungen gegenüber <Commit> im Deckblatt oder einzelnem Patch anzeigen"
 
-#: builtin/index-pack.c:320
-#, c-format
-msgid "unable to create '%s'"
-msgstr "konnte '%s' nicht erstellen"
+#: builtin/log.c:1706
+msgid "show changes against <refspec> in cover letter or single patch"
+msgstr ""
+"Änderungen gegenüber <Refspec> im Deckblatt oder einzelnem Patch anzeigen"
 
-#: builtin/index-pack.c:326
+#: builtin/log.c:1708
+msgid "percentage by which creation is weighted"
+msgstr "Prozentsatz mit welchem Erzeugung gewichtet wird"
+
+#: builtin/log.c:1792
 #, c-format
-msgid "cannot open packfile '%s'"
-msgstr "Kann Paketdatei '%s' nicht öffnen"
+msgid "invalid ident line: %s"
+msgstr "Ungültige Identifikationszeile: %s"
 
-#: builtin/index-pack.c:340
-msgid "pack signature mismatch"
-msgstr "Paketsignatur stimmt nicht überein"
+#: builtin/log.c:1807
+msgid "-n and -k are mutually exclusive"
+msgstr "-n und -k schließen sich gegenseitig aus."
 
-#: builtin/index-pack.c:342
-#, c-format
-msgid "pack version %<PRIu32> unsupported"
-msgstr "Paketversion %<PRIu32> nicht unterstützt"
+#: builtin/log.c:1809
+msgid "--subject-prefix/--rfc and -k are mutually exclusive"
+msgstr "--subject-prefix/--rfc und -k schließen sich gegenseitig aus."
 
-#: builtin/index-pack.c:360
-#, c-format
-msgid "pack has bad object at offset %<PRIuMAX>: %s"
-msgstr "Paket hat ein ungültiges Objekt bei Versatz %<PRIuMAX>: %s"
+#: builtin/log.c:1817
+msgid "--name-only does not make sense"
+msgstr "Die Option --name-only kann nicht verwendet werden."
 
-#: builtin/index-pack.c:481
-#, c-format
-msgid "inflate returned %d"
-msgstr "Dekomprimierung gab %d zurück"
+#: builtin/log.c:1819
+msgid "--name-status does not make sense"
+msgstr "Die Option --name-status kann nicht verwendet werden."
+
+#: builtin/log.c:1821
+msgid "--check does not make sense"
+msgstr "Die Option --check kann nicht verwendet werden."
 
-#: builtin/index-pack.c:530
-msgid "offset value overflow for delta base object"
-msgstr "Wert für Versatz bei Differenzobjekt übergelaufen"
+#: builtin/log.c:1854
+msgid "standard output, or directory, which one?"
+msgstr "Standard-Ausgabe oder Verzeichnis, welches von beidem?"
 
-#: builtin/index-pack.c:538
-msgid "delta base offset is out of bound"
-msgstr ""
-"Wert für Versatz bei Differenzobjekt liegt außerhalb des gültigen Bereichs"
+#: builtin/log.c:1958
+msgid "--interdiff requires --cover-letter or single patch"
+msgstr "--interdiff erfordert --cover-letter oder einzelnen Patch."
+
+#: builtin/log.c:1962
+msgid "Interdiff:"
+msgstr "Interdiff:"
 
-#: builtin/index-pack.c:546
+#: builtin/log.c:1963
 #, c-format
-msgid "unknown object type %d"
-msgstr "Unbekannter Objekt-Typ %d"
+msgid "Interdiff against v%d:"
+msgstr "Interdiff gegen v%d:"
 
-#: builtin/index-pack.c:577
-msgid "cannot pread pack file"
-msgstr "Kann Paketdatei %s nicht lesen"
+#: builtin/log.c:1969
+msgid "--creation-factor requires --range-diff"
+msgstr "--creation-factor erfordert --range-diff"
 
-#: builtin/index-pack.c:579
-#, c-format
-msgid "premature end of pack file, %<PRIuMAX> byte missing"
-msgid_plural "premature end of pack file, %<PRIuMAX> bytes missing"
-msgstr[0] "frühzeitiges Ende der Paketdatei, vermisse %<PRIuMAX> Byte"
-msgstr[1] "frühzeitiges Ende der Paketdatei, vermisse %<PRIuMAX> Bytes"
+#: builtin/log.c:1973
+msgid "--range-diff requires --cover-letter or single patch"
+msgstr "--range-diff erfordert --cover-letter oder einzelnen Patch."
 
-#: builtin/index-pack.c:605
-msgid "serious inflate inconsistency"
-msgstr "ernsthafte Inkonsistenz nach Dekomprimierung"
+#: builtin/log.c:1981
+msgid "Range-diff:"
+msgstr "Range-Diff:"
 
-#: builtin/index-pack.c:750 builtin/index-pack.c:756 builtin/index-pack.c:779
-#: builtin/index-pack.c:818 builtin/index-pack.c:827
+#: builtin/log.c:1982
 #, c-format
-msgid "SHA1 COLLISION FOUND WITH %s !"
-msgstr "SHA1 KOLLISION MIT %s GEFUNDEN !"
+msgid "Range-diff against v%d:"
+msgstr "Range-Diff gegen v%d:"
 
-#: builtin/index-pack.c:753 builtin/pack-objects.c:182
-#: builtin/pack-objects.c:276
+#: builtin/log.c:1993
 #, c-format
-msgid "unable to read %s"
-msgstr "kann %s nicht lesen"
+msgid "unable to read signature file '%s'"
+msgstr "Konnte Signatur-Datei '%s' nicht lesen"
 
-#: builtin/index-pack.c:816
-#, c-format
-msgid "cannot read existing object info %s"
-msgstr "Kann existierende Informationen zu Objekt %s nicht lesen."
+#: builtin/log.c:2029
+msgid "Generating patches"
+msgstr "Erzeuge Patches"
 
-#: builtin/index-pack.c:824
-#, c-format
-msgid "cannot read existing object %s"
-msgstr "Kann existierendes Objekt %s nicht lesen."
+#: builtin/log.c:2073
+msgid "failed to create output files"
+msgstr "Fehler beim Erstellen der Ausgabedateien."
 
-#: builtin/index-pack.c:838
-#, c-format
-msgid "invalid blob object %s"
-msgstr "ungültiges Blob-Objekt %s"
+#: builtin/log.c:2132
+msgid "git cherry [-v] [<upstream> [<head> [<limit>]]]"
+msgstr "git cherry [-v] [<Upstream> [<Branch> [<Limit>]]]"
 
-#: builtin/index-pack.c:853
+#: builtin/log.c:2186
 #, c-format
-msgid "invalid %s"
-msgstr "Ungültiger Objekt-Typ %s"
+msgid ""
+"Could not find a tracked remote branch, please specify <upstream> manually.\n"
+msgstr ""
+"Konnte gefolgten Remote-Branch nicht finden, bitte geben Sie <Upstream> "
+"manuell an.\n"
 
-#: builtin/index-pack.c:856
-msgid "Error in object"
-msgstr "Fehler in Objekt"
+#: builtin/ls-files.c:470
+msgid "git ls-files [<options>] [<file>...]"
+msgstr "git ls-files [<Optionen>] [<Datei>...]"
 
-#: builtin/index-pack.c:858
-#, c-format
-msgid "Not all child objects of %s are reachable"
-msgstr "Nicht alle Kind-Objekte von %s sind erreichbar"
+#: builtin/ls-files.c:526
+msgid "identify the file status with tags"
+msgstr "den Dateistatus mit Tags anzeigen"
 
-#: builtin/index-pack.c:930 builtin/index-pack.c:961
-msgid "failed to apply delta"
-msgstr "Konnte Dateiunterschied nicht anwenden"
+#: builtin/ls-files.c:528
+msgid "use lowercase letters for 'assume unchanged' files"
+msgstr ""
+"Kleinbuchstaben für Dateien mit 'assume unchanged' Markierung verwenden"
 
-#: builtin/index-pack.c:1131
-msgid "Receiving objects"
-msgstr "Empfange Objekte"
+#: builtin/ls-files.c:530
+msgid "use lowercase letters for 'fsmonitor clean' files"
+msgstr "Kleinbuchstaben für 'fsmonitor clean' Dateien verwenden"
 
-#: builtin/index-pack.c:1131
-msgid "Indexing objects"
-msgstr "Indiziere Objekte"
+#: builtin/ls-files.c:532
+msgid "show cached files in the output (default)"
+msgstr "zwischengespeicherte Dateien in der Ausgabe anzeigen (Standard)"
 
-#: builtin/index-pack.c:1165
-msgid "pack is corrupted (SHA1 mismatch)"
-msgstr "Paket ist beschädigt (SHA1 unterschiedlich)"
+#: builtin/ls-files.c:534
+msgid "show deleted files in the output"
+msgstr "entfernte Dateien in der Ausgabe anzeigen"
 
-#: builtin/index-pack.c:1170
-msgid "cannot fstat packfile"
-msgstr "kann Paketdatei nicht lesen"
+#: builtin/ls-files.c:536
+msgid "show modified files in the output"
+msgstr "geänderte Dateien in der Ausgabe anzeigen"
 
-#: builtin/index-pack.c:1173
-msgid "pack has junk at the end"
-msgstr "Paketende enthält nicht verwendbaren Inhalt"
+#: builtin/ls-files.c:538
+msgid "show other files in the output"
+msgstr "sonstige Dateien in der Ausgabe anzeigen"
 
-#: builtin/index-pack.c:1185
-msgid "confusion beyond insanity in parse_pack_objects()"
-msgstr "Fehler beim Ausführen von \"parse_pack_objects()\""
+#: builtin/ls-files.c:540
+msgid "show ignored files in the output"
+msgstr "ignorierte Dateien in der Ausgabe anzeigen"
 
-#: builtin/index-pack.c:1208
-msgid "Resolving deltas"
-msgstr "Löse Unterschiede auf"
+#: builtin/ls-files.c:543
+msgid "show staged contents' object name in the output"
+msgstr ""
+"Objektnamen von Inhalten, die zum Commit vorgemerkt sind, in der Ausgabe "
+"anzeigen"
 
-#: builtin/index-pack.c:1219
-#, c-format
-msgid "unable to create thread: %s"
-msgstr "kann Thread nicht erzeugen: %s"
+#: builtin/ls-files.c:545
+msgid "show files on the filesystem that need to be removed"
+msgstr "Dateien im Dateisystem, die gelöscht werden müssen, anzeigen"
 
-#: builtin/index-pack.c:1261
-msgid "confusion beyond insanity"
-msgstr "Fehler beim Auflösen der Unterschiede"
+#: builtin/ls-files.c:547
+msgid "show 'other' directories' names only"
+msgstr "nur Namen von 'sonstigen' Verzeichnissen anzeigen"
 
-#: builtin/index-pack.c:1267
-#, c-format
-msgid "completed with %d local object"
-msgid_plural "completed with %d local objects"
-msgstr[0] "abgeschlossen mit %d lokalem Objekt"
-msgstr[1] "abgeschlossen mit %d lokalen Objekten"
+#: builtin/ls-files.c:549
+msgid "show line endings of files"
+msgstr "Zeilenenden von Dateien anzeigen"
 
-#: builtin/index-pack.c:1279
-#, c-format
-msgid "Unexpected tail checksum for %s (disk corruption?)"
-msgstr "Unerwartete Prüfsumme für %s (Festplattenfehler?)"
+#: builtin/ls-files.c:551
+msgid "don't show empty directories"
+msgstr "keine leeren Verzeichnisse anzeigen"
 
-#: builtin/index-pack.c:1283
-#, c-format
-msgid "pack has %d unresolved delta"
-msgid_plural "pack has %d unresolved deltas"
-msgstr[0] "Paket hat %d unaufgelöste Unterschied"
-msgstr[1] "Paket hat %d unaufgelöste Unterschiede"
+#: builtin/ls-files.c:554
+msgid "show unmerged files in the output"
+msgstr "nicht zusammengeführte Dateien in der Ausgabe anzeigen"
 
-#: builtin/index-pack.c:1307
-#, c-format
-msgid "unable to deflate appended object (%d)"
-msgstr "Konnte angehängtes Objekt (%d) nicht komprimieren"
+#: builtin/ls-files.c:556
+msgid "show resolve-undo information"
+msgstr "'resolve-undo' Informationen anzeigen"
 
-#: builtin/index-pack.c:1383
-#, c-format
-msgid "local object %s is corrupt"
-msgstr "lokales Objekt %s ist beschädigt"
+#: builtin/ls-files.c:558
+msgid "skip files matching pattern"
+msgstr "Dateien auslassen, die einem Muster entsprechen"
 
-#: builtin/index-pack.c:1397
-#, c-format
-msgid "packfile name '%s' does not end with '.pack'"
-msgstr "Name der Paketdatei '%s' endet nicht mit '.pack'"
+#: builtin/ls-files.c:561
+msgid "exclude patterns are read from <file>"
+msgstr "Muster, gelesen von <Datei>, ausschließen"
 
-#: builtin/index-pack.c:1422
-#, c-format
-msgid "cannot write %s file '%s'"
-msgstr "Kann %s Datei '%s' nicht schreiben."
+#: builtin/ls-files.c:564
+msgid "read additional per-directory exclude patterns in <file>"
+msgstr "zusätzliche pro-Verzeichnis Auschlussmuster aus <Datei> auslesen"
 
-#: builtin/index-pack.c:1430
-#, c-format
-msgid "cannot close written %s file '%s'"
-msgstr "Kann eben geschriebene %s Datei '%s' nicht schließen."
+#: builtin/ls-files.c:566
+msgid "add the standard git exclusions"
+msgstr "die standardmäßigen Git-Ausschlüsse hinzufügen"
 
-#: builtin/index-pack.c:1454
-msgid "error while closing pack file"
-msgstr "Fehler beim Schließen der Paketdatei"
+#: builtin/ls-files.c:570
+msgid "make the output relative to the project top directory"
+msgstr "Ausgabe relativ zum Projektverzeichnis"
 
-#: builtin/index-pack.c:1468
-msgid "cannot store pack file"
-msgstr "Kann Paketdatei nicht speichern"
+#: builtin/ls-files.c:573
+msgid "recurse through submodules"
+msgstr "Rekursion in Submodulen durchführen"
 
-#: builtin/index-pack.c:1476
-msgid "cannot store index file"
-msgstr "Kann Indexdatei nicht speichern"
+#: builtin/ls-files.c:575
+msgid "if any <file> is not in the index, treat this as an error"
+msgstr "als Fehler behandeln, wenn sich eine <Datei> nicht im Index befindet"
 
-#: builtin/index-pack.c:1513
-#, c-format
-msgid "bad pack.indexversion=%<PRIu32>"
-msgstr "\"pack.indexversion=%<PRIu32>\" ist ungültig"
+#: builtin/ls-files.c:576
+msgid "tree-ish"
+msgstr "Commit-Referenz"
 
-#: builtin/index-pack.c:1581
-#, c-format
-msgid "Cannot open existing pack file '%s'"
-msgstr "Kann existierende Paketdatei '%s' nicht öffnen"
+#: builtin/ls-files.c:577
+msgid "pretend that paths removed since <tree-ish> are still present"
+msgstr ""
+"vorgeben, dass Pfade, die seit <Commit-Referenz> gelöscht wurden, immer noch "
+"vorhanden sind"
 
-#: builtin/index-pack.c:1583
-#, c-format
-msgid "Cannot open existing pack idx file for '%s'"
-msgstr "Kann existierende Indexdatei für Paket '%s' nicht öffnen"
+#: builtin/ls-files.c:579
+msgid "show debugging data"
+msgstr "Ausgaben zur Fehlersuche anzeigen"
 
-#: builtin/index-pack.c:1631
-#, c-format
-msgid "non delta: %d object"
-msgid_plural "non delta: %d objects"
-msgstr[0] "kein Unterschied: %d Objekt"
-msgstr[1] "kein Unterschied: %d Objekte"
+#: builtin/ls-remote.c:9
+msgid ""
+"git ls-remote [--heads] [--tags] [--refs] [--upload-pack=<exec>]\n"
+"                     [-q | --quiet] [--exit-code] [--get-url]\n"
+"                     [--symref] [<repository> [<refs>...]]"
+msgstr ""
+"git ls-remote [--heads] [--tags] [--refs] [--upload-pack=<Programm>]\n"
+"                     [-q | --quiet] [--exit-code] [--get-url]\n"
+"                     [--symref] [<Repository> [<Referenzen>...]]"
 
-#: builtin/index-pack.c:1638
-#, c-format
-msgid "chain length = %d: %lu object"
-msgid_plural "chain length = %d: %lu objects"
-msgstr[0] "Länge der Objekt-Liste = %d: %lu Objekt"
-msgstr[1] "Länge der Objekt-Liste = %d: %lu Objekte"
+#: builtin/ls-remote.c:59
+msgid "do not print remote URL"
+msgstr "URL des Remote-Repositories nicht ausgeben"
 
-#: builtin/index-pack.c:1675
-msgid "Cannot come back to cwd"
-msgstr "Kann nicht zurück zum Arbeitsverzeichnis wechseln"
+#: builtin/ls-remote.c:60 builtin/ls-remote.c:62 builtin/rebase.c:1518
+msgid "exec"
+msgstr "Programm"
 
-#: builtin/index-pack.c:1724 builtin/index-pack.c:1727
-#: builtin/index-pack.c:1743 builtin/index-pack.c:1747
-#, c-format
-msgid "bad %s"
-msgstr "%s ist ungültig"
+#: builtin/ls-remote.c:61 builtin/ls-remote.c:63
+msgid "path of git-upload-pack on the remote host"
+msgstr "Pfad zu \"git-upload-pack\" auf der Gegenseite"
 
-#: builtin/index-pack.c:1763
-msgid "--fix-thin cannot be used without --stdin"
-msgstr "Die Option --fix-thin kann nicht ohne --stdin verwendet werden."
+#: builtin/ls-remote.c:65
+msgid "limit to tags"
+msgstr "auf Tags einschränken"
 
-#: builtin/index-pack.c:1765
-msgid "--stdin requires a git repository"
-msgstr "--stdin erfordert ein Git-Repository"
+#: builtin/ls-remote.c:66
+msgid "limit to heads"
+msgstr "auf Branches einschränken"
 
-#: builtin/index-pack.c:1771
-msgid "--verify with no packfile name given"
-msgstr "Die Option --verify wurde ohne Namen der Paketdatei angegeben."
+#: builtin/ls-remote.c:67
+msgid "do not show peeled tags"
+msgstr "keine Tags anzeigen, die andere Tags enthalten"
 
-#: builtin/init-db.c:55
-#, c-format
-msgid "cannot stat '%s'"
-msgstr "Kann '%s' nicht lesen"
+#: builtin/ls-remote.c:69
+msgid "take url.<base>.insteadOf into account"
+msgstr "url.<Basis>.insteadOf berücksichtigen"
 
-#: builtin/init-db.c:61
-#, c-format
-msgid "cannot stat template '%s'"
-msgstr "kann Vorlage '%s' nicht lesen"
+#: builtin/ls-remote.c:72
+msgid "exit with exit code 2 if no matching refs are found"
+msgstr ""
+"mit Exit-Code 2 beenden, wenn keine übereinstimmenden Referenzen\n"
+"gefunden wurden"
 
-#: builtin/init-db.c:66
-#, c-format
-msgid "cannot opendir '%s'"
-msgstr "kann Verzeichnis '%s' nicht öffnen"
+#: builtin/ls-remote.c:75
+msgid "show underlying ref in addition to the object pointed by it"
+msgstr "zusätzlich zum Objekt die darauf verweisenden Referenzen anzeigen"
 
-#: builtin/init-db.c:77
-#, c-format
-msgid "cannot readlink '%s'"
-msgstr "kann Verweis '%s' nicht lesen"
+#: builtin/ls-tree.c:30
+msgid "git ls-tree [<options>] <tree-ish> [<path>...]"
+msgstr "git ls-tree [<Optionen>] <Commit-Referenz> [<Pfad>...]"
+
+#: builtin/ls-tree.c:128
+msgid "only show trees"
+msgstr "nur Verzeichnisse anzeigen"
+
+#: builtin/ls-tree.c:130
+msgid "recurse into subtrees"
+msgstr "Rekursion in Unterverzeichnissen durchführen"
+
+#: builtin/ls-tree.c:132
+msgid "show trees when recursing"
+msgstr "Verzeichnisse bei Rekursion anzeigen"
+
+#: builtin/ls-tree.c:135
+msgid "terminate entries with NUL byte"
+msgstr "Einträge mit NUL-Byte abschließen"
 
-#: builtin/init-db.c:79
-#, c-format
-msgid "cannot symlink '%s' '%s'"
-msgstr "kann symbolische Verknüpfung '%s' auf '%s' nicht erstellen"
+#: builtin/ls-tree.c:136
+msgid "include object size"
+msgstr "Objektgröße einschließen"
 
-#: builtin/init-db.c:85
-#, c-format
-msgid "cannot copy '%s' to '%s'"
-msgstr "kann '%s' nicht nach '%s' kopieren"
+#: builtin/ls-tree.c:138 builtin/ls-tree.c:140
+msgid "list only filenames"
+msgstr "nur Dateinamen auflisten"
 
-#: builtin/init-db.c:89
-#, c-format
-msgid "ignoring template %s"
-msgstr "ignoriere Vorlage %s"
+#: builtin/ls-tree.c:143
+msgid "use full path names"
+msgstr "vollständige Pfadnamen verwenden"
 
-#: builtin/init-db.c:120
-#, c-format
-msgid "templates not found %s"
-msgstr "keine Vorlagen in '%s' gefunden"
+#: builtin/ls-tree.c:145
+msgid "list entire tree; not just current directory (implies --full-name)"
+msgstr ""
+"das gesamte Verzeichnis auflisten; nicht nur das aktuelle Verzeichnis "
+"(impliziert --full-name)"
 
-#: builtin/init-db.c:135
+#: builtin/mailsplit.c:241
 #, c-format
-msgid "not copying templates from '%s': %s"
-msgstr "kopiere keine Vorlagen von '%s': %s"
+msgid "empty mbox: '%s'"
+msgstr "Leere mbox: '%s'"
 
-#: builtin/init-db.c:328
-#, c-format
-msgid "unable to handle file type %d"
-msgstr "kann nicht mit Dateityp %d umgehen"
+#: builtin/merge.c:55
+msgid "git merge [<options>] [<commit>...]"
+msgstr "git merge [<Optionen>] [<Commit>...]"
 
-#: builtin/init-db.c:331
-#, c-format
-msgid "unable to move %s to %s"
-msgstr "Konnte %s nicht nach %s verschieben"
+#: builtin/merge.c:56
+msgid "git merge --abort"
+msgstr "git merge --abort"
 
-#: builtin/init-db.c:348 builtin/init-db.c:351
-#, c-format
-msgid "%s already exists"
-msgstr "%s existiert bereits"
+#: builtin/merge.c:57
+msgid "git merge --continue"
+msgstr "git merge --continue"
 
-#: builtin/init-db.c:404
-#, c-format
-msgid "Reinitialized existing shared Git repository in %s%s\n"
-msgstr "Bestehendes verteiltes Git-Repository in %s%s neuinitialisiert\n"
+#: builtin/merge.c:118
+msgid "switch `m' requires a value"
+msgstr "Schalter 'm' erfordert einen Wert."
 
-#: builtin/init-db.c:405
+#: builtin/merge.c:141
 #, c-format
-msgid "Reinitialized existing Git repository in %s%s\n"
-msgstr "Bestehendes Git-Repository in %s%s neuinitialisiert\n"
+msgid "option `%s' requires a value"
+msgstr "Option `%s' erfordert einen Wert."
 
-#: builtin/init-db.c:409
+#: builtin/merge.c:187
 #, c-format
-msgid "Initialized empty shared Git repository in %s%s\n"
-msgstr "Leeres verteiltes Git-Repository in %s%s initialisiert\n"
+msgid "Could not find merge strategy '%s'.\n"
+msgstr "Konnte Merge-Strategie '%s' nicht finden.\n"
 
-#: builtin/init-db.c:410
+#: builtin/merge.c:188
 #, c-format
-msgid "Initialized empty Git repository in %s%s\n"
-msgstr "Leeres Git-Repository in %s%s initialisiert\n"
-
-#: builtin/init-db.c:458
-msgid ""
-"git init [-q | --quiet] [--bare] [--template=<template-directory>] [--"
-"shared[=<permissions>]] [<directory>]"
-msgstr ""
-"git init [-q | --quiet] [--bare] [--template=<Vorlagenverzeichnis>] [--"
-"shared[=<Berechtigungen>]] [<Verzeichnis>]"
+msgid "Available strategies are:"
+msgstr "Verfügbare Strategien sind:"
 
-#: builtin/init-db.c:481
-msgid "permissions"
-msgstr "Berechtigungen"
+#: builtin/merge.c:193
+#, c-format
+msgid "Available custom strategies are:"
+msgstr "Verfügbare benutzerdefinierte Strategien sind:"
 
-#: builtin/init-db.c:482
-msgid "specify that the git repository is to be shared amongst several users"
-msgstr "angeben, dass das Git-Repository mit mehreren Benutzern geteilt wird"
+#: builtin/merge.c:244 builtin/pull.c:152
+msgid "do not show a diffstat at the end of the merge"
+msgstr "keine Zusammenfassung der Unterschiede am Schluss des Merges anzeigen"
 
-#: builtin/init-db.c:516 builtin/init-db.c:521
-#, c-format
-msgid "cannot mkdir %s"
-msgstr "kann Verzeichnis %s nicht erstellen"
+#: builtin/merge.c:247 builtin/pull.c:155
+msgid "show a diffstat at the end of the merge"
+msgstr "eine Zusammenfassung der Unterschiede am Schluss des Merges anzeigen"
 
-#: builtin/init-db.c:525
-#, c-format
-msgid "cannot chdir to %s"
-msgstr "kann nicht in Verzeichnis %s wechseln"
+#: builtin/merge.c:248 builtin/pull.c:158
+msgid "(synonym to --stat)"
+msgstr "(Synonym für --stat)"
 
-#: builtin/init-db.c:546
-#, c-format
-msgid ""
-"%s (or --work-tree=<directory>) not allowed without specifying %s (or --git-"
-"dir=<directory>)"
+#: builtin/merge.c:250 builtin/pull.c:161
+msgid "add (at most <n>) entries from shortlog to merge commit message"
 msgstr ""
-"%s (oder --work-tree=<Verzeichnis>) nicht erlaubt ohne Spezifizierung von %s "
-"(oder --git-dir=<Verzeichnis>)"
+"(höchstens <n>) Einträge von \"shortlog\" zur Beschreibung des Merge-Commits "
+"hinzufügen"
 
-#: builtin/init-db.c:574
-#, c-format
-msgid "Cannot access work tree '%s'"
-msgstr "Kann nicht auf Arbeitsverzeichnis '%s' zugreifen."
+#: builtin/merge.c:253 builtin/pull.c:167
+msgid "create a single commit instead of doing a merge"
+msgstr "einen einzelnen Commit anstatt eines Merges erzeugen"
 
-#: builtin/interpret-trailers.c:15
-msgid ""
-"git interpret-trailers [--in-place] [--trim-empty] [(--trailer "
-"<token>[(=|:)<value>])...] [<file>...]"
-msgstr ""
-"git interpret-trailers [--in-place] [--trim-empty] [(--trailer "
-"<Token>[(=|:)<Wert>])...] [<Datei>...]"
+#: builtin/merge.c:255 builtin/pull.c:170
+msgid "perform a commit if the merge succeeds (default)"
+msgstr "einen Commit durchführen, wenn der Merge erfolgreich war (Standard)"
 
-#: builtin/interpret-trailers.c:92
-msgid "edit files in place"
-msgstr "vorhandene Dateien direkt bearbeiten"
+#: builtin/merge.c:257 builtin/pull.c:173
+msgid "edit message before committing"
+msgstr "Bearbeitung der Beschreibung vor dem Commit"
 
-#: builtin/interpret-trailers.c:93
-msgid "trim empty trailers"
-msgstr "kürzt leere Anhänge"
+#: builtin/merge.c:259
+msgid "allow fast-forward (default)"
+msgstr "Vorspulen erlauben (Standard)"
 
-#: builtin/interpret-trailers.c:96
-msgid "where to place the new trailer"
-msgstr "wo der neue Anhang platziert wird"
+#: builtin/merge.c:261 builtin/pull.c:180
+msgid "abort if fast-forward is not possible"
+msgstr "abbrechen, wenn kein Vorspulen möglich ist"
 
-#: builtin/interpret-trailers.c:98
-msgid "action if trailer already exists"
-msgstr "Aktion, wenn Anhang bereits existiert"
+#: builtin/merge.c:265 builtin/pull.c:183
+msgid "verify that the named commit has a valid GPG signature"
+msgstr "den genannten Commit auf eine gültige GPG-Signatur überprüfen"
 
-#: builtin/interpret-trailers.c:100
-msgid "action if trailer is missing"
-msgstr "Aktion, wenn Anhang fehlt"
+#: builtin/merge.c:266 builtin/notes.c:787 builtin/pull.c:187
+#: builtin/rebase.c:512 builtin/rebase.c:1531 builtin/revert.c:114
+msgid "strategy"
+msgstr "Strategie"
 
-#: builtin/interpret-trailers.c:102
-msgid "output only the trailers"
-msgstr "nur Anhänge ausgeben"
+#: builtin/merge.c:267 builtin/pull.c:188
+msgid "merge strategy to use"
+msgstr "zu verwendende Merge-Strategie"
 
-#: builtin/interpret-trailers.c:103
-msgid "do not apply config rules"
-msgstr "Regeln aus Konfiguration nicht anwenden"
+#: builtin/merge.c:268 builtin/pull.c:191
+msgid "option=value"
+msgstr "Option=Wert"
 
-#: builtin/interpret-trailers.c:104
-msgid "join whitespace-continued values"
-msgstr "durch Leerzeichen fortgesetzte Werte verbinden"
+#: builtin/merge.c:269 builtin/pull.c:192
+msgid "option for selected merge strategy"
+msgstr "Option für ausgewählte Merge-Strategie"
 
-#: builtin/interpret-trailers.c:105
-msgid "set parsing options"
-msgstr "Optionen für das Parsen setzen"
+#: builtin/merge.c:271
+msgid "merge commit message (for a non-fast-forward merge)"
+msgstr ""
+"Commit-Beschreibung zusammenführen (für einen Merge, der kein Vorspulen war)"
 
-#: builtin/interpret-trailers.c:107
-msgid "trailer"
-msgstr "Anhang"
+#: builtin/merge.c:278
+msgid "abort the current in-progress merge"
+msgstr "den sich im Gange befindlichen Merge abbrechen"
 
-#: builtin/interpret-trailers.c:108
-msgid "trailer(s) to add"
-msgstr "Anhang/Anhänge hinzufügen"
+#: builtin/merge.c:280
+msgid "--abort but leave index and working tree alone"
+msgstr "--abort, aber Index und Arbeitsverzeichnis unverändert lassen"
 
-#: builtin/interpret-trailers.c:117
-msgid "--trailer with --only-input does not make sense"
-msgstr ""
-"Die Optionen --trailer und --only-input können nicht gemeinsam verwendet "
-"werden."
+#: builtin/merge.c:282
+msgid "continue the current in-progress merge"
+msgstr "den sich im Gange befindlichen Merge fortsetzen"
 
-#: builtin/interpret-trailers.c:127
-msgid "no input file given for in-place editing"
-msgstr "keine Datei zur direkten Bearbeitung angegeben"
+#: builtin/merge.c:284 builtin/pull.c:199
+msgid "allow merging unrelated histories"
+msgstr "erlaube das Zusammenführen von nicht zusammenhängenden Historien"
 
-#: builtin/log.c:48
-msgid "git log [<options>] [<revision-range>] [[--] <path>...]"
-msgstr "git log [<Optionen>] [<Commitbereich>] [[--] <Pfad>...]"
+#: builtin/merge.c:290
+msgid "bypass pre-merge-commit and commit-msg hooks"
+msgstr "Hooks pre-merge-commit und commit-msg umgehen"
 
-#: builtin/log.c:49
-msgid "git show [<options>] <object>..."
-msgstr "git show [<Optionen>] <Objekt>..."
+#: builtin/merge.c:307
+msgid "could not run stash."
+msgstr "Konnte \"stash\" nicht ausführen."
 
-#: builtin/log.c:93
+#: builtin/merge.c:312
+msgid "stash failed"
+msgstr "\"stash\" fehlgeschlagen"
+
+#: builtin/merge.c:317
 #, c-format
-msgid "invalid --decorate option: %s"
-msgstr "Ungültige Option für --decorate: %s"
+msgid "not a valid object: %s"
+msgstr "kein gültiges Objekt: %s"
 
-#: builtin/log.c:153
-msgid "suppress diff output"
-msgstr "Ausgabe der Unterschiede unterdrücken"
+#: builtin/merge.c:339 builtin/merge.c:356
+msgid "read-tree failed"
+msgstr "read-tree fehlgeschlagen"
 
-#: builtin/log.c:154
-msgid "show source"
-msgstr "Quelle anzeigen"
+#: builtin/merge.c:386
+msgid " (nothing to squash)"
+msgstr " (nichts zu quetschen)"
 
-#: builtin/log.c:155
-msgid "Use mail map file"
-msgstr "\"mailmap\"-Datei verwenden"
+#: builtin/merge.c:397
+#, c-format
+msgid "Squash commit -- not updating HEAD\n"
+msgstr "Quetsche Commit -- HEAD wird nicht aktualisiert\n"
 
-#: builtin/log.c:157
-msgid "only decorate refs that match <pattern>"
-msgstr "\"decorate\" nur bei Referenzen anwenden, die <Muster> entsprechen"
+#: builtin/merge.c:447
+#, c-format
+msgid "No merge message -- not updating HEAD\n"
+msgstr "Keine Merge-Commit-Beschreibung -- HEAD wird nicht aktualisiert\n"
 
-#: builtin/log.c:159
-msgid "do not decorate refs that match <pattern>"
-msgstr "\"decorate\" nicht bei Referenzen anwenden, die <Muster> entsprechen"
+#: builtin/merge.c:498
+#, c-format
+msgid "'%s' does not point to a commit"
+msgstr "'%s' zeigt auf keinen Commit"
 
-#: builtin/log.c:160
-msgid "decorate options"
-msgstr "decorate-Optionen"
+#: builtin/merge.c:585
+#, c-format
+msgid "Bad branch.%s.mergeoptions string: %s"
+msgstr "Ungültiger branch.%s.mergeoptions String: %s"
 
-#: builtin/log.c:163
-msgid "Process line range n,m in file, counting from 1"
-msgstr "Verarbeitet nur Zeilen im Bereich n,m in der Datei, gezählt von 1"
+#: builtin/merge.c:705
+msgid "Not handling anything other than two heads merge."
+msgstr "Es wird nur der Merge von zwei Branches behandelt."
 
-#: builtin/log.c:259
+#: builtin/merge.c:719
 #, c-format
-msgid "Final output: %d %s\n"
-msgstr "letzte Ausgabe: %d %s\n"
+msgid "Unknown option for merge-recursive: -X%s"
+msgstr "Unbekannte Option für merge-recursive: -X%s"
 
-#: builtin/log.c:510
+#: builtin/merge.c:734
 #, c-format
-msgid "git show %s: bad file"
-msgstr "git show %s: ungültige Datei"
+msgid "unable to write %s"
+msgstr "konnte %s nicht schreiben"
 
-#: builtin/log.c:525 builtin/log.c:619
+#: builtin/merge.c:786
 #, c-format
-msgid "Could not read object %s"
-msgstr "Kann Objekt %s nicht lesen."
+msgid "Could not read from '%s'"
+msgstr "konnte nicht von '%s' lesen"
 
-#: builtin/log.c:643
+#: builtin/merge.c:795
 #, c-format
-msgid "Unknown type: %d"
-msgstr "Unbekannter Typ: %d"
+msgid "Not committing merge; use 'git commit' to complete the merge.\n"
+msgstr ""
+"Merge wurde nicht committet; benutzen Sie 'git commit', um den Merge "
+"abzuschließen.\n"
 
-#: builtin/log.c:764
-msgid "format.headers without value"
-msgstr "format.headers ohne Wert"
+#: builtin/merge.c:801
+msgid ""
+"Please enter a commit message to explain why this merge is necessary,\n"
+"especially if it merges an updated upstream into a topic branch.\n"
+"\n"
+msgstr ""
+"Bitte geben Sie eine Commit-Beschreibung ein, um zu erklären, warum dieser\n"
+"Merge erforderlich ist, insbesondere wenn es einen aktualisierten\n"
+"Upstream-Branch mit einem Thema-Branch zusammenführt.\n"
+"\n"
 
-#: builtin/log.c:865
-msgid "name of output directory is too long"
-msgstr "Name des Ausgabeverzeichnisses ist zu lang."
+#: builtin/merge.c:806
+msgid "An empty message aborts the commit.\n"
+msgstr "Eine leere Commit-Beschreibung bricht den Commit ab.\n"
 
-#: builtin/log.c:881
+#: builtin/merge.c:809
 #, c-format
-msgid "Cannot open patch file %s"
-msgstr "Kann Patch-Datei %s nicht öffnen"
+msgid ""
+"Lines starting with '%c' will be ignored, and an empty message aborts\n"
+"the commit.\n"
+msgstr ""
+"Zeilen, die mit '%c' beginnen, werden ignoriert,\n"
+"und eine leere Beschreibung bricht den Commit ab.\n"
 
-#: builtin/log.c:898
-msgid "Need exactly one range."
-msgstr "Brauche genau einen Commit-Bereich."
+#: builtin/merge.c:862
+msgid "Empty commit message."
+msgstr "Leere Commit-Beschreibung"
 
-#: builtin/log.c:908
-msgid "Not a range."
-msgstr "Kein Commit-Bereich."
+#: builtin/merge.c:877
+#, c-format
+msgid "Wonderful.\n"
+msgstr "Wunderbar.\n"
 
-#: builtin/log.c:1014
-msgid "Cover letter needs email format"
-msgstr "Anschreiben benötigt E-Mail-Format"
+#: builtin/merge.c:938
+#, c-format
+msgid "Automatic merge failed; fix conflicts and then commit the result.\n"
+msgstr ""
+"Automatischer Merge fehlgeschlagen; beheben Sie die Konflikte und committen "
+"Sie dann das Ergebnis.\n"
+
+#: builtin/merge.c:977
+msgid "No current branch."
+msgstr "Sie befinden sich auf keinem Branch."
 
-#: builtin/log.c:1095
-#, c-format
-msgid "insane in-reply-to: %s"
-msgstr "ungültiges in-reply-to: %s"
+#: builtin/merge.c:979
+msgid "No remote for the current branch."
+msgstr "Kein Remote-Repository für den aktuellen Branch."
 
-#: builtin/log.c:1122
-msgid "git format-patch [<options>] [<since> | <revision-range>]"
-msgstr "git format-patch [<Optionen>] [<seit> | <Commitbereich>]"
+#: builtin/merge.c:981
+msgid "No default upstream defined for the current branch."
+msgstr ""
+"Es ist kein Standard-Upstream-Branch für den aktuellen Branch definiert."
 
-#: builtin/log.c:1172
-msgid "Two output directories?"
-msgstr "Zwei Ausgabeverzeichnisse?"
+#: builtin/merge.c:986
+#, c-format
+msgid "No remote-tracking branch for %s from %s"
+msgstr "Kein Remote-Tracking-Branch für %s von %s"
 
-#: builtin/log.c:1279 builtin/log.c:1932 builtin/log.c:1934 builtin/log.c:1946
+#: builtin/merge.c:1043
 #, c-format
-msgid "Unknown commit %s"
-msgstr "Unbekannter Commit %s"
+msgid "Bad value '%s' in environment '%s'"
+msgstr "Fehlerhafter Wert '%s' in Umgebungsvariable '%s'"
 
-#: builtin/log.c:1289 builtin/notes.c:887 builtin/tag.c:522
+#: builtin/merge.c:1146
 #, c-format
-msgid "Failed to resolve '%s' as a valid ref."
-msgstr "Konnte '%s' nicht als gültige Referenz auflösen."
+msgid "not something we can merge in %s: %s"
+msgstr "nichts was wir in %s zusammenführen können: %s"
 
-#: builtin/log.c:1294
-msgid "Could not find exact merge base."
-msgstr "Konnte keine exakte Merge-Basis finden."
+#: builtin/merge.c:1180
+msgid "not something we can merge"
+msgstr "nichts was wir zusammenführen können"
 
-#: builtin/log.c:1298
-msgid ""
-"Failed to get upstream, if you want to record base commit automatically,\n"
-"please use git branch --set-upstream-to to track a remote branch.\n"
-"Or you could specify base commit by --base=<base-commit-id> manually."
-msgstr ""
-"Fehler beim Bestimmen des Upstream-Branches. Wenn Sie den Basis-Commit\n"
-"automatisch speichern lassen möchten, benutzen Sie bitte\n"
-"'git branch --set-upstream-to', um einem Remote-Branch zu folgen.\n"
-"Oder geben Sie den Basis-Commit mit '--base=<Basis-Commit-Id>' manuell an."
+#: builtin/merge.c:1283
+msgid "--abort expects no arguments"
+msgstr "--abort akzeptiert keine Argumente"
 
-#: builtin/log.c:1318
-msgid "Failed to find exact merge base"
-msgstr "Fehler beim Finden einer exakten Merge-Basis."
+#: builtin/merge.c:1287
+msgid "There is no merge to abort (MERGE_HEAD missing)."
+msgstr "Es gibt keinen Merge abzubrechen (MERGE_HEAD fehlt)"
 
-#: builtin/log.c:1329
-msgid "base commit should be the ancestor of revision list"
-msgstr "Basis-Commit sollte der Vorgänger der Revisionsliste sein."
+#: builtin/merge.c:1296
+msgid "--quit expects no arguments"
+msgstr "--quit erwartet keine Argumente"
 
-#: builtin/log.c:1333
-msgid "base commit shouldn't be in revision list"
-msgstr "Basis-Commit sollte nicht in der Revisionsliste enthalten sein."
+#: builtin/merge.c:1309
+msgid "--continue expects no arguments"
+msgstr "--continue erwartet keine Argumente"
 
-#: builtin/log.c:1382
-msgid "cannot get patch id"
-msgstr "kann Patch-Id nicht lesen"
+#: builtin/merge.c:1313
+msgid "There is no merge in progress (MERGE_HEAD missing)."
+msgstr "Es ist kein Merge im Gange (MERGE_HEAD fehlt)."
 
-#: builtin/log.c:1441
-msgid "use [PATCH n/m] even with a single patch"
-msgstr "[PATCH n/m] auch mit einzelnem Patch verwenden"
+#: builtin/merge.c:1329
+msgid ""
+"You have not concluded your merge (MERGE_HEAD exists).\n"
+"Please, commit your changes before you merge."
+msgstr ""
+"Sie haben Ihren Merge nicht abgeschlossen (MERGE_HEAD existiert).\n"
+"Bitte committen Sie Ihre Änderungen, bevor Sie den Merge ausführen."
 
-#: builtin/log.c:1444
-msgid "use [PATCH] even with multiple patches"
-msgstr "[PATCH] auch mit mehreren Patches verwenden"
+#: builtin/merge.c:1336
+msgid ""
+"You have not concluded your cherry-pick (CHERRY_PICK_HEAD exists).\n"
+"Please, commit your changes before you merge."
+msgstr ""
+"Sie haben \"cherry-pick\" nicht abgeschlossen (CHERRY_PICK_HEAD existiert).\n"
+"Bitte committen Sie Ihre Änderungen, bevor Sie den Merge ausführen."
 
-#: builtin/log.c:1448
-msgid "print patches to standard out"
-msgstr "Ausgabe der Patches in Standard-Ausgabe"
+#: builtin/merge.c:1339
+msgid "You have not concluded your cherry-pick (CHERRY_PICK_HEAD exists)."
+msgstr ""
+"Sie haben \"cherry-pick\" nicht abgeschlossen (CHERRY_PICK_HEAD existiert)."
 
-#: builtin/log.c:1450
-msgid "generate a cover letter"
-msgstr "ein Deckblatt erzeugen"
+#: builtin/merge.c:1353
+msgid "You cannot combine --squash with --no-ff."
+msgstr "Sie können --squash nicht mit --no-ff kombinieren."
 
-#: builtin/log.c:1452
-msgid "use simple number sequence for output file names"
-msgstr "einfache Nummernfolge für die Namen der Ausgabedateien verwenden"
+#: builtin/merge.c:1355
+msgid "You cannot combine --squash with --commit."
+msgstr "Sie können --squash nicht mit --commit kombinieren."
 
-#: builtin/log.c:1453
-msgid "sfx"
-msgstr "Dateiendung"
+#: builtin/merge.c:1371
+msgid "No commit specified and merge.defaultToUpstream not set."
+msgstr "Kein Commit angegeben und merge.defaultToUpstream ist nicht gesetzt."
 
-#: builtin/log.c:1454
-msgid "use <sfx> instead of '.patch'"
-msgstr "<Dateiendung> anstatt '.patch' verwenden"
+#: builtin/merge.c:1388
+msgid "Squash commit into empty head not supported yet"
+msgstr ""
+"Bin auf einem Commit, der noch geboren wird; kann \"squash\" nicht ausführen."
 
-#: builtin/log.c:1456
-msgid "start numbering patches at <n> instead of 1"
-msgstr "die Nummerierung der Patches bei <n> anstatt bei 1 beginnen"
+#: builtin/merge.c:1390
+msgid "Non-fast-forward commit does not make sense into an empty head"
+msgstr ""
+"Nicht vorzuspulender Commit kann nicht in einem leeren Branch verwendet "
+"werden."
 
-#: builtin/log.c:1458
-msgid "mark the series as Nth re-roll"
-msgstr "die Serie als n-te Fassung kennzeichnen"
+#: builtin/merge.c:1395
+#, c-format
+msgid "%s - not something we can merge"
+msgstr "%s - nichts was wir zusammenführen können"
 
-#: builtin/log.c:1460
-msgid "Use [RFC PATCH] instead of [PATCH]"
-msgstr "[RFC PATCH] anstatt [PATCH] verwenden"
+#: builtin/merge.c:1397
+msgid "Can merge only exactly one commit into empty head"
+msgstr "Kann nur exakt einen Commit in einem leeren Branch zusammenführen."
 
-#: builtin/log.c:1463
-msgid "Use [<prefix>] instead of [PATCH]"
-msgstr "[<Präfix>] anstatt [PATCH] verwenden"
+#: builtin/merge.c:1476
+msgid "refusing to merge unrelated histories"
+msgstr "Verweigere den Merge von nicht zusammenhängenden Historien."
 
-#: builtin/log.c:1466
-msgid "store resulting files in <dir>"
-msgstr "erzeugte Dateien in <Verzeichnis> speichern"
+#: builtin/merge.c:1485
+msgid "Already up to date."
+msgstr "Bereits aktuell."
 
-#: builtin/log.c:1469
-msgid "don't strip/add [PATCH]"
-msgstr "[PATCH] nicht entfernen/hinzufügen"
+#: builtin/merge.c:1495
+#, c-format
+msgid "Updating %s..%s\n"
+msgstr "Aktualisiere %s..%s\n"
 
-#: builtin/log.c:1472
-msgid "don't output binary diffs"
-msgstr "keine binären Unterschiede ausgeben"
+#: builtin/merge.c:1537
+#, c-format
+msgid "Trying really trivial in-index merge...\n"
+msgstr "Probiere wirklich trivialen \"in-index\"-Merge ...\n"
 
-#: builtin/log.c:1474
-msgid "output all-zero hash in From header"
-msgstr "Hash mit Nullen in \"From\"-Header ausgeben"
+#: builtin/merge.c:1544
+#, c-format
+msgid "Nope.\n"
+msgstr "Nein.\n"
 
-#: builtin/log.c:1476
-msgid "don't include a patch matching a commit upstream"
-msgstr ""
-"keine Patches einschließen, die einem Commit im Upstream-Branch entsprechen"
+#: builtin/merge.c:1569
+msgid "Already up to date. Yeeah!"
+msgstr "Bereits aktuell."
 
-#: builtin/log.c:1478
-msgid "show patch format instead of default (patch + stat)"
-msgstr "Patchformat anstatt des Standards anzeigen (Patch + Zusammenfassung)"
+#: builtin/merge.c:1575
+msgid "Not possible to fast-forward, aborting."
+msgstr "Vorspulen nicht möglich, breche ab."
 
-#: builtin/log.c:1480
-msgid "Messaging"
-msgstr "E-Mail-Einstellungen"
+#: builtin/merge.c:1598 builtin/merge.c:1663
+#, c-format
+msgid "Rewinding the tree to pristine...\n"
+msgstr "Rücklauf des Verzeichnisses bis zum Ursprung ...\n"
 
-#: builtin/log.c:1481
-msgid "header"
-msgstr "Header"
+#: builtin/merge.c:1602
+#, c-format
+msgid "Trying merge strategy %s...\n"
+msgstr "Probiere Merge-Strategie %s ...\n"
 
-#: builtin/log.c:1482
-msgid "add email header"
-msgstr "E-Mail-Header hinzufügen"
+#: builtin/merge.c:1654
+#, c-format
+msgid "No merge strategy handled the merge.\n"
+msgstr "Keine Merge-Strategie behandelt diesen Merge.\n"
 
-#: builtin/log.c:1483 builtin/log.c:1485
-msgid "email"
-msgstr "E-Mail"
+#: builtin/merge.c:1656
+#, c-format
+msgid "Merge with strategy %s failed.\n"
+msgstr "Merge mit Strategie %s fehlgeschlagen.\n"
 
-#: builtin/log.c:1483
-msgid "add To: header"
-msgstr "\"To:\"-Header hinzufügen"
+#: builtin/merge.c:1665
+#, c-format
+msgid "Using the %s to prepare resolving by hand.\n"
+msgstr "Benutzen Sie \"%s\", um die Auflösung per Hand vorzubereiten.\n"
 
-#: builtin/log.c:1485
-msgid "add Cc: header"
-msgstr "\"Cc:\"-Header hinzufügen"
+#: builtin/merge.c:1677
+#, c-format
+msgid "Automatic merge went well; stopped before committing as requested\n"
+msgstr ""
+"Automatischer Merge abgeschlossen; halte, wie gewünscht, vor dem Commit an\n"
 
-#: builtin/log.c:1487
-msgid "ident"
-msgstr "Ident"
+#: builtin/merge-base.c:32
+msgid "git merge-base [-a | --all] <commit> <commit>..."
+msgstr "git merge-base [-a | --all] <Commit> <Commit>..."
 
-#: builtin/log.c:1488
-msgid "set From address to <ident> (or committer ident if absent)"
-msgstr ""
-"\"From\"-Adresse auf <Ident> setzen (oder Ident des Commit-Erstellers, wenn "
-"fehlend)"
+#: builtin/merge-base.c:33
+msgid "git merge-base [-a | --all] --octopus <commit>..."
+msgstr "git merge-base [-a | --all] --octopus <Commit>..."
 
-#: builtin/log.c:1490
-msgid "message-id"
-msgstr "message-id"
+#: builtin/merge-base.c:34
+msgid "git merge-base --independent <commit>..."
+msgstr "git merge-base --independent <Commit>..."
 
-#: builtin/log.c:1491
-msgid "make first mail a reply to <message-id>"
-msgstr "aus erster E-Mail eine Antwort zu <message-id> machen"
+#: builtin/merge-base.c:35
+msgid "git merge-base --is-ancestor <commit> <commit>"
+msgstr "git merge-base --is-ancestor <Commit> <Commit>"
 
-#: builtin/log.c:1492 builtin/log.c:1495
-msgid "boundary"
-msgstr "Grenze"
+#: builtin/merge-base.c:36
+msgid "git merge-base --fork-point <ref> [<commit>]"
+msgstr "git merge-base --fork-point <Referenz> [<Commit>]"
 
-#: builtin/log.c:1493
-msgid "attach the patch"
-msgstr "den Patch anhängen"
+#: builtin/merge-base.c:153
+msgid "output all common ancestors"
+msgstr "Ausgabe aller gemeinsamen Vorgänger-Commits"
 
-#: builtin/log.c:1496
-msgid "inline the patch"
-msgstr "den Patch direkt in die Nachricht einfügen"
+#: builtin/merge-base.c:155
+msgid "find ancestors for a single n-way merge"
+msgstr "Vorgänger-Commits für einen einzelnen n-Wege-Merge finden"
 
-#: builtin/log.c:1500
-msgid "enable message threading, styles: shallow, deep"
-msgstr "Nachrichtenverkettung aktivieren, Stile: shallow, deep"
+#: builtin/merge-base.c:157
+msgid "list revs not reachable from others"
+msgstr "Commits auflisten, die nicht durch Andere erreichbar sind"
 
-#: builtin/log.c:1502
-msgid "signature"
-msgstr "Signatur"
+#: builtin/merge-base.c:159
+msgid "is the first one ancestor of the other?"
+msgstr "ist der Erste ein Vorgänger-Commit des Anderen?"
 
-#: builtin/log.c:1503
-msgid "add a signature"
-msgstr "eine Signatur hinzufügen"
+#: builtin/merge-base.c:161
+msgid "find where <commit> forked from reflog of <ref>"
+msgstr "<Commit> finden, von wo Reflog von <Referenz> abgespalten wurde"
 
-#: builtin/log.c:1504
-msgid "base-commit"
-msgstr "Basis-Commit"
+#: builtin/merge-file.c:9
+msgid ""
+"git merge-file [<options>] [-L <name1> [-L <orig> [-L <name2>]]] <file1> "
+"<orig-file> <file2>"
+msgstr ""
+"git merge-file [<Optionen>] [-L <Name1> [-L <orig> [-L <Name2>]]] <Datei1> "
+"<orig-Datei> <Datei2>"
 
-#: builtin/log.c:1505
-msgid "add prerequisite tree info to the patch series"
-msgstr "erforderliche Revisions-Informationen der Patch-Serie hinzufügen"
+#: builtin/merge-file.c:35
+msgid "send results to standard output"
+msgstr "Ergebnisse zur Standard-Ausgabe senden"
 
-#: builtin/log.c:1507
-msgid "add a signature from a file"
-msgstr "eine Signatur aus einer Datei hinzufügen"
+#: builtin/merge-file.c:36
+msgid "use a diff3 based merge"
+msgstr "einen diff3 basierten Merge verwenden"
 
-#: builtin/log.c:1508
-msgid "don't print the patch filenames"
-msgstr "keine Dateinamen der Patches anzeigen"
+#: builtin/merge-file.c:37
+msgid "for conflicts, use our version"
+msgstr "bei Konflikten unsere Variante verwenden"
 
-#: builtin/log.c:1510
-msgid "show progress while generating patches"
-msgstr "Forschrittsanzeige während der Erzeugung der Patches"
+#: builtin/merge-file.c:39
+msgid "for conflicts, use their version"
+msgstr "bei Konflikten ihre Variante verwenden"
 
-#: builtin/log.c:1585
-#, c-format
-msgid "invalid ident line: %s"
-msgstr "Ungültige Identifikationszeile: %s"
+#: builtin/merge-file.c:41
+msgid "for conflicts, use a union version"
+msgstr "bei Konflikten eine gemeinsame Variante verwenden"
 
-#: builtin/log.c:1600
-msgid "-n and -k are mutually exclusive."
-msgstr "Die Optionen -n und -k schließen sich gegenseitig aus."
+#: builtin/merge-file.c:44
+msgid "for conflicts, use this marker size"
+msgstr "bei Konflikten diese Kennzeichnungslänge verwenden"
 
-#: builtin/log.c:1602
-msgid "--subject-prefix/--rfc and -k are mutually exclusive."
-msgstr "--subject-prefix/--rfc und -k schließen sich gegenseitig aus."
+#: builtin/merge-file.c:45
+msgid "do not warn about conflicts"
+msgstr "keine Warnung bei Konflikten"
 
-#: builtin/log.c:1610
-msgid "--name-only does not make sense"
-msgstr "Die Option --name-only kann nicht verwendet werden."
+#: builtin/merge-file.c:47
+msgid "set labels for file1/orig-file/file2"
+msgstr "Beschriftung für Datei1/orig-Datei/Datei2 setzen"
 
-#: builtin/log.c:1612
-msgid "--name-status does not make sense"
-msgstr "Die Option --name-status kann nicht verwendet werden."
+#: builtin/merge-recursive.c:47
+#, c-format
+msgid "unknown option %s"
+msgstr "unbekannte Option: %s"
 
-#: builtin/log.c:1614
-msgid "--check does not make sense"
-msgstr "Die Option --check kann nicht verwendet werden."
+#: builtin/merge-recursive.c:53
+#, c-format
+msgid "could not parse object '%s'"
+msgstr "Konnte Objekt '%s' nicht parsen."
 
-#: builtin/log.c:1646
-msgid "standard output, or directory, which one?"
-msgstr "Standard-Ausgabe oder Verzeichnis, welches von beidem?"
+#: builtin/merge-recursive.c:57
+#, c-format
+msgid "cannot handle more than %d base. Ignoring %s."
+msgid_plural "cannot handle more than %d bases. Ignoring %s."
+msgstr[0] "kann nicht mit mehr als %d Merge-Basis umgehen. Ignoriere %s."
+msgstr[1] "kann nicht mit mehr als %d Merge-Basen umgehen. Ignoriere %s."
 
-#: builtin/log.c:1648
+#: builtin/merge-recursive.c:65
+msgid "not handling anything other than two heads merge."
+msgstr "Es wird nur der Merge von zwei Branches behandelt."
+
+#: builtin/merge-recursive.c:74 builtin/merge-recursive.c:76
 #, c-format
-msgid "Could not create directory '%s'"
-msgstr "Konnte Verzeichnis '%s' nicht erstellen."
+msgid "could not resolve ref '%s'"
+msgstr "Konnte Referenz '%s' nicht auflösen"
 
-#: builtin/log.c:1741
+#: builtin/merge-recursive.c:82
 #, c-format
-msgid "unable to read signature file '%s'"
-msgstr "Konnte Signatur-Datei '%s' nicht lesen"
+msgid "Merging %s with %s\n"
+msgstr "Führe %s mit %s zusammen\n"
 
-#: builtin/log.c:1773
-msgid "Generating patches"
-msgstr "Erzeuge Patches"
+#: builtin/mktree.c:66
+msgid "git mktree [-z] [--missing] [--batch]"
+msgstr "git mktree [-z] [--missing] [--batch]"
 
-#: builtin/log.c:1817
-msgid "Failed to create output files"
-msgstr "Fehler beim Erstellen der Ausgabedateien."
+#: builtin/mktree.c:154
+msgid "input is NUL terminated"
+msgstr "Eingabe ist durch NUL-Zeichen abgeschlossen"
 
-#: builtin/log.c:1867
-msgid "git cherry [-v] [<upstream> [<head> [<limit>]]]"
-msgstr "git cherry [-v] [<Upstream> [<Branch> [<Limit>]]]"
+#: builtin/mktree.c:155 builtin/write-tree.c:26
+msgid "allow missing objects"
+msgstr "fehlende Objekte erlauben"
 
-#: builtin/log.c:1921
-#, c-format
+#: builtin/mktree.c:156
+msgid "allow creation of more than one tree"
+msgstr "die Erstellung von mehr als einem \"Tree\"-Objekt erlauben"
+
+#: builtin/multi-pack-index.c:9
 msgid ""
-"Could not find a tracked remote branch, please specify <upstream> manually.\n"
+"git multi-pack-index [<options>] (write|verify|expire|repack --batch-"
+"size=<size>)"
 msgstr ""
-"Konnte gefolgten Remote-Branch nicht finden, bitte geben Sie <Upstream> "
-"manuell an.\n"
-
-#: builtin/ls-files.c:468
-msgid "git ls-files [<options>] [<file>...]"
-msgstr "git ls-files [<Optionen>] [<Datei>...]"
-
-#: builtin/ls-files.c:517
-msgid "identify the file status with tags"
-msgstr "den Dateistatus mit Tags anzeigen"
+"git multi-pack-index [<Optionen>] (write|verify|expire|repack --batch-"
+"size=<Größe>)"
 
-#: builtin/ls-files.c:519
-msgid "use lowercase letters for 'assume unchanged' files"
+#: builtin/multi-pack-index.c:26
+msgid "object directory containing set of packfile and pack-index pairs"
 msgstr ""
-"Kleinbuchstaben für Dateien mit 'assume unchanged' Markierung verwenden"
+"Objekt-Verzeichnis, welches Paare von Packdateien und pack-index enthält"
 
-#: builtin/ls-files.c:521
-msgid "use lowercase letters for 'fsmonitor clean' files"
-msgstr "Kleinbuchstaben für 'fsmonitor clean' Dateien verwenden"
+#: builtin/multi-pack-index.c:29
+msgid ""
+"during repack, collect pack-files of smaller size into a batch that is "
+"larger than this size"
+msgstr ""
+"Während des Umpackens, sammle Paket-Dateien von geringerer Größe in "
+"einenStapel, welcher größer ist als diese Größe"
 
-#: builtin/ls-files.c:523
-msgid "show cached files in the output (default)"
-msgstr "zwischengespeicherte Dateien in der Ausgabe anzeigen (Standard)"
+#: builtin/multi-pack-index.c:50 builtin/prune-packed.c:67
+msgid "too many arguments"
+msgstr "Zu viele Argumente."
 
-#: builtin/ls-files.c:525
-msgid "show deleted files in the output"
-msgstr "entfernte Dateien in der Ausgabe anzeigen"
+#: builtin/multi-pack-index.c:60
+msgid "--batch-size option is only for 'repack' subcommand"
+msgstr "Option --batch-size ist nur für den Unterbefehl 'repack'"
 
-#: builtin/ls-files.c:527
-msgid "show modified files in the output"
-msgstr "geänderte Dateien in der Ausgabe anzeigen"
+#: builtin/multi-pack-index.c:69
+#, c-format
+msgid "unrecognized subcommand: %s"
+msgstr "Nicht erkannter Unterbefehl: %s"
 
-#: builtin/ls-files.c:529
-msgid "show other files in the output"
-msgstr "sonstige Dateien in der Ausgabe anzeigen"
+#: builtin/mv.c:18
+msgid "git mv [<options>] <source>... <destination>"
+msgstr "git mv [<Optionen>] <Quelle>... <Ziel>"
 
-#: builtin/ls-files.c:531
-msgid "show ignored files in the output"
-msgstr "ignorierte Dateien in der Ausgabe anzeigen"
+#: builtin/mv.c:83
+#, c-format
+msgid "Directory %s is in index and no submodule?"
+msgstr "Verzeichnis %s ist zum Commit vorgemerkt und kein Submodul?"
 
-#: builtin/ls-files.c:534
-msgid "show staged contents' object name in the output"
+#: builtin/mv.c:85
+msgid "Please stage your changes to .gitmodules or stash them to proceed"
 msgstr ""
-"Objektnamen von Inhalten, die zum Commit vorgemerkt sind, in der Ausgabe "
-"anzeigen"
+"Bitte merken Sie Ihre Änderungen in .gitmodules zum Commit vor oder "
+"benutzen\n"
+"Sie \"stash\", um fortzufahren."
 
-#: builtin/ls-files.c:536
-msgid "show files on the filesystem that need to be removed"
-msgstr "Dateien im Dateisystem, die gelöscht werden müssen, anzeigen"
+#: builtin/mv.c:103
+#, c-format
+msgid "%.*s is in index"
+msgstr "%.*s ist zum Commit vorgemerkt"
 
-#: builtin/ls-files.c:538
-msgid "show 'other' directories' names only"
-msgstr "nur Namen von 'sonstigen' Verzeichnissen anzeigen"
+#: builtin/mv.c:125
+msgid "force move/rename even if target exists"
+msgstr "Verschieben/Umbenennen erzwingen, auch wenn das Ziel existiert"
 
-#: builtin/ls-files.c:540
-msgid "show line endings of files"
-msgstr "Zeilenenden von Dateien anzeigen"
+#: builtin/mv.c:127
+msgid "skip move/rename errors"
+msgstr "Fehler beim Verschieben oder Umbenennen überspringen"
 
-#: builtin/ls-files.c:542
-msgid "don't show empty directories"
-msgstr "keine leeren Verzeichnisse anzeigen"
+#: builtin/mv.c:169
+#, c-format
+msgid "destination '%s' is not a directory"
+msgstr "Ziel '%s' ist kein Verzeichnis"
 
-#: builtin/ls-files.c:545
-msgid "show unmerged files in the output"
-msgstr "nicht zusammengeführte Dateien in der Ausgabe anzeigen"
+#: builtin/mv.c:180
+#, c-format
+msgid "Checking rename of '%s' to '%s'\n"
+msgstr "Prüfe Umbenennung von '%s' nach '%s'\n"
 
-#: builtin/ls-files.c:547
-msgid "show resolve-undo information"
-msgstr "'resolve-undo' Informationen anzeigen"
+#: builtin/mv.c:184
+msgid "bad source"
+msgstr "ungültige Quelle"
 
-#: builtin/ls-files.c:549
-msgid "skip files matching pattern"
-msgstr "Dateien auslassen, die einem Muster entsprechen"
+#: builtin/mv.c:187
+msgid "can not move directory into itself"
+msgstr "kann Verzeichnis nicht in sich selbst verschieben"
 
-#: builtin/ls-files.c:552
-msgid "exclude patterns are read from <file>"
-msgstr "Muster, gelesen von <Datei>, ausschließen"
+#: builtin/mv.c:190
+msgid "cannot move directory over file"
+msgstr "kann Verzeichnis nicht über Datei verschieben"
 
-#: builtin/ls-files.c:555
-msgid "read additional per-directory exclude patterns in <file>"
-msgstr "zusätzliche pro-Verzeichnis Auschlussmuster aus <Datei> auslesen"
+#: builtin/mv.c:199
+msgid "source directory is empty"
+msgstr "Quellverzeichnis ist leer"
 
-#: builtin/ls-files.c:557
-msgid "add the standard git exclusions"
-msgstr "die standardmäßigen Git-Ausschlüsse hinzufügen"
+#: builtin/mv.c:224
+msgid "not under version control"
+msgstr "nicht unter Versionskontrolle"
 
-#: builtin/ls-files.c:560
-msgid "make the output relative to the project top directory"
-msgstr "Ausgabe relativ zum Projektverzeichnis"
+#: builtin/mv.c:227
+msgid "destination exists"
+msgstr "Ziel existiert bereits"
 
-#: builtin/ls-files.c:563
-msgid "recurse through submodules"
-msgstr "Rekursion in Submodulen durchführen"
+#: builtin/mv.c:235
+#, c-format
+msgid "overwriting '%s'"
+msgstr "überschreibe '%s'"
 
-#: builtin/ls-files.c:565
-msgid "if any <file> is not in the index, treat this as an error"
-msgstr "als Fehler behandeln, wenn sich eine <Datei> nicht im Index befindet"
+#: builtin/mv.c:238
+msgid "Cannot overwrite"
+msgstr "Kann nicht überschreiben"
 
-#: builtin/ls-files.c:566
-msgid "tree-ish"
-msgstr "Commit-Referenz"
+#: builtin/mv.c:241
+msgid "multiple sources for the same target"
+msgstr "mehrere Quellen für dasselbe Ziel"
 
-#: builtin/ls-files.c:567
-msgid "pretend that paths removed since <tree-ish> are still present"
-msgstr ""
-"vorgeben, dass Pfade, die seit <Commit-Referenz> gelöscht wurden, immer noch "
-"vorhanden sind"
+#: builtin/mv.c:243
+msgid "destination directory does not exist"
+msgstr "Zielverzeichnis existiert nicht"
 
-#: builtin/ls-files.c:569
-msgid "show debugging data"
-msgstr "Ausgaben zur Fehlersuche anzeigen"
+#: builtin/mv.c:250
+#, c-format
+msgid "%s, source=%s, destination=%s"
+msgstr "%s, Quelle=%s, Ziel=%s"
 
-#: builtin/ls-remote.c:7
-msgid ""
-"git ls-remote [--heads] [--tags] [--refs] [--upload-pack=<exec>]\n"
-"                     [-q | --quiet] [--exit-code] [--get-url]\n"
-"                     [--symref] [<repository> [<refs>...]]"
-msgstr ""
-"git ls-remote [--heads] [--tags] [--refs] [--upload-pack=<Programm>]\n"
-"                     [-q | --quiet] [--exit-code] [--get-url]\n"
-"                     [--symref] [<Repository> [<Referenzen>...]]"
+#: builtin/mv.c:271
+#, c-format
+msgid "Renaming %s to %s\n"
+msgstr "Benenne %s nach %s um\n"
 
-#: builtin/ls-remote.c:52
-msgid "do not print remote URL"
-msgstr "URL des Remote-Repositories nicht ausgeben"
+#: builtin/mv.c:277 builtin/remote.c:716 builtin/repack.c:518
+#, c-format
+msgid "renaming '%s' failed"
+msgstr "Umbenennung von '%s' fehlgeschlagen"
 
-#: builtin/ls-remote.c:53 builtin/ls-remote.c:55
-msgid "exec"
-msgstr "Programm"
+#: builtin/name-rev.c:403
+msgid "git name-rev [<options>] <commit>..."
+msgstr "git name-rev [<Optionen>] <Commit>..."
 
-#: builtin/ls-remote.c:54 builtin/ls-remote.c:56
-msgid "path of git-upload-pack on the remote host"
-msgstr "Pfad zu \"git-upload-pack\" auf der Gegenseite"
+#: builtin/name-rev.c:404
+msgid "git name-rev [<options>] --all"
+msgstr "git name-rev [<Optionen>] --all"
 
-#: builtin/ls-remote.c:58
-msgid "limit to tags"
-msgstr "auf Tags einschränken"
+#: builtin/name-rev.c:405
+msgid "git name-rev [<options>] --stdin"
+msgstr "git name-rev [<Optionen>] --stdin"
 
-#: builtin/ls-remote.c:59
-msgid "limit to heads"
-msgstr "auf Branches einschränken"
+#: builtin/name-rev.c:462
+msgid "print only names (no SHA-1)"
+msgstr "nur Namen anzeigen (keine SHA-1)"
 
-#: builtin/ls-remote.c:60
-msgid "do not show peeled tags"
-msgstr "keine Tags anzeigen, die andere Tags enthalten"
+#: builtin/name-rev.c:463
+msgid "only use tags to name the commits"
+msgstr "nur Tags verwenden, um die Commits zu benennen"
 
-#: builtin/ls-remote.c:62
-msgid "take url.<base>.insteadOf into account"
-msgstr "url.<Basis>.insteadOf berücksichtigen"
+#: builtin/name-rev.c:465
+msgid "only use refs matching <pattern>"
+msgstr "nur Referenzen verwenden, die <Muster> entsprechen"
 
-#: builtin/ls-remote.c:64
-msgid "exit with exit code 2 if no matching refs are found"
-msgstr ""
-"mit Rückkehrwert 2 beenden, wenn keine übereinstimmenden Referenzen\n"
-"gefunden wurden"
+#: builtin/name-rev.c:467
+msgid "ignore refs matching <pattern>"
+msgstr "ignoriere Referenzen die <Muster> entsprechen"
 
-#: builtin/ls-remote.c:67
-msgid "show underlying ref in addition to the object pointed by it"
-msgstr "zusätzlich zum Objekt die darauf verweisenden Referenzen anzeigen"
+#: builtin/name-rev.c:469
+msgid "list all commits reachable from all refs"
+msgstr "alle Commits auflisten, die von allen Referenzen erreichbar sind"
 
-#: builtin/ls-tree.c:29
-msgid "git ls-tree [<options>] <tree-ish> [<path>...]"
-msgstr "git ls-tree [<Optionen>] <Commit-Referenz> [<Pfad>...]"
+#: builtin/name-rev.c:470
+msgid "read from stdin"
+msgstr "von der Standard-Eingabe lesen"
 
-#: builtin/ls-tree.c:127
-msgid "only show trees"
-msgstr "nur Verzeichnisse anzeigen"
+#: builtin/name-rev.c:471
+msgid "allow to print `undefined` names (default)"
+msgstr "Ausgabe von `undefinierten` Namen erlauben (Standard)"
 
-#: builtin/ls-tree.c:129
-msgid "recurse into subtrees"
-msgstr "Rekursion in Unterverzeichnissen durchführen"
+#: builtin/name-rev.c:477
+msgid "dereference tags in the input (internal use)"
+msgstr "Tags in der Eingabe dereferenzieren (interne Verwendung)"
 
-#: builtin/ls-tree.c:131
-msgid "show trees when recursing"
-msgstr "Verzeichnisse bei Rekursion anzeigen"
+#: builtin/notes.c:28
+msgid "git notes [--ref <notes-ref>] [list [<object>]]"
+msgstr "git notes [--ref <Notiz-Referenz>] [list [<Objekt>]]"
 
-#: builtin/ls-tree.c:134
-msgid "terminate entries with NUL byte"
-msgstr "Einträge mit NUL-Byte abschließen"
+#: builtin/notes.c:29
+msgid ""
+"git notes [--ref <notes-ref>] add [-f] [--allow-empty] [-m <msg> | -F <file> "
+"| (-c | -C) <object>] [<object>]"
+msgstr ""
+"git notes [--ref <Notiz-Referenz>] add [-f] [--allow-empty] [-m "
+"<Beschreibung> | -F <Datei> | (-c | -C) <Objekt>] [<Objekt>]"
 
-#: builtin/ls-tree.c:135
-msgid "include object size"
-msgstr "Objektgröße einschließen"
+#: builtin/notes.c:30
+msgid "git notes [--ref <notes-ref>] copy [-f] <from-object> <to-object>"
+msgstr ""
+"git notes [--ref <Notiz-Referenz>] copy [-f] <von-Objekt> <nach-Objekt>"
+
+#: builtin/notes.c:31
+msgid ""
+"git notes [--ref <notes-ref>] append [--allow-empty] [-m <msg> | -F <file> | "
+"(-c | -C) <object>] [<object>]"
+msgstr ""
+"git notes [--ref <Notiz-Referenz>] append [--allow-empty] [-m <Beschreibung> "
+"| -F <Datei> | (-c | -C) <Objekt>] [<Objekt>]"
 
-#: builtin/ls-tree.c:137 builtin/ls-tree.c:139
-msgid "list only filenames"
-msgstr "nur Dateinamen auflisten"
+#: builtin/notes.c:32
+msgid "git notes [--ref <notes-ref>] edit [--allow-empty] [<object>]"
+msgstr "git notes [--ref <Notiz-Referenz>] edit [--allow-empty] [<Objekt>]"
 
-#: builtin/ls-tree.c:142
-msgid "use full path names"
-msgstr "vollständige Pfadnamen verwenden"
+#: builtin/notes.c:33
+msgid "git notes [--ref <notes-ref>] show [<object>]"
+msgstr "git notes [--ref <Notiz-Referenz>] show [<Objekt>]"
 
-#: builtin/ls-tree.c:144
-msgid "list entire tree; not just current directory (implies --full-name)"
+#: builtin/notes.c:34
+msgid ""
+"git notes [--ref <notes-ref>] merge [-v | -q] [-s <strategy>] <notes-ref>"
 msgstr ""
-"das gesamte Verzeichnis auflisten; nicht nur das aktuelle Verzeichnis "
-"(impliziert --full-name)"
+"git notes [--ref <Notiz-Referenz>] merge [-v | -q] [-s <Strategie>] <Notiz-"
+"Referenz>"
 
-#: builtin/mailsplit.c:241
-#, c-format
-msgid "empty mbox: '%s'"
-msgstr "Leere mbox: '%s'"
+#: builtin/notes.c:35
+msgid "git notes merge --commit [-v | -q]"
+msgstr "git notes merge --commit [-v | -q]"
 
-#: builtin/merge.c:49
-msgid "git merge [<options>] [<commit>...]"
-msgstr "git merge [<Optionen>] [<Commit>...]"
+#: builtin/notes.c:36
+msgid "git notes merge --abort [-v | -q]"
+msgstr "git notes merge --abort [-v | -q]"
 
-#: builtin/merge.c:50
-msgid "git merge --abort"
-msgstr "git merge --abort"
+#: builtin/notes.c:37
+msgid "git notes [--ref <notes-ref>] remove [<object>...]"
+msgstr "git notes [--ref <Notiz-Referenz>] remove [<Objekt>...]"
 
-#: builtin/merge.c:51
-msgid "git merge --continue"
-msgstr "git merge --continue"
+#: builtin/notes.c:38
+msgid "git notes [--ref <notes-ref>] prune [-n] [-v]"
+msgstr "git notes [--ref <Notiz-Referenz>] prune [-n] [-v]"
 
-#: builtin/merge.c:108
-msgid "switch `m' requires a value"
-msgstr "Schalter 'm' erfordert einen Wert."
+#: builtin/notes.c:39
+msgid "git notes [--ref <notes-ref>] get-ref"
+msgstr "git notes [--ref <Notiz-Referenz>] get-ref"
 
-#: builtin/merge.c:145
-#, c-format
-msgid "Could not find merge strategy '%s'.\n"
-msgstr "Konnte Merge-Strategie '%s' nicht finden.\n"
+#: builtin/notes.c:44
+msgid "git notes [list [<object>]]"
+msgstr "git notes [list [<Objekt>]]"
 
-#: builtin/merge.c:146
-#, c-format
-msgid "Available strategies are:"
-msgstr "Verfügbare Strategien sind:"
+#: builtin/notes.c:49
+msgid "git notes add [<options>] [<object>]"
+msgstr "git notes add [<Optionen>] [<Objekt>]"
 
-#: builtin/merge.c:151
-#, c-format
-msgid "Available custom strategies are:"
-msgstr "Verfügbare benutzerdefinierte Strategien sind:"
+#: builtin/notes.c:54
+msgid "git notes copy [<options>] <from-object> <to-object>"
+msgstr "git notes copy [<Optionen>] <von-Objekt> <nach-Objekt>"
 
-#: builtin/merge.c:201 builtin/pull.c:137
-msgid "do not show a diffstat at the end of the merge"
-msgstr "keine Zusammenfassung der Unterschiede am Schluss des Merges anzeigen"
+#: builtin/notes.c:55
+msgid "git notes copy --stdin [<from-object> <to-object>]..."
+msgstr "git notes copy --stdin [<von-Objekt> <nach-Objekt>]..."
 
-#: builtin/merge.c:204 builtin/pull.c:140
-msgid "show a diffstat at the end of the merge"
-msgstr "eine Zusammenfassung der Unterschiede am Schluss des Merges anzeigen"
+#: builtin/notes.c:60
+msgid "git notes append [<options>] [<object>]"
+msgstr "git notes append [<Optionen>] [<Objekt>]"
 
-#: builtin/merge.c:205 builtin/pull.c:143
-msgid "(synonym to --stat)"
-msgstr "(Synonym für --stat)"
+#: builtin/notes.c:65
+msgid "git notes edit [<object>]"
+msgstr "git notes edit [<Objekt>]"
 
-#: builtin/merge.c:207 builtin/pull.c:146
-msgid "add (at most <n>) entries from shortlog to merge commit message"
-msgstr ""
-"(höchstens <n>) Einträge von \"shortlog\" zur Beschreibung des Merge-Commits "
-"hinzufügen"
+#: builtin/notes.c:70
+msgid "git notes show [<object>]"
+msgstr "git notes show [<Objekt>]"
 
-#: builtin/merge.c:210 builtin/pull.c:152
-msgid "create a single commit instead of doing a merge"
-msgstr "einen einzelnen Commit anstatt eines Merges erzeugen"
+#: builtin/notes.c:75
+msgid "git notes merge [<options>] <notes-ref>"
+msgstr "git notes merge [<Optionen>] <Notiz-Referenz>"
 
-#: builtin/merge.c:212 builtin/pull.c:155
-msgid "perform a commit if the merge succeeds (default)"
-msgstr "einen Commit durchführen, wenn der Merge erfolgreich war (Standard)"
+#: builtin/notes.c:76
+msgid "git notes merge --commit [<options>]"
+msgstr "git notes merge --commit [<Optionen>]"
 
-#: builtin/merge.c:214 builtin/pull.c:158
-msgid "edit message before committing"
-msgstr "Bearbeitung der Beschreibung vor dem Commit"
+#: builtin/notes.c:77
+msgid "git notes merge --abort [<options>]"
+msgstr "git notes merge --abort [<Optionen>]"
 
-#: builtin/merge.c:215
-msgid "allow fast-forward (default)"
-msgstr "Vorspulen erlauben (Standard)"
+#: builtin/notes.c:82
+msgid "git notes remove [<object>]"
+msgstr "git notes remove [<Objekt>]"
 
-#: builtin/merge.c:217 builtin/pull.c:164
-msgid "abort if fast-forward is not possible"
-msgstr "abbrechen, wenn kein Vorspulen möglich ist"
+#: builtin/notes.c:87
+msgid "git notes prune [<options>]"
+msgstr "git notes prune [<Optionen>]"
 
-#: builtin/merge.c:221 builtin/pull.c:167
-msgid "verify that the named commit has a valid GPG signature"
-msgstr "den genannten Commit auf eine gültige GPG-Signatur überprüfen"
+#: builtin/notes.c:92
+msgid "git notes get-ref"
+msgstr "git notes get-ref"
 
-#: builtin/merge.c:222 builtin/notes.c:777 builtin/pull.c:171
-#: builtin/revert.c:109
-msgid "strategy"
-msgstr "Strategie"
+#: builtin/notes.c:97
+msgid "Write/edit the notes for the following object:"
+msgstr "Schreiben/Bearbeiten der Notizen für das folgende Objekt:"
 
-#: builtin/merge.c:223 builtin/pull.c:172
-msgid "merge strategy to use"
-msgstr "zu verwendende Merge-Strategie"
+#: builtin/notes.c:150
+#, c-format
+msgid "unable to start 'show' for object '%s'"
+msgstr "konnte 'show' für Objekt '%s' nicht starten"
 
-#: builtin/merge.c:224 builtin/pull.c:175
-msgid "option=value"
-msgstr "Option=Wert"
+#: builtin/notes.c:154
+msgid "could not read 'show' output"
+msgstr "Konnte Ausgabe von 'show' nicht lesen."
 
-#: builtin/merge.c:225 builtin/pull.c:176
-msgid "option for selected merge strategy"
-msgstr "Option für ausgewählte Merge-Strategie"
+#: builtin/notes.c:162
+#, c-format
+msgid "failed to finish 'show' for object '%s'"
+msgstr "konnte 'show' für Objekt '%s' nicht abschließen"
 
-#: builtin/merge.c:227
-msgid "merge commit message (for a non-fast-forward merge)"
+#: builtin/notes.c:197
+msgid "please supply the note contents using either -m or -F option"
 msgstr ""
-"Commit-Beschreibung zusammenführen (für einen Merge, der kein Vorspulen war)"
-
-#: builtin/merge.c:231
-msgid "abort the current in-progress merge"
-msgstr "den sich im Gange befindlichen Merge abbrechen"
-
-#: builtin/merge.c:233
-msgid "continue the current in-progress merge"
-msgstr "den sich im Gange befindlichen Merge fortsetzen"
-
-#: builtin/merge.c:235 builtin/pull.c:183
-msgid "allow merging unrelated histories"
-msgstr "erlaube das Zusammenführen von nicht zusammenhängenden Historien"
-
-#: builtin/merge.c:241
-msgid "verify commit-msg hook"
-msgstr "commit-msg Hook überprüfen"
+"Bitte liefern Sie die Notiz-Inhalte unter Verwendung der Option -m oder -F."
 
-#: builtin/merge.c:266
-msgid "could not run stash."
-msgstr "Konnte \"stash\" nicht ausführen."
+#: builtin/notes.c:206
+msgid "unable to write note object"
+msgstr "Konnte Notiz-Objekt nicht schreiben"
 
-#: builtin/merge.c:271
-msgid "stash failed"
-msgstr "\"stash\" fehlgeschlagen"
+#: builtin/notes.c:208
+#, c-format
+msgid "the note contents have been left in %s"
+msgstr "Die Notiz-Inhalte wurden in %s belassen."
 
-#: builtin/merge.c:276
+#: builtin/notes.c:242 builtin/tag.c:532
 #, c-format
-msgid "not a valid object: %s"
-msgstr "kein gültiges Objekt: %s"
+msgid "could not open or read '%s'"
+msgstr "konnte '%s' nicht öffnen oder lesen"
 
-#: builtin/merge.c:298 builtin/merge.c:315
-msgid "read-tree failed"
-msgstr "read-tree fehlgeschlagen"
+#: builtin/notes.c:263 builtin/notes.c:313 builtin/notes.c:315
+#: builtin/notes.c:383 builtin/notes.c:438 builtin/notes.c:526
+#: builtin/notes.c:531 builtin/notes.c:610 builtin/notes.c:672
+#, c-format
+msgid "failed to resolve '%s' as a valid ref."
+msgstr "Konnte '%s' nicht als gültige Referenz auflösen."
 
-#: builtin/merge.c:345
-msgid " (nothing to squash)"
-msgstr " (nichts zu quetschen)"
+#: builtin/notes.c:265
+#, c-format
+msgid "failed to read object '%s'."
+msgstr "Fehler beim Lesen des Objektes '%s'."
 
-#: builtin/merge.c:356
+#: builtin/notes.c:268
 #, c-format
-msgid "Squash commit -- not updating HEAD\n"
-msgstr "Quetsche Commit -- HEAD wird nicht aktualisiert\n"
+msgid "cannot read note data from non-blob object '%s'."
+msgstr "Kann Notiz-Daten nicht von Nicht-Blob Objekt '%s' lesen."
 
-#: builtin/merge.c:406
+#: builtin/notes.c:309
 #, c-format
-msgid "No merge message -- not updating HEAD\n"
-msgstr "Keine Merge-Commit-Beschreibung -- HEAD wird nicht aktualisiert\n"
+msgid "malformed input line: '%s'."
+msgstr "Fehlerhafte Eingabezeile: '%s'."
 
-#: builtin/merge.c:456
+#: builtin/notes.c:324
 #, c-format
-msgid "'%s' does not point to a commit"
-msgstr "'%s' zeigt auf keinen Commit"
+msgid "failed to copy notes from '%s' to '%s'"
+msgstr "Fehler beim Kopieren der Notizen von '%s' nach '%s'"
 
-#: builtin/merge.c:546
+#. TRANSLATORS: the first %s will be replaced by a git
+#. notes command: 'add', 'merge', 'remove', etc.
+#.
+#: builtin/notes.c:356
 #, c-format
-msgid "Bad branch.%s.mergeoptions string: %s"
-msgstr "Ungültiger branch.%s.mergeoptions String: %s"
+msgid "refusing to %s notes in %s (outside of refs/notes/)"
+msgstr ""
+"Ausführung von %s auf Notizen in %s (außerhalb von refs/notes/) "
+"zurückgewiesen"
 
-#: builtin/merge.c:668
-msgid "Not handling anything other than two heads merge."
-msgstr "Es wird nur der Merge von zwei Branches behandelt."
+#: builtin/notes.c:376 builtin/notes.c:431 builtin/notes.c:509
+#: builtin/notes.c:521 builtin/notes.c:598 builtin/notes.c:665
+#: builtin/notes.c:815 builtin/notes.c:963 builtin/notes.c:985
+msgid "too many parameters"
+msgstr "zu viele Parameter"
 
-#: builtin/merge.c:682
+#: builtin/notes.c:389 builtin/notes.c:678
 #, c-format
-msgid "Unknown option for merge-recursive: -X%s"
-msgstr "Unbekannte Option für merge-recursive: -X%s"
+msgid "no note found for object %s."
+msgstr "Keine Notiz für Objekt %s gefunden."
+
+#: builtin/notes.c:410 builtin/notes.c:576
+msgid "note contents as a string"
+msgstr "Notizinhalte als Zeichenkette"
+
+#: builtin/notes.c:413 builtin/notes.c:579
+msgid "note contents in a file"
+msgstr "Notizinhalte in einer Datei"
+
+#: builtin/notes.c:416 builtin/notes.c:582
+msgid "reuse and edit specified note object"
+msgstr "Wiederverwendung und Bearbeitung des angegebenen Notiz-Objektes"
+
+#: builtin/notes.c:419 builtin/notes.c:585
+msgid "reuse specified note object"
+msgstr "Wiederverwendung des angegebenen Notiz-Objektes"
+
+#: builtin/notes.c:422 builtin/notes.c:588
+msgid "allow storing empty note"
+msgstr "Speichern leerer Notiz erlauben"
+
+#: builtin/notes.c:423 builtin/notes.c:496
+msgid "replace existing notes"
+msgstr "existierende Notizen ersetzen"
 
-#: builtin/merge.c:697
+#: builtin/notes.c:448
 #, c-format
-msgid "unable to write %s"
-msgstr "konnte %s nicht schreiben"
+msgid ""
+"Cannot add notes. Found existing notes for object %s. Use '-f' to overwrite "
+"existing notes"
+msgstr ""
+"Konnte Notizen nicht hinzufügen. Existierende Notizen für Objekt %s "
+"gefunden. Verwenden Sie '-f', um die existierenden Notizen zu überschreiben."
 
-#: builtin/merge.c:749
+#: builtin/notes.c:463 builtin/notes.c:544
 #, c-format
-msgid "Could not read from '%s'"
-msgstr "konnte nicht von '%s' lesen"
+msgid "Overwriting existing notes for object %s\n"
+msgstr "Überschreibe existierende Notizen für Objekt %s\n"
 
-#: builtin/merge.c:758
+#: builtin/notes.c:475 builtin/notes.c:637 builtin/notes.c:902
 #, c-format
-msgid "Not committing merge; use 'git commit' to complete the merge.\n"
+msgid "Removing note for object %s\n"
+msgstr "Entferne Notiz für Objekt %s\n"
+
+#: builtin/notes.c:497
+msgid "read objects from stdin"
+msgstr "Objekte von der Standard-Eingabe lesen"
+
+#: builtin/notes.c:499
+msgid "load rewriting config for <command> (implies --stdin)"
 msgstr ""
-"Merge wurde nicht committet; benutzen Sie 'git commit', um den Merge "
-"abzuschließen.\n"
+"Konfiguration für <Befehl> zum Umschreiben von Commits laden (impliziert --"
+"stdin)"
+
+#: builtin/notes.c:517
+msgid "too few parameters"
+msgstr "zu wenig Parameter"
 
-#: builtin/merge.c:764
+#: builtin/notes.c:538
 #, c-format
 msgid ""
-"Please enter a commit message to explain why this merge is necessary,\n"
-"especially if it merges an updated upstream into a topic branch.\n"
-"\n"
-"Lines starting with '%c' will be ignored, and an empty message aborts\n"
-"the commit.\n"
+"Cannot copy notes. Found existing notes for object %s. Use '-f' to overwrite "
+"existing notes"
 msgstr ""
-"Bitte geben Sie eine Commit-Beschreibung ein, um zu erklären, warum dieser\n"
-"Merge erforderlich ist, insbesondere wenn es einen aktualisierten\n"
-"Upstream-Branch mit einem Thema-Branch zusammenführt.\n"
-"\n"
-"Zeilen beginnend mit '%c' werden ignoriert, und eine leere Beschreibung\n"
-"bricht den Commit ab.\n"
-
-#: builtin/merge.c:800
-msgid "Empty commit message."
-msgstr "Leere Commit-Beschreibung"
+"Kann Notizen nicht kopieren. Existierende Notizen für Objekt %s gefunden. "
+"Verwenden Sie '-f', um die existierenden Notizen zu überschreiben."
 
-#: builtin/merge.c:820
+#: builtin/notes.c:550
 #, c-format
-msgid "Wonderful.\n"
-msgstr "Wunderbar.\n"
+msgid "missing notes on source object %s. Cannot copy."
+msgstr "Keine Notizen für Quell-Objekt %s. Kopie nicht möglich."
 
-#: builtin/merge.c:873
+#: builtin/notes.c:603
 #, c-format
-msgid "Automatic merge failed; fix conflicts and then commit the result.\n"
+msgid ""
+"The -m/-F/-c/-C options have been deprecated for the 'edit' subcommand.\n"
+"Please use 'git notes add -f -m/-F/-c/-C' instead.\n"
 msgstr ""
-"Automatischer Merge fehlgeschlagen; beheben Sie die Konflikte und committen "
-"Sie dann das Ergebnis.\n"
+"Die Optionen -m/-F/-c/-C sind für den Unterbefehl 'edit' veraltet.\n"
+"Bitte benutzen Sie stattdessen 'git notes add -f -m/-F/-c/-C'.\n"
 
-#: builtin/merge.c:912
-msgid "No current branch."
-msgstr "Sie befinden sich auf keinem Branch."
+#: builtin/notes.c:698
+msgid "failed to delete ref NOTES_MERGE_PARTIAL"
+msgstr "Fehler beim Löschen der Referenz NOTES_MERGE_PARTIAL"
 
-#: builtin/merge.c:914
-msgid "No remote for the current branch."
-msgstr "Kein Remote-Repository für den aktuellen Branch."
+#: builtin/notes.c:700
+msgid "failed to delete ref NOTES_MERGE_REF"
+msgstr "Fehler beim Löschen der Referenz NOTES_MERGE_REF"
 
-#: builtin/merge.c:916
-msgid "No default upstream defined for the current branch."
-msgstr ""
-"Es ist kein Standard-Upstream-Branch für den aktuellen Branch definiert."
+#: builtin/notes.c:702
+msgid "failed to remove 'git notes merge' worktree"
+msgstr "Fehler beim Löschen des Arbeitsverzeichnisses von 'git notes merge'."
 
-#: builtin/merge.c:921
-#, c-format
-msgid "No remote-tracking branch for %s from %s"
-msgstr "Kein Remote-Tracking-Branch für %s von %s"
+#: builtin/notes.c:722
+msgid "failed to read ref NOTES_MERGE_PARTIAL"
+msgstr "Fehler beim Lesen der Referenz NOTES_MERGE_PARTIAL"
 
-#: builtin/merge.c:974
-#, c-format
-msgid "Bad value '%s' in environment '%s'"
-msgstr "Fehlerhafter Wert '%s' in Umgebungsvariable '%s'"
+#: builtin/notes.c:724
+msgid "could not find commit from NOTES_MERGE_PARTIAL."
+msgstr "Konnte Commit von NOTES_MERGE_PARTIAL nicht finden."
 
-#: builtin/merge.c:1076
-#, c-format
-msgid "not something we can merge in %s: %s"
-msgstr "nichts was wir in %s zusammenführen können: %s"
+#: builtin/notes.c:726
+msgid "could not parse commit from NOTES_MERGE_PARTIAL."
+msgstr "Konnte Commit von NOTES_MERGE_PARTIAL nicht parsen."
 
-#: builtin/merge.c:1110
-msgid "not something we can merge"
-msgstr "nichts was wir zusammenführen können"
+#: builtin/notes.c:739
+msgid "failed to resolve NOTES_MERGE_REF"
+msgstr "Fehler beim Auflösen von NOTES_MERGE_REF"
 
-#: builtin/merge.c:1212
-msgid "--abort expects no arguments"
-msgstr "--abort akzeptiert keine Argumente"
+#: builtin/notes.c:742
+msgid "failed to finalize notes merge"
+msgstr "Fehler beim Abschließen der Zusammenführung der Notizen."
 
-#: builtin/merge.c:1216
-msgid "There is no merge to abort (MERGE_HEAD missing)."
-msgstr "Es gibt keinen Merge abzubrechen (MERGE_HEAD fehlt)"
+#: builtin/notes.c:768
+#, c-format
+msgid "unknown notes merge strategy %s"
+msgstr "unbekannte Merge-Strategie '%s' für Notizen"
 
-#: builtin/merge.c:1228
-msgid "--continue expects no arguments"
-msgstr "--continue erwartet keine Argumente"
+#: builtin/notes.c:784
+msgid "General options"
+msgstr "Allgemeine Optionen"
 
-#: builtin/merge.c:1232
-msgid "There is no merge in progress (MERGE_HEAD missing)."
-msgstr "Es ist kein Merge im Gange (MERGE_HEAD fehlt)."
+#: builtin/notes.c:786
+msgid "Merge options"
+msgstr "Merge-Optionen"
 
-#: builtin/merge.c:1248
+#: builtin/notes.c:788
 msgid ""
-"You have not concluded your merge (MERGE_HEAD exists).\n"
-"Please, commit your changes before you merge."
+"resolve notes conflicts using the given strategy (manual/ours/theirs/union/"
+"cat_sort_uniq)"
 msgstr ""
-"Sie haben Ihren Merge nicht abgeschlossen (MERGE_HEAD existiert).\n"
-"Bitte committen Sie Ihre Änderungen, bevor Sie den Merge ausführen."
+"löst Konflikte bei Notizen mit der angegebenen Strategie auf (manual/ours/"
+"theirs/union/cat_sort_uniq)"
 
-#: builtin/merge.c:1255
-msgid ""
-"You have not concluded your cherry-pick (CHERRY_PICK_HEAD exists).\n"
-"Please, commit your changes before you merge."
-msgstr ""
-"Sie haben \"cherry-pick\" nicht abgeschlossen (CHERRY_PICK_HEAD existiert).\n"
-"Bitte committen Sie Ihre Änderungen, bevor Sie den Merge ausführen."
+#: builtin/notes.c:790
+msgid "Committing unmerged notes"
+msgstr "nicht zusammengeführte Notizen eintragen"
 
-#: builtin/merge.c:1258
-msgid "You have not concluded your cherry-pick (CHERRY_PICK_HEAD exists)."
+#: builtin/notes.c:792
+msgid "finalize notes merge by committing unmerged notes"
 msgstr ""
-"Sie haben \"cherry-pick\" nicht abgeschlossen (CHERRY_PICK_HEAD existiert)."
+"Merge von Notizen abschließen, in dem nicht zusammengeführte Notizen "
+"committet werden"
 
-#: builtin/merge.c:1267
-msgid "You cannot combine --squash with --no-ff."
-msgstr "Sie können --squash nicht mit --no-ff kombinieren."
+#: builtin/notes.c:794
+msgid "Aborting notes merge resolution"
+msgstr "Konfliktauflösung beim Merge von Notizen abbrechen"
 
-#: builtin/merge.c:1275
-msgid "No commit specified and merge.defaultToUpstream not set."
-msgstr "Kein Commit angegeben und merge.defaultToUpstream ist nicht gesetzt."
+#: builtin/notes.c:796
+msgid "abort notes merge"
+msgstr "Merge von Notizen abbrechen"
 
-#: builtin/merge.c:1292
-msgid "Squash commit into empty head not supported yet"
-msgstr ""
-"Bin auf einem Commit, der noch geboren wird; kann \"squash\" nicht ausführen."
+#: builtin/notes.c:807
+msgid "cannot mix --commit, --abort or -s/--strategy"
+msgstr "Kann --commit, --abort oder -s/--strategy nicht kombinieren."
 
-#: builtin/merge.c:1294
-msgid "Non-fast-forward commit does not make sense into an empty head"
-msgstr ""
-"Nicht vorzuspulender Commit kann nicht in einem leeren Branch verwendet "
-"werden."
+#: builtin/notes.c:812
+msgid "must specify a notes ref to merge"
+msgstr "Sie müssen eine Notiz-Referenz zum Mergen angeben."
 
-#: builtin/merge.c:1299
+#: builtin/notes.c:836
 #, c-format
-msgid "%s - not something we can merge"
-msgstr "%s - nichts was wir zusammenführen können"
+msgid "unknown -s/--strategy: %s"
+msgstr "Unbekannter Wert für -s/--strategy: %s"
 
-#: builtin/merge.c:1301
-msgid "Can merge only exactly one commit into empty head"
-msgstr "Kann nur exakt einen Commit in einem leeren Branch zusammenführen."
+#: builtin/notes.c:873
+#, c-format
+msgid "a notes merge into %s is already in-progress at %s"
+msgstr "Ein Merge von Notizen nach %s ist bereits im Gange bei %s"
 
-#: builtin/merge.c:1335
+#: builtin/notes.c:876
 #, c-format
-msgid "Commit %s has an untrusted GPG signature, allegedly by %s."
+msgid "failed to store link to current notes ref (%s)"
 msgstr ""
-"Commit %s hat eine nicht vertrauenswürdige GPG-Signatur, angeblich von %s."
+"Fehler beim Speichern der Verknüpfung zur aktuellen Notes-Referenz (%s)"
 
-#: builtin/merge.c:1338
+#: builtin/notes.c:878
 #, c-format
-msgid "Commit %s has a bad GPG signature allegedly by %s."
-msgstr "Commit %s hat eine ungültige GPG-Signatur, angeblich von %s."
+msgid ""
+"Automatic notes merge failed. Fix conflicts in %s and commit the result with "
+"'git notes merge --commit', or abort the merge with 'git notes merge --"
+"abort'.\n"
+msgstr ""
+"Automatisches Zusammenführen der Notizen fehlgeschlagen. Beheben Sie die\n"
+"Konflikte in %s und committen Sie das Ergebnis mit 'git notes merge --"
+"commit',\n"
+"oder brechen Sie den Merge mit 'git notes merge --abort' ab.\n"
 
-#: builtin/merge.c:1341
+#: builtin/notes.c:897 builtin/tag.c:545
 #, c-format
-msgid "Commit %s does not have a GPG signature."
-msgstr "Commit %s hat keine GPG-Signatur."
+msgid "Failed to resolve '%s' as a valid ref."
+msgstr "Konnte '%s' nicht als gültige Referenz auflösen."
 
-#: builtin/merge.c:1344
+#: builtin/notes.c:900
 #, c-format
-msgid "Commit %s has a good GPG signature by %s\n"
-msgstr "Commit %s hat eine gültige GPG-Signatur von %s\n"
+msgid "Object %s has no note\n"
+msgstr "Objekt %s hat keine Notiz\n"
 
-#: builtin/merge.c:1403
-msgid "refusing to merge unrelated histories"
-msgstr "Verweigere den Merge von nicht zusammenhängenden Historien."
+#: builtin/notes.c:912
+msgid "attempt to remove non-existent note is not an error"
+msgstr "der Versuch, eine nicht existierende Notiz zu löschen, ist kein Fehler"
 
-#: builtin/merge.c:1412
-msgid "Already up to date."
-msgstr "Bereits aktuell."
+#: builtin/notes.c:915
+msgid "read object names from the standard input"
+msgstr "Objektnamen von der Standard-Eingabe lesen"
 
-#: builtin/merge.c:1422
-#, c-format
-msgid "Updating %s..%s\n"
-msgstr "Aktualisiere %s..%s\n"
+#: builtin/notes.c:954 builtin/prune.c:130 builtin/worktree.c:164
+msgid "do not remove, show only"
+msgstr "nicht löschen, nur anzeigen"
 
-#: builtin/merge.c:1463
-#, c-format
-msgid "Trying really trivial in-index merge...\n"
-msgstr "Probiere wirklich trivialen \"in-index\"-Merge ...\n"
+#: builtin/notes.c:955
+msgid "report pruned notes"
+msgstr "gelöschte Notizen melden"
+
+#: builtin/notes.c:998
+msgid "notes-ref"
+msgstr "Notiz-Referenz"
+
+#: builtin/notes.c:999
+msgid "use notes from <notes-ref>"
+msgstr "Notizen von <Notiz-Referenz> verwenden"
 
-#: builtin/merge.c:1470
+#: builtin/notes.c:1034 builtin/stash.c:1607
 #, c-format
-msgid "Nope.\n"
-msgstr "Nein.\n"
+msgid "unknown subcommand: %s"
+msgstr "Unbekannter Unterbefehl: %s"
 
-#: builtin/merge.c:1495
-msgid "Already up to date. Yeeah!"
-msgstr "Bereits aktuell."
+#: builtin/pack-objects.c:52
+msgid ""
+"git pack-objects --stdout [<options>...] [< <ref-list> | < <object-list>]"
+msgstr ""
+"git pack-objects --stdout [<Optionen>...] [< <Referenzliste> | < "
+"<Objektliste>]"
 
-#: builtin/merge.c:1501
-msgid "Not possible to fast-forward, aborting."
-msgstr "Vorspulen nicht möglich, breche ab."
+#: builtin/pack-objects.c:53
+msgid ""
+"git pack-objects [<options>...] <base-name> [< <ref-list> | < <object-list>]"
+msgstr ""
+"git pack-objects [<Optionen>...] <Basis-Name> [< <Referenzliste> | < "
+"<Objektliste>]"
 
-#: builtin/merge.c:1524 builtin/merge.c:1603
+#: builtin/pack-objects.c:428
 #, c-format
-msgid "Rewinding the tree to pristine...\n"
-msgstr "Rücklauf des Verzeichnisses bis zum Ursprung ...\n"
+msgid "bad packed object CRC for %s"
+msgstr "Ungültiges CRC für gepacktes Objekt %s."
 
-#: builtin/merge.c:1528
+#: builtin/pack-objects.c:439
 #, c-format
-msgid "Trying merge strategy %s...\n"
-msgstr "Probiere Merge-Strategie %s ...\n"
+msgid "corrupt packed object for %s"
+msgstr "Fehlerhaftes gepacktes Objekt für %s."
 
-#: builtin/merge.c:1594
+#: builtin/pack-objects.c:570
 #, c-format
-msgid "No merge strategy handled the merge.\n"
-msgstr "Keine Merge-Strategie behandelt diesen Merge.\n"
+msgid "recursive delta detected for object %s"
+msgstr "Rekursiver Unterschied für Objekt %s festgestellt."
 
-#: builtin/merge.c:1596
+#: builtin/pack-objects.c:781
 #, c-format
-msgid "Merge with strategy %s failed.\n"
-msgstr "Merge mit Strategie %s fehlgeschlagen.\n"
+msgid "ordered %u objects, expected %<PRIu32>"
+msgstr "%u Objekte geordnet, %<PRIu32> erwartet."
 
-#: builtin/merge.c:1605
+#: builtin/pack-objects.c:794
 #, c-format
-msgid "Using the %s to prepare resolving by hand.\n"
-msgstr "Benutzen Sie \"%s\", um die Auflösung per Hand vorzubereiten.\n"
+msgid "packfile is invalid: %s"
+msgstr "Packdatei ist ungültig: %s"
 
-#: builtin/merge.c:1617
+#: builtin/pack-objects.c:798
 #, c-format
-msgid "Automatic merge went well; stopped before committing as requested\n"
+msgid "unable to open packfile for reuse: %s"
+msgstr "Konnte Packdatei nicht zur Wiederverwendung öffnen: %s"
+
+#: builtin/pack-objects.c:802
+msgid "unable to seek in reused packfile"
+msgstr "Konnte \"seek\" nicht in wiederverwendeter Packdatei ausführen."
+
+#: builtin/pack-objects.c:813
+msgid "unable to read from reused packfile"
+msgstr "Konnte nicht von wiederverwendeter Packdatei lesen."
+
+#: builtin/pack-objects.c:841
+msgid "disabling bitmap writing, packs are split due to pack.packSizeLimit"
 msgstr ""
-"Automatischer Merge abgeschlossen; halte, wie gewünscht, vor dem Commit an\n"
+"Deaktiviere Schreiben der Bitmap, Pakete wurden durch pack.packSizeLimit\n"
+"aufgetrennt."
 
-#: builtin/merge-base.c:30
-msgid "git merge-base [-a | --all] <commit> <commit>..."
-msgstr "git merge-base [-a | --all] <Commit> <Commit>..."
+#: builtin/pack-objects.c:854
+msgid "Writing objects"
+msgstr "Schreibe Objekte"
 
-#: builtin/merge-base.c:31
-msgid "git merge-base [-a | --all] --octopus <commit>..."
-msgstr "git merge-base [-a | --all] --octopus <Commit>..."
+#: builtin/pack-objects.c:917 builtin/update-index.c:90
+#, c-format
+msgid "failed to stat %s"
+msgstr "Konnte '%s' nicht lesen"
 
-#: builtin/merge-base.c:32
-msgid "git merge-base --independent <commit>..."
-msgstr "git merge-base --independent <Commit>..."
+#: builtin/pack-objects.c:970
+#, c-format
+msgid "wrote %<PRIu32> objects while expecting %<PRIu32>"
+msgstr "Schrieb %<PRIu32> Objekte während %<PRIu32> erwartet waren."
 
-#: builtin/merge-base.c:33
-msgid "git merge-base --is-ancestor <commit> <commit>"
-msgstr "git merge-base --is-ancestor <Commit> <Commit>"
+#: builtin/pack-objects.c:1164
+msgid "disabling bitmap writing, as some objects are not being packed"
+msgstr ""
+"Deaktiviere Schreiben der Bitmap, da einige Objekte nicht in eine Pack-"
+"Datei\n"
+"geschrieben wurden."
 
-#: builtin/merge-base.c:34
-msgid "git merge-base --fork-point <ref> [<commit>]"
-msgstr "git merge-base --fork-point <Referenz> [<Commit>]"
+#: builtin/pack-objects.c:1592
+#, c-format
+msgid "delta base offset overflow in pack for %s"
+msgstr "\"delta base offset\" Überlauf in Paket für %s"
 
-#: builtin/merge-base.c:220
-msgid "output all common ancestors"
-msgstr "Ausgabe aller gemeinsamen Vorgänger-Commits"
+#: builtin/pack-objects.c:1601
+#, c-format
+msgid "delta base offset out of bound for %s"
+msgstr "\"delta base offset\" liegt außerhalb des gültigen Bereichs für %s"
 
-#: builtin/merge-base.c:222
-msgid "find ancestors for a single n-way merge"
-msgstr "Vorgänger-Commits für einen einzelnen n-Wege-Merge finden"
+#: builtin/pack-objects.c:1870
+msgid "Counting objects"
+msgstr "Zähle Objekte"
 
-#: builtin/merge-base.c:224
-msgid "list revs not reachable from others"
-msgstr "Commits auflisten, die nicht durch Andere erreichbar sind"
+#: builtin/pack-objects.c:2000
+#, c-format
+msgid "unable to get size of %s"
+msgstr "Konnte Größe von %s nicht bestimmen."
 
-#: builtin/merge-base.c:226
-msgid "is the first one ancestor of the other?"
-msgstr "ist der Erste ein Vorgänger-Commit des Anderen?"
+#: builtin/pack-objects.c:2015
+#, c-format
+msgid "unable to parse object header of %s"
+msgstr "Konnte Kopfbereich von Objekt '%s' nicht parsen."
 
-#: builtin/merge-base.c:228
-msgid "find where <commit> forked from reflog of <ref>"
-msgstr "<Commit> finden, von wo Reflog von <Referenz> abgespalten wurde"
+#: builtin/pack-objects.c:2085 builtin/pack-objects.c:2101
+#: builtin/pack-objects.c:2111
+#, c-format
+msgid "object %s cannot be read"
+msgstr "Objekt %s kann nicht gelesen werden."
 
-#: builtin/merge-file.c:9
-msgid ""
-"git merge-file [<options>] [-L <name1> [-L <orig> [-L <name2>]]] <file1> "
-"<orig-file> <file2>"
-msgstr ""
-"git merge-file [<Optionen>] [-L <Name1> [-L <orig> [-L <Name2>]]] <Datei1> "
-"<orig-Datei> <Datei2>"
+#: builtin/pack-objects.c:2088 builtin/pack-objects.c:2115
+#, c-format
+msgid "object %s inconsistent object length (%<PRIuMAX> vs %<PRIuMAX>)"
+msgstr "Inkonsistente Objektlänge bei Objekt %s (%<PRIuMAX> vs %<PRIuMAX>)"
 
-#: builtin/merge-file.c:33
-msgid "send results to standard output"
-msgstr "Ergebnisse zur Standard-Ausgabe senden"
+#: builtin/pack-objects.c:2125
+msgid "suboptimal pack - out of memory"
+msgstr "ungünstiges Packet - Speicher voll"
 
-#: builtin/merge-file.c:34
-msgid "use a diff3 based merge"
-msgstr "einen diff3 basierten Merge verwenden"
+#: builtin/pack-objects.c:2440
+#, c-format
+msgid "Delta compression using up to %d threads"
+msgstr "Delta-Kompression verwendet bis zu %d Threads."
 
-#: builtin/merge-file.c:35
-msgid "for conflicts, use our version"
-msgstr "bei Konflikten unsere Variante verwenden"
+#: builtin/pack-objects.c:2572
+#, c-format
+msgid "unable to pack objects reachable from tag %s"
+msgstr "Konnte keine Objekte packen, die von Tag %s erreichbar sind."
 
-#: builtin/merge-file.c:37
-msgid "for conflicts, use their version"
-msgstr "bei Konflikten ihre Variante verwenden"
+#: builtin/pack-objects.c:2659
+msgid "Compressing objects"
+msgstr "Komprimiere Objekte"
 
-#: builtin/merge-file.c:39
-msgid "for conflicts, use a union version"
-msgstr "bei Konflikten eine gemeinsame Variante verwenden"
+#: builtin/pack-objects.c:2665
+msgid "inconsistency with delta count"
+msgstr "Inkonsistenz mit der Anzahl von Deltas"
+
+#: builtin/pack-objects.c:2742
+#, c-format
+msgid ""
+"expected edge object ID, got garbage:\n"
+" %s"
+msgstr ""
+"Erwartete Randobjekt-ID, erhielt nutzlose Daten:\n"
+" %s"
 
-#: builtin/merge-file.c:42
-msgid "for conflicts, use this marker size"
-msgstr "bei Konflikten diese Kennzeichnungslänge verwenden"
+#: builtin/pack-objects.c:2748
+#, c-format
+msgid ""
+"expected object ID, got garbage:\n"
+" %s"
+msgstr ""
+"Erwartete Objekt-ID, erhielt nutzlose Daten:\n"
+" %s"
 
-#: builtin/merge-file.c:43
-msgid "do not warn about conflicts"
-msgstr "keine Warnung bei Konflikten"
+#: builtin/pack-objects.c:2846
+msgid "invalid value for --missing"
+msgstr "Ungültiger Wert für --missing."
 
-#: builtin/merge-file.c:45
-msgid "set labels for file1/orig-file/file2"
-msgstr "Beschriftung für Datei1/orig-Datei/Datei2 setzen"
+#: builtin/pack-objects.c:2905 builtin/pack-objects.c:3013
+msgid "cannot open pack index"
+msgstr "Kann Paketindex nicht öffnen."
 
-#: builtin/merge-recursive.c:45
+#: builtin/pack-objects.c:2936
 #, c-format
-msgid "unknown option %s"
-msgstr "unbekannte Option: %s"
+msgid "loose object at %s could not be examined"
+msgstr "Loses Objekt bei %s konnte nicht untersucht werden."
+
+#: builtin/pack-objects.c:3021
+msgid "unable to force loose object"
+msgstr "Konnte loses Objekt nicht erzwingen."
 
-#: builtin/merge-recursive.c:51
+#: builtin/pack-objects.c:3113
 #, c-format
-msgid "could not parse object '%s'"
-msgstr "Konnte Objekt '%s' nicht parsen."
+msgid "not a rev '%s'"
+msgstr "'%s' ist kein Commit."
 
-#: builtin/merge-recursive.c:55
+#: builtin/pack-objects.c:3116
 #, c-format
-msgid "cannot handle more than %d base. Ignoring %s."
-msgid_plural "cannot handle more than %d bases. Ignoring %s."
-msgstr[0] "kann nicht mit mehr als %d Merge-Basis umgehen. Ignoriere %s."
-msgstr[1] "kann nicht mit mehr als %d Merge-Basen umgehen. Ignoriere %s."
+msgid "bad revision '%s'"
+msgstr "Ungültiger Commit '%s'."
 
-#: builtin/merge-recursive.c:63
-msgid "not handling anything other than two heads merge."
-msgstr "Es wird nur der Merge von zwei Branches behandelt."
+#: builtin/pack-objects.c:3141
+msgid "unable to add recent objects"
+msgstr "Konnte jüngste Objekte nicht hinzufügen."
 
-#: builtin/merge-recursive.c:69 builtin/merge-recursive.c:71
+#: builtin/pack-objects.c:3194
 #, c-format
-msgid "could not resolve ref '%s'"
-msgstr "Konnte Referenz '%s' nicht auflösen"
+msgid "unsupported index version %s"
+msgstr "Nicht unterstützte Index-Version %s"
 
-#: builtin/merge-recursive.c:77
+#: builtin/pack-objects.c:3198
 #, c-format
-msgid "Merging %s with %s\n"
-msgstr "Führe %s mit %s zusammen\n"
+msgid "bad index version '%s'"
+msgstr "Ungültige Index-Version '%s'"
 
-#: builtin/mktree.c:65
-msgid "git mktree [-z] [--missing] [--batch]"
-msgstr "git mktree [-z] [--missing] [--batch]"
+#: builtin/pack-objects.c:3236
+msgid "<version>[,<offset>]"
+msgstr "<Version>[,<Offset>]"
 
-#: builtin/mktree.c:153
-msgid "input is NUL terminated"
-msgstr "Eingabe ist durch NUL-Zeichen abgeschlossen"
+#: builtin/pack-objects.c:3237
+msgid "write the pack index file in the specified idx format version"
+msgstr ""
+"die Index-Datei des Paketes in der angegebenen Indexformat-Version schreiben"
 
-#: builtin/mktree.c:154 builtin/write-tree.c:25
-msgid "allow missing objects"
-msgstr "fehlende Objekte erlauben"
+#: builtin/pack-objects.c:3240
+msgid "maximum size of each output pack file"
+msgstr "maximale Größe für jede ausgegebene Paketdatei"
 
-#: builtin/mktree.c:155
-msgid "allow creation of more than one tree"
-msgstr "die Erstellung von mehr als einem \"Tree\"-Objekt erlauben"
+#: builtin/pack-objects.c:3242
+msgid "ignore borrowed objects from alternate object store"
+msgstr "geliehene Objekte von alternativem Objektspeicher ignorieren"
 
-#: builtin/mv.c:17
-msgid "git mv [<options>] <source>... <destination>"
-msgstr "git mv [<Optionen>] <Quelle>... <Ziel>"
+#: builtin/pack-objects.c:3244
+msgid "ignore packed objects"
+msgstr "gepackte Objekte ignorieren"
 
-#: builtin/mv.c:83
-#, c-format
-msgid "Directory %s is in index and no submodule?"
-msgstr "Verzeichnis %s ist zum Commit vorgemerkt und kein Submodul?"
+#: builtin/pack-objects.c:3246
+msgid "limit pack window by objects"
+msgstr "Paketfenster durch Objekte begrenzen"
 
-#: builtin/mv.c:85 builtin/rm.c:289
-msgid "Please stage your changes to .gitmodules or stash them to proceed"
+#: builtin/pack-objects.c:3248
+msgid "limit pack window by memory in addition to object limit"
 msgstr ""
-"Bitte merken Sie Ihre Änderungen in .gitmodules zum Commit vor oder "
-"benutzen\n"
-"Sie \"stash\", um fortzufahren."
+"Paketfenster, zusätzlich zur Objektbegrenzung, durch Speicher begrenzen"
 
-#: builtin/mv.c:103
-#, c-format
-msgid "%.*s is in index"
-msgstr "%.*s ist zum Commit vorgemerkt"
+#: builtin/pack-objects.c:3250
+msgid "maximum length of delta chain allowed in the resulting pack"
+msgstr ""
+"maximale Länge der erlaubten Differenzverkettung im resultierenden Paket"
 
-#: builtin/mv.c:125
-msgid "force move/rename even if target exists"
-msgstr "Verschieben/Umbenennen erzwingen, auch wenn das Ziel existiert"
+#: builtin/pack-objects.c:3252
+msgid "reuse existing deltas"
+msgstr "existierende Unterschiede wiederverwenden"
 
-#: builtin/mv.c:127
-msgid "skip move/rename errors"
-msgstr "Fehler beim Verschieben oder Umbenennen überspringen"
+#: builtin/pack-objects.c:3254
+msgid "reuse existing objects"
+msgstr "existierende Objekte wiederverwenden"
 
-#: builtin/mv.c:168
-#, c-format
-msgid "destination '%s' is not a directory"
-msgstr "Ziel '%s' ist kein Verzeichnis"
+#: builtin/pack-objects.c:3256
+msgid "use OFS_DELTA objects"
+msgstr "OFS_DELTA Objekte verwenden"
 
-#: builtin/mv.c:179
-#, c-format
-msgid "Checking rename of '%s' to '%s'\n"
-msgstr "Prüfe Umbenennung von '%s' nach '%s'\n"
+#: builtin/pack-objects.c:3258
+msgid "use threads when searching for best delta matches"
+msgstr ""
+"Threads bei der Suche nach den besten Übereinstimmungen bei Unterschieden "
+"verwenden"
 
-#: builtin/mv.c:183
-msgid "bad source"
-msgstr "ungültige Quelle"
+#: builtin/pack-objects.c:3260
+msgid "do not create an empty pack output"
+msgstr "keine leeren Pakete erzeugen"
 
-#: builtin/mv.c:186
-msgid "can not move directory into itself"
-msgstr "kann Verzeichnis nicht in sich selbst verschieben"
+#: builtin/pack-objects.c:3262
+msgid "read revision arguments from standard input"
+msgstr "Argumente bezüglich Commits von der Standard-Eingabe lesen"
 
-#: builtin/mv.c:189
-msgid "cannot move directory over file"
-msgstr "kann Verzeichnis nicht über Datei verschieben"
+#: builtin/pack-objects.c:3264
+msgid "limit the objects to those that are not yet packed"
+msgstr "die Objekte zu solchen, die noch nicht gepackt wurden, begrenzen"
 
-#: builtin/mv.c:198
-msgid "source directory is empty"
-msgstr "Quellverzeichnis ist leer"
+#: builtin/pack-objects.c:3267
+msgid "include objects reachable from any reference"
+msgstr "Objekte einschließen, die von jeder Referenz erreichbar sind"
 
-#: builtin/mv.c:223
-msgid "not under version control"
-msgstr "nicht unter Versionskontrolle"
+#: builtin/pack-objects.c:3270
+msgid "include objects referred by reflog entries"
+msgstr ""
+"Objekte einschließen, die von Einträgen des Reflogs referenziert werden"
 
-#: builtin/mv.c:226
-msgid "destination exists"
-msgstr "Ziel existiert bereits"
+#: builtin/pack-objects.c:3273
+msgid "include objects referred to by the index"
+msgstr "Objekte einschließen, die vom Index referenziert werden"
 
-#: builtin/mv.c:234
-#, c-format
-msgid "overwriting '%s'"
-msgstr "überschreibe '%s'"
+#: builtin/pack-objects.c:3276
+msgid "output pack to stdout"
+msgstr "Paket in die Standard-Ausgabe schreiben"
 
-#: builtin/mv.c:237
-msgid "Cannot overwrite"
-msgstr "Kann nicht überschreiben"
+#: builtin/pack-objects.c:3278
+msgid "include tag objects that refer to objects to be packed"
+msgstr "Tag-Objekte einschließen, die auf gepackte Objekte referenzieren"
 
-#: builtin/mv.c:240
-msgid "multiple sources for the same target"
-msgstr "mehrere Quellen für dasselbe Ziel"
+#: builtin/pack-objects.c:3280
+msgid "keep unreachable objects"
+msgstr "nicht erreichbare Objekte behalten"
 
-#: builtin/mv.c:242
-msgid "destination directory does not exist"
-msgstr "Zielverzeichnis existiert nicht"
+#: builtin/pack-objects.c:3282
+msgid "pack loose unreachable objects"
+msgstr "nicht erreichbare lose Objekte packen"
 
-#: builtin/mv.c:249
-#, c-format
-msgid "%s, source=%s, destination=%s"
-msgstr "%s, Quelle=%s, Ziel=%s"
+#: builtin/pack-objects.c:3284
+msgid "unpack unreachable objects newer than <time>"
+msgstr "nicht erreichbare Objekte entpacken, die neuer als <Zeit> sind"
 
-#: builtin/mv.c:270
-#, c-format
-msgid "Renaming %s to %s\n"
-msgstr "Benenne %s nach %s um\n"
+#: builtin/pack-objects.c:3287
+msgid "use the sparse reachability algorithm"
+msgstr "den \"sparse\" Algorithmus zur Bestimmung der Erreichbarkeit benutzen"
 
-#: builtin/mv.c:276 builtin/remote.c:712 builtin/repack.c:394
-#, c-format
-msgid "renaming '%s' failed"
-msgstr "Umbenennung von '%s' fehlgeschlagen"
+#: builtin/pack-objects.c:3289
+msgid "create thin packs"
+msgstr "dünnere Pakete erzeugen"
 
-#: builtin/name-rev.c:338
-msgid "git name-rev [<options>] <commit>..."
-msgstr "git name-rev [<Optionen>] <Commit>..."
+#: builtin/pack-objects.c:3291
+msgid "create packs suitable for shallow fetches"
+msgstr ""
+"Pakete geeignet für Abholung mit unvollständiger Historie (shallow) erzeugen"
 
-#: builtin/name-rev.c:339
-msgid "git name-rev [<options>] --all"
-msgstr "git name-rev [<Optionen>] --all"
+#: builtin/pack-objects.c:3293
+msgid "ignore packs that have companion .keep file"
+msgstr "Pakete ignorieren, die .keep Dateien haben"
 
-#: builtin/name-rev.c:340
-msgid "git name-rev [<options>] --stdin"
-msgstr "git name-rev [<Optionen>] --stdin"
+#: builtin/pack-objects.c:3295
+msgid "ignore this pack"
+msgstr "dieses Paket ignorieren"
 
-#: builtin/name-rev.c:395
-msgid "print only names (no SHA-1)"
-msgstr "nur Namen anzeigen (keine SHA-1)"
+#: builtin/pack-objects.c:3297
+msgid "pack compression level"
+msgstr "Komprimierungsgrad für Paketierung"
 
-#: builtin/name-rev.c:396
-msgid "only use tags to name the commits"
-msgstr "nur Tags verwenden, um die Commits zu benennen"
+#: builtin/pack-objects.c:3299
+msgid "do not hide commits by grafts"
+msgstr "keine künstlichen Vorgänger-Commits (\"grafts\") verbergen"
 
-#: builtin/name-rev.c:398
-msgid "only use refs matching <pattern>"
-msgstr "nur Referenzen verwenden, die <Muster> entsprechen"
+#: builtin/pack-objects.c:3301
+msgid "use a bitmap index if available to speed up counting objects"
+msgstr ""
+"Bitmap-Index (falls verfügbar) zur Optimierung der Objektzählung benutzen"
 
-#: builtin/name-rev.c:400
-msgid "ignore refs matching <pattern>"
-msgstr "ignoriere Referenzen die <Muster> entsprechen"
+#: builtin/pack-objects.c:3303
+msgid "write a bitmap index together with the pack index"
+msgstr "Bitmap-Index zusammen mit Pack-Index schreiben"
 
-#: builtin/name-rev.c:402
-msgid "list all commits reachable from all refs"
-msgstr "alle Commits auflisten, die von allen Referenzen erreichbar sind"
+#: builtin/pack-objects.c:3307
+msgid "write a bitmap index if possible"
+msgstr "Bitmap-Index schreiben, wenn möglich"
 
-#: builtin/name-rev.c:403
-msgid "read from stdin"
-msgstr "von der Standard-Eingabe lesen"
+#: builtin/pack-objects.c:3311
+msgid "handling for missing objects"
+msgstr "Behandlung für fehlende Objekte"
 
-#: builtin/name-rev.c:404
-msgid "allow to print `undefined` names (default)"
-msgstr "Ausgabe von `undefinierten` Namen erlauben (Standard)"
+#: builtin/pack-objects.c:3314
+msgid "do not pack objects in promisor packfiles"
+msgstr ""
+"keine Objekte aus Packdateien von partiell geklonten Remote-Repositories "
+"packen"
 
-#: builtin/name-rev.c:410
-msgid "dereference tags in the input (internal use)"
-msgstr "Tags in der Eingabe dereferenzieren (interne Verwendung)"
+#: builtin/pack-objects.c:3316
+msgid "respect islands during delta compression"
+msgstr "Delta-Islands bei Delta-Kompression beachten"
 
-#: builtin/notes.c:26
-msgid "git notes [--ref <notes-ref>] [list [<object>]]"
-msgstr "git notes [--ref <Notiz-Referenz>] [list [<Objekt>]]"
+#: builtin/pack-objects.c:3345
+#, c-format
+msgid "delta chain depth %d is too deep, forcing %d"
+msgstr "Tiefe für Verkettung von Unterschieden %d ist zu tief, erzwinge %d"
 
-#: builtin/notes.c:27
-msgid ""
-"git notes [--ref <notes-ref>] add [-f] [--allow-empty] [-m <msg> | -F <file> "
-"| (-c | -C) <object>] [<object>]"
-msgstr ""
-"git notes [--ref <Notiz-Referenz>] add [-f] [--allow-empty] [-m "
-"<Beschreibung> | -F <Datei> | (-c | -C) <Objekt>] [<Objekt>]"
+#: builtin/pack-objects.c:3350
+#, c-format
+msgid "pack.deltaCacheLimit is too high, forcing %d"
+msgstr "pack.deltaCacheLimit ist zu hoch, erzwinge %d"
 
-#: builtin/notes.c:28
-msgid "git notes [--ref <notes-ref>] copy [-f] <from-object> <to-object>"
+#: builtin/pack-objects.c:3404
+msgid "--max-pack-size cannot be used to build a pack for transfer"
 msgstr ""
-"git notes [--ref <Notiz-Referenz>] copy [-f] <von-Objekt> <nach-Objekt>"
+"--max-pack-size kann nicht für die Erstellung eines Pakets für eine "
+"Übertragung\n"
+"benutzt werden."
 
-#: builtin/notes.c:29
-msgid ""
-"git notes [--ref <notes-ref>] append [--allow-empty] [-m <msg> | -F <file> | "
-"(-c | -C) <object>] [<object>]"
+#: builtin/pack-objects.c:3406
+msgid "minimum pack size limit is 1 MiB"
+msgstr "Minimales Limit für die Paketgröße ist 1 MiB."
+
+#: builtin/pack-objects.c:3411
+msgid "--thin cannot be used to build an indexable pack"
 msgstr ""
-"git notes [--ref <Notiz-Referenz>] append [--allow-empty] [-m <Beschreibung> "
-"| -F <Datei> | (-c | -C) <Objekt>] [<Objekt>]"
+"--thin kann nicht benutzt werden, um ein indizierbares Paket zu erstellen."
 
-#: builtin/notes.c:30
-msgid "git notes [--ref <notes-ref>] edit [--allow-empty] [<object>]"
-msgstr "git notes [--ref <Notiz-Referenz>] edit [--allow-empty] [<Objekt>]"
+#: builtin/pack-objects.c:3414
+msgid "--keep-unreachable and --unpack-unreachable are incompatible"
+msgstr "--keep-unreachable und --unpack-unreachable sind inkompatibel"
 
-#: builtin/notes.c:31
-msgid "git notes [--ref <notes-ref>] show [<object>]"
-msgstr "git notes [--ref <Notiz-Referenz>] show [<Objekt>]"
+#: builtin/pack-objects.c:3420
+msgid "cannot use --filter without --stdout"
+msgstr "Kann --filter nicht ohne --stdout benutzen."
 
-#: builtin/notes.c:32
-msgid ""
-"git notes [--ref <notes-ref>] merge [-v | -q] [-s <strategy>] <notes-ref>"
+#: builtin/pack-objects.c:3481
+msgid "Enumerating objects"
+msgstr "Objekte aufzählen"
+
+#: builtin/pack-objects.c:3511
+#, c-format
+msgid "Total %<PRIu32> (delta %<PRIu32>), reused %<PRIu32> (delta %<PRIu32>)"
 msgstr ""
-"git notes [--ref <Notiz-Referenz>] merge [-v | -q] [-s <Strategie>] <Notiz-"
-"Referenz>"
+"Gesamt %<PRIu32> (Delta %<PRIu32>), Wiederverwendet %<PRIu32> (Delta "
+"%<PRIu32>)"
 
-#: builtin/notes.c:33
-msgid "git notes merge --commit [-v | -q]"
-msgstr "git notes merge --commit [-v | -q]"
+#: builtin/pack-refs.c:8
+msgid "git pack-refs [<options>]"
+msgstr "git pack-refs [<Optionen>]"
 
-#: builtin/notes.c:34
-msgid "git notes merge --abort [-v | -q]"
-msgstr "git notes merge --abort [-v | -q]"
+#: builtin/pack-refs.c:16
+msgid "pack everything"
+msgstr "alles packen"
 
-#: builtin/notes.c:35
-msgid "git notes [--ref <notes-ref>] remove [<object>...]"
-msgstr "git notes [--ref <Notiz-Referenz>] remove [<Objekt>...]"
+#: builtin/pack-refs.c:17
+msgid "prune loose refs (default)"
+msgstr "lose Referenzen entfernen (Standard)"
 
-#: builtin/notes.c:36
-msgid "git notes [--ref <notes-ref>] prune [-n] [-v]"
-msgstr "git notes [--ref <Notiz-Referenz>] prune [-n] [-v]"
+#: builtin/prune-packed.c:9
+msgid "git prune-packed [-n | --dry-run] [-q | --quiet]"
+msgstr "git prune-packed [-n | --dry-run] [-q | --quiet]"
 
-#: builtin/notes.c:37
-msgid "git notes [--ref <notes-ref>] get-ref"
-msgstr "git notes [--ref <Notiz-Referenz>] get-ref"
+#: builtin/prune-packed.c:42
+msgid "Removing duplicate objects"
+msgstr "Lösche doppelte Objekte"
 
-#: builtin/notes.c:42
-msgid "git notes [list [<object>]]"
-msgstr "git notes [list [<Objekt>]]"
+#: builtin/prune.c:12
+msgid "git prune [-n] [-v] [--progress] [--expire <time>] [--] [<head>...]"
+msgstr "git prune [-n] [-v] [--progress] [--expire <Zeit>] [--] [<Branch>...]"
+
+#: builtin/prune.c:131
+msgid "report pruned objects"
+msgstr "gelöschte Objekte melden"
 
-#: builtin/notes.c:47
-msgid "git notes add [<options>] [<object>]"
-msgstr "git notes add [<Optionen>] [<Objekt>]"
+#: builtin/prune.c:134
+msgid "expire objects older than <time>"
+msgstr "Objekte älter als <Zeit> verfallen lassen"
 
-#: builtin/notes.c:52
-msgid "git notes copy [<options>] <from-object> <to-object>"
-msgstr "git notes copy [<Optionen>] <von-Objekt> <nach-Objekt>"
+#: builtin/prune.c:136
+msgid "limit traversal to objects outside promisor packfiles"
+msgstr ""
+"Traversierung auf Objekte außerhalb von Packdateien aus partiell geklonten "
+"Remote-Repositories einschränken"
 
-#: builtin/notes.c:53
-msgid "git notes copy --stdin [<from-object> <to-object>]..."
-msgstr "git notes copy --stdin [<von-Objekt> <nach-Objekt>]..."
+#: builtin/prune.c:150
+msgid "cannot prune in a precious-objects repo"
+msgstr "kann \"prune\" in precious-objects Repository nicht ausführen"
 
-#: builtin/notes.c:58
-msgid "git notes append [<options>] [<object>]"
-msgstr "git notes append [<Optionen>] [<Objekt>]"
+#: builtin/pull.c:66 builtin/pull.c:68
+#, c-format
+msgid "Invalid value for %s: %s"
+msgstr "Ungültiger Wert für %s: %s"
 
-#: builtin/notes.c:63
-msgid "git notes edit [<object>]"
-msgstr "git notes edit [<Objekt>]"
+#: builtin/pull.c:88
+msgid "git pull [<options>] [<repository> [<refspec>...]]"
+msgstr "git pull [<Optionen>] [<Repository> [<Refspec>...]]"
 
-#: builtin/notes.c:68
-msgid "git notes show [<object>]"
-msgstr "git notes show [<Objekt>]"
+#: builtin/pull.c:142
+msgid "control for recursive fetching of submodules"
+msgstr "rekursive Anforderungen von Submodulen kontrollieren"
 
-#: builtin/notes.c:73
-msgid "git notes merge [<options>] <notes-ref>"
-msgstr "git notes merge [<Optionen>] <Notiz-Referenz>"
+#: builtin/pull.c:146
+msgid "Options related to merging"
+msgstr "Optionen bezogen auf Merge"
 
-#: builtin/notes.c:74
-msgid "git notes merge --commit [<options>]"
-msgstr "git notes merge --commit [<Optionen>]"
+#: builtin/pull.c:149
+msgid "incorporate changes by rebasing rather than merging"
+msgstr "Integration von Änderungen durch Rebase statt Merge"
 
-#: builtin/notes.c:75
-msgid "git notes merge --abort [<options>]"
-msgstr "git notes merge --abort [<Optionen>]"
+#: builtin/pull.c:177 builtin/rebase.c:467 builtin/revert.c:126
+msgid "allow fast-forward"
+msgstr "Vorspulen erlauben"
 
-#: builtin/notes.c:80
-msgid "git notes remove [<object>]"
-msgstr "git notes remove [<Objekt>]"
+#: builtin/pull.c:186
+msgid "automatically stash/stash pop before and after rebase"
+msgstr "automatischer Stash/Stash-Pop vor und nach eines Rebase"
 
-#: builtin/notes.c:85
-msgid "git notes prune [<options>]"
-msgstr "git notes prune [<Optionen>]"
+#: builtin/pull.c:202
+msgid "Options related to fetching"
+msgstr "Optionen bezogen auf Fetch"
 
-#: builtin/notes.c:90
-msgid "git notes get-ref"
-msgstr "git notes get-ref"
+#: builtin/pull.c:212
+msgid "force overwrite of local branch"
+msgstr "das Überschreiben von lokalen Branches erzwingen"
 
-#: builtin/notes.c:95
-msgid "Write/edit the notes for the following object:"
-msgstr "Schreiben/Bearbeiten der Notizen für das folgende Objekt:"
+#: builtin/pull.c:220
+msgid "number of submodules pulled in parallel"
+msgstr "Anzahl der parallel mit 'pull' zu verarbeitenden Submodule"
 
-#: builtin/notes.c:148
+#: builtin/pull.c:320
 #, c-format
-msgid "unable to start 'show' for object '%s'"
-msgstr "konnte 'show' für Objekt '%s' nicht starten"
+msgid "Invalid value for pull.ff: %s"
+msgstr "Ungültiger Wert für pull.ff: %s"
 
-#: builtin/notes.c:152
-msgid "could not read 'show' output"
-msgstr "Konnte Ausgabe von 'show' nicht lesen."
+#: builtin/pull.c:437
+msgid ""
+"There is no candidate for rebasing against among the refs that you just "
+"fetched."
+msgstr ""
+"Es gibt keinen Kandidaten für Rebase innerhalb der Referenzen, die eben "
+"angefordert wurden."
+
+#: builtin/pull.c:439
+msgid ""
+"There are no candidates for merging among the refs that you just fetched."
+msgstr ""
+"Es gibt keine Kandidaten für Merge innerhalb der Referenzen, die eben "
+"angefordert wurden."
+
+#: builtin/pull.c:440
+msgid ""
+"Generally this means that you provided a wildcard refspec which had no\n"
+"matches on the remote end."
+msgstr ""
+"Im Allgemeinen bedeutet das, dass Sie einen Refspec mit Wildcards angegeben\n"
+"haben, der auf der Gegenseite mit keinen Referenzen übereinstimmt."
 
-#: builtin/notes.c:160
+#: builtin/pull.c:443
 #, c-format
-msgid "failed to finish 'show' for object '%s'"
-msgstr "konnte 'show' für Objekt '%s' nicht abschließen"
+msgid ""
+"You asked to pull from the remote '%s', but did not specify\n"
+"a branch. Because this is not the default configured remote\n"
+"for your current branch, you must specify a branch on the command line."
+msgstr ""
+"Sie führten \"pull\" von Remote-Repository '%s' aus, ohne einen\n"
+"Branch anzugeben. Da das nicht das konfigurierte Standard-Remote-\n"
+"Repository für den aktuellen Branch ist, müssen Sie einen Branch auf\n"
+"der Befehlszeile angeben."
 
-#: builtin/notes.c:195
-msgid "please supply the note contents using either -m or -F option"
+#: builtin/pull.c:448 builtin/rebase.c:1375 git-parse-remote.sh:73
+msgid "You are not currently on a branch."
+msgstr "Im Moment auf keinem Branch."
+
+#: builtin/pull.c:450 builtin/pull.c:465 git-parse-remote.sh:79
+msgid "Please specify which branch you want to rebase against."
 msgstr ""
-"Bitte liefern Sie die Notiz-Inhalte unter Verwendung der Option -m oder -F."
+"Bitte geben Sie den Branch an, gegen welchen Sie \"rebase\" ausführen "
+"möchten."
 
-#: builtin/notes.c:204
-msgid "unable to write note object"
-msgstr "Konnte Notiz-Objekt nicht schreiben"
+#: builtin/pull.c:452 builtin/pull.c:467 git-parse-remote.sh:82
+msgid "Please specify which branch you want to merge with."
+msgstr "Bitte geben Sie den Branch an, welchen Sie zusammenführen möchten."
 
-#: builtin/notes.c:206
-#, c-format
-msgid "the note contents have been left in %s"
-msgstr "Die Notiz-Inhalte wurden in %s belassen."
+#: builtin/pull.c:453 builtin/pull.c:468
+msgid "See git-pull(1) for details."
+msgstr "Siehe git-pull(1) für weitere Details."
 
-#: builtin/notes.c:234 builtin/tag.c:506
-#, c-format
-msgid "cannot read '%s'"
-msgstr "kann '%s' nicht lesen"
+#: builtin/pull.c:455 builtin/pull.c:461 builtin/pull.c:470
+#: builtin/rebase.c:1381 git-parse-remote.sh:64
+msgid "<remote>"
+msgstr "<Remote-Repository>"
 
-#: builtin/notes.c:236 builtin/tag.c:509
-#, c-format
-msgid "could not open or read '%s'"
-msgstr "konnte '%s' nicht öffnen oder lesen"
+#: builtin/pull.c:455 builtin/pull.c:470 builtin/pull.c:475
+#: git-parse-remote.sh:65
+msgid "<branch>"
+msgstr "<Branch>"
 
-#: builtin/notes.c:255 builtin/notes.c:306 builtin/notes.c:308
-#: builtin/notes.c:376 builtin/notes.c:431 builtin/notes.c:517
-#: builtin/notes.c:522 builtin/notes.c:600 builtin/notes.c:662
-#, c-format
-msgid "failed to resolve '%s' as a valid ref."
-msgstr "Konnte '%s' nicht als gültige Referenz auflösen."
+#: builtin/pull.c:463 builtin/rebase.c:1373 git-parse-remote.sh:75
+msgid "There is no tracking information for the current branch."
+msgstr "Es gibt keine Tracking-Informationen für den aktuellen Branch."
 
-#: builtin/notes.c:258
-#, c-format
-msgid "failed to read object '%s'."
-msgstr "Fehler beim Lesen des Objektes '%s'."
+#: builtin/pull.c:472 git-parse-remote.sh:95
+msgid ""
+"If you wish to set tracking information for this branch you can do so with:"
+msgstr ""
+"Wenn Sie Tracking-Informationen für diesen Branch setzen möchten, können "
+"Sie\n"
+"dies tun mit:"
 
-#: builtin/notes.c:262
+#: builtin/pull.c:477
 #, c-format
-msgid "cannot read note data from non-blob object '%s'."
-msgstr "Kann Notiz-Daten nicht von Nicht-Blob Objekt '%s' lesen."
+msgid ""
+"Your configuration specifies to merge with the ref '%s'\n"
+"from the remote, but no such ref was fetched."
+msgstr ""
+"Ihre Konfiguration gibt an, den Merge mit Referenz '%s'\n"
+"des Remote-Repositories durchzuführen, aber diese Referenz\n"
+"wurde nicht angefordert."
 
-#: builtin/notes.c:302
+#: builtin/pull.c:587
 #, c-format
-msgid "malformed input line: '%s'."
-msgstr "Fehlerhafte Eingabezeile: '%s'."
+msgid "unable to access commit %s"
+msgstr "Konnte nicht auf Commit '%s' zugreifen."
 
-#: builtin/notes.c:317
-#, c-format
-msgid "failed to copy notes from '%s' to '%s'"
-msgstr "Fehler beim Kopieren der Notizen von '%s' nach '%s'"
+#: builtin/pull.c:867
+msgid "ignoring --verify-signatures for rebase"
+msgstr "Ignoriere --verify-signatures für Rebase"
 
-#. TRANSLATORS: the first %s will be replaced by a git
-#. notes command: 'add', 'merge', 'remove', etc.
-#.
-#: builtin/notes.c:349
-#, c-format
-msgid "refusing to %s notes in %s (outside of refs/notes/)"
+#: builtin/pull.c:922
+msgid "--[no-]autostash option is only valid with --rebase."
+msgstr "--[no-]autostash ist nur mit --rebase zulässig."
+
+#: builtin/pull.c:930
+msgid "Updating an unborn branch with changes added to the index."
 msgstr ""
-"Ausführung von %s auf Notizen in %s (außerhalb von refs/notes/) "
-"zurückgewiesen"
+"Aktualisiere einen ungeborenen Branch mit Änderungen, die zum Commit "
+"vorgemerkt sind."
 
-#: builtin/notes.c:369 builtin/notes.c:424 builtin/notes.c:500
-#: builtin/notes.c:512 builtin/notes.c:588 builtin/notes.c:655
-#: builtin/notes.c:805 builtin/notes.c:952 builtin/notes.c:973
-msgid "too many parameters"
-msgstr "zu viele Parameter"
+#: builtin/pull.c:934
+msgid "pull with rebase"
+msgstr "Pull mit Rebase"
+
+#: builtin/pull.c:935
+msgid "please commit or stash them."
+msgstr "Bitte committen Sie die Änderungen oder benutzen Sie \"stash\"."
 
-#: builtin/notes.c:382 builtin/notes.c:668
+#: builtin/pull.c:960
 #, c-format
-msgid "no note found for object %s."
-msgstr "Keine Notiz für Objekt %s gefunden."
+msgid ""
+"fetch updated the current branch head.\n"
+"fast-forwarding your working tree from\n"
+"commit %s."
+msgstr ""
+"\"fetch\" aktualisierte die Spitze des aktuellen Branches.\n"
+"Spule Ihr Arbeitsverzeichnis von Commit %s vor."
 
-#: builtin/notes.c:403 builtin/notes.c:566
-msgid "note contents as a string"
-msgstr "Notizinhalte als Zeichenkette"
+#: builtin/pull.c:966
+#, c-format
+msgid ""
+"Cannot fast-forward your working tree.\n"
+"After making sure that you saved anything precious from\n"
+"$ git diff %s\n"
+"output, run\n"
+"$ git reset --hard\n"
+"to recover."
+msgstr ""
+"Kann Arbeitsverzeichnis nicht vorspulen.\n"
+"Nachdem Sie sichergestellt haben, alles Schützenswerte der Ausgabe von\n"
+"$ git diff %s\n"
+"gespeichert zu haben. Führen Sie\n"
+"$ git reset --hard\n"
+"zur Wiederherstellung aus."
 
-#: builtin/notes.c:406 builtin/notes.c:569
-msgid "note contents in a file"
-msgstr "Notizinhalte in einer Datei"
+#: builtin/pull.c:981
+msgid "Cannot merge multiple branches into empty head."
+msgstr "Kann nicht mehrere Branches in einen leeren Branch zusammenführen."
 
-#: builtin/notes.c:409 builtin/notes.c:572
-msgid "reuse and edit specified note object"
-msgstr "Wiederverwendung und Bearbeitung des angegebenen Notiz-Objektes"
+#: builtin/pull.c:985
+msgid "Cannot rebase onto multiple branches."
+msgstr "Kann Rebase nicht auf mehrere Branches ausführen."
 
-#: builtin/notes.c:412 builtin/notes.c:575
-msgid "reuse specified note object"
-msgstr "Wiederverwendung des angegebenen Notiz-Objektes"
+#: builtin/pull.c:992
+msgid "cannot rebase with locally recorded submodule modifications"
+msgstr ""
+"Kann Rebase nicht mit lokal aufgezeichneten Änderungen in Submodulen "
+"ausführen."
 
-#: builtin/notes.c:415 builtin/notes.c:578
-msgid "allow storing empty note"
-msgstr "Speichern leerer Notiz erlauben"
+#: builtin/push.c:19
+msgid "git push [<options>] [<repository> [<refspec>...]]"
+msgstr "git push [<Optionen>] [<Repository> [<Refspec>...]]"
 
-#: builtin/notes.c:416 builtin/notes.c:487
-msgid "replace existing notes"
-msgstr "existierende Notizen ersetzen"
+#: builtin/push.c:112
+msgid "tag shorthand without <tag>"
+msgstr "Kurzschrift für Tag ohne <Tag>"
 
-#: builtin/notes.c:441
-#, c-format
+#: builtin/push.c:122
+msgid "--delete only accepts plain target ref names"
+msgstr "Die Option --delete akzeptiert nur reine Referenznamen als Ziel."
+
+#: builtin/push.c:168
 msgid ""
-"Cannot add notes. Found existing notes for object %s. Use '-f' to overwrite "
-"existing notes"
+"\n"
+"To choose either option permanently, see push.default in 'git help config'."
 msgstr ""
-"Konnte Notizen nicht hinzufügen. Existierende Notizen für Objekt %s "
-"gefunden. Verwenden Sie '-f', um die existierenden Notizen zu überschreiben."
+"\n"
+"Um eine Variante permanent zu verwenden, siehe push.default in 'git help "
+"config'."
 
-#: builtin/notes.c:456 builtin/notes.c:535
+#: builtin/push.c:171
 #, c-format
-msgid "Overwriting existing notes for object %s\n"
-msgstr "Überschreibe existierende Notizen für Objekt %s\n"
+msgid ""
+"The upstream branch of your current branch does not match\n"
+"the name of your current branch.  To push to the upstream branch\n"
+"on the remote, use\n"
+"\n"
+"    git push %s HEAD:%s\n"
+"\n"
+"To push to the branch of the same name on the remote, use\n"
+"\n"
+"    git push %s HEAD\n"
+"%s"
+msgstr ""
+"Der Name des Upstream-Branches stimmt nicht mit dem Namen Ihres\n"
+"aktuellen Branches überein. Um auf den Upstream-Branch in dem Remote-\n"
+"Repository zu versenden, benutzen Sie:\n"
+"\n"
+"    git push %s HEAD:%s\n"
+"\n"
+"Um auf den Branch mit demselben Namen im Remote-Repository zu versenden,\n"
+"benutzen Sie:\n"
+"\n"
+"    git push %s HEAD\n"
+"%s"
 
-#: builtin/notes.c:467 builtin/notes.c:627 builtin/notes.c:892
+#: builtin/push.c:186
 #, c-format
-msgid "Removing note for object %s\n"
-msgstr "Entferne Notiz für Objekt %s\n"
-
-#: builtin/notes.c:488
-msgid "read objects from stdin"
-msgstr "Objekte von der Standard-Eingabe lesen"
-
-#: builtin/notes.c:490
-msgid "load rewriting config for <command> (implies --stdin)"
+msgid ""
+"You are not currently on a branch.\n"
+"To push the history leading to the current (detached HEAD)\n"
+"state now, use\n"
+"\n"
+"    git push %s HEAD:<name-of-remote-branch>\n"
 msgstr ""
-"Konfiguration für <Befehl> zum Umschreiben von Commits laden (impliziert --"
-"stdin)"
-
-#: builtin/notes.c:508
-msgid "too few parameters"
-msgstr "zu wenig Parameter"
+"Sie befinden sich im Moment auf keinem Branch.\n"
+"Um die Historie, führend zum aktuellen (losgelöster HEAD)\n"
+"Status zu versenden, benutzen Sie\n"
+"\n"
+"    git push %s HEAD:<Name-des-Remote-Branches>\n"
 
-#: builtin/notes.c:529
+#: builtin/push.c:200
 #, c-format
 msgid ""
-"Cannot copy notes. Found existing notes for object %s. Use '-f' to overwrite "
-"existing notes"
+"The current branch %s has no upstream branch.\n"
+"To push the current branch and set the remote as upstream, use\n"
+"\n"
+"    git push --set-upstream %s %s\n"
 msgstr ""
-"Kann Notizen nicht kopieren. Existierende Notizen für Objekt %s gefunden. "
-"Verwenden Sie '-f', um die existierenden Notizen zu überschreiben."
+"Der aktuelle Branch %s hat keinen Upstream-Branch.\n"
+"Um den aktuellen Branch zu versenden und den Remote-Branch\n"
+"als Upstream-Branch zu setzen, benutzen Sie\n"
+"\n"
+"    git push --set-upstream %s %s\n"
 
-#: builtin/notes.c:541
+#: builtin/push.c:208
 #, c-format
-msgid "missing notes on source object %s. Cannot copy."
-msgstr "Keine Notizen für Quell-Objekt %s. Kopie nicht möglich."
+msgid "The current branch %s has multiple upstream branches, refusing to push."
+msgstr ""
+"Der aktuelle Branch %s hat mehrere Upstream-Branches, \"push\" verweigert."
 
-#: builtin/notes.c:593
+#: builtin/push.c:211
 #, c-format
 msgid ""
-"The -m/-F/-c/-C options have been deprecated for the 'edit' subcommand.\n"
-"Please use 'git notes add -f -m/-F/-c/-C' instead.\n"
+"You are pushing to remote '%s', which is not the upstream of\n"
+"your current branch '%s', without telling me what to push\n"
+"to update which remote branch."
 msgstr ""
-"Die Optionen -m/-F/-c/-C sind für den Unterbefehl 'edit' veraltet.\n"
-"Bitte benutzen Sie stattdessen 'git notes add -f -m/-F/-c/-C'.\n"
-
-#: builtin/notes.c:688
-msgid "failed to delete ref NOTES_MERGE_PARTIAL"
-msgstr "Fehler beim Löschen der Referenz NOTES_MERGE_PARTIAL"
-
-#: builtin/notes.c:690
-msgid "failed to delete ref NOTES_MERGE_REF"
-msgstr "Fehler beim Löschen der Referenz NOTES_MERGE_REF"
-
-#: builtin/notes.c:692
-msgid "failed to remove 'git notes merge' worktree"
-msgstr "Fehler beim Löschen des Arbeitsverzeichnisses von 'git notes merge'."
-
-#: builtin/notes.c:712
-msgid "failed to read ref NOTES_MERGE_PARTIAL"
-msgstr "Fehler beim Lesen der Referenz NOTES_MERGE_PARTIAL"
-
-#: builtin/notes.c:714
-msgid "could not find commit from NOTES_MERGE_PARTIAL."
-msgstr "Konnte Commit von NOTES_MERGE_PARTIAL nicht finden."
-
-#: builtin/notes.c:716
-msgid "could not parse commit from NOTES_MERGE_PARTIAL."
-msgstr "Konnte Commit von NOTES_MERGE_PARTIAL nicht parsen."
-
-#: builtin/notes.c:729
-msgid "failed to resolve NOTES_MERGE_REF"
-msgstr "Fehler beim Auflösen von NOTES_MERGE_REF"
-
-#: builtin/notes.c:732
-msgid "failed to finalize notes merge"
-msgstr "Fehler beim Abschließen der Zusammenführung der Notizen."
-
-#: builtin/notes.c:758
-#, c-format
-msgid "unknown notes merge strategy %s"
-msgstr "unbekannte Merge-Strategie '%s' für Notizen"
-
-#: builtin/notes.c:774
-msgid "General options"
-msgstr "Allgemeine Optionen"
-
-#: builtin/notes.c:776
-msgid "Merge options"
-msgstr "Merge-Optionen"
+"Sie versenden nach '%s', welches kein Upstream-Repository Ihres aktuellen\n"
+"Branches '%s' ist, ohne anzugeben, was versendet werden soll, um welchen\n"
+"Remote-Branch zu aktualisieren."
 
-#: builtin/notes.c:778
+#: builtin/push.c:270
 msgid ""
-"resolve notes conflicts using the given strategy (manual/ours/theirs/union/"
-"cat_sort_uniq)"
+"You didn't specify any refspecs to push, and push.default is \"nothing\"."
 msgstr ""
-"löst Konflikte bei Notizen mit der angegebenen Strategie auf (manual/ours/"
-"theirs/union/cat_sort_uniq)"
-
-#: builtin/notes.c:780
-msgid "Committing unmerged notes"
-msgstr "nicht zusammengeführte Notizen eintragen"
+"Sie haben keine Refspec für \"push\" angegeben, und push.default ist "
+"\"nothing\"."
 
-#: builtin/notes.c:782
-msgid "finalize notes merge by committing unmerged notes"
+#: builtin/push.c:277
+msgid ""
+"Updates were rejected because the tip of your current branch is behind\n"
+"its remote counterpart. Integrate the remote changes (e.g.\n"
+"'git pull ...') before pushing again.\n"
+"See the 'Note about fast-forwards' in 'git push --help' for details."
 msgstr ""
-"Merge von Notizen abschließen, in dem nicht zusammengeführte Notizen "
-"committet werden"
+"Aktualisierungen wurden zurückgewiesen, weil die Spitze Ihres aktuellen\n"
+"Branches hinter seinem externen Gegenstück zurückgefallen ist. Führen Sie\n"
+"die externen Änderungen zusammen (z. B. 'git pull ...') bevor Sie \"push\"\n"
+"erneut ausführen.\n"
+"Siehe auch die Sektion 'Note about fast-forwards' in 'git push --help'\n"
+"für weitere Details."
 
-#: builtin/notes.c:784
-msgid "Aborting notes merge resolution"
-msgstr "Konfliktauflösung beim Merge von Notizen abbrechen"
+#: builtin/push.c:283
+msgid ""
+"Updates were rejected because a pushed branch tip is behind its remote\n"
+"counterpart. Check out this branch and integrate the remote changes\n"
+"(e.g. 'git pull ...') before pushing again.\n"
+"See the 'Note about fast-forwards' in 'git push --help' for details."
+msgstr ""
+"Aktualisierungen wurden zurückgewiesen, weil die Spitze eines versendeten\n"
+"Branches hinter seinem externen Gegenstück zurückgefallen ist. Checken Sie\n"
+"diesen Branch aus und führen Sie die externen Änderungen zusammen\n"
+"(z. B. 'git pull ...') bevor Sie erneut \"push\" ausführen.\n"
+"Siehe auch die Sektion 'Note about fast-forwards' in 'git push --help'\n"
+"für weitere Details."
 
-#: builtin/notes.c:786
-msgid "abort notes merge"
-msgstr "Merge von Notizen abbrechen"
+#: builtin/push.c:289
+msgid ""
+"Updates were rejected because the remote contains work that you do\n"
+"not have locally. This is usually caused by another repository pushing\n"
+"to the same ref. You may want to first integrate the remote changes\n"
+"(e.g., 'git pull ...') before pushing again.\n"
+"See the 'Note about fast-forwards' in 'git push --help' for details."
+msgstr ""
+"Aktualisierungen wurden zurückgewiesen, weil das Remote-Repository Commits "
+"enthält,\n"
+"die lokal nicht vorhanden sind. Das wird üblicherweise durch einen \"push\" "
+"von\n"
+"Commits auf dieselbe Referenz von einem anderen Repository aus verursacht.\n"
+"Vielleicht müssen Sie die externen Änderungen zusammenführen (z. B. 'git "
+"pull ...')\n"
+"bevor Sie erneut \"push\" ausführen.\n"
+"Siehe auch die Sektion 'Note about fast-forwards' in 'git push --help'\n"
+"für weitere Details."
 
-#: builtin/notes.c:797
-msgid "cannot mix --commit, --abort or -s/--strategy"
-msgstr "Kann --commit, --abort oder -s/--strategy nicht kombinieren."
+#: builtin/push.c:296
+msgid "Updates were rejected because the tag already exists in the remote."
+msgstr ""
+"Aktualisierungen wurden zurückgewiesen, weil das Tag bereits\n"
+"im Remote-Repository existiert."
 
-#: builtin/notes.c:802
-msgid "must specify a notes ref to merge"
-msgstr "Sie müssen eine Notiz-Referenz zum Mergen angeben."
+#: builtin/push.c:299
+msgid ""
+"You cannot update a remote ref that points at a non-commit object,\n"
+"or update a remote ref to make it point at a non-commit object,\n"
+"without using the '--force' option.\n"
+msgstr ""
+"Sie können keine Remote-Referenz aktualisieren, die auf ein Objekt zeigt,\n"
+"das kein Commit ist, oder es auf ein solches Objekt zeigen lassen, ohne\n"
+"die Option '--force' zu verwenden.\n"
 
-#: builtin/notes.c:826
+#: builtin/push.c:360
 #, c-format
-msgid "unknown -s/--strategy: %s"
-msgstr "Unbekannter Wert für -s/--strategy: %s"
+msgid "Pushing to %s\n"
+msgstr "Versende nach %s\n"
 
-#: builtin/notes.c:863
+#: builtin/push.c:367
 #, c-format
-msgid "a notes merge into %s is already in-progress at %s"
-msgstr "Ein Merge von Notizen nach %s ist bereits im Gange bei %s"
+msgid "failed to push some refs to '%s'"
+msgstr "Fehler beim Versenden einiger Referenzen nach '%s'"
 
-#: builtin/notes.c:866
-#, c-format
-msgid "failed to store link to current notes ref (%s)"
-msgstr ""
-"Fehler beim Speichern der Verknüpfung zur aktuellen Notes-Referenz (%s)"
+#: builtin/push.c:542
+msgid "repository"
+msgstr "Repository"
 
-#: builtin/notes.c:868
-#, c-format
-msgid ""
-"Automatic notes merge failed. Fix conflicts in %s and commit the result with "
-"'git notes merge --commit', or abort the merge with 'git notes merge --"
-"abort'.\n"
-msgstr ""
-"Automatisches Zusammenführen der Notizen fehlgeschlagen. Beheben Sie die\n"
-"Konflikte in %s und committen Sie das Ergebnis mit 'git notes merge --"
-"commit',\n"
-"oder brechen Sie den Merge mit 'git notes merge --abort' ab.\n"
+#: builtin/push.c:543 builtin/send-pack.c:164
+msgid "push all refs"
+msgstr "alle Referenzen versenden"
 
-#: builtin/notes.c:890
-#, c-format
-msgid "Object %s has no note\n"
-msgstr "Objekt %s hat keine Notiz\n"
+#: builtin/push.c:544 builtin/send-pack.c:166
+msgid "mirror all refs"
+msgstr "alle Referenzen spiegeln"
 
-#: builtin/notes.c:902
-msgid "attempt to remove non-existent note is not an error"
-msgstr "der Versuch, eine nicht existierende Notiz zu löschen, ist kein Fehler"
+#: builtin/push.c:546
+msgid "delete refs"
+msgstr "Referenzen löschen"
 
-#: builtin/notes.c:905
-msgid "read object names from the standard input"
-msgstr "Objektnamen von der Standard-Eingabe lesen"
+#: builtin/push.c:547
+msgid "push tags (can't be used with --all or --mirror)"
+msgstr "Tags versenden (kann nicht mit --all oder --mirror verwendet werden)"
 
-#: builtin/notes.c:943 builtin/prune.c:106 builtin/worktree.c:160
-msgid "do not remove, show only"
-msgstr "nicht löschen, nur anzeigen"
+#: builtin/push.c:550 builtin/send-pack.c:167
+msgid "force updates"
+msgstr "Aktualisierung erzwingen"
 
-#: builtin/notes.c:944
-msgid "report pruned notes"
-msgstr "gelöschte Notizen melden"
+#: builtin/push.c:552 builtin/send-pack.c:181
+msgid "<refname>:<expect>"
+msgstr "<Referenzname>:<Erwartungswert>"
 
-#: builtin/notes.c:986
-msgid "notes-ref"
-msgstr "Notiz-Referenz"
+#: builtin/push.c:553 builtin/send-pack.c:182
+msgid "require old value of ref to be at this value"
+msgstr "Referenz muss sich auf dem angegebenen Wert befinden"
 
-#: builtin/notes.c:987
-msgid "use notes from <notes-ref>"
-msgstr "Notizen von <Notiz-Referenz> verwenden"
+#: builtin/push.c:556
+msgid "control recursive pushing of submodules"
+msgstr "rekursiven \"push\" von Submodulen steuern"
 
-#: builtin/notes.c:1022
-#, c-format
-msgid "unknown subcommand: %s"
-msgstr "Unbekannter Unterbefehl: %s"
+#: builtin/push.c:558 builtin/send-pack.c:175
+msgid "use thin pack"
+msgstr "kleinere Pakete verwenden"
 
-#: builtin/pack-objects.c:33
-msgid ""
-"git pack-objects --stdout [<options>...] [< <ref-list> | < <object-list>]"
-msgstr ""
-"git pack-objects --stdout [<Optionen>...] [< <Referenzliste> | < "
-"<Objektliste>]"
+#: builtin/push.c:559 builtin/push.c:560 builtin/send-pack.c:161
+#: builtin/send-pack.c:162
+msgid "receive pack program"
+msgstr "'receive pack' Programm"
 
-#: builtin/pack-objects.c:34
-msgid ""
-"git pack-objects [<options>...] <base-name> [< <ref-list> | < <object-list>]"
-msgstr ""
-"git pack-objects [<Optionen>...] <Basis-Name> [< <Referenzliste> | < "
-"<Objektliste>]"
+#: builtin/push.c:561
+msgid "set upstream for git pull/status"
+msgstr "Upstream für \"git pull/status\" setzen"
 
-#: builtin/pack-objects.c:195 builtin/pack-objects.c:198
-#, c-format
-msgid "deflate error (%d)"
-msgstr "Fehler beim Komprimieren (%d)"
+#: builtin/push.c:564
+msgid "prune locally removed refs"
+msgstr "lokal gelöschte Referenzen entfernen"
 
-#: builtin/pack-objects.c:791
-msgid "disabling bitmap writing, packs are split due to pack.packSizeLimit"
-msgstr ""
-"Deaktiviere Schreiben der Bitmap, Pakete wurden durch pack.packSizeLimit\n"
-"aufgetrennt."
+#: builtin/push.c:566
+msgid "bypass pre-push hook"
+msgstr "\"pre-push hook\" umgehen"
 
-#: builtin/pack-objects.c:804
-msgid "Writing objects"
-msgstr "Schreibe Objekte"
+#: builtin/push.c:567
+msgid "push missing but relevant tags"
+msgstr "fehlende, aber relevante Tags versenden"
+
+#: builtin/push.c:570 builtin/send-pack.c:169
+msgid "GPG sign the push"
+msgstr "signiert \"push\" mit GPG"
 
-#: builtin/pack-objects.c:1084
-msgid "disabling bitmap writing, as some objects are not being packed"
-msgstr ""
-"Deaktiviere Schreiben der Bitmap, da einige Objekte nicht in eine Pack-"
-"Datei\n"
-"geschrieben wurden."
+#: builtin/push.c:572 builtin/send-pack.c:176
+msgid "request atomic transaction on remote side"
+msgstr "Referenzen atomar versenden"
 
-#: builtin/pack-objects.c:2454
-msgid "Compressing objects"
-msgstr "Komprimiere Objekte"
+#: builtin/push.c:590
+msgid "--delete is incompatible with --all, --mirror and --tags"
+msgstr "Die Option --delete ist inkompatibel mit --all, --mirror und --tags."
 
-#: builtin/pack-objects.c:2625
-msgid "invalid value for --missing"
-msgstr "Ungültiger Wert für --missing."
+#: builtin/push.c:592
+msgid "--delete doesn't make sense without any refs"
+msgstr "Die Option --delete kann nur mit Referenzen verwendet werden."
 
-#: builtin/pack-objects.c:2928
+#: builtin/push.c:612
 #, c-format
-msgid "unsupported index version %s"
-msgstr "Nicht unterstützte Index-Version %s"
+msgid "bad repository '%s'"
+msgstr "ungültiges Repository '%s'"
 
-#: builtin/pack-objects.c:2932
-#, c-format
-msgid "bad index version '%s'"
-msgstr "Ungültige Index-Version '%s'"
+#: builtin/push.c:613
+msgid ""
+"No configured push destination.\n"
+"Either specify the URL from the command-line or configure a remote "
+"repository using\n"
+"\n"
+"    git remote add <name> <url>\n"
+"\n"
+"and then push using the remote name\n"
+"\n"
+"    git push <name>\n"
+msgstr ""
+"Kein Ziel für \"push\" konfiguriert.\n"
+"Entweder spezifizieren Sie die URL von der Befehlszeile oder konfigurieren "
+"ein Remote-Repository unter Benutzung von\n"
+"\n"
+"    git remote add <Name> <URL>\n"
+"\n"
+"und führen \"push\" dann unter Benutzung dieses Namens aus\n"
+"\n"
+"    git push <Name>\n"
 
-#: builtin/pack-objects.c:2962
-msgid "do not show progress meter"
-msgstr "keine Fortschrittsanzeige anzeigen"
+#: builtin/push.c:628
+msgid "--all and --tags are incompatible"
+msgstr "Die Optionen --all und --tags sind inkompatibel."
 
-#: builtin/pack-objects.c:2964
-msgid "show progress meter"
-msgstr "Fortschrittsanzeige anzeigen"
+#: builtin/push.c:630
+msgid "--all can't be combined with refspecs"
+msgstr "Die Option --all kann nicht mit Refspecs kombiniert werden."
 
-#: builtin/pack-objects.c:2966
-msgid "show progress meter during object writing phase"
-msgstr "Forschrittsanzeige während des Schreibens von Objekten anzeigen"
+#: builtin/push.c:634
+msgid "--mirror and --tags are incompatible"
+msgstr "Die Optionen --mirror und --tags sind inkompatibel."
 
-#: builtin/pack-objects.c:2969
-msgid "similar to --all-progress when progress meter is shown"
-msgstr "ähnlich zu --all-progress wenn Fortschrittsanzeige darstellt wird"
+#: builtin/push.c:636
+msgid "--mirror can't be combined with refspecs"
+msgstr "Die Option --mirror kann nicht mit Refspecs kombiniert werden."
+
+#: builtin/push.c:639
+msgid "--all and --mirror are incompatible"
+msgstr "Die Optionen --all und --mirror sind inkompatibel."
 
-#: builtin/pack-objects.c:2970
-msgid "version[,offset]"
-msgstr "version[,offset]"
+#: builtin/push.c:643
+msgid "push options must not have new line characters"
+msgstr "Push-Optionen dürfen keine Zeilenvorschubzeichen haben"
 
-#: builtin/pack-objects.c:2971
-msgid "write the pack index file in the specified idx format version"
+#: builtin/range-diff.c:8
+msgid "git range-diff [<options>] <old-base>..<old-tip> <new-base>..<new-tip>"
 msgstr ""
-"die Index-Datei des Paketes in der angegebenen Indexformat-Version schreiben"
+"git range-diff [<Optionen>] <alte-Basis>..<alte-Spitze> <neue-Basis>..<neue-"
+"Spitze>"
 
-#: builtin/pack-objects.c:2974
-msgid "maximum size of each output pack file"
-msgstr "maximale Größe für jede ausgegebene Paketdatei"
+#: builtin/range-diff.c:9
+msgid "git range-diff [<options>] <old-tip>...<new-tip>"
+msgstr "git range-diff [<Optionen>] <alte-Spitze>...<neue-Spitze>"
 
-#: builtin/pack-objects.c:2976
-msgid "ignore borrowed objects from alternate object store"
-msgstr "geliehene Objekte von alternativem Objektspeicher ignorieren"
+#: builtin/range-diff.c:10
+msgid "git range-diff [<options>] <base> <old-tip> <new-tip>"
+msgstr "git range-diff [<Optionen>] <Basis> <alte-Spitze> <neue-Spitze>"
 
-#: builtin/pack-objects.c:2978
-msgid "ignore packed objects"
-msgstr "gepackte Objekte ignorieren"
+#: builtin/range-diff.c:22
+msgid "Percentage by which creation is weighted"
+msgstr "Prozentsatz mit welchem Erzeugung gewichtet wird"
 
-#: builtin/pack-objects.c:2980
-msgid "limit pack window by objects"
-msgstr "Paketfenster durch Objekte begrenzen"
+#: builtin/range-diff.c:24
+msgid "use simple diff colors"
+msgstr "einfache Diff-Farben benutzen"
 
-#: builtin/pack-objects.c:2982
-msgid "limit pack window by memory in addition to object limit"
-msgstr ""
-"Paketfenster, zusätzlich zur Objektbegrenzung, durch Speicher begrenzen"
+#: builtin/range-diff.c:26
+msgid "notes"
+msgstr "Notizen"
 
-#: builtin/pack-objects.c:2984
-msgid "maximum length of delta chain allowed in the resulting pack"
-msgstr ""
-"maximale Länge der erlaubten Differenzverkettung im resultierenden Paket"
+#: builtin/range-diff.c:26
+msgid "passed to 'git log'"
+msgstr "an 'git log' übergeben"
 
-#: builtin/pack-objects.c:2986
-msgid "reuse existing deltas"
-msgstr "existierende Unterschiede wiederverwenden"
+#: builtin/range-diff.c:50 builtin/range-diff.c:54
+#, c-format
+msgid "no .. in range: '%s'"
+msgstr "Kein .. im Bereich: '%s'"
 
-#: builtin/pack-objects.c:2988
-msgid "reuse existing objects"
-msgstr "existierende Objekte wiederverwenden"
+#: builtin/range-diff.c:64
+msgid "single arg format must be symmetric range"
+msgstr "Format mit einfachem Argument muss symmetrischer Bereich sein."
 
-#: builtin/pack-objects.c:2990
-msgid "use OFS_DELTA objects"
-msgstr "OFS_DELTA Objekte verwenden"
+#: builtin/range-diff.c:79
+msgid "need two commit ranges"
+msgstr "Benötige zwei Commit-Bereiche."
 
-#: builtin/pack-objects.c:2992
-msgid "use threads when searching for best delta matches"
+#: builtin/read-tree.c:41
+msgid ""
+"git read-tree [(-m [--trivial] [--aggressive] | --reset | --prefix=<prefix>) "
+"[-u [--exclude-per-directory=<gitignore>] | -i]] [--no-sparse-checkout] [--"
+"index-output=<file>] (--empty | <tree-ish1> [<tree-ish2> [<tree-ish3>]])"
 msgstr ""
-"Threads bei der Suche nach den besten Übereinstimmungen bei Unterschieden "
-"verwenden"
-
-#: builtin/pack-objects.c:2994
-msgid "do not create an empty pack output"
-msgstr "keine leeren Pakete erzeugen"
+"git read-tree [(-m [--trivial] [--aggressive] | --reset | --prefix=<Präfix>) "
+"[-u [--exclude-per-directory=<gitignore>] | -i]] [--no-sparse-checkout] [--"
+"index-output=<Datei>] (--empty | <Commit-Referenz1> [<Commit-Referenz2> "
+"[<Commit-Referenz3>]])"
 
-#: builtin/pack-objects.c:2996
-msgid "read revision arguments from standard input"
-msgstr "Argumente bezüglich Commits von der Standard-Eingabe lesen"
+#: builtin/read-tree.c:124
+msgid "write resulting index to <file>"
+msgstr "resultierenden Index nach <Datei> schreiben"
 
-#: builtin/pack-objects.c:2998
-msgid "limit the objects to those that are not yet packed"
-msgstr "die Objekte zu solchen, die noch nicht gepackt wurden, begrenzen"
+#: builtin/read-tree.c:127
+msgid "only empty the index"
+msgstr "nur den Index leeren"
 
-#: builtin/pack-objects.c:3001
-msgid "include objects reachable from any reference"
-msgstr "Objekte einschließen, die von jeder Referenz erreichbar sind"
+#: builtin/read-tree.c:129
+msgid "Merging"
+msgstr "Merge"
 
-#: builtin/pack-objects.c:3004
-msgid "include objects referred by reflog entries"
-msgstr ""
-"Objekte einschließen, die von Einträgen des Reflogs referenziert werden"
+#: builtin/read-tree.c:131
+msgid "perform a merge in addition to a read"
+msgstr "einen Merge, zusätzlich zum Lesen, ausführen"
 
-#: builtin/pack-objects.c:3007
-msgid "include objects referred to by the index"
-msgstr "Objekte einschließen, die vom Index referenziert werden"
+#: builtin/read-tree.c:133
+msgid "3-way merge if no file level merging required"
+msgstr "3-Wege-Merge, wenn kein Merge auf Dateiebene erforderlich ist"
 
-#: builtin/pack-objects.c:3010
-msgid "output pack to stdout"
-msgstr "Paket in die Standard-Ausgabe schreiben"
+#: builtin/read-tree.c:135
+msgid "3-way merge in presence of adds and removes"
+msgstr "3-Wege-Merge bei Vorhandensein von hinzugefügten/entfernten Zeilen"
 
-#: builtin/pack-objects.c:3012
-msgid "include tag objects that refer to objects to be packed"
-msgstr "Tag-Objekte einschließen, die auf gepackte Objekte referenzieren"
+#: builtin/read-tree.c:137
+msgid "same as -m, but discard unmerged entries"
+msgstr "genau wie -m, aber nicht zusammengeführte Einträge verwerfen"
 
-#: builtin/pack-objects.c:3014
-msgid "keep unreachable objects"
-msgstr "nicht erreichbare Objekte behalten"
+#: builtin/read-tree.c:138
+msgid "<subdirectory>/"
+msgstr "<Unterverzeichnis>/"
 
-#: builtin/pack-objects.c:3016
-msgid "pack loose unreachable objects"
-msgstr "nicht erreichbare lose Objekte packen"
+#: builtin/read-tree.c:139
+msgid "read the tree into the index under <subdirectory>/"
+msgstr "das Verzeichnis in den Index unter <Unterverzeichnis>/ lesen"
 
-#: builtin/pack-objects.c:3018
-msgid "unpack unreachable objects newer than <time>"
-msgstr "nicht erreichbare Objekte entpacken, die neuer als <Zeit> sind"
+#: builtin/read-tree.c:142
+msgid "update working tree with merge result"
+msgstr "Arbeitsverzeichnis mit dem Ergebnis des Merges aktualisieren"
 
-#: builtin/pack-objects.c:3021
-msgid "create thin packs"
-msgstr "dünnere Pakete erzeugen"
+#: builtin/read-tree.c:144
+msgid "gitignore"
+msgstr "gitignore"
 
-#: builtin/pack-objects.c:3023
-msgid "create packs suitable for shallow fetches"
-msgstr ""
-"Pakete geeignet für Abholung mit unvollständiger Historie (shallow) erzeugen"
+#: builtin/read-tree.c:145
+msgid "allow explicitly ignored files to be overwritten"
+msgstr "explizit ignorierte Dateien zu überschreiben erlauben"
 
-#: builtin/pack-objects.c:3025
-msgid "ignore packs that have companion .keep file"
-msgstr "Pakete ignorieren, die .keep Dateien haben"
+#: builtin/read-tree.c:148
+msgid "don't check the working tree after merging"
+msgstr "das Arbeitsverzeichnis nach dem Merge nicht prüfen"
 
-#: builtin/pack-objects.c:3027
-msgid "pack compression level"
-msgstr "Komprimierungsgrad für Paketierung"
+#: builtin/read-tree.c:149
+msgid "don't update the index or the work tree"
+msgstr "weder den Index, noch das Arbeitsverzeichnis aktualisieren"
 
-#: builtin/pack-objects.c:3029
-msgid "do not hide commits by grafts"
-msgstr "keine künstlichen Vorgänger-Commits (\"grafts\") verbergen"
+#: builtin/read-tree.c:151
+msgid "skip applying sparse checkout filter"
+msgstr "Anwendung des Filters für partielles Auschecken überspringen"
 
-#: builtin/pack-objects.c:3031
-msgid "use a bitmap index if available to speed up counting objects"
-msgstr ""
-"Bitmap-Index (falls verfügbar) zur Optimierung der Objektzählung benutzen"
+#: builtin/read-tree.c:153
+msgid "debug unpack-trees"
+msgstr "unpack-trees protokollieren"
 
-#: builtin/pack-objects.c:3033
-msgid "write a bitmap index together with the pack index"
-msgstr "Bitmap-Index zusammen mit Pack-Index schreiben"
+#: builtin/read-tree.c:157
+msgid "suppress feedback messages"
+msgstr "Rückmeldungen unterdrücken"
 
-#: builtin/pack-objects.c:3036
-msgid "handling for missing objects"
-msgstr "Behandlung für fehlende Objekte"
+#: builtin/read-tree.c:188
+msgid "You need to resolve your current index first"
+msgstr "Sie müssen zuerst die Konflikte in Ihrem aktuellen Index auflösen."
 
-#: builtin/pack-objects.c:3039
-msgid "do not pack objects in promisor packfiles"
-msgstr "keine Objekte aus Packdateien von partiell geklonten Remote-Repositories packen"
+#: builtin/rebase.c:32
+msgid ""
+"git rebase [-i] [options] [--exec <cmd>] [--onto <newbase> | --keep-base] "
+"[<upstream> [<branch>]]"
+msgstr ""
+"git rebase [-i] [<Optionen>] [--exec <Programm>] [--onto <neue-Basis> | --"
+"keep-base] [<Upstream> [<Branch>]]"
 
-#: builtin/pack-objects.c:3178
-msgid "Counting objects"
-msgstr "Zähle Objekte"
+#: builtin/rebase.c:34
+msgid ""
+"git rebase [-i] [options] [--exec <cmd>] [--onto <newbase>] --root [<branch>]"
+msgstr ""
+"git rebase [-i] [<Optionen>] [--exec <Programm>] [--onto <neue-Basis>] --"
+"root [<Branch>]"
 
-#: builtin/pack-refs.c:6
-msgid "git pack-refs [<options>]"
-msgstr "git pack-refs [<Optionen>]"
+#: builtin/rebase.c:36
+msgid "git rebase --continue | --abort | --skip | --edit-todo"
+msgstr "git rebase --continue | --abort | --skip | --edit-todo"
 
-#: builtin/pack-refs.c:14
-msgid "pack everything"
-msgstr "alles packen"
+#: builtin/rebase.c:177 builtin/rebase.c:201 builtin/rebase.c:228
+#, c-format
+msgid "unusable todo list: '%s'"
+msgstr "Unbenutzbare TODO-Liste: '%s'"
 
-#: builtin/pack-refs.c:15
-msgid "prune loose refs (default)"
-msgstr "lose Referenzen entfernen (Standard)"
+#: builtin/rebase.c:186 builtin/rebase.c:212 builtin/rebase.c:236
+#, c-format
+msgid "could not write '%s'."
+msgstr "Konnte '%s' nicht schreiben."
 
-#: builtin/prune-packed.c:8
-msgid "git prune-packed [-n | --dry-run] [-q | --quiet]"
-msgstr "git prune-packed [-n | --dry-run] [-q | --quiet]"
+#: builtin/rebase.c:271
+msgid "no HEAD?"
+msgstr "Kein HEAD?"
 
-#: builtin/prune-packed.c:41
-msgid "Removing duplicate objects"
-msgstr "Lösche doppelte Objekte"
+#: builtin/rebase.c:298
+#, c-format
+msgid "could not create temporary %s"
+msgstr "Konnte temporäres Verzeichnis '%s' nicht erstellen."
 
-#: builtin/prune.c:11
-msgid "git prune [-n] [-v] [--progress] [--expire <time>] [--] [<head>...]"
-msgstr "git prune [-n] [-v] [--progress] [--expire <Zeit>] [--] [<Branch>...]"
+#: builtin/rebase.c:304
+msgid "could not mark as interactive"
+msgstr "Markierung auf interaktiven Rebase fehlgeschlagen."
 
-#: builtin/prune.c:107
-msgid "report pruned objects"
-msgstr "gelöschte Objekte melden"
+#: builtin/rebase.c:362
+msgid "could not generate todo list"
+msgstr "Konnte TODO-Liste nicht erzeugen."
 
-#: builtin/prune.c:110
-msgid "expire objects older than <time>"
-msgstr "Objekte älter als <Zeit> verfallen lassen"
+#: builtin/rebase.c:402
+msgid "a base commit must be provided with --upstream or --onto"
+msgstr "Ein Basis-Commit muss mit --upstream oder --onto angegeben werden."
+
+#: builtin/rebase.c:457
+msgid "git rebase--interactive [<options>]"
+msgstr "git rebase--interactive [<Optionen>]"
 
-#: builtin/prune.c:112
-msgid "limit traversal to objects outside promisor packfiles"
-msgstr "Traversierung auf Objekte außerhalb von Packdateien aus partiell geklonten Remote-Repositories einschränken"
+#: builtin/rebase.c:469
+msgid "keep empty commits"
+msgstr "leere Commits behalten"
 
-#: builtin/prune.c:126
-msgid "cannot prune in a precious-objects repo"
-msgstr "kann \"prune\" in precious-objects Repository nicht ausführen"
+#: builtin/rebase.c:471 builtin/revert.c:128
+msgid "allow commits with empty messages"
+msgstr "Commits mit leerer Beschreibung erlauben"
 
-#: builtin/pull.c:54 builtin/pull.c:56
-#, c-format
-msgid "Invalid value for %s: %s"
-msgstr "Ungültiger Wert für %s: %s"
+#: builtin/rebase.c:472
+msgid "rebase merge commits"
+msgstr "Rebase auf Merge-Commits ausführen"
 
-#: builtin/pull.c:76
-msgid "git pull [<options>] [<repository> [<refspec>...]]"
-msgstr "git pull [<Optionen>] [<Repository> [<Refspec>...]]"
+#: builtin/rebase.c:474
+msgid "keep original branch points of cousins"
+msgstr "originale Branch-Punkte der Cousins behalten"
 
-#: builtin/pull.c:127
-msgid "control for recursive fetching of submodules"
-msgstr "rekursive Anforderungen von Submodulen kontrollieren"
+#: builtin/rebase.c:476
+msgid "move commits that begin with squash!/fixup!"
+msgstr "Commits verschieben, die mit squash!/fixup! beginnen"
 
-#: builtin/pull.c:131
-msgid "Options related to merging"
-msgstr "Optionen bezogen auf Merge"
+#: builtin/rebase.c:477
+msgid "sign commits"
+msgstr "Commits signieren"
 
-#: builtin/pull.c:134
-msgid "incorporate changes by rebasing rather than merging"
-msgstr "Integration von Änderungen durch Rebase statt Merge"
+#: builtin/rebase.c:479 builtin/rebase.c:1455
+msgid "display a diffstat of what changed upstream"
+msgstr ""
+"Zusammenfassung der Unterschiede gegenüber dem Upstream-Branch anzeigen"
 
-#: builtin/pull.c:161 builtin/rebase--helper.c:23 builtin/revert.c:121
-msgid "allow fast-forward"
-msgstr "Vorspulen erlauben"
+#: builtin/rebase.c:481
+msgid "continue rebase"
+msgstr "Rebase fortsetzen"
 
-#: builtin/pull.c:170
-msgid "automatically stash/stash pop before and after rebase"
-msgstr "automatischer Stash/Stash-Pop vor und nach eines Rebase"
+#: builtin/rebase.c:483
+msgid "skip commit"
+msgstr "Commit auslassen"
+
+#: builtin/rebase.c:484
+msgid "edit the todo list"
+msgstr "die TODO-Liste bearbeiten"
+
+#: builtin/rebase.c:486
+msgid "show the current patch"
+msgstr "den aktuellen Patch anzeigen"
 
-#: builtin/pull.c:186
-msgid "Options related to fetching"
-msgstr "Optionen bezogen auf Fetch"
+#: builtin/rebase.c:489
+msgid "shorten commit ids in the todo list"
+msgstr "Commit-IDs in der TODO-Liste verkürzen"
 
-#: builtin/pull.c:204
-msgid "number of submodules pulled in parallel"
-msgstr "Anzahl der parallel mit 'pull' zu verarbeitenden Submodule"
+#: builtin/rebase.c:491
+msgid "expand commit ids in the todo list"
+msgstr "Commit-IDs in der TODO-Liste erweitern"
 
-#: builtin/pull.c:299
-#, c-format
-msgid "Invalid value for pull.ff: %s"
-msgstr "Ungültiger Wert für pull.ff: %s"
+#: builtin/rebase.c:493
+msgid "check the todo list"
+msgstr "die TODO-Liste prüfen"
 
-#: builtin/pull.c:415
-msgid ""
-"There is no candidate for rebasing against among the refs that you just "
-"fetched."
-msgstr ""
-"Es gibt keinen Kandidaten für Rebase innerhalb der Referenzen, die eben "
-"angefordert wurden."
+#: builtin/rebase.c:495
+msgid "rearrange fixup/squash lines"
+msgstr "fixup/squash-Zeilen umordnen"
 
-#: builtin/pull.c:417
-msgid ""
-"There are no candidates for merging among the refs that you just fetched."
-msgstr ""
-"Es gibt keine Kandidaten für Merge innerhalb der Referenzen, die eben "
-"angefordert wurden."
+#: builtin/rebase.c:497
+msgid "insert exec commands in todo list"
+msgstr "\"exec\"-Befehle in TODO-Liste einfügen"
 
-#: builtin/pull.c:418
-msgid ""
-"Generally this means that you provided a wildcard refspec which had no\n"
-"matches on the remote end."
-msgstr ""
-"Im Allgemeinen bedeutet das, dass Sie einen Refspec mit Wildcards angegeben\n"
-"haben, der auf der Gegenseite mit keinen Referenzen übereinstimmt."
+#: builtin/rebase.c:498
+msgid "onto"
+msgstr "auf"
 
-#: builtin/pull.c:421
-#, c-format
-msgid ""
-"You asked to pull from the remote '%s', but did not specify\n"
-"a branch. Because this is not the default configured remote\n"
-"for your current branch, you must specify a branch on the command line."
-msgstr ""
-"Sie führten \"pull\" von Remote-Repository '%s' aus, ohne einen\n"
-"Branch anzugeben. Da das nicht das konfigurierte Standard-Remote-\n"
-"Repository für den aktuellen Branch ist, müssen Sie einen Branch auf\n"
-"der Befehlszeile angeben."
+#: builtin/rebase.c:501
+msgid "restrict-revision"
+msgstr "Begrenzungscommit"
 
-#: builtin/pull.c:426 git-parse-remote.sh:73
-msgid "You are not currently on a branch."
-msgstr "Im Moment auf keinem Branch."
+#: builtin/rebase.c:501
+msgid "restrict revision"
+msgstr "Begrenzungscommit"
 
-#: builtin/pull.c:428 builtin/pull.c:443 git-parse-remote.sh:79
-msgid "Please specify which branch you want to rebase against."
-msgstr ""
-"Bitte geben Sie den Branch an, gegen welchen Sie \"rebase\" ausführen "
-"möchten."
+#: builtin/rebase.c:503
+msgid "squash-onto"
+msgstr "squash-onto"
 
-#: builtin/pull.c:430 builtin/pull.c:445 git-parse-remote.sh:82
-msgid "Please specify which branch you want to merge with."
-msgstr "Bitte geben Sie den Branch an, welchen Sie zusammenführen möchten."
+#: builtin/rebase.c:504
+msgid "squash onto"
+msgstr "squash onto"
 
-#: builtin/pull.c:431 builtin/pull.c:446
-msgid "See git-pull(1) for details."
-msgstr "Siehe git-pull(1) für weitere Details."
+#: builtin/rebase.c:506
+msgid "the upstream commit"
+msgstr "der Upstream-Commit"
 
-#: builtin/pull.c:433 builtin/pull.c:439 builtin/pull.c:448
-#: git-parse-remote.sh:64
-msgid "<remote>"
-msgstr "<Remote-Repository>"
+#: builtin/rebase.c:508
+msgid "head-name"
+msgstr "head-Name"
 
-#: builtin/pull.c:433 builtin/pull.c:448 builtin/pull.c:453 git-rebase.sh:477
-#: git-parse-remote.sh:65
-msgid "<branch>"
-msgstr "<Branch>"
+#: builtin/rebase.c:508
+msgid "head name"
+msgstr "head-Name"
 
-#: builtin/pull.c:441 git-parse-remote.sh:75
-msgid "There is no tracking information for the current branch."
-msgstr "Es gibt keine Tracking-Informationen für den aktuellen Branch."
+#: builtin/rebase.c:513
+msgid "rebase strategy"
+msgstr "Rebase-Strategie"
 
-#: builtin/pull.c:450 git-parse-remote.sh:95
-msgid ""
-"If you wish to set tracking information for this branch you can do so with:"
-msgstr ""
-"Wenn Sie Tracking-Informationen für diesen Branch setzen möchten, können "
-"Sie\n"
-"dies tun mit:"
+#: builtin/rebase.c:514
+msgid "strategy-opts"
+msgstr "Strategie-Optionen"
 
-#: builtin/pull.c:455
-#, c-format
-msgid ""
-"Your configuration specifies to merge with the ref '%s'\n"
-"from the remote, but no such ref was fetched."
-msgstr ""
-"Ihre Konfiguration gibt an, den Merge mit Referenz '%s'\n"
-"des Remote-Repositories durchzuführen, aber diese Referenz\n"
-"wurde nicht angefordert."
+#: builtin/rebase.c:515
+msgid "strategy options"
+msgstr "Strategie-Optionen"
 
-#: builtin/pull.c:819
-msgid "ignoring --verify-signatures for rebase"
-msgstr "Ignoriere --verify-signatures für Rebase"
+#: builtin/rebase.c:516
+msgid "switch-to"
+msgstr "wechseln zu"
 
-#: builtin/pull.c:867
-msgid "--[no-]autostash option is only valid with --rebase."
-msgstr "--[no-]autostash ist nur mit --rebase zulässig."
+#: builtin/rebase.c:517
+msgid "the branch or commit to checkout"
+msgstr "der Branch oder Commit zum Auschecken"
 
-#: builtin/pull.c:875
-msgid "Updating an unborn branch with changes added to the index."
-msgstr ""
-"Aktualisiere einen ungeborenen Branch mit Änderungen, die zum Commit "
-"vorgemerkt sind."
+#: builtin/rebase.c:518
+msgid "onto-name"
+msgstr "onto-Name"
 
-#: builtin/pull.c:878
-msgid "pull with rebase"
-msgstr "Pull mit Rebase"
+#: builtin/rebase.c:518
+msgid "onto name"
+msgstr "onto-Name"
 
-#: builtin/pull.c:879
-msgid "please commit or stash them."
-msgstr "Bitte committen Sie die Änderungen oder benutzen Sie \"stash\"."
+#: builtin/rebase.c:519
+msgid "cmd"
+msgstr "Befehl"
 
-#: builtin/pull.c:904
-#, c-format
-msgid ""
-"fetch updated the current branch head.\n"
-"fast-forwarding your working tree from\n"
-"commit %s."
-msgstr ""
-"\"fetch\" aktualisierte die Spitze des aktuellen Branches.\n"
-"Spule Ihr Arbeitsverzeichnis von Commit %s vor."
+#: builtin/rebase.c:519
+msgid "the command to run"
+msgstr "auszuführender Befehl"
+
+#: builtin/rebase.c:522 builtin/rebase.c:1540
+msgid "automatically re-schedule any `exec` that fails"
+msgstr "jeden fehlgeschlagenen `exec`-Befehl neu ansetzen"
 
-#: builtin/pull.c:909
+#: builtin/rebase.c:540
+msgid "--[no-]rebase-cousins has no effect without --rebase-merges"
+msgstr "--[no-]rebase-cousins hat ohne --rebase-merges keine Auswirkung"
+
+#: builtin/rebase.c:556
 #, c-format
-msgid ""
-"Cannot fast-forward your working tree.\n"
-"After making sure that you saved anything precious from\n"
-"$ git diff %s\n"
-"output, run\n"
-"$ git reset --hard\n"
-"to recover."
-msgstr ""
-"Kann Arbeitsverzeichnis nicht vorspulen.\n"
-"Nachdem Sie sichergestellt haben, alles Schützenswerte der Ausgabe von\n"
-"$ git diff %s\n"
-"gespeichert zu haben. Führen Sie\n"
-"$ git reset --hard\n"
-"zur Wiederherstellung aus."
+msgid "%s requires an interactive rebase"
+msgstr "%s erfordert ein interaktives Rebase"
 
-#: builtin/pull.c:924
-msgid "Cannot merge multiple branches into empty head."
-msgstr "Kann nicht mehrere Branches in einen leeren Branch zusammenführen."
+#: builtin/rebase.c:608
+#, c-format
+msgid "could not get 'onto': '%s'"
+msgstr "Konnte 'onto' nicht bestimmen: '%s'"
 
-#: builtin/pull.c:928
-msgid "Cannot rebase onto multiple branches."
-msgstr "Kann Rebase nicht auf mehrere Branches ausführen."
+#: builtin/rebase.c:623
+#, c-format
+msgid "invalid orig-head: '%s'"
+msgstr "Ungültiges orig-head: '%s'"
 
-#: builtin/pull.c:935
-msgid "cannot rebase with locally recorded submodule modifications"
-msgstr ""
-"Kann Rebase nicht mit lokal aufgezeichneten Änderungen in Submodulen "
-"ausführen."
+#: builtin/rebase.c:648
+#, c-format
+msgid "ignoring invalid allow_rerere_autoupdate: '%s'"
+msgstr "Ignoriere ungültiges allow_rerere_autoupdate: '%s'"
 
-#: builtin/push.c:17
-msgid "git push [<options>] [<repository> [<refspec>...]]"
-msgstr "git push [<Optionen>] [<Repository> [<Refspec>...]]"
+#: builtin/rebase.c:724
+#, c-format
+msgid "Could not read '%s'"
+msgstr "Konnte '%s' nicht lesen."
 
-#: builtin/push.c:92
-msgid "tag shorthand without <tag>"
-msgstr "Kurzschrift für Tag ohne <Tag>"
+#: builtin/rebase.c:742
+#, c-format
+msgid "Cannot store %s"
+msgstr "Kann %s nicht speichern."
 
-#: builtin/push.c:102
-msgid "--delete only accepts plain target ref names"
-msgstr "Die Option --delete akzeptiert nur reine Referenznamen als Ziel."
+#: builtin/rebase.c:849
+msgid "could not determine HEAD revision"
+msgstr "Konnte HEAD-Commit nicht bestimmen."
 
-#: builtin/push.c:146
+#: builtin/rebase.c:972 git-rebase--preserve-merges.sh:81
 msgid ""
-"\n"
-"To choose either option permanently, see push.default in 'git help config'."
+"Resolve all conflicts manually, mark them as resolved with\n"
+"\"git add/rm <conflicted_files>\", then run \"git rebase --continue\".\n"
+"You can instead skip this commit: run \"git rebase --skip\".\n"
+"To abort and get back to the state before \"git rebase\", run \"git rebase --"
+"abort\"."
 msgstr ""
-"\n"
-"Um eine Variante permanent zu verwenden, siehe push.default in 'git help "
-"config'."
+"Lösen Sie alle Konflikte manuell auf, markieren Sie diese mit\n"
+"\"git add/rm <konfliktbehaftete_Dateien>\" und führen Sie dann\n"
+"\"git rebase --continue\" aus.\n"
+"Sie können auch stattdessen diesen Commit auslassen, indem\n"
+"Sie \"git rebase --skip\" ausführen.\n"
+"Um abzubrechen und zurück zum Zustand vor \"git rebase\" zu gelangen,\n"
+"führen Sie \"git rebase --abort\" aus."
 
-#: builtin/push.c:149
+#: builtin/rebase.c:1060
 #, c-format
 msgid ""
-"The upstream branch of your current branch does not match\n"
-"the name of your current branch.  To push to the upstream branch\n"
-"on the remote, use\n"
 "\n"
-"    git push %s HEAD:%s\n"
+"git encountered an error while preparing the patches to replay\n"
+"these revisions:\n"
 "\n"
-"To push to the branch of the same name on the remote, use\n"
+"    %s\n"
 "\n"
-"    git push %s %s\n"
-"%s"
+"As a result, git cannot rebase them."
 msgstr ""
-"Der Name des Upstream-Branches stimmt nicht mit dem Namen Ihres\n"
-"aktuellen Branches überein. Um auf den Upstream-Branch in dem Remote-\n"
-"Repository zu versenden, benutzen Sie:\n"
 "\n"
-"    git push %s HEAD:%s\n"
+"Git stellte einen Fehler beim Vorbereiten der Patches zur\n"
+"wiederholten Anwendung der Revisionen fest:\n"
 "\n"
-"Um auf den Branch mit demselben Namen im Remote-Repository zu versenden,\n"
-"benutzen Sie:\n"
+"    %s\n"
 "\n"
-"    git push %s %s\n"
-"%s"
+"Infolge dessen kann Git auf diesen Revisionen Rebase nicht\n"
+"ausführen."
 
-#: builtin/push.c:164
+#: builtin/rebase.c:1367
 #, c-format
 msgid ""
-"You are not currently on a branch.\n"
-"To push the history leading to the current (detached HEAD)\n"
-"state now, use\n"
-"\n"
-"    git push %s HEAD:<name-of-remote-branch>\n"
-msgstr ""
-"Sie befinden sich im Moment auf keinem Branch.\n"
-"Um die Historie, führend zum aktuellen (losgelöster HEAD)\n"
-"Status zu versenden, benutzen Sie\n"
+"%s\n"
+"Please specify which branch you want to rebase against.\n"
+"See git-rebase(1) for details.\n"
 "\n"
-"    git push %s HEAD:<Name-des-Remote-Branches>\n"
-
-#: builtin/push.c:178
-#, c-format
-msgid ""
-"The current branch %s has no upstream branch.\n"
-"To push the current branch and set the remote as upstream, use\n"
+"    git rebase '<branch>'\n"
 "\n"
-"    git push --set-upstream %s %s\n"
 msgstr ""
-"Der aktuelle Branch %s hat keinen Upstream-Branch.\n"
-"Um den aktuellen Branch zu versenden und den Remote-Branch\n"
-"als Upstream-Branch zu setzen, benutzen Sie\n"
+"%s\n"
+"Bitte geben Sie den Branch an, gegen welchen Sie \"rebase\" ausführen "
+"möchten.\n"
+"Siehe git-rebase(1) für Details.\n"
+"\n"
+"    git rebase '<Branch>'\n"
 "\n"
-"    git push --set-upstream %s %s\n"
-
-#: builtin/push.c:186
-#, c-format
-msgid "The current branch %s has multiple upstream branches, refusing to push."
-msgstr ""
-"Der aktuelle Branch %s hat mehrere Upstream-Branches, \"push\" verweigert."
-
-#: builtin/push.c:189
-#, c-format
-msgid ""
-"You are pushing to remote '%s', which is not the upstream of\n"
-"your current branch '%s', without telling me what to push\n"
-"to update which remote branch."
-msgstr ""
-"Sie versenden nach '%s', welches kein Upstream-Repository Ihres aktuellen\n"
-"Branches '%s' ist, ohne anzugeben, was versendet werden soll, um welchen\n"
-"Remote-Branch zu aktualisieren."
-
-#: builtin/push.c:248
-msgid ""
-"You didn't specify any refspecs to push, and push.default is \"nothing\"."
-msgstr ""
-"Sie haben keine Refspec für \"push\" angegeben, und push.default ist "
-"\"nothing\"."
-
-#: builtin/push.c:255
-msgid ""
-"Updates were rejected because the tip of your current branch is behind\n"
-"its remote counterpart. Integrate the remote changes (e.g.\n"
-"'git pull ...') before pushing again.\n"
-"See the 'Note about fast-forwards' in 'git push --help' for details."
-msgstr ""
-"Aktualisierungen wurden zurückgewiesen, weil die Spitze Ihres aktuellen\n"
-"Branches hinter seinem externen Gegenstück zurückgefallen ist. Führen Sie\n"
-"die externen Änderungen zusammen (z. B. 'git pull ...') bevor Sie \"push\"\n"
-"erneut ausführen.\n"
-"Siehe auch die Sektion 'Note about fast-forwards' in 'git push --help'\n"
-"für weitere Details."
-
-#: builtin/push.c:261
-msgid ""
-"Updates were rejected because a pushed branch tip is behind its remote\n"
-"counterpart. Check out this branch and integrate the remote changes\n"
-"(e.g. 'git pull ...') before pushing again.\n"
-"See the 'Note about fast-forwards' in 'git push --help' for details."
-msgstr ""
-"Aktualisierungen wurden zurückgewiesen, weil die Spitze eines versendeten\n"
-"Branches hinter seinem externen Gegenstück zurückgefallen ist. Checken Sie\n"
-"diesen Branch aus und führen Sie die externen Änderungen zusammen\n"
-"(z. B. 'git pull ...') bevor Sie erneut \"push\" ausführen.\n"
-"Siehe auch die Sektion 'Note about fast-forwards' in 'git push --help'\n"
-"für weitere Details."
-
-#: builtin/push.c:267
-msgid ""
-"Updates were rejected because the remote contains work that you do\n"
-"not have locally. This is usually caused by another repository pushing\n"
-"to the same ref. You may want to first integrate the remote changes\n"
-"(e.g., 'git pull ...') before pushing again.\n"
-"See the 'Note about fast-forwards' in 'git push --help' for details."
-msgstr ""
-"Aktualisierungen wurden zurückgewiesen, weil das Remote-Repository Commits "
-"enthält,\n"
-"die lokal nicht vorhanden sind. Das wird üblicherweise durch einen \"push\" "
-"von\n"
-"Commits auf dieselbe Referenz von einem anderen Repository aus verursacht.\n"
-"Vielleicht müssen Sie die externen Änderungen zusammenführen (z. B. 'git "
-"pull ...')\n"
-"bevor Sie erneut \"push\" ausführen.\n"
-"Siehe auch die Sektion 'Note about fast-forwards' in 'git push --help'\n"
-"für weitere Details."
-
-#: builtin/push.c:274
-msgid "Updates were rejected because the tag already exists in the remote."
-msgstr ""
-"Aktualisierungen wurden zurückgewiesen, weil das Tag bereits\n"
-"im Remote-Repository existiert."
-
-#: builtin/push.c:277
-msgid ""
-"You cannot update a remote ref that points at a non-commit object,\n"
-"or update a remote ref to make it point at a non-commit object,\n"
-"without using the '--force' option.\n"
-msgstr ""
-"Sie können keine Remote-Referenz aktualisieren, die auf ein Objekt zeigt,\n"
-"das kein Commit ist, oder es auf ein solches Objekt zeigen lassen, ohne\n"
-"die Option '--force' zu verwenden.\n"
-
-#: builtin/push.c:337
-#, c-format
-msgid "Pushing to %s\n"
-msgstr "Versende nach %s\n"
-
-#: builtin/push.c:341
-#, c-format
-msgid "failed to push some refs to '%s'"
-msgstr "Fehler beim Versenden einiger Referenzen nach '%s'"
 
-#: builtin/push.c:372
+#: builtin/rebase.c:1383
 #, c-format
-msgid "bad repository '%s'"
-msgstr "ungültiges Repository '%s'"
-
-#: builtin/push.c:373
 msgid ""
-"No configured push destination.\n"
-"Either specify the URL from the command-line or configure a remote "
-"repository using\n"
-"\n"
-"    git remote add <name> <url>\n"
+"If you wish to set tracking information for this branch you can do so with:\n"
 "\n"
-"and then push using the remote name\n"
+"    git branch --set-upstream-to=%s/<branch> %s\n"
 "\n"
-"    git push <name>\n"
 msgstr ""
-"Kein Ziel für \"push\" konfiguriert.\n"
-"Entweder spezifizieren Sie die URL von der Befehlszeile oder konfigurieren "
-"ein Remote-Repository unter Benutzung von\n"
-"\n"
-"    git remote add <Name> <URL>\n"
+"Wenn Sie Tracking-Informationen für diesen Branch setzen möchten,\n"
+"können Sie dies tun mit:\n"
 "\n"
-"und führen \"push\" dann unter Benutzung dieses Namens aus\n"
+"    git branch --set-upstream-to=%s/<Branch> %s\n"
 "\n"
-"    git push <Name>\n"
 
-#: builtin/push.c:391
-msgid "--all and --tags are incompatible"
-msgstr "Die Optionen --all und --tags sind inkompatibel."
+#: builtin/rebase.c:1413
+msgid "exec commands cannot contain newlines"
+msgstr "\"exec\"-Befehle können keine neuen Zeilen enthalten"
 
-#: builtin/push.c:392
-msgid "--all can't be combined with refspecs"
-msgstr "Die Option --all kann nicht mit Refspecs kombiniert werden."
+#: builtin/rebase.c:1417
+msgid "empty exec command"
+msgstr "Leerer \"exec\"-Befehl."
 
-#: builtin/push.c:397
-msgid "--mirror and --tags are incompatible"
-msgstr "Die Optionen --mirror und --tags sind inkompatibel."
+#: builtin/rebase.c:1446
+msgid "rebase onto given branch instead of upstream"
+msgstr "Rebase auf angegebenen Branch anstelle des Upstream-Branches ausführen"
 
-#: builtin/push.c:398
-msgid "--mirror can't be combined with refspecs"
-msgstr "Die Option --mirror kann nicht mit Refspecs kombiniert werden."
+#: builtin/rebase.c:1448
+msgid "use the merge-base of upstream and branch as the current base"
+msgstr "Nutze die Merge-Basis von Upstream und Branch als die aktuelle Basis"
 
-#: builtin/push.c:403
-msgid "--all and --mirror are incompatible"
-msgstr "Die Optionen --all und --mirror sind inkompatibel."
+#: builtin/rebase.c:1450
+msgid "allow pre-rebase hook to run"
+msgstr "Ausführung des pre-rebase-Hooks erlauben"
 
-#: builtin/push.c:535
-msgid "repository"
-msgstr "Repository"
+#: builtin/rebase.c:1452
+msgid "be quiet. implies --no-stat"
+msgstr "weniger Ausgaben (impliziert --no-stat)"
 
-#: builtin/push.c:536 builtin/send-pack.c:163
-msgid "push all refs"
-msgstr "alle Referenzen versenden"
+#: builtin/rebase.c:1458
+msgid "do not show diffstat of what changed upstream"
+msgstr ""
+"Zusammenfassung der Unterschiede gegenüber dem Upstream-Branch verbergen"
 
-#: builtin/push.c:537 builtin/send-pack.c:165
-msgid "mirror all refs"
-msgstr "alle Referenzen spiegeln"
+#: builtin/rebase.c:1461
+msgid "add a Signed-off-by: line to each commit"
+msgstr "eine \"Signed-off-by:\"-Zeile zu jedem Commit hinzufügen"
 
-#: builtin/push.c:539
-msgid "delete refs"
-msgstr "Referenzen löschen"
+#: builtin/rebase.c:1464
+msgid "make committer date match author date"
+msgstr "Commit-Datum und Autor-Datum sollen übereinstimmen"
 
-#: builtin/push.c:540
-msgid "push tags (can't be used with --all or --mirror)"
-msgstr "Tags versenden (kann nicht mit --all oder --mirror verwendet werden)"
+#: builtin/rebase.c:1466
+msgid "ignore author date and use current date"
+msgstr "Autor-Datum ignorieren und aktuelles Datum nutzen"
 
-#: builtin/push.c:543 builtin/send-pack.c:166
-msgid "force updates"
-msgstr "Aktualisierung erzwingen"
+#: builtin/rebase.c:1468
+msgid "synonym of --reset-author-date"
+msgstr "Synonym für --reset-author-date"
 
-#: builtin/push.c:545 builtin/send-pack.c:180
-msgid "refname>:<expect"
-msgstr "Referenzname>:<Erwartungswert"
+#: builtin/rebase.c:1470 builtin/rebase.c:1474
+msgid "passed to 'git apply'"
+msgstr "an 'git apply' übergeben"
 
-#: builtin/push.c:546 builtin/send-pack.c:181
-msgid "require old value of ref to be at this value"
-msgstr "Referenz muss sich auf dem angegebenen Wert befinden"
+#: builtin/rebase.c:1472
+msgid "ignore changes in whitespace"
+msgstr "Whitespace-Änderungen ignorieren"
 
-#: builtin/push.c:549
-msgid "control recursive pushing of submodules"
-msgstr "rekursiven \"push\" von Submodulen steuern"
+#: builtin/rebase.c:1476 builtin/rebase.c:1479
+msgid "cherry-pick all commits, even if unchanged"
+msgstr ""
+"Cherry-Pick auf alle Commits ausführen, auch wenn diese unverändert sind"
 
-#: builtin/push.c:551 builtin/send-pack.c:174
-msgid "use thin pack"
-msgstr "kleinere Pakete verwenden"
+#: builtin/rebase.c:1481
+msgid "continue"
+msgstr "fortsetzen"
 
-#: builtin/push.c:552 builtin/push.c:553 builtin/send-pack.c:160
-#: builtin/send-pack.c:161
-msgid "receive pack program"
-msgstr "'receive pack' Programm"
+#: builtin/rebase.c:1484
+msgid "skip current patch and continue"
+msgstr "den aktuellen Patch auslassen und fortfahren"
 
-#: builtin/push.c:554
-msgid "set upstream for git pull/status"
-msgstr "Upstream für \"git pull/status\" setzen"
+#: builtin/rebase.c:1486
+msgid "abort and check out the original branch"
+msgstr "abbrechen und den ursprünglichen Branch auschecken"
 
-#: builtin/push.c:557
-msgid "prune locally removed refs"
-msgstr "lokal gelöschte Referenzen entfernen"
+#: builtin/rebase.c:1489
+msgid "abort but keep HEAD where it is"
+msgstr "abbrechen, aber HEAD an aktueller Stelle belassen"
 
-#: builtin/push.c:559
-msgid "bypass pre-push hook"
-msgstr "\"pre-push hook\" umgehen"
+#: builtin/rebase.c:1490
+msgid "edit the todo list during an interactive rebase"
+msgstr "TODO-Liste während eines interaktiven Rebase bearbeiten"
 
-#: builtin/push.c:560
-msgid "push missing but relevant tags"
-msgstr "fehlende, aber relevante Tags versenden"
+#: builtin/rebase.c:1493
+msgid "show the patch file being applied or merged"
+msgstr "den Patch, der gerade angewendet oder zusammengeführt wird, anzeigen"
 
-#: builtin/push.c:563 builtin/send-pack.c:168
-msgid "GPG sign the push"
-msgstr "signiert \"push\" mit GPG"
+#: builtin/rebase.c:1496
+msgid "use merging strategies to rebase"
+msgstr "Merge-Strategien beim Rebase verwenden"
 
-#: builtin/push.c:565 builtin/send-pack.c:175
-msgid "request atomic transaction on remote side"
-msgstr "Referenzen atomar versenden"
+#: builtin/rebase.c:1500
+msgid "let the user edit the list of commits to rebase"
+msgstr "den Benutzer die Liste der Commits für den Rebase bearbeiten lassen"
 
-#: builtin/push.c:566 builtin/send-pack.c:171
-msgid "server-specific"
-msgstr "serverspezifisch"
+#: builtin/rebase.c:1504
+msgid "(DEPRECATED) try to recreate merges instead of ignoring them"
+msgstr ""
+"(VERALTET) Versuche, Merges wiederherzustellen anstatt sie zu ignorieren"
 
-#: builtin/push.c:566 builtin/send-pack.c:172
-msgid "option to transmit"
-msgstr "Option übertragen"
+#: builtin/rebase.c:1509
+msgid "preserve empty commits during rebase"
+msgstr "leere Commits während des Rebase erhalten"
 
-#: builtin/push.c:583
-msgid "--delete is incompatible with --all, --mirror and --tags"
-msgstr "Die Option --delete ist inkompatibel mit --all, --mirror und --tags."
+#: builtin/rebase.c:1511
+msgid "move commits that begin with squash!/fixup! under -i"
+msgstr "bei -i Commits verschieben, die mit squash!/fixup! beginnen"
 
-#: builtin/push.c:585
-msgid "--delete doesn't make sense without any refs"
-msgstr "Die Option --delete kann nur mit Referenzen verwendet werden."
+#: builtin/rebase.c:1517
+msgid "automatically stash/stash pop before and after"
+msgstr "automatischer Stash/Stash-Pop davor und danach"
 
-#: builtin/push.c:604
-msgid "push options must not have new line characters"
-msgstr "Push-Optionen dürfen keine Zeilenvorschubzeichen haben"
+#: builtin/rebase.c:1519
+msgid "add exec lines after each commit of the editable list"
+msgstr "exec-Zeilen nach jedem Commit der editierbaren Liste hinzufügen"
+
+#: builtin/rebase.c:1523
+msgid "allow rebasing commits with empty messages"
+msgstr "Rebase von Commits mit leerer Beschreibung erlauben"
+
+#: builtin/rebase.c:1526
+msgid "try to rebase merges instead of skipping them"
+msgstr ""
+"versuchen, Rebase mit Merges auszuführen, anstatt diese zu überspringen"
+
+#: builtin/rebase.c:1529
+msgid "use 'merge-base --fork-point' to refine upstream"
+msgstr ""
+"'git merge-base --fork-point' benutzen, um Upstream-Branch zu bestimmen"
+
+#: builtin/rebase.c:1531
+msgid "use the given merge strategy"
+msgstr "angegebene Merge-Strategie verwenden"
+
+#: builtin/rebase.c:1533 builtin/revert.c:115
+msgid "option"
+msgstr "Option"
+
+#: builtin/rebase.c:1534
+msgid "pass the argument through to the merge strategy"
+msgstr "Argument zur Merge-Strategie durchreichen"
+
+#: builtin/rebase.c:1537
+msgid "rebase all reachable commits up to the root(s)"
+msgstr "Rebase auf alle erreichbaren Commits bis zum Root-Commit ausführen"
 
-#: builtin/read-tree.c:40
+#: builtin/rebase.c:1554
 msgid ""
-"git read-tree [(-m [--trivial] [--aggressive] | --reset | --prefix=<prefix>) "
-"[-u [--exclude-per-directory=<gitignore>] | -i]] [--no-sparse-checkout] [--"
-"index-output=<file>] (--empty | <tree-ish1> [<tree-ish2> [<tree-ish3>]])"
+"the rebase.useBuiltin support has been removed!\n"
+"See its entry in 'git help config' for details."
 msgstr ""
-"git read-tree [(-m [--trivial] [--aggressive] | --reset | --prefix=<Präfix>) "
-"[-u [--exclude-per-directory=<gitignore>] | -i]] [--no-sparse-checkout] [--"
-"index-output=<Datei>] (--empty | <Commit-Referenz1> [<Commit-Referenz2> "
-"[<Commit-Referenz3>]])"
+"Die Unterstützung für rebase.useBuiltin wurde entfernt!\n"
+"Siehe dessen Eintrag in 'git help config' für Details."
 
-#: builtin/read-tree.c:121
-msgid "write resulting index to <file>"
-msgstr "resultierenden Index nach <Datei> schreiben"
+#: builtin/rebase.c:1560
+msgid "It looks like 'git am' is in progress. Cannot rebase."
+msgstr "'git-am' scheint im Gange zu sein. Kann Rebase nicht durchführen."
 
-#: builtin/read-tree.c:124
-msgid "only empty the index"
-msgstr "nur den Index leeren"
+#: builtin/rebase.c:1601
+msgid ""
+"git rebase --preserve-merges is deprecated. Use --rebase-merges instead."
+msgstr ""
+"'git rebase --preserve-merges' ist veraltet. Benutzen Sie stattdessen '--"
+"rebase-merges'."
 
-#: builtin/read-tree.c:126
-msgid "Merging"
-msgstr "Merge"
+#: builtin/rebase.c:1606
+msgid "cannot combine '--keep-base' with '--onto'"
+msgstr "'--keep-base' kann nicht mit '--onto' kombiniert werden"
 
-#: builtin/read-tree.c:128
-msgid "perform a merge in addition to a read"
-msgstr "einen Merge, zusätzlich zum Lesen, ausführen"
+#: builtin/rebase.c:1608
+msgid "cannot combine '--keep-base' with '--root'"
+msgstr "'--keep-base' kann nicht mit '--root' kombiniert werden"
 
-#: builtin/read-tree.c:130
-msgid "3-way merge if no file level merging required"
-msgstr "3-Wege-Merge, wenn kein Merge auf Dateiebene erforderlich ist"
+#: builtin/rebase.c:1612
+msgid "No rebase in progress?"
+msgstr "Kein Rebase im Gange?"
 
-#: builtin/read-tree.c:132
-msgid "3-way merge in presence of adds and removes"
-msgstr "3-Wege-Merge bei Vorhandensein von hinzugefügten/entfernten Zeilen"
+#: builtin/rebase.c:1616
+msgid "The --edit-todo action can only be used during interactive rebase."
+msgstr ""
+"Die --edit-todo Aktion kann nur während eines interaktiven Rebase verwendet "
+"werden."
 
-#: builtin/read-tree.c:134
-msgid "same as -m, but discard unmerged entries"
-msgstr "genau wie -m, aber nicht zusammengeführte Einträge verwerfen"
+#: builtin/rebase.c:1639
+msgid "Cannot read HEAD"
+msgstr "Kann HEAD nicht lesen"
 
-#: builtin/read-tree.c:135
-msgid "<subdirectory>/"
-msgstr "<Unterverzeichnis>/"
+#: builtin/rebase.c:1651
+msgid ""
+"You must edit all merge conflicts and then\n"
+"mark them as resolved using git add"
+msgstr ""
+"Sie müssen alle Merge-Konflikte editieren und diese dann\n"
+"mittels \"git add\" als aufgelöst markieren"
 
-#: builtin/read-tree.c:136
-msgid "read the tree into the index under <subdirectory>/"
-msgstr "das Verzeichnis in den Index unter <Unterverzeichnis>/ lesen"
+#: builtin/rebase.c:1670
+msgid "could not discard worktree changes"
+msgstr "Konnte Änderungen im Arbeitsverzeichnis nicht verwerfen."
 
-#: builtin/read-tree.c:139
-msgid "update working tree with merge result"
-msgstr "Arbeitsverzeichnis mit dem Ergebnis des Merges aktualisieren"
+#: builtin/rebase.c:1689
+#, c-format
+msgid "could not move back to %s"
+msgstr "Konnte nicht zu %s zurückgehen."
 
-#: builtin/read-tree.c:141
-msgid "gitignore"
-msgstr "gitignore"
+#: builtin/rebase.c:1734
+#, c-format
+msgid ""
+"It seems that there is already a %s directory, and\n"
+"I wonder if you are in the middle of another rebase.  If that is the\n"
+"case, please try\n"
+"\t%s\n"
+"If that is not the case, please\n"
+"\t%s\n"
+"and run me again.  I am stopping in case you still have something\n"
+"valuable there.\n"
+msgstr ""
+"Es sieht so aus, als ob es das Verzeichnis %s bereits gibt\n"
+"und es könnte ein anderer Rebase im Gange sein. Wenn das der Fall ist,\n"
+"probieren Sie bitte\n"
+"\t%s\n"
+"Wenn das nicht der Fall ist, probieren Sie bitte\n"
+"\t%s\n"
+"und führen Sie diesen Befehl nochmal aus. Es wird angehalten, falls noch\n"
+"etwas Schützenswertes vorhanden ist.\n"
 
-#: builtin/read-tree.c:142
-msgid "allow explicitly ignored files to be overwritten"
-msgstr "explizit ignorierte Dateien zu überschreiben erlauben"
+#: builtin/rebase.c:1757
+msgid "switch `C' expects a numerical value"
+msgstr "Schalter `C' erwartet einen numerischen Wert."
 
-#: builtin/read-tree.c:145
-msgid "don't check the working tree after merging"
-msgstr "das Arbeitsverzeichnis nach dem Merge nicht prüfen"
+#: builtin/rebase.c:1798
+#, c-format
+msgid "Unknown mode: %s"
+msgstr "Unbekannter Modus: %s"
 
-#: builtin/read-tree.c:146
-msgid "don't update the index or the work tree"
-msgstr "weder den Index, noch das Arbeitsverzeichnis aktualisieren"
+#: builtin/rebase.c:1820
+msgid "--strategy requires --merge or --interactive"
+msgstr "--strategy erfordert --merge oder --interactive"
 
-#: builtin/read-tree.c:148
-msgid "skip applying sparse checkout filter"
-msgstr "Anwendung des Filters für partielles Auschecken überspringen"
+#: builtin/rebase.c:1860
+msgid "--reschedule-failed-exec requires --exec or --interactive"
+msgstr "--reschedule-failed-exec erfordert --exec oder --interactive"
 
-#: builtin/read-tree.c:150
-msgid "debug unpack-trees"
-msgstr "unpack-trees protokollieren"
+#: builtin/rebase.c:1872
+msgid "cannot combine am options with either interactive or merge options"
+msgstr ""
+"Optionen für \"am\" können nicht mit Optionen für \"interactive\" oder "
+"\"merge\" kombiniert werden."
 
-#: builtin/rebase--helper.c:8
-msgid "git rebase--helper [<options>]"
-msgstr "git rebase--helper [<Optionen>]"
+#: builtin/rebase.c:1891
+msgid "cannot combine '--preserve-merges' with '--rebase-merges'"
+msgstr ""
+"'--preserve-merges' kann nicht mit '--rebase-merges' kombiniert werden."
 
-#: builtin/rebase--helper.c:24
-msgid "keep empty commits"
-msgstr "leere Commits behalten"
+#: builtin/rebase.c:1895
+msgid ""
+"error: cannot combine '--preserve-merges' with '--reschedule-failed-exec'"
+msgstr ""
+"Fehler: '--preserve-merges' kann nicht mit '--reschedule-failed-exec' "
+"kombiniert werden."
 
-#: builtin/rebase--helper.c:26 builtin/revert.c:123
-msgid "allow commits with empty messages"
-msgstr "Commits mit leerer Beschreibung erlauben"
+#: builtin/rebase.c:1919
+#, c-format
+msgid "invalid upstream '%s'"
+msgstr "Ungültiger Upstream '%s'"
 
-#: builtin/rebase--helper.c:27
-msgid "continue rebase"
-msgstr "Rebase fortsetzen"
+#: builtin/rebase.c:1925
+msgid "Could not create new root commit"
+msgstr "Konnte neuen Root-Commit nicht erstellen."
 
-#: builtin/rebase--helper.c:29
-msgid "abort rebase"
-msgstr "Rebase abbrechen"
-
-#: builtin/rebase--helper.c:32
-msgid "make rebase script"
-msgstr "Rebase-Skript erstellen"
+#: builtin/rebase.c:1951
+#, c-format
+msgid "'%s': need exactly one merge base with branch"
+msgstr "'%s': benötige genau eine Merge-Basis mit dem Branch"
 
-#: builtin/rebase--helper.c:34
-msgid "shorten commit ids in the todo list"
-msgstr "Commit-IDs in der TODO-Liste verkürzen"
+#: builtin/rebase.c:1954
+#, c-format
+msgid "'%s': need exactly one merge base"
+msgstr "'%s': benötige genau eine Merge-Basis"
 
-#: builtin/rebase--helper.c:36
-msgid "expand commit ids in the todo list"
-msgstr "Commit-IDs in der TODO-Liste erweitern"
+#: builtin/rebase.c:1962
+#, c-format
+msgid "Does not point to a valid commit '%s'"
+msgstr "'%s' zeigt auf keinen gültigen Commit."
 
-#: builtin/rebase--helper.c:38
-msgid "check the todo list"
-msgstr "die TODO-Liste prüfen"
+#: builtin/rebase.c:1987
+#, c-format
+msgid "fatal: no such branch/commit '%s'"
+msgstr "fatal: Branch/Commit '%s' nicht gefunden"
 
-#: builtin/rebase--helper.c:40
-msgid "skip unnecessary picks"
-msgstr "nicht erforderliche \"pick\"-Befehle auslassen"
+#: builtin/rebase.c:1995 builtin/submodule--helper.c:40
+#: builtin/submodule--helper.c:1961
+#, c-format
+msgid "No such ref: %s"
+msgstr "Referenz nicht gefunden: %s"
 
-#: builtin/rebase--helper.c:42
-msgid "rearrange fixup/squash lines"
-msgstr "fixup/squash-Zeilen umordnen"
+#: builtin/rebase.c:2006
+msgid "Could not resolve HEAD to a revision"
+msgstr "Konnte HEAD zu keinem Commit auflösen."
 
-#: builtin/rebase--helper.c:44
-msgid "insert exec commands in todo list"
-msgstr "\"exec\"-Befehle in TODO-Liste einfügen"
+#: builtin/rebase.c:2044
+msgid "Cannot autostash"
+msgstr "Kann automatischen Stash nicht erzeugen."
+
+#: builtin/rebase.c:2047
+#, c-format
+msgid "Unexpected stash response: '%s'"
+msgstr "Unerwartete 'stash'-Antwort: '%s'"
+
+#: builtin/rebase.c:2053
+#, c-format
+msgid "Could not create directory for '%s'"
+msgstr "Konnte Verzeichnis für '%s' nicht erstellen."
+
+#: builtin/rebase.c:2056
+#, c-format
+msgid "Created autostash: %s\n"
+msgstr "Automatischen Stash erzeugt: %s\n"
+
+#: builtin/rebase.c:2059
+msgid "could not reset --hard"
+msgstr "Konnte 'reset --hard' nicht ausführen."
+
+#: builtin/rebase.c:2068
+msgid "Please commit or stash them."
+msgstr "Bitte committen Sie die Änderungen oder benutzen Sie \"stash\"."
+
+#: builtin/rebase.c:2095
+#, c-format
+msgid "could not parse '%s'"
+msgstr "Konnte '%s' nicht parsen."
+
+#: builtin/rebase.c:2108
+#, c-format
+msgid "could not switch to %s"
+msgstr "Konnte nicht zu %s wechseln."
+
+#: builtin/rebase.c:2119
+msgid "HEAD is up to date."
+msgstr "HEAD ist aktuell."
+
+#: builtin/rebase.c:2121
+#, c-format
+msgid "Current branch %s is up to date.\n"
+msgstr "Aktueller Branch %s ist auf dem neuesten Stand.\n"
+
+#: builtin/rebase.c:2129
+msgid "HEAD is up to date, rebase forced."
+msgstr "HEAD ist aktuell, Rebase erzwungen."
+
+#: builtin/rebase.c:2131
+#, c-format
+msgid "Current branch %s is up to date, rebase forced.\n"
+msgstr "Aktueller Branch %s ist auf dem neuesten Stand, Rebase erzwungen.\n"
+
+#: builtin/rebase.c:2139
+msgid "The pre-rebase hook refused to rebase."
+msgstr "Der \"pre-rebase hook\" hat den Rebase zurückgewiesen."
+
+#: builtin/rebase.c:2146
+#, c-format
+msgid "Changes to %s:\n"
+msgstr "Änderungen zu %s:\n"
+
+#: builtin/rebase.c:2149
+#, c-format
+msgid "Changes from %s to %s:\n"
+msgstr "Änderungen von %s zu %s:\n"
+
+#: builtin/rebase.c:2174
+#, c-format
+msgid "First, rewinding head to replay your work on top of it...\n"
+msgstr ""
+"Zunächst wird der Branch zurückgespult, um Ihre Änderungen darauf neu "
+"anzuwenden...\n"
 
-#: builtin/receive-pack.c:30
+#: builtin/rebase.c:2183
+msgid "Could not detach HEAD"
+msgstr "Konnte HEAD nicht loslösen."
+
+#: builtin/rebase.c:2192
+#, c-format
+msgid "Fast-forwarded %s to %s.\n"
+msgstr "Spule %s vor zu %s.\n"
+
+#: builtin/receive-pack.c:32
 msgid "git receive-pack <git-dir>"
 msgstr "git receive-pack <Git-Verzeichnis>"
 
-#: builtin/receive-pack.c:841
+#: builtin/receive-pack.c:830
 msgid ""
 "By default, updating the current branch in a non-bare repository\n"
 "is denied, because it will make the index and work tree inconsistent\n"
@@ -12575,7 +18728,7 @@ msgstr ""
 "setzen Sie die Konfigurationsvariable 'receive.denyCurrentBranch' auf\n"
 "'refuse'."
 
-#: builtin/receive-pack.c:861
+#: builtin/receive-pack.c:850
 msgid ""
 "By default, deleting the current branch is denied, because the next\n"
 "'git clone' won't result in any file checked out, causing confusion.\n"
@@ -12596,24 +18749,79 @@ msgstr ""
 "\n"
 "Um diese Meldung zu unterdrücken, setzen Sie die Variable auf 'refuse'."
 
-#: builtin/receive-pack.c:1934
+#: builtin/receive-pack.c:1936
 msgid "quiet"
 msgstr "weniger Ausgaben"
 
-#: builtin/receive-pack.c:1948
+#: builtin/receive-pack.c:1950
 msgid "You must specify a directory."
 msgstr "Sie müssen ein Repository angeben."
 
-#: builtin/reflog.c:532 builtin/reflog.c:537
+#: builtin/reflog.c:17
+msgid ""
+"git reflog expire [--expire=<time>] [--expire-unreachable=<time>] [--"
+"rewrite] [--updateref] [--stale-fix] [--dry-run | -n] [--verbose] [--all] "
+"<refs>..."
+msgstr ""
+"git reflog expire [--expire=<Zeit>] [--expire-unreachable=<Zeit>] [--"
+"rewrite] [--updateref] [--stale-fix] [--dry-run | -n] [--verbose] [--all] "
+"<Referenzen>..."
+
+#: builtin/reflog.c:22
+msgid ""
+"git reflog delete [--rewrite] [--updateref] [--dry-run | -n] [--verbose] "
+"<refs>..."
+msgstr ""
+"git reflog delete [--rewrite] [--updateref] [--dry-run | -n] [--verbose] "
+"<Referenzen>..."
+
+#: builtin/reflog.c:25
+msgid "git reflog exists <ref>"
+msgstr "git reflog exists <Referenz>"
+
+#: builtin/reflog.c:567 builtin/reflog.c:572
 #, c-format
 msgid "'%s' is not a valid timestamp"
 msgstr "'%s' ist kein gültiger Zeitstempel"
 
-#: builtin/remote.c:13
+#: builtin/reflog.c:605
+#, c-format
+msgid "Marking reachable objects..."
+msgstr "Markiere nicht erreichbare Objekte..."
+
+#: builtin/reflog.c:643
+#, c-format
+msgid "%s points nowhere!"
+msgstr "%s zeigt auf nichts!"
+
+#: builtin/reflog.c:695
+msgid "no reflog specified to delete"
+msgstr "Kein Reflog zum Löschen angegeben."
+
+#: builtin/reflog.c:704
+#, c-format
+msgid "not a reflog: %s"
+msgstr "Kein Reflog: %s"
+
+#: builtin/reflog.c:709
+#, c-format
+msgid "no reflog for '%s'"
+msgstr "Kein Reflog für '%s'."
+
+#: builtin/reflog.c:755
+#, c-format
+msgid "invalid ref format: %s"
+msgstr "Ungültiges Format für Referenzen: %s"
+
+#: builtin/reflog.c:764
+msgid "git reflog [ show | expire | delete | exists ]"
+msgstr "git reflog [ show | expire | delete | exists ]"
+
+#: builtin/remote.c:16
 msgid "git remote [-v | --verbose]"
 msgstr "git remote [-v | --verbose]"
 
-#: builtin/remote.c:14
+#: builtin/remote.c:17
 msgid ""
 "git remote add [-t <branch>] [-m <master>] [-f] [--tags | --no-tags] [--"
 "mirror=<fetch|push>] <name> <url>"
@@ -12621,82 +18829,82 @@ msgstr ""
 "git remote add [-t <Branch>] [-m <master>] [-f] [--tags | --no-tags] [--"
 "mirror=<fetch|push>] <Name> <URL>"
 
-#: builtin/remote.c:15 builtin/remote.c:35
+#: builtin/remote.c:18 builtin/remote.c:38
 msgid "git remote rename <old> <new>"
 msgstr "git remote rename <alt> <neu>"
 
-#: builtin/remote.c:16 builtin/remote.c:40
+#: builtin/remote.c:19 builtin/remote.c:43
 msgid "git remote remove <name>"
 msgstr "git remote remove <Name>"
 
-#: builtin/remote.c:17 builtin/remote.c:45
+#: builtin/remote.c:20 builtin/remote.c:48
 msgid "git remote set-head <name> (-a | --auto | -d | --delete | <branch>)"
 msgstr "git remote set-head <Name> (-a | --auto | -d | --delete | <Branch>)"
 
-#: builtin/remote.c:18
+#: builtin/remote.c:21
 msgid "git remote [-v | --verbose] show [-n] <name>"
 msgstr "git remote [-v | --verbose] show [-n] <Name>"
 
-#: builtin/remote.c:19
+#: builtin/remote.c:22
 msgid "git remote prune [-n | --dry-run] <name>"
 msgstr "git remote prune [-n | --dry-run] <Name>"
 
-#: builtin/remote.c:20
+#: builtin/remote.c:23
 msgid ""
 "git remote [-v | --verbose] update [-p | --prune] [(<group> | <remote>)...]"
 msgstr ""
 "git remote [-v | --verbose] update [-p | --prune] [(<Gruppe> | <Remote>)...]"
 
-#: builtin/remote.c:21
+#: builtin/remote.c:24
 msgid "git remote set-branches [--add] <name> <branch>..."
 msgstr "git remote set-branches [--add] <Name> <Branch>..."
 
-#: builtin/remote.c:22 builtin/remote.c:71
+#: builtin/remote.c:25 builtin/remote.c:74
 msgid "git remote get-url [--push] [--all] <name>"
 msgstr "git remote get-url [--push] [--all] <Name>"
 
-#: builtin/remote.c:23 builtin/remote.c:76
+#: builtin/remote.c:26 builtin/remote.c:79
 msgid "git remote set-url [--push] <name> <newurl> [<oldurl>]"
 msgstr "git remote set-url [--push] <Name> <neueURL> [<alteURL>]"
 
-#: builtin/remote.c:24 builtin/remote.c:77
+#: builtin/remote.c:27 builtin/remote.c:80
 msgid "git remote set-url --add <name> <newurl>"
 msgstr "git remote set-url --add <Name> <neueURL>"
 
-#: builtin/remote.c:25 builtin/remote.c:78
+#: builtin/remote.c:28 builtin/remote.c:81
 msgid "git remote set-url --delete <name> <url>"
 msgstr "git remote set-url --delete <Name> <URL>"
 
-#: builtin/remote.c:30
+#: builtin/remote.c:33
 msgid "git remote add [<options>] <name> <url>"
 msgstr "git remote add [<Optionen>] <Name> <URL>"
 
-#: builtin/remote.c:50
+#: builtin/remote.c:53
 msgid "git remote set-branches <name> <branch>..."
 msgstr "git remote set-branches <Name> <Branch>..."
 
-#: builtin/remote.c:51
+#: builtin/remote.c:54
 msgid "git remote set-branches --add <name> <branch>..."
 msgstr "git remote set-branches --add <Name> <Branch>..."
 
-#: builtin/remote.c:56
+#: builtin/remote.c:59
 msgid "git remote show [<options>] <name>"
 msgstr "git remote show [<Optionen>] <Name>"
 
-#: builtin/remote.c:61
+#: builtin/remote.c:64
 msgid "git remote prune [<options>] <name>"
 msgstr "git remote prune [<Optionen>] <Name>"
 
-#: builtin/remote.c:66
+#: builtin/remote.c:69
 msgid "git remote update [<options>] [<group> | <remote>]..."
 msgstr "git remote update [<Optionen>] [<Gruppe> | <externesRepository>]..."
 
-#: builtin/remote.c:95
+#: builtin/remote.c:98
 #, c-format
 msgid "Updating %s"
 msgstr "Aktualisiere %s"
 
-#: builtin/remote.c:127
+#: builtin/remote.c:130
 msgid ""
 "--mirror is dangerous and deprecated; please\n"
 "\t use --mirror=fetch or --mirror=push instead"
@@ -12704,92 +18912,88 @@ msgstr ""
 "--mirror ist gefährlich und veraltet; bitte\n"
 "\t benutzen Sie stattdessen --mirror=fetch oder --mirror=push"
 
-#: builtin/remote.c:144
+#: builtin/remote.c:147
 #, c-format
 msgid "unknown mirror argument: %s"
 msgstr "unbekanntes Argument für Option --mirror: %s"
 
-#: builtin/remote.c:160
+#: builtin/remote.c:163
 msgid "fetch the remote branches"
 msgstr "die Remote-Branches anfordern"
 
-#: builtin/remote.c:162
+#: builtin/remote.c:165
 msgid "import all tags and associated objects when fetching"
 msgstr "alle Tags und verbundene Objekte beim Anfordern importieren"
 
-#: builtin/remote.c:165
+#: builtin/remote.c:168
 msgid "or do not fetch any tag at all (--no-tags)"
 msgstr "oder fordere gar keine Tags an (--no-tags)"
 
-#: builtin/remote.c:167
+#: builtin/remote.c:170
 msgid "branch(es) to track"
 msgstr "Branch(es) zur Übernahme"
 
-#: builtin/remote.c:168
+#: builtin/remote.c:171
 msgid "master branch"
 msgstr "Hauptbranch"
 
-#: builtin/remote.c:169
-msgid "push|fetch"
-msgstr "push|fetch"
-
-#: builtin/remote.c:170
+#: builtin/remote.c:173
 msgid "set up remote as a mirror to push to or fetch from"
 msgstr ""
 "Aufsetzen des Remote-Repositories als Spiegel-Repository für \"push\" und "
 "\"fetch\""
 
-#: builtin/remote.c:182
+#: builtin/remote.c:185
 msgid "specifying a master branch makes no sense with --mirror"
 msgstr ""
 "Die Option --mirror kann nicht mit der Angabe eines Hauptbranches verwendet "
 "werden."
 
-#: builtin/remote.c:184
+#: builtin/remote.c:187
 msgid "specifying branches to track makes sense only with fetch mirrors"
 msgstr ""
 "Die Angabe von zu folgenden Branches kann nur mit dem Anfordern von "
 "Spiegelarchiven verwendet werden."
 
-#: builtin/remote.c:191 builtin/remote.c:631
+#: builtin/remote.c:194 builtin/remote.c:636
 #, c-format
 msgid "remote %s already exists."
 msgstr "externes Repository %s existiert bereits"
 
-#: builtin/remote.c:195 builtin/remote.c:635
+#: builtin/remote.c:198 builtin/remote.c:640
 #, c-format
 msgid "'%s' is not a valid remote name"
 msgstr "'%s' ist kein gültiger Name für ein Remote-Repository"
 
-#: builtin/remote.c:235
+#: builtin/remote.c:238
 #, c-format
 msgid "Could not setup master '%s'"
 msgstr "Konnte symbolische Referenz für Hauptbranch von '%s' nicht einrichten"
 
-#: builtin/remote.c:337
+#: builtin/remote.c:344
 #, c-format
 msgid "Could not get fetch map for refspec %s"
 msgstr "Konnte Fetch-Map für Refspec %s nicht bekommen"
 
-#: builtin/remote.c:438 builtin/remote.c:446
+#: builtin/remote.c:443 builtin/remote.c:451
 msgid "(matching)"
 msgstr "(übereinstimmend)"
 
-#: builtin/remote.c:450
+#: builtin/remote.c:455
 msgid "(delete)"
 msgstr "(lösche)"
 
-#: builtin/remote.c:624 builtin/remote.c:759 builtin/remote.c:858
+#: builtin/remote.c:629 builtin/remote.c:764 builtin/remote.c:863
 #, c-format
-msgid "No such remote: %s"
-msgstr "Kein solches Remote-Repository: %s"
+msgid "No such remote: '%s'"
+msgstr "Kein solches Remote-Repository: '%s'"
 
-#: builtin/remote.c:641
+#: builtin/remote.c:646
 #, c-format
 msgid "Could not rename config section '%s' to '%s'"
 msgstr "Konnte Sektion '%s' in Konfiguration nicht nach '%s' umbenennen"
 
-#: builtin/remote.c:661
+#: builtin/remote.c:666
 #, c-format
 msgid ""
 "Not updating non-default fetch refspec\n"
@@ -12800,17 +19004,17 @@ msgstr ""
 "\t%s\n"
 "\tBitte aktualisieren Sie, falls notwendig, die Konfiguration manuell."
 
-#: builtin/remote.c:697
+#: builtin/remote.c:701
 #, c-format
 msgid "deleting '%s' failed"
 msgstr "Konnte '%s' nicht löschen"
 
-#: builtin/remote.c:731
+#: builtin/remote.c:735
 #, c-format
 msgid "creating '%s' failed"
 msgstr "Konnte '%s' nicht erstellen"
 
-#: builtin/remote.c:796
+#: builtin/remote.c:801
 msgid ""
 "Note: A branch outside the refs/remotes/ hierarchy was not removed;\n"
 "to delete it, use:"
@@ -12826,113 +19030,118 @@ msgstr[1] ""
 "entfernt;\n"
 "um diese zu entfernen, benutzen Sie:"
 
-#: builtin/remote.c:810
+#: builtin/remote.c:815
 #, c-format
 msgid "Could not remove config section '%s'"
 msgstr "Konnte Sektion '%s' nicht aus Konfiguration entfernen"
 
-#: builtin/remote.c:911
+#: builtin/remote.c:916
 #, c-format
 msgid " new (next fetch will store in remotes/%s)"
 msgstr " neu (wird bei nächstem \"fetch\" in remotes/%s gespeichert)"
 
-#: builtin/remote.c:914
+#: builtin/remote.c:919
 msgid " tracked"
 msgstr " gefolgt"
 
-#: builtin/remote.c:916
+#: builtin/remote.c:921
 msgid " stale (use 'git remote prune' to remove)"
 msgstr " veraltet (benutzen Sie 'git remote prune' zum Löschen)"
 
-#: builtin/remote.c:918
+#: builtin/remote.c:923
 msgid " ???"
 msgstr " ???"
 
-#: builtin/remote.c:959
+#: builtin/remote.c:964
 #, c-format
 msgid "invalid branch.%s.merge; cannot rebase onto > 1 branch"
 msgstr "ungültiges branch.%s.merge; kann Rebase nicht auf > 1 Branch ausführen"
 
-#: builtin/remote.c:967
+#: builtin/remote.c:973
 #, c-format
 msgid "rebases interactively onto remote %s"
 msgstr "interaktiver Rebase auf Remote-Branch %s"
 
-#: builtin/remote.c:968
+#: builtin/remote.c:975
+#, c-format
+msgid "rebases interactively (with merges) onto remote %s"
+msgstr "interaktiver Rebase (mit Merges) auf Remote-Branch %s"
+
+#: builtin/remote.c:978
 #, c-format
 msgid "rebases onto remote %s"
 msgstr "Rebase auf Remote-Branch %s"
 
-#: builtin/remote.c:971
+#: builtin/remote.c:982
 #, c-format
 msgid " merges with remote %s"
 msgstr " führt mit Remote-Branch %s zusammen"
 
-#: builtin/remote.c:974
+#: builtin/remote.c:985
 #, c-format
 msgid "merges with remote %s"
 msgstr "führt mit Remote-Branch %s zusammen"
 
-#: builtin/remote.c:977
+#: builtin/remote.c:988
 #, c-format
 msgid "%-*s    and with remote %s\n"
 msgstr "%-*s    und mit Remote-Branch %s\n"
 
-#: builtin/remote.c:1020
+#: builtin/remote.c:1031
 msgid "create"
 msgstr "erstellt"
 
-#: builtin/remote.c:1023
+#: builtin/remote.c:1034
 msgid "delete"
 msgstr "gelöscht"
 
-#: builtin/remote.c:1027
+#: builtin/remote.c:1038
 msgid "up to date"
 msgstr "aktuell"
 
-#: builtin/remote.c:1030
+#: builtin/remote.c:1041
 msgid "fast-forwardable"
 msgstr "vorspulbar"
 
-#: builtin/remote.c:1033
+#: builtin/remote.c:1044
 msgid "local out of date"
 msgstr "lokal nicht aktuell"
 
-#: builtin/remote.c:1040
+#: builtin/remote.c:1051
 #, c-format
 msgid "    %-*s forces to %-*s (%s)"
 msgstr "    %-*s erzwingt Versandt nach %-*s (%s)"
 
-#: builtin/remote.c:1043
+#: builtin/remote.c:1054
 #, c-format
 msgid "    %-*s pushes to %-*s (%s)"
 msgstr "    %-*s versendet nach %-*s (%s)"
 
-#: builtin/remote.c:1047
+#: builtin/remote.c:1058
 #, c-format
 msgid "    %-*s forces to %s"
 msgstr "    %-*s erzwingt Versand nach %s"
 
-#: builtin/remote.c:1050
+#: builtin/remote.c:1061
 #, c-format
 msgid "    %-*s pushes to %s"
 msgstr "    %-*s versendet nach %s"
 
-#: builtin/remote.c:1118
+#: builtin/remote.c:1129
 msgid "do not query remotes"
 msgstr "keine Abfrage von Remote-Repositories"
 
-#: builtin/remote.c:1145
+#: builtin/remote.c:1156
 #, c-format
 msgid "* remote %s"
 msgstr "* Remote-Repository %s"
 
-#: builtin/remote.c:1146
+#: builtin/remote.c:1157
 #, c-format
 msgid "  Fetch URL: %s"
 msgstr "  URL zum Abholen: %s"
 
-#: builtin/remote.c:1147 builtin/remote.c:1163 builtin/remote.c:1302
+#: builtin/remote.c:1158 builtin/remote.c:1174 builtin/remote.c:1313
 msgid "(no URL)"
 msgstr "(keine URL)"
 
@@ -12940,25 +19149,25 @@ msgstr "(keine URL)"
 #. with the one in " Fetch URL: %s"
 #. translation.
 #.
-#: builtin/remote.c:1161 builtin/remote.c:1163
+#: builtin/remote.c:1172 builtin/remote.c:1174
 #, c-format
 msgid "  Push  URL: %s"
 msgstr "  URL zum Versenden: %s"
 
-#: builtin/remote.c:1165 builtin/remote.c:1167 builtin/remote.c:1169
+#: builtin/remote.c:1176 builtin/remote.c:1178 builtin/remote.c:1180
 #, c-format
 msgid "  HEAD branch: %s"
 msgstr "  Hauptbranch: %s"
 
-#: builtin/remote.c:1165
+#: builtin/remote.c:1176
 msgid "(not queried)"
 msgstr "(nicht abgefragt)"
 
-#: builtin/remote.c:1167
+#: builtin/remote.c:1178
 msgid "(unknown)"
 msgstr "(unbekannt)"
 
-#: builtin/remote.c:1171
+#: builtin/remote.c:1182
 #, c-format
 msgid ""
 "  HEAD branch (remote HEAD is ambiguous, may be one of the following):\n"
@@ -12966,172 +19175,163 @@ msgstr ""
 "  Hauptbranch (externer HEAD ist mehrdeutig, könnte einer der folgenden "
 "sein):\n"
 
-#: builtin/remote.c:1183
+#: builtin/remote.c:1194
 #, c-format
 msgid "  Remote branch:%s"
 msgid_plural "  Remote branches:%s"
 msgstr[0] "  Remote-Branch:%s"
 msgstr[1] "  Remote-Branches:%s"
 
-#: builtin/remote.c:1186 builtin/remote.c:1212
+#: builtin/remote.c:1197 builtin/remote.c:1223
 msgid " (status not queried)"
 msgstr " (Zustand nicht abgefragt)"
 
-#: builtin/remote.c:1195
+#: builtin/remote.c:1206
 msgid "  Local branch configured for 'git pull':"
 msgid_plural "  Local branches configured for 'git pull':"
 msgstr[0] "  Lokaler Branch konfiguriert für 'git pull':"
 msgstr[1] "  Lokale Branches konfiguriert für 'git pull':"
 
-#: builtin/remote.c:1203
+#: builtin/remote.c:1214
 msgid "  Local refs will be mirrored by 'git push'"
 msgstr "  Lokale Referenzen werden von 'git push' gespiegelt"
 
-#: builtin/remote.c:1209
+#: builtin/remote.c:1220
 #, c-format
 msgid "  Local ref configured for 'git push'%s:"
 msgid_plural "  Local refs configured for 'git push'%s:"
 msgstr[0] "  Lokale Referenz konfiguriert für 'git push'%s:"
 msgstr[1] "  Lokale Referenzen konfiguriert für 'git push'%s:"
 
-#: builtin/remote.c:1230
+#: builtin/remote.c:1241
 msgid "set refs/remotes/<name>/HEAD according to remote"
 msgstr "setzt refs/remotes/<Name>/HEAD gemäß dem Remote-Repository"
 
-#: builtin/remote.c:1232
+#: builtin/remote.c:1243
 msgid "delete refs/remotes/<name>/HEAD"
 msgstr "entfernt refs/remotes/<Name>/HEAD"
 
-#: builtin/remote.c:1247
+#: builtin/remote.c:1258
 msgid "Cannot determine remote HEAD"
 msgstr "Kann HEAD des Remote-Repositories nicht bestimmen"
 
-#: builtin/remote.c:1249
+#: builtin/remote.c:1260
 msgid "Multiple remote HEAD branches. Please choose one explicitly with:"
 msgstr ""
 "Mehrere Hauptbranches im Remote-Repository. Bitte wählen Sie explizit einen "
 "aus mit:"
 
-#: builtin/remote.c:1259
+#: builtin/remote.c:1270
 #, c-format
 msgid "Could not delete %s"
 msgstr "Konnte %s nicht entfernen"
 
-#: builtin/remote.c:1267
+#: builtin/remote.c:1278
 #, c-format
 msgid "Not a valid ref: %s"
 msgstr "keine gültige Referenz: %s"
 
-#: builtin/remote.c:1269
+#: builtin/remote.c:1280
 #, c-format
 msgid "Could not setup %s"
 msgstr "Konnte %s nicht einrichten"
 
-#: builtin/remote.c:1287
+#: builtin/remote.c:1298
 #, c-format
 msgid " %s will become dangling!"
 msgstr " %s wird unreferenziert!"
 
-#: builtin/remote.c:1288
+#: builtin/remote.c:1299
 #, c-format
 msgid " %s has become dangling!"
 msgstr " %s wurde unreferenziert!"
 
-#: builtin/remote.c:1298
+#: builtin/remote.c:1309
 #, c-format
 msgid "Pruning %s"
 msgstr "entferne veraltete Branches von %s"
 
-#: builtin/remote.c:1299
+#: builtin/remote.c:1310
 #, c-format
 msgid "URL: %s"
 msgstr "URL: %s"
 
-#: builtin/remote.c:1315
+#: builtin/remote.c:1326
 #, c-format
 msgid " * [would prune] %s"
 msgstr " * [würde veralteten Branch entfernen] %s"
 
-#: builtin/remote.c:1318
+#: builtin/remote.c:1329
 #, c-format
 msgid " * [pruned] %s"
 msgstr "* [veralteten Branch entfernt] %s"
 
-#: builtin/remote.c:1363
+#: builtin/remote.c:1374
 msgid "prune remotes after fetching"
 msgstr "entferne veraltete Branches im Remote-Repository nach \"fetch\""
 
-#: builtin/remote.c:1426 builtin/remote.c:1480 builtin/remote.c:1548
+#: builtin/remote.c:1437 builtin/remote.c:1491 builtin/remote.c:1559
 #, c-format
 msgid "No such remote '%s'"
 msgstr "Kein solches Remote-Repository '%s'"
 
-#: builtin/remote.c:1442
+#: builtin/remote.c:1453
 msgid "add branch"
 msgstr "Branch hinzufügen"
 
-#: builtin/remote.c:1449
+#: builtin/remote.c:1460
 msgid "no remote specified"
 msgstr "kein Remote-Repository angegeben"
 
-#: builtin/remote.c:1466
+#: builtin/remote.c:1477
 msgid "query push URLs rather than fetch URLs"
 msgstr "nur URLs für Push ausgeben"
 
-#: builtin/remote.c:1468
+#: builtin/remote.c:1479
 msgid "return all URLs"
 msgstr "alle URLs ausgeben"
 
-#: builtin/remote.c:1496
+#: builtin/remote.c:1507
 #, c-format
 msgid "no URLs configured for remote '%s'"
 msgstr "Keine URLs für Remote-Repository '%s' konfiguriert."
 
-#: builtin/remote.c:1522
+#: builtin/remote.c:1533
 msgid "manipulate push URLs"
 msgstr "URLs für \"push\" manipulieren"
 
-#: builtin/remote.c:1524
+#: builtin/remote.c:1535
 msgid "add URL"
 msgstr "URL hinzufügen"
 
-#: builtin/remote.c:1526
+#: builtin/remote.c:1537
 msgid "delete URLs"
 msgstr "URLs löschen"
 
-#: builtin/remote.c:1533
+#: builtin/remote.c:1544
 msgid "--add --delete doesn't make sense"
 msgstr ""
 "Die Optionen --add und --delete können nicht gemeinsam verwendet werden."
 
-#: builtin/remote.c:1572
+#: builtin/remote.c:1583
 #, c-format
 msgid "Invalid old URL pattern: %s"
 msgstr "ungültiges altes URL Format: %s"
 
-#: builtin/remote.c:1580
+#: builtin/remote.c:1591
 #, c-format
 msgid "No such URL found: %s"
 msgstr "Keine solche URL gefunden: %s"
 
-#: builtin/remote.c:1582
+#: builtin/remote.c:1593
 msgid "Will not delete all non-push URLs"
 msgstr "Werde keine URLs entfernen, die nicht für \"push\" bestimmt sind"
 
-#: builtin/remote.c:1598
-msgid "be verbose; must be placed before a subcommand"
-msgstr "erweiterte Ausgaben; muss vor einem Unterbefehl angegeben werden"
-
-#: builtin/remote.c:1629
-#, c-format
-msgid "Unknown subcommand: %s"
-msgstr "Unbekannter Unterbefehl: %s"
-
-#: builtin/repack.c:18
+#: builtin/repack.c:23
 msgid "git repack [<options>]"
 msgstr "git repack [<Optionen>]"
 
-#: builtin/repack.c:23
+#: builtin/repack.c:28
 msgid ""
 "Incremental repacks are incompatible with bitmap indexes.  Use\n"
 "--no-write-bitmap-index or disable the pack.writebitmaps configuration."
@@ -13140,130 +19340,282 @@ msgstr ""
 "--no-write-bitmap-index oder deaktivieren Sie die pack.writebitmaps\n"
 "Konfiguration."
 
-#: builtin/repack.c:170
+#: builtin/repack.c:191
+msgid "could not start pack-objects to repack promisor objects"
+msgstr ""
+"Konnte 'pack-objects' für das Neupacken von Objekten aus partiell geklonten\n"
+"Remote-Repositories nicht starten."
+
+#: builtin/repack.c:230 builtin/repack.c:416
+msgid "repack: Expecting full hex object ID lines only from pack-objects."
+msgstr ""
+"repack: Erwarte Zeilen mit vollständiger Hex-Objekt-ID nur von pack-objects."
+
+#: builtin/repack.c:254
+msgid "could not finish pack-objects to repack promisor objects"
+msgstr ""
+"Konnte 'pack-objects' für das Neupacken von Objekten aus partiell geklonten\n"
+"Remote-Repositories nicht abschließen."
+
+#: builtin/repack.c:292
 msgid "pack everything in a single pack"
 msgstr "alles in eine einzige Pack-Datei packen"
 
-#: builtin/repack.c:172
+#: builtin/repack.c:294
 msgid "same as -a, and turn unreachable objects loose"
 msgstr "genau wie -a, unerreichbare Objekte werden aber nicht gelöscht"
 
-#: builtin/repack.c:175
+#: builtin/repack.c:297
 msgid "remove redundant packs, and run git-prune-packed"
 msgstr "redundante Pakete entfernen und \"git-prune-packed\" ausführen"
 
-#: builtin/repack.c:177
+#: builtin/repack.c:299
 msgid "pass --no-reuse-delta to git-pack-objects"
 msgstr "--no-reuse-delta an git-pack-objects übergeben"
 
-#: builtin/repack.c:179
+#: builtin/repack.c:301
 msgid "pass --no-reuse-object to git-pack-objects"
 msgstr "--no-reuse-object an git-pack-objects übergeben"
 
-#: builtin/repack.c:181
+#: builtin/repack.c:303
 msgid "do not run git-update-server-info"
 msgstr "git-update-server-info nicht ausführen"
 
-#: builtin/repack.c:184
+#: builtin/repack.c:306
 msgid "pass --local to git-pack-objects"
 msgstr "--local an git-pack-objects übergeben"
 
-#: builtin/repack.c:186
+#: builtin/repack.c:308
 msgid "write bitmap index"
 msgstr "Bitmap-Index schreiben"
 
-#: builtin/repack.c:187
+#: builtin/repack.c:310
+msgid "pass --delta-islands to git-pack-objects"
+msgstr "--delta-islands an git-pack-objects übergeben"
+
+#: builtin/repack.c:311
 msgid "approxidate"
 msgstr "Datumsangabe"
 
-#: builtin/repack.c:188
+#: builtin/repack.c:312
 msgid "with -A, do not loosen objects older than this"
 msgstr "mit -A, keine Objekte älter als dieses Datum löschen"
 
-#: builtin/repack.c:190
+#: builtin/repack.c:314
 msgid "with -a, repack unreachable objects"
 msgstr "mit -a, nicht erreichbare Objekte neu packen"
 
-#: builtin/repack.c:192
+#: builtin/repack.c:316
 msgid "size of the window used for delta compression"
 msgstr "Größe des Fensters für die Delta-Kompression"
 
-#: builtin/repack.c:193 builtin/repack.c:199
+#: builtin/repack.c:317 builtin/repack.c:323
 msgid "bytes"
 msgstr "Bytes"
 
-#: builtin/repack.c:194
+#: builtin/repack.c:318
 msgid "same as the above, but limit memory size instead of entries count"
 msgstr ""
 "gleiches wie oben, aber die Speichergröße anstatt der\n"
 "Anzahl der Einträge limitieren"
 
-#: builtin/repack.c:196
+#: builtin/repack.c:320
 msgid "limits the maximum delta depth"
 msgstr "die maximale Delta-Tiefe limitieren"
 
-#: builtin/repack.c:198
+#: builtin/repack.c:322
 msgid "limits the maximum number of threads"
 msgstr "maximale Anzahl von Threads limitieren"
 
-#: builtin/repack.c:200
+#: builtin/repack.c:324
 msgid "maximum size of each packfile"
 msgstr "maximale Größe für jede Paketdatei"
 
-#: builtin/repack.c:202
+#: builtin/repack.c:326
 msgid "repack objects in packs marked with .keep"
 msgstr ""
 "Objekte umpacken, die sich in mit .keep markierten Pack-Dateien befinden"
 
-#: builtin/repack.c:212
+#: builtin/repack.c:328
+msgid "do not repack this pack"
+msgstr "dieses Paket nicht neu packen"
+
+#: builtin/repack.c:338
 msgid "cannot delete packs in a precious-objects repo"
 msgstr "kann Pack-Dateien in precious-objects Repository nicht löschen"
 
-#: builtin/repack.c:216
+#: builtin/repack.c:342
 msgid "--keep-unreachable and -A are incompatible"
 msgstr "--keep-unreachable und -A sind inkompatibel"
 
-#: builtin/repack.c:410 builtin/worktree.c:148
+#: builtin/repack.c:425
+msgid "Nothing new to pack."
+msgstr "Nichts Neues zum Packen."
+
+#: builtin/repack.c:486
+#, c-format
+msgid ""
+"WARNING: Some packs in use have been renamed by\n"
+"WARNING: prefixing old- to their name, in order to\n"
+"WARNING: replace them with the new version of the\n"
+"WARNING: file.  But the operation failed, and the\n"
+"WARNING: attempt to rename them back to their\n"
+"WARNING: original names also failed.\n"
+"WARNING: Please rename them in %s manually:\n"
+msgstr ""
+"WARNUNG: Einige in Verwendung befindliche Pakete wurden\n"
+"WARNUNG: umbenannt, indem 'old-' an deren Namen vorrangestellt\n"
+"WARNUNG: wurde, um diese mit der neuen Dateiversion zu ersetzen.\n"
+"WARNUNG: Diese Operation ist fehlgeschlagen. Der Versuch, die\n"
+"WARNUNG: Datei zu ihrem ursprünglichen Namen umzubenennen, schlug\n"
+"WARNUNG: ebenfalls fehl.\n"
+"WARNUNG: Bitte benennen Sie diese manuell nach %s um:\n"
+
+#: builtin/repack.c:534
 #, c-format
 msgid "failed to remove '%s'"
 msgstr "Fehler beim Löschen von '%s'"
 
-#: builtin/replace.c:20
+#: builtin/replace.c:22
 msgid "git replace [-f] <object> <replacement>"
 msgstr "git replace [-f] <Objekt> <Ersetzung>"
 
-#: builtin/replace.c:21
+#: builtin/replace.c:23
 msgid "git replace [-f] --edit <object>"
 msgstr "git replace [-f] --edit <Objekt>"
 
-#: builtin/replace.c:22
+#: builtin/replace.c:24
 msgid "git replace [-f] --graft <commit> [<parent>...]"
 msgstr "git replace [-f] --graft <Commit> [<Eltern-Commit>...]"
 
-#: builtin/replace.c:23
+#: builtin/replace.c:25
+msgid "git replace [-f] --convert-graft-file"
+msgstr "git replace [-f] --convert-graft-file"
+
+#: builtin/replace.c:26
 msgid "git replace -d <object>..."
 msgstr "git replace -d <Objekt>..."
 
-#: builtin/replace.c:24
+#: builtin/replace.c:27
 msgid "git replace [--format=<format>] [-l [<pattern>]]"
 msgstr "git replace [--format=<Format>] [-l [<Muster>]]"
 
-#: builtin/replace.c:331 builtin/replace.c:369 builtin/replace.c:397
+#: builtin/replace.c:90
 #, c-format
-msgid "Not a valid object name: '%s'"
-msgstr "Ungültiger Objekt-Name: '%s'"
+msgid ""
+"invalid replace format '%s'\n"
+"valid formats are 'short', 'medium' and 'long'"
+msgstr ""
+"Ungültiges Ersetzungsformat '%s'\n"
+"Gültige Formate sind 'short', 'medium' und 'long'."
+
+#: builtin/replace.c:125
+#, c-format
+msgid "replace ref '%s' not found"
+msgstr "Ersetzende Referenz '%s' nicht gefunden."
+
+#: builtin/replace.c:141
+#, c-format
+msgid "Deleted replace ref '%s'"
+msgstr "Ersetzende Referenz '%s' gelöscht."
+
+#: builtin/replace.c:153
+#, c-format
+msgid "'%s' is not a valid ref name"
+msgstr "'%s' ist kein gültiger Referenzname."
+
+#: builtin/replace.c:158
+#, c-format
+msgid "replace ref '%s' already exists"
+msgstr "Ersetzende Referenz '%s' existiert bereits."
+
+#: builtin/replace.c:178
+#, c-format
+msgid ""
+"Objects must be of the same type.\n"
+"'%s' points to a replaced object of type '%s'\n"
+"while '%s' points to a replacement object of type '%s'."
+msgstr ""
+"Objekte müssen vom selben Typ sein.\n"
+"'%s' zeigt auf ein ersetztes Objekt vom Typ '%s'\n"
+"während '%s' auf ein ersetzendes Objekt vom Typ '%s'\n"
+"zeigt."
+
+#: builtin/replace.c:229
+#, c-format
+msgid "unable to open %s for writing"
+msgstr "Konnte '%s' nicht zum Schreiben öffnen."
+
+#: builtin/replace.c:242
+msgid "cat-file reported failure"
+msgstr "cat-file meldete Fehler."
+
+#: builtin/replace.c:258
+#, c-format
+msgid "unable to open %s for reading"
+msgstr "Konnte '%s' nicht zum Lesen öffnen."
+
+#: builtin/replace.c:272
+msgid "unable to spawn mktree"
+msgstr "Konnte mktree nicht ausführen."
+
+#: builtin/replace.c:276
+msgid "unable to read from mktree"
+msgstr "Konnte nicht von mktree lesen."
+
+#: builtin/replace.c:285
+msgid "mktree reported failure"
+msgstr "mktree meldete Fehler."
+
+#: builtin/replace.c:289
+msgid "mktree did not return an object name"
+msgstr "mktree lieferte keinen Objektnamen zurück."
 
-#: builtin/replace.c:361
+#: builtin/replace.c:298
+#, c-format
+msgid "unable to fstat %s"
+msgstr "Kann fstat auf %s nicht ausführen."
+
+#: builtin/replace.c:303
+msgid "unable to write object to database"
+msgstr "Konnte Objekt nicht in Datenbank schreiben."
+
+#: builtin/replace.c:322 builtin/replace.c:378 builtin/replace.c:423
+#: builtin/replace.c:453
+#, c-format
+msgid "not a valid object name: '%s'"
+msgstr "Kein gültiger Objektname: '%s'"
+
+#: builtin/replace.c:326
+#, c-format
+msgid "unable to get object type for %s"
+msgstr "Konnte Objektart von %s nicht bestimmten."
+
+#: builtin/replace.c:342
+msgid "editing object file failed"
+msgstr "Bearbeiten von Objektdatei fehlgeschlagen."
+
+#: builtin/replace.c:351
+#, c-format
+msgid "new object is the same as the old one: '%s'"
+msgstr "Neues Objekt ist dasselbe wie das alte: '%s'"
+
+#: builtin/replace.c:384
+#, c-format
+msgid "could not parse %s as a commit"
+msgstr "Konnte nicht %s als Commit parsen."
+
+#: builtin/replace.c:415
 #, c-format
 msgid "bad mergetag in commit '%s'"
 msgstr "ungültiger Merge-Tag in Commit '%s'"
 
-#: builtin/replace.c:363
+#: builtin/replace.c:417
 #, c-format
 msgid "malformed mergetag in commit '%s'"
 msgstr "fehlerhafter Merge-Tag in Commit '%s'"
 
-#: builtin/replace.c:374
+#: builtin/replace.c:429
 #, c-format
 msgid ""
 "original commit '%s' contains mergetag '%s' that is discarded; use --edit "
@@ -13272,224 +19624,310 @@ msgstr ""
 "Der ursprüngliche Commit '%s' enthält Merge-Tag '%s', der verworfen\n"
 "wird; benutzen Sie --edit anstatt --graft"
 
-#: builtin/replace.c:407
+#: builtin/replace.c:468
 #, c-format
-msgid "the original commit '%s' has a gpg signature."
-msgstr "Der ursprüngliche Commit '%s' hat eine GPG-Signatur."
+msgid "the original commit '%s' has a gpg signature"
+msgstr "Der originale Commit '%s' hat eine GPG-Signatur."
 
-#: builtin/replace.c:408
+#: builtin/replace.c:469
 msgid "the signature will be removed in the replacement commit!"
 msgstr "Die Signatur wird in dem Ersetzungs-Commit entfernt!"
 
-#: builtin/replace.c:414
+#: builtin/replace.c:479
 #, c-format
 msgid "could not write replacement commit for: '%s'"
 msgstr "Konnte Ersetzungs-Commit für '%s' nicht schreiben"
 
-#: builtin/replace.c:438
+#: builtin/replace.c:487
+#, c-format
+msgid "graft for '%s' unnecessary"
+msgstr "Künstlicher Vorgänger (\"graft\") für '%s' nicht notwendig."
+
+#: builtin/replace.c:491
+#, c-format
+msgid "new commit is the same as the old one: '%s'"
+msgstr "Neuer Commit ist derselbe wie der alte: '%s'"
+
+#: builtin/replace.c:526
+#, c-format
+msgid ""
+"could not convert the following graft(s):\n"
+"%s"
+msgstr ""
+"Konnte die folgenden künstlichen Vorgänger (\"grafts\") nicht konvertieren:\n"
+"%s"
+
+#: builtin/replace.c:547
 msgid "list replace refs"
 msgstr "ersetzende Referenzen auflisten"
 
-#: builtin/replace.c:439
+#: builtin/replace.c:548
 msgid "delete replace refs"
 msgstr "ersetzende Referenzen löschen"
 
-#: builtin/replace.c:440
+#: builtin/replace.c:549
 msgid "edit existing object"
 msgstr "existierendes Objekt bearbeiten"
 
-#: builtin/replace.c:441
+#: builtin/replace.c:550
 msgid "change a commit's parents"
 msgstr "Eltern-Commits eines Commits ändern"
 
-#: builtin/replace.c:442
+#: builtin/replace.c:551
+msgid "convert existing graft file"
+msgstr "existierende Datei des künstlichen Vorgängers (\"graft\") konvertieren"
+
+#: builtin/replace.c:552
 msgid "replace the ref if it exists"
 msgstr "die Referenz ersetzen, wenn sie existiert"
 
-#: builtin/replace.c:444
+#: builtin/replace.c:554
 msgid "do not pretty-print contents for --edit"
 msgstr "keine ansprechende Anzeige des Objektinhaltes für --edit"
 
-#: builtin/replace.c:445
+#: builtin/replace.c:555
 msgid "use this format"
 msgstr "das angegebene Format benutzen"
 
+#: builtin/replace.c:568
+msgid "--format cannot be used when not listing"
+msgstr "--format kann nicht beim Auflisten verwendet werden."
+
+#: builtin/replace.c:576
+msgid "-f only makes sense when writing a replacement"
+msgstr "-f macht nur beim Schreiben einer Ersetzung Sinn."
+
+#: builtin/replace.c:580
+msgid "--raw only makes sense with --edit"
+msgstr "--raw macht nur mit --edit Sinn."
+
+#: builtin/replace.c:586
+msgid "-d needs at least one argument"
+msgstr "-d benötigt mindestens ein Argument."
+
+#: builtin/replace.c:592
+msgid "bad number of arguments"
+msgstr "Ungültige Anzahl von Argumenten."
+
+#: builtin/replace.c:598
+msgid "-e needs exactly one argument"
+msgstr "-e benötigt genau ein Argument."
+
+#: builtin/replace.c:604
+msgid "-g needs at least one argument"
+msgstr "-g benötigt mindestens ein Argument."
+
+#: builtin/replace.c:610
+msgid "--convert-graft-file takes no argument"
+msgstr "--convert-graft-file erwartet keine Argumente"
+
+#: builtin/replace.c:616
+msgid "only one pattern can be given with -l"
+msgstr "Mit -l kann nur ein Muster angegeben werden."
+
 #: builtin/rerere.c:13
 msgid "git rerere [clear | forget <path>... | status | remaining | diff | gc]"
 msgstr "git rerere [clean | forget <Pfad>... | status | remaining | diff | gc]"
 
-#: builtin/rerere.c:59
+#: builtin/rerere.c:60
 msgid "register clean resolutions in index"
 msgstr "saubere Auflösungen im Index registrieren"
 
-#: builtin/reset.c:29
+#: builtin/rerere.c:79
+msgid "'git rerere forget' without paths is deprecated"
+msgstr "'git rerere forget' ohne Pfade ist veraltet."
+
+#: builtin/rerere.c:113
+#, c-format
+msgid "unable to generate diff for '%s'"
+msgstr "Konnte kein Diff für '%s' generieren."
+
+#: builtin/reset.c:32
 msgid ""
 "git reset [--mixed | --soft | --hard | --merge | --keep] [-q] [<commit>]"
 msgstr ""
 "git reset [--mixed | --soft | --hard | --merge | --keep] [-q] [<Commit>]"
 
-#: builtin/reset.c:30
-msgid "git reset [-q] [<tree-ish>] [--] <paths>..."
-msgstr "git reset [-q] [<Commit-Referenz>] [--] <Pfade>..."
-
-#: builtin/reset.c:31
-msgid "git reset --patch [<tree-ish>] [--] [<paths>...]"
-msgstr "git reset --patch [<Commit-Referenz>] [--] [<Pfade>...]"
+#: builtin/reset.c:33
+msgid "git reset [-q] [<tree-ish>] [--] <pathspec>..."
+msgstr "git reset [-q] [<Commit-Referenz>] [--] <Pfadspezifikation>..."
+
+#: builtin/reset.c:34
+msgid ""
+"git reset [-q] [--pathspec-from-file [--pathspec-file-nul]] [<tree-ish>]"
+msgstr ""
+"git reset [-q] [--pathspec-from-file [--pathspec-file-nul]] "
+"[<Commit-Referenz>]"
 
-#: builtin/reset.c:37
+#: builtin/reset.c:35
+msgid "git reset --patch [<tree-ish>] [--] [<pathspec>...]"
+msgstr "git reset --patch [<Commit-Referenz>] [--] [<Pfadspezifikation>...]"
+
+#: builtin/reset.c:41
 msgid "mixed"
 msgstr "mixed"
 
-#: builtin/reset.c:37
+#: builtin/reset.c:41
 msgid "soft"
 msgstr "soft"
 
-#: builtin/reset.c:37
+#: builtin/reset.c:41
 msgid "hard"
 msgstr "hard"
 
-#: builtin/reset.c:37
+#: builtin/reset.c:41
 msgid "merge"
 msgstr "zusammenführen"
 
-#: builtin/reset.c:37
+#: builtin/reset.c:41
 msgid "keep"
 msgstr "keep"
 
-#: builtin/reset.c:78
+#: builtin/reset.c:82
 msgid "You do not have a valid HEAD."
 msgstr "Sie haben keinen gültigen HEAD."
 
-#: builtin/reset.c:80
+#: builtin/reset.c:84
 msgid "Failed to find tree of HEAD."
 msgstr "Fehler beim Finden des \"Tree\"-Objektes von HEAD."
 
-#: builtin/reset.c:86
+#: builtin/reset.c:90
 #, c-format
 msgid "Failed to find tree of %s."
 msgstr "Fehler beim Finden des \"Tree\"-Objektes von %s."
 
-#: builtin/reset.c:111
+#: builtin/reset.c:115
 #, c-format
 msgid "HEAD is now at %s"
 msgstr "HEAD ist jetzt bei %s"
 
-#: builtin/reset.c:189
+#: builtin/reset.c:194
 #, c-format
 msgid "Cannot do a %s reset in the middle of a merge."
 msgstr "Kann keinen '%s'-Reset durchführen, während ein Merge im Gange ist."
 
-#: builtin/reset.c:289
+#: builtin/reset.c:294 builtin/stash.c:519 builtin/stash.c:594
+#: builtin/stash.c:618
 msgid "be quiet, only report errors"
-msgstr "weniger Ausgaben, meldet nur Fehler"
+msgstr "weniger Ausgaben, nur Fehler melden"
 
-#: builtin/reset.c:291
+#: builtin/reset.c:296
 msgid "reset HEAD and index"
 msgstr "HEAD und Index umsetzen"
 
-#: builtin/reset.c:292
+#: builtin/reset.c:297
 msgid "reset only HEAD"
 msgstr "nur HEAD umsetzen"
 
-#: builtin/reset.c:294 builtin/reset.c:296
+#: builtin/reset.c:299 builtin/reset.c:301
 msgid "reset HEAD, index and working tree"
 msgstr "HEAD, Index und Arbeitsverzeichnis umsetzen"
 
-#: builtin/reset.c:298
+#: builtin/reset.c:303
 msgid "reset HEAD but keep local changes"
 msgstr "HEAD umsetzen, aber lokale Änderungen behalten"
 
-#: builtin/reset.c:304
+#: builtin/reset.c:309
 msgid "record only the fact that removed paths will be added later"
 msgstr "nur speichern, dass gelöschte Pfade später hinzugefügt werden sollen"
 
-#: builtin/reset.c:321
+#: builtin/reset.c:343
 #, c-format
 msgid "Failed to resolve '%s' as a valid revision."
 msgstr "Konnte '%s' nicht als gültigen Commit auflösen."
 
-#: builtin/reset.c:329
+#: builtin/reset.c:351
 #, c-format
 msgid "Failed to resolve '%s' as a valid tree."
 msgstr "Konnte '%s' nicht als gültiges \"Tree\"-Objekt auflösen."
 
-#: builtin/reset.c:338
+#: builtin/reset.c:360
 msgid "--patch is incompatible with --{hard,mixed,soft}"
 msgstr "--patch ist inkompatibel mit --{hard,mixed,soft}"
 
-#: builtin/reset.c:347
+#: builtin/reset.c:370
 msgid "--mixed with paths is deprecated; use 'git reset -- <paths>' instead."
 msgstr ""
 "--mixed mit Pfaden ist veraltet; benutzen Sie stattdessen 'git reset -- "
 "<Pfade>'."
 
-#: builtin/reset.c:349
+#: builtin/reset.c:372
 #, c-format
 msgid "Cannot do %s reset with paths."
 msgstr "Ein '%s'-Reset mit Pfaden ist nicht möglich."
 
-#: builtin/reset.c:359
+#: builtin/reset.c:387
 #, c-format
 msgid "%s reset is not allowed in a bare repository"
 msgstr "'%s'-Reset ist in einem Bare-Repository nicht erlaubt"
 
-#: builtin/reset.c:363
+#: builtin/reset.c:391
 msgid "-N can only be used with --mixed"
 msgstr "-N kann nur mit -mixed benutzt werden"
 
-#: builtin/reset.c:380
+#: builtin/reset.c:412
 msgid "Unstaged changes after reset:"
 msgstr "Nicht zum Commit vorgemerkte Änderungen nach Zurücksetzung:"
 
-#: builtin/reset.c:386
+#: builtin/reset.c:415
+#, c-format
+msgid ""
+"\n"
+"It took %.2f seconds to enumerate unstaged changes after reset.  You can\n"
+"use '--quiet' to avoid this.  Set the config setting reset.quiet to true\n"
+"to make this the default.\n"
+msgstr ""
+"\n"
+"Es dauerte %.2f Sekunden, um über die nach einem Reset nicht zum Commit\n"
+"vorgemerkten Änderungen zu zählen. Sie können '--quiet' benutzen, um\n"
+"das zu verhindern. Setzen Sie die Konfigurationseinstellung reset.quiet\n"
+"auf \"true\", um das zum Standard zu machen.\n"
+
+#: builtin/reset.c:425
 #, c-format
 msgid "Could not reset index file to revision '%s'."
 msgstr "Konnte Index-Datei nicht zu Commit '%s' setzen."
 
-#: builtin/reset.c:390
+#: builtin/reset.c:429
 msgid "Could not write new index file."
 msgstr "Konnte neue Index-Datei nicht schreiben."
 
-#: builtin/rev-list.c:397
+#: builtin/rev-list.c:411
 msgid "cannot combine --exclude-promisor-objects and --missing"
-msgstr "--exclude-promisor-objects und --missing können nicht kombiniert werden."
+msgstr ""
+"--exclude-promisor-objects und --missing können nicht kombiniert werden."
 
-#: builtin/rev-list.c:455
+#: builtin/rev-list.c:472
 msgid "object filtering requires --objects"
 msgstr "Das Filtern von Objekten erfordert --objects."
 
-#: builtin/rev-list.c:458
-#, c-format
-msgid "invalid sparse value '%s'"
-msgstr "Ungültiger \"sparse\"-Wert '%s'."
-
-#: builtin/rev-list.c:499
+#: builtin/rev-list.c:522
 msgid "rev-list does not support display of notes"
 msgstr "rev-list unterstützt keine Anzeige von Notizen"
 
-#: builtin/rev-list.c:502
+#: builtin/rev-list.c:525
 msgid "cannot combine --use-bitmap-index with object filtering"
 msgstr ""
 "--use-bitmap-index kann nicht mit dem Filtern von Objekten kombiniert werden."
 
-#: builtin/rev-parse.c:402
+#: builtin/rev-parse.c:408
 msgid "git rev-parse --parseopt [<options>] -- [<args>...]"
 msgstr "git rev-parse --parseopt [<Optionen>] -- [<Argumente>...]"
 
-#: builtin/rev-parse.c:407
+#: builtin/rev-parse.c:413
 msgid "keep the `--` passed as an arg"
 msgstr "`--` als Argument lassen"
 
-#: builtin/rev-parse.c:409
+#: builtin/rev-parse.c:415
 msgid "stop parsing after the first non-option argument"
 msgstr "das Parsen nach dem ersten Argument, was keine Option ist, stoppen"
 
-#: builtin/rev-parse.c:412
+#: builtin/rev-parse.c:418
 msgid "output in stuck long form"
 msgstr ""
 "Ausgabe in Langform mit Argumenten an den Optionen (getrennt durch '=')"
 
-#: builtin/rev-parse.c:545
+#: builtin/rev-parse.c:551
 msgid ""
 "git rev-parse --parseopt [<options>] -- [<args>...]\n"
 "   or: git rev-parse --sq-quote [<arg>...]\n"
@@ -13504,92 +19942,97 @@ msgstr ""
 "Führen Sie \"git rev-parse --parseopt -h\" für weitere Informationen bei "
 "erster Verwendung aus."
 
-#: builtin/revert.c:23
+#: builtin/revert.c:24
 msgid "git revert [<options>] <commit-ish>..."
 msgstr "git revert [<Optionen>] <Commit-Angabe>..."
 
-#: builtin/revert.c:24
+#: builtin/revert.c:25
 msgid "git revert <subcommand>"
 msgstr "git revert <Unterbefehl>"
 
-#: builtin/revert.c:29
+#: builtin/revert.c:30
 msgid "git cherry-pick [<options>] <commit-ish>..."
 msgstr "git cherry-pick [<Optionen>] <Commit-Angabe>..."
 
-#: builtin/revert.c:30
+#: builtin/revert.c:31
 msgid "git cherry-pick <subcommand>"
 msgstr "git cherry-pick <Unterbefehl>"
 
-#: builtin/revert.c:90
+#: builtin/revert.c:72
+#, c-format
+msgid "option `%s' expects a number greater than zero"
+msgstr "Option `%s' erwartet eine Nummer größer als 0."
+
+#: builtin/revert.c:92
 #, c-format
 msgid "%s: %s cannot be used with %s"
 msgstr "%s: %s kann nicht mit %s verwendet werden"
 
-#: builtin/revert.c:99
+#: builtin/revert.c:102
 msgid "end revert or cherry-pick sequence"
 msgstr "\"revert\" oder \"cherry-pick\" Ablauf beenden"
 
-#: builtin/revert.c:100
+#: builtin/revert.c:103
 msgid "resume revert or cherry-pick sequence"
 msgstr "\"revert\" oder \"cherry-pick\" Ablauf fortsetzen"
 
-#: builtin/revert.c:101
+#: builtin/revert.c:104
 msgid "cancel revert or cherry-pick sequence"
 msgstr "\"revert\" oder \"cherry-pick\" Ablauf abbrechen"
 
-#: builtin/revert.c:102
+#: builtin/revert.c:105
+msgid "skip current commit and continue"
+msgstr "den aktuellen Commit auslassen und fortfahren"
+
+#: builtin/revert.c:107
 msgid "don't automatically commit"
 msgstr "nicht automatisch committen"
 
-#: builtin/revert.c:103
+#: builtin/revert.c:108
 msgid "edit the commit message"
 msgstr "Commit-Beschreibung bearbeiten"
 
-#: builtin/revert.c:106
+#: builtin/revert.c:111
 msgid "parent-number"
 msgstr "Nummer des Elternteils"
 
-#: builtin/revert.c:107
+#: builtin/revert.c:112
 msgid "select mainline parent"
 msgstr "Elternteil der Hauptlinie auswählen"
 
-#: builtin/revert.c:109
+#: builtin/revert.c:114
 msgid "merge strategy"
 msgstr "Merge-Strategie"
 
-#: builtin/revert.c:110
-msgid "option"
-msgstr "Option"
-
-#: builtin/revert.c:111
+#: builtin/revert.c:116
 msgid "option for merge strategy"
 msgstr "Option für Merge-Strategie"
 
-#: builtin/revert.c:120
+#: builtin/revert.c:125
 msgid "append commit name"
 msgstr "Commit-Namen anhängen"
 
-#: builtin/revert.c:122
+#: builtin/revert.c:127
 msgid "preserve initially empty commits"
 msgstr "ursprüngliche, leere Commits erhalten"
 
-#: builtin/revert.c:124
+#: builtin/revert.c:129
 msgid "keep redundant, empty commits"
 msgstr "redundante, leere Commits behalten"
 
-#: builtin/revert.c:214
+#: builtin/revert.c:232
 msgid "revert failed"
 msgstr "\"revert\" fehlgeschlagen"
 
-#: builtin/revert.c:227
+#: builtin/revert.c:245
 msgid "cherry-pick failed"
 msgstr "\"cherry-pick\" fehlgeschlagen"
 
-#: builtin/rm.c:18
+#: builtin/rm.c:19
 msgid "git rm [<options>] [--] <file>..."
 msgstr "git rm [<Optionen>] [--] <Datei>..."
 
-#: builtin/rm.c:206
+#: builtin/rm.c:207
 msgid ""
 "the following file has staged content different from both the\n"
 "file and the HEAD:"
@@ -13604,7 +20047,7 @@ msgstr[1] ""
 "unterschiedlich\n"
 "zu der Datei und HEAD:"
 
-#: builtin/rm.c:211
+#: builtin/rm.c:212
 msgid ""
 "\n"
 "(use -f to force removal)"
@@ -13612,13 +20055,13 @@ msgstr ""
 "\n"
 "(benutzen Sie -f, um die Löschung zu erzwingen)"
 
-#: builtin/rm.c:215
+#: builtin/rm.c:216
 msgid "the following file has changes staged in the index:"
 msgid_plural "the following files have changes staged in the index:"
 msgstr[0] "die folgende Datei hat zum Commit vorgemerkte Änderungen:"
 msgstr[1] "die folgenden Dateien haben zum Commit vorgemerkte Änderungen:"
 
-#: builtin/rm.c:219 builtin/rm.c:228
+#: builtin/rm.c:220 builtin/rm.c:229
 msgid ""
 "\n"
 "(use --cached to keep the file, or -f to force removal)"
@@ -13627,32 +20070,38 @@ msgstr ""
 "(benutzen Sie --cached, um die Datei zu behalten, oder -f, um das Entfernen "
 "zu erzwingen)"
 
-#: builtin/rm.c:225
+#: builtin/rm.c:226
 msgid "the following file has local modifications:"
 msgid_plural "the following files have local modifications:"
 msgstr[0] "die folgende Datei hat lokale Änderungen:"
 msgstr[1] "die folgenden Dateien haben lokale Änderungen:"
 
-#: builtin/rm.c:243
+#: builtin/rm.c:242
 msgid "do not list removed files"
 msgstr "keine gelöschten Dateien auflisten"
 
-#: builtin/rm.c:244
+#: builtin/rm.c:243
 msgid "only remove from the index"
 msgstr "nur aus dem Index entfernen"
 
-#: builtin/rm.c:245
+#: builtin/rm.c:244
 msgid "override the up-to-date check"
 msgstr "die \"up-to-date\" Prüfung überschreiben"
 
-#: builtin/rm.c:246
+#: builtin/rm.c:245
 msgid "allow recursive removal"
 msgstr "rekursives Entfernen erlauben"
 
-#: builtin/rm.c:248
+#: builtin/rm.c:247
 msgid "exit with a zero status even if nothing matched"
 msgstr "mit Rückgabewert 0 beenden, wenn keine Übereinstimmung gefunden wurde"
 
+#: builtin/rm.c:289
+msgid "please stage your changes to .gitmodules or stash them to proceed"
+msgstr ""
+"Bitte merken Sie Ihre Änderungen in .gitmodules zum Commit vor oder\n"
+"benutzen Sie \"stash\", um fortzufahren."
+
 #: builtin/rm.c:307
 #, c-format
 msgid "not removing '%s' recursively without -r"
@@ -13663,12 +20112,7 @@ msgstr "'%s' wird nicht ohne -r rekursiv
 msgid "git rm: unable to remove %s"
 msgstr "git rm: konnte %s nicht löschen"
 
-#: builtin/rm.c:369
-#, c-format
-msgid "could not remove '%s'"
-msgstr "Konnte '%s' nicht löschen"
-
-#: builtin/send-pack.c:19
+#: builtin/send-pack.c:20
 msgid ""
 "git send-pack [--all | --mirror] [--dry-run] [--force] [--receive-pack=<git-"
 "receive-pack>] [--verbose] [--thin] [--atomic] [<host>:]<directory> "
@@ -13681,51 +20125,59 @@ msgstr ""
 "  --all und die explizite Angabe einer <Referenz> schließen sich gegenseitig "
 "aus."
 
-#: builtin/send-pack.c:162
+#: builtin/send-pack.c:163
 msgid "remote name"
 msgstr "Name des Remote-Repositories"
 
-#: builtin/send-pack.c:176
+#: builtin/send-pack.c:177
 msgid "use stateless RPC protocol"
 msgstr "zustandsloses RPC-Protokoll verwenden"
 
-#: builtin/send-pack.c:177
+#: builtin/send-pack.c:178
 msgid "read refs from stdin"
 msgstr "Referenzen von der Standard-Eingabe lesen"
 
-#: builtin/send-pack.c:178
+#: builtin/send-pack.c:179
 msgid "print status from remote helper"
 msgstr "Status des Remote-Helpers ausgeben"
 
 #: builtin/shortlog.c:14
-msgid "git shortlog [<options>] [<revision-range>] [[--] [<path>...]]"
-msgstr "git shortlog [<Optionen>] [<Commitbereich>] [[--] [<Pfad>...]]"
+msgid "git shortlog [<options>] [<revision-range>] [[--] <path>...]"
+msgstr "git shortlog [<Optionen>] [<Commitbereich>] [[--] <Pfad>...]"
+
+#: builtin/shortlog.c:15
+msgid "git log --pretty=short | git shortlog [<options>]"
+msgstr "git log --pretty=short | git shortlog [<Optionen>]"
 
-#: builtin/shortlog.c:263
+#: builtin/shortlog.c:264
 msgid "Group by committer rather than author"
 msgstr "über Commit-Ersteller anstatt Autor gruppieren"
 
-#: builtin/shortlog.c:265
+#: builtin/shortlog.c:266
 msgid "sort output according to the number of commits per author"
 msgstr "die Ausgabe entsprechend der Anzahl von Commits pro Autor sortieren"
 
-#: builtin/shortlog.c:267
+#: builtin/shortlog.c:268
 msgid "Suppress commit descriptions, only provides commit count"
 msgstr "Commit-Beschreibungen unterdrücken, nur Anzahl der Commits liefern"
 
-#: builtin/shortlog.c:269
+#: builtin/shortlog.c:270
 msgid "Show the email address of each author"
 msgstr "die E-Mail-Adresse von jedem Autor anzeigen"
 
-#: builtin/shortlog.c:270
-msgid "w[,i1[,i2]]"
-msgstr "w[,i1[,i2]]"
-
 #: builtin/shortlog.c:271
+msgid "<w>[,<i1>[,<i2>]]"
+msgstr "<w>[,<i1>[,<i2>]]"
+
+#: builtin/shortlog.c:272
 msgid "Linewrap output"
 msgstr "Ausgabe mit Zeilenumbrüchen"
 
-#: builtin/show-branch.c:12
+#: builtin/shortlog.c:301
+msgid "too many arguments given outside repository"
+msgstr "zu viele Argumente außerhalb des Repositories angegeben"
+
+#: builtin/show-branch.c:13
 msgid ""
 "git show-branch [-a | --all] [-r | --remotes] [--topo-order | --date-order]\n"
 "\t\t[--current] [--color[=<when>] | --no-color] [--sparse]\n"
@@ -13737,178 +20189,458 @@ msgstr ""
 "\t\t[--more=<n> | --list | --independent | --merge-base]\n"
 "\t\t[--no-name | --sha1-name] [--topics] [(<Commit> | <glob>)...]"
 
-#: builtin/show-branch.c:16
+#: builtin/show-branch.c:17
 msgid "git show-branch (-g | --reflog)[=<n>[,<base>]] [--list] [<ref>]"
 msgstr "git show-branch (-g | --reflog)[=<n>[,<Basis>]] [--list] [<Referenz>]"
 
-#: builtin/show-branch.c:376
+#: builtin/show-branch.c:395
 #, c-format
 msgid "ignoring %s; cannot handle more than %d ref"
 msgid_plural "ignoring %s; cannot handle more than %d refs"
 msgstr[0] "ignoriere %s; kann nicht mehr als %d Referenz behandeln"
 msgstr[1] "ignoriere %s; kann nicht mehr als %d Referenzen behandeln"
 
-#: builtin/show-branch.c:530
+#: builtin/show-branch.c:548
 #, c-format
 msgid "no matching refs with %s"
 msgstr "keine übereinstimmenden Referenzen mit %s"
 
-#: builtin/show-branch.c:626
+#: builtin/show-branch.c:645
 msgid "show remote-tracking and local branches"
 msgstr "Remote-Tracking und lokale Branches anzeigen"
 
-#: builtin/show-branch.c:628
+#: builtin/show-branch.c:647
 msgid "show remote-tracking branches"
 msgstr "Remote-Tracking-Branches anzeigen"
 
-#: builtin/show-branch.c:630
+#: builtin/show-branch.c:649
 msgid "color '*!+-' corresponding to the branch"
 msgstr "'*!+-' entsprechend des Branches einfärben"
 
-#: builtin/show-branch.c:632
+#: builtin/show-branch.c:651
 msgid "show <n> more commits after the common ancestor"
 msgstr "<n> weitere Commits nach dem gemeinsamen Vorgänger-Commit anzeigen"
 
-#: builtin/show-branch.c:634
+#: builtin/show-branch.c:653
 msgid "synonym to more=-1"
 msgstr "Synonym für more=-1"
 
-#: builtin/show-branch.c:635
+#: builtin/show-branch.c:654
 msgid "suppress naming strings"
 msgstr "Namen unterdrücken"
 
-#: builtin/show-branch.c:637
+#: builtin/show-branch.c:656
 msgid "include the current branch"
 msgstr "den aktuellen Branch einbeziehen"
 
-#: builtin/show-branch.c:639
+#: builtin/show-branch.c:658
 msgid "name commits with their object names"
 msgstr "Commits nach ihren Objektnamen benennen"
 
-#: builtin/show-branch.c:641
+#: builtin/show-branch.c:660
 msgid "show possible merge bases"
 msgstr "mögliche Merge-Basen anzeigen"
 
-#: builtin/show-branch.c:643
+#: builtin/show-branch.c:662
 msgid "show refs unreachable from any other ref"
 msgstr ""
 "Referenzen, die unerreichbar von allen anderen Referenzen sind, anzeigen"
 
-#: builtin/show-branch.c:645
+#: builtin/show-branch.c:664
 msgid "show commits in topological order"
 msgstr "Commits in topologischer Ordnung anzeigen"
 
-#: builtin/show-branch.c:648
+#: builtin/show-branch.c:667
 msgid "show only commits not on the first branch"
 msgstr "nur Commits anzeigen, die sich nicht im ersten Branch befinden"
 
-#: builtin/show-branch.c:650
+#: builtin/show-branch.c:669
 msgid "show merges reachable from only one tip"
 msgstr "Merges anzeigen, die nur von einem Branch aus erreichbar sind"
 
-#: builtin/show-branch.c:652
+#: builtin/show-branch.c:671
 msgid "topologically sort, maintaining date order where possible"
 msgstr "topologische Sortierung, Beibehaltung Datumsordnung wo möglich"
 
-#: builtin/show-branch.c:655
+#: builtin/show-branch.c:674
 msgid "<n>[,<base>]"
 msgstr "<n>[,<Basis>]"
 
-#: builtin/show-branch.c:656
+#: builtin/show-branch.c:675
 msgid "show <n> most recent ref-log entries starting at base"
 msgstr "die <n> jüngsten Einträge im Reflog, beginnend an der Basis, anzeigen"
 
-#: builtin/show-branch.c:690
+#: builtin/show-branch.c:711
 msgid ""
 "--reflog is incompatible with --all, --remotes, --independent or --merge-base"
 msgstr ""
 "--reflog ist inkompatibel mit --all, --remotes, --independent oder --merge-"
 "base"
 
-#: builtin/show-branch.c:714
+#: builtin/show-branch.c:735
 msgid "no branches given, and HEAD is not valid"
 msgstr "keine Branches angegeben, und HEAD ist ungültig"
 
-#: builtin/show-branch.c:717
-msgid "--reflog option needs one branch name"
-msgstr "Die Option --reflog benötigt einen Branchnamen."
+#: builtin/show-branch.c:738
+msgid "--reflog option needs one branch name"
+msgstr "Die Option --reflog benötigt einen Branchnamen."
+
+#: builtin/show-branch.c:741
+#, c-format
+msgid "only %d entry can be shown at one time."
+msgid_plural "only %d entries can be shown at one time."
+msgstr[0] "nur %d Eintrag kann zur selben Zeit angezeigt werden"
+msgstr[1] "nur %d Einträge können zur selben Zeit angezeigt werden"
+
+#: builtin/show-branch.c:745
+#, c-format
+msgid "no such ref %s"
+msgstr "Referenz nicht gefunden: %s"
+
+#: builtin/show-branch.c:831
+#, c-format
+msgid "cannot handle more than %d rev."
+msgid_plural "cannot handle more than %d revs."
+msgstr[0] "Kann nicht mehr als %d Commit behandeln."
+msgstr[1] "Kann nicht mehr als %d Commits behandeln."
+
+#: builtin/show-branch.c:835
+#, c-format
+msgid "'%s' is not a valid ref."
+msgstr "'%s' ist keine gültige Referenz."
+
+#: builtin/show-branch.c:838
+#, c-format
+msgid "cannot find commit %s (%s)"
+msgstr "kann Commit %s (%s) nicht finden"
+
+#: builtin/show-ref.c:12
+msgid ""
+"git show-ref [-q | --quiet] [--verify] [--head] [-d | --dereference] [-s | --"
+"hash[=<n>]] [--abbrev[=<n>]] [--tags] [--heads] [--] [<pattern>...]"
+msgstr ""
+"git show-ref [-q | --quiet] [--verify] [--head] [-d | --dereference] [-s | --"
+"hash[=<n>]] [--abbrev[=<n>]] [--tags] [--heads] [--] [<Muster>...] "
+
+#: builtin/show-ref.c:13
+msgid "git show-ref --exclude-existing[=<pattern>]"
+msgstr "git show-ref --exclude-existing[=<Muster>]"
+
+#: builtin/show-ref.c:162
+msgid "only show tags (can be combined with heads)"
+msgstr "nur Tags anzeigen (kann mit \"heads\" kombiniert werden)"
+
+#: builtin/show-ref.c:163
+msgid "only show heads (can be combined with tags)"
+msgstr "nur Branches anzeigen (kann mit \"tags\" kombiniert werden)"
+
+#: builtin/show-ref.c:164
+msgid "stricter reference checking, requires exact ref path"
+msgstr "strengere Referenzprüfung, erfordert exakten Referenzpfad"
+
+#: builtin/show-ref.c:167 builtin/show-ref.c:169
+msgid "show the HEAD reference, even if it would be filtered out"
+msgstr ""
+"die HEAD-Referenz anzeigen, selbst wenn diese ausgefiltert werden würde"
+
+#: builtin/show-ref.c:171
+msgid "dereference tags into object IDs"
+msgstr "Tags in Objekt-Identifikationen dereferenzieren"
+
+#: builtin/show-ref.c:173
+msgid "only show SHA1 hash using <n> digits"
+msgstr "nur SHA1 Hash mit <n> Ziffern anzeigen"
+
+#: builtin/show-ref.c:177
+msgid "do not print results to stdout (useful with --verify)"
+msgstr ""
+"keine Ausgabe der Ergebnisse in die Standard-Ausgabe (nützlich mit --verify)"
+
+#: builtin/show-ref.c:179
+msgid "show refs from stdin that aren't in local repository"
+msgstr ""
+"Referenzen von der Standard-Eingabe anzeigen, die sich nicht im lokalen "
+"Repository befinden"
+
+#: builtin/sparse-checkout.c:20
+msgid "git sparse-checkout (init|list|set|disable) <options>"
+msgstr "git sparse-checkout (init|list|set|disable) <Optionen>"
+
+#: builtin/sparse-checkout.c:61
+msgid "this worktree is not sparse (sparse-checkout file may not exist)"
+msgstr ""
+"Dieses Arbeitsverzeichnis ist nicht partiell (Datei für partieller Checkout "
+"existiert eventuell nicht)."
+
+#: builtin/sparse-checkout.c:220
+msgid "failed to set extensions.worktreeConfig setting"
+msgstr "Einstellung für extensions.worktreeConfig konnte nicht gesetzt werden"
+
+#: builtin/sparse-checkout.c:237
+msgid "git sparse-checkout init [--cone]"
+msgstr "git sparse-checkout init [--cone]"
+
+#: builtin/sparse-checkout.c:256
+msgid "initialize the sparse-checkout in cone mode"
+msgstr "Initialisiere den partiellen Checkout im Cone-Modus"
+
+#: builtin/sparse-checkout.c:262
+msgid "initialize sparse-checkout"
+msgstr "Partiellen Checkout initialisieren"
+
+#: builtin/sparse-checkout.c:295
+#, c-format
+msgid "failed to open '%s'"
+msgstr "Fehler beim Öffnen von '%s'"
+
+#: builtin/sparse-checkout.c:361
+msgid "git sparse-checkout set (--stdin | <patterns>)"
+msgstr "git sparse-checkout set (--stdin | <Muster>)"
+
+#: builtin/sparse-checkout.c:378
+msgid "read patterns from standard in"
+msgstr "Muster von der Standard-Eingabe lesen"
+
+#: builtin/sparse-checkout.c:384
+msgid "set sparse-checkout patterns"
+msgstr "Setze Muster für partielles Auschecken"
+
+#: builtin/sparse-checkout.c:447
+msgid "disable sparse-checkout"
+msgstr "Partiellen Checkout deaktivieren"
+
+#: builtin/sparse-checkout.c:459
+msgid "error while refreshing working directory"
+msgstr "Fehler während der Aktualisierung des Arbeitsverzeichnisses."
+
+#: builtin/stash.c:22 builtin/stash.c:37
+msgid "git stash list [<options>]"
+msgstr "git stash list [<Optionen>]"
+
+#: builtin/stash.c:23 builtin/stash.c:42
+msgid "git stash show [<options>] [<stash>]"
+msgstr "git stash show [<Optionen>] [<Stash>]"
+
+#: builtin/stash.c:24 builtin/stash.c:47
+msgid "git stash drop [-q|--quiet] [<stash>]"
+msgstr "git stash drop [-q|--quiet] [<Stash>]"
+
+#: builtin/stash.c:25
+msgid "git stash ( pop | apply ) [--index] [-q|--quiet] [<stash>]"
+msgstr "git stash ( pop | apply ) [--index] [-q|--quiet] [<Stash>]"
+
+#: builtin/stash.c:26 builtin/stash.c:62
+msgid "git stash branch <branchname> [<stash>]"
+msgstr "git stash branch <Branch> [<Stash>]"
+
+#: builtin/stash.c:27 builtin/stash.c:67
+msgid "git stash clear"
+msgstr "git stash clear"
+
+#: builtin/stash.c:28 builtin/stash.c:77
+msgid ""
+"git stash [push [-p|--patch] [-k|--[no-]keep-index] [-q|--quiet]\n"
+"          [-u|--include-untracked] [-a|--all] [-m|--message <message>]\n"
+"          [--] [<pathspec>...]]"
+msgstr ""
+"git stash [push [-p|--patch] [-k|--[no-]keep-index] [-q|--quiet]\n"
+"          [-u|--include-untracked] [-a|--all] [-m|--message <Nachricht>]\n"
+"          [--] [<Pfadspezifikation>...]]"
+
+#: builtin/stash.c:31 builtin/stash.c:84
+msgid ""
+"git stash save [-p|--patch] [-k|--[no-]keep-index] [-q|--quiet]\n"
+"          [-u|--include-untracked] [-a|--all] [<message>]"
+msgstr ""
+"git stash save [-p|--patch] [-k|--[no-]keep-index] [-q|--quiet]\n"
+"          [-u|--include-untracked] [-a|--all] [<Nachricht>]"
+
+#: builtin/stash.c:52
+msgid "git stash pop [--index] [-q|--quiet] [<stash>]"
+msgstr "git stash pop [--index] [-q|--quiet] [<Stash>]"
+
+#: builtin/stash.c:57
+msgid "git stash apply [--index] [-q|--quiet] [<stash>]"
+msgstr "git stash apply [--index] [-q|--quiet] [<Stash>]"
+
+#: builtin/stash.c:72
+msgid "git stash store [-m|--message <message>] [-q|--quiet] <commit>"
+msgstr "git stash store [-m|--message <Nachricht>] [-q|--quiet] <Commit>"
+
+#: builtin/stash.c:127
+#, c-format
+msgid "'%s' is not a stash-like commit"
+msgstr "'%s' ist kein \"stash\"-artiger Commit"
+
+#: builtin/stash.c:147
+#, c-format
+msgid "Too many revisions specified:%s"
+msgstr "Zu viele Commits angegeben:%s"
+
+#: builtin/stash.c:161 git-legacy-stash.sh:549
+msgid "No stash entries found."
+msgstr "Keine Stash-Einträge gefunden."
+
+#: builtin/stash.c:175
+#, c-format
+msgid "%s is not a valid reference"
+msgstr "'%s' ist kein gültiger Referenzname."
+
+#: builtin/stash.c:224 git-legacy-stash.sh:75
+msgid "git stash clear with parameters is unimplemented"
+msgstr "git stash clear mit Parametern ist nicht implementiert"
+
+#: builtin/stash.c:403
+msgid "cannot apply a stash in the middle of a merge"
+msgstr "Kann Stash nicht anwenden, solange ein Merge im Gange ist"
 
-#: builtin/show-branch.c:720
+#: builtin/stash.c:414
 #, c-format
-msgid "only %d entry can be shown at one time."
-msgid_plural "only %d entries can be shown at one time."
-msgstr[0] "nur %d Eintrag kann zur selben Zeit angezeigt werden"
-msgstr[1] "nur %d Einträge können zur selben Zeit angezeigt werden"
+msgid "could not generate diff %s^!."
+msgstr "Konnte keinen Diff erzeugen %s^!."
+
+#: builtin/stash.c:421
+msgid "conflicts in index.Try without --index."
+msgstr "Konflikte im Index. Versuchen Sie es ohne --index."
+
+#: builtin/stash.c:427
+msgid "could not save index tree"
+msgstr "Konnte Index-Verzeichnis nicht speichern"
+
+#: builtin/stash.c:436
+msgid "could not restore untracked files from stash"
+msgstr "Konnte unversionierte Dateien vom Stash nicht wiederherstellen."
 
-#: builtin/show-branch.c:724
+#: builtin/stash.c:450
 #, c-format
-msgid "no such ref %s"
-msgstr "Referenz nicht gefunden: %s"
+msgid "Merging %s with %s"
+msgstr "Führe %s mit %s zusammen"
+
+#: builtin/stash.c:460 git-legacy-stash.sh:681
+msgid "Index was not unstashed."
+msgstr "Index wurde nicht aus dem Stash zurückgeladen."
+
+#: builtin/stash.c:521 builtin/stash.c:620
+msgid "attempt to recreate the index"
+msgstr "Versuche Index wiederherzustellen."
 
-#: builtin/show-branch.c:808
+#: builtin/stash.c:554
 #, c-format
-msgid "cannot handle more than %d rev."
-msgid_plural "cannot handle more than %d revs."
-msgstr[0] "Kann nicht mehr als %d Commit behandeln."
-msgstr[1] "Kann nicht mehr als %d Commits behandeln."
+msgid "Dropped %s (%s)"
+msgstr "%s (%s) gelöscht"
 
-#: builtin/show-branch.c:812
+#: builtin/stash.c:557
 #, c-format
-msgid "'%s' is not a valid ref."
-msgstr "'%s' ist keine gültige Referenz."
+msgid "%s: Could not drop stash entry"
+msgstr "%s: Konnte Stash-Eintrag nicht löschen"
 
-#: builtin/show-branch.c:815
+#: builtin/stash.c:582
 #, c-format
-msgid "cannot find commit %s (%s)"
-msgstr "kann Commit %s (%s) nicht finden"
+msgid "'%s' is not a stash reference"
+msgstr "'%s' ist keine Stash-Referenz"
 
-#: builtin/show-ref.c:10
-msgid ""
-"git show-ref [-q | --quiet] [--verify] [--head] [-d | --dereference] [-s | --"
-"hash[=<n>]] [--abbrev[=<n>]] [--tags] [--heads] [--] [<pattern>...]"
+#: builtin/stash.c:632 git-legacy-stash.sh:695
+msgid "The stash entry is kept in case you need it again."
 msgstr ""
-"git show-ref [-q | --quiet] [--verify] [--head] [-d | --dereference] [-s | --"
-"hash[=<n>]] [--abbrev[=<n>]] [--tags] [--heads] [--] [<Muster>...] "
+"Der Stash-Eintrag wird für den Fall behalten, dass Sie diesen nochmal "
+"benötigen."
 
-#: builtin/show-ref.c:11
-msgid "git show-ref --exclude-existing[=<pattern>]"
-msgstr "git show-ref --exclude-existing[=<Muster>]"
+#: builtin/stash.c:655 git-legacy-stash.sh:713
+msgid "No branch name specified"
+msgstr "Kein Branchname spezifiziert"
 
-#: builtin/show-ref.c:159
-msgid "only show tags (can be combined with heads)"
-msgstr "nur Tags anzeigen (kann mit \"heads\" kombiniert werden)"
+#: builtin/stash.c:795 builtin/stash.c:832
+#, c-format
+msgid "Cannot update %s with %s"
+msgstr "Kann nicht %s mit %s aktualisieren."
 
-#: builtin/show-ref.c:160
-msgid "only show heads (can be combined with tags)"
-msgstr "nur Branches anzeigen (kann mit \"tags\" kombiniert werden)"
+#: builtin/stash.c:813 builtin/stash.c:1470 builtin/stash.c:1506
+msgid "stash message"
+msgstr "Stash-Beschreibung"
 
-#: builtin/show-ref.c:161
-msgid "stricter reference checking, requires exact ref path"
-msgstr "strengere Referenzprüfung, erfordert exakten Referenzpfad"
+#: builtin/stash.c:823
+msgid "\"git stash store\" requires one <commit> argument"
+msgstr "\"git stash store\" erwartet ein Argument <Commit>"
 
-#: builtin/show-ref.c:164 builtin/show-ref.c:166
-msgid "show the HEAD reference, even if it would be filtered out"
-msgstr ""
-"die HEAD-Referenz anzeigen, selbst wenn diese ausgefiltert werden würde"
+#: builtin/stash.c:1045 git-legacy-stash.sh:218
+msgid "No changes selected"
+msgstr "Keine Änderungen ausgewählt"
 
-#: builtin/show-ref.c:168
-msgid "dereference tags into object IDs"
-msgstr "Tags in Objekt-Identifikationen dereferenzieren"
+#: builtin/stash.c:1145 git-legacy-stash.sh:150
+msgid "You do not have the initial commit yet"
+msgstr "Sie haben bisher noch keinen initialen Commit"
 
-#: builtin/show-ref.c:170
-msgid "only show SHA1 hash using <n> digits"
-msgstr "nur SHA1 Hash mit <n> Ziffern anzeigen"
+#: builtin/stash.c:1172 git-legacy-stash.sh:165
+msgid "Cannot save the current index state"
+msgstr "Kann den aktuellen Zustand des Index nicht speichern"
 
-#: builtin/show-ref.c:174
-msgid "do not print results to stdout (useful with --verify)"
-msgstr ""
-"keine Ausgabe der Ergebnisse in die Standard-Ausgabe (nützlich mit --verify)"
+#: builtin/stash.c:1181 git-legacy-stash.sh:180
+msgid "Cannot save the untracked files"
+msgstr "Kann die unversionierten Dateien nicht speichern"
 
-#: builtin/show-ref.c:176
-msgid "show refs from stdin that aren't in local repository"
+#: builtin/stash.c:1192 builtin/stash.c:1201 git-legacy-stash.sh:201
+#: git-legacy-stash.sh:214
+msgid "Cannot save the current worktree state"
+msgstr "Kann den aktuellen Zustand des Arbeitsverzeichnisses nicht speichern"
+
+#: builtin/stash.c:1229 git-legacy-stash.sh:234
+msgid "Cannot record working tree state"
+msgstr "Kann Zustand des Arbeitsverzeichnisses nicht aufzeichnen"
+
+#: builtin/stash.c:1278 git-legacy-stash.sh:338
+msgid "Can't use --patch and --include-untracked or --all at the same time"
 msgstr ""
-"Referenzen von der Standard-Eingabe anzeigen, die sich nicht im lokalen "
-"Repository befinden"
+"Kann nicht gleichzeitig --patch und --include-untracked oder --all verwenden"
+
+#: builtin/stash.c:1294
+msgid "Did you forget to 'git add'?"
+msgstr "Haben Sie vielleicht 'git add' vergessen?"
+
+#: builtin/stash.c:1309 git-legacy-stash.sh:346
+msgid "No local changes to save"
+msgstr "Keine lokalen Änderungen zum Speichern"
+
+#: builtin/stash.c:1316 git-legacy-stash.sh:351
+msgid "Cannot initialize stash"
+msgstr "Kann \"stash\" nicht initialisieren"
+
+#: builtin/stash.c:1331 git-legacy-stash.sh:355
+msgid "Cannot save the current status"
+msgstr "Kann den aktuellen Status nicht speichern"
+
+#: builtin/stash.c:1336
+#, c-format
+msgid "Saved working directory and index state %s"
+msgstr "Arbeitsverzeichnis und Index-Status %s gespeichert."
+
+#: builtin/stash.c:1426 git-legacy-stash.sh:385
+msgid "Cannot remove worktree changes"
+msgstr "Kann Änderungen im Arbeitsverzeichnis nicht löschen"
+
+#: builtin/stash.c:1461 builtin/stash.c:1497
+msgid "keep index"
+msgstr "behalte Index"
+
+#: builtin/stash.c:1463 builtin/stash.c:1499
+msgid "stash in patch mode"
+msgstr "Stash in Patch-Modus"
+
+#: builtin/stash.c:1464 builtin/stash.c:1500
+msgid "quiet mode"
+msgstr "weniger Ausgaben"
+
+#: builtin/stash.c:1466 builtin/stash.c:1502
+msgid "include untracked files in stash"
+msgstr "unversionierte Dateien in Stash einbeziehen"
+
+#: builtin/stash.c:1468 builtin/stash.c:1504
+msgid "include ignore files"
+msgstr "ignorierte Dateien einbeziehen"
+
+#: builtin/stash.c:1564
+#, c-format
+msgid "could not exec %s"
+msgstr "Konnte 'exec %s' nicht ausführen."
 
 #: builtin/stripspace.c:18
 msgid "git stripspace [-s | --strip-comments]"
@@ -13918,160 +20650,191 @@ msgstr "git stripspace [-s | --strip-com
 msgid "git stripspace [-c | --comment-lines]"
 msgstr "git stripspace [-c | --comment-lines]"
 
-#: builtin/stripspace.c:36
+#: builtin/stripspace.c:37
 msgid "skip and remove all lines starting with comment character"
 msgstr ""
 "alle Zeilen, die mit dem Kommentarzeichen beginnen, überspringen und "
 "entfernen"
 
-#: builtin/stripspace.c:39
+#: builtin/stripspace.c:40
 msgid "prepend comment character and space to each line"
 msgstr "Kommentarzeichen mit Leerzeichen an jede Zeile voranstellen"
 
-#: builtin/submodule--helper.c:35 builtin/submodule--helper.c:1669
-#, c-format
-msgid "No such ref: %s"
-msgstr "Referenz nicht gefunden: %s"
-
-#: builtin/submodule--helper.c:42 builtin/submodule--helper.c:1678
+#: builtin/submodule--helper.c:47 builtin/submodule--helper.c:1970
 #, c-format
 msgid "Expecting a full ref name, got %s"
 msgstr "Vollständiger Referenzname erwartet, %s erhalten"
 
-#: builtin/submodule--helper.c:59
+#: builtin/submodule--helper.c:64
 msgid "submodule--helper print-default-remote takes no arguments"
 msgstr "'submodule--helper print-default-remote' erwartet keine Argumente."
 
-#: builtin/submodule--helper.c:96
+#: builtin/submodule--helper.c:102
 #, c-format
 msgid "cannot strip one component off url '%s'"
 msgstr "Kann eine Komponente von URL '%s' nicht extrahieren"
 
-#: builtin/submodule--helper.c:404 builtin/submodule--helper.c:1198
+#: builtin/submodule--helper.c:410 builtin/submodule--helper.c:1380
 msgid "alternative anchor for relative paths"
 msgstr "Alternativer Anker für relative Pfade"
 
-#: builtin/submodule--helper.c:409
+#: builtin/submodule--helper.c:415
 msgid "git submodule--helper list [--prefix=<path>] [<path>...]"
 msgstr "git submodule--helper list [--prefix=<Pfad>] [<Pfad>...]"
 
-#: builtin/submodule--helper.c:460 builtin/submodule--helper.c:483
+#: builtin/submodule--helper.c:472 builtin/submodule--helper.c:630
+#: builtin/submodule--helper.c:653
 #, c-format
 msgid "No url found for submodule path '%s' in .gitmodules"
 msgstr "Keine URL für Submodul-Pfad '%s' in .gitmodules gefunden"
 
-#: builtin/submodule--helper.c:498
+#: builtin/submodule--helper.c:524
+#, c-format
+msgid "Entering '%s'\n"
+msgstr "Betrete '%s'\n"
+
+#: builtin/submodule--helper.c:527
+#, c-format
+msgid ""
+"run_command returned non-zero status for %s\n"
+"."
+msgstr ""
+"run_command gab nicht-Null Status für '%s' zurück.\n"
+"."
+
+#: builtin/submodule--helper.c:549
+#, c-format
+msgid ""
+"run_command returned non-zero status while recursing in the nested "
+"submodules of %s\n"
+"."
+msgstr ""
+"run_command gab während der Rekursion in verschachtelte Submodule von %s "
+"einen\n"
+"nicht-Null Status zurück.\n"
+"."
+
+#: builtin/submodule--helper.c:565
+msgid "Suppress output of entering each submodule command"
+msgstr ""
+"Ausgaben beim Betreten und der Befehlsausführung in einem Submodul "
+"unterdrücken"
+
+#: builtin/submodule--helper.c:567 builtin/submodule--helper.c:1053
+msgid "Recurse into nested submodules"
+msgstr "Rekursion in verschachtelte Submodule durchführen"
+
+#: builtin/submodule--helper.c:572
+msgid "git submodule--helper foreach [--quiet] [--recursive] [--] <command>"
+msgstr "git submodule--helper foreach [--quiet] [--recursive] [--] <Befehl>"
+
+#: builtin/submodule--helper.c:599
 #, c-format
 msgid ""
-"could not lookup configuration '%s'. Assuming this repository is its own "
+"could not look up configuration '%s'. Assuming this repository is its own "
 "authoritative upstream."
 msgstr ""
-"Konnte Konfiguration '%s' nicht nachschlagen. Nehme an, dass dieses "
-"Repository\n"
-"sein eigenes verbindliches Upstream-Repository ist."
+"Konnte Konfiguration '%s' nicht nachschlagen. Nehme an, dass dieses\n"
+"Repository sein eigenes verbindliches Upstream-Repository ist."
 
-#: builtin/submodule--helper.c:509
+#: builtin/submodule--helper.c:667
 #, c-format
 msgid "Failed to register url for submodule path '%s'"
 msgstr ""
 "Fehler beim Eintragen der URL für Submodul-Pfad '%s' in die Konfiguration."
 
-#: builtin/submodule--helper.c:513
+#: builtin/submodule--helper.c:671
 #, c-format
 msgid "Submodule '%s' (%s) registered for path '%s'\n"
 msgstr "Submodul '%s' (%s) für Pfad '%s' in die Konfiguration eingetragen.\n"
 
-#: builtin/submodule--helper.c:523
+#: builtin/submodule--helper.c:681
 #, c-format
 msgid "warning: command update mode suggested for submodule '%s'\n"
 msgstr "Warnung: 'update'-Modus für Submodul '%s' vorgeschlagen\n"
 
-#: builtin/submodule--helper.c:530
+#: builtin/submodule--helper.c:688
 #, c-format
 msgid "Failed to register update mode for submodule path '%s'"
 msgstr ""
 "Fehler bei Änderung des Aktualisierungsmodus für Submodul-Pfad '%s' in der\n"
 "Konfiguration."
 
-#: builtin/submodule--helper.c:552
+#: builtin/submodule--helper.c:710
 msgid "Suppress output for initializing a submodule"
 msgstr "Ausgaben bei Initialisierung eines Submoduls unterdrücken"
 
-#: builtin/submodule--helper.c:557
-msgid "git submodule--helper init [<path>]"
-msgstr "git submodule--helper init [<Pfad>]"
+#: builtin/submodule--helper.c:715
+msgid "git submodule--helper init [<options>] [<path>]"
+msgstr "git submodule--helper init [<Optionen>] [<Pfad>]"
 
-#: builtin/submodule--helper.c:625 builtin/submodule--helper.c:747
+#: builtin/submodule--helper.c:787 builtin/submodule--helper.c:914
 #, c-format
 msgid "no submodule mapping found in .gitmodules for path '%s'"
 msgstr "Keine Submodul-Zuordnung in .gitmodules für Pfad '%s' gefunden"
 
-#: builtin/submodule--helper.c:660
+#: builtin/submodule--helper.c:827
 #, c-format
 msgid "could not resolve HEAD ref inside the submodule '%s'"
 msgstr "Konnte HEAD-Referenz nicht innerhalb des Submodul-Pfads '%s' auflösen."
 
-#: builtin/submodule--helper.c:687 builtin/submodule--helper.c:856
+#: builtin/submodule--helper.c:854 builtin/submodule--helper.c:1023
 #, c-format
 msgid "failed to recurse into submodule '%s'"
 msgstr "Fehler bei Rekursion in Submodul '%s'."
 
-#: builtin/submodule--helper.c:711 builtin/submodule--helper.c:1021
+#: builtin/submodule--helper.c:878 builtin/submodule--helper.c:1189
 msgid "Suppress submodule status output"
 msgstr "Ausgabe über Submodul-Status unterdrücken"
 
-#: builtin/submodule--helper.c:712
+#: builtin/submodule--helper.c:879
 msgid ""
 "Use commit stored in the index instead of the one stored in the submodule "
 "HEAD"
 msgstr ""
 "Benutze den Commit, der im Index gespeichert ist, statt den im Submodul HEAD"
 
-#: builtin/submodule--helper.c:713
+#: builtin/submodule--helper.c:880
 msgid "recurse into nested submodules"
 msgstr "Rekursion in verschachtelte Submodule durchführen"
 
-#: builtin/submodule--helper.c:718
+#: builtin/submodule--helper.c:885
 msgid "git submodule status [--quiet] [--cached] [--recursive] [<path>...]"
 msgstr "git submodule status [--quiet] [--cached] [--recursive] [<Pfad>...]"
 
-#: builtin/submodule--helper.c:742
+#: builtin/submodule--helper.c:909
 msgid "git submodule--helper name <path>"
 msgstr "git submodule--helper name <Pfad>"
 
-#: builtin/submodule--helper.c:806
+#: builtin/submodule--helper.c:973
 #, c-format
 msgid "Synchronizing submodule url for '%s'\n"
 msgstr "Synchronisiere Submodul-URL für '%s'\n"
 
-#: builtin/submodule--helper.c:812
+#: builtin/submodule--helper.c:979
 #, c-format
 msgid "failed to register url for submodule path '%s'"
 msgstr "Fehler beim Registrieren der URL für Submodul-Pfad '%s'."
 
-#: builtin/submodule--helper.c:826
+#: builtin/submodule--helper.c:993
 #, c-format
 msgid "failed to get the default remote for submodule '%s'"
 msgstr "Fehler beim Lesen des Standard-Remote-Repositories für Submodul '%s'."
 
-#: builtin/submodule--helper.c:837
+#: builtin/submodule--helper.c:1004
 #, c-format
 msgid "failed to update remote for submodule '%s'"
 msgstr "Fehler beim Aktualisieren des Remote-Repositories für Submodul '%s'."
 
-#: builtin/submodule--helper.c:885
+#: builtin/submodule--helper.c:1051
 msgid "Suppress output of synchronizing submodule url"
 msgstr "Ausgaben bei der Synchronisierung der Submodul-URLs unterdrücken"
 
-#: builtin/submodule--helper.c:887
-msgid "Recurse into nested submodules"
-msgstr "Rekursion in verschachtelte Submodule durchführen"
-
-#: builtin/submodule--helper.c:892
+#: builtin/submodule--helper.c:1058
 msgid "git submodule--helper sync [--quiet] [--recursive] [<path>]"
 msgstr "git submodule--helper sync [--quiet] [--recursive] [<Pfad>]"
 
-#: builtin/submodule--helper.c:946
+#: builtin/submodule--helper.c:1112
 #, c-format
 msgid ""
 "Submodule work tree '%s' contains a .git directory (use 'rm -rf' if you "
@@ -14081,7 +20844,7 @@ msgstr ""
 "(benutzen Sie 'rm -rf', wenn Sie dieses wirklich mitsamt seiner Historie\n"
 "löschen möchten)"
 
-#: builtin/submodule--helper.c:958
+#: builtin/submodule--helper.c:1124
 #, c-format
 msgid ""
 "Submodule work tree '%s' contains local modifications; use '-f' to discard "
@@ -14090,81 +20853,101 @@ msgstr ""
 "Arbeitsverzeichnis von Submodul in '%s' enthält lokale Änderungen;\n"
 "verwenden Sie '-f', um diese zu verwerfen."
 
-#: builtin/submodule--helper.c:966
+#: builtin/submodule--helper.c:1132
 #, c-format
 msgid "Cleared directory '%s'\n"
 msgstr "Verzeichnis '%s' bereinigt.\n"
 
-#: builtin/submodule--helper.c:968
+#: builtin/submodule--helper.c:1134
 #, c-format
 msgid "Could not remove submodule work tree '%s'\n"
 msgstr "Konnte Arbeitsverzeichnis des Submoduls in '%s' nicht löschen.\n"
 
-#: builtin/submodule--helper.c:977
+#: builtin/submodule--helper.c:1145
 #, c-format
 msgid "could not create empty submodule directory %s"
 msgstr "Konnte kein leeres Verzeichnis für Submodul in '%s' erstellen."
 
-#: builtin/submodule--helper.c:993
+#: builtin/submodule--helper.c:1161
 #, c-format
 msgid "Submodule '%s' (%s) unregistered for path '%s'\n"
 msgstr "Submodul '%s' (%s) für Pfad '%s' ausgetragen.\n"
 
-#: builtin/submodule--helper.c:1022
+#: builtin/submodule--helper.c:1190
 msgid "Remove submodule working trees even if they contain local changes"
-msgstr "Arbeitsverzeichnisse von Submodulen löschen, auch wenn lokale Änderungen vorliegen"
+msgstr ""
+"Arbeitsverzeichnisse von Submodulen löschen, auch wenn lokale Änderungen "
+"vorliegen"
 
-#: builtin/submodule--helper.c:1023
+#: builtin/submodule--helper.c:1191
 msgid "Unregister all submodules"
 msgstr "alle Submodule austragen"
 
-#: builtin/submodule--helper.c:1028
+#: builtin/submodule--helper.c:1196
 msgid ""
 "git submodule deinit [--quiet] [-f | --force] [--all | [--] [<path>...]]"
-msgstr "git submodule deinit [--quiet] [-f | --force] [--all | [--] [<Pfad>...]]"
+msgstr ""
+"git submodule deinit [--quiet] [-f | --force] [--all | [--] [<Pfad>...]]"
 
-#: builtin/submodule--helper.c:1042
+#: builtin/submodule--helper.c:1210
 msgid "Use '--all' if you really want to deinitialize all submodules"
 msgstr ""
 "Verwenden Sie '--all', wenn Sie wirklich alle Submodule deinitialisieren\n"
 "möchten."
 
-#: builtin/submodule--helper.c:1133 builtin/submodule--helper.c:1136
+#: builtin/submodule--helper.c:1275
+msgid ""
+"An alternate computed from a superproject's alternate is invalid.\n"
+"To allow Git to clone without an alternate in such a case, set\n"
+"submodule.alternateErrorStrategy to 'info' or, equivalently, clone with\n"
+"'--reference-if-able' instead of '--reference'."
+msgstr ""
+"Eine Alternative, die von einer übergeordneten Projekt-Alternative\n"
+"berechnet wurde, ist ungültig.\n"
+"Um Git das Klonen ohne Alternative in solch einem Fall zu erlauben, setze\n"
+"submodule.alternateErrorStrategy auf 'info' oder klone mit der Option\n"
+"'--reference-if-able' statt '--reference'."
+
+#: builtin/submodule--helper.c:1314 builtin/submodule--helper.c:1317
 #, c-format
 msgid "submodule '%s' cannot add alternate: %s"
 msgstr "Submodul '%s' kann Alternative nicht hinzufügen: %s"
 
-#: builtin/submodule--helper.c:1172
+#: builtin/submodule--helper.c:1353
 #, c-format
 msgid "Value '%s' for submodule.alternateErrorStrategy is not recognized"
 msgstr "Wert '%s' für submodule.alternateErrorStrategy wird nicht erkannt"
 
-#: builtin/submodule--helper.c:1179
+#: builtin/submodule--helper.c:1360
 #, c-format
 msgid "Value '%s' for submodule.alternateLocation is not recognized"
 msgstr "Wert '%s' für submodule.alternateLocation wird nicht erkannt."
 
-#: builtin/submodule--helper.c:1201
+#: builtin/submodule--helper.c:1383
 msgid "where the new submodule will be cloned to"
 msgstr "Pfad für neues Submodul"
 
-#: builtin/submodule--helper.c:1204
+#: builtin/submodule--helper.c:1386
 msgid "name of the new submodule"
 msgstr "Name des neuen Submoduls"
 
-#: builtin/submodule--helper.c:1207
+#: builtin/submodule--helper.c:1389
 msgid "url where to clone the submodule from"
 msgstr "URL von der das Submodul geklont wird"
 
-#: builtin/submodule--helper.c:1213
+#: builtin/submodule--helper.c:1397
 msgid "depth for shallow clones"
 msgstr "Tiefe des Klons mit unvollständiger Historie (shallow)"
 
-#: builtin/submodule--helper.c:1216 builtin/submodule--helper.c:1587
+#: builtin/submodule--helper.c:1400 builtin/submodule--helper.c:1897
 msgid "force cloning progress"
 msgstr "Fortschrittsanzeige beim Klonen erzwingen"
 
-#: builtin/submodule--helper.c:1221
+#: builtin/submodule--helper.c:1402 builtin/submodule--helper.c:1899
+msgid "disallow cloning into non-empty directory"
+msgstr "Klonen in ein nicht leeres Verzeichnis verbieten"
+
+#: builtin/submodule--helper.c:1407
 msgid ""
 "git submodule--helper clone [--prefix=<path>] [--quiet] [--reference "
 "<repository>] [--name <name>] [--depth <depth>] --url <url> --path <path>"
@@ -14173,88 +20956,111 @@ msgstr ""
 "<Repository>] [--name <Name>] [--url <URL>] [--name <Name>] [--depth "
 "<Tiefe>] --url <URL> --path <Pfad>"
 
-#: builtin/submodule--helper.c:1252
+#: builtin/submodule--helper.c:1431
+#, c-format
+msgid "refusing to create/use '%s' in another submodule's git dir"
+msgstr ""
+"Erstellung/Benutzung von '%s' in einem anderen Submodul-Git-Verzeichnis\n"
+"verweigert."
+
+#: builtin/submodule--helper.c:1442
 #, c-format
 msgid "clone of '%s' into submodule path '%s' failed"
-msgstr "Klonen von '%s' in Submodul-Pfad '%s' fehlgeschlagen"
+msgstr "Klonen von '%s' in Submodul-Pfad '%s' fehlgeschlagen."
+
+#: builtin/submodule--helper.c:1446
+#, c-format
+msgid "directory not empty: '%s'"
+msgstr "Verzeichnis ist nicht leer: '%s'"
 
-#: builtin/submodule--helper.c:1267
+#: builtin/submodule--helper.c:1458
 #, c-format
 msgid "could not get submodule directory for '%s'"
 msgstr "Konnte Submodul-Verzeichnis '%s' nicht finden."
 
-#: builtin/submodule--helper.c:1332
+#: builtin/submodule--helper.c:1494
+#, c-format
+msgid "Invalid update mode '%s' for submodule path '%s'"
+msgstr "Ungültiger Aktualisierungsmodus '%s' für Submodul-Pfad '%s'."
+
+#: builtin/submodule--helper.c:1498
+#, c-format
+msgid "Invalid update mode '%s' configured for submodule path '%s'"
+msgstr ""
+"Ungültiger Aktualisierungsmodus '%s' für Submodul-Pfad '%s' konfiguriert."
+
+#: builtin/submodule--helper.c:1594
 #, c-format
 msgid "Submodule path '%s' not initialized"
 msgstr "Submodul-Pfad '%s' nicht initialisiert"
 
-#: builtin/submodule--helper.c:1336
+#: builtin/submodule--helper.c:1598
 msgid "Maybe you want to use 'update --init'?"
 msgstr "Meinten Sie vielleicht 'update --init'?"
 
-#: builtin/submodule--helper.c:1365
+#: builtin/submodule--helper.c:1628
 #, c-format
 msgid "Skipping unmerged submodule %s"
 msgstr "Überspringe nicht zusammengeführtes Submodul %s"
 
-#: builtin/submodule--helper.c:1394
+#: builtin/submodule--helper.c:1657
 #, c-format
 msgid "Skipping submodule '%s'"
 msgstr "Überspringe Submodul '%s'"
 
-#: builtin/submodule--helper.c:1527
+#: builtin/submodule--helper.c:1803
 #, c-format
 msgid "Failed to clone '%s'. Retry scheduled"
 msgstr "Fehler beim Klonen von '%s'. Weiterer Versuch geplant"
 
-#: builtin/submodule--helper.c:1538
+#: builtin/submodule--helper.c:1814
 #, c-format
 msgid "Failed to clone '%s' a second time, aborting"
 msgstr "Zweiter Versuch '%s' zu klonen fehlgeschlagen, breche ab."
 
-#: builtin/submodule--helper.c:1568 builtin/submodule--helper.c:1788
+#: builtin/submodule--helper.c:1876 builtin/submodule--helper.c:2120
 msgid "path into the working tree"
 msgstr "Pfad zum Arbeitsverzeichnis"
 
-#: builtin/submodule--helper.c:1571
+#: builtin/submodule--helper.c:1879
 msgid "path into the working tree, across nested submodule boundaries"
 msgstr ""
 "Pfad zum Arbeitsverzeichnis, über verschachtelte Submodul-Grenzen hinweg"
 
-#: builtin/submodule--helper.c:1575
+#: builtin/submodule--helper.c:1883
 msgid "rebase, merge, checkout or none"
 msgstr "rebase, merge, checkout oder none"
 
-#: builtin/submodule--helper.c:1579
+#: builtin/submodule--helper.c:1889
 msgid "Create a shallow clone truncated to the specified number of revisions"
 msgstr ""
 "Erstellung eines Klons mit unvollständiger Historie (shallow), abgeschnitten "
 "bei\n"
 "der angegebenen Anzahl von Commits."
 
-#: builtin/submodule--helper.c:1582
+#: builtin/submodule--helper.c:1892
 msgid "parallel jobs"
 msgstr "Parallele Ausführungen"
 
-#: builtin/submodule--helper.c:1584
+#: builtin/submodule--helper.c:1894
 msgid "whether the initial clone should follow the shallow recommendation"
 msgstr ""
 "ob das initiale Klonen den Empfehlungen für eine unvollständige\n"
 "Historie (shallow) folgen soll"
 
-#: builtin/submodule--helper.c:1585
+#: builtin/submodule--helper.c:1895
 msgid "don't print cloning progress"
 msgstr "keine Fortschrittsanzeige beim Klonen"
 
-#: builtin/submodule--helper.c:1592
-msgid "git submodule--helper update_clone [--prefix=<path>] [<path>...]"
-msgstr "git submodule--helper update_clone [--prefix=<Pfad>] [<Pfad>...]"
+#: builtin/submodule--helper.c:1904
+msgid "git submodule--helper update-clone [--prefix=<path>] [<path>...]"
+msgstr "git submodule--helper update-clone [--prefix=<Pfad>] [<Pfad>...]"
 
-#: builtin/submodule--helper.c:1605
+#: builtin/submodule--helper.c:1917
 msgid "bad value for update parameter"
 msgstr "Fehlerhafter Wert für --update Parameter"
 
-#: builtin/submodule--helper.c:1673
+#: builtin/submodule--helper.c:1965
 #, c-format
 msgid ""
 "Submodule (%s) branch configured to inherit branch from superproject, but "
@@ -14263,20 +21069,52 @@ msgstr ""
 "Branch von Submodul (%s) ist konfiguriert, den Branch des Hauptprojektes\n"
 "zu erben, aber das Hauptprojekt befindet sich auf keinem Branch."
 
-#: builtin/submodule--helper.c:1789
+#: builtin/submodule--helper.c:2088
+#, c-format
+msgid "could not get a repository handle for submodule '%s'"
+msgstr "Konnte kein Repository-Handle für Submodul '%s' erhalten."
+
+#: builtin/submodule--helper.c:2121
 msgid "recurse into submodules"
 msgstr "Rekursion in Submodule durchführen"
 
-#: builtin/submodule--helper.c:1795
-msgid "git submodule--helper embed-git-dir [<path>...]"
-msgstr "git submodule--helper embed-git-dir [<Pfad>...]"
+#: builtin/submodule--helper.c:2127
+msgid "git submodule--helper absorb-git-dirs [<options>] [<path>...]"
+msgstr "git submodule--helper absorb-git-dirs [<Optionen>] [<Pfad>...]"
+
+#: builtin/submodule--helper.c:2183
+msgid "check if it is safe to write to the .gitmodules file"
+msgstr "prüfen, ob es sicher ist, in die Datei .gitmodules zu schreiben"
+
+#: builtin/submodule--helper.c:2186
+msgid "unset the config in the .gitmodules file"
+msgstr "Konfiguration in der .gitmodules-Datei entfernen"
+
+#: builtin/submodule--helper.c:2191
+msgid "git submodule--helper config <name> [<value>]"
+msgstr "git submodule--helper config <name> [<Wert>]"
+
+#: builtin/submodule--helper.c:2192
+msgid "git submodule--helper config --unset <name>"
+msgstr "git submodule--helper config --unset <Name>"
 
-#: builtin/submodule--helper.c:1857
+#: builtin/submodule--helper.c:2193
+msgid "git submodule--helper config --check-writeable"
+msgstr "git submodule--helper config --check-writeable"
+
+#: builtin/submodule--helper.c:2212 git-submodule.sh:173
+#, sh-format
+msgid "please make sure that the .gitmodules file is in the working tree"
+msgstr ""
+"Bitte stellen Sie sicher, dass sich die Datei .gitmodules im "
+"Arbeitsverzeichnis befindet."
+
+#: builtin/submodule--helper.c:2262 git.c:433 git.c:684
 #, c-format
 msgid "%s doesn't support --super-prefix"
 msgstr "%s unterstützt kein --super-prefix"
 
-#: builtin/submodule--helper.c:1863
+#: builtin/submodule--helper.c:2268
 #, c-format
 msgid "'%s' is not a valid submodule--helper subcommand"
 msgstr "'%s' ist kein gültiger Unterbefehl von submodule--helper"
@@ -14302,27 +21140,27 @@ msgstr "symbolische Referenzen löschen"
 msgid "shorten ref output"
 msgstr "verkürzte Ausgabe der Referenzen"
 
-#: builtin/symbolic-ref.c:43 builtin/update-ref.c:362
+#: builtin/symbolic-ref.c:43 builtin/update-ref.c:363
 msgid "reason"
 msgstr "Grund"
 
-#: builtin/symbolic-ref.c:43 builtin/update-ref.c:362
+#: builtin/symbolic-ref.c:43 builtin/update-ref.c:363
 msgid "reason of the update"
 msgstr "Grund für die Aktualisierung"
 
-#: builtin/tag.c:24
+#: builtin/tag.c:25
 msgid ""
-"git tag [-a | -s | -u <key-id>] [-f] [-m <msg> | -F <file>] <tagname> "
-"[<head>]"
+"git tag [-a | -s | -u <key-id>] [-f] [-m <msg> | -F <file>]\n"
+"\t\t<tagname> [<head>]"
 msgstr ""
-"git tag [-a | -s | -u <Schlüssel-id>] [-f] [-m <Beschreibung> | -F <Datei>] "
-"<Tagname> [<Commit>]"
+"git tag [-a | -s | -u <Schlüssel-id>] [-f] [-m <Beschreibung> | -F <Datei>]\n"
+"\t\t<Tagname> [<Commit>]"
 
-#: builtin/tag.c:25
+#: builtin/tag.c:27
 msgid "git tag -d <tagname>..."
 msgstr "git tag -d <Tagname>..."
 
-#: builtin/tag.c:26
+#: builtin/tag.c:28
 msgid ""
 "git tag -l [-n[<num>]] [--contains <commit>] [--no-contains <commit>] [--"
 "points-at <object>]\n"
@@ -14332,21 +21170,21 @@ msgstr ""
 "points-at <Objekt>]\n"
 "\t\t[--format=<Muster>] [--[no-]merged [<Commit>]] [<Muster>...]"
 
-#: builtin/tag.c:28
+#: builtin/tag.c:30
 msgid "git tag -v [--format=<format>] <tagname>..."
 msgstr "git tag -v [--format=<Format>] <Tagname>..."
 
-#: builtin/tag.c:86
+#: builtin/tag.c:89
 #, c-format
 msgid "tag '%s' not found."
 msgstr "Tag '%s' nicht gefunden."
 
-#: builtin/tag.c:102
+#: builtin/tag.c:105
 #, c-format
 msgid "Deleted tag '%s' (was %s)\n"
 msgstr "Tag '%s' gelöscht (war %s)\n"
 
-#: builtin/tag.c:131
+#: builtin/tag.c:135
 #, c-format
 msgid ""
 "\n"
@@ -14359,7 +21197,7 @@ msgstr ""
 "  %s\n"
 "ein. Zeilen, die mit '%c' beginnen, werden ignoriert.\n"
 
-#: builtin/tag.c:135
+#: builtin/tag.c:139
 #, c-format
 msgid ""
 "\n"
@@ -14374,368 +21212,381 @@ msgstr ""
 "ein. Zeilen, die mit '%c' beginnen, werden behalten; Sie dürfen diese\n"
 "selbst entfernen wenn Sie möchten.\n"
 
-#: builtin/tag.c:189
+#: builtin/tag.c:198
 msgid "unable to sign the tag"
 msgstr "konnte Tag nicht signieren"
 
-#: builtin/tag.c:191
+#: builtin/tag.c:200
 msgid "unable to write tag file"
 msgstr "konnte Tag-Datei nicht schreiben"
 
 #: builtin/tag.c:216
+#, c-format
+msgid ""
+"You have created a nested tag. The object referred to by your new tag is\n"
+"already a tag. If you meant to tag the object that it points to, use:\n"
+"\n"
+"\tgit tag -f %s %s^{}"
+msgstr ""
+"Sie haben einen verschachtelten Tag erzeugt. Das Objekt, auf welches Ihr\n"
+"neues Tag referenziert, ist bereits ein Tag. Wenn Sie das Objekt taggen\n"
+"wollten, worauf dieses zeigt, nutzen Sie:\n"
+"\n"
+"\tgit tag -f %s %s^{}"
+
+#: builtin/tag.c:232
 msgid "bad object type."
 msgstr "ungültiger Objekt-Typ"
 
-#: builtin/tag.c:265
+#: builtin/tag.c:284
 msgid "no tag message?"
 msgstr "keine Tag-Beschreibung?"
 
-#: builtin/tag.c:272
+#: builtin/tag.c:291
 #, c-format
 msgid "The tag message has been left in %s\n"
-msgstr "Die Tag-Beschreibung wurde gelassen in %s\n"
+msgstr "Die Tag-Beschreibung wurde in %s gelassen\n"
 
-#: builtin/tag.c:381
+#: builtin/tag.c:402
 msgid "list tag names"
 msgstr "Tagnamen auflisten"
 
-#: builtin/tag.c:383
+#: builtin/tag.c:404
 msgid "print <n> lines of each tag message"
 msgstr "<n> Zeilen jeder Tag-Beschreibung anzeigen"
 
-#: builtin/tag.c:385
+#: builtin/tag.c:406
 msgid "delete tags"
 msgstr "Tags löschen"
 
-#: builtin/tag.c:386
+#: builtin/tag.c:407
 msgid "verify tags"
 msgstr "Tags überprüfen"
 
-#: builtin/tag.c:388
+#: builtin/tag.c:409
 msgid "Tag creation options"
 msgstr "Optionen für Erstellung von Tags"
 
-#: builtin/tag.c:390
+#: builtin/tag.c:411
 msgid "annotated tag, needs a message"
 msgstr "annotiertes Tag, benötigt eine Beschreibung"
 
-#: builtin/tag.c:392
+#: builtin/tag.c:413
 msgid "tag message"
 msgstr "Tag-Beschreibung"
 
-#: builtin/tag.c:394
+#: builtin/tag.c:415
 msgid "force edit of tag message"
 msgstr "Bearbeitung der Tag-Beschreibung erzwingen"
 
-#: builtin/tag.c:395
+#: builtin/tag.c:416
 msgid "annotated and GPG-signed tag"
 msgstr "annotiertes und GPG-signiertes Tag"
 
-#: builtin/tag.c:399
+#: builtin/tag.c:419
 msgid "use another key to sign the tag"
 msgstr "einen anderen Schlüssel verwenden, um das Tag zu signieren"
 
-#: builtin/tag.c:400
+#: builtin/tag.c:420
 msgid "replace the tag if exists"
 msgstr "das Tag ersetzen, wenn es existiert"
 
-#: builtin/tag.c:401 builtin/update-ref.c:368
+#: builtin/tag.c:421 builtin/update-ref.c:369
 msgid "create a reflog"
 msgstr "Reflog erstellen"
 
-#: builtin/tag.c:403
+#: builtin/tag.c:423
 msgid "Tag listing options"
 msgstr "Optionen für Auflistung der Tags"
 
-#: builtin/tag.c:404
+#: builtin/tag.c:424
 msgid "show tag list in columns"
 msgstr "Liste der Tags in Spalten anzeigen"
 
-#: builtin/tag.c:405 builtin/tag.c:407
+#: builtin/tag.c:425 builtin/tag.c:427
 msgid "print only tags that contain the commit"
 msgstr "nur Tags ausgeben, die diesen Commit beinhalten"
 
-#: builtin/tag.c:406 builtin/tag.c:408
+#: builtin/tag.c:426 builtin/tag.c:428
 msgid "print only tags that don't contain the commit"
 msgstr "nur Tags ausgeben, die diesen Commit nicht enthalten"
 
-#: builtin/tag.c:409
+#: builtin/tag.c:429
 msgid "print only tags that are merged"
 msgstr "nur Tags ausgeben, die gemerged wurden"
 
-#: builtin/tag.c:410
+#: builtin/tag.c:430
 msgid "print only tags that are not merged"
 msgstr "nur Tags ausgeben, die nicht gemerged wurden"
 
-#: builtin/tag.c:415
+#: builtin/tag.c:434
 msgid "print only tags of the object"
 msgstr "nur Tags von dem Objekt ausgeben"
 
-#: builtin/tag.c:459
+#: builtin/tag.c:482
 msgid "--column and -n are incompatible"
 msgstr "--column und -n sind inkompatibel"
 
-#: builtin/tag.c:481
+#: builtin/tag.c:504
 msgid "-n option is only allowed in list mode"
 msgstr "Die Option -n ist nur im Listenmodus erlaubt."
 
-#: builtin/tag.c:483
+#: builtin/tag.c:506
 msgid "--contains option is only allowed in list mode"
 msgstr "Die Option --contains ist nur im Listenmodus erlaubt."
 
-#: builtin/tag.c:485
+#: builtin/tag.c:508
 msgid "--no-contains option is only allowed in list mode"
 msgstr "Die Option --no-contains ist nur im Listenmodus erlaubt."
 
-#: builtin/tag.c:487
+#: builtin/tag.c:510
 msgid "--points-at option is only allowed in list mode"
 msgstr "Die Option --points-at ist nur im Listenmodus erlaubt."
 
-#: builtin/tag.c:489
+#: builtin/tag.c:512
 msgid "--merged and --no-merged options are only allowed in list mode"
 msgstr "Die Optionen --merged und --no-merged sind nur im Listenmodus erlaubt."
 
-#: builtin/tag.c:500
+#: builtin/tag.c:523
 msgid "only one -F or -m option is allowed."
 msgstr "nur eine -F oder -m Option ist erlaubt."
 
-#: builtin/tag.c:519
+#: builtin/tag.c:542
 msgid "too many params"
 msgstr "zu viele Parameter"
 
-#: builtin/tag.c:525
+#: builtin/tag.c:548
 #, c-format
 msgid "'%s' is not a valid tag name."
 msgstr "'%s' ist kein gültiger Tagname."
 
-#: builtin/tag.c:530
+#: builtin/tag.c:553
 #, c-format
 msgid "tag '%s' already exists"
 msgstr "Tag '%s' existiert bereits"
 
-#: builtin/tag.c:561
+#: builtin/tag.c:584
 #, c-format
 msgid "Updated tag '%s' (was %s)\n"
 msgstr "Tag '%s' aktualisiert (war %s)\n"
 
-#: builtin/unpack-objects.c:498
+#: builtin/unpack-objects.c:501
 msgid "Unpacking objects"
 msgstr "Entpacke Objekte"
 
-#: builtin/update-index.c:82
+#: builtin/update-index.c:84
 #, c-format
 msgid "failed to create directory %s"
 msgstr "Fehler beim Erstellen von Verzeichnis '%s'"
 
-#: builtin/update-index.c:88
-#, c-format
-msgid "failed to stat %s"
-msgstr "Konnte '%s' nicht lesen"
-
-#: builtin/update-index.c:98
+#: builtin/update-index.c:100
 #, c-format
 msgid "failed to create file %s"
 msgstr "Konnte Datei '%s' nicht erstellen"
 
-#: builtin/update-index.c:106
+#: builtin/update-index.c:108
 #, c-format
 msgid "failed to delete file %s"
 msgstr "Konnte Datei '%s' nicht löschen"
 
-#: builtin/update-index.c:113 builtin/update-index.c:219
+#: builtin/update-index.c:115 builtin/update-index.c:221
 #, c-format
 msgid "failed to delete directory %s"
 msgstr "Konnte Verzeichnis '%s' nicht löschen"
 
-#: builtin/update-index.c:138
+#: builtin/update-index.c:140
 #, c-format
 msgid "Testing mtime in '%s' "
 msgstr "Prüfe mtime in '%s' "
 
-#: builtin/update-index.c:152
+#: builtin/update-index.c:154
 msgid "directory stat info does not change after adding a new file"
 msgstr ""
 "Verzeichnisinformationen haben sich nach Hinzufügen einer neuen Datei nicht "
 "geändert"
 
-#: builtin/update-index.c:165
+#: builtin/update-index.c:167
 msgid "directory stat info does not change after adding a new directory"
 msgstr ""
 "Verzeichnisinformationen haben sich nach Hinzufügen eines neuen "
 "Verzeichnisses nicht geändert"
 
-#: builtin/update-index.c:178
+#: builtin/update-index.c:180
 msgid "directory stat info changes after updating a file"
 msgstr ""
 "Verzeichnisinformationen haben sich nach Aktualisierung einer Datei geändert"
 
-#: builtin/update-index.c:189
+#: builtin/update-index.c:191
 msgid "directory stat info changes after adding a file inside subdirectory"
 msgstr ""
 "Verzeichnisinformationen haben sich nach Hinzufügen einer Datei in ein "
 "Unterverzeichnis geändert"
 
-#: builtin/update-index.c:200
+#: builtin/update-index.c:202
 msgid "directory stat info does not change after deleting a file"
 msgstr ""
 "Verzeichnisinformationen haben sich nach dem Löschen einer Datei nicht "
 "geändert"
 
-#: builtin/update-index.c:213
+#: builtin/update-index.c:215
 msgid "directory stat info does not change after deleting a directory"
 msgstr ""
 "Verzeichnisinformationen haben sich nach dem Löschen eines Verzeichnisses "
 "nicht geändert"
 
-#: builtin/update-index.c:220
+#: builtin/update-index.c:222
 msgid " OK"
 msgstr " OK"
 
-#: builtin/update-index.c:579
+#: builtin/update-index.c:591
 msgid "git update-index [<options>] [--] [<file>...]"
 msgstr "git update-index [<Optionen>] [--] [<Datei>...]"
 
-#: builtin/update-index.c:936
+#: builtin/update-index.c:974
 msgid "continue refresh even when index needs update"
 msgstr ""
 "Aktualisierung fortsetzen, auch wenn der Index aktualisiert werden muss"
 
-#: builtin/update-index.c:939
+#: builtin/update-index.c:977
 msgid "refresh: ignore submodules"
 msgstr "Aktualisierung: ignoriert Submodule"
 
-#: builtin/update-index.c:942
+#: builtin/update-index.c:980
 msgid "do not ignore new files"
 msgstr "keine neuen Dateien ignorieren"
 
-#: builtin/update-index.c:944
+#: builtin/update-index.c:982
 msgid "let files replace directories and vice-versa"
 msgstr "Dateien Verzeichnisse ersetzen lassen, und umgedreht"
 
-#: builtin/update-index.c:946
+#: builtin/update-index.c:984
 msgid "notice files missing from worktree"
 msgstr "fehlende Dateien im Arbeitsverzeichnis beachten"
 
-#: builtin/update-index.c:948
+#: builtin/update-index.c:986
 msgid "refresh even if index contains unmerged entries"
 msgstr ""
 "aktualisieren, auch wenn der Index nicht zusammengeführte Einträge beinhaltet"
 
-#: builtin/update-index.c:951
+#: builtin/update-index.c:989
 msgid "refresh stat information"
 msgstr "Dateiinformationen aktualisieren"
 
-#: builtin/update-index.c:955
+#: builtin/update-index.c:993
 msgid "like --refresh, but ignore assume-unchanged setting"
 msgstr "wie --refresh, ignoriert aber \"assume-unchanged\" Einstellung"
 
-#: builtin/update-index.c:959
+#: builtin/update-index.c:997
 msgid "<mode>,<object>,<path>"
 msgstr "<Modus>,<Objekt>,<Pfad>"
 
-#: builtin/update-index.c:960
+#: builtin/update-index.c:998
 msgid "add the specified entry to the index"
 msgstr "den angegebenen Eintrag zum Commit vormerken"
 
-#: builtin/update-index.c:969
+#: builtin/update-index.c:1008
 msgid "mark files as \"not changing\""
 msgstr "diese Datei immer als unverändert betrachten"
 
-#: builtin/update-index.c:972
+#: builtin/update-index.c:1011
 msgid "clear assumed-unchanged bit"
 msgstr "\"assumed-unchanged\"-Bit löschen"
 
-#: builtin/update-index.c:975
+#: builtin/update-index.c:1014
 msgid "mark files as \"index-only\""
 msgstr "Dateien als \"index-only\" markieren"
 
-#: builtin/update-index.c:978
+#: builtin/update-index.c:1017
 msgid "clear skip-worktree bit"
 msgstr "\"skip-worktree\"-Bit löschen"
 
-#: builtin/update-index.c:981
+#: builtin/update-index.c:1020
+msgid "do not touch index-only entries"
+msgstr "\"index-only\" Einträge überspringen"
+
+#: builtin/update-index.c:1022
 msgid "add to index only; do not add content to object database"
 msgstr ""
 "die Änderungen nur zum Commit vormerken; Inhalt wird nicht der Objekt-"
 "Datenbank hinzugefügt"
 
-#: builtin/update-index.c:983
+#: builtin/update-index.c:1024
 msgid "remove named paths even if present in worktree"
 msgstr ""
 "benannte Pfade löschen, auch wenn sie sich im Arbeitsverzeichnis befinden"
 
-#: builtin/update-index.c:985
+#: builtin/update-index.c:1026
 msgid "with --stdin: input lines are terminated by null bytes"
 msgstr "mit --stdin: eingegebene Zeilen sind durch NUL-Bytes abgeschlossen"
 
-#: builtin/update-index.c:987
+#: builtin/update-index.c:1028
 msgid "read list of paths to be updated from standard input"
 msgstr "Liste der zu aktualisierenden Pfade von der Standard-Eingabe lesen"
 
-#: builtin/update-index.c:991
+#: builtin/update-index.c:1032
 msgid "add entries from standard input to the index"
 msgstr "Einträge von der Standard-Eingabe zum Commit vormerken"
 
-#: builtin/update-index.c:995
+#: builtin/update-index.c:1036
 msgid "repopulate stages #2 and #3 for the listed paths"
 msgstr ""
 "wiederholtes Einpflegen der Zustände #2 und #3 für die aufgelisteten Pfade"
 
-#: builtin/update-index.c:999
+#: builtin/update-index.c:1040
 msgid "only update entries that differ from HEAD"
 msgstr "nur Einträge aktualisieren, die unterschiedlich zu HEAD sind"
 
-#: builtin/update-index.c:1003
+#: builtin/update-index.c:1044
 msgid "ignore files missing from worktree"
 msgstr "fehlende Dateien im Arbeitsverzeichnis ignorieren"
 
-#: builtin/update-index.c:1006
+#: builtin/update-index.c:1047
 msgid "report actions to standard output"
 msgstr "die Aktionen in der Standard-Ausgabe ausgeben"
 
-#: builtin/update-index.c:1008
+#: builtin/update-index.c:1049
 msgid "(for porcelains) forget saved unresolved conflicts"
 msgstr "(für Fremdprogramme) keine gespeicherten, nicht aufgelöste Konflikte"
 
-#: builtin/update-index.c:1012
+#: builtin/update-index.c:1053
 msgid "write index in this format"
 msgstr "Index-Datei in diesem Format schreiben"
 
-#: builtin/update-index.c:1014
+#: builtin/update-index.c:1055
 msgid "enable or disable split index"
 msgstr "Splitting des Index aktivieren oder deaktivieren"
 
-#: builtin/update-index.c:1016
+#: builtin/update-index.c:1057
 msgid "enable/disable untracked cache"
 msgstr "Cache für unversionierte Dateien aktivieren oder deaktivieren"
 
-#: builtin/update-index.c:1018
+#: builtin/update-index.c:1059
 msgid "test if the filesystem supports untracked cache"
 msgstr ""
 "prüfen, ob das Dateisystem einen Cache für unversionierte Dateien unterstützt"
 
-#: builtin/update-index.c:1020
+#: builtin/update-index.c:1061
 msgid "enable untracked cache without testing the filesystem"
 msgstr ""
 "Cache für unversionierte Dateien ohne Prüfung des Dateisystems aktivieren"
 
-#: builtin/update-index.c:1022
+#: builtin/update-index.c:1063
 msgid "write out the index even if is not flagged as changed"
 msgstr "Index rausschreiben, auch wenn dieser nicht als geändert markiert ist"
 
-#: builtin/update-index.c:1024
+#: builtin/update-index.c:1065
 msgid "enable or disable file system monitor"
 msgstr "Dateisystem-Monitor aktivieren oder deaktivieren"
 
-#: builtin/update-index.c:1026
+#: builtin/update-index.c:1067
 msgid "mark files as fsmonitor valid"
 msgstr "Dateien als \"fsmonitor valid\" markieren"
 
-#: builtin/update-index.c:1029
+#: builtin/update-index.c:1070
 msgid "clear fsmonitor valid bit"
 msgstr "\"fsmonitor valid\"-Bit löschen"
 
-#: builtin/update-index.c:1127
+#: builtin/update-index.c:1173
 msgid ""
 "core.splitIndex is set to false; remove or change it, if you really want to "
 "enable split index"
@@ -14743,7 +21594,7 @@ msgstr ""
 "core.splitIndex ist auf 'false' gesetzt. Entfernen oder ändern Sie dies,\n"
 "wenn sie wirklich das Splitting des Index aktivieren möchten."
 
-#: builtin/update-index.c:1136
+#: builtin/update-index.c:1182
 msgid ""
 "core.splitIndex is set to true; remove or change it, if you really want to "
 "disable split index"
@@ -14751,7 +21602,7 @@ msgstr ""
 "core.splitIndex ist auf 'true' gesetzt. Entfernen oder ändern Sie dies,\n"
 "wenn Sie wirklich das Splitting des Index deaktivieren möchten."
 
-#: builtin/update-index.c:1147
+#: builtin/update-index.c:1194
 msgid ""
 "core.untrackedCache is set to true; remove or change it, if you really want "
 "to disable the untracked cache"
@@ -14759,11 +21610,11 @@ msgstr ""
 "core.untrackedCache ist auf 'true' gesetzt. Entfernen oder ändern Sie dies,\n"
 "wenn Sie wirklich den Cache für unversionierte Dateien deaktivieren möchten."
 
-#: builtin/update-index.c:1151
+#: builtin/update-index.c:1198
 msgid "Untracked cache disabled"
 msgstr "Cache für unversionierte Dateien deaktiviert"
 
-#: builtin/update-index.c:1159
+#: builtin/update-index.c:1206
 msgid ""
 "core.untrackedCache is set to false; remove or change it, if you really want "
 "to enable the untracked cache"
@@ -14772,23 +21623,23 @@ msgstr ""
 "dies,\n"
 "wenn sie wirklich den Cache für unversionierte Dateien aktivieren möchten."
 
-#: builtin/update-index.c:1163
+#: builtin/update-index.c:1210
 #, c-format
 msgid "Untracked cache enabled for '%s'"
 msgstr "Cache für unversionierte Dateien für '%s' aktiviert"
 
-#: builtin/update-index.c:1171
+#: builtin/update-index.c:1218
 msgid "core.fsmonitor is unset; set it if you really want to enable fsmonitor"
 msgstr ""
 "core.fsmonitor nicht gesetzt. Setzen Sie es, wenn Sie den Dateisystem-"
 "Monitor\n"
 "wirklich aktivieren möchten."
 
-#: builtin/update-index.c:1175
+#: builtin/update-index.c:1222
 msgid "fsmonitor enabled"
 msgstr "Dateisystem-Monitor aktiviert"
 
-#: builtin/update-index.c:1178
+#: builtin/update-index.c:1225
 msgid ""
 "core.fsmonitor is set; remove it if you really want to disable fsmonitor"
 msgstr ""
@@ -14796,7 +21647,7 @@ msgstr ""
 "Monitor\n"
 "wirklich deaktivieren möchten."
 
-#: builtin/update-index.c:1182
+#: builtin/update-index.c:1229
 msgid "fsmonitor disabled"
 msgstr "Dateisystem-Monitor deaktiviert"
 
@@ -14813,19 +21664,19 @@ msgstr ""
 msgid "git update-ref [<options>] --stdin [-z]"
 msgstr "git update-ref [<Optionen>] --stdin [-z]"
 
-#: builtin/update-ref.c:363
+#: builtin/update-ref.c:364
 msgid "delete the reference"
 msgstr "diese Referenz löschen"
 
-#: builtin/update-ref.c:365
+#: builtin/update-ref.c:366
 msgid "update <refname> not the one it points to"
 msgstr "<Referenzname> aktualisieren, nicht den Verweis"
 
-#: builtin/update-ref.c:366
+#: builtin/update-ref.c:367
 msgid "stdin has NUL-terminated arguments"
 msgstr "Standard-Eingabe hat durch NUL-Zeichen abgeschlossene Argumente"
 
-#: builtin/update-ref.c:367
+#: builtin/update-ref.c:368
 msgid "read updates from stdin"
 msgstr "Aktualisierungen von der Standard-Eingabe lesen"
 
@@ -14837,15 +21688,37 @@ msgstr "git update-server-info [--force]
 msgid "update the info files from scratch"
 msgstr "die Informationsdateien von Grund auf aktualisieren"
 
-#: builtin/verify-commit.c:18
+#: builtin/upload-pack.c:11
+msgid "git upload-pack [<options>] <dir>"
+msgstr "git upload-pack [<Optionen>] <Verzeichnis>"
+
+#: builtin/upload-pack.c:23 t/helper/test-serve-v2.c:17
+msgid "quit after a single request/response exchange"
+msgstr "nach einem einzigen Request/Response-Austausch beenden"
+
+#: builtin/upload-pack.c:25
+msgid "exit immediately after initial ref advertisement"
+msgstr "direkt nach der initialen Angabe der Commits beenden"
+
+#: builtin/upload-pack.c:27
+msgid "do not try <directory>/.git/ if <directory> is no Git directory"
+msgstr ""
+"kein Versuch in <Verzeichnis>/.git/ wenn <Verzeichnis> kein Git-Verzeichnis "
+"ist"
+
+#: builtin/upload-pack.c:29
+msgid "interrupt transfer after <n> seconds of inactivity"
+msgstr "Übertragung nach <n> Sekunden Inaktivität unterbrechen"
+
+#: builtin/verify-commit.c:19
 msgid "git verify-commit [-v | --verbose] <commit>..."
 msgstr "git verify-commit [-v | --verbose] <Commit>..."
 
-#: builtin/verify-commit.c:73
+#: builtin/verify-commit.c:68
 msgid "print commit contents"
 msgstr "Commit-Inhalte ausgeben"
 
-#: builtin/verify-commit.c:74 builtin/verify-tag.c:38
+#: builtin/verify-commit.c:69 builtin/verify-tag.c:37
 msgid "print raw gpg status output"
 msgstr "unbearbeitete Ausgabe des Status von gpg ausgeben"
 
@@ -14861,11 +21734,11 @@ msgstr "erweiterte Ausgaben"
 msgid "show statistics only"
 msgstr "nur Statistiken anzeigen"
 
-#: builtin/verify-tag.c:19
+#: builtin/verify-tag.c:18
 msgid "git verify-tag [-v | --verbose] [--format=<format>] <tag>..."
 msgstr "git verify-tag [-v | --verbose] [--format=<Format>] <Tag>..."
 
-#: builtin/verify-tag.c:37
+#: builtin/verify-tag.c:36
 msgid "print tag contents"
 msgstr "Tag-Inhalte ausgeben"
 
@@ -14897,22 +21770,27 @@ msgstr "git worktree remove [<Optionen>]
 msgid "git worktree unlock <path>"
 msgstr "git worktree unlock <Pfad>"
 
-#: builtin/worktree.c:60
+#: builtin/worktree.c:60 builtin/worktree.c:898
+#, c-format
+msgid "failed to delete '%s'"
+msgstr "Fehler beim Löschen von '%s'"
+
+#: builtin/worktree.c:79
 #, c-format
 msgid "Removing worktrees/%s: not a valid directory"
 msgstr "Lösche worktrees/%s: kein gültiges Verzeichnis"
 
-#: builtin/worktree.c:66
+#: builtin/worktree.c:85
 #, c-format
 msgid "Removing worktrees/%s: gitdir file does not exist"
 msgstr "Lösche worktrees/%s: gitdir-Datei existiert nicht"
 
-#: builtin/worktree.c:71 builtin/worktree.c:80
+#: builtin/worktree.c:90 builtin/worktree.c:99
 #, c-format
 msgid "Removing worktrees/%s: unable to read gitdir file (%s)"
 msgstr "Lösche worktrees/%s: konnte gitdir-Datei (%s) nicht lesen"
 
-#: builtin/worktree.c:90
+#: builtin/worktree.c:109
 #, c-format
 msgid ""
 "Removing worktrees/%s: short read (expected %<PRIuMAX> bytes, read "
@@ -14921,226 +21799,284 @@ msgstr ""
 "Lösche worktrees/%s: read() zu kurz (%<PRIuMAX> Bytes erwartet, %<PRIuMAX> "
 "gelesen)"
 
-#: builtin/worktree.c:98
+#: builtin/worktree.c:117
 #, c-format
 msgid "Removing worktrees/%s: invalid gitdir file"
 msgstr "Lösche worktrees/%s: ungültige gitdir-Datei"
 
-#: builtin/worktree.c:114
+#: builtin/worktree.c:126
 #, c-format
 msgid "Removing worktrees/%s: gitdir file points to non-existent location"
 msgstr "Lösche worktrees/%s: gitdir-Datei verweist auf nicht existierenden Ort"
 
-#: builtin/worktree.c:161
+#: builtin/worktree.c:165
 msgid "report pruned working trees"
 msgstr "entfernte Arbeitsverzeichnisse ausgeben"
 
-#: builtin/worktree.c:163
+#: builtin/worktree.c:167
 msgid "expire working trees older than <time>"
 msgstr "Arbeitsverzeichnisse älter als <Zeit> verfallen lassen"
 
-#: builtin/worktree.c:238
+#: builtin/worktree.c:234
 #, c-format
 msgid "'%s' already exists"
 msgstr "'%s' existiert bereits"
 
-#: builtin/worktree.c:269
+#: builtin/worktree.c:251
+#, c-format
+msgid "unable to re-add worktree '%s'"
+msgstr "Konnte Arbeitsverzeichnis '%s' nicht neu hinzufügen."
+
+#: builtin/worktree.c:256
+#, c-format
+msgid ""
+"'%s' is a missing but locked worktree;\n"
+"use 'add -f -f' to override, or 'unlock' and 'prune' or 'remove' to clear"
+msgstr ""
+"'%s' ist ein fehlendes, aber gesperrtes Arbeitsverzeichnis;\n"
+"Benutzen Sie 'add -f -f' zum Überschrieben, oder 'unlock' und 'prune'\n"
+"oder 'remove' zum Löschen."
+
+#: builtin/worktree.c:258
+#, c-format
+msgid ""
+"'%s' is a missing but already registered worktree;\n"
+"use 'add -f' to override, or 'prune' or 'remove' to clear"
+msgstr ""
+"'%s' ist ein fehlendes, aber bereits registriertes Arbeitsverzeichnis;\n"
+"Benutzen Sie 'add -f' zum Überschreiben, oder 'prune' oder 'remove' zum\n"
+"Löschen."
+
+#: builtin/worktree.c:308
 #, c-format
 msgid "could not create directory of '%s'"
 msgstr "Konnte Verzeichnis '%s' nicht erstellen."
 
-#: builtin/worktree.c:308
+#: builtin/worktree.c:439 builtin/worktree.c:445
+#, c-format
+msgid "Preparing worktree (new branch '%s')"
+msgstr "Bereite Arbeitsverzeichnis vor (neuer Branch '%s')"
+
+#: builtin/worktree.c:441
 #, c-format
-msgid "Preparing %s (identifier %s)"
-msgstr "Bereite %s vor (Identifikation %s)"
+msgid "Preparing worktree (resetting branch '%s'; was at %s)"
+msgstr "Bereite Arbeitsverzeichnis vor (setze Branch '%s' um; war bei %s)"
 
-#: builtin/worktree.c:385
+#: builtin/worktree.c:450
+#, c-format
+msgid "Preparing worktree (checking out '%s')"
+msgstr "Bereite Arbeitsverzeichnis vor (checke '%s' aus)"
+
+#: builtin/worktree.c:456
+#, c-format
+msgid "Preparing worktree (detached HEAD %s)"
+msgstr "Bereite Arbeitsverzeichnis vor (losgelöster HEAD %s)"
+
+#: builtin/worktree.c:497
 msgid "checkout <branch> even if already checked out in other worktree"
 msgstr ""
 "<Branch> auschecken, auch wenn dieser bereits in einem anderen "
 "Arbeitsverzeichnis ausgecheckt ist"
 
-#: builtin/worktree.c:388
+#: builtin/worktree.c:500
 msgid "create a new branch"
 msgstr "neuen Branch erstellen"
 
-#: builtin/worktree.c:390
+#: builtin/worktree.c:502
 msgid "create or reset a branch"
 msgstr "Branch erstellen oder umsetzen"
 
-#: builtin/worktree.c:392
+#: builtin/worktree.c:504
 msgid "populate the new working tree"
 msgstr "das neue Arbeitsverzeichnis auschecken"
 
-#: builtin/worktree.c:393
+#: builtin/worktree.c:505
 msgid "keep the new working tree locked"
 msgstr "das neue Arbeitsverzeichnis gesperrt lassen"
 
-#: builtin/worktree.c:395
+#: builtin/worktree.c:508
 msgid "set up tracking mode (see git-branch(1))"
 msgstr "Modus zum Folgen von Branches einstellen (siehe git-branch(1))"
 
-#: builtin/worktree.c:398
+#: builtin/worktree.c:511
 msgid "try to match the new branch name with a remote-tracking branch"
 msgstr ""
 "versuchen, eine Übereinstimmung des Branch-Namens mit einem\n"
 "Remote-Tracking-Branch herzustellen"
 
-#: builtin/worktree.c:406
+#: builtin/worktree.c:519
 msgid "-b, -B, and --detach are mutually exclusive"
 msgstr "-b, -B und --detach schließen sich gegenseitig aus"
 
-#: builtin/worktree.c:471
+#: builtin/worktree.c:580
 msgid "--[no-]track can only be used if a new branch is created"
 msgstr ""
 "--[no]-track kann nur verwendet werden, wenn ein neuer Branch erstellt wird."
 
-#: builtin/worktree.c:571
+#: builtin/worktree.c:680
 msgid "reason for locking"
 msgstr "Sperrgrund"
 
-#: builtin/worktree.c:583 builtin/worktree.c:616 builtin/worktree.c:670
-#: builtin/worktree.c:809
+#: builtin/worktree.c:692 builtin/worktree.c:725 builtin/worktree.c:799
+#: builtin/worktree.c:926
 #, c-format
 msgid "'%s' is not a working tree"
 msgstr "'%s' ist kein Arbeitsverzeichnis"
 
-#: builtin/worktree.c:585 builtin/worktree.c:618
+#: builtin/worktree.c:694 builtin/worktree.c:727
 msgid "The main working tree cannot be locked or unlocked"
 msgstr "Das Hauptarbeitsverzeichnis kann nicht gesperrt oder entsperrt werden."
 
-#: builtin/worktree.c:590
+#: builtin/worktree.c:699
 #, c-format
 msgid "'%s' is already locked, reason: %s"
 msgstr "'%s' ist bereits gesperrt, Grund: %s"
 
-#: builtin/worktree.c:592
+#: builtin/worktree.c:701
 #, c-format
 msgid "'%s' is already locked"
 msgstr "'%s' ist bereits gesperrt"
 
-#: builtin/worktree.c:620
+#: builtin/worktree.c:729
 #, c-format
 msgid "'%s' is not locked"
 msgstr "'%s' ist nicht gesperrt"
 
-#: builtin/worktree.c:645
+#: builtin/worktree.c:770
 msgid "working trees containing submodules cannot be moved or removed"
 msgstr ""
 "Arbeitsverzeichnisse, die Submodule enthalten, können nicht verschoben oder\n"
 "entfernt werden."
 
-#: builtin/worktree.c:672 builtin/worktree.c:811
+#: builtin/worktree.c:778
+msgid "force move even if worktree is dirty or locked"
+msgstr ""
+"Verschieben erzwingen, auch wenn das Arbeitsverzeichnis geändert oder "
+"gesperrt ist"
+
+#: builtin/worktree.c:801 builtin/worktree.c:928
 #, c-format
 msgid "'%s' is a main working tree"
 msgstr "'%s' ist ein Hauptarbeitsverzeichnis"
 
-#: builtin/worktree.c:677
+#: builtin/worktree.c:806
 #, c-format
 msgid "could not figure out destination name from '%s'"
 msgstr "Konnte Zielname aus '%s' nicht bestimmen."
 
-#: builtin/worktree.c:683
+#: builtin/worktree.c:812
 #, c-format
 msgid "target '%s' already exists"
 msgstr "Ziel '%s' existiert bereits."
 
-#: builtin/worktree.c:690
+#: builtin/worktree.c:820
 #, c-format
-msgid "cannot move a locked working tree, lock reason: %s"
-msgstr "Kann gesperrtes Arbeitsverzeichnis nicht verschieben, Sperrgrund: %s"
+msgid ""
+"cannot move a locked working tree, lock reason: %s\n"
+"use 'move -f -f' to override or unlock first"
+msgstr ""
+"Kann kein gesperrtes Arbeitsverzeichnis verschieben, Sperrgrund: %s\n"
+"Benutzen Sie 'move -f -f' zum Überschreiben oder entsperren Sie zuerst\n"
+"das Arbeitsverzeichnis."
 
-#: builtin/worktree.c:692
-msgid "cannot move a locked working tree"
-msgstr "Kann gesperrtes Arbeitsverzeichnis nicht verschieben."
+#: builtin/worktree.c:822
+msgid ""
+"cannot move a locked working tree;\n"
+"use 'move -f -f' to override or unlock first"
+msgstr ""
+"Kann kein gesperrtes Arbeitsverzeichnis verschieben.\n"
+"Benutzen Sie 'move -f -f' zum Überschreiben oder entsperren Sie zuerst\n"
+"das Arbeitsverzeichnis."
 
-#: builtin/worktree.c:695
+#: builtin/worktree.c:825
 #, c-format
 msgid "validation failed, cannot move working tree: %s"
 msgstr "Validierung fehlgeschlagen, kann Arbeitszeichnis nicht verschieben: %s"
 
-#: builtin/worktree.c:700
+#: builtin/worktree.c:830
 #, c-format
 msgid "failed to move '%s' to '%s'"
 msgstr "Fehler beim Verschieben von '%s' nach '%s'"
 
-#: builtin/worktree.c:748
+#: builtin/worktree.c:878
 #, c-format
 msgid "failed to run 'git status' on '%s'"
 msgstr "Fehler beim Ausführen von 'git status' auf '%s'"
 
-#: builtin/worktree.c:752
+#: builtin/worktree.c:882
 #, c-format
-msgid "'%s' is dirty, use --force to delete it"
-msgstr "'%s' ist verändert, benutzen Sie --force zum Löschen"
+msgid "'%s' contains modified or untracked files, use --force to delete it"
+msgstr ""
+"'%s' enthält geänderte oder nicht versionierte Dateien, benutzen Sie --force "
+"zum Löschen"
 
-#: builtin/worktree.c:757
+#: builtin/worktree.c:887
 #, c-format
 msgid "failed to run 'git status' on '%s', code %d"
 msgstr "Fehler beim Ausführen von 'git status' auf '%s'. Code: %d"
 
-#: builtin/worktree.c:768 builtin/worktree.c:782
+#: builtin/worktree.c:910
+msgid "force removal even if worktree is dirty or locked"
+msgstr ""
+"Löschen erzwingen, auch wenn das Arbeitsverzeichnis geändert oder gesperrt "
+"ist"
+
+#: builtin/worktree.c:933
 #, c-format
-msgid "failed to delete '%s'"
-msgstr "Fehler beim Löschen von '%s'"
+msgid ""
+"cannot remove a locked working tree, lock reason: %s\n"
+"use 'remove -f -f' to override or unlock first"
+msgstr ""
+"Kann kein gesperrtes Arbeitsverzeichnis löschen, Sperrgrund: %s\n"
+"Benutzen Sie 'remove -f -f' zum Überschreiben oder entsperren Sie zuerst\n"
+"das Arbeitsverzeichnis."
 
-#: builtin/worktree.c:794
-msgid "force removing even if the worktree is dirty"
-msgstr "Löschen erzwingen, auch wenn das Arbeitsverzeichnis geändert wurde"
-
-#: builtin/worktree.c:815
-#, c-format
-msgid "cannot remove a locked working tree, lock reason: %s"
-msgstr "Kann gesperrtes Arbeitsverzeichnis nicht löschen, Sperrgrund: %s"
-
-#: builtin/worktree.c:817
-msgid "cannot remove a locked working tree"
-msgstr "Kann gesperrtes Arbeitsverzeichnis nicht löschen."
+#: builtin/worktree.c:935
+msgid ""
+"cannot remove a locked working tree;\n"
+"use 'remove -f -f' to override or unlock first"
+msgstr ""
+"Kann kein gesperrtes Arbeitsverzeichnis löschen.\n"
+"Benutzen Sie 'remove -f -f' zum Überschreiben oder entsperren Sie zuerst\n"
+"das Arbeitsverzeichnis."
 
-#: builtin/worktree.c:820
+#: builtin/worktree.c:938
 #, c-format
 msgid "validation failed, cannot remove working tree: %s"
 msgstr "Validierung fehlgeschlagen, kann Arbeitsverzeichnis nicht löschen: %s"
 
-#: builtin/write-tree.c:14
+#: builtin/write-tree.c:15
 msgid "git write-tree [--missing-ok] [--prefix=<prefix>/]"
 msgstr "git write-tree [--missing-ok] [--prefix=<Präfix>/]"
 
-#: builtin/write-tree.c:27
+#: builtin/write-tree.c:28
 msgid "<prefix>/"
 msgstr "<Präfix>/"
 
-#: builtin/write-tree.c:28
+#: builtin/write-tree.c:29
 msgid "write tree object for a subdirectory <prefix>"
-msgstr "das \"Tree\"-Objekt für ein Unterverzeichnis <Präfix> schreiben"
+msgstr "das Tree-Objekt für ein Unterverzeichnis <Präfix> schreiben"
 
 #: builtin/write-tree.c:31
-msgid "only useful for debugging"
-msgstr "nur nützlich für Fehlersuche"
-
-#: upload-pack.c:27
-msgid "git upload-pack [<options>] <dir>"
-msgstr "git upload-pack [<Optionen>] <Verzeichnis>"
-
-#: upload-pack.c:1070
-msgid "quit after a single request/response exchange"
-msgstr "nach einem einzigen Request/Response-Austausch beenden"
+msgid "only useful for debugging"
+msgstr "nur nützlich für Fehlersuche"
 
-#: upload-pack.c:1072
-msgid "exit immediately after initial ref advertisement"
-msgstr "direkt nach der initialen Angabe der Commits beenden"
+#: fast-import.c:3125
+#, c-format
+msgid "Expected 'mark' command, got %s"
+msgstr "'mark' Befehl erwartet, '%s' bekommen"
 
-#: upload-pack.c:1074
-msgid "do not try <directory>/.git/ if <directory> is no Git directory"
-msgstr ""
-"kein Versuch in <Verzeichnis>/.git/ wenn <Verzeichnis> kein Git-Verzeichnis "
-"ist"
+#: fast-import.c:3130
+#, c-format
+msgid "Expected 'to' command, got %s"
+msgstr "'to' Befehl erwartet, '%s' bekommen"
 
-#: upload-pack.c:1076
-msgid "interrupt transfer after <n> seconds of inactivity"
-msgstr "Übertragung nach <n> Sekunden Inaktivität unterbrechen"
+#: fast-import.c:3254
+#, c-format
+msgid "feature '%s' forbidden in input without --allow-unsafe-features"
+msgstr "Feature '%s' verboten in Eingabe ohne Option --allow-unsafe-features"
 
-#: credential-cache--daemon.c:222
+#: credential-cache--daemon.c:223
 #, c-format
 msgid ""
 "The permissions on your socket directory are too loose; other\n"
@@ -15156,96 +22092,196 @@ msgstr ""
 "\n"
 "auszuführen."
 
-#: credential-cache--daemon.c:271
+#: credential-cache--daemon.c:272
 msgid "print debugging messages to stderr"
 msgstr "Meldungen zur Fehlersuche in Standard-Fehlerausgabe ausgeben"
 
-#: git.c:8
+#: t/helper/test-reach.c:152
+#, c-format
+msgid "commit %s is not marked reachable"
+msgstr "Commit %s ist nicht als erreichbar gekennzeichnet."
+
+#: t/helper/test-reach.c:162
+msgid "too many commits marked reachable"
+msgstr "Zu viele Commits als erreichbar gekennzeichnet."
+
+#: t/helper/test-serve-v2.c:7
+msgid "test-tool serve-v2 [<options>]"
+msgstr "test-tool serve-v2 [<Optionen>]"
+
+#: t/helper/test-serve-v2.c:19
+msgid "exit immediately after advertising capabilities"
+msgstr "direkt nach Anzeige der angebotenen Fähigkeiten beenden"
+
+#: git.c:27
 msgid ""
 "git [--version] [--help] [-C <path>] [-c <name>=<value>]\n"
 "           [--exec-path[=<path>]] [--html-path] [--man-path] [--info-path]\n"
-"           [-p | --paginate | --no-pager] [--no-replace-objects] [--bare]\n"
+"           [-p | --paginate | -P | --no-pager] [--no-replace-objects] [--"
+"bare]\n"
 "           [--git-dir=<path>] [--work-tree=<path>] [--namespace=<name>]\n"
 "           <command> [<args>]"
 msgstr ""
 "git [--version] [--help] [-C <Pfad>] [-c <Name>=<Wert>]\n"
 "           [--exec-path[=<Pfad>]] [--html-path] [--man-path] [--info-path]\n"
-"           [-p | --paginate | --no-pager] [--no-replace-objects] [--bare]\n"
+"           [-p | --paginate | -P | --no-pager] [--no-replace-objects] [--"
+"bare]\n"
 "           [--git-dir=<Pfad>] [--work-tree=<Pfad>] [--namespace=<Name>]\n"
 "           <Befehl> [<Argumente>]"
 
-#: git.c:15
+#: git.c:34
 msgid ""
 "'git help -a' and 'git help -g' list available subcommands and some\n"
 "concept guides. See 'git help <command>' or 'git help <concept>'\n"
-"to read about a specific subcommand or concept."
+"to read about a specific subcommand or concept.\n"
+"See 'git help git' for an overview of the system."
 msgstr ""
 "'git help -a' und 'git help -g' listet verfügbare Unterbefehle und\n"
 "einige Anleitungen zu Git-Konzepten auf. Benutzen Sie 'git help <Befehl>'\n"
 "oder 'git help <Konzept>', um mehr über einen spezifischen Befehl oder\n"
-"Konzept zu erfahren."
+"Konzept zu erfahren.\n"
+"Benutzen Sie 'git help git' für einen Überblick des Systems."
 
-#: git.c:95
+#: git.c:186
 #, c-format
 msgid "no directory given for --git-dir\n"
 msgstr "Kein Verzeichnis für --git-dir angegeben.\n"
 
-#: git.c:109
+#: git.c:200
 #, c-format
 msgid "no namespace given for --namespace\n"
 msgstr "Kein Namespace für --namespace angegeben.\n"
 
-#: git.c:123
+#: git.c:214
 #, c-format
 msgid "no directory given for --work-tree\n"
 msgstr "Kein Verzeichnis für --work-tree angegeben.\n"
 
-#: git.c:137
+#: git.c:228
 #, c-format
 msgid "no prefix given for --super-prefix\n"
 msgstr "Kein Präfix für --super-prefix angegeben.\n"
 
-#: git.c:159
+#: git.c:250
 #, c-format
 msgid "-c expects a configuration string\n"
 msgstr "-c erwartet einen Konfigurationsstring.\n"
 
-#: git.c:197
+#: git.c:288
 #, c-format
 msgid "no directory given for -C\n"
 msgstr "Kein Verzeichnis für -C angegeben.\n"
 
-#: git.c:212
+#: git.c:314
 #, c-format
 msgid "unknown option: %s\n"
 msgstr "Unbekannte Option: %s\n"
 
-#: git.c:687
+#: git.c:360
+#, c-format
+msgid "while expanding alias '%s': '%s'"
+msgstr "beim Erweitern von Alias '%s': '%s'"
+
+#: git.c:369
+#, c-format
+msgid ""
+"alias '%s' changes environment variables.\n"
+"You can use '!git' in the alias to do this"
+msgstr ""
+"Alias '%s' ändert Umgebungsvariablen.\n"
+"Sie können '!git' im Alias benutzen, um dies zu tun."
+
+#: git.c:376
+#, c-format
+msgid "empty alias for %s"
+msgstr "leerer Alias für %s"
+
+#: git.c:379
+#, c-format
+msgid "recursive alias: %s"
+msgstr "rekursiver Alias: %s"
+
+#: git.c:459
+msgid "write failure on standard output"
+msgstr "Fehler beim Schreiben in die Standard-Ausgabe."
+
+#: git.c:461
+msgid "unknown write failure on standard output"
+msgstr "Unbekannter Fehler beim Schreiben in die Standard-Ausgabe."
+
+#: git.c:463
+msgid "close failed on standard output"
+msgstr "Fehler beim Schließen der Standard-Ausgabe."
+
+#: git.c:793
+#, c-format
+msgid "alias loop detected: expansion of '%s' does not terminate:%s"
+msgstr "Alias-Schleife erkannt: Erweiterung von '%s' schließt nicht ab:%s"
+
+#: git.c:843
+#, c-format
+msgid "cannot handle %s as a builtin"
+msgstr "Kann %s nicht als eingebauten Befehl behandeln."
+
+#: git.c:856
+#, c-format
+msgid ""
+"usage: %s\n"
+"\n"
+msgstr ""
+"Verwendung: %s\n"
+"\n"
+
+#: git.c:876
 #, c-format
 msgid "expansion of alias '%s' failed; '%s' is not a git command\n"
 msgstr "Erweiterung von Alias '%s' fehlgeschlagen; '%s' ist kein Git-Befehl.\n"
 
-#: git.c:699
+#: git.c:888
 #, c-format
 msgid "failed to run command '%s': %s\n"
 msgstr "Fehler beim Ausführen von Befehl '%s': %s\n"
 
-#: http.c:342
+#: http.c:378
 #, c-format
 msgid "negative value for http.postbuffer; defaulting to %d"
 msgstr "negativer Wert für http.postbuffer; benutze Standardwert %d"
 
-#: http.c:363
+#: http.c:399
 msgid "Delegation control is not supported with cURL < 7.22.0"
 msgstr "Kontrolle über Delegation wird mit cURL < 7.22.0 nicht unterstützt"
 
-#: http.c:372
+#: http.c:408
 msgid "Public key pinning not supported with cURL < 7.44.0"
 msgstr ""
 "Das Anheften des öffentlichen Schlüssels wird mit cURL < 7.44.0\n"
 "nicht unterstützt."
 
-#: http.c:1857
+#: http.c:876
+msgid "CURLSSLOPT_NO_REVOKE not supported with cURL < 7.44.0"
+msgstr "CURLSSLOPT_NO_REVOKE wird mit cURL < 7.44.0 nicht unterstützt."
+
+#: http.c:949
+msgid "Protocol restrictions not supported with cURL < 7.19.4"
+msgstr "Protokollbeschränkungen werden mit cURL < 7.19.4 nicht unterstützt."
+
+#: http.c:1086
+#, c-format
+msgid "Unsupported SSL backend '%s'. Supported SSL backends:"
+msgstr "Nicht unterstütztes SSL-Backend '%s'. Unterstützte SSL-Backends:"
+
+#: http.c:1093
+#, c-format
+msgid "Could not set SSL backend to '%s': cURL was built without SSL backends"
+msgstr ""
+"Konnte SSL-Backend nicht zu '%s' setzen: cURL wurde ohne SSL-Backends gebaut."
+
+#: http.c:1097
+#, c-format
+msgid "Could not set SSL backend to '%s': already set"
+msgstr "Konnte SSL-Backend nicht zu '%s' setzen: bereits gesetzt"
+
+#: http.c:1966
 #, c-format
 msgid ""
 "unable to update url base from redirection:\n"
@@ -15256,157 +22292,865 @@ msgstr ""
 "  gefragt nach: %s\n"
 "    umgeleitet: %s"
 
-#: remote-curl.c:345
+#: remote-curl.c:166
+#, c-format
+msgid "invalid quoting in push-option value: '%s'"
+msgstr "Ungültiges Quoting beim \"push-option\"-Wert: '%s'"
+
+#: remote-curl.c:263
+#, c-format
+msgid "%sinfo/refs not valid: is this a git repository?"
+msgstr "%sinfo/refs nicht gültig: Ist das ein Git-Repository?"
+
+#: remote-curl.c:364
+msgid "invalid server response; expected service, got flush packet"
+msgstr "Ungültige Antwort des Servers. Service erwartet, Flush-Paket bekommen"
+
+#: remote-curl.c:395
+#, c-format
+msgid "invalid server response; got '%s'"
+msgstr "Ungültige Serverantwort; '%s' bekommen"
+
+#: remote-curl.c:455
+#, c-format
+msgid "repository '%s' not found"
+msgstr "Repository '%s' nicht gefunden."
+
+#: remote-curl.c:459
+#, c-format
+msgid "Authentication failed for '%s'"
+msgstr "Authentifizierung fehlgeschlagen für '%s'"
+
+#: remote-curl.c:463
+#, c-format
+msgid "unable to access '%s': %s"
+msgstr "konnte nicht auf '%s' zugreifen: %s"
+
+#: remote-curl.c:469
 #, c-format
 msgid "redirecting to %s"
 msgstr "Leite nach %s um"
 
-#: list-objects-filter-options.h:59
+#: remote-curl.c:593
+msgid "shouldn't have EOF when not gentle on EOF"
+msgstr "sollte kein EOF haben, wenn nicht behutsam mit EOF"
+
+#: remote-curl.c:673
+msgid "unable to rewind rpc post data - try increasing http.postBuffer"
+msgstr ""
+"Konnte nicht RPC-POST-Daten zurückspulen - Versuchen Sie http.postBuffer zu "
+"erhöhen"
+
+#: remote-curl.c:733
+#, c-format
+msgid "RPC failed; %s"
+msgstr "RPC fehlgeschlagen; %s"
+
+#: remote-curl.c:773
+msgid "cannot handle pushes this big"
+msgstr "Kann solche großen Übertragungen nicht verarbeiten."
+
+#: remote-curl.c:888
+#, c-format
+msgid "cannot deflate request; zlib deflate error %d"
+msgstr "Kann Request nicht komprimieren; \"zlib deflate\"-Fehler %d"
+
+#: remote-curl.c:892
+#, c-format
+msgid "cannot deflate request; zlib end error %d"
+msgstr "Kann Request nicht komprimieren; \"zlib end\"-Fehler %d"
+
+#: remote-curl.c:1023
+msgid "dumb http transport does not support shallow capabilities"
+msgstr "Dumb HTTP-Transport unterstützt keine shallow-Funktionen"
+
+#: remote-curl.c:1037
+msgid "fetch failed."
+msgstr "\"fetch\" fehlgeschlagen."
+
+#: remote-curl.c:1085
+msgid "cannot fetch by sha1 over smart http"
+msgstr "Kann SHA-1 nicht über Smart-HTTP anfordern"
+
+#: remote-curl.c:1129 remote-curl.c:1135
+#, c-format
+msgid "protocol error: expected sha/ref, got '%s'"
+msgstr "Protokollfehler: SHA-1/Referenz erwartet, '%s' bekommen"
+
+#: remote-curl.c:1147 remote-curl.c:1261
+#, c-format
+msgid "http transport does not support %s"
+msgstr "HTTP-Transport unterstützt nicht %s"
+
+#: remote-curl.c:1183
+msgid "git-http-push failed"
+msgstr "\"git-http-push\" fehlgeschlagen"
+
+#: remote-curl.c:1367
+msgid "remote-curl: usage: git remote-curl <remote> [<url>]"
+msgstr "remote-curl: Verwendung: git remote-curl <Remote-Repository> [<URL>]"
+
+#: remote-curl.c:1399
+msgid "remote-curl: error reading command stream from git"
+msgstr "remote-curl: Fehler beim Lesen des Kommando-Streams von Git"
+
+#: remote-curl.c:1406
+msgid "remote-curl: fetch attempted without a local repo"
+msgstr "remote-curl: \"fetch\" ohne lokales Repository versucht"
+
+#: remote-curl.c:1446
+#, c-format
+msgid "remote-curl: unknown command '%s' from git"
+msgstr "remote-curl: Unbekannter Befehl '%s' von Git"
+
+#: list-objects-filter-options.h:85
 msgid "args"
 msgstr "Argumente"
 
-#: list-objects-filter-options.h:60
+#: list-objects-filter-options.h:86
 msgid "object filtering"
 msgstr "Filtern nach Objekten"
 
-#: common-cmds.h:9
-msgid "start a working area (see also: git help tutorial)"
-msgstr "Arbeitsverzeichnis anlegen (siehe auch: git help tutorial)"
+#: parse-options.h:183
+msgid "expiry-date"
+msgstr "Verfallsdatum"
 
-#: common-cmds.h:10
-msgid "work on the current change (see also: git help everyday)"
-msgstr "an aktuellen Änderungen arbeiten (siehe auch: git help everyday)"
+#: parse-options.h:197
+msgid "no-op (backward compatibility)"
+msgstr "Kein Effekt (Rückwärtskompatibilität)"
 
-#: common-cmds.h:11
-msgid "examine the history and state (see also: git help revisions)"
-msgstr "Historie und Status untersuchen (siehe auch: git help revisions)"
+#: parse-options.h:309
+msgid "be more verbose"
+msgstr "erweiterte Ausgaben"
 
-#: common-cmds.h:12
-msgid "grow, mark and tweak your common history"
-msgstr "Historie erweitern und bearbeiten"
+#: parse-options.h:311
+msgid "be more quiet"
+msgstr "weniger Ausgaben"
 
-#: common-cmds.h:13
-msgid "collaborate (see also: git help workflows)"
-msgstr "mit anderen zusammenarbeiten (siehe auch: git help workflows)"
+#: parse-options.h:317
+msgid "use <n> digits to display SHA-1s"
+msgstr "benutze <n> Ziffern zur Anzeige von SHA-1s"
+
+#: parse-options.h:336
+msgid "how to strip spaces and #comments from message"
+msgstr ""
+"wie Leerzeichen und #Kommentare von der Beschreibung getrennt werden sollen"
+
+#: parse-options.h:337
+msgid "read pathspec from file"
+msgstr "Pfadspezifikation aus einer Datei lesen"
+
+#: parse-options.h:338
+msgid ""
+"with --pathspec-from-file, pathspec elements are separated with NUL character"
+msgstr ""
+"Mit der Option --pathspec-from-file sind Pfade durch NUL-Zeichen getrennt"
+
+#: ref-filter.h:101
+msgid "key"
+msgstr "Schüssel"
+
+#: ref-filter.h:101
+msgid "field name to sort on"
+msgstr "sortiere nach diesem Feld"
+
+#: rerere.h:44
+msgid "update the index with reused conflict resolution if possible"
+msgstr ""
+"Index, wenn möglich, mit wiederverwendeter Konfliktauflösung aktualisieren"
+
+#: wt-status.h:67
+msgid "HEAD detached at "
+msgstr "HEAD losgelöst bei "
+
+#: wt-status.h:68
+msgid "HEAD detached from "
+msgstr "HEAD losgelöst von "
 
-#: common-cmds.h:17
+#: command-list.h:50
 msgid "Add file contents to the index"
 msgstr "Dateiinhalte zum Commit vormerken"
 
-#: common-cmds.h:18
+#: command-list.h:51
+msgid "Apply a series of patches from a mailbox"
+msgstr "eine Serie von Patches von einer Mailbox anwenden"
+
+#: command-list.h:52
+msgid "Annotate file lines with commit information"
+msgstr "Zeilen der Datei mit Commit-Informationen versehen und anzeigen"
+
+#: command-list.h:53
+msgid "Apply a patch to files and/or to the index"
+msgstr "einen Patch auf Dateien und/oder den Index anwenden"
+
+#: command-list.h:54
+msgid "Import a GNU Arch repository into Git"
+msgstr "ein GNU Arch Repository in Git importieren"
+
+#: command-list.h:55
+msgid "Create an archive of files from a named tree"
+msgstr "Dateiarchiv von angegebenem Verzeichnis erstellen"
+
+#: command-list.h:56
 msgid "Use binary search to find the commit that introduced a bug"
 msgstr ""
 "Binärsuche verwenden, um den Commit zu finden, der einen Fehler verursacht "
 "hat"
 
-#: common-cmds.h:19
+#: command-list.h:57
+msgid "Show what revision and author last modified each line of a file"
+msgstr ""
+"Anzeigen, durch welchen Commit und Autor die jeweiligen Zeilen\n"
+"einer Datei zuletzt geändert wurden"
+
+#: command-list.h:58
 msgid "List, create, or delete branches"
 msgstr "Branches anzeigen, erstellen oder entfernen"
 
-#: common-cmds.h:20
+#: command-list.h:59
+msgid "Move objects and refs by archive"
+msgstr "Objekte und Referenzen über ein Archiv verteilen"
+
+#: command-list.h:60
+msgid "Provide content or type and size information for repository objects"
+msgstr ""
+"Inhalt oder Informationen zu Typ und Größe für Repository-Objekte "
+"bereitstellen"
+
+#: command-list.h:61
+msgid "Display gitattributes information"
+msgstr "gitattributes Informationen darstellen"
+
+#: command-list.h:62
+msgid "Debug gitignore / exclude files"
+msgstr "Fehlersuche in gitignore / exclude Dateien"
+
+#: command-list.h:63
+msgid "Show canonical names and email addresses of contacts"
+msgstr "Name und E-Mail-Adresse von Kontakten anzeigen"
+
+#: command-list.h:64
 msgid "Switch branches or restore working tree files"
 msgstr "Branches wechseln oder Dateien im Arbeitsverzeichnis wiederherstellen"
 
-#: common-cmds.h:21
+#: command-list.h:65
+msgid "Copy files from the index to the working tree"
+msgstr "Dateien von dem Index ins Arbeitsverzeichnis kopieren"
+
+#: command-list.h:66
+msgid "Ensures that a reference name is well formed"
+msgstr "Sicherstellen, dass ein Referenzname wohlgeformt ist"
+
+#: command-list.h:67
+msgid "Find commits yet to be applied to upstream"
+msgstr ""
+"Commits finden, die noch auf dem Upstream-Branch angewendet werden müssen"
+
+#: command-list.h:68
+msgid "Apply the changes introduced by some existing commits"
+msgstr "Änderungen eines existierenden Commits anwenden"
+
+#: command-list.h:69
+msgid "Graphical alternative to git-commit"
+msgstr "grafische Alternative zu git-commit"
+
+#: command-list.h:70
+msgid "Remove untracked files from the working tree"
+msgstr "unversionierte Dateien vom Arbeitsverzeichnis entfernen"
+
+#: command-list.h:71
 msgid "Clone a repository into a new directory"
 msgstr "ein Repository in einem neuen Verzeichnis klonen"
 
-#: common-cmds.h:22
+#: command-list.h:72
+msgid "Display data in columns"
+msgstr "Daten in Spalten anzeigen"
+
+#: command-list.h:73
 msgid "Record changes to the repository"
 msgstr "Änderungen in das Repository eintragen"
 
-#: common-cmds.h:23
+#: command-list.h:74
+msgid "Write and verify Git commit-graph files"
+msgstr "Git Commit-Graph-Dateien schreiben und überprüfen"
+
+#: command-list.h:75
+msgid "Create a new commit object"
+msgstr "ein neues Commit-Objekt erstellen"
+
+#: command-list.h:76
+msgid "Get and set repository or global options"
+msgstr "repositoryweite oder globale Optionen lesen oder setzen"
+
+#: command-list.h:77
+msgid "Count unpacked number of objects and their disk consumption"
+msgstr "Anzahl und Speicherverbrauch ungepackter Objekte zählen"
+
+#: command-list.h:78
+msgid "Retrieve and store user credentials"
+msgstr "Zugangsdaten des Benutzers empfangen und speichern"
+
+#: command-list.h:79
+msgid "Helper to temporarily store passwords in memory"
+msgstr ""
+"Hilfsprogramm zum temporären Speichern von Zugangsdaten im Hauptspeicher"
+
+#: command-list.h:80
+msgid "Helper to store credentials on disk"
+msgstr "Hilfsprogramm zum Speichern von Zugangsdaten auf der Festplatte"
+
+#: command-list.h:81
+msgid "Export a single commit to a CVS checkout"
+msgstr "einzelnen Commit zu einem ausgecheckten CSV-Repository exportieren"
+
+#: command-list.h:82
+msgid "Salvage your data out of another SCM people love to hate"
+msgstr "Ihre Daten aus einem anderen SCM übernehmen"
+
+#: command-list.h:83
+msgid "A CVS server emulator for Git"
+msgstr "ein CSV Server Emulator für Git"
+
+#: command-list.h:84
+msgid "A really simple server for Git repositories"
+msgstr "ein wirklich einfacher Server für Git Repositories"
+
+#: command-list.h:85
+msgid "Give an object a human readable name based on an available ref"
+msgstr ""
+"einem Objekt einen für Menschen lesbaren Namen basierend auf\n"
+"einer verfügbaren Referenz geben"
+
+#: command-list.h:86
 msgid "Show changes between commits, commit and working tree, etc"
 msgstr ""
 "Änderungen zwischen Commits, Commit und Arbeitsverzeichnis, etc. anzeigen"
 
-#: common-cmds.h:24
+#: command-list.h:87
+msgid "Compares files in the working tree and the index"
+msgstr "Dateien von dem Arbeitsverzeichnis und dem Index vergleichen"
+
+#: command-list.h:88
+msgid "Compare a tree to the working tree or index"
+msgstr "ein Verzeichnis von dem Arbeitsverzeichnis und dem Index vergleichen"
+
+#: command-list.h:89
+msgid "Compares the content and mode of blobs found via two tree objects"
+msgstr ""
+"den Inhalt und Modus von Blobs aus zwei Verzeichnisobjekten vergleichen"
+
+#: command-list.h:90
+msgid "Show changes using common diff tools"
+msgstr "Änderungen mittels den allgemeinen Diff-Tools anzeigen"
+
+#: command-list.h:91
+msgid "Git data exporter"
+msgstr "Export Tool für Git Daten"
+
+#: command-list.h:92
+msgid "Backend for fast Git data importers"
+msgstr "Backend für schnelle Git Daten Import Tools"
+
+#: command-list.h:93
 msgid "Download objects and refs from another repository"
 msgstr "Objekte und Referenzen von einem anderen Repository herunterladen"
 
-#: common-cmds.h:25
+#: command-list.h:94
+msgid "Receive missing objects from another repository"
+msgstr "fehlende Objekte von einem anderen Repository empfangen"
+
+#: command-list.h:95
+msgid "Rewrite branches"
+msgstr "Branches umschreiben"
+
+#: command-list.h:96
+msgid "Produce a merge commit message"
+msgstr "Beschreibung eines Merge-Commits erzeugen"
+
+#: command-list.h:97
+msgid "Output information on each ref"
+msgstr "Informationen für jede Referenz ausgeben"
+
+#: command-list.h:98
+msgid "Prepare patches for e-mail submission"
+msgstr "Patches für E-Mail-Versand vorbereiten"
+
+#: command-list.h:99
+msgid "Verifies the connectivity and validity of the objects in the database"
+msgstr ""
+"stellt die Verbundenheit und Gültigkeit der Objekte in der Datenbank sicher"
+
+#: command-list.h:100
+msgid "Cleanup unnecessary files and optimize the local repository"
+msgstr "nicht benötigte Dateien entfernen und das lokale Repository optimieren"
+
+#: command-list.h:101
+msgid "Extract commit ID from an archive created using git-archive"
+msgstr ""
+"Commit-ID eines Archivs extrahieren, welches mit git-archive erstellt wurde"
+
+#: command-list.h:102
 msgid "Print lines matching a pattern"
 msgstr "Zeilen darstellen, die einem Muster entsprechen"
 
-#: common-cmds.h:26
+#: command-list.h:103
+msgid "A portable graphical interface to Git"
+msgstr "eine portable grafische Schnittstelle zu Git"
+
+#: command-list.h:104
+msgid "Compute object ID and optionally creates a blob from a file"
+msgstr ""
+"von einer Datei die Objekt-ID berechnen und optional ein Blob erstellen"
+
+#: command-list.h:105
+msgid "Display help information about Git"
+msgstr "Hilfsinformationen über Git anzeigen"
+
+#: command-list.h:106
+msgid "Server side implementation of Git over HTTP"
+msgstr "serverseitige Implementierung von Git über HTTP"
+
+#: command-list.h:107
+msgid "Download from a remote Git repository via HTTP"
+msgstr "von einem Remote-Git-Repository über HTTP herunterladen"
+
+#: command-list.h:108
+msgid "Push objects over HTTP/DAV to another repository"
+msgstr "Objekte über HTTP/DAV zu einem anderen Repository übertragen"
+
+#: command-list.h:109
+msgid "Send a collection of patches from stdin to an IMAP folder"
+msgstr ""
+"eine Sammlung von Patches von der Standard-Eingabe zu einem IMAP-Ordner "
+"senden"
+
+#: command-list.h:110
+msgid "Build pack index file for an existing packed archive"
+msgstr "Pack-Index-Datei für ein existierendes gepacktes Archiv erzeugen"
+
+#: command-list.h:111
 msgid "Create an empty Git repository or reinitialize an existing one"
 msgstr ""
 "ein leeres Git-Repository erstellen oder ein bestehendes neuinitialisieren"
 
-#: common-cmds.h:27
+#: command-list.h:112
+msgid "Instantly browse your working repository in gitweb"
+msgstr "Ihr aktuelles Repository sofort in gitweb betrachten"
+
+#: command-list.h:113
+msgid "Add or parse structured information in commit messages"
+msgstr ""
+"Strukturierte Informationen in Commit-Beschreibungen hinzufügen oder parsen"
+
+#: command-list.h:114
+msgid "The Git repository browser"
+msgstr "der Git-Repository-Browser"
+
+#: command-list.h:115
 msgid "Show commit logs"
 msgstr "Commit-Historie anzeigen"
 
-#: common-cmds.h:28
+#: command-list.h:116
+msgid "Show information about files in the index and the working tree"
+msgstr ""
+"Informationen über Dateien in dem Index und im Arbeitsverzeichnis anzeigen"
+
+#: command-list.h:117
+msgid "List references in a remote repository"
+msgstr "Referenzen in einem Remote-Repository auflisten"
+
+#: command-list.h:118
+msgid "List the contents of a tree object"
+msgstr "Inhalte eines Tree-Objektes auflisten"
+
+#: command-list.h:119
+msgid "Extracts patch and authorship from a single e-mail message"
+msgstr ""
+"Patch und Urheberschaft von einer einzelnen E-Mail-Nachricht extrahieren"
+
+#: command-list.h:120
+msgid "Simple UNIX mbox splitter program"
+msgstr "einfaches UNIX mbox Splitter-Programm"
+
+#: command-list.h:121
 msgid "Join two or more development histories together"
 msgstr "zwei oder mehr Entwicklungszweige zusammenführen"
 
-#: common-cmds.h:29
+#: command-list.h:122
+msgid "Find as good common ancestors as possible for a merge"
+msgstr "möglichst besten gemeinsamen Vorgänger-Commit für einen Merge finden"
+
+#: command-list.h:123
+msgid "Run a three-way file merge"
+msgstr "einen 3-Wege-Datei-Merge ausführen"
+
+#: command-list.h:124
+msgid "Run a merge for files needing merging"
+msgstr "einen Merge für zusammenzuführende Dateien ausführen"
+
+#: command-list.h:125
+msgid "The standard helper program to use with git-merge-index"
+msgstr "das Standard-Hilfsprogramm für die Verwendung mit git-merge-index"
+
+#: command-list.h:126
+msgid "Run merge conflict resolution tools to resolve merge conflicts"
+msgstr ""
+"Ausführen von Tools zur Auflösung von Merge-Konflikten zur Behebung dieser"
+
+#: command-list.h:127
+msgid "Show three-way merge without touching index"
+msgstr "3-Wege-Merge anzeigen ohne den Index zu verändern"
+
+#: command-list.h:128
+msgid "Write and verify multi-pack-indexes"
+msgstr "multi-pack-indexes schreiben und überprüfen"
+
+#: command-list.h:129
+msgid "Creates a tag object"
+msgstr "ein Tag-Objekt erstellen"
+
+#: command-list.h:130
+msgid "Build a tree-object from ls-tree formatted text"
+msgstr "Tree-Objekt aus ls-tree formattiertem Text erzeugen"
+
+#: command-list.h:131
 msgid "Move or rename a file, a directory, or a symlink"
 msgstr ""
 "eine Datei, ein Verzeichnis, oder eine symbolische Verknüpfung verschieben "
 "oder umbenennen"
 
-#: common-cmds.h:30
+#: command-list.h:132
+msgid "Find symbolic names for given revs"
+msgstr "symbolische Namen für die gegebenen Commits finden"
+
+#: command-list.h:133
+msgid "Add or inspect object notes"
+msgstr "Objekt-Notizen hinzufügen oder überprüfen"
+
+#: command-list.h:134
+msgid "Import from and submit to Perforce repositories"
+msgstr "von Perforce Repositories importieren und nach diese senden"
+
+#: command-list.h:135
+msgid "Create a packed archive of objects"
+msgstr "ein gepacktes Archiv von Objekten erstellen"
+
+#: command-list.h:136
+msgid "Find redundant pack files"
+msgstr "redundante Paketdateien finden"
+
+#: command-list.h:137
+msgid "Pack heads and tags for efficient repository access"
+msgstr "Branches und Tags für effizienten Zugriff auf das Repository packen"
+
+#: command-list.h:138
+msgid "Routines to help parsing remote repository access parameters"
+msgstr ""
+"Routinen als Hilfe zum Parsen von Zugriffsparametern von Remote-Repositories"
+
+#: command-list.h:139
+msgid "Compute unique ID for a patch"
+msgstr "eindeutige ID für einen Patch berechnen"
+
+#: command-list.h:140
+msgid "Prune all unreachable objects from the object database"
+msgstr "alle nicht erreichbaren Objekte von der Objektdatenbank entfernen"
+
+#: command-list.h:141
+msgid "Remove extra objects that are already in pack files"
+msgstr ""
+"zusätzliche Objekte, die sich bereits in Paketdateien befinden, entfernen"
+
+#: command-list.h:142
 msgid "Fetch from and integrate with another repository or a local branch"
 msgstr ""
 "Objekte von einem externen Repository anfordern und sie mit einem anderen "
 "Repository oder einem lokalen Branch zusammenführen"
 
-#: common-cmds.h:31
+#: command-list.h:143
 msgid "Update remote refs along with associated objects"
 msgstr "Remote-Referenzen mitsamt den verbundenen Objekten aktualisieren"
 
-#: common-cmds.h:32
+#: command-list.h:144
+msgid "Applies a quilt patchset onto the current branch"
+msgstr "Patches aus quilt auf aktuellen Branch anwenden"
+
+#: command-list.h:145
+msgid "Compare two commit ranges (e.g. two versions of a branch)"
+msgstr "zwei Commit-Bereiche vergleichen (zwei Versionen eines Branches)"
+
+#: command-list.h:146
+msgid "Reads tree information into the index"
+msgstr "Verzeichnisinformationen in den Index einlesen"
+
+#: command-list.h:147
 msgid "Reapply commits on top of another base tip"
 msgstr "Wiederholtes Anwenden von Commits auf anderem Basis-Commit"
 
-#: common-cmds.h:33
+#: command-list.h:148
+msgid "Receive what is pushed into the repository"
+msgstr "Empfangen was in das Repository übertragen wurde"
+
+#: command-list.h:149
+msgid "Manage reflog information"
+msgstr "Reflog Informationen verwalten"
+
+#: command-list.h:150
+msgid "Manage set of tracked repositories"
+msgstr "Menge von hinterlegten Repositories verwalten"
+
+#: command-list.h:151
+msgid "Pack unpacked objects in a repository"
+msgstr "ungepackte Objekte in einem Repository packen"
+
+#: command-list.h:152
+msgid "Create, list, delete refs to replace objects"
+msgstr "Referenzen für ersetzende Objekte erstellen, auflisten, löschen"
+
+#: command-list.h:153
+msgid "Generates a summary of pending changes"
+msgstr "eine Übersicht über ausstehende Änderungen generieren"
+
+#: command-list.h:154
+msgid "Reuse recorded resolution of conflicted merges"
+msgstr "aufgezeichnete Auflösung von Merge-Konflikten wiederverwenden"
+
+#: command-list.h:155
 msgid "Reset current HEAD to the specified state"
 msgstr "aktuellen HEAD zu einem spezifizierten Zustand setzen"
 
-#: common-cmds.h:34
+#: command-list.h:156
+msgid "Restore working tree files"
+msgstr "Dateien im Arbeitsverzeichnis wiederherstellen"
+
+#: command-list.h:157
+msgid "Revert some existing commits"
+msgstr "einige bestehende Commits rückgängig machen"
+
+#: command-list.h:158
+msgid "Lists commit objects in reverse chronological order"
+msgstr "Commit-Objekte in umgekehrter chronologischer Ordnung auflisten"
+
+#: command-list.h:159
+msgid "Pick out and massage parameters"
+msgstr "Parameter herauspicken und ändern"
+
+#: command-list.h:160
 msgid "Remove files from the working tree and from the index"
 msgstr "Dateien im Arbeitsverzeichnis und vom Index löschen"
 
-#: common-cmds.h:35
+#: command-list.h:161
+msgid "Send a collection of patches as emails"
+msgstr "eine Sammlung von Patches als E-Mails versenden"
+
+#: command-list.h:162
+msgid "Push objects over Git protocol to another repository"
+msgstr "Objekte über das Git Protokoll zu einem anderen Repository übertragen"
+
+#: command-list.h:163
+msgid "Restricted login shell for Git-only SSH access"
+msgstr "Login-Shell beschränkt für Nur-Git SSH-Zugriff"
+
+#: command-list.h:164
+msgid "Summarize 'git log' output"
+msgstr "Ausgabe von 'git log' zusammenfassen"
+
+#: command-list.h:165
 msgid "Show various types of objects"
 msgstr "verschiedene Arten von Objekten anzeigen"
 
-#: common-cmds.h:36
+#: command-list.h:166
+msgid "Show branches and their commits"
+msgstr "Branches und ihre Commits ausgeben"
+
+#: command-list.h:167
+msgid "Show packed archive index"
+msgstr "gepackten Archiv-Index anzeigen"
+
+#: command-list.h:168
+msgid "List references in a local repository"
+msgstr "Referenzen in einem lokales Repository auflisten"
+
+#: command-list.h:169
+msgid "Git's i18n setup code for shell scripts"
+msgstr "Git's i18n-Konfigurationscode für Shell-Skripte"
+
+#: command-list.h:170
+msgid "Common Git shell script setup code"
+msgstr "allgemeiner Git Shell-Skript Konfigurationscode"
+
+#: command-list.h:171
+msgid "Initialize and modify the sparse-checkout"
+msgstr "Initialisiere und verändere den partiellen Checkout"
+
+#: command-list.h:172
+msgid "Stash the changes in a dirty working directory away"
+msgstr "Änderungen in einem Arbeitsverzeichnis aufbewahren"
+
+#: command-list.h:173
+msgid "Add file contents to the staging area"
+msgstr "Dateiinhalte der Staging-Area hinzufügen"
+
+#: command-list.h:174
 msgid "Show the working tree status"
 msgstr "den Zustand des Arbeitsverzeichnisses anzeigen"
 
-#: common-cmds.h:37
+#: command-list.h:175
+msgid "Remove unnecessary whitespace"
+msgstr "nicht erforderlichen Whitespace entfernen"
+
+#: command-list.h:176
+msgid "Initialize, update or inspect submodules"
+msgstr "Submodule initialisieren, aktualisieren oder inspizieren"
+
+#: command-list.h:177
+msgid "Bidirectional operation between a Subversion repository and Git"
+msgstr ""
+"Bidirektionale Operationen zwischen einem Subversion Repository und Git"
+
+#: command-list.h:178
+msgid "Switch branches"
+msgstr "Branches wechseln"
+
+#: command-list.h:179
+msgid "Read, modify and delete symbolic refs"
+msgstr "symbolische Referenzen lesen, ändern und löschen"
+
+#: command-list.h:180
 msgid "Create, list, delete or verify a tag object signed with GPG"
 msgstr ""
 "ein mit GPG signiertes Tag-Objekt erzeugen, auflisten, löschen oder "
 "verifizieren."
 
-#: parse-options.h:157
-msgid "expiry-date"
-msgstr "Verfallsdatum"
+#: command-list.h:181
+msgid "Creates a temporary file with a blob's contents"
+msgstr "eine temporäre Datei mit den Inhalten eines Blobs erstellen"
+
+#: command-list.h:182
+msgid "Unpack objects from a packed archive"
+msgstr "Objekte von einem gepackten Archiv entpacken"
+
+#: command-list.h:183
+msgid "Register file contents in the working tree to the index"
+msgstr "Dateiinhalte aus dem Arbeitsverzeichnis im Index registrieren"
+
+#: command-list.h:184
+msgid "Update the object name stored in a ref safely"
+msgstr ""
+"den Objektnamen, der in einer Referenz gespeichert ist, sicher aktualisieren"
+
+#: command-list.h:185
+msgid "Update auxiliary info file to help dumb servers"
+msgstr "Hilfsinformationsdatei zur Hilfe von einfachen Servern aktualisieren"
+
+#: command-list.h:186
+msgid "Send archive back to git-archive"
+msgstr "Archiv zurück zu git-archive senden"
+
+#: command-list.h:187
+msgid "Send objects packed back to git-fetch-pack"
+msgstr "Objekte gepackt zurück an git-fetch-pack senden"
+
+#: command-list.h:188
+msgid "Show a Git logical variable"
+msgstr "eine logische Variable von Git anzeigen"
+
+#: command-list.h:189
+msgid "Check the GPG signature of commits"
+msgstr "die GPG-Signatur von Commits prüfen"
+
+#: command-list.h:190
+msgid "Validate packed Git archive files"
+msgstr "gepackte Git-Archivdateien validieren"
+
+#: command-list.h:191
+msgid "Check the GPG signature of tags"
+msgstr "die GPG-Signatur von Tags prüfen"
+
+#: command-list.h:192
+msgid "Git web interface (web frontend to Git repositories)"
+msgstr "Git Web Interface (Web-Frontend für Git-Repositories)"
+
+#: command-list.h:193
+msgid "Show logs with difference each commit introduces"
+msgstr "Logs mit dem Unterschied, den jeder Commit einführt, anzeigen"
+
+#: command-list.h:194
+msgid "Manage multiple working trees"
+msgstr "mehrere Arbeitsverzeichnisse verwalten"
+
+#: command-list.h:195
+msgid "Create a tree object from the current index"
+msgstr "Tree-Objekt vom aktuellen Index erstellen"
+
+#: command-list.h:196
+msgid "Defining attributes per path"
+msgstr "Definition von Attributen pro Pfad"
+
+#: command-list.h:197
+msgid "Git command-line interface and conventions"
+msgstr "Git Kommandozeilenschnittstelle und Konventionen"
+
+#: command-list.h:198
+msgid "A Git core tutorial for developers"
+msgstr "eine Git Anleitung für Entwickler"
+
+#: command-list.h:199
+msgid "Git for CVS users"
+msgstr "Git für CVS Benutzer"
+
+#: command-list.h:200
+msgid "Tweaking diff output"
+msgstr "Diff-Ausgabe optimieren"
+
+#: command-list.h:201
+msgid "A useful minimum set of commands for Everyday Git"
+msgstr ""
+"ein kleine, nützliche Menge von Befehlen für die tägliche Verwendung von Git"
+
+#: command-list.h:202
+msgid "A Git Glossary"
+msgstr "ein Git-Glossar"
 
-#: parse-options.h:172
-msgid "no-op (backward compatibility)"
-msgstr "Kein Effekt (Rückwärtskompatibilität)"
+#: command-list.h:203
+msgid "Hooks used by Git"
+msgstr "von Git verwendete Hooks"
 
-#: parse-options.h:250
-msgid "be more verbose"
-msgstr "erweiterte Ausgaben"
+#: command-list.h:204
+msgid "Specifies intentionally untracked files to ignore"
+msgstr "Spezifikation von bewusst ignorierten, unversionierten Dateien"
 
-#: parse-options.h:252
-msgid "be more quiet"
-msgstr "weniger Ausgaben"
+#: command-list.h:205
+msgid "Defining submodule properties"
+msgstr "Definition von Submodul-Eigenschaften"
 
-#: parse-options.h:258
-msgid "use <n> digits to display SHA-1s"
-msgstr "benutze <n> Ziffern zur Anzeige von SHA-1s"
+#: command-list.h:206
+msgid "Git namespaces"
+msgstr "Git Namensbereiche"
+
+#: command-list.h:207
+msgid "Git Repository Layout"
+msgstr "Git Repository Aufbau"
 
-#: rerere.h:40
-msgid "update the index with reused conflict resolution if possible"
-msgstr ""
-"Index, wenn möglich, mit wiederverwendeter Konfliktauflösung aktualisieren"
+#: command-list.h:208
+msgid "Specifying revisions and ranges for Git"
+msgstr "Spezifikation von Commits und Bereichen für Git"
+
+#: command-list.h:209
+msgid "Mounting one repository inside another"
+msgstr "Einbinden eines Repositories in ein anderes"
+
+#: command-list.h:210
+msgid "A tutorial introduction to Git: part two"
+msgstr "eine einführende Anleitung zu Git: Teil zwei"
+
+#: command-list.h:211
+msgid "A tutorial introduction to Git"
+msgstr "eine einführende Anleitung zu Git"
+
+#: command-list.h:212
+msgid "An overview of recommended workflows with Git"
+msgstr "Eine Übersicht über empfohlene Arbeitsabläufe mit Git"
 
 #: git-bisect.sh:54
 msgid "You need to start by \"git bisect start\""
@@ -15419,152 +23163,62 @@ msgstr "Sie müssen mit \"git bisect sta
 msgid "Do you want me to do it for you [Y/n]? "
 msgstr "Wollen Sie, dass ich es für Sie mache [Y/n]? "
 
-#: git-bisect.sh:121
-#, sh-format
-msgid "unrecognised option: '$arg'"
-msgstr "nicht erkannte Option: '$arg'"
-
-#: git-bisect.sh:125
-#, sh-format
-msgid "'$arg' does not appear to be a valid revision"
-msgstr "'$arg' scheint kein gültiger Commit zu sein"
-
-#: git-bisect.sh:154
-msgid "Bad HEAD - I need a HEAD"
-msgstr "Ungültiger HEAD - HEAD wird benötigt"
-
-#: git-bisect.sh:167
-#, sh-format
-msgid ""
-"Checking out '$start_head' failed. Try 'git bisect reset <valid-branch>'."
-msgstr ""
-"Auschecken von '$start_head' fehlgeschlagen. Versuchen Sie 'git bisect reset "
-"<gültiger-Branch>'."
-
-#: git-bisect.sh:177
-msgid "won't bisect on cg-seek'ed tree"
-msgstr ""
-"binäre Suche auf einem durch 'cg-seek' geändertem Verzeichnis nicht möglich"
-
-#: git-bisect.sh:181
-msgid "Bad HEAD - strange symbolic ref"
-msgstr "Ungültiger HEAD - merkwürdige symbolische Referenz"
-
-#: git-bisect.sh:233
-#, sh-format
-msgid "Bad bisect_write argument: $state"
-msgstr "Ungültiges \"bisect_write\" Argument: $state"
-
-#: git-bisect.sh:246
+#: git-bisect.sh:101
 #, sh-format
 msgid "Bad rev input: $arg"
 msgstr "Ungültige Referenz-Eingabe: $arg"
 
-#: git-bisect.sh:265
+#: git-bisect.sh:121
 #, sh-format
 msgid "Bad rev input: $bisected_head"
 msgstr "Ungültige Referenz-Eingabe: $bisected_head"
 
-#: git-bisect.sh:274
+#: git-bisect.sh:130
 #, sh-format
 msgid "Bad rev input: $rev"
 msgstr "Ungültige Referenz-Eingabe: $rev"
 
-#: git-bisect.sh:283
+#: git-bisect.sh:139
 #, sh-format
 msgid "'git bisect $TERM_BAD' can take only one argument."
 msgstr "'git bisect $TERM_BAD' kann nur ein Argument entgegennehmen."
 
-#: git-bisect.sh:306
-#, sh-format
-msgid "Warning: bisecting only with a $TERM_BAD commit."
-msgstr "Warnung: binäre Suche nur mit einem $TERM_BAD Commit."
-
-#. TRANSLATORS: Make sure to include [Y] and [n] in your
-#. translation. The program will only accept English input
-#. at this point.
-#: git-bisect.sh:312
-msgid "Are you sure [Y/n]? "
-msgstr "Sind Sie sicher [Y/n]? "
-
-#: git-bisect.sh:324
-#, sh-format
-msgid ""
-"You need to give me at least one $bad_syn and one $good_syn revision.\n"
-"(You can use \"git bisect $bad_syn\" and \"git bisect $good_syn\" for that.)"
-msgstr ""
-"Sie müssen mindestens einen \"$bad_syn\" und einen \"$good_syn\" Commit "
-"angeben.\n"
-"(Sie können dafür \"git bisect $bad_syn\" und \"git bisect $good_syn\" "
-"benutzen.)"
-
-#: git-bisect.sh:327
-#, sh-format
-msgid ""
-"You need to start by \"git bisect start\".\n"
-"You then need to give me at least one $good_syn and one $bad_syn revision.\n"
-"(You can use \"git bisect $bad_syn\" and \"git bisect $good_syn\" for that.)"
-msgstr ""
-"Sie müssen mit \"git bisect start\" beginnen.\n"
-"Danach müssen Sie mindestens einen \"$good_syn\" und einen \"$bad_syn\" "
-"Commit angeben.\n"
-"(Sie können dafür \"git bisect $bad_syn\" und \"git bisect $good_syn\" "
-"benutzen.)"
-
-#: git-bisect.sh:398 git-bisect.sh:512
-msgid "We are not bisecting."
-msgstr "keine binäre Suche im Gange"
-
-#: git-bisect.sh:405
-#, sh-format
-msgid "'$invalid' is not a valid commit"
-msgstr "'$invalid' ist kein gültiger Commit"
-
-#: git-bisect.sh:414
-#, sh-format
-msgid ""
-"Could not check out original HEAD '$branch'.\n"
-"Try 'git bisect reset <commit>'."
-msgstr ""
-"Konnte den ursprünglichen HEAD '$branch' nicht auschecken.\n"
-"Versuchen Sie 'git bisect reset <Commit>'."
-
-#: git-bisect.sh:422
+#: git-bisect.sh:209
 msgid "No logfile given"
 msgstr "Keine Log-Datei gegeben"
 
-#: git-bisect.sh:423
+#: git-bisect.sh:210
 #, sh-format
 msgid "cannot read $file for replaying"
 msgstr "kann $file nicht für das Abspielen lesen"
 
-#: git-bisect.sh:444
+#: git-bisect.sh:232
 msgid "?? what are you talking about?"
 msgstr "?? Was reden Sie da?"
 
-#: git-bisect.sh:453
+#: git-bisect.sh:241
 msgid "bisect run failed: no command provided."
 msgstr "'bisect run' fehlgeschlagen: kein Befehl angegeben."
 
-#: git-bisect.sh:458
+#: git-bisect.sh:246
 #, sh-format
 msgid "running $command"
 msgstr "führe $command aus"
 
-#: git-bisect.sh:465
+#: git-bisect.sh:253
 #, sh-format
 msgid ""
 "bisect run failed:\n"
 "exit code $res from '$command' is < 0 or >= 128"
 msgstr ""
 "'bisect run' fehlgeschlagen:\n"
-"Rückkehrwert $res von '$command' ist < 0 oder >= 128"
+"Exit-Code $res von '$command' ist < 0 oder >= 128"
 
-#: git-bisect.sh:491
+#: git-bisect.sh:279
 msgid "bisect run cannot continue any more"
 msgstr "'bisect run' kann nicht mehr fortgesetzt werden"
 
-#: git-bisect.sh:497
+#: git-bisect.sh:285
 #, sh-format
 msgid ""
 "bisect run failed:\n"
@@ -15573,29 +23227,13 @@ msgstr ""
 "'bisect run' fehlgeschlagen:\n"
 "'bisect_state $state' wurde mit Fehlerwert $res beendet"
 
-#: git-bisect.sh:504
+#: git-bisect.sh:292
 msgid "bisect run success"
 msgstr "'bisect run' erfolgreich ausgeführt"
 
-#: git-bisect.sh:533
-#, sh-format
-msgid "Invalid command: you're currently in a $TERM_BAD/$TERM_GOOD bisect."
-msgstr ""
-"Ungültiger Befehl: Sie sind gerade bei einer binären $TERM_BAD/$TERM_GOOD "
-"Suche."
-
-#: git-bisect.sh:567
-msgid "no terms defined"
-msgstr "Keine Begriffe definiert."
-
-#: git-bisect.sh:584
-#, sh-format
-msgid ""
-"invalid argument $arg for 'git bisect terms'.\n"
-"Supported options are: --term-good|--term-old and --term-bad|--term-new."
-msgstr ""
-"Ungültiges Argument $arg für 'git bisect terms'.\n"
-"Unterstützte Optionen sind: --term-good|--term-old und --term-bad|--term-new."
+#: git-bisect.sh:300
+msgid "We are not bisecting."
+msgstr "keine binäre Suche im Gange"
 
 #: git-merge-octopus.sh:46
 msgid ""
@@ -15638,334 +23276,116 @@ msgstr "Versuche einfachen Merge mit $pr
 msgid "Simple merge did not work, trying automatic merge."
 msgstr "Einfacher Merge hat nicht funktioniert, versuche automatischen Merge."
 
-#: git-rebase.sh:60
-msgid ""
-"Resolve all conflicts manually, mark them as resolved with\n"
-"\"git add/rm <conflicted_files>\", then run \"git rebase --continue\".\n"
-"You can instead skip this commit: run \"git rebase --skip\".\n"
-"To abort and get back to the state before \"git rebase\", run \"git rebase --"
-"abort\"."
-msgstr ""
-"Lösen Sie alle Konflikte manuell auf, markieren Sie diese mit\n"
-"\"git add/rm <konfliktbehaftete_Dateien>\" und führen Sie dann\n"
-"\"git rebase --continue\" aus.\n"
-"Sie können auch stattdessen diesen Commit auslassen, indem\n"
-"Sie \"git rebase --skip\" ausführen.\n"
-"Um abzubrechen und zurück zum Zustand vor \"git rebase\" zu gelangen,\n"
-"führen Sie \"git rebase --abort\" aus."
-
-#: git-rebase.sh:163 git-rebase.sh:409
-#, sh-format
-msgid "Could not move back to $head_name"
-msgstr "Konnte nicht zu $head_name zurückgehen"
-
-#: git-rebase.sh:174
-msgid "Applied autostash."
-msgstr "Automatischen Stash angewendet."
-
-#: git-rebase.sh:177
-#, sh-format
-msgid "Cannot store $stash_sha1"
-msgstr "Kann $stash_sha1 nicht speichern."
-
-#: git-rebase.sh:218
-msgid "The pre-rebase hook refused to rebase."
-msgstr "Der \"pre-rebase hook\" hat den Rebase zurückgewiesen."
-
-#: git-rebase.sh:223
-msgid "It looks like 'git am' is in progress. Cannot rebase."
-msgstr "'git-am' scheint im Gange zu sein. Kann Rebase nicht durchführen."
-
-#: git-rebase.sh:370
-msgid "No rebase in progress?"
-msgstr "Kein Rebase im Gange?"
-
-#: git-rebase.sh:381
-msgid "The --edit-todo action can only be used during interactive rebase."
-msgstr ""
-"Die --edit-todo Aktion kann nur während eines interaktiven Rebase verwendet "
-"werden."
-
-#: git-rebase.sh:388
-msgid "Cannot read HEAD"
-msgstr "Kann HEAD nicht lesen"
-
-#: git-rebase.sh:391
-msgid ""
-"You must edit all merge conflicts and then\n"
-"mark them as resolved using git add"
-msgstr ""
-"Sie müssen alle Merge-Konflikte editieren und diese dann\n"
-"mittels \"git add\" als aufgelöst markieren"
-
-#: git-rebase.sh:435
-#, sh-format
-msgid ""
-"It seems that there is already a $state_dir_base directory, and\n"
-"I wonder if you are in the middle of another rebase.  If that is the\n"
-"case, please try\n"
-"\t$cmd_live_rebase\n"
-"If that is not the case, please\n"
-"\t$cmd_clear_stale_rebase\n"
-"and run me again.  I am stopping in case you still have something\n"
-"valuable there."
-msgstr ""
-"Es sieht so aus, als ob es das Verzeichnis $state_dir_base bereits gibt\n"
-"und es könnte ein anderer Rebase im Gange sein. Wenn das der Fall ist,\n"
-"probieren Sie bitte\n"
-"\t$cmd_live_rebase\n"
-"Wenn das nicht der Fall ist, probieren Sie bitte\n"
-"\t$cmd_clear_stale_rebase\n"
-"und führen Sie diesen Befehl nochmal aus. Es wird angehalten, falls noch\n"
-"etwas Schützenswertes vorhanden ist."
-
-#: git-rebase.sh:491
-#, sh-format
-msgid "invalid upstream '$upstream_name'"
-msgstr "Ungültiger Upstream-Branch '$upstream_name'."
-
-#: git-rebase.sh:515
-#, sh-format
-msgid "$onto_name: there are more than one merge bases"
-msgstr "$onto_name: es gibt mehr als eine Merge-Basis"
-
-#: git-rebase.sh:518 git-rebase.sh:522
-#, sh-format
-msgid "$onto_name: there is no merge base"
-msgstr "$onto_name: es gibt keine Merge-Basis"
-
-#: git-rebase.sh:527
-#, sh-format
-msgid "Does not point to a valid commit: $onto_name"
-msgstr "$onto_name zeigt auf keinen gültigen Commit"
-
-#: git-rebase.sh:553
-#, sh-format
-msgid "fatal: no such branch/commit '$branch_name'"
-msgstr "fatal: Branch/Commit '$branch_name' nicht gefunden"
-
-#: git-rebase.sh:586
-msgid "Cannot autostash"
-msgstr "Kann automatischen Stash nicht erzeugen."
-
-#: git-rebase.sh:591
-#, sh-format
-msgid "Created autostash: $stash_abbrev"
-msgstr "Automatischen Stash erzeugt: $stash_abbrev"
-
-#: git-rebase.sh:595
-msgid "Please commit or stash them."
-msgstr "Bitte committen Sie die Änderungen oder benutzen Sie \"stash\"."
-
-#: git-rebase.sh:618
-#, sh-format
-msgid "HEAD is up to date."
-msgstr "HEAD ist aktuell."
-
-#: git-rebase.sh:620
-#, sh-format
-msgid "Current branch $branch_name is up to date."
-msgstr "Aktueller Branch $branch_name ist auf dem neuesten Stand."
-
-#: git-rebase.sh:628
-#, sh-format
-msgid "HEAD is up to date, rebase forced."
-msgstr "HEAD ist aktuell, Rebase erzwungen."
-
-#: git-rebase.sh:630
-#, sh-format
-msgid "Current branch $branch_name is up to date, rebase forced."
-msgstr ""
-"Aktueller Branch $branch_name ist auf dem neuesten Stand, Rebase erzwungen."
-
-#: git-rebase.sh:642
-#, sh-format
-msgid "Changes from $mb to $onto:"
-msgstr "Änderungen von $mb zu $onto:"
-
-#: git-rebase.sh:651
-msgid "First, rewinding head to replay your work on top of it..."
-msgstr ""
-"Zunächst wird der Branch zurückgespult, um Ihre Änderungen\n"
-"darauf neu anzuwenden ..."
-
-#: git-rebase.sh:661
-#, sh-format
-msgid "Fast-forwarded $branch_name to $onto_name."
-msgstr "$branch_name zu $onto_name vorgespult."
-
-#: git-stash.sh:61
-msgid "git stash clear with parameters is unimplemented"
-msgstr "git stash clear mit Parametern ist nicht implementiert"
-
-#: git-stash.sh:108
-msgid "You do not have the initial commit yet"
-msgstr "Sie haben bisher noch keinen initialen Commit"
-
-#: git-stash.sh:123
-msgid "Cannot save the current index state"
-msgstr "Kann den aktuellen Zustand des Index nicht speichern"
-
-#: git-stash.sh:138
-msgid "Cannot save the untracked files"
-msgstr "Kann die unversionierten Dateien nicht speichern"
-
-#: git-stash.sh:158 git-stash.sh:171
-msgid "Cannot save the current worktree state"
-msgstr "Kann den aktuellen Zustand des Arbeitsverzeichnisses nicht speichern"
-
-#: git-stash.sh:175
-msgid "No changes selected"
-msgstr "Keine Änderungen ausgewählt"
-
-#: git-stash.sh:178
+#: git-legacy-stash.sh:221
 msgid "Cannot remove temporary index (can't happen)"
 msgstr "Kann temporären Index nicht löschen (kann nicht passieren)"
 
-#: git-stash.sh:191
-msgid "Cannot record working tree state"
-msgstr "Kann Zustand des Arbeitsverzeichnisses nicht aufzeichnen"
-
-#: git-stash.sh:229
+#: git-legacy-stash.sh:272
 #, sh-format
 msgid "Cannot update $ref_stash with $w_commit"
 msgstr "Kann $ref_stash nicht mit $w_commit aktualisieren."
 
-#: git-stash.sh:281
+#: git-legacy-stash.sh:324
 #, sh-format
 msgid "error: unknown option for 'stash push': $option"
 msgstr "Fehler: unbekannte Option für 'stash push': $option"
 
-#: git-stash.sh:295
-msgid "Can't use --patch and --include-untracked or --all at the same time"
-msgstr ""
-"Kann nicht gleichzeitig --patch und --include-untracked oder --all verwenden"
-
-#: git-stash.sh:303
-msgid "No local changes to save"
-msgstr "Keine lokalen Änderungen zum Speichern"
-
-#: git-stash.sh:308
-msgid "Cannot initialize stash"
-msgstr "Kann \"stash\" nicht initialisieren"
-
-#: git-stash.sh:312
-msgid "Cannot save the current status"
-msgstr "Kann den aktuellen Status nicht speichern"
-
-#: git-stash.sh:313
+#: git-legacy-stash.sh:356
 #, sh-format
 msgid "Saved working directory and index state $stash_msg"
 msgstr "Speicherte Arbeitsverzeichnis und Index-Status $stash_msg"
 
-#: git-stash.sh:340
-msgid "Cannot remove worktree changes"
-msgstr "Kann Änderungen im Arbeitsverzeichnis nicht löschen"
-
-#: git-stash.sh:488
+#: git-legacy-stash.sh:536
 #, sh-format
 msgid "unknown option: $opt"
 msgstr "unbekannte Option: $opt"
 
-#: git-stash.sh:501
-msgid "No stash entries found."
-msgstr "Keine Stash-Einträge gefunden."
-
-#: git-stash.sh:508
+#: git-legacy-stash.sh:556
 #, sh-format
 msgid "Too many revisions specified: $REV"
 msgstr "Zu viele Commits angegeben: $REV"
 
-#: git-stash.sh:523
+#: git-legacy-stash.sh:571
 #, sh-format
 msgid "$reference is not a valid reference"
 msgstr "$reference ist keine gültige Referenz"
 
-#: git-stash.sh:551
+#: git-legacy-stash.sh:599
 #, sh-format
 msgid "'$args' is not a stash-like commit"
 msgstr "'$args' ist kein \"stash\"-artiger Commit"
 
-#: git-stash.sh:562
+#: git-legacy-stash.sh:610
 #, sh-format
 msgid "'$args' is not a stash reference"
 msgstr "'$args' ist keine \"stash\"-Referenz"
 
-#: git-stash.sh:570
+#: git-legacy-stash.sh:618
 msgid "unable to refresh index"
 msgstr "Konnte den Index nicht aktualisieren."
 
-#: git-stash.sh:574
+#: git-legacy-stash.sh:622
 msgid "Cannot apply a stash in the middle of a merge"
 msgstr "Kann \"stash\" nicht anwenden, solange ein Merge im Gange ist"
 
-#: git-stash.sh:582
+#: git-legacy-stash.sh:630
 msgid "Conflicts in index. Try without --index."
 msgstr "Konflikte im Index. Versuchen Sie es ohne --index."
 
-#: git-stash.sh:584
+#: git-legacy-stash.sh:632
 msgid "Could not save index tree"
 msgstr "Konnte Index-Verzeichnis nicht speichern"
 
-#: git-stash.sh:593
+#: git-legacy-stash.sh:641
 msgid "Could not restore untracked files from stash entry"
 msgstr ""
 "Konnte unversionierte Dateien vom Stash-Eintrag nicht wiederherstellen."
 
-#: git-stash.sh:618
+#: git-legacy-stash.sh:666
 msgid "Cannot unstage modified files"
 msgstr "Kann geänderte Dateien nicht aus dem Index entfernen"
 
-#: git-stash.sh:633
-msgid "Index was not unstashed."
-msgstr "Index wurde nicht aus dem Stash zurückgeladen."
-
-#: git-stash.sh:647
-msgid "The stash entry is kept in case you need it again."
-msgstr ""
-"Der Stash-Eintrag wird für den Fall behalten, dass Sie diesen nochmal "
-"benötigen."
-
-#: git-stash.sh:656
+#: git-legacy-stash.sh:704
 #, sh-format
 msgid "Dropped ${REV} ($s)"
 msgstr "${REV} ($s) gelöscht"
 
-#: git-stash.sh:657
+#: git-legacy-stash.sh:705
 #, sh-format
 msgid "${REV}: Could not drop stash entry"
 msgstr "${REV}: Konnte \"stash\"-Eintrag nicht löschen"
 
-#: git-stash.sh:665
-msgid "No branch name specified"
-msgstr "Kein Branchname spezifiziert"
-
-#: git-stash.sh:744
+#: git-legacy-stash.sh:792
 msgid "(To restore them type \"git stash apply\")"
 msgstr "(Zur Wiederherstellung geben Sie \"git stash apply\" ein)"
 
-#: git-submodule.sh:181
+#: git-submodule.sh:202
 msgid "Relative path can only be used from the toplevel of the working tree"
 msgstr ""
 "Relative Pfade können nur von der obersten Ebene des Arbeitsverzeichnisses "
 "benutzt werden."
 
-#: git-submodule.sh:191
+#: git-submodule.sh:212
 #, sh-format
 msgid "repo URL: '$repo' must be absolute or begin with ./|../"
 msgstr "repo URL: '$repo' muss absolut sein oder mit ./|../ beginnen"
 
-#: git-submodule.sh:210
+#: git-submodule.sh:231
 #, sh-format
 msgid "'$sm_path' already exists in the index"
 msgstr "'$sm_path' ist bereits zum Commit vorgemerkt"
 
-#: git-submodule.sh:213
+#: git-submodule.sh:234
 #, sh-format
 msgid "'$sm_path' already exists in the index and is not a submodule"
 msgstr "'$sm_path' ist bereits zum Commit vorgemerkt und ist kein Submodul"
 
-#: git-submodule.sh:219
+#: git-submodule.sh:241
+#, sh-format
+msgid "'$sm_path' does not have a commit checked out"
+msgstr "'$sm_path' hat keinen Commit ausgecheckt"
+
+#: git-submodule.sh:247
 #, sh-format
 msgid ""
 "The following path is ignored by one of your .gitignore files:\n"
@@ -15976,24 +23396,24 @@ msgstr ""
 "$sm_path\n"
 "Benutzen Sie -f wenn Sie diesen wirklich hinzufügen möchten."
 
-#: git-submodule.sh:237
+#: git-submodule.sh:270
 #, sh-format
 msgid "Adding existing repo at '$sm_path' to the index"
 msgstr "Füge existierendes Repository in '$sm_path' dem Index hinzu."
 
-#: git-submodule.sh:239
+#: git-submodule.sh:272
 #, sh-format
 msgid "'$sm_path' already exists and is not a valid git repo"
 msgstr "'$sm_path' existiert bereits und ist kein gültiges Git-Repository"
 
-#: git-submodule.sh:247
+#: git-submodule.sh:280
 #, sh-format
 msgid "A git directory for '$sm_name' is found locally with remote(s):"
 msgstr ""
 "Ein Git-Verzeichnis für '$sm_name' wurde lokal gefunden mit den Remote-"
 "Repositories:"
 
-#: git-submodule.sh:249
+#: git-submodule.sh:282
 #, sh-format
 msgid ""
 "If you want to reuse this local git directory instead of cloning again from\n"
@@ -16011,47 +23431,37 @@ msgstr ""
 "nicht das korrekte Repository ist oder Sie unsicher sind, was das bedeutet,\n"
 "wählen Sie einen anderen Namen mit der Option '--name'."
 
-#: git-submodule.sh:255
+#: git-submodule.sh:288
 #, sh-format
 msgid "Reactivating local git directory for submodule '$sm_name'."
 msgstr "Reaktiviere lokales Git-Verzeichnis für Submodul '$sm_name'."
 
-#: git-submodule.sh:267
+#: git-submodule.sh:300
 #, sh-format
 msgid "Unable to checkout submodule '$sm_path'"
 msgstr "Kann Submodul '$sm_path' nicht auschecken"
 
-#: git-submodule.sh:272
+#: git-submodule.sh:305
 #, sh-format
 msgid "Failed to add submodule '$sm_path'"
 msgstr "Hinzufügen von Submodul '$sm_path' fehlgeschlagen"
 
-#: git-submodule.sh:281
+#: git-submodule.sh:314
 #, sh-format
 msgid "Failed to register submodule '$sm_path'"
 msgstr "Fehler beim Eintragen von Submodul '$sm_path' in die Konfiguration."
 
-#: git-submodule.sh:342
-#, sh-format
-msgid "Entering '$displaypath'"
-msgstr "Betrete '$displaypath'"
-
-#: git-submodule.sh:362
-#, sh-format
-msgid "Stopping at '$displaypath'; script returned non-zero status."
-msgstr "Stoppe bei '$displaypath'; Skript gab nicht-Null Status zurück."
-
-#: git-submodule.sh:584
+#: git-submodule.sh:580
 #, sh-format
 msgid "Unable to find current revision in submodule path '$displaypath'"
 msgstr "Konnte aktuellen Commit in Submodul-Pfad '$displaypath' nicht finden."
 
-#: git-submodule.sh:594
+#: git-submodule.sh:590
 #, sh-format
 msgid "Unable to fetch in submodule path '$sm_path'"
 msgstr "Konnte \"fetch\" in Submodul-Pfad '$sm_path' nicht ausführen"
 
-#: git-submodule.sh:599
+#: git-submodule.sh:595
 #, sh-format
 msgid ""
 "Unable to find current ${remote_name}/${branch} revision in submodule path "
@@ -16060,12 +23470,16 @@ msgstr ""
 "Konnte aktuellen Commit von ${remote_name}/${branch} in Submodul-Pfad\n"
 "'$sm_path' nicht finden."
 
-#: git-submodule.sh:617
+#: git-submodule.sh:613
 #, sh-format
-msgid "Unable to fetch in submodule path '$displaypath'"
-msgstr "Konnte \"fetch\" in Submodul-Pfad '$displaypath' nicht ausführen"
+msgid ""
+"Unable to fetch in submodule path '$displaypath'; trying to directly fetch "
+"$sha1:"
+msgstr ""
+"Konnte \"fetch\" in Submodul-Pfad '$displaypath' nicht ausführen. Versuche "
+"$sha1 direkt anzufordern:"
 
-#: git-submodule.sh:623
+#: git-submodule.sh:619
 #, sh-format
 msgid ""
 "Fetched in submodule path '$displaypath', but it did not contain $sha1. "
@@ -16074,134 +23488,141 @@ msgstr ""
 "\"fetch\" in Submodul-Pfad '$displaypath' ausgeführt, aber $sha1 nicht\n"
 "enthalten. Direktes Anfordern dieses Commits ist fehlgeschlagen."
 
-#: git-submodule.sh:630
+#: git-submodule.sh:626
 #, sh-format
 msgid "Unable to checkout '$sha1' in submodule path '$displaypath'"
 msgstr "Konnte '$sha1' in Submodul-Pfad '$displaypath' nicht auschecken."
 
-#: git-submodule.sh:631
+#: git-submodule.sh:627
 #, sh-format
 msgid "Submodule path '$displaypath': checked out '$sha1'"
 msgstr "Submodul-Pfad: '$displaypath': '$sha1' ausgecheckt"
 
-#: git-submodule.sh:635
+#: git-submodule.sh:631
 #, sh-format
 msgid "Unable to rebase '$sha1' in submodule path '$displaypath'"
 msgstr "Rebase auf '$sha1' in Submodul-Pfad '$displaypath' nicht möglich"
 
-#: git-submodule.sh:636
+#: git-submodule.sh:632
 #, sh-format
 msgid "Submodule path '$displaypath': rebased into '$sha1'"
 msgstr "Submodul-Pfad '$displaypath': Rebase auf '$sha1'"
 
-#: git-submodule.sh:641
+#: git-submodule.sh:637
 #, sh-format
 msgid "Unable to merge '$sha1' in submodule path '$displaypath'"
 msgstr "Merge von '$sha1' in Submodul-Pfad '$displaypath' fehlgeschlagen"
 
-#: git-submodule.sh:642
+#: git-submodule.sh:638
 #, sh-format
 msgid "Submodule path '$displaypath': merged in '$sha1'"
 msgstr "Submodul-Pfad '$displaypath': zusammengeführt in '$sha1'"
 
-#: git-submodule.sh:647
+#: git-submodule.sh:643
 #, sh-format
 msgid "Execution of '$command $sha1' failed in submodule path '$displaypath'"
 msgstr ""
 "Ausführung von '$command $sha1' in Submodul-Pfad '$displaypath' "
 "fehlgeschlagen"
 
-#: git-submodule.sh:648
+#: git-submodule.sh:644
 #, sh-format
 msgid "Submodule path '$displaypath': '$command $sha1'"
 msgstr "Submodul-Pfad '$displaypath': '$command $sha1'"
 
-#: git-submodule.sh:679
+#: git-submodule.sh:675
 #, sh-format
 msgid "Failed to recurse into submodule path '$displaypath'"
 msgstr "Fehler bei Rekursion in Submodul-Pfad '$displaypath'"
 
-#: git-submodule.sh:775
+#: git-submodule.sh:886
 msgid "The --cached option cannot be used with the --files option"
 msgstr ""
 "Die Optionen --cached und --files können nicht gemeinsam verwendet werden."
 
-#: git-submodule.sh:827
+#: git-submodule.sh:938
 #, sh-format
 msgid "unexpected mode $mod_dst"
 msgstr "unerwarteter Modus $mod_dst"
 
-#: git-submodule.sh:847
+#: git-submodule.sh:958
 #, sh-format
 msgid "  Warn: $display_name doesn't contain commit $sha1_src"
 msgstr "  Warnung: $display_name beinhaltet nicht Commit $sha1_src"
 
-#: git-submodule.sh:850
+#: git-submodule.sh:961
 #, sh-format
 msgid "  Warn: $display_name doesn't contain commit $sha1_dst"
 msgstr "  Warnung: $display_name beinhaltet nicht Commit $sha1_dst"
 
-#: git-submodule.sh:853
+#: git-submodule.sh:964
 #, sh-format
 msgid "  Warn: $display_name doesn't contain commits $sha1_src and $sha1_dst"
 msgstr ""
 "  Warnung: $display_name beinhaltet nicht die Commits $sha1_src und $sha1_dst"
 
-#: git-parse-remote.sh:89
+#: git-parse-remote.sh:89
+#, sh-format
+msgid "See git-${cmd}(1) for details."
+msgstr "Siehe git-${cmd}(1) für weitere Details."
+
+#: git-rebase--preserve-merges.sh:109
+msgid "Applied autostash."
+msgstr "Automatischen Stash angewendet."
+
+#: git-rebase--preserve-merges.sh:112
 #, sh-format
-msgid "See git-${cmd}(1) for details."
-msgstr "Siehe git-${cmd}(1) für weitere Details."
+msgid "Cannot store $stash_sha1"
+msgstr "Kann $stash_sha1 nicht speichern."
 
-#: git-rebase--interactive.sh:140
+#: git-rebase--preserve-merges.sh:191
 #, sh-format
 msgid "Rebasing ($new_count/$total)"
 msgstr "Führe Rebase aus ($new_count/$total)"
 
-#: git-rebase--interactive.sh:156
+#: git-rebase--preserve-merges.sh:207
 msgid ""
 "\n"
 "Commands:\n"
-"p, pick = use commit\n"
-"r, reword = use commit, but edit the commit message\n"
-"e, edit = use commit, but stop for amending\n"
-"s, squash = use commit, but meld into previous commit\n"
-"f, fixup = like \"squash\", but discard this commit's log message\n"
-"x, exec = run command (the rest of the line) using shell\n"
-"d, drop = remove commit\n"
+"p, pick <commit> = use commit\n"
+"r, reword <commit> = use commit, but edit the commit message\n"
+"e, edit <commit> = use commit, but stop for amending\n"
+"s, squash <commit> = use commit, but meld into previous commit\n"
+"f, fixup <commit> = like \"squash\", but discard this commit's log message\n"
+"x, exec <commit> = run command (the rest of the line) using shell\n"
+"d, drop <commit> = remove commit\n"
+"l, label <label> = label current HEAD with a name\n"
+"t, reset <label> = reset HEAD to a label\n"
+"m, merge [-C <commit> | -c <commit>] <label> [# <oneline>]\n"
+".       create a merge commit using the original merge commit's\n"
+".       message (or the oneline, if no original merge commit was\n"
+".       specified). Use -c <commit> to reword the commit message.\n"
 "\n"
 "These lines can be re-ordered; they are executed from top to bottom.\n"
 msgstr ""
 "\n"
 "Befehle:\n"
-"p, pick = Commit verwenden\n"
-"r, reword = Commit verwenden, aber Commit-Beschreibung bearbeiten\n"
-"e, edit = Commit verwenden, aber zum Nachbessern anhalten\n"
-"s, squash = Commit verwenden, aber mit vorherigem Commit vereinen\n"
-"f, fixup = wie \"squash\", aber diese Commit-Beschreibung verwerfen\n"
-"x, exec = Befehl (Rest der Zeile) mittels Shell ausführen\n"
-"d, drop = Commit entfernen\n"
+"p, pick <Commit> = Commit verwenden\n"
+"r, reword <Commit> = Commit verwenden, aber Commit-Beschreibung bearbeiten\n"
+"e, edit <Commit> = Commit verwenden, aber zum Nachbessern anhalten\n"
+"s, squash <Commit> = Commit verwenden, aber mit vorherigem Commit vereinen\n"
+"f, fixup <Commit> = wie \"squash\", aber diese Commit-Beschreibung "
+"verwerfen\n"
+"x, exec <Commit> = Befehl (Rest der Zeile) mittels Shell ausführen\n"
+"d, drop <Commit> = Commit entfernen\n"
+"l, label <Label> = aktuellen HEAD mit Label versehen\n"
+"t, reset <Label> = HEAD zu einem Label umsetzen\n"
+"m, merge [-C <Commit> | -c <Commit>] <Label> [# <eineZeile>]\n"
+".       Merge-Commit mit der originalen Merge-Commit-Beschreibung erstellen\n"
+".       (oder die eine Zeile, wenn keine originale Merge-Commit-"
+"Beschreibung\n"
+".       spezifiziert ist). Benutzen Sie -c <Commit> zum Bearbeiten der\n"
+".       Commit-Beschreibung.\n"
 "\n"
 "Diese Zeilen können umsortiert werden; Sie werden von oben nach unten\n"
 "ausgeführt.\n"
 
-#: git-rebase--interactive.sh:171
-msgid ""
-"\n"
-"Do not remove any line. Use 'drop' explicitly to remove a commit.\n"
-msgstr ""
-"\n"
-"Keine Zeile entfernen. Benutzen Sie 'drop', um explizit einen Commit zu\n"
-"entfernen.\n"
-
-#: git-rebase--interactive.sh:175
-msgid ""
-"\n"
-"If you remove a line here THAT COMMIT WILL BE LOST.\n"
-msgstr ""
-"\n"
-"Wenn Sie hier eine Zeile entfernen, wird DIESER COMMIT VERLOREN GEHEN.\n"
-
-#: git-rebase--interactive.sh:213
+#: git-rebase--preserve-merges.sh:270
 #, sh-format
 msgid ""
 "You can amend the commit now, with\n"
@@ -16220,83 +23641,83 @@ msgstr ""
 "\n"
 "\tgit rebase --continue"
 
-#: git-rebase--interactive.sh:238
+#: git-rebase--preserve-merges.sh:295
 #, sh-format
 msgid "$sha1: not a commit that can be picked"
 msgstr "$sha1: kein Commit der gepickt werden kann"
 
-#: git-rebase--interactive.sh:277
+#: git-rebase--preserve-merges.sh:334
 #, sh-format
 msgid "Invalid commit name: $sha1"
 msgstr "Ungültiger Commit-Name: $sha1"
 
-#: git-rebase--interactive.sh:319
+#: git-rebase--preserve-merges.sh:364
 msgid "Cannot write current commit's replacement sha1"
 msgstr "Kann ersetzenden SHA-1 des aktuellen Commits nicht schreiben"
 
-#: git-rebase--interactive.sh:371
+#: git-rebase--preserve-merges.sh:415
 #, sh-format
 msgid "Fast-forward to $sha1"
 msgstr "Spule vor zu $sha1"
 
-#: git-rebase--interactive.sh:373
+#: git-rebase--preserve-merges.sh:417
 #, sh-format
 msgid "Cannot fast-forward to $sha1"
 msgstr "Kann nicht zu $sha1 vorspulen"
 
-#: git-rebase--interactive.sh:382
+#: git-rebase--preserve-merges.sh:426
 #, sh-format
 msgid "Cannot move HEAD to $first_parent"
 msgstr "Kann HEAD nicht auf $first_parent setzen"
 
-#: git-rebase--interactive.sh:387
+#: git-rebase--preserve-merges.sh:431
 #, sh-format
 msgid "Refusing to squash a merge: $sha1"
 msgstr "\"squash\" eines Merges ($sha1) zurückgewiesen."
 
-#: git-rebase--interactive.sh:405
+#: git-rebase--preserve-merges.sh:449
 #, sh-format
 msgid "Error redoing merge $sha1"
 msgstr "Fehler beim Wiederholen des Merges von $sha1"
 
-#: git-rebase--interactive.sh:414
+#: git-rebase--preserve-merges.sh:458
 #, sh-format
 msgid "Could not pick $sha1"
 msgstr "Konnte $sha1 nicht picken"
 
-#: git-rebase--interactive.sh:423
+#: git-rebase--preserve-merges.sh:467
 #, sh-format
 msgid "This is the commit message #${n}:"
 msgstr "Das ist Commit-Beschreibung #${n}:"
 
-#: git-rebase--interactive.sh:428
+#: git-rebase--preserve-merges.sh:472
 #, sh-format
 msgid "The commit message #${n} will be skipped:"
 msgstr "Commit-Beschreibung #${n} wird ausgelassen:"
 
-#: git-rebase--interactive.sh:439
+#: git-rebase--preserve-merges.sh:483
 #, sh-format
 msgid "This is a combination of $count commit."
 msgid_plural "This is a combination of $count commits."
 msgstr[0] "Das ist eine Kombination aus $count Commit."
 msgstr[1] "Das ist eine Kombination aus $count Commits."
 
-#: git-rebase--interactive.sh:448
+#: git-rebase--preserve-merges.sh:492
 #, sh-format
 msgid "Cannot write $fixup_msg"
 msgstr "Kann $fixup_msg nicht schreiben"
 
-#: git-rebase--interactive.sh:451
+#: git-rebase--preserve-merges.sh:495
 msgid "This is a combination of 2 commits."
 msgstr "Das ist eine Kombination aus 2 Commits."
 
-#: git-rebase--interactive.sh:492 git-rebase--interactive.sh:535
-#: git-rebase--interactive.sh:538
+#: git-rebase--preserve-merges.sh:536 git-rebase--preserve-merges.sh:579
+#: git-rebase--preserve-merges.sh:582
 #, sh-format
 msgid "Could not apply $sha1... $rest"
 msgstr "Konnte $sha1... ($rest) nicht anwenden"
 
-#: git-rebase--interactive.sh:567
+#: git-rebase--preserve-merges.sh:611
 #, sh-format
 msgid ""
 "Could not amend commit after successfully picking $sha1... $rest\n"
@@ -16313,31 +23734,31 @@ msgstr ""
 "sollten Sie das Problem beheben, bevor Sie die Commit-Beschreibung ändern "
 "können."
 
-#: git-rebase--interactive.sh:582
+#: git-rebase--preserve-merges.sh:626
 #, sh-format
 msgid "Stopped at $sha1_abbrev... $rest"
 msgstr "Angehalten bei $sha1_abbrev... $rest"
 
-#: git-rebase--interactive.sh:597
+#: git-rebase--preserve-merges.sh:641
 #, sh-format
 msgid "Cannot '$squash_style' without a previous commit"
 msgstr "Kann nicht '$squash_style' ohne vorherigen Commit"
 
-#: git-rebase--interactive.sh:639
+#: git-rebase--preserve-merges.sh:683
 #, sh-format
 msgid "Executing: $rest"
 msgstr "Führe aus: $rest"
 
-#: git-rebase--interactive.sh:647
+#: git-rebase--preserve-merges.sh:691
 #, sh-format
 msgid "Execution failed: $rest"
 msgstr "Ausführung fehlgeschlagen: $rest"
 
-#: git-rebase--interactive.sh:649
+#: git-rebase--preserve-merges.sh:693
 msgid "and made changes to the index and/or the working tree"
 msgstr "Der Index und/oder das Arbeitsverzeichnis wurde geändert."
 
-#: git-rebase--interactive.sh:651
+#: git-rebase--preserve-merges.sh:695
 msgid ""
 "You can fix the problem, and then run\n"
 "\n"
@@ -16350,7 +23771,7 @@ msgstr ""
 "ausführen."
 
 #. TRANSLATORS: after these lines is a command to be issued by the user
-#: git-rebase--interactive.sh:664
+#: git-rebase--preserve-merges.sh:708
 #, sh-format
 msgid ""
 "Execution succeeded: $rest\n"
@@ -16366,29 +23787,25 @@ msgstr ""
 "\n"
 "\tgit rebase --continue"
 
-#: git-rebase--interactive.sh:675
+#: git-rebase--preserve-merges.sh:719
 #, sh-format
 msgid "Unknown command: $command $sha1 $rest"
 msgstr "Unbekannter Befehl: $command $sha1 $rest"
 
-#: git-rebase--interactive.sh:676
+#: git-rebase--preserve-merges.sh:720
 msgid "Please fix this using 'git rebase --edit-todo'."
 msgstr "Bitte beheben Sie das, indem Sie 'git rebase --edit-todo' ausführen."
 
-#: git-rebase--interactive.sh:711
+#: git-rebase--preserve-merges.sh:755
 #, sh-format
 msgid "Successfully rebased and updated $head_name."
 msgstr "Erfolgreich Rebase ausgeführt und $head_name aktualisiert."
 
-#: git-rebase--interactive.sh:735
-msgid "could not detach HEAD"
-msgstr "Konnte HEAD nicht loslösen"
-
-#: git-rebase--interactive.sh:771
+#: git-rebase--preserve-merges.sh:812
 msgid "Could not remove CHERRY_PICK_HEAD"
 msgstr "Konnte CHERRY_PICK_HEAD nicht löschen"
 
-#: git-rebase--interactive.sh:776
+#: git-rebase--preserve-merges.sh:817
 #, sh-format
 msgid ""
 "You have staged changes in your working tree.\n"
@@ -16420,13 +23837,13 @@ msgstr ""
 "\n"
 "  git rebase --continue\n"
 
-#: git-rebase--interactive.sh:793
+#: git-rebase--preserve-merges.sh:834
 msgid "Error trying to find the author identity to amend commit"
 msgstr ""
 "Fehler beim Versuch die Identität des Authors zum Verbessern des Commits zu\n"
 "finden"
 
-#: git-rebase--interactive.sh:798
+#: git-rebase--preserve-merges.sh:839
 msgid ""
 "You have uncommitted changes in your working tree. Please commit them\n"
 "first and then run 'git rebase --continue' again."
@@ -16436,228 +23853,134 @@ msgstr ""
 "erneut\n"
 "aus."
 
-#: git-rebase--interactive.sh:803 git-rebase--interactive.sh:807
+#: git-rebase--preserve-merges.sh:844 git-rebase--preserve-merges.sh:848
 msgid "Could not commit staged changes."
 msgstr "Konnte Änderungen aus der Staging-Area nicht committen."
 
-#: git-rebase--interactive.sh:836
-msgid ""
-"\n"
-"You are editing the todo file of an ongoing interactive rebase.\n"
-"To continue rebase after editing, run:\n"
-"    git rebase --continue\n"
-"\n"
-msgstr ""
-"\n"
-"Sie bearbeiten gerade die TODO-Datei eines laufenden interaktiven Rebase.\n"
-"Um den Rebase nach dem Editieren fortzusetzen, führen Sie aus:\n"
-"    git rebase --continue\n"
-"\n"
-
-#: git-rebase--interactive.sh:844 git-rebase--interactive.sh:1008
+#: git-rebase--preserve-merges.sh:879 git-rebase--preserve-merges.sh:965
 msgid "Could not execute editor"
 msgstr "Konnte Editor nicht ausführen."
 
-#: git-rebase--interactive.sh:860
+#: git-rebase--preserve-merges.sh:900
 #, sh-format
 msgid "Could not checkout $switch_to"
 msgstr "Konnte $switch_to nicht auschecken."
 
-#: git-rebase--interactive.sh:865
+#: git-rebase--preserve-merges.sh:907
 msgid "No HEAD?"
 msgstr "Kein HEAD?"
 
-#: git-rebase--interactive.sh:866
+#: git-rebase--preserve-merges.sh:908
 #, sh-format
 msgid "Could not create temporary $state_dir"
 msgstr "Konnte temporäres Verzeichnis $state_dir nicht erstellen."
 
-#: git-rebase--interactive.sh:869
+#: git-rebase--preserve-merges.sh:911
 msgid "Could not mark as interactive"
 msgstr "Konnte nicht als interaktiven Rebase markieren."
 
-#: git-rebase--interactive.sh:879 git-rebase--interactive.sh:884
-msgid "Could not init rewritten commits"
-msgstr "Konnte neu geschriebene Commits nicht initialisieren."
-
-#: git-rebase--interactive.sh:910
-msgid "Could not generate todo list"
-msgstr "Konnte TODO-Liste nicht erzeugen."
-
-#: git-rebase--interactive.sh:986
+#: git-rebase--preserve-merges.sh:943
 #, sh-format
 msgid "Rebase $shortrevisions onto $shortonto ($todocount command)"
 msgid_plural "Rebase $shortrevisions onto $shortonto ($todocount commands)"
 msgstr[0] "Rebase von $shortrevisions auf $shortonto ($todocount Kommando)"
 msgstr[1] "Rebase von $shortrevisions auf $shortonto ($todocount Kommandos)"
 
-#: git-rebase--interactive.sh:991
-msgid ""
-"\n"
-"However, if you remove everything, the rebase will be aborted.\n"
-"\n"
-msgstr ""
-"\n"
-"Wenn Sie jedoch alles löschen, wird der Rebase abgebrochen.\n"
-"\n"
-
-#: git-rebase--interactive.sh:998
-msgid "Note that empty commits are commented out"
-msgstr "Leere Commits sind auskommentiert."
+#: git-rebase--preserve-merges.sh:997 git-rebase--preserve-merges.sh:1002
+msgid "Could not init rewritten commits"
+msgstr "Konnte neu geschriebene Commits nicht initialisieren."
 
 #: git-sh-setup.sh:89 git-sh-setup.sh:94
 #, sh-format
 msgid "usage: $dashless $USAGE"
 msgstr "Verwendung: $dashless $USAGE"
 
-#: git-sh-setup.sh:190
+#: git-sh-setup.sh:191
 #, sh-format
 msgid "Cannot chdir to $cdup, the toplevel of the working tree"
 msgstr ""
 "Konnte nicht in Verzeichnis $cdup wechseln, der obersten Ebene des\n"
 "Arbeitsverzeichnisses."
 
-#: git-sh-setup.sh:199 git-sh-setup.sh:206
+#: git-sh-setup.sh:200 git-sh-setup.sh:207
 #, sh-format
 msgid "fatal: $program_name cannot be used without a working tree."
 msgstr ""
 "fatal: $program_name kann ohne ein Arbeitsverzeichnis nicht verwendet werden."
 
-#: git-sh-setup.sh:220
+#: git-sh-setup.sh:221
 msgid "Cannot rebase: You have unstaged changes."
 msgstr ""
 "Rebase nicht möglich: Sie haben Änderungen, die nicht zum Commit vorgemerkt "
 "sind."
 
-#: git-sh-setup.sh:223
+#: git-sh-setup.sh:224
 msgid "Cannot rewrite branches: You have unstaged changes."
 msgstr ""
 "Kann Branches nicht neu schreiben: Sie haben Änderungen, die nicht zum "
 "Commit\n"
 "vorgemerkt sind."
 
-#: git-sh-setup.sh:226
+#: git-sh-setup.sh:227
 msgid "Cannot pull with rebase: You have unstaged changes."
 msgstr ""
 "Kann \"pull\" mit \"rebase\" nicht ausführen: Sie haben Änderungen, die "
 "nicht zum Commit vorgemerkt sind."
 
-#: git-sh-setup.sh:229
+#: git-sh-setup.sh:230
 #, sh-format
 msgid "Cannot $action: You have unstaged changes."
 msgstr ""
 "Kann $action nicht ausführen: Sie haben Änderungen, die nicht zum Commit\n"
 "vorgemerkt sind."
 
-#: git-sh-setup.sh:242
+#: git-sh-setup.sh:243
 msgid "Cannot rebase: Your index contains uncommitted changes."
 msgstr ""
 "Rebase nicht möglich: Die Staging-Area beinhaltet nicht committete "
 "Änderungen."
 
-#: git-sh-setup.sh:245
+#: git-sh-setup.sh:246
 msgid "Cannot pull with rebase: Your index contains uncommitted changes."
 msgstr ""
 "Kann \"pull\" mit \"rebase\" nicht ausführen: Die Staging-Area beinhaltet "
 "nicht committete Änderungen."
 
-#: git-sh-setup.sh:248
+#: git-sh-setup.sh:249
 #, sh-format
 msgid "Cannot $action: Your index contains uncommitted changes."
 msgstr ""
 "Kann $action nicht ausführen: Die Staging-Area beinhaltet nicht committete\n"
 "Änderungen."
 
-#: git-sh-setup.sh:252
+#: git-sh-setup.sh:253
 msgid "Additionally, your index contains uncommitted changes."
 msgstr "Zusätzlich beinhaltet die Staging-Area nicht committete Änderungen."
 
-#: git-sh-setup.sh:372
+#: git-sh-setup.sh:373
 msgid "You need to run this command from the toplevel of the working tree."
 msgstr ""
 "Sie müssen den Befehl von der obersten Ebene des Arbeitsverzeichnisses "
 "ausführen."
 
-#: git-sh-setup.sh:377
+#: git-sh-setup.sh:378
 msgid "Unable to determine absolute path of git directory"
 msgstr "Konnte absoluten Pfad des Git-Verzeichnisses nicht bestimmen."
 
 #. TRANSLATORS: you can adjust this to align "git add -i" status menu
-#: git-add--interactive.perl:196
+#: git-add--interactive.perl:212
 #, perl-format
 msgid "%12s %12s %s"
 msgstr "%28s %25s %s"
 
-#: git-add--interactive.perl:197
-msgid "staged"
-msgstr "zur Staging-Area hinzugefügt"
-
-#: git-add--interactive.perl:197
-msgid "unstaged"
-msgstr "aus Staging-Area entfernt"
-
-#: git-add--interactive.perl:246 git-add--interactive.perl:271
-msgid "binary"
-msgstr "Binär"
-
-#: git-add--interactive.perl:255 git-add--interactive.perl:309
-msgid "nothing"
-msgstr "Nichts"
-
-#: git-add--interactive.perl:291 git-add--interactive.perl:306
-msgid "unchanged"
-msgstr "unverändert"
-
-#: git-add--interactive.perl:602
-#, perl-format
-msgid "added %d path\n"
-msgid_plural "added %d paths\n"
-msgstr[0] "%d Pfad hinzugefügt\n"
-msgstr[1] "%d Pfade hinzugefügt\n"
-
-#: git-add--interactive.perl:605
-#, perl-format
-msgid "updated %d path\n"
-msgid_plural "updated %d paths\n"
-msgstr[0] "%d Pfad aktualisiert\n"
-msgstr[1] "%d Pfade aktualisiert\n"
-
-#: git-add--interactive.perl:608
-#, perl-format
-msgid "reverted %d path\n"
-msgid_plural "reverted %d paths\n"
-msgstr[0] "%d Pfad wiederhergestellt\n"
-msgstr[1] "%d Pfade wiederhergestellt\n"
-
-#: git-add--interactive.perl:611
+#: git-add--interactive.perl:634
 #, perl-format
 msgid "touched %d path\n"
 msgid_plural "touched %d paths\n"
 msgstr[0] "%d Pfad angefasst\n"
 msgstr[1] "%d Pfade angefasst\n"
 
-#: git-add--interactive.perl:620
-msgid "Update"
-msgstr "Aktualisieren"
-
-#: git-add--interactive.perl:632
-msgid "Revert"
-msgstr "Revert"
-
-#: git-add--interactive.perl:655
-#, perl-format
-msgid "note: %s is untracked now.\n"
-msgstr "Hinweis: %s ist nun unversioniert.\n"
-
-#: git-add--interactive.perl:666
-msgid "Add untracked"
-msgstr "unversionierte Dateien hinzufügen"
-
-#: git-add--interactive.perl:672
-msgid "No untracked files.\n"
-msgstr "Keine unversionierten Dateien.\n"
-
-#: git-add--interactive.perl:1026
+#: git-add--interactive.perl:1053
 msgid ""
 "If the patch applies cleanly, the edited hunk will immediately be\n"
 "marked for staging."
@@ -16666,7 +23989,7 @@ msgstr ""
 "Block\n"
 "direkt als zum Hinzufügen zur Staging-Area markiert."
 
-#: git-add--interactive.perl:1029
+#: git-add--interactive.perl:1056
 msgid ""
 "If the patch applies cleanly, the edited hunk will immediately be\n"
 "marked for stashing."
@@ -16675,7 +23998,7 @@ msgstr ""
 "Block\n"
 "direkt als zum Hinzufügen zum Stash markiert."
 
-#: git-add--interactive.perl:1032
+#: git-add--interactive.perl:1059
 msgid ""
 "If the patch applies cleanly, the edited hunk will immediately be\n"
 "marked for unstaging."
@@ -16684,7 +24007,8 @@ msgstr ""
 "Block\n"
 "direkt als zum Entfernen aus der Staging-Area markiert."
 
-#: git-add--interactive.perl:1035 git-add--interactive.perl:1044
+#: git-add--interactive.perl:1062 git-add--interactive.perl:1071
+#: git-add--interactive.perl:1077
 msgid ""
 "If the patch applies cleanly, the edited hunk will immediately be\n"
 "marked for applying."
@@ -16693,7 +24017,8 @@ msgstr ""
 "Block\n"
 "direkt als zum Anwenden markiert."
 
-#: git-add--interactive.perl:1038 git-add--interactive.perl:1041
+#: git-add--interactive.perl:1065 git-add--interactive.perl:1068
+#: git-add--interactive.perl:1074
 msgid ""
 "If the patch applies cleanly, the edited hunk will immediately be\n"
 "marked for discarding."
@@ -16702,19 +24027,13 @@ msgstr ""
 "Block\n"
 "direkt als zum Verwerfen markiert."
 
-#: git-add--interactive.perl:1078
+#: git-add--interactive.perl:1111
 #, perl-format
 msgid "failed to open hunk edit file for writing: %s"
 msgstr ""
 "Fehler beim Öffnen von Editier-Datei eines Patch-Blocks zum Schreiben: %s"
 
-#: git-add--interactive.perl:1079
-msgid "Manual hunk edit mode -- see bottom for a quick guide.\n"
-msgstr ""
-"Manueller Editiermodus für Patch-Blöcke -- siehe nach unten für eine\n"
-"Kurzanleitung.\n"
-
-#: git-add--interactive.perl:1085
+#: git-add--interactive.perl:1118
 #, perl-format
 msgid ""
 "---\n"
@@ -16727,37 +24046,12 @@ msgstr ""
 "Um '%s' Zeilen zu entfernen, löschen Sie diese.\n"
 "Zeilen, die mit %s beginnen, werden entfernt.\n"
 
-#. TRANSLATORS: 'it' refers to the patch mentioned in the previous messages.
-#: git-add--interactive.perl:1093
-msgid ""
-"If it does not apply cleanly, you will be given an opportunity to\n"
-"edit again.  If all lines of the hunk are removed, then the edit is\n"
-"aborted and the hunk is left unchanged.\n"
-msgstr ""
-"Wenn das nicht sauber angewendet werden kann, haben Sie die Möglichkeit\n"
-"einer erneuten Bearbeitung. Wenn alle Zeilen des Patch-Blocks entfernt "
-"werden,\n"
-"wird die Bearbeitung abgebrochen und der Patch-Block bleibt unverändert.\n"
-
-#: git-add--interactive.perl:1107
+#: git-add--interactive.perl:1140
 #, perl-format
 msgid "failed to open hunk edit file for reading: %s"
 msgstr "Fehler beim Öffnen von Editier-Datei eines Patch-Blocks zum Lesen: %s"
 
-#. TRANSLATORS: do not translate [y/n]
-#. The program will only accept that input
-#. at this point.
-#. Consider translating (saying "no" discards!) as
-#. (saying "n" for "no" discards!) if the translation
-#. of the word "no" does not start with n.
-#: git-add--interactive.perl:1206
-msgid ""
-"Your edited hunk does not apply. Edit again (saying \"no\" discards!) [y/n]? "
-msgstr ""
-"Ihr bearbeiteter Patch-Block kann nicht angewendet werden.\n"
-"Erneut bearbeiten? (\"n\" verwirft Bearbeitung!) [y/n]?"
-
-#: git-add--interactive.perl:1215
+#: git-add--interactive.perl:1248
 msgid ""
 "y - stage this hunk\n"
 "n - do not stage this hunk\n"
@@ -16773,7 +24067,7 @@ msgstr ""
 "d - diesen oder alle weiteren Patch-Blöcke in dieser Datei nicht zum Commit "
 "vormerken"
 
-#: git-add--interactive.perl:1221
+#: git-add--interactive.perl:1254
 msgid ""
 "y - stash this hunk\n"
 "n - do not stash this hunk\n"
@@ -16787,7 +24081,7 @@ msgstr ""
 "a - diesen und alle weiteren Patch-Blöcke dieser Datei stashen\n"
 "d - diesen oder alle weiteren Patch-Blöcke dieser Datei nicht stashen"
 
-#: git-add--interactive.perl:1227
+#: git-add--interactive.perl:1260
 msgid ""
 "y - unstage this hunk\n"
 "n - do not unstage this hunk\n"
@@ -16801,7 +24095,7 @@ msgstr ""
 "a - diesen und alle weiteren Patch-Blöcke dieser Datei unstashen\n"
 "d - diesen oder alle weiteren Patch-Blöcke dieser Datei nicht unstashen"
 
-#: git-add--interactive.perl:1233
+#: git-add--interactive.perl:1266
 msgid ""
 "y - apply this hunk to index\n"
 "n - do not apply this hunk to index\n"
@@ -16818,7 +24112,7 @@ msgstr ""
 "d - diesen oder alle weiteren Patch-Blöcke dieser Datei nicht auf den Index "
 "anwenden"
 
-#: git-add--interactive.perl:1239
+#: git-add--interactive.perl:1272 git-add--interactive.perl:1290
 msgid ""
 "y - discard this hunk from worktree\n"
 "n - do not discard this hunk from worktree\n"
@@ -16835,7 +24129,7 @@ msgstr ""
 "d - diesen oder alle weiteren Patch-Blöcke dieser Datei nicht im "
 "Arbeitsverzeichnis verwerfen"
 
-#: git-add--interactive.perl:1245
+#: git-add--interactive.perl:1278
 msgid ""
 "y - discard this hunk from index and worktree\n"
 "n - do not discard this hunk from index and worktree\n"
@@ -16850,7 +24144,7 @@ msgstr ""
 "a - diesen und alle weiteren Patch-Blöcke in der Datei verwerfen\n"
 "d - diesen oder alle weiteren Patch-Blöcke in der Datei nicht verwerfen"
 
-#: git-add--interactive.perl:1251
+#: git-add--interactive.perl:1284
 msgid ""
 "y - apply this hunk to index and worktree\n"
 "n - do not apply this hunk to index and worktree\n"
@@ -16864,7 +24158,21 @@ msgstr ""
 "a - diesen und alle weiteren Patch-Blöcke in der Datei anwenden\n"
 "d - diesen oder alle weiteren Patch-Blöcke in der Datei nicht anwenden"
 
-#: git-add--interactive.perl:1266
+#: git-add--interactive.perl:1296
+msgid ""
+"y - apply this hunk to worktree\n"
+"n - do not apply this hunk to worktree\n"
+"q - quit; do not apply this hunk or any of the remaining ones\n"
+"a - apply this hunk and all later hunks in the file\n"
+"d - do not apply this hunk or any of the later hunks in the file"
+msgstr ""
+"y - diesen Patch-Block auf das Arbeitsverzeichnis anwenden\n"
+"n - diesen Patch-Block nicht auf das Arbeitsverzeichnis anwenden\n"
+"q - Beenden; diesen und alle verbleibenden Patch-Blöcke nicht anwenden\n"
+"a - diesen und alle weiteren Patch-Blöcke in der Datei anwenden\n"
+"d - diesen und alle weiteren Patch-Blöcke in der Datei nicht anwenden"
+
+#: git-add--interactive.perl:1311
 msgid ""
 "g - select a hunk to go to\n"
 "/ - search for a hunk matching the given regex\n"
@@ -16877,7 +24185,7 @@ msgid ""
 "? - print help\n"
 msgstr ""
 "g - Patch-Block zum Hinspringen auswählen\n"
-"/ - nach Patch-Block suchen der gegebenem regulärem Ausdruck entspricht\n"
+"/ - nach Patch-Block suchen, der gegebenem regulärem Ausdruck entspricht\n"
 "j - diesen Patch-Block unbestimmt lassen, nächsten unbestimmten Patch-Block "
 "anzeigen\n"
 "J - diesen Patch-Block unbestimmt lassen, nächsten Patch-Block anzeigen\n"
@@ -16888,212 +24196,206 @@ msgstr ""
 "e - aktuellen Patch-Block manuell editieren\n"
 "? - Hilfe anzeigen\n"
 
-#: git-add--interactive.perl:1297
+#: git-add--interactive.perl:1342
 msgid "The selected hunks do not apply to the index!\n"
 msgstr ""
 "Die ausgewählten Patch-Blöcke können nicht auf den Index angewendet werden!\n"
 
-#: git-add--interactive.perl:1298
+#: git-add--interactive.perl:1343
 msgid "Apply them to the worktree anyway? "
 msgstr "Trotzdem auf Arbeitsverzeichnis anwenden? "
 
-#: git-add--interactive.perl:1301
+#: git-add--interactive.perl:1346
 msgid "Nothing was applied.\n"
 msgstr "Nichts angewendet.\n"
 
-#: git-add--interactive.perl:1312
+#: git-add--interactive.perl:1357
 #, perl-format
 msgid "ignoring unmerged: %s\n"
 msgstr "ignoriere nicht zusammengeführte Datei: %s\n"
 
-#: git-add--interactive.perl:1321
-msgid "Only binary files changed.\n"
-msgstr "Nur Binärdateien geändert.\n"
-
-#: git-add--interactive.perl:1323
-msgid "No changes.\n"
-msgstr "Keine Änderungen.\n"
-
-#: git-add--interactive.perl:1331
-msgid "Patch update"
-msgstr "Patch Aktualisierung"
-
-#: git-add--interactive.perl:1383
+#: git-add--interactive.perl:1428
 #, perl-format
 msgid "Stage mode change [y,n,q,a,d%s,?]? "
 msgstr "Modusänderung der Staging-Area hinzufügen [y,n,q,a,d%s,?]? "
 
-#: git-add--interactive.perl:1384
+#: git-add--interactive.perl:1429
 #, perl-format
 msgid "Stage deletion [y,n,q,a,d%s,?]? "
 msgstr "Löschung der Staging-Area hinzufügen [y,n,q,a,d%s,?]? "
 
-#: git-add--interactive.perl:1385
+#: git-add--interactive.perl:1430
 #, perl-format
 msgid "Stage this hunk [y,n,q,a,d%s,?]? "
 msgstr "Diesen Patch-Block der Staging-Area hinzufügen [y,n,q,a,d%s,?]? "
 
-#: git-add--interactive.perl:1388
+#: git-add--interactive.perl:1433
 #, perl-format
 msgid "Stash mode change [y,n,q,a,d%s,?]? "
 msgstr "Modusänderung stashen [y,n,q,a,d%s,?]? "
 
-#: git-add--interactive.perl:1389
+#: git-add--interactive.perl:1434
 #, perl-format
 msgid "Stash deletion [y,n,q,a,d%s,?]? "
 msgstr "Löschung stashen [y,n,q,a,d%s,?]? "
 
-#: git-add--interactive.perl:1390
+#: git-add--interactive.perl:1435
 #, perl-format
 msgid "Stash this hunk [y,n,q,a,d%s,?]? "
 msgstr "Diesen Patch-Block stashen [y,n,q,a,d%s,?]? "
 
-#: git-add--interactive.perl:1393
+#: git-add--interactive.perl:1438
 #, perl-format
 msgid "Unstage mode change [y,n,q,a,d%s,?]? "
 msgstr "Modusänderung aus der Staging-Area entfernen [y,n,q,a,d%s,?]? "
 
-#: git-add--interactive.perl:1394
+#: git-add--interactive.perl:1439
 #, perl-format
 msgid "Unstage deletion [y,n,q,a,d%s,?]? "
 msgstr "Löschung aus der Staging-Area entfernen [y,n,q,a,d%s,?]? "
 
-#: git-add--interactive.perl:1395
+#: git-add--interactive.perl:1440
 #, perl-format
 msgid "Unstage this hunk [y,n,q,a,d%s,?]? "
 msgstr "Diesen Patch-Block aus der Staging-Area entfernen [y,n,q,a,d%s,?]? "
 
-#: git-add--interactive.perl:1398
+#: git-add--interactive.perl:1443
 #, perl-format
 msgid "Apply mode change to index [y,n,q,a,d%s,?]? "
 msgstr "Modusänderung auf Index anwenden [y,n,q,a,d%s,?]? "
 
-#: git-add--interactive.perl:1399
+#: git-add--interactive.perl:1444
 #, perl-format
 msgid "Apply deletion to index [y,n,q,a,d%s,?]? "
 msgstr "Löschung auf Index anwenden [y,n,q,a,d%s,?]? "
 
-#: git-add--interactive.perl:1400
+#: git-add--interactive.perl:1445
 #, perl-format
 msgid "Apply this hunk to index [y,n,q,a,d%s,?]? "
 msgstr "Diesen Patch-Block auf Index anwenden [y,n,q,a,d%s,?]? "
 
-#: git-add--interactive.perl:1403
+#: git-add--interactive.perl:1448 git-add--interactive.perl:1463
 #, perl-format
 msgid "Discard mode change from worktree [y,n,q,a,d%s,?]? "
 msgstr "Modusänderung im Arbeitsverzeichnis verwerfen [y,n,q,a,d%s,?]? "
 
-#: git-add--interactive.perl:1404
+#: git-add--interactive.perl:1449 git-add--interactive.perl:1464
 #, perl-format
 msgid "Discard deletion from worktree [y,n,q,a,d%s,?]? "
 msgstr "Löschung im Arbeitsverzeichnis verwerfen [y,n,q,a,d%s,?]? "
 
-#: git-add--interactive.perl:1405
+#: git-add--interactive.perl:1450 git-add--interactive.perl:1465
 #, perl-format
 msgid "Discard this hunk from worktree [y,n,q,a,d%s,?]? "
 msgstr "Diesen Patch-Block im Arbeitsverzeichnis verwerfen [y,n,q,a,d%s,?]? "
 
-#: git-add--interactive.perl:1408
+#: git-add--interactive.perl:1453
 #, perl-format
 msgid "Discard mode change from index and worktree [y,n,q,a,d%s,?]? "
-msgstr "Modusänderung vom Index und Arbeitsverzeichnis verwerfen [y,n,q,a,d%s,?]? "
+msgstr ""
+"Modusänderung vom Index und Arbeitsverzeichnis verwerfen [y,n,q,a,d%s,?]? "
 
-#: git-add--interactive.perl:1409
+#: git-add--interactive.perl:1454
 #, perl-format
 msgid "Discard deletion from index and worktree [y,n,q,a,d%s,?]? "
 msgstr "Löschung vom Index und Arbeitsverzeichnis verwerfen [y,n,q,a,d%s,?]? "
 
-#: git-add--interactive.perl:1410
+#: git-add--interactive.perl:1455
 #, perl-format
 msgid "Discard this hunk from index and worktree [y,n,q,a,d%s,?]? "
-msgstr "Diesen Patch-Block vom Index und Arbeitsverzeichnis verwerfen [y,n,q,a,d%s,?]? "
+msgstr ""
+"Diesen Patch-Block vom Index und Arbeitsverzeichnis verwerfen [y,n,q,a,d"
+"%s,?]? "
 
-#: git-add--interactive.perl:1413
+#: git-add--interactive.perl:1458
 #, perl-format
 msgid "Apply mode change to index and worktree [y,n,q,a,d%s,?]? "
-msgstr "Modusänderung auf Index und Arbeitsverzeichnis anwenden [y,n,q,a,d%s,?]? "
+msgstr ""
+"Modusänderung auf Index und Arbeitsverzeichnis anwenden [y,n,q,a,d%s,?]? "
 
-#: git-add--interactive.perl:1414
+#: git-add--interactive.perl:1459
 #, perl-format
 msgid "Apply deletion to index and worktree [y,n,q,a,d%s,?]? "
 msgstr "Löschung auf Index und Arbeitsverzeichnis anwenden [y,n,q,a,d%s,?]? "
 
-#: git-add--interactive.perl:1415
+#: git-add--interactive.perl:1460
 #, perl-format
 msgid "Apply this hunk to index and worktree [y,n,q,a,d%s,?]? "
-msgstr "Diesen Patch-Block auf Index und Arbeitsverzeichnis anwenden [y,n,q,a,d%s,?]? "
+msgstr ""
+"Diesen Patch-Block auf Index und Arbeitsverzeichnis anwenden [y,n,q,a,d"
+"%s,?]? "
 
-#: git-add--interactive.perl:1515
-msgid "No other hunks to goto\n"
-msgstr "Keine anderen Patch-Blöcke verbleibend\n"
+#: git-add--interactive.perl:1468
+#, perl-format
+msgid "Apply mode change to worktree [y,n,q,a,d%s,?]? "
+msgstr "Modusänderung auf Arbeitsverzeichnis anwenden [y,n,q,a,d%s,?]? "
 
-#: git-add--interactive.perl:1522
-msgid "go to which hunk (<ret> to see more)? "
-msgstr "zu welchem Patch-Block springen (<Enter> für mehr Informationen)? "
+#: git-add--interactive.perl:1469
+#, perl-format
+msgid "Apply deletion to worktree [y,n,q,a,d%s,?]? "
+msgstr "Löschung auf Arbeitsverzeichnis anwenden [y,n,q,a,d%s,?]? "
 
-#: git-add--interactive.perl:1524
-msgid "go to which hunk? "
-msgstr "zu welchem Patch-Block springen? "
+#: git-add--interactive.perl:1470
+#, perl-format
+msgid "Apply this hunk to worktree [y,n,q,a,d%s,?]? "
+msgstr ""
+"Diesen Patch-Block auf das Arbeitsverzeichnis anwenden [y,n,q,a,d%s,?]? "
 
-#: git-add--interactive.perl:1533
+#: git-add--interactive.perl:1570
+msgid "No other hunks to goto\n"
+msgstr "Keine anderen Patch-Blöcke verbleibend\n"
+
+#: git-add--interactive.perl:1588
 #, perl-format
 msgid "Invalid number: '%s'\n"
 msgstr "Ungültige Nummer: '%s'\n"
 
-#: git-add--interactive.perl:1538
+#: git-add--interactive.perl:1593
 #, perl-format
 msgid "Sorry, only %d hunk available.\n"
 msgid_plural "Sorry, only %d hunks available.\n"
 msgstr[0] "Entschuldigung, nur %d Patch-Block verfügbar.\n"
 msgstr[1] "Entschuldigung, nur %d Patch-Blöcke verfügbar.\n"
 
-#: git-add--interactive.perl:1564
+#: git-add--interactive.perl:1619
 msgid "No other hunks to search\n"
 msgstr "Keine anderen Patch-Blöcke zum Durchsuchen\n"
 
-#: git-add--interactive.perl:1568
-msgid "search for regex? "
-msgstr "Suche nach regulärem Ausdruck? "
-
-#: git-add--interactive.perl:1581
+#: git-add--interactive.perl:1636
 #, perl-format
 msgid "Malformed search regexp %s: %s\n"
 msgstr "Fehlerhafter regulärer Ausdruck für Suche %s: %s\n"
 
-#: git-add--interactive.perl:1591
+#: git-add--interactive.perl:1646
 msgid "No hunk matches the given pattern\n"
 msgstr "Kein Patch-Block entspricht dem angegebenen Muster\n"
 
-#: git-add--interactive.perl:1603 git-add--interactive.perl:1625
+#: git-add--interactive.perl:1658 git-add--interactive.perl:1680
 msgid "No previous hunk\n"
 msgstr "Kein vorheriger Patch-Block\n"
 
-#: git-add--interactive.perl:1612 git-add--interactive.perl:1631
+#: git-add--interactive.perl:1667 git-add--interactive.perl:1686
 msgid "No next hunk\n"
 msgstr "Kein folgender Patch-Block\n"
 
-#: git-add--interactive.perl:1637
+#: git-add--interactive.perl:1692
 msgid "Sorry, cannot split this hunk\n"
 msgstr "Entschuldigung, kann diesen Patch-Block nicht aufteilen.\n"
 
-#: git-add--interactive.perl:1643
+#: git-add--interactive.perl:1698
 #, perl-format
 msgid "Split into %d hunk.\n"
 msgid_plural "Split into %d hunks.\n"
 msgstr[0] "In %d Patch-Block aufgeteilt.\n"
 msgstr[1] "In %d Patch-Blöcke aufgeteilt.\n"
 
-#: git-add--interactive.perl:1653
+#: git-add--interactive.perl:1708
 msgid "Sorry, cannot edit this hunk\n"
 msgstr "Entschuldigung, kann diesen Patch-Block nicht bearbeiten.\n"
 
-#: git-add--interactive.perl:1699
-msgid "Review diff"
-msgstr "Diff überprüfen"
-
 #. TRANSLATORS: please do not translate the command names
 #. 'status', 'update', 'revert', etc.
-#: git-add--interactive.perl:1718
+#: git-add--interactive.perl:1773
 msgid ""
 "status        - show paths with changes\n"
 "update        - add working tree state to the staged set of changes\n"
@@ -17112,96 +24414,98 @@ msgstr ""
 "diff          - Unterschiede zwischen HEAD und Index anzeigen\n"
 "add untracked - Inhalte von unversionierten Dateien zum Commit vormerken\n"
 
-#: git-add--interactive.perl:1735 git-add--interactive.perl:1740
-#: git-add--interactive.perl:1743 git-add--interactive.perl:1750
-#: git-add--interactive.perl:1754 git-add--interactive.perl:1760
+#: git-add--interactive.perl:1790 git-add--interactive.perl:1795
+#: git-add--interactive.perl:1798 git-add--interactive.perl:1805
+#: git-add--interactive.perl:1808 git-add--interactive.perl:1815
+#: git-add--interactive.perl:1819 git-add--interactive.perl:1825
 msgid "missing --"
 msgstr "-- fehlt"
 
-#: git-add--interactive.perl:1756
+#: git-add--interactive.perl:1821
 #, perl-format
 msgid "unknown --patch mode: %s"
 msgstr "Unbekannter --patch Modus: %s"
 
-#: git-add--interactive.perl:1762 git-add--interactive.perl:1768
+#: git-add--interactive.perl:1827 git-add--interactive.perl:1833
 #, perl-format
 msgid "invalid argument %s, expecting --"
 msgstr "ungültiges Argument %s, erwarte --"
 
-#: git-send-email.perl:130
+#: git-send-email.perl:138
 msgid "local zone differs from GMT by a non-minute interval\n"
 msgstr ""
 "lokale Zeitzone unterscheidet sich von GMT nicht um ein Minutenintervall\n"
 
-#: git-send-email.perl:137 git-send-email.perl:143
+#: git-send-email.perl:145 git-send-email.perl:151
 msgid "local time offset greater than or equal to 24 hours\n"
 msgstr "lokaler Zeit-Offset größer oder gleich 24 Stunden\n"
 
-#: git-send-email.perl:211 git-send-email.perl:217
+#: git-send-email.perl:223 git-send-email.perl:229
 msgid "the editor exited uncleanly, aborting everything"
 msgstr "Der Editor wurde unsauber beendet, breche alles ab."
 
-#: git-send-email.perl:294
+#: git-send-email.perl:310
 #, perl-format
 msgid ""
 "'%s' contains an intermediate version of the email you were composing.\n"
 msgstr ""
 "'%s' enthält eine Zwischenversion der E-Mail, die Sie gerade verfassen.\n"
 
-#: git-send-email.perl:299
+#: git-send-email.perl:315
 #, perl-format
 msgid "'%s.final' contains the composed email.\n"
 msgstr "'%s.final' enthält die verfasste E-Mail.\n"
 
-#: git-send-email.perl:317
+#: git-send-email.perl:408
 msgid "--dump-aliases incompatible with other options\n"
 msgstr "--dump-aliases ist mit anderen Optionen inkompatibel\n"
 
-#: git-send-email.perl:383 git-send-email.perl:638
+#: git-send-email.perl:481 git-send-email.perl:683
 msgid "Cannot run git format-patch from outside a repository\n"
 msgstr ""
 "Kann 'git format-patch' nicht außerhalb eines Repositories ausführen.\n"
 
-#: git-send-email.perl:386
+#: git-send-email.perl:484
 msgid ""
 "`batch-size` and `relogin` must be specified together (via command-line or "
 "configuration option)\n"
 msgstr ""
-"'batch-size' und 'relogin' müssen gemeinsam angegeben werden (über Kommandozeile\n"
+"'batch-size' und 'relogin' müssen gemeinsam angegeben werden (über "
+"Kommandozeile\n"
 "oder Konfigurationsoption)\n"
 
-#: git-send-email.perl:456
+#: git-send-email.perl:497
 #, perl-format
 msgid "Unknown --suppress-cc field: '%s'\n"
 msgstr "Unbekanntes --suppress-cc Feld: '%s'\n"
 
-#: git-send-email.perl:485
+#: git-send-email.perl:528
 #, perl-format
 msgid "Unknown --confirm setting: '%s'\n"
 msgstr "Unbekannte --confirm Einstellung: '%s'\n"
 
-#: git-send-email.perl:513
+#: git-send-email.perl:556
 #, perl-format
 msgid "warning: sendmail alias with quotes is not supported: %s\n"
 msgstr ""
-"Warnung: sendemail Alias mit Anführungsstrichen wird nicht unterstützt: %s\n"
+"Warnung: sendemail-Alias mit Anführungszeichen wird nicht unterstützt: %s\n"
 
-#: git-send-email.perl:515
+#: git-send-email.perl:558
 #, perl-format
 msgid "warning: `:include:` not supported: %s\n"
 msgstr "Warnung: `:include:` wird nicht unterstützt: %s\n"
 
-#: git-send-email.perl:517
+#: git-send-email.perl:560
 #, perl-format
 msgid "warning: `/file` or `|pipe` redirection not supported: %s\n"
 msgstr "Warnung: `/file` oder `|pipe` Umleitung wird nicht unterstützt: %s\n"
 
-#: git-send-email.perl:522
+#: git-send-email.perl:565
 #, perl-format
 msgid "warning: sendmail line is not recognized: %s\n"
 msgstr "Warnung: sendmail Zeile wird nicht erkannt: %s\n"
 
-#: git-send-email.perl:604
+#: git-send-email.perl:649
 #, perl-format
 msgid ""
 "File '%s' exists but it could also be the range of commits\n"
@@ -17218,12 +24522,12 @@ msgstr ""
 "    * die Option --format-patch angeben, wenn Sie einen Commit-Bereich "
 "meinen\n"
 
-#: git-send-email.perl:625
+#: git-send-email.perl:670
 #, perl-format
 msgid "Failed to opendir %s: %s"
 msgstr "Fehler beim Öffnen von %s: %s"
 
-#: git-send-email.perl:649
+#: git-send-email.perl:694
 #, perl-format
 msgid ""
 "fatal: %s: %s\n"
@@ -17232,7 +24536,7 @@ msgstr ""
 "fatal: %s: %s\n"
 "Warnung: Es wurden keine Patches versendet.\n"
 
-#: git-send-email.perl:660
+#: git-send-email.perl:705
 msgid ""
 "\n"
 "No patch files specified!\n"
@@ -17242,17 +24546,17 @@ msgstr ""
 "keine Patch-Dateien angegeben!\n"
 "\n"
 
-#: git-send-email.perl:673
+#: git-send-email.perl:718
 #, perl-format
 msgid "No subject line in %s?"
 msgstr "Keine Betreffzeile in %s?"
 
-#: git-send-email.perl:683
+#: git-send-email.perl:728
 #, perl-format
 msgid "Failed to open for writing %s: %s"
 msgstr "Fehler beim Öffnen von '%s' zum Schreiben: %s"
 
-#: git-send-email.perl:694
+#: git-send-email.perl:739
 msgid ""
 "Lines beginning in \"GIT:\" will be removed.\n"
 "Consider including an overall diffstat or table of contents\n"
@@ -17267,27 +24571,27 @@ msgstr ""
 "Leeren Sie den Inhalt des Bodys, wenn Sie keine Zusammenfassung senden "
 "möchten.\n"
 
-#: git-send-email.perl:718
+#: git-send-email.perl:763
 #, perl-format
 msgid "Failed to open %s: %s"
 msgstr "Fehler beim Öffnen von %s: %s"
 
-#: git-send-email.perl:735
+#: git-send-email.perl:780
 #, perl-format
 msgid "Failed to open %s.final: %s"
 msgstr "Fehler beim Öffnen von %s.final: %s"
 
-#: git-send-email.perl:778
+#: git-send-email.perl:823
 msgid "Summary email is empty, skipping it\n"
 msgstr "E-Mail mit Zusammenfassung ist leer, wird ausgelassen\n"
 
 #. TRANSLATORS: please keep [y/N] as is.
-#: git-send-email.perl:813
+#: git-send-email.perl:858
 #, perl-format
 msgid "Are you sure you want to use <%s> [y/N]? "
 msgstr "Sind Sie sich sicher, <%s> zu benutzen [y/N]? "
 
-#: git-send-email.perl:868
+#: git-send-email.perl:913
 msgid ""
 "The following files are 8bit, but do not declare a Content-Transfer-"
 "Encoding.\n"
@@ -17295,11 +24599,11 @@ msgstr ""
 "Die folgenden Dateien sind 8-Bit, aber deklarieren kein\n"
 "Content-Transfer-Encoding.\n"
 
-#: git-send-email.perl:873
+#: git-send-email.perl:918
 msgid "Which 8bit encoding should I declare [UTF-8]? "
 msgstr "Welches 8-Bit-Encoding soll deklariert werden [UTF-8]? "
 
-#: git-send-email.perl:881
+#: git-send-email.perl:926
 #, perl-format
 msgid ""
 "Refusing to send because the patch\n"
@@ -17313,22 +24617,22 @@ msgstr ""
 "an,\n"
 "wenn Sie den Patch wirklich versenden wollen.\n"
 
-#: git-send-email.perl:900
+#: git-send-email.perl:945
 msgid "To whom should the emails be sent (if anyone)?"
 msgstr "An wen sollen die E-Mails versendet werden (wenn überhaupt jemand)?"
 
-#: git-send-email.perl:918
+#: git-send-email.perl:963
 #, perl-format
 msgid "fatal: alias '%s' expands to itself\n"
 msgstr "fatal: Alias '%s' erweitert sich zu sich selbst\n"
 
-#: git-send-email.perl:930
+#: git-send-email.perl:975
 msgid "Message-ID to be used as In-Reply-To for the first email (if any)? "
 msgstr ""
 "Message-ID zur Verwendung als In-Reply-To für die erste E-Mail (wenn eine "
 "existiert)? "
 
-#: git-send-email.perl:988 git-send-email.perl:996
+#: git-send-email.perl:1033 git-send-email.perl:1041
 #, perl-format
 msgid "error: unable to extract a valid address from: %s\n"
 msgstr "Fehler: konnte keine gültige Adresse aus %s extrahieren\n"
@@ -17336,18 +24640,18 @@ msgstr "Fehler: konnte keine gültige Ad
 #. TRANSLATORS: Make sure to include [q] [d] [e] in your
 #. translation. The program will only accept English input
 #. at this point.
-#: git-send-email.perl:1000
+#: git-send-email.perl:1045
 msgid "What to do with this address? ([q]uit|[d]rop|[e]dit): "
 msgstr ""
 "Was soll mit dieser Adresse geschehen? (Beenden [q]|Löschen [d]|Bearbeiten "
 "[e]): "
 
-#: git-send-email.perl:1317
+#: git-send-email.perl:1362
 #, perl-format
 msgid "CA path \"%s\" does not exist"
 msgstr "CA Pfad \"%s\" existiert nicht"
 
-#: git-send-email.perl:1395
+#: git-send-email.perl:1445
 msgid ""
 "    The Cc list above has been expanded by additional\n"
 "    addresses found in the patch commit message. By default\n"
@@ -17373,440 +24677,284 @@ msgstr ""
 "    führen Sie 'git config --global sendemail.confirm auto' aus.\n"
 "\n"
 
-#. TRANSLATORS: Make sure to include [y] [n] [q] [a] in your
+#. TRANSLATORS: Make sure to include [y] [n] [e] [q] [a] in your
 #. translation. The program will only accept English input
 #. at this point.
-#: git-send-email.perl:1410
-msgid "Send this email? ([y]es|[n]o|[q]uit|[a]ll): "
-msgstr "Diese E-Mail versenden? (Ja [y]|Nein [n]|Beenden [q]|Alle [a]): "
+#: git-send-email.perl:1460
+msgid "Send this email? ([y]es|[n]o|[e]dit|[q]uit|[a]ll): "
+msgstr ""
+"Diese E-Mail versenden? (Ja [y]|Nein [n]|Bearbeiten [e]|Beenden [q]|Alle "
+"[a]): "
 
-#: git-send-email.perl:1413
+#: git-send-email.perl:1463
 msgid "Send this email reply required"
 msgstr "Zum Versenden dieser E-Mail ist eine Antwort erforderlich."
 
-#: git-send-email.perl:1439
+#: git-send-email.perl:1491
 msgid "The required SMTP server is not properly defined."
 msgstr "Der erforderliche SMTP-Server ist nicht korrekt definiert."
 
-#: git-send-email.perl:1486
+#: git-send-email.perl:1538
 #, perl-format
 msgid "Server does not support STARTTLS! %s"
 msgstr "Server unterstützt kein STARTTLS! %s"
 
-#: git-send-email.perl:1491 git-send-email.perl:1495
+#: git-send-email.perl:1543 git-send-email.perl:1547
 #, perl-format
 msgid "STARTTLS failed! %s"
 msgstr "STARTTLS fehlgeschlagen! %s"
 
-#: git-send-email.perl:1505
+#: git-send-email.perl:1556
 msgid "Unable to initialize SMTP properly. Check config and use --smtp-debug."
 msgstr ""
 "Konnte SMTP nicht korrekt initialisieren. Bitte prüfen Sie Ihre "
 "Konfiguration\n"
 "und benutzen Sie --smtp-debug."
 
-#: git-send-email.perl:1523
+#: git-send-email.perl:1574
 #, perl-format
 msgid "Failed to send %s\n"
 msgstr "Fehler beim Senden %s\n"
 
-#: git-send-email.perl:1526
+#: git-send-email.perl:1577
 #, perl-format
 msgid "Dry-Sent %s\n"
 msgstr "Probeversand %s\n"
 
-#: git-send-email.perl:1526
+#: git-send-email.perl:1577
 #, perl-format
 msgid "Sent %s\n"
 msgstr "%s gesendet\n"
 
-#: git-send-email.perl:1528
+#: git-send-email.perl:1579
 msgid "Dry-OK. Log says:\n"
 msgstr "Probeversand OK. Log enthält:\n"
 
-#: git-send-email.perl:1528
+#: git-send-email.perl:1579
 msgid "OK. Log says:\n"
 msgstr "OK. Log enthält:\n"
 
-#: git-send-email.perl:1540
+#: git-send-email.perl:1591
 msgid "Result: "
 msgstr "Ergebnis: "
 
-#: git-send-email.perl:1543
+#: git-send-email.perl:1594
 msgid "Result: OK\n"
 msgstr "Ergebnis: OK\n"
 
-#: git-send-email.perl:1556
+#: git-send-email.perl:1612
 #, perl-format
 msgid "can't open file %s"
 msgstr "Kann Datei %s nicht öffnen"
 
-#: git-send-email.perl:1603 git-send-email.perl:1623
+#: git-send-email.perl:1659 git-send-email.perl:1679
 #, perl-format
 msgid "(mbox) Adding cc: %s from line '%s'\n"
 msgstr "(mbox) Füge cc: hinzu: %s von Zeile '%s'\n"
 
-#: git-send-email.perl:1609
+#: git-send-email.perl:1665
 #, perl-format
 msgid "(mbox) Adding to: %s from line '%s'\n"
 msgstr "(mbox) Füge to: hinzu: %s von Zeile '%s'\n"
 
-#: git-send-email.perl:1657
+#: git-send-email.perl:1718
 #, perl-format
 msgid "(non-mbox) Adding cc: %s from line '%s'\n"
 msgstr "(non-mbox) Füge cc: hinzu: %s von Zeile '%s'\n"
 
-#: git-send-email.perl:1682
+#: git-send-email.perl:1753
 #, perl-format
 msgid "(body) Adding cc: %s from line '%s'\n"
 msgstr "(body) Füge cc: hinzu: %s von Zeile '%s'\n"
 
-#: git-send-email.perl:1788
+#: git-send-email.perl:1864
 #, perl-format
 msgid "(%s) Could not execute '%s'"
 msgstr "(%s) Konnte '%s' nicht ausführen"
 
-#: git-send-email.perl:1795
+#: git-send-email.perl:1871
 #, perl-format
 msgid "(%s) Adding %s: %s from: '%s'\n"
 msgstr "(%s) Füge %s: %s hinzu von: '%s'\n"
 
-#: git-send-email.perl:1799
+#: git-send-email.perl:1875
 #, perl-format
 msgid "(%s) failed to close pipe to '%s'"
 msgstr "(%s) Fehler beim Schließen der Pipe nach '%s'"
 
-#: git-send-email.perl:1826
+#: git-send-email.perl:1905
 msgid "cannot send message as 7bit"
 msgstr "Kann Nachricht nicht als 7bit versenden."
 
-#: git-send-email.perl:1834
+#: git-send-email.perl:1913
 msgid "invalid transfer encoding"
 msgstr "Ungültiges Transfer-Encoding"
 
-#: git-send-email.perl:1872 git-send-email.perl:1923 git-send-email.perl:1933
+#: git-send-email.perl:1954 git-send-email.perl:2006 git-send-email.perl:2016
 #, perl-format
 msgid "unable to open %s: %s\n"
 msgstr "konnte %s nicht öffnen: %s\n"
 
-#: git-send-email.perl:1875
+#: git-send-email.perl:1957
 #, perl-format
 msgid "%s: patch contains a line longer than 998 characters"
 msgstr "%s: Patch enthält eine Zeile, die länger als 998 Zeichen ist"
 
-#: git-send-email.perl:1891
+#: git-send-email.perl:1974
 #, perl-format
 msgid "Skipping %s with backup suffix '%s'.\n"
 msgstr "Lasse %s mit Backup-Suffix '%s' aus.\n"
 
 #. TRANSLATORS: please keep "[y|N]" as is.
-#: git-send-email.perl:1895
+#: git-send-email.perl:1978
 #, perl-format
 msgid "Do you really want to send %s? [y|N]: "
 msgstr "Wollen Sie %s wirklich versenden? [y|N]: "
 
-#~ msgid "git fetch-pack: expected ACK/NAK, got EOF"
-#~ msgstr "git fetch-pack: ACK/NAK erwartet, EOF bekommen"
-
-#~ msgid "invalid filter-spec expression '%s'"
-#~ msgstr "Ungültiger filter-spec Ausdruck '%s'."
-
-#~ msgid "The copy of the patch that failed is found in: %s"
-#~ msgstr "Die Kopie des fehlgeschlagenen Patches befindet sich in: %s"
-
-#~ msgid "pathspec and --all are incompatible"
-#~ msgstr "Pfadspezifikationen und --all sind inkompatibel."
-
-#~ msgid "Submodule '$name' ($url) unregistered for path '$displaypath'"
-#~ msgstr ""
-#~ "Submodul '$name' ($url) für Pfad '$displaypath' wurde aus der "
-#~ "Konfiguration entfernt."
-
-#~ msgid "To/Cc/Bcc fields are not interpreted yet, they have been ignored\n"
-#~ msgstr ""
-#~ "To/Cc/Bcc Felder wurden noch nicht interpretiert, sie wurden ignoriert\n"
+#~ msgid "unable to get tree for %s"
+#~ msgstr "Konnte Verzeichnis für %s nicht bestimmen."
 
-#~ msgid ""
-#~ "empty strings as pathspecs will be made invalid in upcoming releases. "
-#~ "please use . instead if you meant to match all paths"
+#~ msgid "Use an experimental heuristic to improve diffs"
 #~ msgstr ""
-#~ "Leere Strings als Pfadspezifikationen werden in kommenden Releases "
-#~ "ungültig.\n"
-#~ "Bitte benutzen Sie stattdessen . wenn Sie alle Pfade meinen."
-
-#~ msgid "unable to open '%s' for writing"
-#~ msgstr "Konnte '%s' nicht zum Schreiben öffnen."
-
-#~ msgid "could not truncate '%s'"
-#~ msgstr "Konnte '%s' nicht abschneiden."
-
-#~ msgid "could not finish '%s'"
-#~ msgstr "Konnte '%s' nicht abschließen."
-
-#~ msgid "could not write to %s"
-#~ msgstr "Konnte nicht nach '%s' schreiben."
-
-#~ msgid "could not close %s"
-#~ msgstr "Konnte '%s' nicht schließen."
-
-#~ msgid "Copied a misnamed branch '%s' away"
-#~ msgstr "falsch benannten Branch '%s' wegkopiert"
+#~ "eine experimentelle Heuristik zur Verbesserung der Darstellung\n"
+#~ "von Unterschieden verwenden"
 
-#~ msgid "it does not make sense to create 'HEAD' manually"
-#~ msgstr "'HEAD' darf nicht manuell erstellt werden"
+#~ msgid "git commit-graph [--object-dir <objdir>]"
+#~ msgstr "git commit-graph [--object-dir <Objektverzeichnis>]"
 
-#~ msgid "Don't know how to clone %s"
-#~ msgstr "Weiß nicht wie %s zu klonen ist."
+#~ msgid "git commit-graph read [--object-dir <objdir>]"
+#~ msgstr "git commit-graph read [--object-dir <Objektverzeichnis>]"
 
-#~ msgid "show ignored files"
-#~ msgstr "ignorierte Dateien anzeigen"
-
-#~ msgid "%s is not a valid '%s' object"
-#~ msgstr "%s ist kein gültiges '%s' Objekt"
-
-#~ msgid "Don't know how to fetch from %s"
-#~ msgstr "Weiß nicht wie von %s angefordert wird."
-
-#~ msgid "'$term' is not a valid term"
-#~ msgstr "'$term' ist kein gültiger Begriff"
-
-#~ msgid ""
-#~ "error: unknown option for 'stash save': $option\n"
-#~ "       To provide a message, use git stash save -- '$option'"
+#~ msgid "unknown core.untrackedCache value '%s'; using 'keep' default value"
 #~ msgstr ""
-#~ "Fehler: unbekannte Option für 'stash save': $option\n"
-#~ "        Um eine Beschreibung anzugeben, benutzen Sie \"git stash save -- "
-#~ "'$option'\""
-
-#~ msgid "Failed to recurse into submodule path '$sm_path'"
-#~ msgstr "Fehler bei Rekursion in Submodul-Pfad '$sm_path'"
+#~ "Unbekannter Wert '%s' in core.untrackedCache; benutze Standardwert 'keep'"
 
-#~ msgid "%%(trailers) does not take arguments"
-#~ msgstr "%%(trailers) akzeptiert keine Argumente"
+#~ msgid "cannot change partial clone promisor remote"
+#~ msgstr "Kann Remote-Repository für partielles Klonen nicht ändern."
 
-#~ msgid ""
-#~ "Warning: the SHA-1 is missing or isn't a commit in the following line:\n"
-#~ " - $line"
-#~ msgstr ""
-#~ "Warnung: Der SHA-1 in der folgenden Zeile fehlt oder ist kein Commit:\n"
-#~ " - $line"
+#~ msgid "error building trees"
+#~ msgstr "Fehler beim Erstellen der \"Tree\"-Objekte"
 
-#~ msgid ""
-#~ "Warning: the command isn't recognized in the following line:\n"
-#~ " - $line"
-#~ msgstr ""
-#~ "Warnung: Das Kommando in der folgenden Zeile wurde nicht erkannt:\n"
-#~ " - $line"
+#~ msgid "invalid date format '%s' in '%s'"
+#~ msgstr "Ungültiges Datumsformat '%s' in '%s'"
 
-#~ msgid "Or you can abort the rebase with 'git rebase --abort'."
-#~ msgstr "Oder Sie können den Rebase mit 'git rebase --abort' abbrechen."
+#~ msgid "writing root commit"
+#~ msgstr "Root-Commit schreiben"
 
-#~ msgid "submodule update strategy not supported for submodule '%s'"
+#~ msgid "staged changes in the following files may be lost: %s"
 #~ msgstr ""
-#~ "Strategie zur Aktualisierung von Submodulen für Submodul '%s' nicht "
-#~ "unterstützt."
-
-#~ msgid "change upstream info"
-#~ msgstr "Informationen zum Upstream-Branch ändern"
+#~ "Zum Commit vorgemerkte Änderungen in den folgenden Dateien gehen "
+#~ "eventuell verloren: %s"
 
 #~ msgid ""
-#~ "\n"
-#~ "If you wanted to make '%s' track '%s', do this:\n"
-#~ "\n"
+#~ "--filter can only be used with the remote configured in extensions."
+#~ "partialClone"
 #~ msgstr ""
-#~ "\n"
-#~ "Wenn Sie wollten, dass '%s' den Branch '%s' als Upstream-Branch hat, "
-#~ "führen Sie aus:\n"
-
-#~ msgid "basename"
-#~ msgstr "Basisname"
-
-#~ msgid "prepend parent project's basename to output"
-#~ msgstr "Basisname des Elternprojektes an Ausgaben voranstellen"
+#~ "--filter kann nur mit den Remote-Repositories verwendet werden,\n"
+#~ "die in core.partialClone konfiguriert sind."
 
-#~ msgid "Could not open file '%s'"
-#~ msgstr "Konnte Datei '%s' nicht öffnen"
+#~ msgid "verify commit-msg hook"
+#~ msgstr "commit-msg Hook überprüfen"
 
-#~ msgid "in %0.1f seconds automatically..."
-#~ msgstr "Automatische Ausführung in %0.1f Sekunden ..."
-
-#~ msgid "dup2(%d,%d) failed"
-#~ msgstr "dup2(%d,%d) fehlgeschlagen"
-
-#~ msgid "Initial commit on "
-#~ msgstr "Initialer Commit auf "
-
-#~ msgid "Patch is empty. Was it split wrong?"
-#~ msgstr "Patch ist leer. War dessen Aufteilung falsch?"
-
-#~ msgid ""
-#~ "You still have unmerged paths in your index.\n"
-#~ "Did you forget to use 'git add'?"
+#~ msgid "cannot combine '--rebase-merges' with '--strategy-option'"
 #~ msgstr ""
-#~ "Sie haben immer noch nicht zusammengeführte Pfade im Index.\n"
-#~ "Haben Sie vergessen 'git add' zu benutzen?"
+#~ "'--rebase-merges' kann nicht mit '--strategy-option' kombiniert werden."
+
+#~ msgid "invalid sparse value '%s'"
+#~ msgstr "Ungültiger \"sparse\"-Wert '%s'."
 
 #~ msgid ""
-#~ "Cannot update paths and switch to branch '%s' at the same time.\n"
-#~ "Did you intend to checkout '%s' which can not be resolved as commit?"
+#~ "Fetch normally indicates which branches had a forced update, but that "
+#~ "check has been disabled."
 #~ msgstr ""
-#~ "Kann nicht gleichzeitig Pfade aktualisieren und zu Branch '%s' wechseln.\n"
-#~ "Haben Sie beabsichtigt '%s' auszuchecken, welcher nicht als Commit "
-#~ "aufgelöst werden kann?"
-
-#~ msgid "Explicit paths specified without -i or -o; assuming --only paths..."
-#~ msgstr "Explizite Pfade ohne -i oder -o angegeben; nehme --only an"
-
-#~ msgid "default mode for recursion"
-#~ msgstr "Standard-Modus für Rekursion"
-
-#~ msgid "submodule--helper subcommand must be called with a subcommand"
-#~ msgstr "submodule--helper muss mit einem Unterbefehl aufgerufen werden"
-
-#~ msgid "tag: tagging "
-#~ msgstr "tag: tagge "
-
-#~ msgid "object of unknown type"
-#~ msgstr "Art des Objektes unbekannt"
-
-#~ msgid "commit object"
-#~ msgstr "Commit-Objekt"
-
-#~ msgid "tree object"
-#~ msgstr "Tree-Objekt"
-
-#~ msgid "blob object"
-#~ msgstr "Blob-Objekt"
-
-#~ msgid "other tag object"
-#~ msgstr "anderes Tag-Objekt"
-
-#, fuzzy
-#~ msgid "Submodule '%s' cannot checkout new HEAD"
-#~ msgstr "Submodul '%s' kann Alternative nicht hinzufügen: %s"
-
-#~ msgid "insanely long object directory %.*s"
-#~ msgstr "zu langes Objekt-Verzeichnis %.*s"
-
-#~ msgid "tag name too long: %.*s..."
-#~ msgstr "Tagname zu lang: %.*s..."
-
-#~ msgid "tag header too big."
-#~ msgstr "Tag-Kopf zu groß."
+#~ "'fetch' zeigt normalerweise, welche Branches eine erzwungene "
+#~ "Aktualisierung hatten, aber diese Überprüfung wurde deaktiviert."
 
 #~ msgid ""
-#~ "If the patch applies cleanly, the edited hunk will immediately be\n"
-#~ "marked for discarding"
+#~ "or run 'git config fetch.showForcedUpdates false' to avoid this check.\n"
 #~ msgstr ""
-#~ "Wenn der Patch sauber angewendet werden kann, wird der bearbeitete Patch-"
-#~ "Block\n"
-#~ "direkt als zum Verwerfen markiert."
+#~ "oder führen Sie 'git config fetch.showForcedUpdates false' aus, um diese "
+#~ "Überprüfung zu umgehen.\n"
 
 #~ msgid ""
-#~ "There is nothing to exclude from by :(exclude) patterns.\n"
-#~ "Perhaps you forgot to add either ':/' or '.' ?"
+#~ "log.mailmap is not set; its implicit value will change in an\n"
+#~ "upcoming release. To squelch this message and preserve current\n"
+#~ "behaviour, set the log.mailmap configuration value to false.\n"
+#~ "\n"
+#~ "To squelch this message and adopt the new behaviour now, set the\n"
+#~ "log.mailmap configuration value to true.\n"
+#~ "\n"
+#~ "See 'git help config' and search for 'log.mailmap' for further "
+#~ "information."
 #~ msgstr ""
-#~ ":(exclude) Muster, aber keine anderen Pfadspezifikationen angegeben.\n"
-#~ "Vielleicht haben Sie vergessen entweder ':/' oder '.' hinzuzufügen?"
-
-#~ msgid "unrecognized format: %%(%s)"
-#~ msgstr "nicht erkanntes Format: %%(%s)"
-
-#~ msgid ":strip= requires a positive integer argument"
-#~ msgstr ":strip= erfordert eine positive Ganzzahl als Argument"
+#~ "'log.mailmap' ist nicht gesetzt; der implizite Wert wird sich in einem\n"
+#~ "kommenden Release ändern. Um diese Meldung zu unterdrücken und das "
+#~ "aktuelle\n"
+#~ "Verhalten beizubehalten, setzen Sie den Konfigurationswert von'log."
+#~ "mailmap' auf 'false'.\n"
+#~ "\n"
+#~ "Um diese Meldung zu unterdrücken und jetzt das neue Verhalten zu\n"
+#~ "übernehmen, setzen Sie den Konfigurationswert von 'log.mailmap' auf "
+#~ "'true'.\n"
+#~ "\n"
+#~ "Führen Sie 'git help config' aus und suchen Sie nach 'log.mailmap', um\n"
+#~ "weitere Informationen zu erhalten."
 
-#~ msgid "ref '%s' does not have %ld components to :strip"
-#~ msgstr "Referenz '%s' hat keine %ld Komponenten für :strip"
+#~ msgid "Server supports multi_ack_detailed"
+#~ msgstr "Server unterstützt multi_ack_detailed"
 
-#~ msgid "unknown %.*s format %s"
-#~ msgstr "Unbekanntes %.*s Format %s"
+#~ msgid "Server supports no-done"
+#~ msgstr "Server unterstützt no-done"
 
-#~ msgid "[%s: gone]"
-#~ msgstr "[%s: entfernt]"
+#~ msgid "Server supports multi_ack"
+#~ msgstr "Server unterstützt multi_ack"
 
-#~ msgid "[%s]"
-#~ msgstr "[%s]"
+#~ msgid "Server supports side-band-64k"
+#~ msgstr "Server unterstützt side-band-64k"
 
-#~ msgid "[%s: behind %d]"
-#~ msgstr "[%s: %d hinterher]"
+#~ msgid "Server supports side-band"
+#~ msgstr "Server unterstützt side-band"
 
-#~ msgid "[%s: ahead %d]"
-#~ msgstr "[%s: %d voraus]"
+#~ msgid "Server supports allow-tip-sha1-in-want"
+#~ msgstr "Server unterstützt allow-tip-sha1-in-want"
 
-#~ msgid "[%s: ahead %d, behind %d]"
-#~ msgstr "[%s: %d voraus, %d hinterher]"
+#~ msgid "Server supports allow-reachable-sha1-in-want"
+#~ msgstr "Server unterstützt allow-reachable-sha1-in-want"
 
-#~ msgid " **** invalid ref ****"
-#~ msgstr " **** ungültige Referenz ****"
+#~ msgid "Server supports ofs-delta"
+#~ msgstr "Server unterstützt ofs-delta"
 
-#~ msgid "git merge [<options>] <msg> HEAD <commit>"
-#~ msgstr "git merge [<Optionen>] <Beschreibung> HEAD <Commit>"
+#~ msgid "(HEAD detached at %s)"
+#~ msgstr "(HEAD losgelöst bei %s)"
 
-#~ msgid "cannot open file '%s'"
-#~ msgstr "Kann Datei '%s' nicht öffnen"
+#~ msgid "(HEAD detached from %s)"
+#~ msgstr "(HEAD losgelöst von %s)"
 
-#~ msgid "could not close file %s"
-#~ msgstr "Konnte Datei '%s' nicht schließen."
+#~ msgid "Checking out files"
+#~ msgstr "Checke Dateien aus"
 
-#~ msgid "Use an experimental blank-line-based heuristic to improve diffs"
+#~ msgid "cannot be interactive without stdin connected to a terminal."
 #~ msgstr ""
-#~ "eine experimentelle, auf Leerzeilen basierende Heuristik zur "
-#~ "Verbesserung\n"
-#~ "der Darstellung von Unterschieden verwenden"
-
-#~ msgid "Clever... amending the last one with dirty index."
-#~ msgstr "Klug ... den letzten Commit mit einem geänderten Index nachbessern."
+#~ "Kann nicht interaktiv sein, ohne dass die Standard-Eingabe mit einem "
+#~ "Terminal verbunden ist."
 
-#~ msgid ""
-#~ "the following submodule (or one of its nested submodules)\n"
-#~ "uses a .git directory:"
-#~ msgid_plural ""
-#~ "the following submodules (or one of their nested submodules)\n"
-#~ "use a .git directory:"
-#~ msgstr[0] ""
-#~ "das folgende Submodul (oder ein geschachteltes Submodul hiervon)\n"
-#~ "benutzt ein .git-Verzeichnis:"
-#~ msgstr[1] ""
-#~ "die folgenden Submodule (oder ein geschachteltes Submodul hiervon)\n"
-#~ "benutzen ein .git-Verzeichnis:"
+#~ msgid "failed to stat %s\n"
+#~ msgstr "Konnte %s nicht lesen\n"
 
 #~ msgid ""
+#~ "If you wish to skip this commit, use:\n"
 #~ "\n"
-#~ "(use 'rm -rf' if you really want to remove it including all of its "
-#~ "history)"
-#~ msgstr ""
+#~ "    git reset\n"
 #~ "\n"
-#~ "(benutzen Sie 'rm -rf' wenn Sie dieses Submodul wirklich mitsamt\n"
-#~ "seiner Historie löschen möchten)"
-
-#~ msgid "Your local changes would be overwritten by cherry-pick."
-#~ msgstr ""
-#~ "Ihre lokalen Änderungen würden durch den Cherry-Pick überschrieben werden."
-
-#~ msgid "Cannot revert during another revert."
-#~ msgstr "Kann Revert nicht während eines anderen Reverts ausführen."
-
-#~ msgid "Cannot cherry-pick during another cherry-pick."
+#~ "Then \"git cherry-pick --continue\" will resume cherry-picking\n"
+#~ "the remaining commits.\n"
 #~ msgstr ""
-#~ "Kann Cherry-Pick nicht während eines anderen Cherry-Picks ausführen."
-
-#~ msgid "Could not parse line %d."
-#~ msgstr "Konnte Zeile %d nicht parsen."
-
-#~ msgid "Could not open %s"
-#~ msgstr "Konnte %s nicht öffnen"
-
-#~ msgid "Could not read %s."
-#~ msgstr "Konnte %s nicht lesen."
-
-#~ msgid "Could not format %s."
-#~ msgstr "Konnte %s nicht formatieren."
-
-#~ msgid "%s: %s"
-#~ msgstr "%s: %s"
-
-#~ msgid "cannot open %s: %s"
-#~ msgstr "Kann %s nicht öffnen: %s"
+#~ "Wenn Sie diesen Commit auslassen möchten, benutzen Sie:\n"
+#~ "\n"
+#~ "    git reset\n"
+#~ "\n"
+#~ "Benutzen Sie anschließend \"git cherry-pick --continue\", um die\n"
+#~ "Cherry-Pick-Operation mit den verbleibenden Commits fortzusetzen.\n"
 
-#~ msgid "You need to set your committer info first"
-#~ msgstr "Sie müssen zuerst die Informationen zum Commit-Ersteller setzen."
+#~ msgid "unrecognized verb: %s"
+#~ msgstr "Nicht erkanntes Verb: %s"
diff -pruN 1.2.1+git2.18.0-1/git/po/el.po 1.2.3+git2.25.1-1/git/po/el.po
--- 1.2.1+git2.18.0-1/git/po/el.po	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/po/el.po	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,21468 @@
+# Greek translations for Git.
+# Copyright (C) 2019 Jimmy Angelakos <vyruss@hellug.gr>
+# This file is distributed under the same license as the Git package.
+#
+# Greek translations of common Git words used in this file:
+#
+#   English          |  Greek
+#   -----------------+---------------------------------
+#   3-way merge      |  τριπλή συγχώνευση
+#   #NN              |  υπ' αρ. NN
+#   amend            |  τροποποιώ
+#   archive          |  αρχειοθήκη
+#   backward         |
+#     compatibility  |  συμβατότητα προς τα πίσω
+#   bare repository  |  γυμνό αποθετήριο
+#   bisect           |  διχοτομώ
+#   branch           |  κλάδος
+#   bug              |  σφάλμα
+#   bundle           |  δεσμίδα
+#   bypass           |  παρακάμπτω
+#   (a) checkout     |  εξαγωγή
+#   (to) checkout    |  εξάγω
+#   cherry-pick      |  επιλεκτική διαλογή
+#   (a) commit       |  μια υποβολή
+#   (to) commit      |  υποβάλλω
+#   commit-ish       |  υποβολή ή φαινομενική
+#   config file      |  αρχείο ρυθμίσεων
+#   conflict         |  σύγκρουση
+#   dangling         |  εκκρεμές
+#   (to) debug       |  αποσφαλματώνω
+#   debugging        |  αποσφαλμάτωση
+#   deflate          |  αποσυμπιέζω
+#   directory        |  φάκελος
+#   diverge          |  αποκλίνω
+#   editor           |  διορθωτής
+#   entry            |  στοιχείο
+#   fast-forward     |  ταχεία προώθηση
+#   fast-forwarded   |  ταχέως προωθημένο
+#   (a) fetch        |  ανάκτηση
+#   (to) fetch       |  ανακτώ
+#   fix conflicts    |  επίλυση συγκρούσεων
+#   (to) format      |  μορφοποιώ
+#   glob             |  αντικατάσταση μεταχαρακτήρων
+#   hash             |  συμβολοσειρά
+#   HEAD             |  HEAD (ουδέτερο)
+#   hook             |  άγκιστρο
+#   hunk             |  αλλαγή
+#   inconsistency    |  αντίφαση
+#   (to) inflate     |  αποσυμπιέζω
+#   (a) list         |  παράθεση
+#   (to) list        |  παραθέτω
+#   mapping          |  αντιστοίχιση
+#   mismatch         |  ασυμφωνία
+#   merge            |  συγχώνευση
+#   pack             |  πακέτο
+#   patches          |  διορθώσεις
+#   path             |  διαδρομή
+#   pathspec         |  περιγραφή διαδρομής
+#   pattern          |  μοτίβο
+#   (to) prune       |  κλαδεύω
+#   (a) pull         |  ενσωμάτωση
+#   (to) pull        |  ενσωματώνω
+#   (a) push         |  δημοσίευση
+#   (to) push        |  δημοσιεύω
+#   trailers         |  υποσημειώσεις
+#   repository       |  αποθετήριο
+#   remote           |  απομακρυσμένο (ή απομακρυσμένος εξυπηρετητής)
+#   reset            |  επαναφέρω
+#   resolve          |  επιλύω *ή* ταυτίζω
+#   restore          |  αποκαθιστώ
+#   revision         |  έκδοση
+#   shallow          |  ρηχό
+#   shell            |  κέλυφος
+#   squash           |  συμπτύσσω/σύμπτυξη
+#   stash            |  αποθηκευμένα
+#   (to) stage       |  προετοιμάζω
+#   (to) stash       |  αποθηκεύω
+#   stream           |  ροή
+#   submodule        |  υποενότητα
+#   tag              |  ετικέτα
+#   template         |  πρότυπο
+#   thread           |  νήμα
+#   timestamp        |  χρονοσήμανση
+#   (to) track       |  παρακολουθώ
+#   tree             |  δέντρο
+#   tree-ish         |  δέντρο ή φαινομενικό
+#   unstage          |  αποπροετοιμάζω
+#   upstream         |  προς την πηγή
+#   viewer           |  πρόγραμμα προβολής
+#   worktree /       |
+#   work(ing) tree   |  δέντρο εργασίας
+# Jimmy Angelakos <vyruss@hellug.gr>, 2019.
+#
+msgid ""
+msgstr ""
+"Project-Id-Version: git\n"
+"Report-Msgid-Bugs-To: Git Mailing List <git@vger.kernel.org>\n"
+"POT-Creation-Date: 2019-02-15 10:09+0800\n"
+"PO-Revision-Date: 2019-02-15 02:10+0000\n"
+"Last-Translator: Jimmy Angelakos <vyruss@hellug.gr>\n"
+"Language-Team: Greek, Modern (1453-) <vyruss@hellug.gr>\n"
+"Language: el\n"
+"MIME-Version: 1.0\n"
+"Content-Type: text/plain; charset=UTF-8\n"
+"Content-Transfer-Encoding: 8bit\n"
+"Plural-Forms: nplurals=2; plural=(n != 1);\n"
+
+#: advice.c:101
+#, c-format
+msgid "%shint: %.*s%s\n"
+msgstr "%sνύξη: %.*s%s\n"
+
+#: advice.c:154
+msgid "Cherry-picking is not possible because you have unmerged files."
+msgstr ""
+"Δεν είναι δυνατό να γίνει επιλεκτική διαλογή επειδή έχετε μη συγχωνευμένα "
+"αρχεία."
+
+#: advice.c:156
+msgid "Committing is not possible because you have unmerged files."
+msgstr "Δεν είναι δυνατό να γίνει υποβολή επειδή έχετε μη συγχωνευμένα αρχεία."
+
+#: advice.c:158
+msgid "Merging is not possible because you have unmerged files."
+msgstr ""
+"Δεν είναι δυνατό να γίνει συγχώνευση επειδή έχετε μη συγχωνευμένα αρχεία."
+
+#: advice.c:160
+msgid "Pulling is not possible because you have unmerged files."
+msgstr ""
+"Δεν είναι δυνατό να γίνει ενσωμάτωση επειδή έχετε μη συγχωνευμένα αρχεία."
+
+#: advice.c:162
+msgid "Reverting is not possible because you have unmerged files."
+msgstr ""
+"Δεν είναι δυνατό να γίνει επαναφορά επειδή έχετε μη συγχωνευμένα αρχεία."
+
+#: advice.c:164
+#, c-format
+msgid "It is not possible to %s because you have unmerged files."
+msgstr "Δεν είναι δυνατό να γίνει %s επειδή έχετε μη συγχωνευμένα αρχεία."
+
+#: advice.c:172
+msgid ""
+"Fix them up in the work tree, and then use 'git add/rm <file>'\n"
+"as appropriate to mark resolution and make a commit."
+msgstr ""
+"Φτιάξτε τα στο δέντρο εργασίας, και μετά χρησιμοποιήστε 'git add/rm "
+"<αρχείο>'\n"
+"έτσι ώστε να επισημάνετε την επίλυση και να κάνετε μία υποβολή."
+
+#: advice.c:180
+msgid "Exiting because of an unresolved conflict."
+msgstr "Έξοδος λόγω ανεπίλυτης σύγκρουσης."
+
+#: advice.c:185 builtin/merge.c:1290
+msgid "You have not concluded your merge (MERGE_HEAD exists)."
+msgstr "Δεν έχετε ολοκληρώσει τη συγχώνευσή σας (Υπάρχει το MERGE_HEAD)."
+
+#: advice.c:187
+msgid "Please, commit your changes before merging."
+msgstr "Παρακαλώ, υποβάλετε τις αλλαγές σας πριν συγχωνεύσετε."
+
+#: advice.c:188
+msgid "Exiting because of unfinished merge."
+msgstr "Έξοδος λόγω μη ολοκληρωμένης συγχώνευσης."
+
+#: advice.c:194
+#, c-format
+msgid ""
+"Note: checking out '%s'.\n"
+"\n"
+"You are in 'detached HEAD' state. You can look around, make experimental\n"
+"changes and commit them, and you can discard any commits you make in this\n"
+"state without impacting any branches by performing another checkout.\n"
+"\n"
+"If you want to create a new branch to retain commits you create, you may\n"
+"do so (now or later) by using -b with the checkout command again. Example:\n"
+"\n"
+"  git checkout -b <new-branch-name>\n"
+"\n"
+msgstr ""
+"Σημείωση: εξαγωγή του '%s'.\n"
+"\n"
+"Βρίσκεστε σε κατάσταση 'αποσυνδεδεμένου HEAD'. Μπορείτε να περιηγηθείτε, να "
+"κάνετε πειραματικές\n"
+"αλλαγές και να τις υποβάλετε, καθώς και να απορρίψετε ό,τι υποβολές κάνετε "
+"σε αυτήν την\n"
+"κατάσταση χωρίς να επηρεάσετε άλλους κλάδους απλά κάνοντας μια νέα εξαγωγή.\n"
+"\n"
+"Αν θέλετε να δημιουργήσετε έναν νέο κλάδο για να διατηρήσετε τις υποβολές "
+"που δημιουργείτε, μπορείτε\n"
+"να το κάνετε (τώρα ή αργότερα) χρησιμοποιώντας -b με την εντολή εξαγωγής "
+"checkout πάλι. Παράδειγμα:\n"
+"\n"
+"  git checkout -b <όνομα-νέου-κλάδου>\n"
+"\n"
+
+#: alias.c:50
+msgid "cmdline ends with \\"
+msgstr "γραμμή εντολών τελειώνει με \\"
+
+#: alias.c:51
+msgid "unclosed quote"
+msgstr "ανοιχτά εισαγωγικά"
+
+#: apply.c:59
+#, c-format
+msgid "unrecognized whitespace option '%s'"
+msgstr "άγνωστη επιλογή κενού χώρου '%s'"
+
+#: apply.c:75
+#, c-format
+msgid "unrecognized whitespace ignore option '%s'"
+msgstr "άγνωστη επιλογή αγνόησης κενού χώρου '%s'"
+
+#: apply.c:125
+msgid "--reject and --3way cannot be used together."
+msgstr "--reject και --3way δε γίνεται να χρησιμοποιηθούν μαζί."
+
+#: apply.c:127
+msgid "--cached and --3way cannot be used together."
+msgstr "--cached και --3way δε γίνεται να χρησιμοποιηθούν μαζί.."
+
+#: apply.c:130
+msgid "--3way outside a repository"
+msgstr "--3way έξω από απόθετήριο"
+
+#: apply.c:141
+msgid "--index outside a repository"
+msgstr "--index έξω από αποθετήριο"
+
+#: apply.c:144
+msgid "--cached outside a repository"
+msgstr "--cached έξω από αποθετήριο"
+
+#: apply.c:825
+#, c-format
+msgid "Cannot prepare timestamp regexp %s"
+msgstr "Δεν είναι δυνατή η προετοιμασία κανονικής έκφρασης χρονοσήμανσης %s"
+
+#: apply.c:834
+#, c-format
+msgid "regexec returned %d for input: %s"
+msgstr "Το regexec επέστρεψε %d για εισαγωγή: %s"
+
+#: apply.c:908
+#, c-format
+msgid "unable to find filename in patch at line %d"
+msgstr "δεν είναι δυνατό να βρεθεί το όνομα αρχείου στη διόρθωση στη γραμμή %d"
+
+#: apply.c:946
+#, c-format
+msgid "git apply: bad git-diff - expected /dev/null, got %s on line %d"
+msgstr ""
+"git apply: λάθος git-diff - αναμενόταν /dev/null, βρέθηκε %s στη γραμμή %d"
+
+#: apply.c:952
+#, c-format
+msgid "git apply: bad git-diff - inconsistent new filename on line %d"
+msgstr "git apply: λάθος git-diff - ασύμφωνο όνομα νέου αρχείου στη γραμμή %d"
+
+#: apply.c:953
+#, c-format
+msgid "git apply: bad git-diff - inconsistent old filename on line %d"
+msgstr ""
+"git apply: λάθος git-diff - ασύμφωνο όνομα παλιού αρχείου στη γραμμή %d"
+
+#: apply.c:958
+#, c-format
+msgid "git apply: bad git-diff - expected /dev/null on line %d"
+msgstr "git apply: λάθος git-diff - αναμενόταν /dev/null στη γραμμή %d"
+
+#: apply.c:987
+#, c-format
+msgid "invalid mode on line %d: %s"
+msgstr "μη έγκυρη κατάσταση στη γραμμή %d: %s"
+
+#: apply.c:1306
+#, c-format
+msgid "inconsistent header lines %d and %d"
+msgstr "ασύμφωνες γραμμές επικεφαλίδας %d και %d"
+
+#: apply.c:1478
+#, c-format
+msgid "recount: unexpected line: %.*s"
+msgstr "recount: μη αναμενόμενη γραμμή: %.*s"
+
+#: apply.c:1547
+#, c-format
+msgid "patch fragment without header at line %d: %.*s"
+msgstr "απόσπασμα διόρθωσης χωρίς επικεφαλίδα στη γραμμή %d: %.*s"
+
+#: apply.c:1567
+#, c-format
+msgid ""
+"git diff header lacks filename information when removing %d leading pathname "
+"component (line %d)"
+msgid_plural ""
+"git diff header lacks filename information when removing %d leading pathname "
+"components (line %d)"
+msgstr[0] ""
+"Λείπει η πληροφορία ονόματος αρχείου από την επικεφαλίδα git diff κατά την "
+"αφαίρεση του %d αρχικού συστατικού ονόματος διαδρομής (γραμμή %d)"
+msgstr[1] ""
+"Λείπει η πληροφορία ονόματος αρχείου από την επικεφαλίδα git diff κατά την "
+"αφαίρεση των %d αρχικών συστατικών ονόματος διαδρομής (γραμμή %d)"
+
+#: apply.c:1580
+#, c-format
+msgid "git diff header lacks filename information (line %d)"
+msgstr ""
+"Λείπει η πληροφορία ονόματος αρχείου από την επικεφαλίδα git diff (γραμμή %d)"
+
+#: apply.c:1768
+msgid "new file depends on old contents"
+msgstr "το νέο αρχείο εξαρτάται από τα παλιά περιεχόμενα"
+
+#: apply.c:1770
+msgid "deleted file still has contents"
+msgstr "το διεγραμμένο αρχείο έχει ακόμα περιεχόμενα"
+
+#: apply.c:1804
+#, c-format
+msgid "corrupt patch at line %d"
+msgstr "κατεστραμμένη διόρθωση στη γραμμή %d"
+
+#: apply.c:1841
+#, c-format
+msgid "new file %s depends on old contents"
+msgstr "το νέο αρχείο %s εξαρτάται από τα παλιά περιεχόμενα"
+
+#: apply.c:1843
+#, c-format
+msgid "deleted file %s still has contents"
+msgstr "το διεγραμμένο αρχείο %s έχει ακόμα περιεχόμενα"
+
+#: apply.c:1846
+#, c-format
+msgid "** warning: file %s becomes empty but is not deleted"
+msgstr "** προσοχή: το αρχείο %s γίνεται κενό αλλά δε διαγράφεται"
+
+#: apply.c:1993
+#, c-format
+msgid "corrupt binary patch at line %d: %.*s"
+msgstr "κατεστραμμένη δυαδική διόρθωση στη γραμμή %d: %.*s"
+
+#: apply.c:2030
+#, c-format
+msgid "unrecognized binary patch at line %d"
+msgstr "μη αναγνωρίσιμη δυαδική διόρθωση στη γραμμή %d"
+
+#: apply.c:2192
+#, c-format
+msgid "patch with only garbage at line %d"
+msgstr "διόρθωση με μόνο σκουπίδια στη γραμμή %d"
+
+#: apply.c:2278
+#, c-format
+msgid "unable to read symlink %s"
+msgstr "δεν είναι δυνατή η ανάγνωση του συμβολικού δεσμού %s"
+
+#: apply.c:2282
+#, c-format
+msgid "unable to open or read %s"
+msgstr "δεν είναι δυνατό το άνοιγμα ή η ανάγνωση του %s"
+
+#: apply.c:2941
+#, c-format
+msgid "invalid start of line: '%c'"
+msgstr "μη αποδεκτή αρχή γραμμής: '%c'"
+
+#: apply.c:3062
+#, c-format
+msgid "Hunk #%d succeeded at %d (offset %d line)."
+msgid_plural "Hunk #%d succeeded at %d (offset %d lines)."
+msgstr[0] "Η αλλαγή υπ' αρ. %d πέτυχε στο %d (μετατόπιση %d γραμμή)."
+msgstr[1] "Η αλλαγή υπ' αρ. %d πέτυχε στο %d (μετατόπιση %d γραμμές)."
+
+#: apply.c:3074
+#, c-format
+msgid "Context reduced to (%ld/%ld) to apply fragment at %d"
+msgstr ""
+"Το πλαίσιο μειώθηκε σε (%ld/%ld) για την εφαρμογή του αποσπάσματος στο %d"
+
+#: apply.c:3080
+#, c-format
+msgid ""
+"while searching for:\n"
+"%.*s"
+msgstr ""
+"κατά την αναζήτηση για το:\n"
+"%.*s"
+
+#: apply.c:3102
+#, c-format
+msgid "missing binary patch data for '%s'"
+msgstr "λείπουν τα δυαδικά δεδομένα διόρθωσης για το '%s'"
+
+#: apply.c:3110
+#, c-format
+msgid "cannot reverse-apply a binary patch without the reverse hunk to '%s'"
+msgstr ""
+"δεν είναι δυνατή η εφαρμογή προς τα πίσω δυαδικής διόρθωσης χωρίς την αλλαγή "
+"προς τα πίσω στο '%s'"
+
+#: apply.c:3157
+#, c-format
+msgid "cannot apply binary patch to '%s' without full index line"
+msgstr ""
+"δεν είναι δυνατή η εφαρμογή δυαδικής διόρθωσης στο '%s' χωρίς την πλήρη "
+"γραμμή ευρετηρίου"
+
+#: apply.c:3167
+#, c-format
+msgid ""
+"the patch applies to '%s' (%s), which does not match the current contents."
+msgstr ""
+"η διόρθωση εφαρμόζεται στο '%s' (%s), που δεν ταιριάζει με τα παρόντα "
+"περιεχόμενα."
+
+#: apply.c:3175
+#, c-format
+msgid "the patch applies to an empty '%s' but it is not empty"
+msgstr "η διόρθωση εφαρμόζεται σε ένα κενό '%s' αλλά δεν είναι κενό"
+
+#: apply.c:3193
+#, c-format
+msgid "the necessary postimage %s for '%s' cannot be read"
+msgstr "δεν είναι δυνατή η ανάγνωση της αναγκαίας postimage %s για το '%s'"
+
+#: apply.c:3206
+#, c-format
+msgid "binary patch does not apply to '%s'"
+msgstr "η δυαδική διόρθωση δεν εφαρμόζεται στο '%s'"
+
+#: apply.c:3212
+#, c-format
+msgid "binary patch to '%s' creates incorrect result (expecting %s, got %s)"
+msgstr ""
+"η δυαδική διόρθωση στο '%s' δημιουργεί λάθος αποτέλεσμα (αναμενόταν %s, "
+"βρέθηκε %s)"
+
+#: apply.c:3233
+#, c-format
+msgid "patch failed: %s:%ld"
+msgstr "η διόρθωση απέτυχε: %s:%ld"
+
+#: apply.c:3356
+#, c-format
+msgid "cannot checkout %s"
+msgstr "δεν είναι δυνατή η εξαγωγή του %s"
+
+#: apply.c:3408 apply.c:3419 apply.c:3465 midx.c:58 setup.c:278
+#, c-format
+msgid "failed to read %s"
+msgstr "απέτυχε η ανάγνωση του %s"
+
+#: apply.c:3416
+#, c-format
+msgid "reading from '%s' beyond a symbolic link"
+msgstr "ανάγνωση από το '%s' πίσω από συμβολικό δεσμό"
+
+#: apply.c:3445 apply.c:3688
+#, c-format
+msgid "path %s has been renamed/deleted"
+msgstr "η διαδρομή %s έχει μετονομαστεί/διαγραφεί"
+
+#: apply.c:3531 apply.c:3703
+#, c-format
+msgid "%s: does not exist in index"
+msgstr "%s: δεν υπάρχει στο ευρετήριο"
+
+#: apply.c:3540 apply.c:3711
+#, c-format
+msgid "%s: does not match index"
+msgstr "%s: δεν ταιριάζει με το ευρετήριο"
+
+#: apply.c:3575
+msgid "repository lacks the necessary blob to fall back on 3-way merge."
+msgstr ""
+"από το αποθετήριο λείπει το αναγκαίο blob για να ακολουθηθεί η εναλλακτική "
+"της τριπλής συγχώνευσης."
+
+#: apply.c:3578
+#, c-format
+msgid "Falling back to three-way merge...\n"
+msgstr "Ακολουθείται η εναλλακτική της τριπλής συγχώνευσης...\n"
+
+#: apply.c:3594 apply.c:3598
+#, c-format
+msgid "cannot read the current contents of '%s'"
+msgstr "δεν είναι δυνατή η ανάγνωση των τρεχόντων περιεχομένων του '%s'"
+
+#: apply.c:3610
+#, c-format
+msgid "Failed to fall back on three-way merge...\n"
+msgstr "Απέτυχε η εναλλακτική της τριπλής συγχώνευσης...\n"
+
+#: apply.c:3624
+#, c-format
+msgid "Applied patch to '%s' with conflicts.\n"
+msgstr "Η εφαρμογή της διόρθωσης στο '%s' έγινε με συγκρούσεις.\n"
+
+#: apply.c:3629
+#, c-format
+msgid "Applied patch to '%s' cleanly.\n"
+msgstr "Η εφαρμογή της διόρθωσης στο '%s' έγινε καθαρά.\n"
+
+#: apply.c:3655
+msgid "removal patch leaves file contents"
+msgstr "η διόρθωση αφαίρεσης αφήνει πίσω περιεχόμενα στο αρχείο"
+
+#: apply.c:3728
+#, c-format
+msgid "%s: wrong type"
+msgstr "%s: λάθος τύπος"
+
+#: apply.c:3730
+#, c-format
+msgid "%s has type %o, expected %o"
+msgstr "%s έχει τύπο %o, αναμενόταν %o"
+
+#: apply.c:3881 apply.c:3883 read-cache.c:820 read-cache.c:846
+#: read-cache.c:1299
+#, c-format
+msgid "invalid path '%s'"
+msgstr "μη έγκυρη διαδρομή '%s'"
+
+#: apply.c:3939
+#, c-format
+msgid "%s: already exists in index"
+msgstr "%s: υπάρχει ήδη στο ευρετήριο"
+
+#: apply.c:3942
+#, c-format
+msgid "%s: already exists in working directory"
+msgstr "%s: υπάρχει ήδη στον φάκελο εργασίας"
+
+#: apply.c:3962
+#, c-format
+msgid "new mode (%o) of %s does not match old mode (%o)"
+msgstr "η νέα κατάσταση (%o) του %s δεν ταιριάζει με την παλιά (%o)"
+
+#: apply.c:3967
+#, c-format
+msgid "new mode (%o) of %s does not match old mode (%o) of %s"
+msgstr "η νέα κατάσταση (%o) του %s δεν ταιριάζει με την παλιά (%o) του %s"
+
+#: apply.c:3987
+#, c-format
+msgid "affected file '%s' is beyond a symbolic link"
+msgstr "το αρχείο που επηρεάζεται '%s' είναι πίσω από συμβολικό δεσμό"
+
+#: apply.c:3991
+#, c-format
+msgid "%s: patch does not apply"
+msgstr "%s: η διόρθωση δεν εφαρμόζεται"
+
+#: apply.c:4006
+#, c-format
+msgid "Checking patch %s..."
+msgstr "Γίνεται έλεγχος της διόρθωσης %s..."
+
+#: apply.c:4098
+#, c-format
+msgid "sha1 information is lacking or useless for submodule %s"
+msgstr "πληροφορία sha1 ελλιπής ή άχρηστη για την υποενότητα %s"
+
+#: apply.c:4105
+#, c-format
+msgid "mode change for %s, which is not in current HEAD"
+msgstr ""
+
+#: apply.c:4108
+#, c-format
+msgid "sha1 information is lacking or useless (%s)."
+msgstr "πληροφορία sha1 ελλιπής ή άχρηστη (%s)."
+
+#: apply.c:4113 builtin/checkout.c:248 builtin/reset.c:143
+#, c-format
+msgid "make_cache_entry failed for path '%s'"
+msgstr "το make_cache_entry απέτυχε για τη διαδρομή '%s'"
+
+#: apply.c:4117
+#, c-format
+msgid "could not add %s to temporary index"
+msgstr ""
+
+#: apply.c:4127
+#, c-format
+msgid "could not write temporary index to %s"
+msgstr ""
+
+#: apply.c:4265
+#, c-format
+msgid "unable to remove %s from index"
+msgstr ""
+
+#: apply.c:4299
+#, c-format
+msgid "corrupt patch for submodule %s"
+msgstr ""
+
+#: apply.c:4305
+#, c-format
+msgid "unable to stat newly created file '%s'"
+msgstr ""
+
+#: apply.c:4313
+#, c-format
+msgid "unable to create backing store for newly created file %s"
+msgstr ""
+
+#: apply.c:4319 apply.c:4464
+#, c-format
+msgid "unable to add cache entry for %s"
+msgstr ""
+
+#: apply.c:4362
+#, c-format
+msgid "failed to write to '%s'"
+msgstr ""
+
+#: apply.c:4366
+#, c-format
+msgid "closing file '%s'"
+msgstr ""
+
+#: apply.c:4436
+#, c-format
+msgid "unable to write file '%s' mode %o"
+msgstr ""
+
+#: apply.c:4534
+#, c-format
+msgid "Applied patch %s cleanly."
+msgstr "Η εφαρμογή της διόρθωσης '%s' έγινε καθαρά."
+
+#: apply.c:4542
+msgid "internal error"
+msgstr ""
+
+#: apply.c:4545
+#, c-format
+msgid "Applying patch %%s with %d reject..."
+msgid_plural "Applying patch %%s with %d rejects..."
+msgstr[0] ""
+msgstr[1] ""
+
+#: apply.c:4556
+#, c-format
+msgid "truncating .rej filename to %.*s.rej"
+msgstr ""
+
+#: apply.c:4564 builtin/fetch.c:837 builtin/fetch.c:1118
+#, c-format
+msgid "cannot open %s"
+msgstr ""
+
+#: apply.c:4578
+#, c-format
+msgid "Hunk #%d applied cleanly."
+msgstr "Η αλλαγή υπ' αρ. %d εφαρμόστηκε καθαρά."
+
+#: apply.c:4582
+#, c-format
+msgid "Rejected hunk #%d."
+msgstr "Απορρίφθηκε η αλλαγή υπ' αρ. %d."
+
+#: apply.c:4692
+#, c-format
+msgid "Skipped patch '%s'."
+msgstr ""
+
+#: apply.c:4700
+msgid "unrecognized input"
+msgstr "δεν αναγνωρίζεται η εισαγωγή"
+
+#: apply.c:4720
+msgid "unable to read index file"
+msgstr ""
+
+#: apply.c:4875
+#, c-format
+msgid "can't open patch '%s': %s"
+msgstr ""
+
+#: apply.c:4902
+#, c-format
+msgid "squelched %d whitespace error"
+msgid_plural "squelched %d whitespace errors"
+msgstr[0] ""
+msgstr[1] ""
+
+#: apply.c:4908 apply.c:4923
+#, c-format
+msgid "%d line adds whitespace errors."
+msgid_plural "%d lines add whitespace errors."
+msgstr[0] ""
+msgstr[1] ""
+
+#: apply.c:4916
+#, c-format
+msgid "%d line applied after fixing whitespace errors."
+msgid_plural "%d lines applied after fixing whitespace errors."
+msgstr[0] ""
+msgstr[1] ""
+
+#: apply.c:4932 builtin/add.c:539 builtin/mv.c:301 builtin/rm.c:390
+msgid "Unable to write new index file"
+msgstr ""
+
+#: apply.c:4959 apply.c:4962 builtin/am.c:2203 builtin/am.c:2206
+#: builtin/clone.c:122 builtin/fetch.c:118 builtin/merge.c:263
+#: builtin/pull.c:200 builtin/submodule--helper.c:407
+#: builtin/submodule--helper.c:1366 builtin/submodule--helper.c:1369
+#: builtin/submodule--helper.c:1850 builtin/submodule--helper.c:1853
+#: builtin/submodule--helper.c:2092 git-add--interactive.perl:197
+msgid "path"
+msgstr "διαδρομή"
+
+#: apply.c:4960
+msgid "don't apply changes matching the given path"
+msgstr ""
+
+#: apply.c:4963
+msgid "apply changes matching the given path"
+msgstr ""
+
+#: apply.c:4965 builtin/am.c:2212
+msgid "num"
+msgstr "αριθ."
+
+#: apply.c:4966
+msgid "remove <num> leading slashes from traditional diff paths"
+msgstr ""
+
+#: apply.c:4969
+msgid "ignore additions made by the patch"
+msgstr ""
+
+#: apply.c:4971
+msgid "instead of applying the patch, output diffstat for the input"
+msgstr ""
+
+#: apply.c:4975
+msgid "show number of added and deleted lines in decimal notation"
+msgstr ""
+
+#: apply.c:4977
+msgid "instead of applying the patch, output a summary for the input"
+msgstr ""
+
+#: apply.c:4979
+msgid "instead of applying the patch, see if the patch is applicable"
+msgstr ""
+
+#: apply.c:4981
+msgid "make sure the patch is applicable to the current index"
+msgstr ""
+
+#: apply.c:4983
+msgid "mark new files with `git add --intent-to-add`"
+msgstr ""
+
+#: apply.c:4985
+msgid "apply a patch without touching the working tree"
+msgstr ""
+
+#: apply.c:4987
+msgid "accept a patch that touches outside the working area"
+msgstr ""
+
+#: apply.c:4990
+msgid "also apply the patch (use with --stat/--summary/--check)"
+msgstr ""
+
+#: apply.c:4992
+msgid "attempt three-way merge if a patch does not apply"
+msgstr ""
+
+#: apply.c:4994
+msgid "build a temporary index based on embedded index information"
+msgstr ""
+
+#: apply.c:4997 builtin/checkout-index.c:173 builtin/ls-files.c:524
+msgid "paths are separated with NUL character"
+msgstr ""
+
+#: apply.c:4999
+msgid "ensure at least <n> lines of context match"
+msgstr ""
+
+#: apply.c:5000 builtin/am.c:2191 builtin/interpret-trailers.c:97
+#: builtin/interpret-trailers.c:99 builtin/interpret-trailers.c:101
+#: builtin/pack-objects.c:3314 builtin/rebase.c:1065
+msgid "action"
+msgstr "ενέργεια"
+
+#: apply.c:5001
+msgid "detect new or modified lines that have whitespace errors"
+msgstr ""
+
+#: apply.c:5004 apply.c:5007
+msgid "ignore changes in whitespace when finding context"
+msgstr ""
+
+#: apply.c:5010
+msgid "apply the patch in reverse"
+msgstr ""
+
+#: apply.c:5012
+msgid "don't expect at least one line of context"
+msgstr ""
+
+#: apply.c:5014
+msgid "leave the rejected hunks in corresponding *.rej files"
+msgstr ""
+
+#: apply.c:5016
+msgid "allow overlapping hunks"
+msgstr ""
+
+#: apply.c:5017 builtin/add.c:291 builtin/check-ignore.c:22
+#: builtin/commit.c:1312 builtin/count-objects.c:98 builtin/fsck.c:724
+#: builtin/log.c:2037 builtin/mv.c:123 builtin/read-tree.c:128
+#: builtin/rebase--interactive.c:159
+msgid "be verbose"
+msgstr ""
+
+#: apply.c:5019
+msgid "tolerate incorrectly detected missing new-line at the end of file"
+msgstr ""
+
+#: apply.c:5022
+msgid "do not trust the line counts in the hunk headers"
+msgstr ""
+
+#: apply.c:5024 builtin/am.c:2200
+msgid "root"
+msgstr "ρίζα"
+
+#: apply.c:5025
+msgid "prepend <root> to all filenames"
+msgstr "προσθήκη του προθέματος <ρίζα> σε όλα τα ονόματα αρχείων"
+
+#: archive.c:14
+msgid "git archive [<options>] <tree-ish> [<path>...]"
+msgstr "git archive [<επιλογές>] <δέντρο ή φαινομενικό> [<διαδρομή>...]"
+
+#: archive.c:15
+msgid "git archive --list"
+msgstr "git archive --list"
+
+#: archive.c:16
+msgid ""
+"git archive --remote <repo> [--exec <cmd>] [<options>] <tree-ish> [<path>...]"
+msgstr ""
+"git archive --remote <αποθετήριο> [--exec <εντολή>] [<επιλογές>] <δέντρο ή "
+"φαινομενικό> [<διαδρομή>...]"
+
+#: archive.c:17
+msgid "git archive --remote <repo> [--exec <cmd>] --list"
+msgstr "git archive --remote <αποθετήριο> [--exec <εντολή>] --list"
+
+#: archive.c:372 builtin/add.c:177 builtin/add.c:515 builtin/rm.c:299
+#, c-format
+msgid "pathspec '%s' did not match any files"
+msgstr "η διαδρομή '%s' δεν ταιριάζει με κανένα αρχείο"
+
+#: archive.c:396
+#, c-format
+msgid "no such ref: %.*s"
+msgstr "δεν υπάρχει ref: %.*s"
+
+#: archive.c:401
+#, c-format
+msgid "not a valid object name: %s"
+msgstr "μη έγκυρο όνομα αντικειμένου: %s"
+
+#: archive.c:414
+#, c-format
+msgid "not a tree object: %s"
+msgstr "δεν είναι αντικείμενο δέντρου: %s"
+
+#: archive.c:424
+msgid "current working directory is untracked"
+msgstr "ο τρέχων φάκελος εργασίας δεν παρακολουθείται"
+
+#: archive.c:455
+msgid "fmt"
+msgstr "μρφ."
+
+#: archive.c:455
+msgid "archive format"
+msgstr "μορφή αρχειοθήκης"
+
+#: archive.c:456 builtin/log.c:1549
+msgid "prefix"
+msgstr "πρόθεμα"
+
+#: archive.c:457
+msgid "prepend prefix to each pathname in the archive"
+msgstr "προσθήκη του προθέματος σε κάθε όνομα διαδρομής στην αρχειοθήκη"
+
+#: archive.c:458 builtin/blame.c:820 builtin/blame.c:821 builtin/config.c:129
+#: builtin/fast-export.c:1091 builtin/fast-export.c:1093 builtin/grep.c:895
+#: builtin/hash-object.c:105 builtin/ls-files.c:560 builtin/ls-files.c:563
+#: builtin/notes.c:412 builtin/notes.c:578 builtin/read-tree.c:123
+#: parse-options.h:162
+msgid "file"
+msgstr "αρχείο"
+
+#: archive.c:459 builtin/archive.c:90
+msgid "write the archive to this file"
+msgstr "αρχειοθέτηση σε αυτό το αρχείο"
+
+#: archive.c:461
+msgid "read .gitattributes in working directory"
+msgstr ""
+
+#: archive.c:462
+msgid "report archived files on stderr"
+msgstr ""
+
+#: archive.c:463
+msgid "store only"
+msgstr ""
+
+#: archive.c:464
+msgid "compress faster"
+msgstr "ταχύτερη συμπίεση"
+
+#: archive.c:472
+msgid "compress better"
+msgstr "καλύτερη συμπίεση"
+
+#: archive.c:475
+msgid "list supported archive formats"
+msgstr "παράθεση υποστηριζόμενων μορφών αρχειοθέτησης"
+
+#: archive.c:477 builtin/archive.c:91 builtin/clone.c:112 builtin/clone.c:115
+#: builtin/submodule--helper.c:1378 builtin/submodule--helper.c:1859
+msgid "repo"
+msgstr "αποθ."
+
+#: archive.c:478 builtin/archive.c:92
+msgid "retrieve the archive from remote repository <repo>"
+msgstr ""
+
+#: archive.c:479 builtin/archive.c:93 builtin/difftool.c:715
+#: builtin/notes.c:498
+msgid "command"
+msgstr ""
+
+#: archive.c:480 builtin/archive.c:94
+msgid "path to the remote git-upload-archive command"
+msgstr ""
+
+#: archive.c:487
+msgid "Unexpected option --remote"
+msgstr ""
+
+#: archive.c:489
+msgid "Option --exec can only be used together with --remote"
+msgstr ""
+
+#: archive.c:491
+msgid "Unexpected option --output"
+msgstr ""
+
+#: archive.c:513
+#, c-format
+msgid "Unknown archive format '%s'"
+msgstr "Άγνωστη μορφή αρχειοθέτησης '%s'"
+
+#: archive.c:520
+#, c-format
+msgid "Argument not supported for format '%s': -%d"
+msgstr ""
+
+#: archive-tar.c:125 archive-zip.c:345
+#, c-format
+msgid "cannot stream blob %s"
+msgstr "δεν είναι δυνατή η ροή του blob %s"
+
+#: archive-tar.c:260 archive-zip.c:363
+#, c-format
+msgid "unsupported file mode: 0%o (SHA1: %s)"
+msgstr ""
+
+#: archive-tar.c:287 archive-zip.c:353
+#, c-format
+msgid "cannot read %s"
+msgstr ""
+
+#: archive-tar.c:458
+#, c-format
+msgid "unable to start '%s' filter"
+msgstr ""
+
+#: archive-tar.c:461
+msgid "unable to redirect descriptor"
+msgstr ""
+
+#: archive-tar.c:468
+#, c-format
+msgid "'%s' filter reported error"
+msgstr ""
+
+#: archive-zip.c:314
+#, c-format
+msgid "path is not valid UTF-8: %s"
+msgstr ""
+
+#: archive-zip.c:318
+#, c-format
+msgid "path too long (%d chars, SHA1: %s): %s"
+msgstr ""
+
+#: archive-zip.c:474 builtin/pack-objects.c:225 builtin/pack-objects.c:228
+#, c-format
+msgid "deflate error (%d)"
+msgstr ""
+
+#: archive-zip.c:609
+#, c-format
+msgid "timestamp too large for this system: %<PRIuMAX>"
+msgstr ""
+
+#: attr.c:211
+#, c-format
+msgid "%.*s is not a valid attribute name"
+msgstr ""
+
+#: attr.c:368
+#, c-format
+msgid "%s not allowed: %s:%d"
+msgstr ""
+
+#: attr.c:408
+msgid ""
+"Negative patterns are ignored in git attributes\n"
+"Use '\\!' for literal leading exclamation."
+msgstr ""
+
+#: bisect.c:468
+#, c-format
+msgid "Badly quoted content in file '%s': %s"
+msgstr ""
+
+#: bisect.c:678
+#, c-format
+msgid "We cannot bisect more!\n"
+msgstr ""
+
+#: bisect.c:733
+#, c-format
+msgid "Not a valid commit name %s"
+msgstr "Μη έγκυρο όνομα υποβολής %s"
+
+#: bisect.c:758
+#, c-format
+msgid ""
+"The merge base %s is bad.\n"
+"This means the bug has been fixed between %s and [%s].\n"
+msgstr ""
+
+#: bisect.c:763
+#, c-format
+msgid ""
+"The merge base %s is new.\n"
+"The property has changed between %s and [%s].\n"
+msgstr ""
+
+#: bisect.c:768
+#, c-format
+msgid ""
+"The merge base %s is %s.\n"
+"This means the first '%s' commit is between %s and [%s].\n"
+msgstr ""
+
+#: bisect.c:776
+#, c-format
+msgid ""
+"Some %s revs are not ancestors of the %s rev.\n"
+"git bisect cannot work properly in this case.\n"
+"Maybe you mistook %s and %s revs?\n"
+msgstr ""
+
+#: bisect.c:789
+#, c-format
+msgid ""
+"the merge base between %s and [%s] must be skipped.\n"
+"So we cannot be sure the first %s commit is between %s and %s.\n"
+"We continue anyway."
+msgstr ""
+
+#: bisect.c:822
+#, c-format
+msgid "Bisecting: a merge base must be tested\n"
+msgstr ""
+
+#: bisect.c:865
+#, c-format
+msgid "a %s revision is needed"
+msgstr ""
+
+#: bisect.c:884 builtin/notes.c:177 builtin/tag.c:237
+#, c-format
+msgid "could not create file '%s'"
+msgstr ""
+
+#: bisect.c:937 builtin/merge.c:139
+#, c-format
+msgid "could not read file '%s'"
+msgstr ""
+
+#: bisect.c:967
+msgid "reading bisect refs failed"
+msgstr ""
+
+#: bisect.c:986
+#, c-format
+msgid "%s was both %s and %s\n"
+msgstr ""
+
+#: bisect.c:994
+#, c-format
+msgid ""
+"No testable commit found.\n"
+"Maybe you started with bad path parameters?\n"
+msgstr ""
+
+#: bisect.c:1013
+#, c-format
+msgid "(roughly %d step)"
+msgid_plural "(roughly %d steps)"
+msgstr[0] ""
+msgstr[1] ""
+
+#. TRANSLATORS: the last %s will be replaced with "(roughly %d
+#. steps)" translation.
+#.
+#: bisect.c:1019
+#, c-format
+msgid "Bisecting: %d revision left to test after this %s\n"
+msgid_plural "Bisecting: %d revisions left to test after this %s\n"
+msgstr[0] ""
+msgstr[1] ""
+
+#: blame.c:1792
+msgid "--contents and --reverse do not blend well."
+msgstr ""
+
+#: blame.c:1806
+msgid "cannot use --contents with final commit object name"
+msgstr ""
+
+#: blame.c:1827
+msgid "--reverse and --first-parent together require specified latest commit"
+msgstr ""
+
+#: blame.c:1836 bundle.c:164 ref-filter.c:2071 remote.c:1948 sequencer.c:1993
+#: sequencer.c:4064 builtin/commit.c:1004 builtin/log.c:378 builtin/log.c:936
+#: builtin/log.c:1420 builtin/log.c:1796 builtin/log.c:2086 builtin/merge.c:407
+#: builtin/pack-objects.c:3137 builtin/pack-objects.c:3152
+#: builtin/shortlog.c:192
+msgid "revision walk setup failed"
+msgstr "η αρχικοποίηση του μονοπατιού εκδόσεων απέτυχε"
+
+#: blame.c:1854
+msgid ""
+"--reverse --first-parent together require range along first-parent chain"
+msgstr ""
+
+#: blame.c:1865
+#, c-format
+msgid "no such path %s in %s"
+msgstr "δεν υπάρχει τέτοια διαδρομή %s στο %s"
+
+#: blame.c:1876
+#, c-format
+msgid "cannot read blob %s for path %s"
+msgstr "δεν είναι δυνατή η ανάγνωση του blob %s για τη διαδρομή %s"
+
+#: branch.c:52
+#, c-format
+msgid ""
+"\n"
+"After fixing the error cause you may try to fix up\n"
+"the remote tracking information by invoking\n"
+"\"git branch --set-upstream-to=%s%s%s\"."
+msgstr ""
+"\n"
+"Αφού φτιάξετε την αιτία του σφάλματος μπορείτε να δοκιμάσετε να φτιάξετε\n"
+"τις πληροφορίες παρακολούθησης απομακρυσμένου καλώντας\n"
+"\"git branch --set-upstream-to=%s%s%s\"."
+
+#: branch.c:66
+#, c-format
+msgid "Not setting branch %s as its own upstream."
+msgstr "Δε γίνεται ορισμός του %s ως το προς τα πάνω του εαυτού του."
+
+#: branch.c:92
+#, c-format
+msgid "Branch '%s' set up to track remote branch '%s' from '%s' by rebasing."
+msgstr ""
+
+#: branch.c:93
+#, c-format
+msgid "Branch '%s' set up to track remote branch '%s' from '%s'."
+msgstr ""
+
+#: branch.c:97
+#, c-format
+msgid "Branch '%s' set up to track local branch '%s' by rebasing."
+msgstr ""
+
+#: branch.c:98
+#, c-format
+msgid "Branch '%s' set up to track local branch '%s'."
+msgstr ""
+
+#: branch.c:103
+#, c-format
+msgid "Branch '%s' set up to track remote ref '%s' by rebasing."
+msgstr ""
+
+#: branch.c:104
+#, c-format
+msgid "Branch '%s' set up to track remote ref '%s'."
+msgstr ""
+
+#: branch.c:108
+#, c-format
+msgid "Branch '%s' set up to track local ref '%s' by rebasing."
+msgstr ""
+
+#: branch.c:109
+#, c-format
+msgid "Branch '%s' set up to track local ref '%s'."
+msgstr ""
+
+#: branch.c:118
+msgid "Unable to write upstream branch configuration"
+msgstr ""
+
+#: branch.c:155
+#, c-format
+msgid "Not tracking: ambiguous information for ref %s"
+msgstr ""
+
+#: branch.c:188
+#, c-format
+msgid "'%s' is not a valid branch name."
+msgstr ""
+
+#: branch.c:207
+#, c-format
+msgid "A branch named '%s' already exists."
+msgstr ""
+
+#: branch.c:212
+msgid "Cannot force update the current branch."
+msgstr ""
+
+#: branch.c:232
+#, c-format
+msgid "Cannot setup tracking information; starting point '%s' is not a branch."
+msgstr ""
+
+#: branch.c:234
+#, c-format
+msgid "the requested upstream branch '%s' does not exist"
+msgstr "ο προς τα πάνω κλάδος '%s' που ζητήθηκε δεν υπάρχει"
+
+#: branch.c:236
+msgid ""
+"\n"
+"If you are planning on basing your work on an upstream\n"
+"branch that already exists at the remote, you may need to\n"
+"run \"git fetch\" to retrieve it.\n"
+"\n"
+"If you are planning to push out a new local branch that\n"
+"will track its remote counterpart, you may want to use\n"
+"\"git push -u\" to set the upstream config as you push."
+msgstr ""
+
+#: branch.c:280
+#, c-format
+msgid "Not a valid object name: '%s'."
+msgstr "Μη έγκυρο όνομα αντικειμένου: '%s'."
+
+#: branch.c:300
+#, c-format
+msgid "Ambiguous object name: '%s'."
+msgstr "Αμφίσημο όνομα αντικειμένου: '%s'."
+
+#: branch.c:305
+#, c-format
+msgid "Not a valid branch point: '%s'."
+msgstr "Μη έγκυρο σημείο κλάδου: '%s'."
+
+#: branch.c:359
+#, c-format
+msgid "'%s' is already checked out at '%s'"
+msgstr ""
+
+#: branch.c:382
+#, c-format
+msgid "HEAD of working tree %s is not updated"
+msgstr ""
+
+#: bundle.c:36
+#, c-format
+msgid "'%s' does not look like a v2 bundle file"
+msgstr ""
+
+#: bundle.c:64
+#, c-format
+msgid "unrecognized header: %s%s (%d)"
+msgstr ""
+
+#: bundle.c:90 rerere.c:480 rerere.c:690 sequencer.c:2215 sequencer.c:2763
+#: builtin/commit.c:776
+#, c-format
+msgid "could not open '%s'"
+msgstr "δεν ήταν δυνατό το άνοιγμα του '%s'"
+
+#: bundle.c:143
+msgid "Repository lacks these prerequisite commits:"
+msgstr ""
+
+#: bundle.c:194
+#, c-format
+msgid "The bundle contains this ref:"
+msgid_plural "The bundle contains these %d refs:"
+msgstr[0] ""
+msgstr[1] ""
+
+#: bundle.c:201
+msgid "The bundle records a complete history."
+msgstr ""
+
+#: bundle.c:203
+#, c-format
+msgid "The bundle requires this ref:"
+msgid_plural "The bundle requires these %d refs:"
+msgstr[0] ""
+msgstr[1] ""
+
+#: bundle.c:269
+msgid "unable to dup bundle descriptor"
+msgstr ""
+
+#: bundle.c:276
+msgid "Could not spawn pack-objects"
+msgstr ""
+
+#: bundle.c:287
+msgid "pack-objects died"
+msgstr ""
+
+#: bundle.c:329
+msgid "rev-list died"
+msgstr ""
+
+#: bundle.c:378
+#, c-format
+msgid "ref '%s' is excluded by the rev-list options"
+msgstr ""
+
+#: bundle.c:457 builtin/log.c:193 builtin/log.c:1701 builtin/shortlog.c:306
+#, c-format
+msgid "unrecognized argument: %s"
+msgstr ""
+
+#: bundle.c:465
+msgid "Refusing to create empty bundle."
+msgstr ""
+
+#: bundle.c:475
+#, c-format
+msgid "cannot create '%s'"
+msgstr ""
+
+#: bundle.c:500
+msgid "index-pack died"
+msgstr ""
+
+#: color.c:296
+#, c-format
+msgid "invalid color value: %.*s"
+msgstr ""
+
+#: commit.c:50 sequencer.c:2567 builtin/am.c:355 builtin/am.c:399
+#: builtin/am.c:1375 builtin/am.c:2019 builtin/replace.c:376
+#: builtin/replace.c:448
+#, c-format
+msgid "could not parse %s"
+msgstr ""
+
+#: commit.c:52
+#, c-format
+msgid "%s %s is not a commit!"
+msgstr ""
+
+#: commit.c:193
+msgid ""
+"Support for <GIT_DIR>/info/grafts is deprecated\n"
+"and will be removed in a future Git version.\n"
+"\n"
+"Please use \"git replace --convert-graft-file\"\n"
+"to convert the grafts into replace refs.\n"
+"\n"
+"Turn this message off by running\n"
+"\"git config advice.graftFileDeprecated false\""
+msgstr ""
+
+#: commit.c:1122
+#, c-format
+msgid "Commit %s has an untrusted GPG signature, allegedly by %s."
+msgstr "Η υπογραφή %s έχει μη αξιόπιστη υπογραφή GPG, δήθεν από %s."
+
+#: commit.c:1125
+#, c-format
+msgid "Commit %s has a bad GPG signature allegedly by %s."
+msgstr "Η υποβολή %s έχει λάθος υπογραφή GPG δήθεν από %s."
+
+#: commit.c:1128
+#, c-format
+msgid "Commit %s does not have a GPG signature."
+msgstr "Η υποβολή %s δεν έχει υπογραφή GPG."
+
+#: commit.c:1131
+#, c-format
+msgid "Commit %s has a good GPG signature by %s\n"
+msgstr "Η υποβολή %s έχει σωστή υπογραφή GPG από %s\n"
+
+#: commit.c:1385
+msgid ""
+"Warning: commit message did not conform to UTF-8.\n"
+"You may want to amend it after fixing the message, or set the config\n"
+"variable i18n.commitencoding to the encoding your project uses.\n"
+msgstr ""
+
+#: commit-graph.c:101
+#, c-format
+msgid "graph file %s is too small"
+msgstr ""
+
+#: commit-graph.c:136
+#, c-format
+msgid "graph signature %X does not match signature %X"
+msgstr ""
+
+#: commit-graph.c:143
+#, c-format
+msgid "graph version %X does not match version %X"
+msgstr ""
+
+#: commit-graph.c:150
+#, c-format
+msgid "hash version %X does not match version %X"
+msgstr ""
+
+#: commit-graph.c:173
+msgid "chunk lookup table entry missing; graph file may be incomplete"
+msgstr ""
+
+#: commit-graph.c:184
+#, c-format
+msgid "improper chunk offset %08x%08x"
+msgstr ""
+
+#: commit-graph.c:221
+#, c-format
+msgid "chunk id %08x appears multiple times"
+msgstr ""
+
+#: commit-graph.c:334
+#, c-format
+msgid "could not find commit %s"
+msgstr ""
+
+#: commit-graph.c:671 builtin/pack-objects.c:2646
+#, c-format
+msgid "unable to get type of object %s"
+msgstr ""
+
+#: commit-graph.c:704
+msgid "Loading known commits in commit graph"
+msgstr ""
+
+#: commit-graph.c:720
+msgid "Expanding reachable commits in commit graph"
+msgstr ""
+
+#: commit-graph.c:732
+msgid "Clearing commit marks in commit graph"
+msgstr ""
+
+#: commit-graph.c:752
+msgid "Computing commit graph generation numbers"
+msgstr ""
+
+#: commit-graph.c:869
+#, c-format
+msgid "Finding commits for commit graph in %d pack"
+msgid_plural "Finding commits for commit graph in %d packs"
+msgstr[0] ""
+msgstr[1] ""
+
+#: commit-graph.c:882
+#, c-format
+msgid "error adding pack %s"
+msgstr ""
+
+#: commit-graph.c:884
+#, c-format
+msgid "error opening index for %s"
+msgstr ""
+
+#: commit-graph.c:898
+#, c-format
+msgid "Finding commits for commit graph from %d ref"
+msgid_plural "Finding commits for commit graph from %d refs"
+msgstr[0] ""
+msgstr[1] ""
+
+#: commit-graph.c:930
+msgid "Finding commits for commit graph among packed objects"
+msgstr ""
+
+#: commit-graph.c:943
+msgid "Counting distinct commits in commit graph"
+msgstr ""
+
+#: commit-graph.c:956
+#, c-format
+msgid "the commit graph format cannot write %d commits"
+msgstr ""
+
+#: commit-graph.c:965
+msgid "Finding extra edges in commit graph"
+msgstr ""
+
+#: commit-graph.c:989
+msgid "too many commits to write graph"
+msgstr ""
+
+#: commit-graph.c:996 midx.c:769
+#, c-format
+msgid "unable to create leading directories of %s"
+msgstr ""
+
+#: commit-graph.c:1036
+#, c-format
+msgid "Writing out commit graph in %d pass"
+msgid_plural "Writing out commit graph in %d passes"
+msgstr[0] ""
+msgstr[1] ""
+
+#: commit-graph.c:1109
+msgid "the commit-graph file has incorrect checksum and is likely corrupt"
+msgstr ""
+
+#: commit-graph.c:1153
+msgid "Verifying commits in commit graph"
+msgstr ""
+
+#: compat/obstack.c:406 compat/obstack.c:408
+msgid "memory exhausted"
+msgstr ""
+
+#: config.c:123
+#, c-format
+msgid ""
+"exceeded maximum include depth (%d) while including\n"
+"\t%s\n"
+"from\n"
+"\t%s\n"
+"This might be due to circular includes."
+msgstr ""
+
+#: config.c:139
+#, c-format
+msgid "could not expand include path '%s'"
+msgstr ""
+
+#: config.c:150
+msgid "relative config includes must come from files"
+msgstr ""
+
+#: config.c:190
+msgid "relative config include conditionals must come from files"
+msgstr ""
+
+#: config.c:348
+#, c-format
+msgid "key does not contain a section: %s"
+msgstr ""
+
+#: config.c:354
+#, c-format
+msgid "key does not contain variable name: %s"
+msgstr ""
+
+#: config.c:378 sequencer.c:2330
+#, c-format
+msgid "invalid key: %s"
+msgstr ""
+
+#: config.c:384
+#, c-format
+msgid "invalid key (newline): %s"
+msgstr ""
+
+#: config.c:420 config.c:432
+#, c-format
+msgid "bogus config parameter: %s"
+msgstr ""
+
+#: config.c:467
+#, c-format
+msgid "bogus format in %s"
+msgstr ""
+
+#: config.c:793
+#, c-format
+msgid "bad config line %d in blob %s"
+msgstr "λάθος γραμμή ρυθμίσεων %d στο blob %s"
+
+#: config.c:797
+#, c-format
+msgid "bad config line %d in file %s"
+msgstr "λάθος γραμμή ρυθμίσεων %d στο αρχείο %s"
+
+#: config.c:801
+#, c-format
+msgid "bad config line %d in standard input"
+msgstr "λάθος γραμμή ρυθμίσεων %d στο standard input"
+
+#: config.c:805
+#, c-format
+msgid "bad config line %d in submodule-blob %s"
+msgstr "λάθος γραμμή ρυθμίσεων %d στο blob υποενότητας %s"
+
+#: config.c:809
+#, c-format
+msgid "bad config line %d in command line %s"
+msgstr "λάθος γραμμή ρυθμίσεων %d στη γραμμή εντολών %s"
+
+#: config.c:813
+#, c-format
+msgid "bad config line %d in %s"
+msgstr "λάθος γραμμή ρυθμίσεων %d στο %s"
+
+#: config.c:952
+msgid "out of range"
+msgstr "εκτός ορίων"
+
+#: config.c:952
+msgid "invalid unit"
+msgstr "μη έγκυρη μονάδα μέτρησης"
+
+#: config.c:958
+#, c-format
+msgid "bad numeric config value '%s' for '%s': %s"
+msgstr "λάθος αριθμητική τιμή ρύθμισης '%s' για το '%s': %s"
+
+#: config.c:963
+#, c-format
+msgid "bad numeric config value '%s' for '%s' in blob %s: %s"
+msgstr "λάθος αριθμητική τιμή ρύθμισης '%s' για το '%s' στο blob %s: %s"
+
+#: config.c:966
+#, c-format
+msgid "bad numeric config value '%s' for '%s' in file %s: %s"
+msgstr "λάθος αριθμητική τιμή ρύθμισης '%s' για το '%s' στο αρχείο %s: %s"
+
+#: config.c:969
+#, c-format
+msgid "bad numeric config value '%s' for '%s' in standard input: %s"
+msgstr "λάθος αριθμητική τιμή ρύθμισης '%s' για το '%s' στo standard input: %s"
+
+#: config.c:972
+#, c-format
+msgid "bad numeric config value '%s' for '%s' in submodule-blob %s: %s"
+msgstr ""
+"λάθος αριθμητική τιμή ρύθμισης '%s' για το '%s' στο blob υποενότητας %s: %s"
+
+#: config.c:975
+#, c-format
+msgid "bad numeric config value '%s' for '%s' in command line %s: %s"
+msgstr ""
+"λάθος αριθμητική τιμή ρύθμισης '%s' για το '%s' στη γραμμή εντολών %s: %s"
+
+#: config.c:978
+#, c-format
+msgid "bad numeric config value '%s' for '%s' in %s: %s"
+msgstr "λάθος αριθμητική τιμή ρύθμισης '%s' για το '%s' στο %s: %s"
+
+#: config.c:1073
+#, c-format
+msgid "failed to expand user dir in: '%s'"
+msgstr ""
+
+#: config.c:1082
+#, c-format
+msgid "'%s' for '%s' is not a valid timestamp"
+msgstr "'%s' για το '%s' δεν είναι έγκυρη χρονοσήμανση"
+
+#: config.c:1173
+#, c-format
+msgid "abbrev length out of range: %d"
+msgstr ""
+
+#: config.c:1187 config.c:1198
+#, c-format
+msgid "bad zlib compression level %d"
+msgstr ""
+
+#: config.c:1290
+msgid "core.commentChar should only be one character"
+msgstr ""
+
+#: config.c:1323
+#, c-format
+msgid "invalid mode for object creation: %s"
+msgstr ""
+
+#: config.c:1395
+#, c-format
+msgid "malformed value for %s"
+msgstr ""
+
+#: config.c:1421
+#, c-format
+msgid "malformed value for %s: %s"
+msgstr ""
+
+#: config.c:1422
+msgid "must be one of nothing, matching, simple, upstream or current"
+msgstr ""
+
+#: config.c:1481 builtin/pack-objects.c:3394
+#, c-format
+msgid "bad pack compression level %d"
+msgstr ""
+
+#: config.c:1602
+#, c-format
+msgid "unable to load config blob object '%s'"
+msgstr "δεν ήταν δυνατό να φορτωθεί το αντικείμενο blob ρυθμίσεων '%s'"
+
+#: config.c:1605
+#, c-format
+msgid "reference '%s' does not point to a blob"
+msgstr "η αναφορά '%s' δε δείχνει σε κάποιο blob"
+
+#: config.c:1622
+#, c-format
+msgid "unable to resolve config blob '%s'"
+msgstr "δεν ήταν δυνατή η αναζήτηση blob ρυθμίσεων '%s'"
+
+#: config.c:1652
+#, c-format
+msgid "failed to parse %s"
+msgstr ""
+
+#: config.c:1705
+msgid "unable to parse command-line config"
+msgstr ""
+
+#: config.c:2037
+msgid "unknown error occurred while reading the configuration files"
+msgstr ""
+
+#: config.c:2207
+#, c-format
+msgid "Invalid %s: '%s'"
+msgstr ""
+
+#: config.c:2250
+#, c-format
+msgid "unknown core.untrackedCache value '%s'; using 'keep' default value"
+msgstr ""
+
+#: config.c:2276
+#, c-format
+msgid "splitIndex.maxPercentChange value '%d' should be between 0 and 100"
+msgstr ""
+
+#: config.c:2322
+#, c-format
+msgid "unable to parse '%s' from command-line config"
+msgstr ""
+
+#: config.c:2324
+#, c-format
+msgid "bad config variable '%s' in file '%s' at line %d"
+msgstr ""
+
+#: config.c:2405
+#, c-format
+msgid "invalid section name '%s'"
+msgstr ""
+
+#: config.c:2437
+#, c-format
+msgid "%s has multiple values"
+msgstr ""
+
+#: config.c:2466
+#, c-format
+msgid "failed to write new configuration file %s"
+msgstr ""
+
+#: config.c:2716 config.c:3040
+#, c-format
+msgid "could not lock config file %s"
+msgstr ""
+
+#: config.c:2727
+#, c-format
+msgid "opening %s"
+msgstr ""
+
+#: config.c:2762 builtin/config.c:328
+#, c-format
+msgid "invalid pattern: %s"
+msgstr ""
+
+#: config.c:2787
+#, c-format
+msgid "invalid config file %s"
+msgstr ""
+
+#: config.c:2800 config.c:3053
+#, c-format
+msgid "fstat on %s failed"
+msgstr ""
+
+#: config.c:2811
+#, c-format
+msgid "unable to mmap '%s'"
+msgstr ""
+
+#: config.c:2820 config.c:3058
+#, c-format
+msgid "chmod on %s failed"
+msgstr ""
+
+#: config.c:2905 config.c:3155
+#, c-format
+msgid "could not write config file %s"
+msgstr ""
+
+#: config.c:2939
+#, c-format
+msgid "could not set '%s' to '%s'"
+msgstr ""
+
+#: config.c:2941 builtin/remote.c:782
+#, c-format
+msgid "could not unset '%s'"
+msgstr ""
+
+#: config.c:3031
+#, c-format
+msgid "invalid section name: %s"
+msgstr ""
+
+#: config.c:3198
+#, c-format
+msgid "missing value for '%s'"
+msgstr ""
+
+#: connect.c:61
+msgid "the remote end hung up upon initial contact"
+msgstr ""
+
+#: connect.c:63
+msgid ""
+"Could not read from remote repository.\n"
+"\n"
+"Please make sure you have the correct access rights\n"
+"and the repository exists."
+msgstr ""
+
+#: connect.c:81
+#, c-format
+msgid "server doesn't support '%s'"
+msgstr ""
+
+#: connect.c:103
+#, c-format
+msgid "server doesn't support feature '%s'"
+msgstr ""
+
+#: connect.c:114
+msgid "expected flush after capabilities"
+msgstr ""
+
+#: connect.c:233
+#, c-format
+msgid "ignoring capabilities after first line '%s'"
+msgstr ""
+
+#: connect.c:252
+msgid "protocol error: unexpected capabilities^{}"
+msgstr ""
+
+#: connect.c:273
+#, c-format
+msgid "protocol error: expected shallow sha-1, got '%s'"
+msgstr ""
+
+#: connect.c:275
+msgid "repository on the other end cannot be shallow"
+msgstr ""
+
+#: connect.c:313
+msgid "invalid packet"
+msgstr ""
+
+#: connect.c:333
+#, c-format
+msgid "protocol error: unexpected '%s'"
+msgstr ""
+
+#: connect.c:441
+#, c-format
+msgid "invalid ls-refs response: %s"
+msgstr ""
+
+#: connect.c:445
+msgid "expected flush after ref listing"
+msgstr ""
+
+#: connect.c:544
+#, c-format
+msgid "protocol '%s' is not supported"
+msgstr ""
+
+#: connect.c:595
+msgid "unable to set SO_KEEPALIVE on socket"
+msgstr ""
+
+#: connect.c:635 connect.c:698
+#, c-format
+msgid "Looking up %s ... "
+msgstr ""
+
+#: connect.c:639
+#, c-format
+msgid "unable to look up %s (port %s) (%s)"
+msgstr ""
+
+#. TRANSLATORS: this is the end of "Looking up %s ... "
+#: connect.c:643 connect.c:714
+#, c-format
+msgid ""
+"done.\n"
+"Connecting to %s (port %s) ... "
+msgstr ""
+"ολοκληρώθηκε.\n"
+"Σύνδεση στο %s (port %s) ... "
+
+#: connect.c:665 connect.c:742
+#, c-format
+msgid ""
+"unable to connect to %s:\n"
+"%s"
+msgstr ""
+
+#. TRANSLATORS: this is the end of "Connecting to %s (port %s) ... "
+#: connect.c:671 connect.c:748
+msgid "done."
+msgstr "ολοκληρώθηκε."
+
+#: connect.c:702
+#, c-format
+msgid "unable to look up %s (%s)"
+msgstr ""
+
+#: connect.c:708
+#, c-format
+msgid "unknown port %s"
+msgstr ""
+
+#: connect.c:845 connect.c:1171
+#, c-format
+msgid "strange hostname '%s' blocked"
+msgstr ""
+
+#: connect.c:847
+#, c-format
+msgid "strange port '%s' blocked"
+msgstr ""
+
+#: connect.c:857
+#, c-format
+msgid "cannot start proxy %s"
+msgstr ""
+
+#: connect.c:924
+msgid "no path specified; see 'git help pull' for valid url syntax"
+msgstr ""
+
+#: connect.c:1119
+msgid "ssh variant 'simple' does not support -4"
+msgstr ""
+
+#: connect.c:1131
+msgid "ssh variant 'simple' does not support -6"
+msgstr ""
+
+#: connect.c:1148
+msgid "ssh variant 'simple' does not support setting port"
+msgstr ""
+
+#: connect.c:1259
+#, c-format
+msgid "strange pathname '%s' blocked"
+msgstr ""
+
+#: connect.c:1304
+msgid "unable to fork"
+msgstr ""
+
+#: connected.c:68 builtin/fsck.c:221 builtin/prune.c:146
+msgid "Checking connectivity"
+msgstr ""
+
+#: connected.c:80
+msgid "Could not run 'git rev-list'"
+msgstr ""
+
+#: connected.c:100
+msgid "failed write to rev-list"
+msgstr ""
+
+#: connected.c:107
+msgid "failed to close rev-list's stdin"
+msgstr ""
+
+#: convert.c:193
+#, c-format
+msgid "illegal crlf_action %d"
+msgstr ""
+
+#: convert.c:206
+#, c-format
+msgid "CRLF would be replaced by LF in %s"
+msgstr ""
+
+#: convert.c:208
+#, c-format
+msgid ""
+"CRLF will be replaced by LF in %s.\n"
+"The file will have its original line endings in your working directory"
+msgstr ""
+
+#: convert.c:216
+#, c-format
+msgid "LF would be replaced by CRLF in %s"
+msgstr ""
+
+#: convert.c:218
+#, c-format
+msgid ""
+"LF will be replaced by CRLF in %s.\n"
+"The file will have its original line endings in your working directory"
+msgstr ""
+
+#: convert.c:279
+#, c-format
+msgid "BOM is prohibited in '%s' if encoded as %s"
+msgstr ""
+
+#: convert.c:286
+#, c-format
+msgid ""
+"The file '%s' contains a byte order mark (BOM). Please use UTF-%s as working-"
+"tree-encoding."
+msgstr ""
+
+#: convert.c:304
+#, c-format
+msgid "BOM is required in '%s' if encoded as %s"
+msgstr ""
+
+#: convert.c:306
+#, c-format
+msgid ""
+"The file '%s' is missing a byte order mark (BOM). Please use UTF-%sBE or UTF-"
+"%sLE (depending on the byte order) as working-tree-encoding."
+msgstr ""
+
+#: convert.c:424 convert.c:495
+#, c-format
+msgid "failed to encode '%s' from %s to %s"
+msgstr ""
+
+#: convert.c:467
+#, c-format
+msgid "encoding '%s' from %s to %s and back is not the same"
+msgstr ""
+
+#: convert.c:673
+#, c-format
+msgid "cannot fork to run external filter '%s'"
+msgstr ""
+
+#: convert.c:693
+#, c-format
+msgid "cannot feed the input to external filter '%s'"
+msgstr ""
+
+#: convert.c:700
+#, c-format
+msgid "external filter '%s' failed %d"
+msgstr ""
+
+#: convert.c:735 convert.c:738
+#, c-format
+msgid "read from external filter '%s' failed"
+msgstr ""
+
+#: convert.c:741 convert.c:796
+#, c-format
+msgid "external filter '%s' failed"
+msgstr ""
+
+#: convert.c:844
+msgid "unexpected filter type"
+msgstr ""
+
+#: convert.c:855
+msgid "path name too long for external filter"
+msgstr ""
+
+#: convert.c:929
+#, c-format
+msgid ""
+"external filter '%s' is not available anymore although not all paths have "
+"been filtered"
+msgstr ""
+
+#: convert.c:1228
+msgid "true/false are no valid working-tree-encodings"
+msgstr ""
+
+#: convert.c:1398 convert.c:1432
+#, c-format
+msgid "%s: clean filter '%s' failed"
+msgstr ""
+
+#: convert.c:1476
+#, c-format
+msgid "%s: smudge filter %s failed"
+msgstr ""
+
+#: date.c:137
+msgid "in the future"
+msgstr ""
+
+#: date.c:143
+#, c-format
+msgid "%<PRIuMAX> second ago"
+msgid_plural "%<PRIuMAX> seconds ago"
+msgstr[0] ""
+msgstr[1] ""
+
+#: date.c:150
+#, c-format
+msgid "%<PRIuMAX> minute ago"
+msgid_plural "%<PRIuMAX> minutes ago"
+msgstr[0] ""
+msgstr[1] ""
+
+#: date.c:157
+#, c-format
+msgid "%<PRIuMAX> hour ago"
+msgid_plural "%<PRIuMAX> hours ago"
+msgstr[0] ""
+msgstr[1] ""
+
+#: date.c:164
+#, c-format
+msgid "%<PRIuMAX> day ago"
+msgid_plural "%<PRIuMAX> days ago"
+msgstr[0] ""
+msgstr[1] ""
+
+#: date.c:170
+#, c-format
+msgid "%<PRIuMAX> week ago"
+msgid_plural "%<PRIuMAX> weeks ago"
+msgstr[0] ""
+msgstr[1] ""
+
+#: date.c:177
+#, c-format
+msgid "%<PRIuMAX> month ago"
+msgid_plural "%<PRIuMAX> months ago"
+msgstr[0] ""
+msgstr[1] ""
+
+#: date.c:188
+#, c-format
+msgid "%<PRIuMAX> year"
+msgid_plural "%<PRIuMAX> years"
+msgstr[0] ""
+msgstr[1] ""
+
+#. TRANSLATORS: "%s" is "<n> years"
+#: date.c:191
+#, c-format
+msgid "%s, %<PRIuMAX> month ago"
+msgid_plural "%s, %<PRIuMAX> months ago"
+msgstr[0] ""
+msgstr[1] ""
+
+#: date.c:196 date.c:201
+#, c-format
+msgid "%<PRIuMAX> year ago"
+msgid_plural "%<PRIuMAX> years ago"
+msgstr[0] ""
+msgstr[1] ""
+
+#: delta-islands.c:272
+msgid "Propagating island marks"
+msgstr ""
+
+#: delta-islands.c:290
+#, c-format
+msgid "bad tree object %s"
+msgstr ""
+
+#: delta-islands.c:334
+#, c-format
+msgid "failed to load island regex for '%s': %s"
+msgstr ""
+
+#: delta-islands.c:390
+#, c-format
+msgid "island regex from config has too many capture groups (max=%d)"
+msgstr ""
+
+#: delta-islands.c:466
+#, c-format
+msgid "Marked %d islands, done.\n"
+msgstr ""
+
+#: diffcore-order.c:24
+#, c-format
+msgid "failed to read orderfile '%s'"
+msgstr ""
+
+#: diffcore-rename.c:544
+msgid "Performing inexact rename detection"
+msgstr ""
+
+#: diff.c:108
+#, c-format
+msgid "option '%s' requires a value"
+msgstr ""
+
+#: diff.c:158
+#, c-format
+msgid "  Failed to parse dirstat cut-off percentage '%s'\n"
+msgstr ""
+
+#: diff.c:163
+#, c-format
+msgid "  Unknown dirstat parameter '%s'\n"
+msgstr ""
+
+#: diff.c:291
+msgid ""
+"color moved setting must be one of 'no', 'default', 'blocks', 'zebra', "
+"'dimmed-zebra', 'plain'"
+msgstr ""
+
+#: diff.c:319
+#, c-format
+msgid ""
+"unknown color-moved-ws mode '%s', possible values are 'ignore-space-change', "
+"'ignore-space-at-eol', 'ignore-all-space', 'allow-indentation-change'"
+msgstr ""
+
+#: diff.c:327
+msgid ""
+"color-moved-ws: allow-indentation-change cannot be combined with other "
+"whitespace modes"
+msgstr ""
+
+#: diff.c:400
+#, c-format
+msgid "Unknown value for 'diff.submodule' config variable: '%s'"
+msgstr ""
+
+#: diff.c:460
+#, c-format
+msgid ""
+"Found errors in 'diff.dirstat' config variable:\n"
+"%s"
+msgstr ""
+
+#: diff.c:4211
+#, c-format
+msgid "external diff died, stopping at %s"
+msgstr ""
+
+#: diff.c:4553
+msgid "--name-only, --name-status, --check and -s are mutually exclusive"
+msgstr ""
+
+#: diff.c:4556
+msgid "-G, -S and --find-object are mutually exclusive"
+msgstr ""
+
+#: diff.c:4634
+msgid "--follow requires exactly one pathspec"
+msgstr ""
+
+#: diff.c:4800
+#, c-format
+msgid ""
+"Failed to parse --dirstat/-X option parameter:\n"
+"%s"
+msgstr ""
+
+#: diff.c:4814
+#, c-format
+msgid "Failed to parse --submodule option parameter: '%s'"
+msgstr ""
+
+#: diff.c:5900
+msgid "inexact rename detection was skipped due to too many files."
+msgstr ""
+
+#: diff.c:5903
+msgid "only found copies from modified paths due to too many files."
+msgstr ""
+
+#: diff.c:5906
+#, c-format
+msgid ""
+"you may want to set your %s variable to at least %d and retry the command."
+msgstr ""
+"μπορείτε να δοκιμάστε να ορίσετε τη μεταβλητή σας %s σε τουλάχιστον %d και "
+"να δοκιμάσετε πάλι την εντολή."
+
+#: dir.c:538
+#, c-format
+msgid "pathspec '%s' did not match any file(s) known to git"
+msgstr ""
+
+#: dir.c:927
+#, c-format
+msgid "cannot use %s as an exclude file"
+msgstr ""
+
+#: dir.c:1842
+#, c-format
+msgid "could not open directory '%s'"
+msgstr "δεν ήταν δυνατό το άνοιγμα του φακέλου '%s'"
+
+#: dir.c:2084
+msgid "failed to get kernel name and information"
+msgstr ""
+
+#: dir.c:2208
+msgid "untracked cache is disabled on this system or location"
+msgstr ""
+
+#: dir.c:3009
+#, c-format
+msgid "index file corrupt in repo %s"
+msgstr ""
+
+#: dir.c:3054 dir.c:3059
+#, c-format
+msgid "could not create directories for %s"
+msgstr ""
+
+#: dir.c:3088
+#, c-format
+msgid "could not migrate git directory from '%s' to '%s'"
+msgstr ""
+
+#: editor.c:73
+#, c-format
+msgid "hint: Waiting for your editor to close the file...%c"
+msgstr ""
+
+#: entry.c:178
+msgid "Filtering content"
+msgstr ""
+
+#: entry.c:465
+#, c-format
+msgid "could not stat file '%s'"
+msgstr ""
+
+#: environment.c:150
+#, c-format
+msgid "bad git namespace path \"%s\""
+msgstr ""
+
+#: environment.c:332
+#, c-format
+msgid "could not set GIT_DIR to '%s'"
+msgstr ""
+
+#: exec-cmd.c:361
+#, c-format
+msgid "too many args to run %s"
+msgstr ""
+
+#: fetch-object.c:17
+msgid "Remote with no URL"
+msgstr ""
+
+#: fetch-pack.c:151
+msgid "git fetch-pack: expected shallow list"
+msgstr ""
+
+#: fetch-pack.c:154
+msgid "git fetch-pack: expected a flush packet after shallow list"
+msgstr ""
+
+#: fetch-pack.c:165
+msgid "git fetch-pack: expected ACK/NAK, got a flush packet"
+msgstr ""
+
+#: fetch-pack.c:185
+#, c-format
+msgid "git fetch-pack: expected ACK/NAK, got '%s'"
+msgstr ""
+
+#: fetch-pack.c:256
+msgid "--stateless-rpc requires multi_ack_detailed"
+msgstr ""
+
+#: fetch-pack.c:358 fetch-pack.c:1264
+#, c-format
+msgid "invalid shallow line: %s"
+msgstr ""
+
+#: fetch-pack.c:364 fetch-pack.c:1271
+#, c-format
+msgid "invalid unshallow line: %s"
+msgstr ""
+
+#: fetch-pack.c:366 fetch-pack.c:1273
+#, c-format
+msgid "object not found: %s"
+msgstr ""
+
+#: fetch-pack.c:369 fetch-pack.c:1276
+#, c-format
+msgid "error in object: %s"
+msgstr ""
+
+#: fetch-pack.c:371 fetch-pack.c:1278
+#, c-format
+msgid "no shallow found: %s"
+msgstr ""
+
+#: fetch-pack.c:374 fetch-pack.c:1282
+#, c-format
+msgid "expected shallow/unshallow, got %s"
+msgstr ""
+
+#: fetch-pack.c:415
+#, c-format
+msgid "got %s %d %s"
+msgstr ""
+
+#: fetch-pack.c:432
+#, c-format
+msgid "invalid commit %s"
+msgstr ""
+
+#: fetch-pack.c:463
+msgid "giving up"
+msgstr "εγκατάλειψη"
+
+#: fetch-pack.c:475 progress.c:229
+msgid "done"
+msgstr "ολοκληρώθηκε"
+
+#: fetch-pack.c:487
+#, c-format
+msgid "got %s (%d) %s"
+msgstr ""
+
+#: fetch-pack.c:533
+#, c-format
+msgid "Marking %s as complete"
+msgstr ""
+
+#: fetch-pack.c:740
+#, c-format
+msgid "already have %s (%s)"
+msgstr "υπάρχει ήδη %s (%s)"
+
+#: fetch-pack.c:779
+msgid "fetch-pack: unable to fork off sideband demultiplexer"
+msgstr ""
+
+#: fetch-pack.c:787
+msgid "protocol error: bad pack header"
+msgstr ""
+
+#: fetch-pack.c:855
+#, c-format
+msgid "fetch-pack: unable to fork off %s"
+msgstr ""
+
+#: fetch-pack.c:871
+#, c-format
+msgid "%s failed"
+msgstr ""
+
+#: fetch-pack.c:873
+msgid "error in sideband demultiplexer"
+msgstr ""
+
+#: fetch-pack.c:902
+msgid "Server does not support shallow clients"
+msgstr ""
+
+#: fetch-pack.c:906
+msgid "Server supports multi_ack_detailed"
+msgstr ""
+
+#: fetch-pack.c:909
+msgid "Server supports no-done"
+msgstr ""
+
+#: fetch-pack.c:915
+msgid "Server supports multi_ack"
+msgstr ""
+
+#: fetch-pack.c:919
+msgid "Server supports side-band-64k"
+msgstr ""
+
+#: fetch-pack.c:923
+msgid "Server supports side-band"
+msgstr ""
+
+#: fetch-pack.c:927
+msgid "Server supports allow-tip-sha1-in-want"
+msgstr ""
+
+#: fetch-pack.c:931
+msgid "Server supports allow-reachable-sha1-in-want"
+msgstr ""
+
+#: fetch-pack.c:941
+msgid "Server supports ofs-delta"
+msgstr ""
+
+#: fetch-pack.c:947 fetch-pack.c:1140
+msgid "Server supports filter"
+msgstr ""
+
+#: fetch-pack.c:955
+#, c-format
+msgid "Server version is %.*s"
+msgstr ""
+
+#: fetch-pack.c:961
+msgid "Server does not support --shallow-since"
+msgstr ""
+
+#: fetch-pack.c:965
+msgid "Server does not support --shallow-exclude"
+msgstr ""
+
+#: fetch-pack.c:967
+msgid "Server does not support --deepen"
+msgstr ""
+
+#: fetch-pack.c:984
+msgid "no common commits"
+msgstr ""
+
+#: fetch-pack.c:996 fetch-pack.c:1419
+msgid "git fetch-pack: fetch failed."
+msgstr ""
+
+#: fetch-pack.c:1134
+msgid "Server does not support shallow requests"
+msgstr ""
+
+#: fetch-pack.c:1184
+#, c-format
+msgid "error reading section header '%s'"
+msgstr ""
+
+#: fetch-pack.c:1190
+#, c-format
+msgid "expected '%s', received '%s'"
+msgstr ""
+
+#: fetch-pack.c:1229
+#, c-format
+msgid "unexpected acknowledgment line: '%s'"
+msgstr ""
+
+#: fetch-pack.c:1234
+#, c-format
+msgid "error processing acks: %d"
+msgstr ""
+
+#: fetch-pack.c:1244
+msgid "expected packfile to be sent after 'ready'"
+msgstr ""
+
+#: fetch-pack.c:1246
+msgid "expected no other sections to be sent after no 'ready'"
+msgstr ""
+
+#: fetch-pack.c:1287
+#, c-format
+msgid "error processing shallow info: %d"
+msgstr ""
+
+#: fetch-pack.c:1308
+#, c-format
+msgid "expected wanted-ref, got '%s'"
+msgstr ""
+
+#: fetch-pack.c:1318
+#, c-format
+msgid "unexpected wanted-ref: '%s'"
+msgstr ""
+
+#: fetch-pack.c:1322
+#, c-format
+msgid "error processing wanted refs: %d"
+msgstr ""
+
+#: fetch-pack.c:1646
+msgid "no matching remote head"
+msgstr ""
+
+#: fetch-pack.c:1664 builtin/clone.c:671
+msgid "remote did not send all necessary objects"
+msgstr "ο απομακρυσμένος εξυπηρετητής δεν έστειλε όλα τα αναγκαία αντικείμενα"
+
+#: fetch-pack.c:1690
+#, c-format
+msgid "no such remote ref %s"
+msgstr "δεν υπάρχει τέτοιο απομακρυσμένο ref %s"
+
+#: fetch-pack.c:1693
+#, c-format
+msgid "Server does not allow request for unadvertised object %s"
+msgstr ""
+
+#: gpg-interface.c:318
+msgid "gpg failed to sign the data"
+msgstr ""
+
+#: gpg-interface.c:344
+msgid "could not create temporary file"
+msgstr ""
+
+#: gpg-interface.c:347
+#, c-format
+msgid "failed writing detached signature to '%s'"
+msgstr ""
+
+#: graph.c:97
+#, c-format
+msgid "ignore invalid color '%.*s' in log.graphColors"
+msgstr ""
+
+#: grep.c:2113
+#, c-format
+msgid "'%s': unable to read %s"
+msgstr ""
+
+#: grep.c:2130 setup.c:164 builtin/clone.c:411 builtin/diff.c:82
+#: builtin/rm.c:135
+#, c-format
+msgid "failed to stat '%s'"
+msgstr "απέτυχε το stat του '%s'"
+
+#: grep.c:2141
+#, c-format
+msgid "'%s': short read"
+msgstr ""
+
+#: help.c:23
+msgid "start a working area (see also: git help tutorial)"
+msgstr ""
+
+#: help.c:24
+msgid "work on the current change (see also: git help everyday)"
+msgstr ""
+
+#: help.c:25
+msgid "examine the history and state (see also: git help revisions)"
+msgstr ""
+
+#: help.c:26
+msgid "grow, mark and tweak your common history"
+msgstr ""
+
+#: help.c:27
+msgid "collaborate (see also: git help workflows)"
+msgstr ""
+
+#: help.c:31
+msgid "Main Porcelain Commands"
+msgstr "Κύριες Εντολές Porcelain"
+
+#: help.c:32
+msgid "Ancillary Commands / Manipulators"
+msgstr "Βοηθητικές Εντολές / Χειρισμού"
+
+#: help.c:33
+msgid "Ancillary Commands / Interrogators"
+msgstr "Βοηθητικές Εντολές / Ερωτημάτων"
+
+#: help.c:34
+msgid "Interacting with Others"
+msgstr "Διάδραση με Άλλους"
+
+#: help.c:35
+msgid "Low-level Commands / Manipulators"
+msgstr "Εντολές Χαμηλού Επιπέδου / Χειρισμού"
+
+#: help.c:36
+msgid "Low-level Commands / Interrogators"
+msgstr "Εντολές Χαμηλού Επιπέδου / Ερωτημάτων"
+
+#: help.c:37
+msgid "Low-level Commands / Synching Repositories"
+msgstr "Εντολές Χαμηλού Επιπέδου / Συγχρονισμού Αποθετηρίων"
+
+#: help.c:38
+msgid "Low-level Commands / Internal Helpers"
+msgstr "Εντολές Χαμηλού Επιπέδου / Εσωτερικές Βοηθητικές"
+
+#: help.c:298
+#, c-format
+msgid "available git commands in '%s'"
+msgstr ""
+
+#: help.c:305
+msgid "git commands available from elsewhere on your $PATH"
+msgstr "εντολές git διαθέσιμες από αλλού στο $PATH σας"
+
+#: help.c:314
+msgid "These are common Git commands used in various situations:"
+msgstr ""
+"Αυτές είναι κοινές εντολές Git που χρησιμοποιούνται σε διάφορες περιπτώσεις:"
+
+#: help.c:363 git.c:90
+#, c-format
+msgid "unsupported command listing type '%s'"
+msgstr ""
+
+#: help.c:410
+msgid "The common Git guides are:"
+msgstr ""
+
+#: help.c:519
+msgid "See 'git help <command>' to read about a specific subcommand"
+msgstr ""
+"Δείτε 'git help <εντολή>' για να διαβάσετε για κάποια συγκεκριμένη υποεντολή"
+
+#: help.c:524
+msgid "External commands"
+msgstr "Εξωτερικές εντολές"
+
+#: help.c:539
+msgid "Command aliases"
+msgstr ""
+
+#: help.c:603
+#, c-format
+msgid ""
+"'%s' appears to be a git command, but we were not\n"
+"able to execute it. Maybe git-%s is broken?"
+msgstr ""
+"'%s' φαίνεται να είναι εντολή git, αλλά δεν μπορέσαμε\n"
+"να την εκτελέσουμε. Μήπως το git-%s είναι χαλασμένο;"
+
+#: help.c:662
+msgid "Uh oh. Your system reports no Git commands at all."
+msgstr "Ώπα. Το σύστημά σας δεν αναφέρει καμία απολύτως εντολή Git."
+
+#: help.c:684
+#, c-format
+msgid "WARNING: You called a Git command named '%s', which does not exist."
+msgstr "ΠΡΟΣΟΧΗ: Καλέσατε μία εντολή Git με όνομα '%s', η οποία δεν υπάρχει."
+
+#: help.c:689
+#, c-format
+msgid "Continuing under the assumption that you meant '%s'."
+msgstr "Συνεχίζουμε υποθέτοντας πως εννοούσατε '%s'."
+
+#: help.c:694
+#, c-format
+msgid "Continuing in %0.1f seconds, assuming that you meant '%s'."
+msgstr "Συνεχίζουμε σε %0.1f δευτερόλεπτα, υποθέτοντας πως εννοούσατε '%s'."
+
+#: help.c:702
+#, c-format
+msgid "git: '%s' is not a git command. See 'git --help'."
+msgstr "git: '%s' δεν είναι εντολή git. Δείτε 'git --help'."
+
+#: help.c:706
+msgid ""
+"\n"
+"The most similar command is"
+msgid_plural ""
+"\n"
+"The most similar commands are"
+msgstr[0] ""
+"\n"
+"Η πιο παρόμοια εντολή είναι"
+msgstr[1] ""
+"\n"
+"Οι πιο παρόμοιες εντολές είναι"
+
+#: help.c:721
+msgid "git version [<options>]"
+msgstr "git version [<επιλογές>]"
+
+#: help.c:789
+#, c-format
+msgid "%s: %s - %s"
+msgstr ""
+
+#: help.c:793
+msgid ""
+"\n"
+"Did you mean this?"
+msgid_plural ""
+"\n"
+"Did you mean one of these?"
+msgstr[0] ""
+"\n"
+"Μήπως εννοούσατε αυτό;"
+msgstr[1] ""
+"\n"
+"Μήπως εννοούσατε ένα από αυτά;"
+
+#: ident.c:345
+msgid ""
+"\n"
+"*** Please tell me who you are.\n"
+"\n"
+"Run\n"
+"\n"
+"  git config --global user.email \"you@example.com\"\n"
+"  git config --global user.name \"Your Name\"\n"
+"\n"
+"to set your account's default identity.\n"
+"Omit --global to set the identity only in this repository.\n"
+"\n"
+msgstr ""
+"\n"
+"*** Παρακαλώ πείτε μου το όνομά σας.\n"
+"\n"
+"Τρέξτε\n"
+"\n"
+"  git config --global user.email \"you@example.com\"\n"
+"  git config --global user.name \"Το Όνομά Σας\"\n"
+"\n"
+"για να ορίσετε την προεπιλεγμένη ταυτότητα του λογαριασμού σας.\n"
+"Παραλείψετε το --global για να ορίσετε την ταυτότητα μόνο σε αυτό το "
+"αποθετήριο.\n"
+"\n"
+
+#: ident.c:369
+msgid "no email was given and auto-detection is disabled"
+msgstr "δε δόθηκε email και η αυτόματη ανίχνευση είναι απενεργοποιημένη"
+
+#: ident.c:374
+#, c-format
+msgid "unable to auto-detect email address (got '%s')"
+msgstr "δεν ήταν δυνατή η αυτόματη ανίχνευση διεύθυνσης email (βρέθηκε '%s')"
+
+#: ident.c:384
+msgid "no name was given and auto-detection is disabled"
+msgstr "δε δόθηκε όνομα και η αυτόματη ανίχνευση είναι απενεργοποιημένη"
+
+#: ident.c:390
+#, c-format
+msgid "unable to auto-detect name (got '%s')"
+msgstr "δεν ήταν δυνατή η αυτόματη ανίχνευση ονόματος (βρέθηκε '%s')"
+
+#: ident.c:398
+#, c-format
+msgid "empty ident name (for <%s>) not allowed"
+msgstr "δεν επιτρέπεται κενό όνομα ident (για το <%s>)"
+
+#: ident.c:404
+#, c-format
+msgid "name consists only of disallowed characters: %s"
+msgstr "το όνομα αποτελείται μόνο από μη επιτρεπτούς χαρακτήρες: %s"
+
+#: ident.c:419 builtin/commit.c:608
+#, c-format
+msgid "invalid date format: %s"
+msgstr "μη έγκυρη μορφή ημερομηνίας: %s"
+
+#: list-objects-filter-options.c:36
+msgid "multiple filter-specs cannot be combined"
+msgstr ""
+
+#: list-objects-filter-options.c:58
+msgid "expected 'tree:<depth>'"
+msgstr ""
+
+#: list-objects-filter-options.c:152
+msgid "cannot change partial clone promisor remote"
+msgstr ""
+
+#: lockfile.c:151
+#, c-format
+msgid ""
+"Unable to create '%s.lock': %s.\n"
+"\n"
+"Another git process seems to be running in this repository, e.g.\n"
+"an editor opened by 'git commit'. Please make sure all processes\n"
+"are terminated then try again. If it still fails, a git process\n"
+"may have crashed in this repository earlier:\n"
+"remove the file manually to continue."
+msgstr ""
+"Δε γίνεται να δημιουργηθεί το '%s.lock': %s.\n"
+"\n"
+"Φαίνεται πως μια άλλη διεργασία git τρέχει μέσα σε αυτό το αποθετήριο, π.χ.\n"
+"ένας διορθωτής που άνοιξε από το 'git commit'. Παρακαλώ σιγουρευτείτε πως "
+"όλες οι διεργασίες\n"
+"έχουν τερματιστεί και προσπαθήστε πάλι. Αν αποτυγχάνει ακόμα, μπορεί μια "
+"διεργασία git\n"
+"να έχει καταρρεύσει μέσα σε αυτό το αποθετήριο νωρίτερα:\n"
+"αφαιρέστε το αρχείο χειροκίνητα για να συνεχίσετε."
+
+#: lockfile.c:159
+#, c-format
+msgid "Unable to create '%s.lock': %s"
+msgstr ""
+
+#: merge.c:41
+msgid "failed to read the cache"
+msgstr ""
+
+#: merge.c:107 rerere.c:720 builtin/am.c:1884 builtin/am.c:1918
+#: builtin/checkout.c:416 builtin/checkout.c:745 builtin/clone.c:771
+msgid "unable to write new index file"
+msgstr "δεν είναι δυνατή η εγγραφή νέου αρχείου ευρετηρίου"
+
+#: merge-recursive.c:332
+msgid "(bad commit)\n"
+msgstr ""
+
+#: merge-recursive.c:355
+#, c-format
+msgid "add_cacheinfo failed for path '%s'; merge aborting."
+msgstr ""
+
+#: merge-recursive.c:364
+#, c-format
+msgid "add_cacheinfo failed to refresh for path '%s'; merge aborting."
+msgstr ""
+
+#: merge-recursive.c:447
+msgid "error building trees"
+msgstr ""
+
+#: merge-recursive.c:902
+#, c-format
+msgid "failed to create path '%s'%s"
+msgstr ""
+
+#: merge-recursive.c:913
+#, c-format
+msgid "Removing %s to make room for subdirectory\n"
+msgstr ""
+
+#: merge-recursive.c:927 merge-recursive.c:946
+msgid ": perhaps a D/F conflict?"
+msgstr ""
+
+#: merge-recursive.c:936
+#, c-format
+msgid "refusing to lose untracked file at '%s'"
+msgstr ""
+
+#: merge-recursive.c:978 builtin/cat-file.c:40
+#, c-format
+msgid "cannot read object %s '%s'"
+msgstr ""
+
+#: merge-recursive.c:980
+#, c-format
+msgid "blob expected for %s '%s'"
+msgstr "αναμενόταν blob για %s '%s'"
+
+#: merge-recursive.c:1004
+#, c-format
+msgid "failed to open '%s': %s"
+msgstr ""
+
+#: merge-recursive.c:1015
+#, c-format
+msgid "failed to symlink '%s': %s"
+msgstr ""
+
+#: merge-recursive.c:1020
+#, c-format
+msgid "do not know what to do with %06o %s '%s'"
+msgstr ""
+
+#: merge-recursive.c:1211
+#, c-format
+msgid "Failed to merge submodule %s (not checked out)"
+msgstr ""
+
+#: merge-recursive.c:1218
+#, c-format
+msgid "Failed to merge submodule %s (commits not present)"
+msgstr ""
+
+#: merge-recursive.c:1225
+#, c-format
+msgid "Failed to merge submodule %s (commits don't follow merge-base)"
+msgstr ""
+
+#: merge-recursive.c:1233 merge-recursive.c:1245
+#, c-format
+msgid "Fast-forwarding submodule %s to the following commit:"
+msgstr ""
+
+#: merge-recursive.c:1236 merge-recursive.c:1248
+#, c-format
+msgid "Fast-forwarding submodule %s"
+msgstr ""
+
+#: merge-recursive.c:1271
+#, c-format
+msgid "Failed to merge submodule %s (merge following commits not found)"
+msgstr ""
+
+#: merge-recursive.c:1275
+#, c-format
+msgid "Failed to merge submodule %s (not fast-forward)"
+msgstr ""
+
+#: merge-recursive.c:1276
+msgid "Found a possible merge resolution for the submodule:\n"
+msgstr ""
+
+#: merge-recursive.c:1279
+#, c-format
+msgid ""
+"If this is correct simply add it to the index for example\n"
+"by using:\n"
+"\n"
+"  git update-index --cacheinfo 160000 %s \"%s\"\n"
+"\n"
+"which will accept this suggestion.\n"
+msgstr ""
+
+#: merge-recursive.c:1288
+#, c-format
+msgid "Failed to merge submodule %s (multiple merges found)"
+msgstr ""
+
+#: merge-recursive.c:1361
+msgid "Failed to execute internal merge"
+msgstr ""
+
+#: merge-recursive.c:1366
+#, c-format
+msgid "Unable to add %s to database"
+msgstr ""
+
+#: merge-recursive.c:1398
+#, c-format
+msgid "Auto-merging %s"
+msgstr ""
+
+#: merge-recursive.c:1419
+#, c-format
+msgid "Error: Refusing to lose untracked file at %s; writing to %s instead."
+msgstr ""
+
+#: merge-recursive.c:1486
+#, c-format
+msgid ""
+"CONFLICT (%s/delete): %s deleted in %s and %s in %s. Version %s of %s left "
+"in tree."
+msgstr ""
+"ΣΥΓΚΡΟΥΣΗ (%s/διαγραφή): Έγινε διαγραφή του %s στο %s και %s στο %s. "
+"Διατηρήθηκε η έκδοση %s του %s στο δέντρο."
+
+#: merge-recursive.c:1491
+#, c-format
+msgid ""
+"CONFLICT (%s/delete): %s deleted in %s and %s to %s in %s. Version %s of %s "
+"left in tree."
+msgstr ""
+"ΣΥΓΚΡΟΥΣΗ (%s/διαγραφή): Έγινε διαγραφή του %s στο %s και %s στο %s στο %s. "
+"Διατηρήθηκε η έκδοση %s του %s στο δέντρο."
+
+#: merge-recursive.c:1498
+#, c-format
+msgid ""
+"CONFLICT (%s/delete): %s deleted in %s and %s in %s. Version %s of %s left "
+"in tree at %s."
+msgstr ""
+"ΣΥΓΚΡΟΥΣΗ (%s/διαγραφή): Έγινε διαγραφή του %s στο %s και %s στο %s. "
+"Διατηρήθηκε η έκδοση %s του %s στο δέντρο στο %s."
+
+#: merge-recursive.c:1503
+#, c-format
+msgid ""
+"CONFLICT (%s/delete): %s deleted in %s and %s to %s in %s. Version %s of %s "
+"left in tree at %s."
+msgstr ""
+"ΣΥΓΚΡΟΥΣΗ (%s/διαγραφή): Έγινε διαγραφή του %s στο %s και %s στο %s στο %s. "
+"Διατηρήθηκε η έκδοση %s του %s στο δέντρο στο %s."
+
+#: merge-recursive.c:1537
+msgid "rename"
+msgstr "μετονομασία"
+
+#: merge-recursive.c:1537
+msgid "renamed"
+msgstr "μετονομάστηκε"
+
+#: merge-recursive.c:1633 merge-recursive.c:2481 merge-recursive.c:3213
+#, c-format
+msgid "Refusing to lose dirty file at %s"
+msgstr ""
+
+#: merge-recursive.c:1643
+#, c-format
+msgid "Refusing to lose untracked file at %s, even though it's in the way."
+msgstr ""
+
+#: merge-recursive.c:1706
+#, c-format
+msgid "CONFLICT (rename/add): Rename %s->%s in %s.  Added %s in %s"
+msgstr ""
+"ΣΥΓΚΡΟΥΣΗ (μετονομασία/προσθήκη): Μετονομασία %s->%s στο %s.  Έγινε προσθήκη "
+"%s στο %s"
+
+#: merge-recursive.c:1734
+#, c-format
+msgid "%s is a directory in %s adding as %s instead"
+msgstr ""
+
+#: merge-recursive.c:1739
+#, c-format
+msgid "Refusing to lose untracked file at %s; adding as %s instead"
+msgstr ""
+
+#: merge-recursive.c:1759
+#, c-format
+msgid ""
+"CONFLICT (rename/rename): Rename \"%s\"->\"%s\" in branch \"%s\" rename \"%s"
+"\"->\"%s\" in \"%s\"%s"
+msgstr ""
+"ΣΥΓΚΡΟΥΣΗ (μετονομασία/μετονομασία): Μετονομασία \"%s\"->\"%s\" στον κλάδο "
+"\"%s\" μετονομασία \"%s\"->\"%s\" στον κλάδο \"%s\"%s"
+
+#: merge-recursive.c:1764
+msgid " (left unresolved)"
+msgstr " (έμεινε αταύτιστο)"
+
+#: merge-recursive.c:1868
+#, c-format
+msgid "CONFLICT (rename/rename): Rename %s->%s in %s. Rename %s->%s in %s"
+msgstr ""
+"ΣΥΓΚΡΟΥΣΗ (μετονομασία/μετονομασία): Μετονομασία %s->%s στο %s. Μετονομασία "
+"%s->%s στο %s"
+
+#: merge-recursive.c:2064
+#, c-format
+msgid ""
+"CONFLICT (directory rename split): Unclear where to place %s because "
+"directory %s was renamed to multiple other directories, with no destination "
+"getting a majority of the files."
+msgstr ""
+"ΣΥΓΚΡΟΥΣΗ (ασάφεια μετονομασίας φακέλου): Δεν είναι σαφές πού να τοποθετηθεί "
+"το %s επειδή ο φάκελος %s μετονομάστηκε σε πολλαπλούς άλλους φακέλους, και "
+"κανένας προορισμός δεν πήρε τα περισσότερα αρχεία."
+
+#: merge-recursive.c:2096
+#, c-format
+msgid ""
+"CONFLICT (implicit dir rename): Existing file/dir at %s in the way of "
+"implicit directory rename(s) putting the following path(s) there: %s."
+msgstr ""
+"ΣΥΓΚΡΟΥΣΗ (εννοούμενη μετονομασία φακέλων): Υπάρχον αρχείο/φάκελος στο %s "
+"εμποδίζει την εννοούμενη μετονομασία που θα έβαζε τις επόμενες διαδρομές "
+"εκεί: %s."
+
+#: merge-recursive.c:2106
+#, c-format
+msgid ""
+"CONFLICT (implicit dir rename): Cannot map more than one path to %s; "
+"implicit directory renames tried to put these paths there: %s"
+msgstr ""
+"ΣΥΓΚΡΟΥΣΗ (εννοούμενη μετονομασία φακέλων): Δε μπορεί να γίνει αντιστοίχιση "
+"του %s με περισσότερες από μία διαδρομές, οι εννοούμενες μετονομασίες "
+"φακέλων προσπάθησαν να βάλουν αυτές τις διαδρομές εκεί: %s"
+
+#: merge-recursive.c:2198
+#, c-format
+msgid ""
+"CONFLICT (rename/rename): Rename directory %s->%s in %s. Rename directory %s-"
+">%s in %s"
+msgstr ""
+"ΣΥΓΚΡΟΥΣΗ (μετονομασία/μετονομασία): Μετονομασία φακέλου %s->%s στο %s. "
+"Μετονομασία φακέλου %s->%s στο %s"
+
+#: merge-recursive.c:2443
+#, c-format
+msgid ""
+"WARNING: Avoiding applying %s -> %s rename to %s, because %s itself was "
+"renamed."
+msgstr ""
+
+#: merge-recursive.c:3022
+#, c-format
+msgid "cannot read object %s"
+msgstr ""
+
+#: merge-recursive.c:3025
+#, c-format
+msgid "object %s is not a blob"
+msgstr "το αντικείμενο %s δεν είναι blob"
+
+#: merge-recursive.c:3094
+msgid "modify"
+msgstr "τροποποιώ"
+
+#: merge-recursive.c:3094
+msgid "modified"
+msgstr "τροποποιημένο"
+
+#: merge-recursive.c:3105
+msgid "content"
+msgstr "περιεχόμενο"
+
+#: merge-recursive.c:3112
+msgid "add/add"
+msgstr ""
+
+#: merge-recursive.c:3160
+#, c-format
+msgid "Skipped %s (merged same as existing)"
+msgstr ""
+
+#: merge-recursive.c:3182 git-submodule.sh:861
+msgid "submodule"
+msgstr "υποενότητα"
+
+#: merge-recursive.c:3183
+#, c-format
+msgid "CONFLICT (%s): Merge conflict in %s"
+msgstr "ΣΥΓΚΡΟΥΣΗ (%s): Σύγκρουση συγχώνευσης στο %s"
+
+#: merge-recursive.c:3216
+#, c-format
+msgid "Adding as %s instead"
+msgstr ""
+
+#: merge-recursive.c:3319
+#, c-format
+msgid "Removing %s"
+msgstr "Αφαίρεση του %s"
+
+#: merge-recursive.c:3345
+msgid "file/directory"
+msgstr ""
+
+#: merge-recursive.c:3351
+msgid "directory/file"
+msgstr ""
+
+#: merge-recursive.c:3358
+#, c-format
+msgid "CONFLICT (%s): There is a directory with name %s in %s. Adding %s as %s"
+msgstr ""
+"ΣΥΓΚΡΟΥΣΗ (%s): Υπάρχει φάκελος με όνομα %s στο %s. Γίνεται προσθήκη του %s "
+"ως %s"
+
+#: merge-recursive.c:3367
+#, c-format
+msgid "Adding %s"
+msgstr ""
+
+#: merge-recursive.c:3376
+#, c-format
+msgid "CONFLICT (add/add): Merge conflict in %s"
+msgstr "ΣΥΓΚΡΟΥΣΗ (προσθήκη/προσθήκη): Σύγκρουση συγχώνευσης στο %s"
+
+#: merge-recursive.c:3417
+#, c-format
+msgid ""
+"Your local changes to the following files would be overwritten by merge:\n"
+"  %s"
+msgstr ""
+"Οι τοπικές αλλαγές σας στα ακόλουθα αρχεία θα επεγγραφόντουσαν από τη "
+"συγχώνευση:\n"
+"  %s"
+
+#: merge-recursive.c:3428
+msgid "Already up to date!"
+msgstr "Ήδη πλήρως ενήμερο!"
+
+#: merge-recursive.c:3437
+#, c-format
+msgid "merging of trees %s and %s failed"
+msgstr ""
+
+#: merge-recursive.c:3536
+msgid "Merging:"
+msgstr ""
+
+#: merge-recursive.c:3549
+#, c-format
+msgid "found %u common ancestor:"
+msgid_plural "found %u common ancestors:"
+msgstr[0] ""
+msgstr[1] ""
+
+#: merge-recursive.c:3588
+msgid "merge returned no commit"
+msgstr ""
+
+#: merge-recursive.c:3654
+#, c-format
+msgid "Could not parse object '%s'"
+msgstr ""
+
+#: merge-recursive.c:3670 builtin/merge.c:692 builtin/merge.c:850
+msgid "Unable to write index."
+msgstr ""
+
+#: midx.c:65
+#, c-format
+msgid "multi-pack-index file %s is too small"
+msgstr ""
+
+#: midx.c:81
+#, c-format
+msgid "multi-pack-index signature 0x%08x does not match signature 0x%08x"
+msgstr ""
+
+#: midx.c:86
+#, c-format
+msgid "multi-pack-index version %d not recognized"
+msgstr ""
+
+#: midx.c:91
+#, c-format
+msgid "hash version %u does not match"
+msgstr ""
+
+#: midx.c:105
+msgid "invalid chunk offset (too large)"
+msgstr ""
+
+#: midx.c:129
+msgid "terminating multi-pack-index chunk id appears earlier than expected"
+msgstr ""
+
+#: midx.c:142
+msgid "multi-pack-index missing required pack-name chunk"
+msgstr ""
+
+#: midx.c:144
+msgid "multi-pack-index missing required OID fanout chunk"
+msgstr ""
+
+#: midx.c:146
+msgid "multi-pack-index missing required OID lookup chunk"
+msgstr ""
+
+#: midx.c:148
+msgid "multi-pack-index missing required object offsets chunk"
+msgstr ""
+
+#: midx.c:162
+#, c-format
+msgid "multi-pack-index pack names out of order: '%s' before '%s'"
+msgstr ""
+
+#: midx.c:205
+#, c-format
+msgid "bad pack-int-id: %u (%u total packs)"
+msgstr ""
+
+#: midx.c:246
+msgid "multi-pack-index stores a 64-bit offset, but off_t is too small"
+msgstr ""
+
+#: midx.c:271
+msgid "error preparing packfile from multi-pack-index"
+msgstr ""
+
+#: midx.c:407
+#, c-format
+msgid "failed to add packfile '%s'"
+msgstr ""
+
+#: midx.c:413
+#, c-format
+msgid "failed to open pack-index '%s'"
+msgstr ""
+
+#: midx.c:507
+#, c-format
+msgid "failed to locate object %d in packfile"
+msgstr ""
+
+#: midx.c:943
+#, c-format
+msgid "failed to clear multi-pack-index at %s"
+msgstr ""
+
+#: midx.c:981
+#, c-format
+msgid ""
+"oid fanout out of order: fanout[%d] = %<PRIx32> > %<PRIx32> = fanout[%d]"
+msgstr ""
+
+#: midx.c:992
+#, c-format
+msgid "oid lookup out of order: oid[%d] = %s >= %s = oid[%d]"
+msgstr ""
+
+#: midx.c:996
+msgid "Verifying object offsets"
+msgstr ""
+
+#: midx.c:1004
+#, c-format
+msgid "failed to load pack entry for oid[%d] = %s"
+msgstr ""
+
+#: midx.c:1010
+#, c-format
+msgid "failed to load pack-index for packfile %s"
+msgstr ""
+
+#: midx.c:1019
+#, c-format
+msgid "incorrect object offset for oid[%d] = %s: %<PRIx64> != %<PRIx64>"
+msgstr ""
+
+#: name-hash.c:531
+#, c-format
+msgid "unable to create lazy_dir thread: %s"
+msgstr ""
+
+#: name-hash.c:553
+#, c-format
+msgid "unable to create lazy_name thread: %s"
+msgstr ""
+
+#: name-hash.c:559
+#, c-format
+msgid "unable to join lazy_name thread: %s"
+msgstr ""
+
+#: notes-merge.c:277
+#, c-format
+msgid ""
+"You have not concluded your previous notes merge (%s exists).\n"
+"Please, use 'git notes merge --commit' or 'git notes merge --abort' to "
+"commit/abort the previous merge before you start a new notes merge."
+msgstr ""
+"Δεν έχετε ολοκληρώσει την προηγούμενη συγχώνευση σημειώσεών σας (Υπάρχει το "
+"%s).\n"
+"Παρακαλώ, χρησιμοποιήστε 'git notes merge --commit' ή 'git notes merge --"
+"abort' για να υποβάλετε/εγκαταλείψετε την προηγούμενη συγχώνευση πριν "
+"ξεκινήσετε νέα συγχώνευση σημειώσεων."
+
+#: notes-merge.c:284
+#, c-format
+msgid "You have not concluded your notes merge (%s exists)."
+msgstr "Δεν έχετε ολοκληρώσει τη συγχώνευση σημειώσεών σας (Υπάρχει το %s)."
+
+#: notes-utils.c:46
+msgid "Cannot commit uninitialized/unreferenced notes tree"
+msgstr ""
+
+#: notes-utils.c:105
+#, c-format
+msgid "Bad notes.rewriteMode value: '%s'"
+msgstr ""
+
+#: notes-utils.c:115
+#, c-format
+msgid "Refusing to rewrite notes in %s (outside of refs/notes/)"
+msgstr ""
+
+#. TRANSLATORS: The first %s is the name of
+#. the environment variable, the second %s is
+#. its value.
+#.
+#: notes-utils.c:145
+#, c-format
+msgid "Bad %s value: '%s'"
+msgstr ""
+
+#: object.c:54
+#, c-format
+msgid "invalid object type \"%s\""
+msgstr ""
+
+#: object.c:174
+#, c-format
+msgid "object %s is a %s, not a %s"
+msgstr ""
+
+#: object.c:234
+#, c-format
+msgid "object %s has unknown type id %d"
+msgstr ""
+
+#: object.c:247
+#, c-format
+msgid "unable to parse object: %s"
+msgstr ""
+
+#: object.c:267 object.c:278
+#, c-format
+msgid "hash mismatch %s"
+msgstr ""
+
+#: packfile.c:607
+msgid "offset before end of packfile (broken .idx?)"
+msgstr ""
+
+#: packfile.c:1870
+#, c-format
+msgid "offset before start of pack index for %s (corrupt index?)"
+msgstr ""
+
+#: packfile.c:1874
+#, c-format
+msgid "offset beyond end of pack index for %s (truncated index?)"
+msgstr ""
+
+#: parse-options.c:35
+#, c-format
+msgid "%s requires a value"
+msgstr ""
+
+#: parse-options.c:69
+#, c-format
+msgid "%s is incompatible with %s"
+msgstr ""
+
+#: parse-options.c:74
+#, c-format
+msgid "%s : incompatible with something else"
+msgstr ""
+
+#: parse-options.c:88 parse-options.c:92 parse-options.c:260
+#, c-format
+msgid "%s takes no value"
+msgstr ""
+
+#: parse-options.c:90
+#, c-format
+msgid "%s isn't available"
+msgstr ""
+
+#: parse-options.c:178
+#, c-format
+msgid "%s expects a numerical value"
+msgstr ""
+
+#: parse-options.c:194
+#, c-format
+msgid "%s expects a non-negative integer value with an optional k/m/g suffix"
+msgstr ""
+
+#: parse-options.c:322
+#, c-format
+msgid "ambiguous option: %s (could be --%s%s or --%s%s)"
+msgstr "αμφίσημη επιλογή: %s (θα μπορούσε να είναι --%s%s ή --%s%s)"
+
+#: parse-options.c:356 parse-options.c:364
+#, c-format
+msgid "did you mean `--%s` (with two dashes ?)"
+msgstr ""
+
+#: parse-options.c:649
+#, c-format
+msgid "unknown option `%s'"
+msgstr "άγνωστη επιλογή `%s'"
+
+#: parse-options.c:651
+#, c-format
+msgid "unknown switch `%c'"
+msgstr ""
+
+#: parse-options.c:653
+#, c-format
+msgid "unknown non-ascii option in string: `%s'"
+msgstr ""
+
+#: parse-options.c:675
+msgid "..."
+msgstr "..."
+
+#: parse-options.c:694
+#, c-format
+msgid "usage: %s"
+msgstr "χρήση: %s"
+
+#. TRANSLATORS: the colon here should align with the
+#. one in "usage: %s" translation.
+#.
+#: parse-options.c:700
+#, c-format
+msgid "   or: %s"
+msgstr "   ή: %s"
+
+#: parse-options.c:703
+#, c-format
+msgid "    %s"
+msgstr ""
+
+#: parse-options.c:742
+msgid "-NUM"
+msgstr "-ΑΡΙΘ"
+
+#: parse-options-cb.c:21
+#, c-format
+msgid "option `%s' expects a numerical value"
+msgstr ""
+
+#: parse-options-cb.c:38
+#, c-format
+msgid "malformed expiration date '%s'"
+msgstr ""
+
+#: parse-options-cb.c:51
+#, c-format
+msgid "option `%s' expects \"always\", \"auto\", or \"never\""
+msgstr ""
+
+#: parse-options-cb.c:110
+#, c-format
+msgid "malformed object name '%s'"
+msgstr ""
+
+#: path.c:894
+#, c-format
+msgid "Could not make %s writable by group"
+msgstr ""
+
+#: pathspec.c:128
+msgid "Escape character '\\' not allowed as last character in attr value"
+msgstr ""
+
+#: pathspec.c:146
+msgid "Only one 'attr:' specification is allowed."
+msgstr ""
+
+#: pathspec.c:149
+msgid "attr spec must not be empty"
+msgstr ""
+
+#: pathspec.c:192
+#, c-format
+msgid "invalid attribute name %s"
+msgstr ""
+
+#: pathspec.c:257
+msgid "global 'glob' and 'noglob' pathspec settings are incompatible"
+msgstr ""
+
+#: pathspec.c:264
+msgid ""
+"global 'literal' pathspec setting is incompatible with all other global "
+"pathspec settings"
+msgstr ""
+
+#: pathspec.c:304
+msgid "invalid parameter for pathspec magic 'prefix'"
+msgstr ""
+
+#: pathspec.c:325
+#, c-format
+msgid "Invalid pathspec magic '%.*s' in '%s'"
+msgstr ""
+
+#: pathspec.c:330
+#, c-format
+msgid "Missing ')' at the end of pathspec magic in '%s'"
+msgstr ""
+
+#: pathspec.c:368
+#, c-format
+msgid "Unimplemented pathspec magic '%c' in '%s'"
+msgstr ""
+
+#: pathspec.c:427
+#, c-format
+msgid "%s: 'literal' and 'glob' are incompatible"
+msgstr ""
+
+#: pathspec.c:440
+#, c-format
+msgid "%s: '%s' is outside repository"
+msgstr ""
+
+#: pathspec.c:514
+#, c-format
+msgid "'%s' (mnemonic: '%c')"
+msgstr ""
+
+#: pathspec.c:524
+#, c-format
+msgid "%s: pathspec magic not supported by this command: %s"
+msgstr ""
+"%s: το magic της περιγραφής διαδρομής δεν υποστηρίζεται από την εντολή: %s"
+
+#: pathspec.c:591
+#, c-format
+msgid "pathspec '%s' is beyond a symbolic link"
+msgstr "η περιγραφή διαδρομής '%s' είναι πίσω από συμβολικό δεσμό"
+
+#: pkt-line.c:104
+msgid "flush packet write failed"
+msgstr ""
+
+#: pkt-line.c:144 pkt-line.c:230
+msgid "protocol error: impossibly long line"
+msgstr ""
+
+#: pkt-line.c:160 pkt-line.c:162
+msgid "packet write with format failed"
+msgstr ""
+
+#: pkt-line.c:194
+msgid "packet write failed - data exceeds max packet size"
+msgstr ""
+
+#: pkt-line.c:201 pkt-line.c:208
+msgid "packet write failed"
+msgstr ""
+
+#: pkt-line.c:293
+msgid "read error"
+msgstr ""
+
+#: pkt-line.c:301
+msgid "the remote end hung up unexpectedly"
+msgstr ""
+
+#: pkt-line.c:329
+#, c-format
+msgid "protocol error: bad line length character: %.4s"
+msgstr ""
+
+#: pkt-line.c:339 pkt-line.c:344
+#, c-format
+msgid "protocol error: bad line length %d"
+msgstr ""
+
+#: pkt-line.c:353
+#, c-format
+msgid "remote error: %s"
+msgstr ""
+
+#: preload-index.c:119
+msgid "Refreshing index"
+msgstr ""
+
+#: preload-index.c:138
+#, c-format
+msgid "unable to create threaded lstat: %s"
+msgstr ""
+
+#: pretty.c:963
+msgid "unable to parse --pretty format"
+msgstr ""
+
+#: range-diff.c:56
+msgid "could not start `log`"
+msgstr ""
+
+#: range-diff.c:59
+msgid "could not read `log` output"
+msgstr ""
+
+#: range-diff.c:74 sequencer.c:4828
+#, c-format
+msgid "could not parse commit '%s'"
+msgstr ""
+
+#: range-diff.c:224
+msgid "failed to generate diff"
+msgstr ""
+
+#: range-diff.c:455 range-diff.c:457
+#, c-format
+msgid "could not parse log for '%s'"
+msgstr ""
+
+#: read-cache.c:673
+#, c-format
+msgid "will not add file alias '%s' ('%s' already exists in index)"
+msgstr ""
+
+#: read-cache.c:689
+msgid "cannot create an empty blob in the object database"
+msgstr ""
+"δεν είναι δυνατή η δημιουργία κενού blob στη βάση δεδομένων αντικειμένων"
+
+#: read-cache.c:710
+#, c-format
+msgid "%s: can only add regular files, symbolic links or git-directories"
+msgstr ""
+
+#: read-cache.c:765
+#, c-format
+msgid "unable to index file '%s'"
+msgstr ""
+
+#: read-cache.c:784
+#, c-format
+msgid "unable to add '%s' to index"
+msgstr ""
+
+#: read-cache.c:795
+#, c-format
+msgid "unable to stat '%s'"
+msgstr ""
+
+#: read-cache.c:1304
+#, c-format
+msgid "'%s' appears as both a file and as a directory"
+msgstr ""
+
+#: read-cache.c:1489
+msgid "Refresh index"
+msgstr ""
+
+#: read-cache.c:1603
+#, c-format
+msgid ""
+"index.version set, but the value is invalid.\n"
+"Using version %i"
+msgstr ""
+
+#: read-cache.c:1613
+#, c-format
+msgid ""
+"GIT_INDEX_VERSION set, but the value is invalid.\n"
+"Using version %i"
+msgstr ""
+
+#: read-cache.c:1684
+#, c-format
+msgid "bad signature 0x%08x"
+msgstr ""
+
+#: read-cache.c:1687
+#, c-format
+msgid "bad index version %d"
+msgstr ""
+
+#: read-cache.c:1696
+msgid "bad index file sha1 signature"
+msgstr ""
+
+#: read-cache.c:1726
+#, c-format
+msgid "index uses %.4s extension, which we do not understand"
+msgstr ""
+
+#: read-cache.c:1728
+#, c-format
+msgid "ignoring %.4s extension"
+msgstr ""
+
+#: read-cache.c:1765
+#, c-format
+msgid "unknown index entry format 0x%08x"
+msgstr ""
+
+#: read-cache.c:1781
+#, c-format
+msgid "malformed name field in the index, near path '%s'"
+msgstr ""
+
+#: read-cache.c:1836
+msgid "unordered stage entries in index"
+msgstr ""
+
+#: read-cache.c:1839
+#, c-format
+msgid "multiple stage entries for merged file '%s'"
+msgstr ""
+
+#: read-cache.c:1842
+#, c-format
+msgid "unordered stage entries for '%s'"
+msgstr ""
+
+#: read-cache.c:1949 read-cache.c:2227 rerere.c:565 rerere.c:599 rerere.c:1111
+#: builtin/add.c:459 builtin/check-ignore.c:178 builtin/checkout.c:294
+#: builtin/checkout.c:622 builtin/checkout.c:991 builtin/clean.c:955
+#: builtin/commit.c:344 builtin/diff-tree.c:116 builtin/grep.c:498
+#: builtin/mv.c:145 builtin/reset.c:245 builtin/rm.c:271
+#: builtin/submodule--helper.c:330
+msgid "index file corrupt"
+msgstr "το αρχείο ευρετηρίου είναι κατεστραμμένο"
+
+#: read-cache.c:2090
+#, c-format
+msgid "unable to create load_cache_entries thread: %s"
+msgstr ""
+
+#: read-cache.c:2103
+#, c-format
+msgid "unable to join load_cache_entries thread: %s"
+msgstr ""
+
+#: read-cache.c:2136
+#, c-format
+msgid "%s: index file open failed"
+msgstr ""
+
+#: read-cache.c:2140
+#, c-format
+msgid "%s: cannot stat the open index"
+msgstr ""
+
+#: read-cache.c:2144
+#, c-format
+msgid "%s: index file smaller than expected"
+msgstr ""
+
+#: read-cache.c:2148
+#, c-format
+msgid "%s: unable to map index file"
+msgstr ""
+
+#: read-cache.c:2190
+#, c-format
+msgid "unable to create load_index_extensions thread: %s"
+msgstr ""
+
+#: read-cache.c:2217
+#, c-format
+msgid "unable to join load_index_extensions thread: %s"
+msgstr ""
+
+#: read-cache.c:2239
+#, c-format
+msgid "could not freshen shared index '%s'"
+msgstr ""
+
+#: read-cache.c:2274
+#, c-format
+msgid "broken index, expect %s in %s, got %s"
+msgstr ""
+
+#: read-cache.c:2971 sequencer.c:4791 wrapper.c:658 builtin/merge.c:1087
+#, c-format
+msgid "could not close '%s'"
+msgstr ""
+
+#: read-cache.c:3044 sequencer.c:2237 sequencer.c:3647
+#, c-format
+msgid "could not stat '%s'"
+msgstr ""
+
+#: read-cache.c:3057
+#, c-format
+msgid "unable to open git dir: %s"
+msgstr ""
+
+#: read-cache.c:3069
+#, c-format
+msgid "unable to unlink: %s"
+msgstr ""
+
+#: read-cache.c:3088
+#, c-format
+msgid "cannot fix permission bits on '%s'"
+msgstr ""
+
+#: read-cache.c:3237
+#, c-format
+msgid "%s: cannot drop to stage #0"
+msgstr ""
+
+#: rebase-interactive.c:10
+msgid ""
+"\n"
+"Commands:\n"
+"p, pick <commit> = use commit\n"
+"r, reword <commit> = use commit, but edit the commit message\n"
+"e, edit <commit> = use commit, but stop for amending\n"
+"s, squash <commit> = use commit, but meld into previous commit\n"
+"f, fixup <commit> = like \"squash\", but discard this commit's log message\n"
+"x, exec <command> = run command (the rest of the line) using shell\n"
+"b, break = stop here (continue rebase later with 'git rebase --continue')\n"
+"d, drop <commit> = remove commit\n"
+"l, label <label> = label current HEAD with a name\n"
+"t, reset <label> = reset HEAD to a label\n"
+"m, merge [-C <commit> | -c <commit>] <label> [# <oneline>]\n"
+".       create a merge commit using the original merge commit's\n"
+".       message (or the oneline, if no original merge commit was\n"
+".       specified). Use -c <commit> to reword the commit message.\n"
+"\n"
+"These lines can be re-ordered; they are executed from top to bottom.\n"
+msgstr ""
+
+#: rebase-interactive.c:31 git-rebase--preserve-merges.sh:173
+msgid ""
+"\n"
+"Do not remove any line. Use 'drop' explicitly to remove a commit.\n"
+msgstr ""
+
+#: rebase-interactive.c:34 git-rebase--preserve-merges.sh:177
+msgid ""
+"\n"
+"If you remove a line here THAT COMMIT WILL BE LOST.\n"
+msgstr ""
+
+#: rebase-interactive.c:40 git-rebase--preserve-merges.sh:816
+msgid ""
+"\n"
+"You are editing the todo file of an ongoing interactive rebase.\n"
+"To continue rebase after editing, run:\n"
+"    git rebase --continue\n"
+"\n"
+msgstr ""
+
+#: rebase-interactive.c:45 git-rebase--preserve-merges.sh:893
+msgid ""
+"\n"
+"However, if you remove everything, the rebase will be aborted.\n"
+"\n"
+msgstr ""
+
+#: rebase-interactive.c:51 git-rebase--preserve-merges.sh:900
+msgid "Note that empty commits are commented out"
+msgstr ""
+
+#: rebase-interactive.c:62 rebase-interactive.c:75 sequencer.c:2219
+#: sequencer.c:4569 sequencer.c:4625 sequencer.c:4900
+#, c-format
+msgid "could not read '%s'."
+msgstr ""
+
+#: refs.c:192
+#, c-format
+msgid "%s does not point to a valid object!"
+msgstr ""
+
+#: refs.c:583
+#, c-format
+msgid "ignoring dangling symref %s"
+msgstr ""
+
+#: refs.c:585 ref-filter.c:1976
+#, c-format
+msgid "ignoring broken ref %s"
+msgstr ""
+
+#: refs.c:711
+#, c-format
+msgid "could not open '%s' for writing: %s"
+msgstr "δεν ήταν δυνατό το άνοιγμα του '%s' για εγγραφή: %s"
+
+#: refs.c:721 refs.c:772
+#, c-format
+msgid "could not read ref '%s'"
+msgstr ""
+
+#: refs.c:727
+#, c-format
+msgid "ref '%s' already exists"
+msgstr ""
+
+#: refs.c:732
+#, c-format
+msgid "unexpected object ID when writing '%s'"
+msgstr ""
+
+#: refs.c:740 sequencer.c:396 sequencer.c:2549 sequencer.c:2675
+#: sequencer.c:2689 sequencer.c:2923 sequencer.c:4789 sequencer.c:4852
+#: wrapper.c:656
+#, c-format
+msgid "could not write to '%s'"
+msgstr ""
+
+#: refs.c:767 sequencer.c:4787 sequencer.c:4846 wrapper.c:225 wrapper.c:395
+#: builtin/am.c:713 builtin/rebase.c:575
+#, c-format
+msgid "could not open '%s' for writing"
+msgstr "δεν ήταν δυνατό το άνοιγμα του '%s' για εγγραφή"
+
+#: refs.c:774
+#, c-format
+msgid "unexpected object ID when deleting '%s'"
+msgstr ""
+
+#: refs.c:905
+#, c-format
+msgid "log for ref %s has gap after %s"
+msgstr ""
+
+#: refs.c:911
+#, c-format
+msgid "log for ref %s unexpectedly ended on %s"
+msgstr ""
+
+#: refs.c:969
+#, c-format
+msgid "log for %s is empty"
+msgstr ""
+
+#: refs.c:1061
+#, c-format
+msgid "refusing to update ref with bad name '%s'"
+msgstr ""
+
+#: refs.c:1137
+#, c-format
+msgid "update_ref failed for ref '%s': %s"
+msgstr ""
+
+#: refs.c:1911
+#, c-format
+msgid "multiple updates for ref '%s' not allowed"
+msgstr ""
+
+#: refs.c:1943
+msgid "ref updates forbidden inside quarantine environment"
+msgstr ""
+
+#: refs.c:2039 refs.c:2069
+#, c-format
+msgid "'%s' exists; cannot create '%s'"
+msgstr ""
+
+#: refs.c:2045 refs.c:2080
+#, c-format
+msgid "cannot process '%s' and '%s' at the same time"
+msgstr ""
+
+#: refs/files-backend.c:1228
+#, c-format
+msgid "could not remove reference %s"
+msgstr ""
+
+#: refs/files-backend.c:1242 refs/packed-backend.c:1532
+#: refs/packed-backend.c:1542
+#, c-format
+msgid "could not delete reference %s: %s"
+msgstr ""
+
+#: refs/files-backend.c:1245 refs/packed-backend.c:1545
+#, c-format
+msgid "could not delete references: %s"
+msgstr ""
+
+#: refspec.c:137
+#, c-format
+msgid "invalid refspec '%s'"
+msgstr ""
+
+#: ref-filter.c:39 wt-status.c:1861
+msgid "gone"
+msgstr "δεν υπάρχει πια"
+
+#: ref-filter.c:40
+#, c-format
+msgid "ahead %d"
+msgstr ""
+
+#: ref-filter.c:41
+#, c-format
+msgid "behind %d"
+msgstr ""
+
+#: ref-filter.c:42
+#, c-format
+msgid "ahead %d, behind %d"
+msgstr ""
+
+#: ref-filter.c:138
+#, c-format
+msgid "expected format: %%(color:<color>)"
+msgstr ""
+
+#: ref-filter.c:140
+#, c-format
+msgid "unrecognized color: %%(color:%s)"
+msgstr ""
+
+#: ref-filter.c:162
+#, c-format
+msgid "Integer value expected refname:lstrip=%s"
+msgstr ""
+
+#: ref-filter.c:166
+#, c-format
+msgid "Integer value expected refname:rstrip=%s"
+msgstr ""
+
+#: ref-filter.c:168
+#, c-format
+msgid "unrecognized %%(%s) argument: %s"
+msgstr ""
+
+#: ref-filter.c:223
+#, c-format
+msgid "%%(objecttype) does not take arguments"
+msgstr ""
+
+#: ref-filter.c:245
+#, c-format
+msgid "unrecognized %%(objectsize) argument: %s"
+msgstr ""
+
+#: ref-filter.c:253
+#, c-format
+msgid "%%(deltabase) does not take arguments"
+msgstr ""
+
+#: ref-filter.c:265
+#, c-format
+msgid "%%(body) does not take arguments"
+msgstr ""
+
+#: ref-filter.c:274
+#, c-format
+msgid "%%(subject) does not take arguments"
+msgstr ""
+
+#: ref-filter.c:296
+#, c-format
+msgid "unknown %%(trailers) argument: %s"
+msgstr ""
+
+#: ref-filter.c:325
+#, c-format
+msgid "positive value expected contents:lines=%s"
+msgstr ""
+
+#: ref-filter.c:327
+#, c-format
+msgid "unrecognized %%(contents) argument: %s"
+msgstr ""
+
+#: ref-filter.c:342
+#, c-format
+msgid "positive value expected objectname:short=%s"
+msgstr ""
+
+#: ref-filter.c:346
+#, c-format
+msgid "unrecognized %%(objectname) argument: %s"
+msgstr ""
+
+#: ref-filter.c:376
+#, c-format
+msgid "expected format: %%(align:<width>,<position>)"
+msgstr ""
+
+#: ref-filter.c:388
+#, c-format
+msgid "unrecognized position:%s"
+msgstr ""
+
+#: ref-filter.c:395
+#, c-format
+msgid "unrecognized width:%s"
+msgstr ""
+
+#: ref-filter.c:404
+#, c-format
+msgid "unrecognized %%(align) argument: %s"
+msgstr ""
+
+#: ref-filter.c:412
+#, c-format
+msgid "positive width expected with the %%(align) atom"
+msgstr ""
+
+#: ref-filter.c:430
+#, c-format
+msgid "unrecognized %%(if) argument: %s"
+msgstr ""
+
+#: ref-filter.c:527
+#, c-format
+msgid "malformed field name: %.*s"
+msgstr ""
+
+#: ref-filter.c:554
+#, c-format
+msgid "unknown field name: %.*s"
+msgstr ""
+
+#: ref-filter.c:558
+#, c-format
+msgid ""
+"not a git repository, but the field '%.*s' requires access to object data"
+msgstr ""
+"δεν είναι αποθετήριο git, αλλά το πεδίο '%.*s' χρειάζεται πρόσβαση στα "
+"δεδομένα αντικειμένων"
+
+#: ref-filter.c:682
+#, c-format
+msgid "format: %%(if) atom used without a %%(then) atom"
+msgstr ""
+
+#: ref-filter.c:745
+#, c-format
+msgid "format: %%(then) atom used without an %%(if) atom"
+msgstr ""
+
+#: ref-filter.c:747
+#, c-format
+msgid "format: %%(then) atom used more than once"
+msgstr ""
+
+#: ref-filter.c:749
+#, c-format
+msgid "format: %%(then) atom used after %%(else)"
+msgstr ""
+
+#: ref-filter.c:777
+#, c-format
+msgid "format: %%(else) atom used without an %%(if) atom"
+msgstr ""
+
+#: ref-filter.c:779
+#, c-format
+msgid "format: %%(else) atom used without a %%(then) atom"
+msgstr ""
+
+#: ref-filter.c:781
+#, c-format
+msgid "format: %%(else) atom used more than once"
+msgstr ""
+
+#: ref-filter.c:796
+#, c-format
+msgid "format: %%(end) atom used without corresponding atom"
+msgstr ""
+
+#: ref-filter.c:853
+#, c-format
+msgid "malformed format string %s"
+msgstr ""
+
+#: ref-filter.c:1447
+#, c-format
+msgid "(no branch, rebasing %s)"
+msgstr "(κανένας κλάδος, γίνεται rebase του %s)"
+
+#: ref-filter.c:1450
+#, c-format
+msgid "(no branch, rebasing detached HEAD %s)"
+msgstr "(κανένας κλάδος, γίνεται rebase του αποσυνδεδεμένου HEAD %s)"
+
+#: ref-filter.c:1453
+#, c-format
+msgid "(no branch, bisect started on %s)"
+msgstr "(κανένας κλάδος, η διχοτόμηση άρχισε στο %s)"
+
+#. TRANSLATORS: make sure this matches "HEAD
+#. detached at " in wt-status.c
+#.
+#: ref-filter.c:1461
+#, c-format
+msgid "(HEAD detached at %s)"
+msgstr ""
+
+#. TRANSLATORS: make sure this matches "HEAD
+#. detached from " in wt-status.c
+#.
+#: ref-filter.c:1468
+#, c-format
+msgid "(HEAD detached from %s)"
+msgstr ""
+
+#: ref-filter.c:1472
+msgid "(no branch)"
+msgstr "(κανένας κλάδος)"
+
+#: ref-filter.c:1506 ref-filter.c:1663
+#, c-format
+msgid "missing object %s for %s"
+msgstr ""
+
+#: ref-filter.c:1516
+#, c-format
+msgid "parse_object_buffer failed on %s for %s"
+msgstr ""
+
+#: ref-filter.c:1882
+#, c-format
+msgid "malformed object at '%s'"
+msgstr ""
+
+#: ref-filter.c:1971
+#, c-format
+msgid "ignoring ref with broken name %s"
+msgstr ""
+
+#: ref-filter.c:2257
+#, c-format
+msgid "format: %%(end) atom missing"
+msgstr ""
+
+#: ref-filter.c:2352
+#, c-format
+msgid "option `%s' is incompatible with --merged"
+msgstr ""
+
+#: ref-filter.c:2355
+#, c-format
+msgid "option `%s' is incompatible with --no-merged"
+msgstr ""
+
+#: ref-filter.c:2365
+#, c-format
+msgid "malformed object name %s"
+msgstr ""
+
+#: ref-filter.c:2370
+#, c-format
+msgid "option `%s' must point to a commit"
+msgstr ""
+
+#: remote.c:363
+#, c-format
+msgid "config remote shorthand cannot begin with '/': %s"
+msgstr ""
+"η συντομογραφία ρύθμισης απομακρυσμένου δε γίνεται να ξεκινά με '/': %s"
+
+#: remote.c:410
+msgid "more than one receivepack given, using the first"
+msgstr "δόθηκαν περισσότερα από ένα receivepack, γίνεται χρήση του πρώτου"
+
+#: remote.c:418
+msgid "more than one uploadpack given, using the first"
+msgstr "δόθηκαν περισσότερα από ένα uploadpack, γίνεται χρήση του πρώτου"
+
+#: remote.c:608
+#, c-format
+msgid "Cannot fetch both %s and %s to %s"
+msgstr "Δεν είναι δυνατή η ανάκτηση του %s και του %s ταυτόχρονα στο %s"
+
+#: remote.c:612
+#, c-format
+msgid "%s usually tracks %s, not %s"
+msgstr "το %s συνήθως παρακολουθεί το %s, όχι το %s"
+
+#: remote.c:616
+#, c-format
+msgid "%s tracks both %s and %s"
+msgstr "το %s παρακολουθεί ταυτόχρονα το %s και το %s"
+
+#: remote.c:684
+#, c-format
+msgid "key '%s' of pattern had no '*'"
+msgstr "το κλειδί '%s' του μοτίβου δεν είχε '*'"
+
+#: remote.c:694
+#, c-format
+msgid "value '%s' of pattern has no '*'"
+msgstr "η τιμή '%s' του μοτίβου δεν έχει '*'"
+
+#: remote.c:1000
+#, c-format
+msgid "src refspec %s does not match any"
+msgstr "το refspec πηγής %s δεν ταιριάζει με κανένα"
+
+#: remote.c:1005
+#, c-format
+msgid "src refspec %s matches more than one"
+msgstr "το refspec πηγής %s ταιριάζει με περισσότερα από ένα"
+
+#. TRANSLATORS: "matches '%s'%" is the <dst> part of "git push
+#. <remote> <src>:<dst>" push, and "being pushed ('%s')" is
+#. the <src>.
+#.
+#: remote.c:1020
+#, c-format
+msgid ""
+"The destination you provided is not a full refname (i.e.,\n"
+"starting with \"refs/\"). We tried to guess what you meant by:\n"
+"\n"
+"- Looking for a ref that matches '%s' on the remote side.\n"
+"- Checking if the <src> being pushed ('%s')\n"
+"  is a ref in \"refs/{heads,tags}/\". If so we add a corresponding\n"
+"  refs/{heads,tags}/ prefix on the remote side.\n"
+"\n"
+"Neither worked, so we gave up. You must fully qualify the ref."
+msgstr ""
+"Ο προορισμός που εισαγάγατε δεν είναι πλήρες refname (δηλ.\n"
+"που να αρχίζει με \"refs/\"). Προσπαθήσαμε να μαντέψουμε τι εννοείτε:\n"
+"\n"
+"- Ψάχνοντας για ref που να ταιριάζει με το '%s' στην απομακρυσμένη πλευρά.\n"
+"- Κάνοντας έλεγχο εάν η <πηγή> που δημοσιεύεται ('%s')\n"
+"  είναι ref μέσα σε \"refs/{heads,tags}/\". Αν είναι, προσθέτουμε το "
+"αντίστοιχο\n"
+"  πρόθεμα refs/{heads,tags}/ στην απομακρυσμένη πλευρά.\n"
+"\n"
+"Κανένα από τα δύο δε δούλεψε, οπότε εγκαταλείψαμε. Πρέπει να εισάγετε "
+"ολογράφως το ref."
+
+#: remote.c:1040
+#, c-format
+msgid ""
+"The <src> part of the refspec is a commit object.\n"
+"Did you mean to create a new branch by pushing to\n"
+"'%s:refs/heads/%s'?"
+msgstr ""
+"Το σκέλος <πηγή> του refspec είναι αντικείμενο υποβολής.\n"
+"Θέλατε να δημιουργήσετε νέο κλάδο δημοσιεύοντας στο\n"
+"'%s:refs/tags/%s';"
+
+#: remote.c:1045
+#, c-format
+msgid ""
+"The <src> part of the refspec is a tag object.\n"
+"Did you mean to create a new tag by pushing to\n"
+"'%s:refs/tags/%s'?"
+msgstr ""
+"Το σκέλος <πηγή> του refspec είναι αντικείμενο ετικέτας.\n"
+"Θέλατε να δημιουργήσετε νέα ετικέτα δημοσιεύοντας στο\n"
+"'%s:refs/tags/%s';"
+
+#: remote.c:1050
+#, c-format
+msgid ""
+"The <src> part of the refspec is a tree object.\n"
+"Did you mean to tag a new tree by pushing to\n"
+"'%s:refs/tags/%s'?"
+msgstr ""
+"Το σκέλος <πηγή> του refspec είναι αντικείμενο δέντρου.\n"
+"Θέλατε να βάλετε ετικέτα σε νέο δέντρο δημοσιεύοντας στο\n"
+"'%s:refs/tags/%s';"
+
+#: remote.c:1055
+#, c-format
+msgid ""
+"The <src> part of the refspec is a blob object.\n"
+"Did you mean to tag a new blob by pushing to\n"
+"'%s:refs/tags/%s'?"
+msgstr ""
+"Το σκέλος <πηγή> του refspec είναι αντικείμενο blob.\n"
+"Θέλατε να βάλετε ετικέτα σε νέο blob δημοσιεύοντας στο\n"
+"'%s:refs/tags/%s';"
+
+#: remote.c:1091
+#, c-format
+msgid "%s cannot be resolved to branch"
+msgstr "δε μπορεί να γίνει ταύτιση του %s με κλάδο"
+
+#: remote.c:1102
+#, c-format
+msgid "unable to delete '%s': remote ref does not exist"
+msgstr "δε μπορεί να γίνει διαγραφή του '%s': το απομακρυσμένο ref δεν υπάρχει"
+
+#: remote.c:1114
+#, c-format
+msgid "dst refspec %s matches more than one"
+msgstr "το refspec προορισμού %s ταιριάζει με περισσότερα από ένα"
+
+#: remote.c:1121
+#, c-format
+msgid "dst ref %s receives from more than one src"
+msgstr "το ref προορισμού %s λαμβάνει από περισσότερες από μία πηγές"
+
+#: remote.c:1624 remote.c:1725
+msgid "HEAD does not point to a branch"
+msgstr "Το HEAD δε δείχνει σε κάποιον κλάδο"
+
+#: remote.c:1633
+#, c-format
+msgid "no such branch: '%s'"
+msgstr "δεν υπάρχει ο κλάδος: '%s'"
+
+#: remote.c:1636
+#, c-format
+msgid "no upstream configured for branch '%s'"
+msgstr "δεν έχει ρυθμιστεί προς τα πάνω για τον κλάδο '%s'"
+
+#: remote.c:1642
+#, c-format
+msgid "upstream branch '%s' not stored as a remote-tracking branch"
+msgstr ""
+"ο προς τα πάνω κλάδος '%s' δεν αποθηκεύεται ως κλάδος παρακολούθησης "
+"απομακρυσμένου"
+
+#: remote.c:1657
+#, c-format
+msgid "push destination '%s' on remote '%s' has no local tracking branch"
+msgstr ""
+"ο προορισμός δημοσίευσης '%s' στον απομακρυσμένο εξυπηρετητή '%s' δεν έχει "
+"τοπικό κλάδο παρακολούθησης"
+
+#: remote.c:1669
+#, c-format
+msgid "branch '%s' has no remote for pushing"
+msgstr "ο κλάδος '%s' δεν έχει απομακρυσμένο για δημοσίευση"
+
+#: remote.c:1679
+#, c-format
+msgid "push refspecs for '%s' do not include '%s'"
+msgstr "τα refspec δημοσίευσης για το '%s' δεν περιλαμβάνουν το '%s'"
+
+#: remote.c:1692
+msgid "push has no destination (push.default is 'nothing')"
+msgstr ""
+"η δημοσίευση δεν έχει προορισμό (το push.default είναι το τίποτα: 'nothing')"
+
+#: remote.c:1714
+msgid "cannot resolve 'simple' push to a single destination"
+msgstr "δε μπορεί να γίνει ταύτιση 'simple' δημοσίευσης σε έναν μόνο προορισμό"
+
+#: remote.c:1840
+#, c-format
+msgid "couldn't find remote ref %s"
+msgstr "δεν ήταν δυνατή η εύρεση του απομακρυσμένου ref %s"
+
+#: remote.c:1853
+#, c-format
+msgid "* Ignoring funny ref '%s' locally"
+msgstr "* Γίνεται παράβλεψη του παράξενου ref '%s' τοπικά"
+
+#: remote.c:1990
+#, c-format
+msgid "Your branch is based on '%s', but the upstream is gone.\n"
+msgstr ""
+"Ο κλάδος σας βασίζεται πάνω στο '%s', αλλά το προς τα πάνω δεν υπάρχει πια.\n"
+
+#: remote.c:1994
+msgid "  (use \"git branch --unset-upstream\" to fixup)\n"
+msgstr ""
+"  (χρησιμοποιήστε \"git branch --unset-upstream\" για να επιδιορθώσετε)\n"
+
+#: remote.c:1997
+#, c-format
+msgid "Your branch is up to date with '%s'.\n"
+msgstr "Ο κλάδος σας είναι ενήμερος με το '%s'.\n"
+
+#: remote.c:2001
+#, c-format
+msgid "Your branch and '%s' refer to different commits.\n"
+msgstr "Ο κλάδος σας και το '%s' αναφέρονται σε διαφορετικές υποβολές.\n"
+
+#: remote.c:2004
+#, c-format
+msgid "  (use \"%s\" for details)\n"
+msgstr "  (χρησιμοποιήστε \"%s\" για λεπτομέρειες)\n"
+
+#: remote.c:2008
+#, c-format
+msgid "Your branch is ahead of '%s' by %d commit.\n"
+msgid_plural "Your branch is ahead of '%s' by %d commits.\n"
+msgstr[0] "Ο κλάδος σας είναι μπροστά από το '%s' κατά %d υποβολή.\n"
+msgstr[1] "Ο κλάδος σας είναι μπροστά από το '%s' κατά %d υποβολές.\n"
+
+#: remote.c:2014
+msgid "  (use \"git push\" to publish your local commits)\n"
+msgstr ""
+"  (χρησιμοποιήστε \"git push\" για να δημοσιεύσετε τις τοπικές σας "
+"υποβολές)\n"
+
+#: remote.c:2017
+#, c-format
+msgid "Your branch is behind '%s' by %d commit, and can be fast-forwarded.\n"
+msgid_plural ""
+"Your branch is behind '%s' by %d commits, and can be fast-forwarded.\n"
+msgstr[0] ""
+"Ο κλάδος σας είναι πίσω από το '%s' κατά %d υποβολή, και μπορεί να κάνει "
+"ταχεία προώθηση.\n"
+msgstr[1] ""
+"Ο κλάδος σας είναι πίσω από το '%s' κατά %d υποβολές, και μπορεί να κάνει "
+"ταχεία προώθηση.\n"
+
+#: remote.c:2025
+msgid "  (use \"git pull\" to update your local branch)\n"
+msgstr ""
+"  (χρησιμοποιήστε \"git pull\" για να ενημερώσετε τον τοπικό σας κλάδο)\n"
+
+#: remote.c:2028
+#, c-format
+msgid ""
+"Your branch and '%s' have diverged,\n"
+"and have %d and %d different commit each, respectively.\n"
+msgid_plural ""
+"Your branch and '%s' have diverged,\n"
+"and have %d and %d different commits each, respectively.\n"
+msgstr[0] ""
+"Ο κλάδος σας και το '%s' έχουν αποκλίνει,\n"
+"και έχουν %d και %d διαφορετική υποβολή ο καθένας, αντίστοιχα.\n"
+msgstr[1] ""
+"Ο κλάδος σας και το '%s' έχουν αποκλίνει,\n"
+"και έχουν %d και %d διαφορετικές υποβολές ο καθένας, αντίστοιχα.\n"
+
+#: remote.c:2038
+msgid "  (use \"git pull\" to merge the remote branch into yours)\n"
+msgstr ""
+"  (χρησιμοποιήστε \"git pull\" για να συγχωνεύσετε τον απομακρυσμένο κλάδο "
+"μέσα στον δικό σας)\n"
+
+#: remote.c:2221
+#, c-format
+msgid "cannot parse expected object name '%s'"
+msgstr "δεν είναι δυνατή η ανάλυση του αναμενόμενου ονόματος αντικειμένου '%s'"
+
+#: replace-object.c:21
+#, c-format
+msgid "bad replace ref name: %s"
+msgstr ""
+
+#: replace-object.c:30
+#, c-format
+msgid "duplicate replace ref: %s"
+msgstr ""
+
+#: replace-object.c:73
+#, c-format
+msgid "replace depth too high for object %s"
+msgstr ""
+
+#: rerere.c:217 rerere.c:226 rerere.c:229
+msgid "corrupt MERGE_RR"
+msgstr ""
+
+#: rerere.c:264 rerere.c:269
+msgid "unable to write rerere record"
+msgstr ""
+
+#: rerere.c:485 rerere.c:692 sequencer.c:3186 sequencer.c:3212
+#: builtin/fsck.c:314
+#, c-format
+msgid "could not write '%s'"
+msgstr ""
+
+#: rerere.c:495
+#, c-format
+msgid "there were errors while writing '%s' (%s)"
+msgstr ""
+
+#: rerere.c:498
+#, c-format
+msgid "failed to flush '%s'"
+msgstr ""
+
+#: rerere.c:503 rerere.c:1039
+#, c-format
+msgid "could not parse conflict hunks in '%s'"
+msgstr ""
+
+#: rerere.c:684
+#, c-format
+msgid "failed utime() on '%s'"
+msgstr ""
+
+#: rerere.c:694
+#, c-format
+msgid "writing '%s' failed"
+msgstr ""
+
+#: rerere.c:714
+#, c-format
+msgid "Staged '%s' using previous resolution."
+msgstr ""
+
+#: rerere.c:753
+#, c-format
+msgid "Recorded resolution for '%s'."
+msgstr ""
+
+#: rerere.c:788
+#, c-format
+msgid "Resolved '%s' using previous resolution."
+msgstr "Ταυτίστηκε το '%s' χρησιμοποιώντας την προηγούμενη ταύτιση."
+
+#: rerere.c:803
+#, c-format
+msgid "cannot unlink stray '%s'"
+msgstr ""
+
+#: rerere.c:807
+#, c-format
+msgid "Recorded preimage for '%s'"
+msgstr ""
+
+#: rerere.c:881 submodule.c:2012 builtin/submodule--helper.c:1417
+#: builtin/submodule--helper.c:1427
+#, c-format
+msgid "could not create directory '%s'"
+msgstr ""
+
+#: rerere.c:1057
+#, c-format
+msgid "failed to update conflicted state in '%s'"
+msgstr ""
+
+#: rerere.c:1068 rerere.c:1075
+#, c-format
+msgid "no remembered resolution for '%s'"
+msgstr ""
+
+#: rerere.c:1077
+#, c-format
+msgid "cannot unlink '%s'"
+msgstr ""
+
+#: rerere.c:1087
+#, c-format
+msgid "Updated preimage for '%s'"
+msgstr ""
+
+#: rerere.c:1096
+#, c-format
+msgid "Forgot resolution for '%s'\n"
+msgstr ""
+
+#: rerere.c:1199
+msgid "unable to open rr-cache directory"
+msgstr ""
+
+#: revision.c:2484
+msgid "your current branch appears to be broken"
+msgstr "ο παρών κλάδος σας φαίνεται να είναι χαλασμένος"
+
+#: revision.c:2487
+#, c-format
+msgid "your current branch '%s' does not have any commits yet"
+msgstr "ο τρέχων κλάδος σας '%s' δεν έχει ακόμα καμία υποβολή"
+
+#: revision.c:2684
+msgid "--first-parent is incompatible with --bisect"
+msgstr ""
+
+#: run-command.c:742
+msgid "open /dev/null failed"
+msgstr ""
+
+#: run-command.c:1231
+#, c-format
+msgid "cannot create async thread: %s"
+msgstr ""
+
+#: run-command.c:1295
+#, c-format
+msgid ""
+"The '%s' hook was ignored because it's not set as executable.\n"
+"You can disable this warning with `git config advice.ignoredHook false`."
+msgstr ""
+
+#: send-pack.c:141
+msgid "unexpected flush packet while reading remote unpack status"
+msgstr ""
+
+#: send-pack.c:143
+#, c-format
+msgid "unable to parse remote unpack status: %s"
+msgstr ""
+
+#: send-pack.c:145
+#, c-format
+msgid "remote unpack failed: %s"
+msgstr ""
+
+#: send-pack.c:306
+msgid "failed to sign the push certificate"
+msgstr ""
+
+#: send-pack.c:420
+msgid "the receiving end does not support --signed push"
+msgstr ""
+
+#: send-pack.c:422
+msgid ""
+"not sending a push certificate since the receiving end does not support --"
+"signed push"
+msgstr ""
+
+#: send-pack.c:434
+msgid "the receiving end does not support --atomic push"
+msgstr ""
+
+#: send-pack.c:439
+msgid "the receiving end does not support push options"
+msgstr ""
+
+#: sequencer.c:184
+#, c-format
+msgid "invalid commit message cleanup mode '%s'"
+msgstr ""
+
+#: sequencer.c:288
+#, c-format
+msgid "could not delete '%s'"
+msgstr ""
+
+#: sequencer.c:314
+msgid "revert"
+msgstr ""
+
+#: sequencer.c:316
+msgid "cherry-pick"
+msgstr ""
+
+#: sequencer.c:318
+msgid "rebase -i"
+msgstr ""
+
+#: sequencer.c:320
+#, c-format
+msgid "unknown action: %d"
+msgstr ""
+
+#: sequencer.c:378
+msgid ""
+"after resolving the conflicts, mark the corrected paths\n"
+"with 'git add <paths>' or 'git rm <paths>'"
+msgstr ""
+"αφού επιλύσετε τις συγκρούσεις, επισημάνετε τις διορθωμένες διαδρομές\n"
+"με 'git add <διαδρομές>' ή 'git rm <διαδρομές>'"
+
+#: sequencer.c:381
+msgid ""
+"after resolving the conflicts, mark the corrected paths\n"
+"with 'git add <paths>' or 'git rm <paths>'\n"
+"and commit the result with 'git commit'"
+msgstr ""
+"αφού επιλύσετε τις συγκρούσεις, επισημάνετε τις διορθωμένες διαδρομές\n"
+"με 'git add <διαδρομές>' ή 'git rm <διαδρομές>'\n"
+"και υποβάλετε το αποτέλεσμα με 'git commit'"
+
+#: sequencer.c:394 sequencer.c:2671
+#, c-format
+msgid "could not lock '%s'"
+msgstr ""
+
+#: sequencer.c:401
+#, c-format
+msgid "could not write eol to '%s'"
+msgstr ""
+
+#: sequencer.c:406 sequencer.c:2554 sequencer.c:2677 sequencer.c:2691
+#: sequencer.c:2931
+#, c-format
+msgid "failed to finalize '%s'"
+msgstr ""
+
+#: sequencer.c:429 sequencer.c:931 sequencer.c:1615 sequencer.c:2574
+#: sequencer.c:2913 sequencer.c:3022 builtin/am.c:245 builtin/commit.c:748
+#: builtin/merge.c:1085 builtin/rebase.c:154
+#, c-format
+msgid "could not read '%s'"
+msgstr ""
+
+#: sequencer.c:455
+#, c-format
+msgid "your local changes would be overwritten by %s."
+msgstr "οι τοπικές αλλαγές σας θα επεγγραφόντουσαν από το %s."
+
+#: sequencer.c:459
+msgid "commit your changes or stash them to proceed."
+msgstr "υποβάλετε τις αλλαγές σας ή αποθηκεύστε τις για να προχωρήσετε."
+
+#: sequencer.c:491
+#, c-format
+msgid "%s: fast-forward"
+msgstr ""
+
+#. TRANSLATORS: %s will be "revert", "cherry-pick" or
+#. "rebase -i".
+#.
+#: sequencer.c:582
+#, c-format
+msgid "%s: Unable to write new index file"
+msgstr ""
+
+#: sequencer.c:598
+msgid "unable to update cache tree"
+msgstr ""
+
+#: sequencer.c:612
+msgid "could not resolve HEAD commit"
+msgstr "δεν ήταν δυνατή η ταύτιση της υποβολής HEAD"
+
+#: sequencer.c:692
+#, c-format
+msgid "no key present in '%.*s'"
+msgstr ""
+
+#: sequencer.c:703
+#, c-format
+msgid "unable to dequote value of '%s'"
+msgstr ""
+
+#: sequencer.c:740 wrapper.c:227 wrapper.c:397 builtin/am.c:704
+#: builtin/am.c:796 builtin/merge.c:1082 builtin/rebase.c:617
+#, c-format
+msgid "could not open '%s' for reading"
+msgstr "δεν ήταν δυνατό το άνοιγμα του '%s' για ανάγνωση"
+
+#: sequencer.c:750
+msgid "'GIT_AUTHOR_NAME' already given"
+msgstr "'GIT_AUTHOR_NAME' δόθηκε ήδη"
+
+#: sequencer.c:755
+msgid "'GIT_AUTHOR_EMAIL' already given"
+msgstr "'GIT_AUTHOR_EMAIL' δόθηκε ήδη"
+
+#: sequencer.c:760
+msgid "'GIT_AUTHOR_DATE' already given"
+msgstr "'GIT_AUTHOR_DATE' δόθηκε ήδη"
+
+#: sequencer.c:764
+#, c-format
+msgid "unknown variable '%s'"
+msgstr ""
+
+#: sequencer.c:769
+msgid "missing 'GIT_AUTHOR_NAME'"
+msgstr ""
+
+#: sequencer.c:771
+msgid "missing 'GIT_AUTHOR_EMAIL'"
+msgstr ""
+
+#: sequencer.c:773
+msgid "missing 'GIT_AUTHOR_DATE'"
+msgstr ""
+
+#: sequencer.c:833
+#, c-format
+msgid "invalid date format '%s' in '%s'"
+msgstr ""
+
+#: sequencer.c:850
+#, c-format
+msgid ""
+"you have staged changes in your working tree\n"
+"If these changes are meant to be squashed into the previous commit, run:\n"
+"\n"
+"  git commit --amend %s\n"
+"\n"
+"If they are meant to go into a new commit, run:\n"
+"\n"
+"  git commit %s\n"
+"\n"
+"In both cases, once you're done, continue with:\n"
+"\n"
+"  git rebase --continue\n"
+msgstr ""
+"έχετε προετοιμασμένες αλλαγές στο δέντρο εργασίας σας\n"
+"Αν αυτές οι αλλαγές πρέπει να συμπτυχθούν μέσα στην προηγούμενη υποβολή, "
+"τρέξτε:\n"
+"\n"
+"  git commit --amend %s\n"
+"\n"
+"Αν πρέπει να πάνε σε νέα υποβολή, τρέξτε:\n"
+"\n"
+"  git commit %s\n"
+"\n"
+"Και στις δύο περιπτώσεις, μόλις τελειώσετε, συνεχίστε με:\n"
+"\n"
+"  git rebase --continue\n"
+
+#: sequencer.c:945
+msgid "writing root commit"
+msgstr ""
+
+#: sequencer.c:1155
+msgid "'prepare-commit-msg' hook failed"
+msgstr ""
+
+#: sequencer.c:1162
+msgid ""
+"Your name and email address were configured automatically based\n"
+"on your username and hostname. Please check that they are accurate.\n"
+"You can suppress this message by setting them explicitly. Run the\n"
+"following command and follow the instructions in your editor to edit\n"
+"your configuration file:\n"
+"\n"
+"    git config --global --edit\n"
+"\n"
+"After doing this, you may fix the identity used for this commit with:\n"
+"\n"
+"    git commit --amend --reset-author\n"
+msgstr ""
+"Το όνομα και η διεύθυνση email σας ρυθμίστηκαν αυτόματα με βάση\n"
+"το όνομα χρήστη και το όνομα υπολογιστή σας. Παρακαλώ ελέγξτε πως είναι "
+"ακριβή.\n"
+"Μπορείτε να αποκρύψετε αυτό το μήνυμα ορίζοντας τα ρητά. Τρέξτε την\n"
+"ακόλουθη εντολή και ακολουθήστε τις οδηγίες στον διορθωτή σας για να "
+"επεξεργαστείτε\n"
+"το αρχείο ρυθμίσεών σας :\n"
+"\n"
+"    git config --global --edit\n"
+"\n"
+"Έπειτα, μπορείτε να διορθώσετε την ταυτότητα χρήστη που χρησιμοποιήθηκε για "
+"αυτή την υποβολή με:\n"
+"\n"
+"    git commit --amend --reset-author\n"
+
+#: sequencer.c:1175
+msgid ""
+"Your name and email address were configured automatically based\n"
+"on your username and hostname. Please check that they are accurate.\n"
+"You can suppress this message by setting them explicitly:\n"
+"\n"
+"    git config --global user.name \"Your Name\"\n"
+"    git config --global user.email you@example.com\n"
+"\n"
+"After doing this, you may fix the identity used for this commit with:\n"
+"\n"
+"    git commit --amend --reset-author\n"
+msgstr ""
+"Το όνομα και η διεύθυνση email σας ρυθμίστηκαν αυτόματα με βάση\n"
+"το όνομα χρήστη και το όνομα υπολογιστή σας. Παρακαλώ ελέγξτε πως είναι "
+"ακριβή.\n"
+"Μπορείτε να αποκρύψετε αυτό το μήνυμα ορίζοντας τα ρητά:\n"
+"\n"
+"    git config --global user.name \"Το όνομά σας\"\n"
+"    git config --global user.email you@example.com\n"
+"\n"
+"Έπειτα, μπορείτε να διορθώσετε την ταυτότητα χρήστη που χρησιμοποιήθηκε για "
+"αυτή την υποβολή με:\n"
+"\n"
+"    git commit --amend --reset-author\n"
+
+#: sequencer.c:1217
+msgid "couldn't look up newly created commit"
+msgstr ""
+
+#: sequencer.c:1219
+msgid "could not parse newly created commit"
+msgstr ""
+
+#: sequencer.c:1265
+msgid "unable to resolve HEAD after creating commit"
+msgstr "δεν ήταν δυνατή η ταύτιση του HEAD μετά τη δημιουργία της υποβολής"
+
+#: sequencer.c:1267
+msgid "detached HEAD"
+msgstr ""
+
+#: sequencer.c:1271
+msgid " (root-commit)"
+msgstr ""
+
+#: sequencer.c:1292
+msgid "could not parse HEAD"
+msgstr ""
+
+#: sequencer.c:1294
+#, c-format
+msgid "HEAD %s is not a commit!"
+msgstr "Το HEAD %s δεν είναι υποβολή!"
+
+#: sequencer.c:1298 builtin/commit.c:1546
+msgid "could not parse HEAD commit"
+msgstr ""
+
+#: sequencer.c:1350 sequencer.c:1964
+msgid "unable to parse commit author"
+msgstr ""
+
+#: sequencer.c:1360 builtin/am.c:1570 builtin/merge.c:678
+msgid "git write-tree failed to write a tree"
+msgstr ""
+
+#: sequencer.c:1377 sequencer.c:1433
+#, c-format
+msgid "unable to read commit message from '%s'"
+msgstr ""
+
+#: sequencer.c:1399 builtin/am.c:1591 builtin/commit.c:1649 builtin/merge.c:859
+#: builtin/merge.c:884
+msgid "failed to write commit object"
+msgstr ""
+
+#: sequencer.c:1460
+#, c-format
+msgid "could not parse commit %s"
+msgstr ""
+
+#: sequencer.c:1465
+#, c-format
+msgid "could not parse parent commit %s"
+msgstr ""
+
+#: sequencer.c:1565 sequencer.c:1675
+#, c-format
+msgid "unknown command: %d"
+msgstr ""
+
+#: sequencer.c:1622 sequencer.c:1647
+#, c-format
+msgid "This is a combination of %d commits."
+msgstr ""
+
+#: sequencer.c:1632 sequencer.c:4808
+msgid "need a HEAD to fixup"
+msgstr ""
+
+#: sequencer.c:1634 sequencer.c:2958
+msgid "could not read HEAD"
+msgstr ""
+
+#: sequencer.c:1636
+msgid "could not read HEAD's commit message"
+msgstr ""
+
+#: sequencer.c:1642
+#, c-format
+msgid "cannot write '%s'"
+msgstr ""
+
+#: sequencer.c:1649 git-rebase--preserve-merges.sh:441
+msgid "This is the 1st commit message:"
+msgstr ""
+
+#: sequencer.c:1657
+#, c-format
+msgid "could not read commit message of %s"
+msgstr ""
+
+#: sequencer.c:1664
+#, c-format
+msgid "This is the commit message #%d:"
+msgstr ""
+
+#: sequencer.c:1670
+#, c-format
+msgid "The commit message #%d will be skipped:"
+msgstr ""
+
+#: sequencer.c:1758
+msgid "your index file is unmerged."
+msgstr "το αρχείο ευρετηρίου σας δεν έχει συγχωνευτεί."
+
+#: sequencer.c:1765
+msgid "cannot fixup root commit"
+msgstr ""
+
+#: sequencer.c:1784
+#, c-format
+msgid "commit %s is a merge but no -m option was given."
+msgstr "η υποβολή %s είναι συγχώνευση αλλά δεν έχει δοθεί επιλογή -m."
+
+#: sequencer.c:1792 sequencer.c:1800
+#, c-format
+msgid "commit %s does not have parent %d"
+msgstr "η υποβολή %s δεν έχει γονέα το %d"
+
+#: sequencer.c:1806
+#, c-format
+msgid "cannot get commit message for %s"
+msgstr ""
+
+#. TRANSLATORS: The first %s will be a "todo" command like
+#. "revert" or "pick", the second %s a SHA1.
+#: sequencer.c:1825
+#, c-format
+msgid "%s: cannot parse parent commit %s"
+msgstr ""
+
+#: sequencer.c:1890
+#, c-format
+msgid "could not rename '%s' to '%s'"
+msgstr "δεν ήταν δυνατή η μετονομασία του '%s' σε '%s'"
+
+#: sequencer.c:1945
+#, c-format
+msgid "could not revert %s... %s"
+msgstr ""
+
+#: sequencer.c:1946
+#, c-format
+msgid "could not apply %s... %s"
+msgstr ""
+
+#: sequencer.c:2005
+#, c-format
+msgid "git %s: failed to read the index"
+msgstr ""
+
+#: sequencer.c:2012
+#, c-format
+msgid "git %s: failed to refresh the index"
+msgstr ""
+
+#: sequencer.c:2094
+#, c-format
+msgid "%s does not accept arguments: '%s'"
+msgstr ""
+
+#: sequencer.c:2103
+#, c-format
+msgid "missing arguments for %s"
+msgstr ""
+
+#: sequencer.c:2163
+#, c-format
+msgid "invalid line %d: %.*s"
+msgstr ""
+
+#: sequencer.c:2171
+#, c-format
+msgid "cannot '%s' without a previous commit"
+msgstr ""
+
+#: sequencer.c:2243
+msgid "please fix this using 'git rebase --edit-todo'."
+msgstr ""
+
+#: sequencer.c:2245
+#, c-format
+msgid "unusable instruction sheet: '%s'"
+msgstr ""
+
+#: sequencer.c:2250
+msgid "no commits parsed."
+msgstr ""
+
+#: sequencer.c:2261
+msgid "cannot cherry-pick during a revert."
+msgstr ""
+
+#: sequencer.c:2263
+msgid "cannot revert during a cherry-pick."
+msgstr ""
+
+#: sequencer.c:2333
+#, c-format
+msgid "invalid value for %s: %s"
+msgstr ""
+
+#: sequencer.c:2420
+msgid "unusable squash-onto"
+msgstr ""
+
+#: sequencer.c:2436
+#, c-format
+msgid "malformed options sheet: '%s'"
+msgstr ""
+
+#: sequencer.c:2518 sequencer.c:4067
+msgid "empty commit set passed"
+msgstr ""
+
+#: sequencer.c:2526
+msgid "a cherry-pick or revert is already in progress"
+msgstr ""
+
+#: sequencer.c:2527
+msgid "try \"git cherry-pick (--continue | --quit | --abort)\""
+msgstr ""
+
+#: sequencer.c:2530
+#, c-format
+msgid "could not create sequencer directory '%s'"
+msgstr ""
+
+#: sequencer.c:2544
+msgid "could not lock HEAD"
+msgstr ""
+
+#: sequencer.c:2599 sequencer.c:3819
+msgid "no cherry-pick or revert in progress"
+msgstr "δεν υφίσταται cherry-pick ή revert"
+
+#: sequencer.c:2601
+msgid "cannot resolve HEAD"
+msgstr "δεν είναι δυνατή η ταύτιση του HEAD"
+
+#: sequencer.c:2603 sequencer.c:2638
+msgid "cannot abort from a branch yet to be born"
+msgstr ""
+
+#: sequencer.c:2624 builtin/grep.c:732
+#, c-format
+msgid "cannot open '%s'"
+msgstr ""
+
+#: sequencer.c:2626
+#, c-format
+msgid "cannot read '%s': %s"
+msgstr ""
+
+#: sequencer.c:2627
+msgid "unexpected end of file"
+msgstr ""
+
+#: sequencer.c:2633
+#, c-format
+msgid "stored pre-cherry-pick HEAD file '%s' is corrupt"
+msgstr ""
+
+#: sequencer.c:2644
+msgid "You seem to have moved HEAD. Not rewinding, check your HEAD!"
+msgstr ""
+"Φαίνεται πως μετακινήσατε το HEAD. Δε γίνεται γύρισμα προς τα πίσω, ελέγξτε "
+"το HEAD σας!"
+
+#: sequencer.c:2750 sequencer.c:3735
+#, c-format
+msgid "could not update %s"
+msgstr ""
+
+#: sequencer.c:2788 sequencer.c:3715
+msgid "cannot read HEAD"
+msgstr ""
+
+#: sequencer.c:2805
+#, c-format
+msgid "unable to copy '%s' to '%s'"
+msgstr ""
+
+#: sequencer.c:2813
+#, c-format
+msgid ""
+"You can amend the commit now, with\n"
+"\n"
+"  git commit --amend %s\n"
+"\n"
+"Once you are satisfied with your changes, run\n"
+"\n"
+"  git rebase --continue\n"
+msgstr ""
+"Μπορείτε να τροποποιήσετε την υποβολή τώρα, με\n"
+"\n"
+"  git commit --amend %s\n"
+"\n"
+"Όταν οι αλλαγές σας σας ικανοποιούν, τρέξτε\n"
+"\n"
+"  git rebase --continue\n"
+
+#: sequencer.c:2823
+#, c-format
+msgid "Could not apply %s... %.*s"
+msgstr ""
+
+#: sequencer.c:2830
+#, c-format
+msgid "Could not merge %.*s"
+msgstr "Δεν ήταν δυνατή η συγχώνευση του %.*s"
+
+#: sequencer.c:2844 sequencer.c:2848 builtin/difftool.c:641
+#, c-format
+msgid "could not copy '%s' to '%s'"
+msgstr ""
+
+#: sequencer.c:2870 sequencer.c:3293 builtin/rebase.c:424 builtin/rebase.c:1230
+#: builtin/rebase.c:1591 builtin/rebase.c:1646
+msgid "could not read index"
+msgstr ""
+
+#: sequencer.c:2875
+#, c-format
+msgid ""
+"execution failed: %s\n"
+"%sYou can fix the problem, and then run\n"
+"\n"
+"  git rebase --continue\n"
+"\n"
+msgstr ""
+
+#: sequencer.c:2881
+msgid "and made changes to the index and/or the working tree\n"
+msgstr ""
+
+#: sequencer.c:2887
+#, c-format
+msgid ""
+"execution succeeded: %s\n"
+"but left changes to the index and/or the working tree\n"
+"Commit or stash your changes, and then run\n"
+"\n"
+"  git rebase --continue\n"
+"\n"
+msgstr ""
+
+#: sequencer.c:2948
+#, c-format
+msgid "illegal label name: '%.*s'"
+msgstr ""
+
+#: sequencer.c:3002
+msgid "writing fake root commit"
+msgstr ""
+
+#: sequencer.c:3007
+msgid "writing squash-onto"
+msgstr ""
+
+#: sequencer.c:3045 builtin/rebase.c:429 builtin/rebase.c:435
+#, c-format
+msgid "failed to find tree of %s"
+msgstr ""
+
+#: sequencer.c:3063 builtin/rebase.c:448
+msgid "could not write index"
+msgstr ""
+
+#: sequencer.c:3090
+#, c-format
+msgid "could not resolve '%s'"
+msgstr "δεν ήταν δυνατή η ταύτιση του '%s'"
+
+#: sequencer.c:3118
+msgid "cannot merge without a current revision"
+msgstr ""
+
+#: sequencer.c:3140
+#, c-format
+msgid "unable to parse '%.*s'"
+msgstr ""
+
+#: sequencer.c:3149
+#, c-format
+msgid "nothing to merge: '%.*s'"
+msgstr "δεν υπάρχει τίποτα προς συγχώνευση: '%.*s'"
+
+#: sequencer.c:3161
+msgid "octopus merge cannot be executed on top of a [new root]"
+msgstr ""
+
+#: sequencer.c:3176
+#, c-format
+msgid "could not get commit message of '%s'"
+msgstr ""
+
+#: sequencer.c:3325
+#, c-format
+msgid "could not even attempt to merge '%.*s'"
+msgstr ""
+
+#: sequencer.c:3341
+msgid "merge: Unable to write new index file"
+msgstr ""
+
+#: sequencer.c:3409 builtin/rebase.c:298
+#, c-format
+msgid "Applied autostash.\n"
+msgstr "Έγινε εφαρμογή των αυτόματα αποθηκευμένων.\n"
+
+#: sequencer.c:3421
+#, c-format
+msgid "cannot store %s"
+msgstr ""
+
+#: sequencer.c:3424 builtin/rebase.c:314
+#, c-format
+msgid ""
+"Applying autostash resulted in conflicts.\n"
+"Your changes are safe in the stash.\n"
+"You can run \"git stash pop\" or \"git stash drop\" at any time.\n"
+msgstr ""
+"Η εφαρμογή των αυτόματα αποθηκευμένων οδήγησε σε συγκρούσεις.\n"
+"Οι αλλαγές σας είναι ασφαλείς μέσα στα αποθηκευμένα.\n"
+"Μπορείτε να τρέξετε \"git stash pop\" ή \"git stash drop\" ανά πάσα στιγμή.\n"
+
+#: sequencer.c:3478
+#, c-format
+msgid "could not checkout %s"
+msgstr ""
+
+#: sequencer.c:3492
+#, c-format
+msgid "%s: not a valid OID"
+msgstr ""
+
+#: sequencer.c:3497 git-rebase--preserve-merges.sh:724
+msgid "could not detach HEAD"
+msgstr ""
+
+#: sequencer.c:3512
+#, c-format
+msgid "Stopped at HEAD\n"
+msgstr ""
+
+#: sequencer.c:3514
+#, c-format
+msgid "Stopped at %s\n"
+msgstr ""
+
+#: sequencer.c:3522
+#, c-format
+msgid ""
+"Could not execute the todo command\n"
+"\n"
+"    %.*s\n"
+"It has been rescheduled; To edit the command before continuing, please\n"
+"edit the todo list first:\n"
+"\n"
+"    git rebase --edit-todo\n"
+"    git rebase --continue\n"
+msgstr ""
+
+#: sequencer.c:3597
+#, c-format
+msgid "Stopped at %s...  %.*s\n"
+msgstr ""
+
+#: sequencer.c:3677
+#, c-format
+msgid "unknown command %d"
+msgstr ""
+
+#: sequencer.c:3723
+msgid "could not read orig-head"
+msgstr ""
+
+#: sequencer.c:3728 sequencer.c:4805
+msgid "could not read 'onto'"
+msgstr ""
+
+#: sequencer.c:3742
+#, c-format
+msgid "could not update HEAD to %s"
+msgstr ""
+
+#: sequencer.c:3831
+msgid "cannot rebase: You have unstaged changes."
+msgstr ""
+
+#: sequencer.c:3840
+msgid "cannot amend non-existing commit"
+msgstr ""
+
+#: sequencer.c:3842
+#, c-format
+msgid "invalid file: '%s'"
+msgstr ""
+
+#: sequencer.c:3844
+#, c-format
+msgid "invalid contents: '%s'"
+msgstr ""
+
+#: sequencer.c:3847
+msgid ""
+"\n"
+"You have uncommitted changes in your working tree. Please, commit them\n"
+"first and then run 'git rebase --continue' again."
+msgstr ""
+"\n"
+"Έχετε μη συγχωνευμένες αλλαγές στο δέντρο εργασίας σας. Παρακαλώ, υποβάλετέ "
+"τις\n"
+"πρώτα και μετά τρέξτε 'git rebase --continue' πάλι."
+
+#: sequencer.c:3883 sequencer.c:3921
+#, c-format
+msgid "could not write file: '%s'"
+msgstr ""
+
+#: sequencer.c:3936
+msgid "could not remove CHERRY_PICK_HEAD"
+msgstr ""
+
+#: sequencer.c:3943
+msgid "could not commit staged changes."
+msgstr ""
+
+#: sequencer.c:4044
+#, c-format
+msgid "%s: can't cherry-pick a %s"
+msgstr ""
+
+#: sequencer.c:4048
+#, c-format
+msgid "%s: bad revision"
+msgstr ""
+
+#: sequencer.c:4083
+msgid "can't revert as initial commit"
+msgstr ""
+
+#: sequencer.c:4529
+msgid "make_script: unhandled options"
+msgstr ""
+
+#: sequencer.c:4532
+msgid "make_script: error preparing revisions"
+msgstr ""
+
+#: sequencer.c:4573 sequencer.c:4629 sequencer.c:4904
+#, c-format
+msgid "unusable todo list: '%s'"
+msgstr ""
+
+#: sequencer.c:4684
+#, c-format
+msgid ""
+"unrecognized setting %s for option rebase.missingCommitsCheck. Ignoring."
+msgstr ""
+
+#: sequencer.c:4754
+#, c-format
+msgid ""
+"Warning: some commits may have been dropped accidentally.\n"
+"Dropped commits (newer to older):\n"
+msgstr ""
+
+#: sequencer.c:4761
+#, c-format
+msgid ""
+"To avoid this message, use \"drop\" to explicitly remove a commit.\n"
+"\n"
+"Use 'git config rebase.missingCommitsCheck' to change the level of "
+"warnings.\n"
+"The possible behaviours are: ignore, warn, error.\n"
+"\n"
+msgstr ""
+
+#: sequencer.c:4774
+#, c-format
+msgid ""
+"You can fix this with 'git rebase --edit-todo' and then run 'git rebase --"
+"continue'.\n"
+"Or you can abort the rebase with 'git rebase --abort'.\n"
+msgstr ""
+"Μπορείτε να το διορθώσετε αυτό με 'git rebase --edit-todo' και μετά να "
+"τρέξετε 'git rebase --continue'.\n"
+"Ή μπορείτε να εγκαταλείψετε το rebase με 'git rebase --abort'.\n"
+
+#: sequencer.c:4912 sequencer.c:4950
+msgid "nothing to do"
+msgstr "δεν υπάρχει τίποτα να γίνει"
+
+#: sequencer.c:4916
+#, c-format
+msgid "Rebase %s onto %s (%d command)"
+msgid_plural "Rebase %s onto %s (%d commands)"
+msgstr[0] ""
+msgstr[1] ""
+
+#: sequencer.c:4928
+#, c-format
+msgid "could not copy '%s' to '%s'."
+msgstr ""
+
+#: sequencer.c:4932 sequencer.c:4961
+msgid "could not transform the todo list"
+msgstr ""
+
+#: sequencer.c:4964
+msgid "could not skip unnecessary pick commands"
+msgstr ""
+
+#: sequencer.c:5047
+msgid "the script was already rearranged."
+msgstr ""
+
+#: setup.c:123
+#, c-format
+msgid "'%s' is outside repository"
+msgstr ""
+
+#: setup.c:172
+#, c-format
+msgid ""
+"%s: no such path in the working tree.\n"
+"Use 'git <command> -- <path>...' to specify paths that do not exist locally."
+msgstr ""
+
+#: setup.c:185
+#, c-format
+msgid ""
+"ambiguous argument '%s': unknown revision or path not in the working tree.\n"
+"Use '--' to separate paths from revisions, like this:\n"
+"'git <command> [<revision>...] -- [<file>...]'"
+msgstr ""
+
+#: setup.c:234
+#, c-format
+msgid "option '%s' must come before non-option arguments"
+msgstr ""
+
+#: setup.c:253
+#, c-format
+msgid ""
+"ambiguous argument '%s': both revision and filename\n"
+"Use '--' to separate paths from revisions, like this:\n"
+"'git <command> [<revision>...] -- [<file>...]'"
+msgstr ""
+
+#: setup.c:389
+msgid "unable to set up work tree using invalid config"
+msgstr ""
+
+#: setup.c:393
+msgid "this operation must be run in a work tree"
+msgstr ""
+
+#: setup.c:527
+#, c-format
+msgid "Expected git repo version <= %d, found %d"
+msgstr ""
+
+#: setup.c:535
+msgid "unknown repository extensions found:"
+msgstr ""
+
+#: setup.c:554
+#, c-format
+msgid "error opening '%s'"
+msgstr ""
+
+#: setup.c:556
+#, c-format
+msgid "too large to be a .git file: '%s'"
+msgstr ""
+
+#: setup.c:558
+#, c-format
+msgid "error reading %s"
+msgstr ""
+
+#: setup.c:560
+#, c-format
+msgid "invalid gitfile format: %s"
+msgstr ""
+
+#: setup.c:562
+#, c-format
+msgid "no path in gitfile: %s"
+msgstr ""
+
+#: setup.c:564
+#, c-format
+msgid "not a git repository: %s"
+msgstr "δεν είναι αποθετήριο git: %s"
+
+#: setup.c:663
+#, c-format
+msgid "'$%s' too big"
+msgstr ""
+
+#: setup.c:677
+#, c-format
+msgid "not a git repository: '%s'"
+msgstr "δεν είναι αποθετήριο git: '%s'"
+
+#: setup.c:706 setup.c:708 setup.c:739
+#, c-format
+msgid "cannot chdir to '%s'"
+msgstr ""
+
+#: setup.c:711 setup.c:767 setup.c:777 setup.c:816 setup.c:824
+msgid "cannot come back to cwd"
+msgstr ""
+
+#: setup.c:838
+#, c-format
+msgid "failed to stat '%*s%s%s'"
+msgstr ""
+
+#: setup.c:1068
+msgid "Unable to read current working directory"
+msgstr ""
+
+#: setup.c:1077 setup.c:1083
+#, c-format
+msgid "cannot change to '%s'"
+msgstr ""
+
+#: setup.c:1088
+#, c-format
+msgid "not a git repository (or any of the parent directories): %s"
+msgstr "δεν είναι αποθετήριο git (ή κανένας από τους πιο πάνω φακέλους): %s"
+
+#: setup.c:1094
+#, c-format
+msgid ""
+"not a git repository (or any parent up to mount point %s)\n"
+"Stopping at filesystem boundary (GIT_DISCOVERY_ACROSS_FILESYSTEM not set)."
+msgstr ""
+"δεν είναι αποθετήριο git (ή κανένας πιο πάνω φάκελος μέχρι το σημείο "
+"προσάρτησης %s)\n"
+"Σταμάτημα στα όρια του συστήματος αρχείων (GIT_DISCOVERY_ACROSS_FILESYSTEM "
+"μη ορισμένο)."
+
+#: setup.c:1204
+#, c-format
+msgid ""
+"problem with core.sharedRepository filemode value (0%.3o).\n"
+"The owner of files must always have read and write permissions."
+msgstr ""
+
+#: setup.c:1247
+msgid "open /dev/null or dup failed"
+msgstr ""
+
+#: setup.c:1262
+msgid "fork failed"
+msgstr ""
+
+#: setup.c:1267
+msgid "setsid failed"
+msgstr ""
+
+#: sha1-file.c:445
+#, c-format
+msgid "object directory %s does not exist; check .git/objects/info/alternates"
+msgstr ""
+
+#: sha1-file.c:496
+#, c-format
+msgid "unable to normalize alternate object path: %s"
+msgstr ""
+
+#: sha1-file.c:568
+#, c-format
+msgid "%s: ignoring alternate object stores, nesting too deep"
+msgstr ""
+
+#: sha1-file.c:575
+#, c-format
+msgid "unable to normalize object directory: %s"
+msgstr ""
+
+#: sha1-file.c:618
+msgid "unable to fdopen alternates lockfile"
+msgstr ""
+
+#: sha1-file.c:636
+msgid "unable to read alternates file"
+msgstr ""
+
+#: sha1-file.c:643
+msgid "unable to move new alternates file into place"
+msgstr ""
+
+#: sha1-file.c:678
+#, c-format
+msgid "path '%s' does not exist"
+msgstr ""
+
+#: sha1-file.c:704
+#, c-format
+msgid "reference repository '%s' as a linked checkout is not supported yet."
+msgstr ""
+
+#: sha1-file.c:710
+#, c-format
+msgid "reference repository '%s' is not a local repository."
+msgstr ""
+
+#: sha1-file.c:716
+#, c-format
+msgid "reference repository '%s' is shallow"
+msgstr ""
+
+#: sha1-file.c:724
+#, c-format
+msgid "reference repository '%s' is grafted"
+msgstr ""
+
+#: sha1-file.c:838
+#, c-format
+msgid "attempting to mmap %<PRIuMAX> over limit %<PRIuMAX>"
+msgstr ""
+
+#: sha1-file.c:863
+msgid "mmap failed"
+msgstr ""
+
+#: sha1-file.c:1027
+#, c-format
+msgid "object file %s is empty"
+msgstr ""
+
+#: sha1-file.c:1151 sha1-file.c:2288
+#, c-format
+msgid "corrupt loose object '%s'"
+msgstr ""
+
+#: sha1-file.c:1153 sha1-file.c:2292
+#, c-format
+msgid "garbage at end of loose object '%s'"
+msgstr ""
+
+#: sha1-file.c:1195
+msgid "invalid object type"
+msgstr ""
+
+#: sha1-file.c:1279
+#, c-format
+msgid "unable to unpack %s header with --allow-unknown-type"
+msgstr ""
+
+#: sha1-file.c:1282
+#, c-format
+msgid "unable to unpack %s header"
+msgstr ""
+
+#: sha1-file.c:1288
+#, c-format
+msgid "unable to parse %s header with --allow-unknown-type"
+msgstr ""
+
+#: sha1-file.c:1291
+#, c-format
+msgid "unable to parse %s header"
+msgstr ""
+
+#: sha1-file.c:1481
+#, c-format
+msgid "failed to read object %s"
+msgstr ""
+
+#: sha1-file.c:1485
+#, c-format
+msgid "replacement %s not found for %s"
+msgstr ""
+
+#: sha1-file.c:1489
+#, c-format
+msgid "loose object %s (stored in %s) is corrupt"
+msgstr ""
+
+#: sha1-file.c:1493
+#, c-format
+msgid "packed object %s (stored in %s) is corrupt"
+msgstr ""
+
+#: sha1-file.c:1595
+#, c-format
+msgid "unable to write file %s"
+msgstr ""
+
+#: sha1-file.c:1602
+#, c-format
+msgid "unable to set permission to '%s'"
+msgstr ""
+
+#: sha1-file.c:1609
+msgid "file write error"
+msgstr ""
+
+#: sha1-file.c:1628
+msgid "error when closing loose object file"
+msgstr ""
+
+#: sha1-file.c:1693
+#, c-format
+msgid "insufficient permission for adding an object to repository database %s"
+msgstr ""
+
+#: sha1-file.c:1695
+msgid "unable to create temporary file"
+msgstr ""
+
+#: sha1-file.c:1719
+msgid "unable to write loose object file"
+msgstr ""
+
+#: sha1-file.c:1725
+#, c-format
+msgid "unable to deflate new object %s (%d)"
+msgstr ""
+
+#: sha1-file.c:1729
+#, c-format
+msgid "deflateEnd on object %s failed (%d)"
+msgstr ""
+
+#: sha1-file.c:1733
+#, c-format
+msgid "confused by unstable object source data for %s"
+msgstr ""
+
+#: sha1-file.c:1743 builtin/pack-objects.c:919
+#, c-format
+msgid "failed utime() on %s"
+msgstr ""
+
+#: sha1-file.c:1818
+#, c-format
+msgid "cannot read object for %s"
+msgstr ""
+
+#: sha1-file.c:1858
+msgid "corrupt commit"
+msgstr ""
+
+#: sha1-file.c:1866
+msgid "corrupt tag"
+msgstr ""
+
+#: sha1-file.c:1965
+#, c-format
+msgid "read error while indexing %s"
+msgstr ""
+
+#: sha1-file.c:1968
+#, c-format
+msgid "short read while indexing %s"
+msgstr ""
+
+#: sha1-file.c:2041 sha1-file.c:2050
+#, c-format
+msgid "%s: failed to insert into database"
+msgstr ""
+
+#: sha1-file.c:2056
+#, c-format
+msgid "%s: unsupported file type"
+msgstr ""
+
+#: sha1-file.c:2080
+#, c-format
+msgid "%s is not a valid object"
+msgstr ""
+
+#: sha1-file.c:2082
+#, c-format
+msgid "%s is not a valid '%s' object"
+msgstr ""
+
+#: sha1-file.c:2109 builtin/index-pack.c:154
+#, c-format
+msgid "unable to open %s"
+msgstr "δεν είναι δυνατό το άνοιγμα του %s"
+
+#: sha1-file.c:2299 sha1-file.c:2351
+#, c-format
+msgid "hash mismatch for %s (expected %s)"
+msgstr ""
+
+#: sha1-file.c:2323
+#, c-format
+msgid "unable to mmap %s"
+msgstr ""
+
+#: sha1-file.c:2328
+#, c-format
+msgid "unable to unpack header of %s"
+msgstr ""
+
+#: sha1-file.c:2334
+#, c-format
+msgid "unable to parse header of %s"
+msgstr ""
+
+#: sha1-file.c:2345
+#, c-format
+msgid "unable to unpack contents of %s"
+msgstr ""
+
+#: sha1-name.c:448
+#, c-format
+msgid "short SHA1 %s is ambiguous"
+msgstr ""
+
+#: sha1-name.c:459
+msgid "The candidates are:"
+msgstr ""
+
+#: sha1-name.c:742
+msgid ""
+"Git normally never creates a ref that ends with 40 hex characters\n"
+"because it will be ignored when you just specify 40-hex. These refs\n"
+"may be created by mistake. For example,\n"
+"\n"
+"  git checkout -b $br $(git rev-parse ...)\n"
+"\n"
+"where \"$br\" is somehow empty and a 40-hex ref is created. Please\n"
+"examine these refs and maybe delete them. Turn this message off by\n"
+"running \"git config advice.objectNameWarning false\""
+msgstr ""
+
+#: submodule.c:114 submodule.c:143
+msgid "Cannot change unmerged .gitmodules, resolve merge conflicts first"
+msgstr ""
+"Δεν είναι δυνατή η αλλαγή μη συγχωνευμένων .gitmodule, επιλύστε πρώτα τις "
+"συγκρούσεις συγχώνευσης"
+
+#: submodule.c:118 submodule.c:147
+#, c-format
+msgid "Could not find section in .gitmodules where path=%s"
+msgstr ""
+
+#: submodule.c:154
+#, c-format
+msgid "Could not remove .gitmodules entry for %s"
+msgstr ""
+
+#: submodule.c:165
+msgid "staging updated .gitmodules failed"
+msgstr ""
+
+#: submodule.c:327
+#, c-format
+msgid "in unpopulated submodule '%s'"
+msgstr ""
+
+#: submodule.c:358
+#, c-format
+msgid "Pathspec '%s' is in submodule '%.*s'"
+msgstr "Η περιγραφή διαδρομής '%s' βρίσκεται μέσα στην υποενότητα '%.*s'"
+
+#: submodule.c:906
+#, c-format
+msgid "submodule entry '%s' (%s) is a %s, not a commit"
+msgstr "το στοιχείο υποενότητας '%s' (%s) είναι %s, όχι υποβολή"
+
+#: submodule.c:1143 builtin/branch.c:656 builtin/submodule--helper.c:1989
+msgid "Failed to resolve HEAD as a valid ref."
+msgstr "Απέτυχε η ταύτιση του HEAD με κάποιο έγκυρο ref."
+
+#: submodule.c:1477
+#, c-format
+msgid "Could not access submodule '%s'"
+msgstr ""
+
+#: submodule.c:1639
+#, c-format
+msgid "'%s' not recognized as a git repository"
+msgstr ""
+
+#: submodule.c:1777
+#, c-format
+msgid "could not start 'git status' in submodule '%s'"
+msgstr ""
+
+#: submodule.c:1790
+#, c-format
+msgid "could not run 'git status' in submodule '%s'"
+msgstr ""
+
+#: submodule.c:1805
+#, c-format
+msgid "Could not unset core.worktree setting in submodule '%s'"
+msgstr ""
+
+#: submodule.c:1895
+#, c-format
+msgid "submodule '%s' has dirty index"
+msgstr ""
+
+#: submodule.c:1947
+#, c-format
+msgid "Submodule '%s' could not be updated."
+msgstr ""
+
+#: submodule.c:1996
+#, c-format
+msgid ""
+"relocate_gitdir for submodule '%s' with more than one worktree not supported"
+msgstr ""
+
+#: submodule.c:2008 submodule.c:2064
+#, c-format
+msgid "could not lookup name for submodule '%s'"
+msgstr ""
+
+#: submodule.c:2015
+#, c-format
+msgid ""
+"Migrating git directory of '%s%s' from\n"
+"'%s' to\n"
+"'%s'\n"
+msgstr ""
+
+#: submodule.c:2099
+#, c-format
+msgid "could not recurse into submodule '%s'"
+msgstr ""
+
+#: submodule.c:2143
+msgid "could not start ls-files in .."
+msgstr ""
+
+#: submodule.c:2182
+#, c-format
+msgid "ls-tree returned unexpected return code %d"
+msgstr ""
+
+#: submodule-config.c:232
+#, c-format
+msgid "ignoring suspicious submodule name: %s"
+msgstr ""
+
+#: submodule-config.c:296
+msgid "negative values not allowed for submodule.fetchjobs"
+msgstr ""
+
+#: submodule-config.c:390
+#, c-format
+msgid "ignoring '%s' which may be interpreted as a command-line option: %s"
+msgstr ""
+
+#: submodule-config.c:479
+#, c-format
+msgid "invalid value for %s"
+msgstr ""
+
+#: submodule-config.c:754
+#, c-format
+msgid "Could not update .gitmodules entry %s"
+msgstr ""
+
+#: trailer.c:238
+#, c-format
+msgid "running trailer command '%s' failed"
+msgstr ""
+
+#: trailer.c:485 trailer.c:490 trailer.c:495 trailer.c:549 trailer.c:553
+#: trailer.c:557
+#, c-format
+msgid "unknown value '%s' for key '%s'"
+msgstr ""
+
+#: trailer.c:539 trailer.c:544 builtin/remote.c:295
+#, c-format
+msgid "more than one %s"
+msgstr ""
+
+#: trailer.c:730
+#, c-format
+msgid "empty trailer token in trailer '%.*s'"
+msgstr ""
+
+#: trailer.c:750
+#, c-format
+msgid "could not read input file '%s'"
+msgstr ""
+
+#: trailer.c:753
+msgid "could not read from stdin"
+msgstr ""
+
+#: trailer.c:1011 wrapper.c:701
+#, c-format
+msgid "could not stat %s"
+msgstr ""
+
+#: trailer.c:1013
+#, c-format
+msgid "file %s is not a regular file"
+msgstr ""
+
+#: trailer.c:1015
+#, c-format
+msgid "file %s is not writable by user"
+msgstr ""
+
+#: trailer.c:1027
+msgid "could not open temporary file"
+msgstr "δεν ήταν δυνατό το άνοιγμα του προσωρινού αρχείου"
+
+#: trailer.c:1067
+#, c-format
+msgid "could not rename temporary file to %s"
+msgstr "δεν ήταν δυνατή η μετονομασία προσωρινού αρχείου σε %s"
+
+#: transport.c:116
+#, c-format
+msgid "Would set upstream of '%s' to '%s' of '%s'\n"
+msgstr "Θα όριζε το προς τα πάνω του '%s' ως '%s' του '%s'\n"
+
+#: transport.c:142
+#, c-format
+msgid "could not read bundle '%s'"
+msgstr ""
+
+#: transport.c:208
+#, c-format
+msgid "transport: invalid depth option '%s'"
+msgstr ""
+
+#: transport.c:617
+msgid "could not parse transport.color.* config"
+msgstr ""
+
+#: transport.c:690
+msgid "support for protocol v2 not implemented yet"
+msgstr ""
+
+#: transport.c:817
+#, c-format
+msgid "unknown value for config '%s': %s"
+msgstr ""
+
+#: transport.c:883
+#, c-format
+msgid "transport '%s' not allowed"
+msgstr ""
+
+#: transport.c:937
+msgid "git-over-rsync is no longer supported"
+msgstr ""
+
+#: transport.c:1032
+#, c-format
+msgid ""
+"The following submodule paths contain changes that can\n"
+"not be found on any remote:\n"
+msgstr ""
+"Οι παρακάτω διαδρομές υποενότητας περιέχουν αλλαγές που δεν είναι\n"
+"δυνατό να βρεθούν σε κανέναν απομακρυσμένο εξυπηρετητή:\n"
+
+#: transport.c:1036
+#, c-format
+msgid ""
+"\n"
+"Please try\n"
+"\n"
+"\tgit push --recurse-submodules=on-demand\n"
+"\n"
+"or cd to the path and use\n"
+"\n"
+"\tgit push\n"
+"\n"
+"to push them to a remote.\n"
+"\n"
+msgstr ""
+"\n"
+"Παρακαλώ δοκιμάστε\n"
+"\n"
+"\tgit push --recurse-submodules=on-demand\n"
+"\n"
+"ή κάντε cd στη διαδρομή και χρησιμοποιήστε\n"
+"\n"
+"\tgit push\n"
+"\n"
+"για να τα δημοσιεύσετε σε έναν απομακρυσμένο εξυπηρετητή.\n"
+"\n"
+
+#: transport.c:1044
+msgid "Aborting."
+msgstr "Εγκατάλειψη."
+
+#: transport.c:1184
+msgid "failed to push all needed submodules"
+msgstr ""
+
+#: transport.c:1317 transport-helper.c:643
+msgid "operation not supported by protocol"
+msgstr ""
+
+#: transport.c:1421
+#, c-format
+msgid "invalid line while parsing alternate refs: %s"
+msgstr ""
+
+#: transport-helper.c:51 transport-helper.c:80
+msgid "full write to remote helper failed"
+msgstr ""
+
+#: transport-helper.c:132
+#, c-format
+msgid "unable to find remote helper for '%s'"
+msgstr ""
+
+#: transport-helper.c:148 transport-helper.c:557
+msgid "can't dup helper output fd"
+msgstr ""
+
+#: transport-helper.c:199
+#, c-format
+msgid ""
+"unknown mandatory capability %s; this remote helper probably needs newer "
+"version of Git"
+msgstr ""
+
+#: transport-helper.c:205
+msgid "this remote helper should implement refspec capability"
+msgstr ""
+
+#: transport-helper.c:272 transport-helper.c:412
+#, c-format
+msgid "%s unexpectedly said: '%s'"
+msgstr ""
+
+#: transport-helper.c:401
+#, c-format
+msgid "%s also locked %s"
+msgstr ""
+
+#: transport-helper.c:479
+msgid "couldn't run fast-import"
+msgstr ""
+
+#: transport-helper.c:502
+msgid "error while running fast-import"
+msgstr ""
+
+#: transport-helper.c:531 transport-helper.c:1097
+#, c-format
+msgid "could not read ref %s"
+msgstr ""
+
+#: transport-helper.c:576
+#, c-format
+msgid "unknown response to connect: %s"
+msgstr ""
+
+#: transport-helper.c:598
+msgid "setting remote service path not supported by protocol"
+msgstr ""
+
+#: transport-helper.c:600
+msgid "invalid remote service path"
+msgstr ""
+
+#: transport-helper.c:646
+#, c-format
+msgid "can't connect to subservice %s"
+msgstr ""
+
+#: transport-helper.c:718
+#, c-format
+msgid "expected ok/error, helper said '%s'"
+msgstr ""
+
+#: transport-helper.c:771
+#, c-format
+msgid "helper reported unexpected status of %s"
+msgstr ""
+
+#: transport-helper.c:832
+#, c-format
+msgid "helper %s does not support dry-run"
+msgstr ""
+
+#: transport-helper.c:835
+#, c-format
+msgid "helper %s does not support --signed"
+msgstr ""
+
+#: transport-helper.c:838
+#, c-format
+msgid "helper %s does not support --signed=if-asked"
+msgstr ""
+
+#: transport-helper.c:845
+#, c-format
+msgid "helper %s does not support 'push-option'"
+msgstr ""
+
+#: transport-helper.c:937
+msgid "remote-helper doesn't support push; refspec needed"
+msgstr ""
+
+#: transport-helper.c:942
+#, c-format
+msgid "helper %s does not support 'force'"
+msgstr ""
+
+#: transport-helper.c:989
+msgid "couldn't run fast-export"
+msgstr ""
+
+#: transport-helper.c:994
+msgid "error while running fast-export"
+msgstr ""
+
+#: transport-helper.c:1019
+#, c-format
+msgid ""
+"No refs in common and none specified; doing nothing.\n"
+"Perhaps you should specify a branch such as 'master'.\n"
+msgstr ""
+
+#: transport-helper.c:1083
+#, c-format
+msgid "malformed response in ref list: %s"
+msgstr ""
+
+#: transport-helper.c:1236
+#, c-format
+msgid "read(%s) failed"
+msgstr ""
+
+#: transport-helper.c:1263
+#, c-format
+msgid "write(%s) failed"
+msgstr ""
+
+#: transport-helper.c:1312
+#, c-format
+msgid "%s thread failed"
+msgstr ""
+
+#: transport-helper.c:1316
+#, c-format
+msgid "%s thread failed to join: %s"
+msgstr ""
+
+#: transport-helper.c:1335 transport-helper.c:1339
+#, c-format
+msgid "can't start thread for copying data: %s"
+msgstr ""
+
+#: transport-helper.c:1376
+#, c-format
+msgid "%s process failed to wait"
+msgstr ""
+
+#: transport-helper.c:1380
+#, c-format
+msgid "%s process failed"
+msgstr ""
+
+#: transport-helper.c:1398 transport-helper.c:1407
+msgid "can't start thread for copying data"
+msgstr ""
+
+#: tree-walk.c:33
+msgid "too-short tree object"
+msgstr ""
+
+#: tree-walk.c:39
+msgid "malformed mode in tree entry"
+msgstr ""
+
+#: tree-walk.c:43
+msgid "empty filename in tree entry"
+msgstr ""
+
+#: tree-walk.c:116
+msgid "too-short tree file"
+msgstr ""
+
+#: unpack-trees.c:111
+#, c-format
+msgid ""
+"Your local changes to the following files would be overwritten by checkout:\n"
+"%%sPlease commit your changes or stash them before you switch branches."
+msgstr ""
+"Οι τοπικές αλλαγές σας στα ακόλουθα αρχεία θα επεγγραφόντουσαν από την "
+"εξαγωγή:\n"
+"%%sΠαρακαλώ υποβάλετε τις αλλαγές σας ή αποθηκεύστε τις πριν αλλάξετε κλάδο."
+
+#: unpack-trees.c:113
+#, c-format
+msgid ""
+"Your local changes to the following files would be overwritten by checkout:\n"
+"%%s"
+msgstr ""
+"Οι τοπικές αλλαγές σας στα ακόλουθα αρχεία θα επεγγραφόντουσαν από την "
+"εξαγωγή:\n"
+"%%s"
+
+#: unpack-trees.c:116
+#, c-format
+msgid ""
+"Your local changes to the following files would be overwritten by merge:\n"
+"%%sPlease commit your changes or stash them before you merge."
+msgstr ""
+"Οι τοπικές αλλαγές σας στα ακόλουθα αρχεία θα επεγγραφόντουσαν από τη "
+"συγχώνευση:\n"
+"%%sΠαρακαλώ υποβάλετε τις αλλαγές σας ή αποθηκεύστε τις πριν συγχωνεύσετε."
+
+#: unpack-trees.c:118
+#, c-format
+msgid ""
+"Your local changes to the following files would be overwritten by merge:\n"
+"%%s"
+msgstr ""
+"Οι τοπικές αλλαγές σας στα ακόλουθα αρχεία θα επεγγραφόντουσαν από τη "
+"συγχώνευση:\n"
+"%%s"
+
+#: unpack-trees.c:121
+#, c-format
+msgid ""
+"Your local changes to the following files would be overwritten by %s:\n"
+"%%sPlease commit your changes or stash them before you %s."
+msgstr ""
+"Οι τοπικές αλλαγές σας στα ακόλουθα αρχεία θα επεγγραφόντουσαν από το %s:\n"
+"%%sΠαρακαλώ υποβάλετε τις αλλαγές σας ή αποθηκεύστε τις πριν από το %s."
+
+#: unpack-trees.c:123
+#, c-format
+msgid ""
+"Your local changes to the following files would be overwritten by %s:\n"
+"%%s"
+msgstr ""
+"Οι τοπικές αλλαγές σας στα ακόλουθα αρχεία θα επεγγραφόντουσαν από το %s:\n"
+"%%s"
+
+#: unpack-trees.c:128
+#, c-format
+msgid ""
+"Updating the following directories would lose untracked files in them:\n"
+"%s"
+msgstr ""
+
+#: unpack-trees.c:132
+#, c-format
+msgid ""
+"The following untracked working tree files would be removed by checkout:\n"
+"%%sPlease move or remove them before you switch branches."
+msgstr ""
+
+#: unpack-trees.c:134
+#, c-format
+msgid ""
+"The following untracked working tree files would be removed by checkout:\n"
+"%%s"
+msgstr ""
+
+#: unpack-trees.c:137
+#, c-format
+msgid ""
+"The following untracked working tree files would be removed by merge:\n"
+"%%sPlease move or remove them before you merge."
+msgstr ""
+
+#: unpack-trees.c:139
+#, c-format
+msgid ""
+"The following untracked working tree files would be removed by merge:\n"
+"%%s"
+msgstr ""
+
+#: unpack-trees.c:142
+#, c-format
+msgid ""
+"The following untracked working tree files would be removed by %s:\n"
+"%%sPlease move or remove them before you %s."
+msgstr ""
+
+#: unpack-trees.c:144
+#, c-format
+msgid ""
+"The following untracked working tree files would be removed by %s:\n"
+"%%s"
+msgstr ""
+
+#: unpack-trees.c:150
+#, c-format
+msgid ""
+"The following untracked working tree files would be overwritten by "
+"checkout:\n"
+"%%sPlease move or remove them before you switch branches."
+msgstr ""
+
+#: unpack-trees.c:152
+#, c-format
+msgid ""
+"The following untracked working tree files would be overwritten by "
+"checkout:\n"
+"%%s"
+msgstr ""
+
+#: unpack-trees.c:155
+#, c-format
+msgid ""
+"The following untracked working tree files would be overwritten by merge:\n"
+"%%sPlease move or remove them before you merge."
+msgstr ""
+
+#: unpack-trees.c:157
+#, c-format
+msgid ""
+"The following untracked working tree files would be overwritten by merge:\n"
+"%%s"
+msgstr ""
+
+#: unpack-trees.c:160
+#, c-format
+msgid ""
+"The following untracked working tree files would be overwritten by %s:\n"
+"%%sPlease move or remove them before you %s."
+msgstr ""
+
+#: unpack-trees.c:162
+#, c-format
+msgid ""
+"The following untracked working tree files would be overwritten by %s:\n"
+"%%s"
+msgstr ""
+
+#: unpack-trees.c:170
+#, c-format
+msgid "Entry '%s' overlaps with '%s'.  Cannot bind."
+msgstr ""
+
+#: unpack-trees.c:173
+#, c-format
+msgid ""
+"Cannot update sparse checkout: the following entries are not up to date:\n"
+"%s"
+msgstr ""
+
+#: unpack-trees.c:175
+#, c-format
+msgid ""
+"The following working tree files would be overwritten by sparse checkout "
+"update:\n"
+"%s"
+msgstr ""
+
+#: unpack-trees.c:177
+#, c-format
+msgid ""
+"The following working tree files would be removed by sparse checkout "
+"update:\n"
+"%s"
+msgstr ""
+
+#: unpack-trees.c:179
+#, c-format
+msgid ""
+"Cannot update submodule:\n"
+"%s"
+msgstr ""
+
+#: unpack-trees.c:253
+#, c-format
+msgid "Aborting\n"
+msgstr "Εγκατάλειψη\n"
+
+#: unpack-trees.c:335
+msgid "Checking out files"
+msgstr ""
+
+#: unpack-trees.c:367
+msgid ""
+"the following paths have collided (e.g. case-sensitive paths\n"
+"on a case-insensitive filesystem) and only one from the same\n"
+"colliding group is in the working tree:\n"
+msgstr ""
+
+#: urlmatch.c:163
+msgid "invalid URL scheme name or missing '://' suffix"
+msgstr ""
+
+#: urlmatch.c:187 urlmatch.c:346 urlmatch.c:405
+#, c-format
+msgid "invalid %XX escape sequence"
+msgstr ""
+
+#: urlmatch.c:215
+msgid "missing host and scheme is not 'file:'"
+msgstr ""
+
+#: urlmatch.c:232
+msgid "a 'file:' URL may not have a port number"
+msgstr ""
+
+#: urlmatch.c:247
+msgid "invalid characters in host name"
+msgstr ""
+
+#: urlmatch.c:292 urlmatch.c:303
+msgid "invalid port number"
+msgstr ""
+
+#: urlmatch.c:371
+msgid "invalid '..' path segment"
+msgstr ""
+
+#: worktree.c:249 builtin/am.c:2094
+#, c-format
+msgid "failed to read '%s'"
+msgstr ""
+
+#: worktree.c:295
+#, c-format
+msgid "'%s' at main working tree is not the repository directory"
+msgstr ""
+
+#: worktree.c:306
+#, c-format
+msgid "'%s' file does not contain absolute path to the working tree location"
+msgstr ""
+
+#: worktree.c:318
+#, c-format
+msgid "'%s' does not exist"
+msgstr ""
+
+#: worktree.c:324
+#, c-format
+msgid "'%s' is not a .git file, error code %d"
+msgstr ""
+
+#: worktree.c:332
+#, c-format
+msgid "'%s' does not point back to '%s'"
+msgstr ""
+
+#: wrapper.c:223 wrapper.c:393
+#, c-format
+msgid "could not open '%s' for reading and writing"
+msgstr "δεν ήταν δυνατό το άνοιγμα του '%s' για ανάγνωση και εγγραφή"
+
+#: wrapper.c:424 wrapper.c:624
+#, c-format
+msgid "unable to access '%s'"
+msgstr ""
+
+#: wrapper.c:632
+msgid "unable to get current working directory"
+msgstr ""
+
+#: wt-status.c:155
+msgid "Unmerged paths:"
+msgstr "Μη συγχωνευμένες διαδρομές:"
+
+#: wt-status.c:182 wt-status.c:209
+#, c-format
+msgid "  (use \"git reset %s <file>...\" to unstage)"
+msgstr ""
+"  (χρησιμοποιήστε \"git reset %s <αρχείο>...\" για να αποπροετοιμάσετε)"
+
+#: wt-status.c:184 wt-status.c:211
+msgid "  (use \"git rm --cached <file>...\" to unstage)"
+msgstr ""
+"  (χρησιμοποιήστε \"git rm --cached <αρχείο>...\" για να αποπροετοιμάσετε)"
+
+#: wt-status.c:188
+msgid "  (use \"git add <file>...\" to mark resolution)"
+msgstr ""
+"  (χρησιμοποιήστε \"git add <αρχείο>...\" έτσι ώστε να επισημάνετε την "
+"επίλυση)"
+
+#: wt-status.c:190 wt-status.c:194
+msgid "  (use \"git add/rm <file>...\" as appropriate to mark resolution)"
+msgstr ""
+"  (χρησιμοποιήστε \"git add/rm <αρχείο>...\" έτσι ώστε να επισημάνετε την "
+"επίλυση)"
+
+#: wt-status.c:192
+msgid "  (use \"git rm <file>...\" to mark resolution)"
+msgstr ""
+"  (χρησιμοποιήστε \"git rm <αρχείο>...\" έτσι ώστε να επισημάνετε την "
+"επίλυση)"
+
+#: wt-status.c:203 wt-status.c:1046
+msgid "Changes to be committed:"
+msgstr "Αλλαγές προς υποβολή:"
+
+#: wt-status.c:221 wt-status.c:1055
+msgid "Changes not staged for commit:"
+msgstr "Αλλαγές που δεν έχουν προετοιμαστεί για υποβολή:"
+
+#: wt-status.c:225
+msgid "  (use \"git add <file>...\" to update what will be committed)"
+msgstr ""
+"  (χρησιμοποιήστε \"git add <αρχείο>...\" για να ενημερώσετε αυτά που θα "
+"υποβληθούν)"
+
+#: wt-status.c:227
+msgid "  (use \"git add/rm <file>...\" to update what will be committed)"
+msgstr ""
+"  (χρησιμοποιήστε \"git add/rm <αρχείο>...\" για να ενημερώσετε αυτά που θα "
+"υποβληθούν)"
+
+#: wt-status.c:228
+msgid ""
+"  (use \"git checkout -- <file>...\" to discard changes in working directory)"
+msgstr ""
+"  (χρησιμοποιήστε \"git checkout -- <αρχείο>...\" για να απορρίψετε τις "
+"αλλαγές στο φάκελο εργασίας)"
+
+#: wt-status.c:230
+msgid "  (commit or discard the untracked or modified content in submodules)"
+msgstr ""
+"  (να γίνει υποβολή ή απόρριψη του μη παρακολουθούμενου ή τροποποιημένου "
+"περιεχομένου στις υποενότητες)"
+
+#: wt-status.c:242
+#, c-format
+msgid "  (use \"git %s <file>...\" to include in what will be committed)"
+msgstr ""
+"  (χρησιμοποιήστε \"git %s <αρχείο>...\" για να συμπεριληφθεί σε αυτά που θα "
+"υποβληθούν)"
+
+#: wt-status.c:257
+msgid "both deleted:"
+msgstr "διαγραφή και από τους δύο:"
+
+#: wt-status.c:259
+msgid "added by us:"
+msgstr "προσθήκη από εμάς:"
+
+#: wt-status.c:261
+msgid "deleted by them:"
+msgstr "διαγραφή από αυτούς:"
+
+#: wt-status.c:263
+msgid "added by them:"
+msgstr "προσθήκη από αυτούς:"
+
+#: wt-status.c:265
+msgid "deleted by us:"
+msgstr "διαγραφή από εμάς:"
+
+#: wt-status.c:267
+msgid "both added:"
+msgstr "προσθήκη και από τους δύο:"
+
+#: wt-status.c:269
+msgid "both modified:"
+msgstr "τροποποίηση και από τους δύο:"
+
+#: wt-status.c:279
+msgid "new file:"
+msgstr "νέο αρχείο:"
+
+#: wt-status.c:281
+msgid "copied:"
+msgstr "αντιγραφή:"
+
+#: wt-status.c:283
+msgid "deleted:"
+msgstr "διαγραφή:"
+
+#: wt-status.c:285
+msgid "modified:"
+msgstr "τροποποίηση:"
+
+#: wt-status.c:287
+msgid "renamed:"
+msgstr "μετονομασία:"
+
+#: wt-status.c:289
+msgid "typechange:"
+msgstr "αλλαγή τύπου:"
+
+#: wt-status.c:291
+msgid "unknown:"
+msgstr "άγνωστο:"
+
+#: wt-status.c:293
+msgid "unmerged:"
+msgstr "μη συγχωνευμένο:"
+
+#: wt-status.c:373
+msgid "new commits, "
+msgstr "νέες υποβολές, "
+
+#: wt-status.c:375
+msgid "modified content, "
+msgstr "τροποποιημένο περιεχόμενο, "
+
+#: wt-status.c:377
+msgid "untracked content, "
+msgstr "μη παρακολουθούμενο περιεχόμενο, "
+
+#: wt-status.c:884
+#, c-format
+msgid "Your stash currently has %d entry"
+msgid_plural "Your stash currently has %d entries"
+msgstr[0] "Η αποθήκευσή σας έχει τώρα %d στοιχείο"
+msgstr[1] "Η αποθήκευσή σας έχει τώρα %d στοιχεία"
+
+#: wt-status.c:916
+msgid "Submodules changed but not updated:"
+msgstr "Υποενότητες που άλλαξαν αλλά δεν ενημερώθηκαν:"
+
+#: wt-status.c:918
+msgid "Submodule changes to be committed:"
+msgstr "Αλλαγές σε υποενότητες προς υποβολή:"
+
+#: wt-status.c:1000
+msgid ""
+"Do not modify or remove the line above.\n"
+"Everything below it will be ignored."
+msgstr ""
+"Να μην τροποποιήσετε ή αφαιρέσετε την παραπάνω γραμμή.\n"
+"Οτιδήποτε κάτω από αυτήν θα αγνοηθεί."
+
+#: wt-status.c:1101
+msgid "You have unmerged paths."
+msgstr "Έχετε μη συγχωνευμένες διαδρομές."
+
+#: wt-status.c:1104
+msgid "  (fix conflicts and run \"git commit\")"
+msgstr "  (διορθώστε τις συγκρούσεις και τρέξτε \"git commit\")"
+
+#: wt-status.c:1106
+msgid "  (use \"git merge --abort\" to abort the merge)"
+msgstr ""
+"  (χρησιμοποιήστε \"git merge --abort\" για να εγκαταλείψετε τη συγχώνευση)"
+
+#: wt-status.c:1110
+msgid "All conflicts fixed but you are still merging."
+msgstr "Επιλύθηκαν όλες οι συγκρούσεις αλλά ακόμα κάνετε συγχώνευση."
+
+#: wt-status.c:1113
+msgid "  (use \"git commit\" to conclude merge)"
+msgstr "  (χρησιμοποιήστε \"git commit\" για να ολοκληρώσετε τη συγχώνευση)"
+
+#: wt-status.c:1122
+msgid "You are in the middle of an am session."
+msgstr "Βρίσκεστε στη μέση μιας διεργασίας am."
+
+#: wt-status.c:1125
+msgid "The current patch is empty."
+msgstr "Η παρούσα διόρθωση είναι κενή."
+
+#: wt-status.c:1129
+msgid "  (fix conflicts and then run \"git am --continue\")"
+msgstr "  (διορθώστε τις συγκρούσεις και τρέξτε \"git am --continue\")"
+
+#: wt-status.c:1131
+msgid "  (use \"git am --skip\" to skip this patch)"
+msgstr ""
+"  (χρησιμοποιήστε \"git am --skip\" για να προσπεράσετε αυτή τη διόρθωση)"
+
+#: wt-status.c:1133
+msgid "  (use \"git am --abort\" to restore the original branch)"
+msgstr ""
+"  (χρησιμοποιήστε \"git am --abort\" για να αποκαταστήσετε τον αρχικό κλάδο)"
+
+#: wt-status.c:1264
+msgid "git-rebase-todo is missing."
+msgstr "Λείπει το git-rebase-todo."
+
+#: wt-status.c:1266
+msgid "No commands done."
+msgstr "Δεν ολοκληρώθηκε καμία εντολή."
+
+#: wt-status.c:1269
+#, c-format
+msgid "Last command done (%d command done):"
+msgid_plural "Last commands done (%d commands done):"
+msgstr[0] ""
+msgstr[1] ""
+
+#: wt-status.c:1280
+#, c-format
+msgid "  (see more in file %s)"
+msgstr "  (δείτε περισσότερα στο αρχείο %s)"
+
+#: wt-status.c:1285
+msgid "No commands remaining."
+msgstr "Δεν απομένει καμία εντολή."
+
+#: wt-status.c:1288
+#, c-format
+msgid "Next command to do (%d remaining command):"
+msgid_plural "Next commands to do (%d remaining commands):"
+msgstr[0] "Επόμενη εντολή προς εκτέλεση (%d εντολή απομένει):"
+msgstr[1] "Επόμενες εντολές προς εκτέλεση (%d εντολές απομένουν):"
+
+#: wt-status.c:1296
+msgid "  (use \"git rebase --edit-todo\" to view and edit)"
+msgstr ""
+"  (χρησιμοποιήστε \"git rebase --edit-todo\" για προβολή και επεξεργασία)"
+
+#: wt-status.c:1308
+#, c-format
+msgid "You are currently rebasing branch '%s' on '%s'."
+msgstr "Αυτή τη στιγμή κάνετε rebase τον κλάδο '%s' στο '%s'."
+
+#: wt-status.c:1313
+msgid "You are currently rebasing."
+msgstr "Αυτή τη στιγμή κάνετε rebase."
+
+#: wt-status.c:1326
+msgid "  (fix conflicts and then run \"git rebase --continue\")"
+msgstr "  (διορθώστε τις συγκρούσεις και τρέξτε \"git rebase --continue\")"
+
+#: wt-status.c:1328
+msgid "  (use \"git rebase --skip\" to skip this patch)"
+msgstr ""
+"  (χρησιμοποιήστε \"git rebase --skip\" για να προσπεράσετε αυτή τη διόρθωση)"
+
+#: wt-status.c:1330
+msgid "  (use \"git rebase --abort\" to check out the original branch)"
+msgstr ""
+"  (χρησιμοποιήστε \"git rebase --abort\" για να εξαγάγετε τον αρχικό κλάδο)"
+
+#: wt-status.c:1337
+msgid "  (all conflicts fixed: run \"git rebase --continue\")"
+msgstr "  (επιλύθηκαν όλες οι συγκρούσεις: τρέξτε \"git rebase --continue\")"
+
+#: wt-status.c:1341
+#, c-format
+msgid ""
+"You are currently splitting a commit while rebasing branch '%s' on '%s'."
+msgstr ""
+"Αυτή τη στιγμή τεμαχίζετε μια υποβολή κατά τη διάρκεια rebase του κλάδου "
+"'%s' στο '%s'."
+
+#: wt-status.c:1346
+msgid "You are currently splitting a commit during a rebase."
+msgstr "Αυτή τη στιγμή τεμαχίζετε μια υποβολή κατά τη διάρκεια ενός rebase."
+
+#: wt-status.c:1349
+msgid "  (Once your working directory is clean, run \"git rebase --continue\")"
+msgstr ""
+"  (Όταν ο φάκελος εργασίας σας θα είναι καθαρός, τρέξτε \"git rebase --"
+"continue\")"
+
+#: wt-status.c:1353
+#, c-format
+msgid "You are currently editing a commit while rebasing branch '%s' on '%s'."
+msgstr ""
+"Αυτή τη στιγμή διορθώνετε μια υποβολή κατά τη διάρκεια rebase του κλάδου "
+"'%s' στο '%s'."
+
+#: wt-status.c:1358
+msgid "You are currently editing a commit during a rebase."
+msgstr "Αυτή τη στιγμή διορθώνετε μια υποβολή κατά τη διάρκεια ενός rebase."
+
+#: wt-status.c:1361
+msgid "  (use \"git commit --amend\" to amend the current commit)"
+msgstr ""
+"  (χρησιμοποιήστε \"git commit --amend\" για να τροποποιήσετε την τρέχουσα "
+"υποβολή)"
+
+#: wt-status.c:1363
+msgid ""
+"  (use \"git rebase --continue\" once you are satisfied with your changes)"
+msgstr ""
+"  (χρησιμοποιήστε \"git rebase --continue\" όταν οι αλλαγές σας σας "
+"ικανοποιούν)"
+
+#: wt-status.c:1372
+#, c-format
+msgid "You are currently cherry-picking commit %s."
+msgstr "Αυτή τη στιγμή κάνετε επιλεκτική διαλογή της υποβολής %s."
+
+#: wt-status.c:1377
+msgid "  (fix conflicts and run \"git cherry-pick --continue\")"
+msgstr ""
+"  (διορθώστε τις συγκρούσεις και τρέξτε \"git cherry-pick --continue\")"
+
+#: wt-status.c:1380
+msgid "  (all conflicts fixed: run \"git cherry-pick --continue\")"
+msgstr ""
+"  (επιλύθηκαν όλες οι συγκρούσεις: τρέξτε \"git cherry-pick --continue\")"
+
+#: wt-status.c:1382
+msgid "  (use \"git cherry-pick --abort\" to cancel the cherry-pick operation)"
+msgstr ""
+"  (χρησιμοποιήστε \"git cherry-pick --abort\" για να ακυρώσετε την ενέργεια "
+"επιλεκτικής διαλογής)"
+
+#: wt-status.c:1390
+#, c-format
+msgid "You are currently reverting commit %s."
+msgstr "Αυτή τη στιγμή αναιρείτε την υποβολή %s."
+
+#: wt-status.c:1395
+msgid "  (fix conflicts and run \"git revert --continue\")"
+msgstr "  (επιλύστε τις συγκρούσεις και τρέξτε \"git revert --continue\")"
+
+#: wt-status.c:1398
+msgid "  (all conflicts fixed: run \"git revert --continue\")"
+msgstr "  (επιλύθηκαν όλες οι συγκρούσεις: τρέξτε \"git revert --continue\")"
+
+#: wt-status.c:1400
+msgid "  (use \"git revert --abort\" to cancel the revert operation)"
+msgstr ""
+"  (χρησιμοποιήστε \"git revert --abort\" για να εγκαταλείψετε τη διεργασία "
+"revert)"
+
+#: wt-status.c:1410
+#, c-format
+msgid "You are currently bisecting, started from branch '%s'."
+msgstr "Αυτή τη στιγμή διχοτομείτε, έγινε αρχή από τον κλάδο '%s'."
+
+#: wt-status.c:1414
+msgid "You are currently bisecting."
+msgstr "Αυτή τη στιγμή διχοτομείτε."
+
+#: wt-status.c:1417
+msgid "  (use \"git bisect reset\" to get back to the original branch)"
+msgstr ""
+"  (χρησιμοποιήστε \"git bisect reset\" για να επιστρέψετε στον αρχικό κλάδο)"
+
+#: wt-status.c:1617
+msgid "On branch "
+msgstr "Στον κλάδο "
+
+#: wt-status.c:1624
+msgid "interactive rebase in progress; onto "
+msgstr "εκτελείται διαδραστικό rebase, πάνω στο "
+
+#: wt-status.c:1626
+msgid "rebase in progress; onto "
+msgstr "εκτελείται rebase, πάνω στο "
+
+#: wt-status.c:1631
+msgid "HEAD detached at "
+msgstr "Αποσυνδεδεμένο HEAD στο "
+
+#: wt-status.c:1633
+msgid "HEAD detached from "
+msgstr "Αποσυνδεδεμένο HEAD από το "
+
+#: wt-status.c:1636
+msgid "Not currently on any branch."
+msgstr "Δεν είστε αυτή τη στιγμή σε κανέναν κλάδο."
+
+#: wt-status.c:1653
+msgid "Initial commit"
+msgstr "Αρχική υποβολή"
+
+#: wt-status.c:1654
+msgid "No commits yet"
+msgstr "Δεν υπάρχουν ακόμα υποβολές"
+
+#: wt-status.c:1668
+msgid "Untracked files"
+msgstr "Μη παρακολουθούμενα αρχεία"
+
+#: wt-status.c:1670
+msgid "Ignored files"
+msgstr "Αρχεία που παραβλέπονται"
+
+#: wt-status.c:1674
+#, c-format
+msgid ""
+"It took %.2f seconds to enumerate untracked files. 'status -uno'\n"
+"may speed it up, but you have to be careful not to forget to add\n"
+"new files yourself (see 'git help status')."
+msgstr ""
+"Η απαρίθμηση των μη παρακολουθούμενων αρχείων πήρε %.2f δευτερόλεπτα. Το "
+"'status -uno'\n"
+"μπορεί να την επιταχύνει, αλλά πρέπει να προσέξετε να μην ξεχάσετε να "
+"προσθέσετε\n"
+"εσείς τα νέα αρχεία (δείτε το 'git help status')."
+
+#: wt-status.c:1680
+#, c-format
+msgid "Untracked files not listed%s"
+msgstr "Μη παρακολουθούμενα αρχεία που δεν έγινε παράθεσή τους%s"
+
+#: wt-status.c:1682
+msgid " (use -u option to show untracked files)"
+msgstr ""
+" (χρησιμοποιήστε την επιλογή -u για να γίνει προβολή των μη "
+"παρακολουθούμενων αρχείων)"
+
+#: wt-status.c:1688
+msgid "No changes"
+msgstr "Δεν υπάρχουν αλλαγές"
+
+#: wt-status.c:1693
+#, c-format
+msgid "no changes added to commit (use \"git add\" and/or \"git commit -a\")\n"
+msgstr ""
+"δεν προστέθηκαν αλλαγές στην υποβολή (χρησιμοποιήστε \"git add\" και/ή \"git "
+"commit -a\")\n"
+
+#: wt-status.c:1696
+#, c-format
+msgid "no changes added to commit\n"
+msgstr "δεν προστέθηκαν αλλαγές στην υποβολή\n"
+
+#: wt-status.c:1699
+#, c-format
+msgid ""
+"nothing added to commit but untracked files present (use \"git add\" to "
+"track)\n"
+msgstr ""
+"δεν προστέθηκε τίποτα στην υποβολή αλλά υπάρχουν μη παρακολουθούμενα αρχεία "
+"(χρησιμοποιήστε \"git add\" για να παρακολουθήσετε)\n"
+
+#: wt-status.c:1702
+#, c-format
+msgid "nothing added to commit but untracked files present\n"
+msgstr ""
+"δεν προστέθηκε τίποτα στην υποβολή αλλά υπάρχουν μη παρακολουθούμενα αρχεία\n"
+
+#: wt-status.c:1705
+#, c-format
+msgid "nothing to commit (create/copy files and use \"git add\" to track)\n"
+msgstr ""
+"δεν υπάρχει τίποτα προς υποβολή (δημιουργήστε/αντιγράψτε αρχεία και "
+"χρησιμοποιήστε \"git add\" για να παρακολουθήσετε)\n"
+
+#: wt-status.c:1708 wt-status.c:1713
+#, c-format
+msgid "nothing to commit\n"
+msgstr "δεν υπάρχει τίποτα προς υποβολή\n"
+
+#: wt-status.c:1711
+#, c-format
+msgid "nothing to commit (use -u to show untracked files)\n"
+msgstr ""
+"δεν υπάρχει τίποτα προς υποβολή (χρησιμοποιήστε -u για προβολή των "
+"μηπαρακολουθούμενων αρχείων)\n"
+
+#: wt-status.c:1715
+#, c-format
+msgid "nothing to commit, working tree clean\n"
+msgstr "δεν υπάρχει τίποτα προς υποβολή, το δέντρο εργασίας είναι καθαρό\n"
+
+#: wt-status.c:1828
+msgid "No commits yet on "
+msgstr "Δεν υπάρχουν ακόμα υποβολές στο "
+
+#: wt-status.c:1832
+msgid "HEAD (no branch)"
+msgstr "HEAD (χωρίς κλάδο)"
+
+#: wt-status.c:1863
+msgid "different"
+msgstr "διαφορετικό"
+
+#: wt-status.c:1865 wt-status.c:1873
+msgid "behind "
+msgstr "πίσω "
+
+#: wt-status.c:1868 wt-status.c:1871
+msgid "ahead "
+msgstr "μπροστά "
+
+#. TRANSLATORS: the action is e.g. "pull with rebase"
+#: wt-status.c:2386
+#, c-format
+msgid "cannot %s: You have unstaged changes."
+msgstr "δεν είναι δυνατό να γίνει %s: Έχετε μη προετοιμασμένες αλλαγές."
+
+#: wt-status.c:2392
+msgid "additionally, your index contains uncommitted changes."
+msgstr "επιπρόσθετα, το ευρετήριό σας περιέχει μη υποβεβλημένες αλλαγές."
+
+#: wt-status.c:2394
+#, c-format
+msgid "cannot %s: Your index contains uncommitted changes."
+msgstr ""
+"δεν είναι δυνατό να γίνει %s: Το ευρετήριό σας περιέχει μη υποβεβλημένες "
+"αλλαγές."
+
+#: builtin/add.c:25
+msgid "git add [<options>] [--] <pathspec>..."
+msgstr "git add [<επιλογές>] [--] <περιγραφή διαδρομής>..."
+
+#: builtin/add.c:84
+#, c-format
+msgid "unexpected diff status %c"
+msgstr ""
+
+#: builtin/add.c:89 builtin/commit.c:285
+msgid "updating files failed"
+msgstr ""
+
+#: builtin/add.c:99
+#, c-format
+msgid "remove '%s'\n"
+msgstr ""
+
+#: builtin/add.c:174
+msgid "Unstaged changes after refreshing the index:"
+msgstr ""
+
+#: builtin/add.c:234 builtin/rev-parse.c:896
+msgid "Could not read the index"
+msgstr ""
+
+#: builtin/add.c:245
+#, c-format
+msgid "Could not open '%s' for writing."
+msgstr "Δεν ήταν δυνατό το άνοιγμα του '%s' για εγγραφή."
+
+#: builtin/add.c:249
+msgid "Could not write patch"
+msgstr ""
+
+#: builtin/add.c:252
+msgid "editing patch failed"
+msgstr ""
+
+#: builtin/add.c:255
+#, c-format
+msgid "Could not stat '%s'"
+msgstr ""
+
+#: builtin/add.c:257
+msgid "Empty patch. Aborted."
+msgstr ""
+
+#: builtin/add.c:262
+#, c-format
+msgid "Could not apply '%s'"
+msgstr ""
+
+#: builtin/add.c:270
+msgid "The following paths are ignored by one of your .gitignore files:\n"
+msgstr ""
+
+#: builtin/add.c:290 builtin/clean.c:908 builtin/fetch.c:137 builtin/mv.c:124
+#: builtin/prune-packed.c:56 builtin/pull.c:214 builtin/push.c:560
+#: builtin/remote.c:1345 builtin/rm.c:241 builtin/send-pack.c:165
+msgid "dry run"
+msgstr "δοκιμή"
+
+#: builtin/add.c:293
+msgid "interactive picking"
+msgstr ""
+
+#: builtin/add.c:294 builtin/checkout.c:1304 builtin/reset.c:306
+msgid "select hunks interactively"
+msgstr "να γίνει διαδραστική επιλογή αλλαγών"
+
+#: builtin/add.c:295
+msgid "edit current diff and apply"
+msgstr ""
+
+#: builtin/add.c:296
+msgid "allow adding otherwise ignored files"
+msgstr ""
+
+#: builtin/add.c:297
+msgid "update tracked files"
+msgstr ""
+
+#: builtin/add.c:298
+msgid "renormalize EOL of tracked files (implies -u)"
+msgstr ""
+
+#: builtin/add.c:299
+msgid "record only the fact that the path will be added later"
+msgstr ""
+
+#: builtin/add.c:300
+msgid "add changes from all tracked and untracked files"
+msgstr ""
+
+#: builtin/add.c:303
+msgid "ignore paths removed in the working tree (same as --no-all)"
+msgstr ""
+
+#: builtin/add.c:305
+msgid "don't add, only refresh the index"
+msgstr ""
+
+#: builtin/add.c:306
+msgid "just skip files which cannot be added because of errors"
+msgstr ""
+
+#: builtin/add.c:307
+msgid "check if - even missing - files are ignored in dry run"
+msgstr ""
+
+#: builtin/add.c:309 builtin/update-index.c:991
+msgid "override the executable bit of the listed files"
+msgstr ""
+
+#: builtin/add.c:311
+msgid "warn when adding an embedded repository"
+msgstr ""
+
+#: builtin/add.c:326
+#, c-format
+msgid ""
+"You've added another git repository inside your current repository.\n"
+"Clones of the outer repository will not contain the contents of\n"
+"the embedded repository and will not know how to obtain it.\n"
+"If you meant to add a submodule, use:\n"
+"\n"
+"\tgit submodule add <url> %s\n"
+"\n"
+"If you added this path by mistake, you can remove it from the\n"
+"index with:\n"
+"\n"
+"\tgit rm --cached %s\n"
+"\n"
+"See \"git help submodule\" for more information."
+msgstr ""
+"Προσθέσατε ένα άλλο αποθετήριο git μέσα στο τρέχον αποθετήριο.\n"
+"Οι κλώνοι του εξώτερου αποθετηρίου δε θα περιέχουν τα περιεχόμενα του\n"
+"ενσωματωμένου αποθετηρίου και δεν θα γνωρίζουν πώς να το βρουν.\n"
+"Αν θέλατε να προσθέσετε μια υποενότητα submodule, χρησιμοποιήστε:\n"
+"\n"
+"\tgit submodule add <url> %s\n"
+"\n"
+"Αν προσθέσατε αυτή τη διαδρομή κατά λάθος, μπορείτε να την αφαιρέσετε από "
+"το\n"
+"ευρετήριο με:\n"
+"\n"
+"\tgit rm --cached %s\n"
+"\n"
+"Δείτε \"git help submodule\" για περισσότερες πληροφορίες."
+
+#: builtin/add.c:354
+#, c-format
+msgid "adding embedded git repository: %s"
+msgstr ""
+
+#: builtin/add.c:372
+#, c-format
+msgid "Use -f if you really want to add them.\n"
+msgstr ""
+
+#: builtin/add.c:380
+msgid "adding files failed"
+msgstr ""
+
+#: builtin/add.c:418
+msgid "-A and -u are mutually incompatible"
+msgstr ""
+
+#: builtin/add.c:425
+msgid "Option --ignore-missing can only be used together with --dry-run"
+msgstr ""
+
+#: builtin/add.c:429
+#, c-format
+msgid "--chmod param '%s' must be either -x or +x"
+msgstr ""
+
+#: builtin/add.c:444
+#, c-format
+msgid "Nothing specified, nothing added.\n"
+msgstr ""
+
+#: builtin/add.c:445
+#, c-format
+msgid "Maybe you wanted to say 'git add .'?\n"
+msgstr ""
+
+#: builtin/am.c:348
+msgid "could not parse author script"
+msgstr ""
+
+#: builtin/am.c:432
+#, c-format
+msgid "'%s' was deleted by the applypatch-msg hook"
+msgstr ""
+
+#: builtin/am.c:473
+#, c-format
+msgid "Malformed input line: '%s'."
+msgstr ""
+
+#: builtin/am.c:510
+#, c-format
+msgid "Failed to copy notes from '%s' to '%s'"
+msgstr ""
+
+#: builtin/am.c:536
+msgid "fseek failed"
+msgstr ""
+
+#: builtin/am.c:724
+#, c-format
+msgid "could not parse patch '%s'"
+msgstr ""
+
+#: builtin/am.c:789
+msgid "Only one StGIT patch series can be applied at once"
+msgstr ""
+
+#: builtin/am.c:837
+msgid "invalid timestamp"
+msgstr ""
+
+#: builtin/am.c:842 builtin/am.c:854
+msgid "invalid Date line"
+msgstr ""
+
+#: builtin/am.c:849
+msgid "invalid timezone offset"
+msgstr ""
+
+#: builtin/am.c:942
+msgid "Patch format detection failed."
+msgstr ""
+
+#: builtin/am.c:947 builtin/clone.c:409
+#, c-format
+msgid "failed to create directory '%s'"
+msgstr "απέτυχε η δημιουργία του φακέλου '%s'"
+
+#: builtin/am.c:952
+msgid "Failed to split patches."
+msgstr ""
+
+#: builtin/am.c:1082 builtin/commit.c:371
+msgid "unable to write index file"
+msgstr ""
+
+#: builtin/am.c:1096
+#, c-format
+msgid "When you have resolved this problem, run \"%s --continue\"."
+msgstr "Όταν έχετε επιλύσει αυτό το πρόβλημα, τρέξτε \"%s --continue\"."
+
+#: builtin/am.c:1097
+#, c-format
+msgid "If you prefer to skip this patch, run \"%s --skip\" instead."
+msgstr ""
+
+#: builtin/am.c:1098
+#, c-format
+msgid "To restore the original branch and stop patching, run \"%s --abort\"."
+msgstr ""
+
+#: builtin/am.c:1181
+msgid "Patch sent with format=flowed; space at the end of lines might be lost."
+msgstr ""
+
+#: builtin/am.c:1209
+msgid "Patch is empty."
+msgstr ""
+
+#: builtin/am.c:1275
+#, c-format
+msgid "invalid ident line: %.*s"
+msgstr ""
+
+#: builtin/am.c:1297
+#, c-format
+msgid "unable to parse commit %s"
+msgstr ""
+
+#: builtin/am.c:1493
+msgid "Repository lacks necessary blobs to fall back on 3-way merge."
+msgstr ""
+"Λείπουν τα αναγκαία blob από το αποθετήριο για να ακολουθηθεί η εναλλακτική "
+"τριπλής συγχώνευσης."
+
+#: builtin/am.c:1495
+msgid "Using index info to reconstruct a base tree..."
+msgstr ""
+
+#: builtin/am.c:1514
+msgid ""
+"Did you hand edit your patch?\n"
+"It does not apply to blobs recorded in its index."
+msgstr ""
+"Επεξεργαστήκατε με το χέρι τη διόρθωσή σας;\n"
+"Δεν εφαρμόζεται στα blob που είναι καταγεγραμμένα στο ευρετήριό του."
+
+#: builtin/am.c:1520
+msgid "Falling back to patching base and 3-way merge..."
+msgstr ""
+
+#: builtin/am.c:1546
+msgid "Failed to merge in the changes."
+msgstr ""
+
+#: builtin/am.c:1578
+msgid "applying to an empty history"
+msgstr ""
+
+#: builtin/am.c:1624 builtin/am.c:1628
+#, c-format
+msgid "cannot resume: %s does not exist."
+msgstr ""
+
+#: builtin/am.c:1644
+msgid "cannot be interactive without stdin connected to a terminal."
+msgstr ""
+
+#: builtin/am.c:1649
+msgid "Commit Body is:"
+msgstr "Το περιεχόμενο της υποβολής είναι:"
+
+#. TRANSLATORS: Make sure to include [y], [n], [e], [v] and [a]
+#. in your translation. The program will only accept English
+#. input at this point.
+#.
+#: builtin/am.c:1659
+msgid "Apply? [y]es/[n]o/[e]dit/[v]iew patch/[a]ccept all: "
+msgstr "Να γίνει εφαρμογή; [y]es/[n]o/[e]dit/[v]iew patch/[a]ccept all: "
+
+#: builtin/am.c:1709
+#, c-format
+msgid "Dirty index: cannot apply patches (dirty: %s)"
+msgstr ""
+
+#: builtin/am.c:1749 builtin/am.c:1817
+#, c-format
+msgid "Applying: %.*s"
+msgstr ""
+
+#: builtin/am.c:1766
+msgid "No changes -- Patch already applied."
+msgstr "Καθόλου αλλαγές -- Έχει γίνει ήδη εφαρμογή της διόρθωσης."
+
+#: builtin/am.c:1772
+#, c-format
+msgid "Patch failed at %s %.*s"
+msgstr ""
+
+#: builtin/am.c:1776
+msgid "Use 'git am --show-current-patch' to see the failed patch"
+msgstr ""
+"Χρησιμοποιήστε 'git am --show-current-patch' για να δείτε τη διόρθωση που "
+"απέτυχε"
+
+#: builtin/am.c:1820
+msgid ""
+"No changes - did you forget to use 'git add'?\n"
+"If there is nothing left to stage, chances are that something else\n"
+"already introduced the same changes; you might want to skip this patch."
+msgstr ""
+"Καθόλου αλλαγές - ξεχάσατε να χρησιμοποιήσετε το 'git add';\n"
+"Αν δεν έχει απομείνει τίποτα για προετοιμασία, μάλλον κάτι άλλο έχει\n"
+"ήδη εισαγάγει τις ίδιες αλλαγές, μπορεί να θέλετε να προσπεράσετε αυτή τη "
+"διόρθωση."
+
+#: builtin/am.c:1827
+msgid ""
+"You still have unmerged paths in your index.\n"
+"You should 'git add' each file with resolved conflicts to mark them as "
+"such.\n"
+"You might run `git rm` on a file to accept \"deleted by them\" for it."
+msgstr ""
+"Έχετε ακόμα μη συγχωνευμένες διαδρομές στο ευρετήριό σας.\n"
+"Θα πρέπει να προσθέσετε με 'git add' κάθε αρχείο που έχει επιλυμένες "
+"συγκρούσεις για να το επισημάνετε.\n"
+"Μπορείτε να τρέξετε `git rm` σε ένα αρχείο για να αποδεχθείτε για αυτό πως "
+"\"διαγράφηκε από αυτούς\"."
+
+#: builtin/am.c:1934 builtin/am.c:1938 builtin/am.c:1950 builtin/reset.c:329
+#: builtin/reset.c:337
+#, c-format
+msgid "Could not parse object '%s'."
+msgstr "Δεν ήταν δυνατή η ανάλυση του αντικειμένου '%s'."
+
+#: builtin/am.c:1986
+msgid "failed to clean index"
+msgstr ""
+
+#: builtin/am.c:2030
+msgid ""
+"You seem to have moved HEAD since the last 'am' failure.\n"
+"Not rewinding to ORIG_HEAD"
+msgstr ""
+"Φαίνεται πως μετακινήσατε το HEAD από τη στιγμή της τελευταίας αποτυχίας "
+"'am'.\n"
+"Δε γίνεται γύρισμα προς τα πίσω στο ORIG_HEAD"
+
+#: builtin/am.c:2123
+#, c-format
+msgid "Invalid value for --patch-format: %s"
+msgstr ""
+
+#: builtin/am.c:2159
+msgid "git am [<options>] [(<mbox> | <Maildir>)...]"
+msgstr "git am [<επιλογές>] [(<mbox> | <Maildir>)...]"
+
+#: builtin/am.c:2160
+msgid "git am [<options>] (--continue | --skip | --abort)"
+msgstr "git am [<επιλογές>] (--continue | --skip | --abort)"
+
+#: builtin/am.c:2166
+msgid "run interactively"
+msgstr ""
+
+#: builtin/am.c:2168
+msgid "historical option -- no-op"
+msgstr ""
+
+#: builtin/am.c:2170
+msgid "allow fall back on 3way merging if needed"
+msgstr ""
+
+#: builtin/am.c:2171 builtin/init-db.c:486 builtin/prune-packed.c:58
+#: builtin/repack.c:306
+msgid "be quiet"
+msgstr ""
+
+#: builtin/am.c:2173
+msgid "add a Signed-off-by line to the commit message"
+msgstr ""
+
+#: builtin/am.c:2176
+msgid "recode into utf8 (default)"
+msgstr ""
+
+#: builtin/am.c:2178
+msgid "pass -k flag to git-mailinfo"
+msgstr ""
+
+#: builtin/am.c:2180
+msgid "pass -b flag to git-mailinfo"
+msgstr ""
+
+#: builtin/am.c:2182
+msgid "pass -m flag to git-mailinfo"
+msgstr ""
+
+#: builtin/am.c:2184
+msgid "pass --keep-cr flag to git-mailsplit for mbox format"
+msgstr ""
+
+#: builtin/am.c:2187
+msgid "do not pass --keep-cr flag to git-mailsplit independent of am.keepcr"
+msgstr ""
+
+#: builtin/am.c:2190
+msgid "strip everything before a scissors line"
+msgstr ""
+
+#: builtin/am.c:2192 builtin/am.c:2195 builtin/am.c:2198 builtin/am.c:2201
+#: builtin/am.c:2204 builtin/am.c:2207 builtin/am.c:2210 builtin/am.c:2213
+#: builtin/am.c:2219
+msgid "pass it through git-apply"
+msgstr ""
+
+#: builtin/am.c:2209 builtin/commit.c:1343 builtin/fmt-merge-msg.c:671
+#: builtin/fmt-merge-msg.c:674 builtin/grep.c:879 builtin/merge.c:240
+#: builtin/pull.c:152 builtin/pull.c:210 builtin/rebase.c:1062
+#: builtin/repack.c:317 builtin/repack.c:321 builtin/repack.c:323
+#: builtin/show-branch.c:651 builtin/show-ref.c:171 builtin/tag.c:386
+#: parse-options.h:144 parse-options.h:146 parse-options.h:266
+msgid "n"
+msgstr ""
+
+#: builtin/am.c:2215 builtin/branch.c:637 builtin/for-each-ref.c:38
+#: builtin/replace.c:544 builtin/tag.c:422 builtin/verify-tag.c:39
+msgid "format"
+msgstr ""
+
+#: builtin/am.c:2216
+msgid "format the patch(es) are in"
+msgstr ""
+
+#: builtin/am.c:2222
+msgid "override error message when patch failure occurs"
+msgstr ""
+
+#: builtin/am.c:2224
+msgid "continue applying patches after resolving a conflict"
+msgstr ""
+
+#: builtin/am.c:2227
+msgid "synonyms for --continue"
+msgstr ""
+
+#: builtin/am.c:2230
+msgid "skip the current patch"
+msgstr ""
+
+#: builtin/am.c:2233
+msgid "restore the original branch and abort the patching operation."
+msgstr ""
+
+#: builtin/am.c:2236
+msgid "abort the patching operation but keep HEAD where it is."
+msgstr ""
+
+#: builtin/am.c:2239
+msgid "show the patch being applied."
+msgstr ""
+
+#: builtin/am.c:2243
+msgid "lie about committer date"
+msgstr ""
+
+#: builtin/am.c:2245
+msgid "use current timestamp for author date"
+msgstr ""
+
+#: builtin/am.c:2247 builtin/commit.c:1486 builtin/merge.c:274
+#: builtin/pull.c:185 builtin/rebase.c:1106 builtin/rebase--interactive.c:185
+#: builtin/revert.c:114 builtin/tag.c:402
+msgid "key-id"
+msgstr ""
+
+#: builtin/am.c:2248 builtin/rebase.c:1107 builtin/rebase--interactive.c:186
+msgid "GPG-sign commits"
+msgstr ""
+
+#: builtin/am.c:2251
+msgid "(internal use for git-rebase)"
+msgstr ""
+
+#: builtin/am.c:2269
+msgid ""
+"The -b/--binary option has been a no-op for long time, and\n"
+"it will be removed. Please do not use it anymore."
+msgstr ""
+
+#: builtin/am.c:2276
+msgid "failed to read the index"
+msgstr ""
+
+#: builtin/am.c:2291
+#, c-format
+msgid "previous rebase directory %s still exists but mbox given."
+msgstr ""
+
+#: builtin/am.c:2315
+#, c-format
+msgid ""
+"Stray %s directory found.\n"
+"Use \"git am --abort\" to remove it."
+msgstr ""
+
+#: builtin/am.c:2321
+msgid "Resolve operation not in progress, we are not resuming."
+msgstr "Δεν υφίσταται διεργασία επίλυσης, δε συνεχίζουμε."
+
+#: builtin/apply.c:8
+msgid "git apply [<options>] [<patch>...]"
+msgstr "git apply [<επιλογές>] [<διόρθωση>...]"
+
+#: builtin/archive.c:17
+#, c-format
+msgid "could not create archive file '%s'"
+msgstr ""
+
+#: builtin/archive.c:20
+msgid "could not redirect output"
+msgstr ""
+
+#: builtin/archive.c:37
+msgid "git archive: Remote with no URL"
+msgstr "git archive: Απομακρυσμένος εξυπηρετητής χωρίς URL"
+
+#: builtin/archive.c:61
+msgid "git archive: expected ACK/NAK, got a flush packet"
+msgstr "git archive: αναμενόταν ACK/NAK, βρέθηκε πακέτο flush"
+
+#: builtin/archive.c:64
+#, c-format
+msgid "git archive: NACK %s"
+msgstr "git archive: NACK %s"
+
+#: builtin/archive.c:65
+msgid "git archive: protocol error"
+msgstr "git archive: σφάλμα πρωτοκόλλου επικοινωνίας"
+
+#: builtin/archive.c:69
+msgid "git archive: expected a flush"
+msgstr "git archive: αναμενόταν flush"
+
+#: builtin/bisect--helper.c:22
+msgid "git bisect--helper --next-all [--no-checkout]"
+msgstr "git bisect--helper --next-all [--no-checkout]"
+
+#: builtin/bisect--helper.c:23
+msgid "git bisect--helper --write-terms <bad_term> <good_term>"
+msgstr "git bisect--helper --write-terms <λάθος όρος> <σωστός όρος>"
+
+#: builtin/bisect--helper.c:24
+msgid "git bisect--helper --bisect-clean-state"
+msgstr "git bisect--helper --bisect-clean-state"
+
+#: builtin/bisect--helper.c:25
+msgid "git bisect--helper --bisect-reset [<commit>]"
+msgstr "git bisect--helper --bisect-reset [<υποβολή>]"
+
+#: builtin/bisect--helper.c:26
+msgid ""
+"git bisect--helper --bisect-write [--no-log] <state> <revision> <good_term> "
+"<bad_term>"
+msgstr ""
+"git bisect--helper --bisect-write [--no-log] <κατάσταση> <έκδοση> <σωστός "
+"όρος> <λάθος όρος>"
+
+#: builtin/bisect--helper.c:27
+msgid ""
+"git bisect--helper --bisect-check-and-set-terms <command> <good_term> "
+"<bad_term>"
+msgstr ""
+"git bisect--helper --bisect-check-and-set-terms <εντολή> <σωστός όρος> "
+"<λάθος όρος>"
+
+#: builtin/bisect--helper.c:28
+msgid "git bisect--helper --bisect-next-check <good_term> <bad_term> [<term>]"
+msgstr ""
+"git bisect--helper --bisect-next-check <σωστός όρος> <λάθος όρος> [<όρος>]"
+
+#: builtin/bisect--helper.c:29
+msgid ""
+"git bisect--helper --bisect-terms [--term-good | --term-old | --term-bad | --"
+"term-new]"
+msgstr ""
+"git bisect--helper --bisect-terms [--term-good | --term-old | --term-bad | --"
+"term-new]"
+
+#: builtin/bisect--helper.c:30
+msgid ""
+"git bisect--helper --bisect-start [--term-{old,good}=<term> --term-{new,bad}"
+"=<term>][--no-checkout] [<bad> [<good>...]] [--] [<paths>...]"
+msgstr ""
+"git bisect--helper --bisect-start [--term-{old,good}=<όρος> --term-{new,bad}"
+"=<όρος>][--no-checkout] [<λάθος> [<σωστό>...]] [--] [<διαδρομές>...]"
+
+#: builtin/bisect--helper.c:86
+#, c-format
+msgid "'%s' is not a valid term"
+msgstr ""
+
+#: builtin/bisect--helper.c:90
+#, c-format
+msgid "can't use the builtin command '%s' as a term"
+msgstr ""
+
+#: builtin/bisect--helper.c:100
+#, c-format
+msgid "can't change the meaning of the term '%s'"
+msgstr ""
+
+#: builtin/bisect--helper.c:111
+msgid "please use two different terms"
+msgstr ""
+
+#: builtin/bisect--helper.c:118
+msgid "could not open the file BISECT_TERMS"
+msgstr "δεν ήταν δυνατό το άνοιγμα του αρχείου BISECT_TERMS"
+
+#: builtin/bisect--helper.c:155
+#, c-format
+msgid "We are not bisecting.\n"
+msgstr ""
+
+#: builtin/bisect--helper.c:163
+#, c-format
+msgid "'%s' is not a valid commit"
+msgstr ""
+
+#: builtin/bisect--helper.c:174
+#, c-format
+msgid ""
+"could not check out original HEAD '%s'. Try 'git bisect reset <commit>'."
+msgstr ""
+
+#: builtin/bisect--helper.c:215
+#, c-format
+msgid "Bad bisect_write argument: %s"
+msgstr ""
+
+#: builtin/bisect--helper.c:220
+#, c-format
+msgid "couldn't get the oid of the rev '%s'"
+msgstr ""
+
+#: builtin/bisect--helper.c:232
+#, c-format
+msgid "couldn't open the file '%s'"
+msgstr ""
+
+#: builtin/bisect--helper.c:258
+#, c-format
+msgid "Invalid command: you're currently in a %s/%s bisect"
+msgstr ""
+
+#: builtin/bisect--helper.c:285
+#, c-format
+msgid ""
+"You need to give me at least one %s and %s revision.\n"
+"You can use \"git bisect %s\" and \"git bisect %s\" for that."
+msgstr ""
+"Πρέπει να δώσετε τουλάχιστον ένα %s και %s έκδοση.\n"
+"Μπορείτε να χρησιμοποιήσετε \"git bisect %s\" και \"git bisect %s\" για αυτό."
+
+#: builtin/bisect--helper.c:289
+#, c-format
+msgid ""
+"You need to start by \"git bisect start\".\n"
+"You then need to give me at least one %s and %s revision.\n"
+"You can use \"git bisect %s\" and \"git bisect %s\" for that."
+msgstr ""
+"Χρειάζεται να αρχίσετε με \"git bisect start\".\n"
+"Έπειτα χρειάζεται να δώσετε τουλάχιστον ένα %s και %s έκδοση.\n"
+"Μπορείτε να χρησιμοποιήσετε \"git bisect %s\" και \"git bisect %s\" για αυτό."
+
+#: builtin/bisect--helper.c:321
+#, c-format
+msgid "bisecting only with a %s commit"
+msgstr ""
+
+#. TRANSLATORS: Make sure to include [Y] and [n] in your
+#. translation. The program will only accept English input
+#. at this point.
+#.
+#: builtin/bisect--helper.c:329
+msgid "Are you sure [Y/n]? "
+msgstr "Επιβεβαιώνετε [Y/n]; "
+
+#: builtin/bisect--helper.c:376
+msgid "no terms defined"
+msgstr ""
+
+#: builtin/bisect--helper.c:379
+#, c-format
+msgid ""
+"Your current terms are %s for the old state\n"
+"and %s for the new state.\n"
+msgstr ""
+"Οι παρόντες όροι σας είναι %s για την παλιά κατάσταση\n"
+"και %s για τη νέα κατάσταση.\n"
+
+#: builtin/bisect--helper.c:389
+#, c-format
+msgid ""
+"invalid argument %s for 'git bisect terms'.\n"
+"Supported options are: --term-good|--term-old and --term-bad|--term-new."
+msgstr ""
+
+#: builtin/bisect--helper.c:475
+#, c-format
+msgid "unrecognized option: '%s'"
+msgstr ""
+
+#: builtin/bisect--helper.c:479
+#, c-format
+msgid "'%s' does not appear to be a valid revision"
+msgstr ""
+
+#: builtin/bisect--helper.c:511
+msgid "bad HEAD - I need a HEAD"
+msgstr ""
+
+#: builtin/bisect--helper.c:526
+#, c-format
+msgid "checking out '%s' failed. Try 'git bisect start <valid-branch>'."
+msgstr ""
+
+#: builtin/bisect--helper.c:547
+msgid "won't bisect on cg-seek'ed tree"
+msgstr ""
+
+#: builtin/bisect--helper.c:550
+msgid "bad HEAD - strange symbolic ref"
+msgstr ""
+
+#: builtin/bisect--helper.c:627
+msgid "perform 'git bisect next'"
+msgstr ""
+
+#: builtin/bisect--helper.c:629
+msgid "write the terms to .git/BISECT_TERMS"
+msgstr ""
+
+#: builtin/bisect--helper.c:631
+msgid "cleanup the bisection state"
+msgstr ""
+
+#: builtin/bisect--helper.c:633
+msgid "check for expected revs"
+msgstr ""
+
+#: builtin/bisect--helper.c:635
+msgid "reset the bisection state"
+msgstr ""
+
+#: builtin/bisect--helper.c:637
+msgid "write out the bisection state in BISECT_LOG"
+msgstr ""
+
+#: builtin/bisect--helper.c:639
+msgid "check and set terms in a bisection state"
+msgstr ""
+
+#: builtin/bisect--helper.c:641
+msgid "check whether bad or good terms exist"
+msgstr ""
+
+#: builtin/bisect--helper.c:643
+msgid "print out the bisect terms"
+msgstr ""
+
+#: builtin/bisect--helper.c:645
+msgid "start the bisect session"
+msgstr ""
+
+#: builtin/bisect--helper.c:647
+msgid "update BISECT_HEAD instead of checking out the current commit"
+msgstr ""
+
+#: builtin/bisect--helper.c:649
+msgid "no log for BISECT_WRITE"
+msgstr ""
+
+#: builtin/bisect--helper.c:666
+msgid "--write-terms requires two arguments"
+msgstr ""
+
+#: builtin/bisect--helper.c:670
+msgid "--bisect-clean-state requires no arguments"
+msgstr ""
+
+#: builtin/bisect--helper.c:677
+msgid "--bisect-reset requires either no argument or a commit"
+msgstr ""
+
+#: builtin/bisect--helper.c:681
+msgid "--bisect-write requires either 4 or 5 arguments"
+msgstr ""
+
+#: builtin/bisect--helper.c:687
+msgid "--check-and-set-terms requires 3 arguments"
+msgstr ""
+
+#: builtin/bisect--helper.c:693
+msgid "--bisect-next-check requires 2 or 3 arguments"
+msgstr ""
+
+#: builtin/bisect--helper.c:699
+msgid "--bisect-terms requires 0 or 1 argument"
+msgstr ""
+
+#: builtin/blame.c:31
+msgid "git blame [<options>] [<rev-opts>] [<rev>] [--] <file>"
+msgstr "git blame [<επιλογές>] [<επιλογές έκδ.>] [<έκδ.>] [--] <αρχείο>"
+
+#: builtin/blame.c:36
+msgid "<rev-opts> are documented in git-rev-list(1)"
+msgstr ""
+
+#: builtin/blame.c:406
+#, c-format
+msgid "expecting a color: %s"
+msgstr ""
+
+#: builtin/blame.c:413
+msgid "must end with a color"
+msgstr ""
+
+#: builtin/blame.c:700
+#, c-format
+msgid "invalid color '%s' in color.blame.repeatedLines"
+msgstr ""
+
+#: builtin/blame.c:718
+msgid "invalid value for blame.coloring"
+msgstr ""
+
+#: builtin/blame.c:793
+msgid "Show blame entries as we find them, incrementally"
+msgstr ""
+
+#: builtin/blame.c:794
+msgid "Show blank SHA-1 for boundary commits (Default: off)"
+msgstr ""
+
+#: builtin/blame.c:795
+msgid "Do not treat root commits as boundaries (Default: off)"
+msgstr ""
+
+#: builtin/blame.c:796
+msgid "Show work cost statistics"
+msgstr ""
+
+#: builtin/blame.c:797
+msgid "Force progress reporting"
+msgstr ""
+
+#: builtin/blame.c:798
+msgid "Show output score for blame entries"
+msgstr ""
+
+#: builtin/blame.c:799
+msgid "Show original filename (Default: auto)"
+msgstr ""
+
+#: builtin/blame.c:800
+msgid "Show original linenumber (Default: off)"
+msgstr ""
+
+#: builtin/blame.c:801
+msgid "Show in a format designed for machine consumption"
+msgstr ""
+
+#: builtin/blame.c:802
+msgid "Show porcelain format with per-line commit information"
+msgstr "Προβολή μορφής εντολών porcelain με πληροφορίες υποβολής ανά γραμμή"
+
+#: builtin/blame.c:803
+msgid "Use the same output mode as git-annotate (Default: off)"
+msgstr ""
+
+#: builtin/blame.c:804
+msgid "Show raw timestamp (Default: off)"
+msgstr ""
+
+#: builtin/blame.c:805
+msgid "Show long commit SHA1 (Default: off)"
+msgstr ""
+
+#: builtin/blame.c:806
+msgid "Suppress author name and timestamp (Default: off)"
+msgstr ""
+
+#: builtin/blame.c:807
+msgid "Show author email instead of name (Default: off)"
+msgstr ""
+
+#: builtin/blame.c:808
+msgid "Ignore whitespace differences"
+msgstr ""
+
+#: builtin/blame.c:809
+msgid "color redundant metadata from previous line differently"
+msgstr ""
+
+#: builtin/blame.c:810
+msgid "color lines by age"
+msgstr ""
+
+#: builtin/blame.c:817
+msgid "Use an experimental heuristic to improve diffs"
+msgstr ""
+
+#: builtin/blame.c:819
+msgid "Spend extra cycles to find better match"
+msgstr ""
+
+#: builtin/blame.c:820
+msgid "Use revisions from <file> instead of calling git-rev-list"
+msgstr ""
+
+#: builtin/blame.c:821
+msgid "Use <file>'s contents as the final image"
+msgstr ""
+
+#: builtin/blame.c:822 builtin/blame.c:823
+msgid "score"
+msgstr ""
+
+#: builtin/blame.c:822
+msgid "Find line copies within and across files"
+msgstr ""
+
+#: builtin/blame.c:823
+msgid "Find line movements within and across files"
+msgstr ""
+
+#: builtin/blame.c:824
+msgid "n,m"
+msgstr "n,m"
+
+#: builtin/blame.c:824
+msgid "Process only line range n,m, counting from 1"
+msgstr ""
+
+#: builtin/blame.c:875
+msgid "--progress can't be used with --incremental or porcelain formats"
+msgstr ""
+"το --progress δε γίνεται να χρησιμοποιηθεί με το --incremental ή με μορφές "
+"εντολών porcelain"
+
+#. TRANSLATORS: This string is used to tell us the
+#. maximum display width for a relative timestamp in
+#. "git blame" output.  For C locale, "4 years, 11
+#. months ago", which takes 22 places, is the longest
+#. among various forms of relative timestamps, but
+#. your language may need more or fewer display
+#. columns.
+#.
+#: builtin/blame.c:926
+msgid "4 years, 11 months ago"
+msgstr "πριν από 4 χρόνια και 11 μήνες"
+
+#: builtin/blame.c:1018
+#, c-format
+msgid "file %s has only %lu line"
+msgid_plural "file %s has only %lu lines"
+msgstr[0] ""
+msgstr[1] ""
+
+#: builtin/blame.c:1064
+msgid "Blaming lines"
+msgstr ""
+
+#: builtin/branch.c:29
+msgid "git branch [<options>] [-r | -a] [--merged | --no-merged]"
+msgstr "git branch [<επιλογές>] [-r | -a] [--merged | --no-merged]"
+
+#: builtin/branch.c:30
+msgid "git branch [<options>] [-l] [-f] <branch-name> [<start-point>]"
+msgstr "git branch [<επιλογές>] [-l] [-f] <όνομα κλάδου> [<αρχικό σημείο>]"
+
+#: builtin/branch.c:31
+msgid "git branch [<options>] [-r] (-d | -D) <branch-name>..."
+msgstr "git branch [<επιλογές>] [-r] (-d | -D) <όνομα κλάδου>..."
+
+#: builtin/branch.c:32
+msgid "git branch [<options>] (-m | -M) [<old-branch>] <new-branch>"
+msgstr "git branch [<επιλογές>] (-m | -M) [<παλιός κλάδος>] <νέος κλάδος>"
+
+#: builtin/branch.c:33
+msgid "git branch [<options>] (-c | -C) [<old-branch>] <new-branch>"
+msgstr "git branch [<επιλογές>] (-c | -C) [<παλιός κλάδος>] <νέος κλάδος>"
+
+#: builtin/branch.c:34
+msgid "git branch [<options>] [-r | -a] [--points-at]"
+msgstr "git branch [<επιλογές>] [-r | -a] [--points-at]"
+
+#: builtin/branch.c:35
+msgid "git branch [<options>] [-r | -a] [--format]"
+msgstr "git branch [<επιλογές>] [-r | -a] [--format]"
+
+#: builtin/branch.c:151
+#, c-format
+msgid ""
+"deleting branch '%s' that has been merged to\n"
+"         '%s', but not yet merged to HEAD."
+msgstr ""
+
+#: builtin/branch.c:155
+#, c-format
+msgid ""
+"not deleting branch '%s' that is not yet merged to\n"
+"         '%s', even though it is merged to HEAD."
+msgstr ""
+"δε γίνεται διαγραφή του κλάδου '%s' που δεν έχει συγχωνευτεί ακόμα με το\n"
+"         '%s', παρόλο που έχει συγχωνευτεί με το HEAD."
+
+#: builtin/branch.c:169
+#, c-format
+msgid "Couldn't look up commit object for '%s'"
+msgstr ""
+
+#: builtin/branch.c:173
+#, c-format
+msgid ""
+"The branch '%s' is not fully merged.\n"
+"If you are sure you want to delete it, run 'git branch -D %s'."
+msgstr ""
+
+#: builtin/branch.c:186
+msgid "Update of config-file failed"
+msgstr ""
+
+#: builtin/branch.c:217
+msgid "cannot use -a with -d"
+msgstr ""
+
+#: builtin/branch.c:223
+msgid "Couldn't look up commit object for HEAD"
+msgstr ""
+
+#: builtin/branch.c:237
+#, c-format
+msgid "Cannot delete branch '%s' checked out at '%s'"
+msgstr ""
+
+#: builtin/branch.c:252
+#, c-format
+msgid "remote-tracking branch '%s' not found."
+msgstr ""
+
+#: builtin/branch.c:253
+#, c-format
+msgid "branch '%s' not found."
+msgstr ""
+
+#: builtin/branch.c:268
+#, c-format
+msgid "Error deleting remote-tracking branch '%s'"
+msgstr ""
+
+#: builtin/branch.c:269
+#, c-format
+msgid "Error deleting branch '%s'"
+msgstr ""
+
+#: builtin/branch.c:276
+#, c-format
+msgid "Deleted remote-tracking branch %s (was %s).\n"
+msgstr ""
+
+#: builtin/branch.c:277
+#, c-format
+msgid "Deleted branch %s (was %s).\n"
+msgstr ""
+
+#: builtin/branch.c:421 builtin/tag.c:59
+msgid "unable to parse format string"
+msgstr ""
+
+#: builtin/branch.c:458
+#, c-format
+msgid "Branch %s is being rebased at %s"
+msgstr ""
+
+#: builtin/branch.c:462
+#, c-format
+msgid "Branch %s is being bisected at %s"
+msgstr ""
+
+#: builtin/branch.c:479
+msgid "cannot copy the current branch while not on any."
+msgstr ""
+
+#: builtin/branch.c:481
+msgid "cannot rename the current branch while not on any."
+msgstr ""
+
+#: builtin/branch.c:492
+#, c-format
+msgid "Invalid branch name: '%s'"
+msgstr ""
+
+#: builtin/branch.c:519
+msgid "Branch rename failed"
+msgstr ""
+
+#: builtin/branch.c:521
+msgid "Branch copy failed"
+msgstr ""
+
+#: builtin/branch.c:525
+#, c-format
+msgid "Created a copy of a misnamed branch '%s'"
+msgstr ""
+
+#: builtin/branch.c:528
+#, c-format
+msgid "Renamed a misnamed branch '%s' away"
+msgstr ""
+
+#: builtin/branch.c:534
+#, c-format
+msgid "Branch renamed to %s, but HEAD is not updated!"
+msgstr ""
+
+#: builtin/branch.c:543
+msgid "Branch is renamed, but update of config-file failed"
+msgstr ""
+
+#: builtin/branch.c:545
+msgid "Branch is copied, but update of config-file failed"
+msgstr ""
+
+#: builtin/branch.c:561
+#, c-format
+msgid ""
+"Please edit the description for the branch\n"
+"  %s\n"
+"Lines starting with '%c' will be stripped.\n"
+msgstr ""
+
+#: builtin/branch.c:594
+msgid "Generic options"
+msgstr ""
+
+#: builtin/branch.c:596
+msgid "show hash and subject, give twice for upstream branch"
+msgstr ""
+
+#: builtin/branch.c:597
+msgid "suppress informational messages"
+msgstr ""
+
+#: builtin/branch.c:598
+msgid "set up tracking mode (see git-pull(1))"
+msgstr ""
+
+#: builtin/branch.c:600
+msgid "do not use"
+msgstr ""
+
+#: builtin/branch.c:602 builtin/rebase--interactive.c:182
+msgid "upstream"
+msgstr "προς τα πάνω"
+
+#: builtin/branch.c:602
+msgid "change the upstream info"
+msgstr ""
+
+#: builtin/branch.c:603
+msgid "Unset the upstream info"
+msgstr ""
+
+#: builtin/branch.c:604
+msgid "use colored output"
+msgstr ""
+
+#: builtin/branch.c:605
+msgid "act on remote-tracking branches"
+msgstr ""
+
+#: builtin/branch.c:607 builtin/branch.c:609
+msgid "print only branches that contain the commit"
+msgstr ""
+
+#: builtin/branch.c:608 builtin/branch.c:610
+msgid "print only branches that don't contain the commit"
+msgstr ""
+
+#: builtin/branch.c:613
+msgid "Specific git-branch actions:"
+msgstr ""
+
+#: builtin/branch.c:614
+msgid "list both remote-tracking and local branches"
+msgstr ""
+
+#: builtin/branch.c:616
+msgid "delete fully merged branch"
+msgstr ""
+
+#: builtin/branch.c:617
+msgid "delete branch (even if not merged)"
+msgstr ""
+
+#: builtin/branch.c:618
+msgid "move/rename a branch and its reflog"
+msgstr ""
+
+#: builtin/branch.c:619
+msgid "move/rename a branch, even if target exists"
+msgstr ""
+
+#: builtin/branch.c:620
+msgid "copy a branch and its reflog"
+msgstr ""
+
+#: builtin/branch.c:621
+msgid "copy a branch, even if target exists"
+msgstr ""
+
+#: builtin/branch.c:622
+msgid "list branch names"
+msgstr ""
+
+#: builtin/branch.c:623
+msgid "create the branch's reflog"
+msgstr ""
+
+#: builtin/branch.c:625
+msgid "edit the description for the branch"
+msgstr ""
+
+#: builtin/branch.c:626
+msgid "force creation, move/rename, deletion"
+msgstr ""
+
+#: builtin/branch.c:627
+msgid "print only branches that are merged"
+msgstr ""
+
+#: builtin/branch.c:628
+msgid "print only branches that are not merged"
+msgstr ""
+
+#: builtin/branch.c:629
+msgid "list branches in columns"
+msgstr ""
+
+#: builtin/branch.c:630 builtin/for-each-ref.c:40 builtin/ls-remote.c:70
+#: builtin/tag.c:415
+msgid "key"
+msgstr ""
+
+#: builtin/branch.c:631 builtin/for-each-ref.c:41 builtin/ls-remote.c:71
+#: builtin/tag.c:416
+msgid "field name to sort on"
+msgstr ""
+
+#: builtin/branch.c:633 builtin/for-each-ref.c:43 builtin/notes.c:415
+#: builtin/notes.c:418 builtin/notes.c:581 builtin/notes.c:584
+#: builtin/tag.c:418
+msgid "object"
+msgstr "αντικείμενο"
+
+#: builtin/branch.c:634
+msgid "print only branches of the object"
+msgstr ""
+
+#: builtin/branch.c:636 builtin/for-each-ref.c:49 builtin/tag.c:425
+msgid "sorting and filtering are case insensitive"
+msgstr ""
+
+#: builtin/branch.c:637 builtin/for-each-ref.c:38 builtin/tag.c:423
+#: builtin/verify-tag.c:39
+msgid "format to use for the output"
+msgstr ""
+
+#: builtin/branch.c:660 builtin/clone.c:746
+msgid "HEAD not found below refs/heads!"
+msgstr "Το HEAD δε βρέθηκε κάτω από το refs/heads!"
+
+#: builtin/branch.c:683
+msgid "--column and --verbose are incompatible"
+msgstr ""
+
+#: builtin/branch.c:698 builtin/branch.c:749 builtin/branch.c:758
+msgid "branch name required"
+msgstr ""
+
+#: builtin/branch.c:725
+msgid "Cannot give description to detached HEAD"
+msgstr ""
+
+#: builtin/branch.c:730
+msgid "cannot edit description of more than one branch"
+msgstr ""
+
+#: builtin/branch.c:737
+#, c-format
+msgid "No commit on branch '%s' yet."
+msgstr ""
+
+#: builtin/branch.c:740
+#, c-format
+msgid "No branch named '%s'."
+msgstr "Δεν υπάρχει κλάδος με όνομα '%s'."
+
+#: builtin/branch.c:755
+msgid "too many branches for a copy operation"
+msgstr ""
+
+#: builtin/branch.c:764
+msgid "too many arguments for a rename operation"
+msgstr ""
+
+#: builtin/branch.c:769
+msgid "too many arguments to set new upstream"
+msgstr ""
+
+#: builtin/branch.c:773
+#, c-format
+msgid ""
+"could not set upstream of HEAD to %s when it does not point to any branch."
+msgstr ""
+
+#: builtin/branch.c:776 builtin/branch.c:799
+#, c-format
+msgid "no such branch '%s'"
+msgstr "δεν υπάρχει ο κλάδος '%s'"
+
+#: builtin/branch.c:780
+#, c-format
+msgid "branch '%s' does not exist"
+msgstr ""
+
+#: builtin/branch.c:793
+msgid "too many arguments to unset upstream"
+msgstr ""
+
+#: builtin/branch.c:797
+msgid "could not unset upstream of HEAD when it does not point to any branch."
+msgstr ""
+
+#: builtin/branch.c:803
+#, c-format
+msgid "Branch '%s' has no upstream information"
+msgstr ""
+
+#: builtin/branch.c:813
+msgid "-a and -r options to 'git branch' do not make sense with a branch name"
+msgstr ""
+
+#: builtin/branch.c:816
+msgid ""
+"the '--set-upstream' option is no longer supported. Please use '--track' or "
+"'--set-upstream-to' instead."
+msgstr ""
+
+#: builtin/bundle.c:45
+#, c-format
+msgid "%s is okay\n"
+msgstr ""
+
+#: builtin/bundle.c:58
+msgid "Need a repository to create a bundle."
+msgstr ""
+
+#: builtin/bundle.c:62
+msgid "Need a repository to unbundle."
+msgstr ""
+
+#: builtin/cat-file.c:593
+msgid ""
+"git cat-file (-t [--allow-unknown-type] | -s [--allow-unknown-type] | -e | -"
+"p | <type> | --textconv | --filters) [--path=<path>] <object>"
+msgstr ""
+"git cat-file (-t [--allow-unknown-type] | -s [--allow-unknown-type] | -e | -"
+"p | <τύπος> | --textconv | --filters) [--path=<διαδρομή>] <αντικείμενο>"
+
+#: builtin/cat-file.c:594
+msgid ""
+"git cat-file (--batch | --batch-check) [--follow-symlinks] [--textconv | --"
+"filters]"
+msgstr ""
+"git cat-file (--batch | --batch-check) [--follow-symlinks] [--textconv | --"
+"filters]"
+
+#: builtin/cat-file.c:615
+msgid "only one batch option may be specified"
+msgstr ""
+
+#: builtin/cat-file.c:633
+msgid "<type> can be one of: blob, tree, commit, tag"
+msgstr "ο <τύπος> μπορεί να είναι ένας εκ των: blob, δέντρο, υποβολή, ετικέτα"
+
+#: builtin/cat-file.c:634
+msgid "show object type"
+msgstr ""
+
+#: builtin/cat-file.c:635
+msgid "show object size"
+msgstr ""
+
+#: builtin/cat-file.c:637
+msgid "exit with zero when there's no error"
+msgstr ""
+
+#: builtin/cat-file.c:638
+msgid "pretty-print object's content"
+msgstr ""
+
+#: builtin/cat-file.c:640
+msgid "for blob objects, run textconv on object's content"
+msgstr "για αντικείμενα blob, τρέξτε textconv στο περιεχόμενο του αντικειμένου"
+
+#: builtin/cat-file.c:642
+msgid "for blob objects, run filters on object's content"
+msgstr "για αντικείμενα blob, τρέξτε φίλτρα στο περιεχόμενο του αντικειμένου"
+
+#: builtin/cat-file.c:643 git-submodule.sh:860
+msgid "blob"
+msgstr ""
+
+#: builtin/cat-file.c:644
+msgid "use a specific path for --textconv/--filters"
+msgstr ""
+
+#: builtin/cat-file.c:646
+msgid "allow -s and -t to work with broken/corrupt objects"
+msgstr ""
+
+#: builtin/cat-file.c:647
+msgid "buffer --batch output"
+msgstr ""
+
+#: builtin/cat-file.c:649
+msgid "show info and content of objects fed from the standard input"
+msgstr ""
+
+#: builtin/cat-file.c:653
+msgid "show info about objects fed from the standard input"
+msgstr ""
+
+#: builtin/cat-file.c:657
+msgid "follow in-tree symlinks (used with --batch or --batch-check)"
+msgstr ""
+
+#: builtin/cat-file.c:659
+msgid "show all objects with --batch or --batch-check"
+msgstr ""
+
+#: builtin/cat-file.c:661
+msgid "do not order --batch-all-objects output"
+msgstr ""
+
+#: builtin/check-attr.c:13
+msgid "git check-attr [-a | --all | <attr>...] [--] <pathname>..."
+msgstr "git check-attr [-a | --all | <πεδίο>...] [--] <όνομα διαδρομής>..."
+
+#: builtin/check-attr.c:14
+msgid "git check-attr --stdin [-z] [-a | --all | <attr>...]"
+msgstr "git check-attr --stdin [-z] [-a | --all | <πεδίο>...]"
+
+#: builtin/check-attr.c:21
+msgid "report all attributes set on file"
+msgstr ""
+
+#: builtin/check-attr.c:22
+msgid "use .gitattributes only from the index"
+msgstr "να γίνει χρήση του .gitattributes μόνο από το ευρετήριο"
+
+#: builtin/check-attr.c:23 builtin/check-ignore.c:25 builtin/hash-object.c:102
+msgid "read file names from stdin"
+msgstr ""
+
+#: builtin/check-attr.c:25 builtin/check-ignore.c:27
+msgid "terminate input and output records by a NUL character"
+msgstr ""
+
+#: builtin/check-ignore.c:21 builtin/checkout.c:1280 builtin/gc.c:517
+#: builtin/worktree.c:496
+msgid "suppress progress reporting"
+msgstr "να μην αναφέρεται η πρόοδος"
+
+#: builtin/check-ignore.c:29
+msgid "show non-matching input paths"
+msgstr ""
+
+#: builtin/check-ignore.c:31
+msgid "ignore index when checking"
+msgstr ""
+
+#: builtin/check-ignore.c:160
+msgid "cannot specify pathnames with --stdin"
+msgstr ""
+
+#: builtin/check-ignore.c:163
+msgid "-z only makes sense with --stdin"
+msgstr "το -z έχει νόημα μόνο με το --stdin"
+
+#: builtin/check-ignore.c:165
+msgid "no path specified"
+msgstr ""
+
+#: builtin/check-ignore.c:169
+msgid "--quiet is only valid with a single pathname"
+msgstr ""
+
+#: builtin/check-ignore.c:171
+msgid "cannot have both --quiet and --verbose"
+msgstr ""
+
+#: builtin/check-ignore.c:174
+msgid "--non-matching is only valid with --verbose"
+msgstr ""
+
+#: builtin/check-mailmap.c:9
+msgid "git check-mailmap [<options>] <contact>..."
+msgstr "git check-mailmap [<επιλογές>] <επαφή>..."
+
+#: builtin/check-mailmap.c:14
+msgid "also read contacts from stdin"
+msgstr ""
+
+#: builtin/check-mailmap.c:25
+#, c-format
+msgid "unable to parse contact: %s"
+msgstr ""
+
+#: builtin/check-mailmap.c:48
+msgid "no contacts specified"
+msgstr ""
+
+#: builtin/checkout-index.c:131
+msgid "git checkout-index [<options>] [--] [<file>...]"
+msgstr "git checkout-index [<επιλογές>] [--] [<αρχείο>...]"
+
+#: builtin/checkout-index.c:148
+msgid "stage should be between 1 and 3 or all"
+msgstr ""
+
+#: builtin/checkout-index.c:164
+msgid "check out all files in the index"
+msgstr ""
+
+#: builtin/checkout-index.c:165
+msgid "force overwrite of existing files"
+msgstr ""
+
+#: builtin/checkout-index.c:167
+msgid "no warning for existing files and files not in index"
+msgstr ""
+
+#: builtin/checkout-index.c:169
+msgid "don't checkout new files"
+msgstr ""
+
+#: builtin/checkout-index.c:171
+msgid "update stat information in the index file"
+msgstr ""
+
+#: builtin/checkout-index.c:175
+msgid "read list of paths from the standard input"
+msgstr ""
+
+#: builtin/checkout-index.c:177
+msgid "write the content to temporary files"
+msgstr ""
+
+#: builtin/checkout-index.c:178 builtin/column.c:31
+#: builtin/submodule--helper.c:1372 builtin/submodule--helper.c:1375
+#: builtin/submodule--helper.c:1383 builtin/submodule--helper.c:1857
+#: builtin/worktree.c:669
+msgid "string"
+msgstr ""
+
+#: builtin/checkout-index.c:179
+msgid "when creating files, prepend <string>"
+msgstr ""
+
+#: builtin/checkout-index.c:181
+msgid "copy out the files from named stage"
+msgstr ""
+
+#: builtin/checkout.c:32
+msgid "git checkout [<options>] <branch>"
+msgstr "git checkout [<επιλογές>] <κλάδος>"
+
+#: builtin/checkout.c:33
+msgid "git checkout [<options>] [<branch>] -- <file>..."
+msgstr "git checkout [<επιλογές>] [<κλάδος>] -- <αρχείο>..."
+
+#: builtin/checkout.c:147 builtin/checkout.c:181
+#, c-format
+msgid "path '%s' does not have our version"
+msgstr "η διαδρομή '%s' δεν έχει τη δική μας έκδοση"
+
+#: builtin/checkout.c:149 builtin/checkout.c:183
+#, c-format
+msgid "path '%s' does not have their version"
+msgstr "η διαδρομή '%s' δεν έχει τη δική τους έκδοση"
+
+#: builtin/checkout.c:165
+#, c-format
+msgid "path '%s' does not have all necessary versions"
+msgstr "η διαδρομή '%s' δεν έχει όλες τις αναγκαίες εκδόσεις"
+
+#: builtin/checkout.c:210
+#, c-format
+msgid "path '%s' does not have necessary versions"
+msgstr "η διαδρομή '%s' δεν έχει τις αναγκαίες εκδόσεις"
+
+#: builtin/checkout.c:228
+#, c-format
+msgid "path '%s': cannot merge"
+msgstr "διαδρομή '%s': δεν είναι δυνατή η συγχώνευση"
+
+#: builtin/checkout.c:244
+#, c-format
+msgid "Unable to add merge result for '%s'"
+msgstr "Δεν είναι δυνατή η προσθήκη αποτελέσματος συγχώνευσης για το '%s'"
+
+#: builtin/checkout.c:267 builtin/checkout.c:270 builtin/checkout.c:273
+#: builtin/checkout.c:276
+#, c-format
+msgid "'%s' cannot be used with updating paths"
+msgstr "το '%s' δε γίνεται να χρησιμοποιηθεί με την ενημέρωση διαδρομών"
+
+#: builtin/checkout.c:279 builtin/checkout.c:282
+#, c-format
+msgid "'%s' cannot be used with %s"
+msgstr "το '%s' δε γίνεται να χρησιμοποιηθεί με το %s"
+
+#: builtin/checkout.c:285
+#, c-format
+msgid "Cannot update paths and switch to branch '%s' at the same time."
+msgstr "Δε γίνεται ενημέρωση διαδρομών και αλλαγή στον κλάδο '%s' ταυτόχρονα."
+
+#: builtin/checkout.c:354 builtin/checkout.c:361
+#, c-format
+msgid "path '%s' is unmerged"
+msgstr "δεν έχει γίνει συγχώνευση της διαδρομής '%s'"
+
+#: builtin/checkout.c:397
+#, c-format
+msgid "Recreated %d merge conflict"
+msgid_plural "Recreated %d merge conflicts"
+msgstr[0] ""
+msgstr[1] ""
+
+#: builtin/checkout.c:402
+#, c-format
+msgid "Updated %d path from %s"
+msgid_plural "Updated %d paths from %s"
+msgstr[0] ""
+msgstr[1] ""
+
+#: builtin/checkout.c:409
+#, c-format
+msgid "Updated %d path from the index"
+msgid_plural "Updated %d paths from the index"
+msgstr[0] ""
+msgstr[1] ""
+
+#: builtin/checkout.c:645
+msgid "you need to resolve your current index first"
+msgstr "πρέπει να επιλύσετε το τρέχον σας ευρετήριο πρώτα"
+
+#: builtin/checkout.c:782
+#, c-format
+msgid "Can not do reflog for '%s': %s\n"
+msgstr "Δεν είναι δυνατό το reflog για το '%s': %s\n"
+
+#: builtin/checkout.c:824
+msgid "HEAD is now at"
+msgstr "Το HEAD βρίσκεται τώρα στο"
+
+#: builtin/checkout.c:828 builtin/clone.c:699
+msgid "unable to update HEAD"
+msgstr "δεν ήταν δυνατό να ενημερωθεί το HEAD"
+
+#: builtin/checkout.c:832
+#, c-format
+msgid "Reset branch '%s'\n"
+msgstr "Επαναφορά του κλάδου '%s'\n"
+
+#: builtin/checkout.c:835
+#, c-format
+msgid "Already on '%s'\n"
+msgstr "Βρίσκεστε ήδη στο '%s'\n"
+
+#: builtin/checkout.c:839
+#, c-format
+msgid "Switched to and reset branch '%s'\n"
+msgstr "Αλλαγή και επαναφορά στον κλάδο '%s'\n"
+
+#: builtin/checkout.c:841 builtin/checkout.c:1212
+#, c-format
+msgid "Switched to a new branch '%s'\n"
+msgstr "Αλλαγή σε νέο κλάδο '%s'\n"
+
+#: builtin/checkout.c:843
+#, c-format
+msgid "Switched to branch '%s'\n"
+msgstr "Αλλαγή στον κλάδο '%s'\n"
+
+#: builtin/checkout.c:894
+#, c-format
+msgid " ... and %d more.\n"
+msgstr " ... και %d ακόμα.\n"
+
+#: builtin/checkout.c:900
+#, c-format
+msgid ""
+"Warning: you are leaving %d commit behind, not connected to\n"
+"any of your branches:\n"
+"\n"
+"%s\n"
+msgid_plural ""
+"Warning: you are leaving %d commits behind, not connected to\n"
+"any of your branches:\n"
+"\n"
+"%s\n"
+msgstr[0] ""
+msgstr[1] ""
+
+#: builtin/checkout.c:919
+#, c-format
+msgid ""
+"If you want to keep it by creating a new branch, this may be a good time\n"
+"to do so with:\n"
+"\n"
+" git branch <new-branch-name> %s\n"
+"\n"
+msgid_plural ""
+"If you want to keep them by creating a new branch, this may be a good time\n"
+"to do so with:\n"
+"\n"
+" git branch <new-branch-name> %s\n"
+"\n"
+msgstr[0] ""
+msgstr[1] ""
+
+#: builtin/checkout.c:951
+msgid "internal error in revision walk"
+msgstr "εσωτερικό σφάλμα στο μονοπάτι εκδόσεων"
+
+#: builtin/checkout.c:955
+msgid "Previous HEAD position was"
+msgstr "Η προηγούμενη θέση του HEAD ήταν"
+
+#: builtin/checkout.c:983 builtin/checkout.c:1207
+msgid "You are on a branch yet to be born"
+msgstr "Βρίσκεστε σε κλάδο που δεν έχει ακόμα γεννηθεί"
+
+#: builtin/checkout.c:1104
+#, c-format
+msgid "only one reference expected, %d given."
+msgstr "αναμενόταν μόνο μία αναφορά, δόθηκαν %d."
+
+#: builtin/checkout.c:1140
+#, c-format
+msgid ""
+"'%s' could be both a local file and a tracking branch.\n"
+"Please use -- (and optionally --no-guess) to disambiguate"
+msgstr ""
+"Το '%s' θα μπορούσε να είναι είτε τοπικό αρχείο είτε κλάδος παρακολούθησης.\n"
+"Παρακαλώ χρησιμοποιήστε -- (και προαιρετικά --no-guess) για να αποσαφηνίσετε"
+
+#: builtin/checkout.c:1153 builtin/worktree.c:290 builtin/worktree.c:445
+#, c-format
+msgid "invalid reference: %s"
+msgstr "μη έγκυρη αναφορά: %s"
+
+#: builtin/checkout.c:1182
+#, c-format
+msgid "reference is not a tree: %s"
+msgstr "η αναφορά δεν είναι δέντρο: %s"
+
+#: builtin/checkout.c:1221
+msgid "paths cannot be used with switching branches"
+msgstr "δεν είναι δυνατή η χρήση διαδρομών με την αλλαγή κλάδων"
+
+#: builtin/checkout.c:1224 builtin/checkout.c:1228
+#, c-format
+msgid "'%s' cannot be used with switching branches"
+msgstr "δεν είναι δυνατή η χρήση του '%s' με την αλλαγή κλάδων"
+
+#: builtin/checkout.c:1232 builtin/checkout.c:1235 builtin/checkout.c:1240
+#: builtin/checkout.c:1243
+#, c-format
+msgid "'%s' cannot be used with '%s'"
+msgstr "δεν είναι δυνατή η χρήση του '%s' με το '%s'"
+
+#: builtin/checkout.c:1248
+#, c-format
+msgid "Cannot switch branch to a non-commit '%s'"
+msgstr "Δεν είναι δυνατή η αλλαγή του κλάδου στο '%s' που δεν είναι υποβολή"
+
+#: builtin/checkout.c:1281 builtin/checkout.c:1283 builtin/clone.c:120
+#: builtin/remote.c:169 builtin/remote.c:171 builtin/worktree.c:489
+#: builtin/worktree.c:491
+msgid "branch"
+msgstr "κλάδος"
+
+#: builtin/checkout.c:1282
+msgid "create and checkout a new branch"
+msgstr "να δημιουργηθεί και να εξαχθεί ένας νέος κλάδος"
+
+#: builtin/checkout.c:1284
+msgid "create/reset and checkout a branch"
+msgstr "να δημιουργηθεί/επαναφερθεί και να εξαχθεί ένας κλάδος"
+
+#: builtin/checkout.c:1285
+msgid "create reflog for new branch"
+msgstr "να δημιουργηθεί reflog για νέο κλάδο"
+
+#: builtin/checkout.c:1286 builtin/worktree.c:493
+msgid "detach HEAD at named commit"
+msgstr "να γίνει αποσύνδεση του HEAD στην κατονομασμένη υποβολή"
+
+#: builtin/checkout.c:1287
+msgid "set upstream info for new branch"
+msgstr "να οριστούν οι πληροφορίες του προς τα πάνω για τον νέο κλάδο"
+
+#: builtin/checkout.c:1289
+msgid "new-branch"
+msgstr "νέος κλάδος"
+
+#: builtin/checkout.c:1289
+msgid "new unparented branch"
+msgstr "νέος κλάδος χωρίς γονέα"
+
+#: builtin/checkout.c:1291
+msgid "checkout our version for unmerged files"
+msgstr "να γίνει εξαγωγή της δικής μας έκδοσης για τα μη συγχωνευμένα αρχεία"
+
+#: builtin/checkout.c:1294
+msgid "checkout their version for unmerged files"
+msgstr "να γίνει εξαγωγή της δικής τους έκδοσης για τα μη συγχωνευμένα αρχεία"
+
+#: builtin/checkout.c:1296
+msgid "force checkout (throw away local modifications)"
+msgstr "να γίνει αναγκαστική εξαγωγή (απόρριψη των τοπικών τροποποιήσεων)"
+
+#: builtin/checkout.c:1298
+msgid "perform a 3-way merge with the new branch"
+msgstr "να γίνει τριπλή συγχώνευση με τον νέο κλάδο"
+
+#: builtin/checkout.c:1300 builtin/merge.c:276
+msgid "update ignored files (default)"
+msgstr "να ενημερωθούν τα αρχεία που παραβλέπονται (προεπιλογή)"
+
+#: builtin/checkout.c:1302 builtin/log.c:1586 parse-options.h:272
+msgid "style"
+msgstr "μορφή"
+
+#: builtin/checkout.c:1303
+msgid "conflict style (merge or diff3)"
+msgstr "μορφή συγκρούσεων (merge ή diff3)"
+
+#: builtin/checkout.c:1306
+msgid "do not limit pathspecs to sparse entries only"
+msgstr ""
+"να μη γίνει περιορισμός των περιγραφών διαδρομών σε μόνο διάσπαρτα στοιχεία"
+
+#: builtin/checkout.c:1308
+msgid "do not second guess 'git checkout <no-such-branch>'"
+msgstr ""
+"να μη γίνει δεύτερη απόπειρα ερμηνείας 'git checkout <κλάδος που δεν "
+"υπάρχει>'"
+
+#: builtin/checkout.c:1310
+msgid "do not check if another worktree is holding the given ref"
+msgstr ""
+"να μη γίνει έλεγχος αν κάποιο άλλο δέντρο εργασίας κρατά το ref που δόθηκε"
+
+#: builtin/checkout.c:1314 builtin/clone.c:87 builtin/fetch.c:141
+#: builtin/merge.c:273 builtin/pull.c:130 builtin/push.c:575
+#: builtin/send-pack.c:174
+msgid "force progress reporting"
+msgstr "να γίνει αναγκαστικά αναφορά της προόδου"
+
+#: builtin/checkout.c:1345
+msgid "-b, -B and --orphan are mutually exclusive"
+msgstr "τα -b, -B και --orphan είναι αλληλοαποκλειόμενα"
+
+#: builtin/checkout.c:1362
+msgid "--track needs a branch name"
+msgstr "το --track χρειάζεται ένα όνομα κλάδου"
+
+#: builtin/checkout.c:1367
+msgid "missing branch name; try -b"
+msgstr "λείπει το όνομα κλάδου, δοκιμάστε -b"
+
+#: builtin/checkout.c:1404
+msgid "invalid path specification"
+msgstr "μη έγκυρη περιγραφή διαδρομής"
+
+#: builtin/checkout.c:1411
+#, c-format
+msgid "'%s' is not a commit and a branch '%s' cannot be created from it"
+msgstr ""
+"το '%s' δεν είναι υποβολή και δε γίνεται να δημιουργηθεί κλάδος '%s' από αυτό"
+
+#: builtin/checkout.c:1415
+#, c-format
+msgid "git checkout: --detach does not take a path argument '%s'"
+msgstr "git checkout: το --detach δε δέχεται όρισμα διαδρομής '%s'"
+
+#: builtin/checkout.c:1419
+msgid ""
+"git checkout: --ours/--theirs, --force and --merge are incompatible when\n"
+"checking out of the index."
+msgstr ""
+"git checkout: --ours/--theirs, --force και --merge είναι ασύμβατα όταν\n"
+"γίνεται εξαγωγή από το ευρετήριο."
+
+#: builtin/checkout.c:1439
+#, c-format
+msgid ""
+"'%s' matched more than one remote tracking branch.\n"
+"We found %d remotes with a reference that matched. So we fell back\n"
+"on trying to resolve the argument as a path, but failed there too!\n"
+"\n"
+"If you meant to check out a remote tracking branch on, e.g. 'origin',\n"
+"you can do so by fully qualifying the name with the --track option:\n"
+"\n"
+"    git checkout --track origin/<name>\n"
+"\n"
+"If you'd like to always have checkouts of an ambiguous <name> prefer\n"
+"one remote, e.g. the 'origin' remote, consider setting\n"
+"checkout.defaultRemote=origin in your config."
+msgstr ""
+"Το '%s' ταίριαξε με περισσότερους από έναν απομακρυσμένους "
+"παρακολουθούμενους κλάδους.\n"
+"Βρήκαμε %d απομακρυσμένους εξυπηρετητές με αναφορά που ταιριάζει. Οπότε "
+"έγινε εναλλακτικά\n"
+"απόπειρα ταύτισης του ορίσματος με διαδρομή, αλλά απέτυχε και αυτή!\n"
+"\n"
+"Αν θέλατε να εξαγάγετε έναν απομακρυσμένο παρακολουθούμενο κλάδο π.χ. στο "
+"'origin',\n"
+"μπορείτε να το κάνετε ορίζοντας ολογράφως το όνομα με την επιλογή --track:\n"
+"\n"
+"    git checkout --track origin/<όνομα>\n"
+"\n"
+"Αν θα θέλατε οι εξαγωγές από ένα αμφίσημο <όνομα> να προτιμούν πάντα\n"
+"έναν απομακρυσμένο εξυπηρετητή, π.χ. το απομακρυσμένο 'origin', σκεφτείτε να "
+"ορίσετε\n"
+"checkout.defaultRemote=origin στις ρυθμίσεις σας."
+
+#: builtin/clean.c:28
+msgid ""
+"git clean [-d] [-f] [-i] [-n] [-q] [-e <pattern>] [-x | -X] [--] <paths>..."
+msgstr ""
+"git clean [-d] [-f] [-i] [-n] [-q] [-e <μοτίβο>] [-x | -X] [--] "
+"<διαδρομές>..."
+
+#: builtin/clean.c:32
+#, c-format
+msgid "Removing %s\n"
+msgstr "Αφαίρεση του %s\n"
+
+#: builtin/clean.c:33
+#, c-format
+msgid "Would remove %s\n"
+msgstr "Θα αφαιρούσε το %s\n"
+
+#: builtin/clean.c:34
+#, c-format
+msgid "Skipping repository %s\n"
+msgstr "Προσπερνάται το αποθετήριο %s\n"
+
+#: builtin/clean.c:35
+#, c-format
+msgid "Would skip repository %s\n"
+msgstr "Θα προσπερνούσε το αποθετήριο %s\n"
+
+#: builtin/clean.c:36
+#, c-format
+msgid "failed to remove %s"
+msgstr ""
+
+#: builtin/clean.c:299 git-add--interactive.perl:579
+#, c-format
+msgid ""
+"Prompt help:\n"
+"1          - select a numbered item\n"
+"foo        - select item based on unique prefix\n"
+"           - (empty) select nothing\n"
+msgstr ""
+"Βοήθεια:\n"
+"1          - επιλογή αριθμημένου στοιχείου\n"
+"foo        - επιλογή στοιχείου με βάση μοναδικό πρόθεμα\n"
+"           - (κενό) μη επιλογή κανενός\n"
+
+#: builtin/clean.c:303 git-add--interactive.perl:588
+#, c-format
+msgid ""
+"Prompt help:\n"
+"1          - select a single item\n"
+"3-5        - select a range of items\n"
+"2-3,6-9    - select multiple ranges\n"
+"foo        - select item based on unique prefix\n"
+"-...       - unselect specified items\n"
+"*          - choose all items\n"
+"           - (empty) finish selecting\n"
+msgstr ""
+"Βοήθεια:\n"
+"1          - επιλογή ενός μόνο στοιχείου\n"
+"3-5        - επιλογή εύρους στοιχείων\n"
+"2-3,6-9    - επιλογή πολλαπλών ευρών στοιχείων\n"
+"foo        - επιλογή στοιχείου με βάση μοναδικό πρόθεμα\n"
+"-...       - αποεπιλογή των εξής στοιχείων\n"
+"*          - επιλογή όλων των στοιχείων\n"
+"           - (κενό) ολοκλήρωση επιλογής\n"
+
+#: builtin/clean.c:519 git-add--interactive.perl:554
+#: git-add--interactive.perl:559
+#, c-format, perl-format
+msgid "Huh (%s)?\n"
+msgstr "Ορίστε (%s);\n"
+
+#: builtin/clean.c:661
+#, c-format
+msgid "Input ignore patterns>> "
+msgstr ""
+
+#: builtin/clean.c:698
+#, c-format
+msgid "WARNING: Cannot find items matched by: %s"
+msgstr ""
+
+#: builtin/clean.c:719
+msgid "Select items to delete"
+msgstr ""
+
+#. TRANSLATORS: Make sure to keep [y/N] as is
+#: builtin/clean.c:760
+#, c-format
+msgid "Remove %s [y/N]? "
+msgstr ""
+
+#: builtin/clean.c:785 git-add--interactive.perl:1717
+#, c-format
+msgid "Bye.\n"
+msgstr "Αντίο.\n"
+
+#: builtin/clean.c:793
+msgid ""
+"clean               - start cleaning\n"
+"filter by pattern   - exclude items from deletion\n"
+"select by numbers   - select items to be deleted by numbers\n"
+"ask each            - confirm each deletion (like \"rm -i\")\n"
+"quit                - stop cleaning\n"
+"help                - this screen\n"
+"?                   - help for prompt selection"
+msgstr ""
+
+#: builtin/clean.c:820 git-add--interactive.perl:1793
+msgid "*** Commands ***"
+msgstr ""
+
+#: builtin/clean.c:821 git-add--interactive.perl:1790
+msgid "What now"
+msgstr ""
+
+#: builtin/clean.c:829
+msgid "Would remove the following item:"
+msgid_plural "Would remove the following items:"
+msgstr[0] ""
+msgstr[1] ""
+
+#: builtin/clean.c:845
+msgid "No more files to clean, exiting."
+msgstr ""
+
+#: builtin/clean.c:907
+msgid "do not print names of files removed"
+msgstr ""
+
+#: builtin/clean.c:909
+msgid "force"
+msgstr ""
+
+#: builtin/clean.c:910
+msgid "interactive cleaning"
+msgstr ""
+
+#: builtin/clean.c:912
+msgid "remove whole directories"
+msgstr ""
+
+#: builtin/clean.c:913 builtin/describe.c:546 builtin/describe.c:548
+#: builtin/grep.c:897 builtin/log.c:167 builtin/log.c:169
+#: builtin/ls-files.c:557 builtin/name-rev.c:415 builtin/name-rev.c:417
+#: builtin/show-ref.c:178
+msgid "pattern"
+msgstr "μοτίβο"
+
+#: builtin/clean.c:914
+msgid "add <pattern> to ignore rules"
+msgstr ""
+
+#: builtin/clean.c:915
+msgid "remove ignored files, too"
+msgstr ""
+
+#: builtin/clean.c:917
+msgid "remove only ignored files"
+msgstr ""
+
+#: builtin/clean.c:935
+msgid "-x and -X cannot be used together"
+msgstr ""
+
+#: builtin/clean.c:939
+msgid ""
+"clean.requireForce set to true and neither -i, -n, nor -f given; refusing to "
+"clean"
+msgstr ""
+
+#: builtin/clean.c:942
+msgid ""
+"clean.requireForce defaults to true and neither -i, -n, nor -f given; "
+"refusing to clean"
+msgstr ""
+
+#: builtin/clone.c:44
+msgid "git clone [<options>] [--] <repo> [<dir>]"
+msgstr "git clone [<επιλογές>] [--] <αποθετήριο> [<φάκελος>]"
+
+#: builtin/clone.c:89
+msgid "don't create a checkout"
+msgstr "να μη δημιουργηθεί εξαγωγή"
+
+#: builtin/clone.c:90 builtin/clone.c:92 builtin/init-db.c:481
+msgid "create a bare repository"
+msgstr "να δημιουργηθεί ένα γυμνό αποθετήριο"
+
+#: builtin/clone.c:94
+msgid "create a mirror repository (implies bare)"
+msgstr "να δημιουργηθεί αποθετήριο αντίγραφο (εννοείται γυμνό)"
+
+#: builtin/clone.c:96
+msgid "to clone from a local repository"
+msgstr "για κλωνοποίηση από τοπικό αποθετήριο"
+
+#: builtin/clone.c:98
+msgid "don't use local hardlinks, always copy"
+msgstr "να μη γίνει χρήση τοπικών hardlinks, να γίνεται πάντα αντιγραφή"
+
+#: builtin/clone.c:100
+msgid "setup as shared repository"
+msgstr "αρχικοποίηση ως αποθετήριο κοινής χρήσης"
+
+#: builtin/clone.c:102 builtin/clone.c:106
+msgid "pathspec"
+msgstr "περιγραφή διαδρομής"
+
+#: builtin/clone.c:102 builtin/clone.c:106
+msgid "initialize submodules in the clone"
+msgstr "αρχικοποίηση υποενοτήτων μέσα στον κλώνο"
+
+#: builtin/clone.c:109
+msgid "number of submodules cloned in parallel"
+msgstr "αριθμός υποενοτήτων προς παράλληλη κλωνοποίηση"
+
+#: builtin/clone.c:110 builtin/init-db.c:478
+msgid "template-directory"
+msgstr "φάκελος προτύπων"
+
+#: builtin/clone.c:111 builtin/init-db.c:479
+msgid "directory from which templates will be used"
+msgstr "φάκελος από τον οποίο θα χρησιμοποιηθούνται πρότυπα"
+
+#: builtin/clone.c:113 builtin/clone.c:115 builtin/submodule--helper.c:1379
+#: builtin/submodule--helper.c:1860
+msgid "reference repository"
+msgstr "αποθετήριο αναφοράς"
+
+#: builtin/clone.c:117 builtin/submodule--helper.c:1381
+#: builtin/submodule--helper.c:1862
+msgid "use --reference only while cloning"
+msgstr "να γίνει χρήση του --reference μόνο κατά τη διάρκεια κλωνοποίησης"
+
+#: builtin/clone.c:118 builtin/column.c:27 builtin/merge-file.c:46
+#: builtin/pack-objects.c:3303 builtin/repack.c:329
+msgid "name"
+msgstr "όνομα"
+
+#: builtin/clone.c:119
+msgid "use <name> instead of 'origin' to track upstream"
+msgstr ""
+"να χρησιμοποιηθεί το <όνομα> αντί για 'origin' για την παρακολούθηση του "
+"προς τα πάνω"
+
+#: builtin/clone.c:121
+msgid "checkout <branch> instead of the remote's HEAD"
+msgstr "να εξαχθεί ο <κλάδος> αντί για το HEAD του απομακρυσμένου"
+
+#: builtin/clone.c:123
+msgid "path to git-upload-pack on the remote"
+msgstr "διαδρομή για το git-upload-pack στον απομακρυσμένο εξυπηρετητή"
+
+#: builtin/clone.c:124 builtin/fetch.c:142 builtin/grep.c:836
+#: builtin/pull.c:218
+msgid "depth"
+msgstr "βάθος"
+
+#: builtin/clone.c:125
+msgid "create a shallow clone of that depth"
+msgstr "να δημιουργηθεί ρηχός κλώνος με αυτό το βάθος"
+
+#: builtin/clone.c:126 builtin/fetch.c:144 builtin/pack-objects.c:3292
+msgid "time"
+msgstr "χρόνος"
+
+#: builtin/clone.c:127
+msgid "create a shallow clone since a specific time"
+msgstr "να δημιουργηθεί ρηχός κλώνος από κάποια συγκεκριμένη στιγμή και μετά"
+
+#: builtin/clone.c:128 builtin/fetch.c:146 builtin/fetch.c:169
+#: builtin/rebase.c:1039
+msgid "revision"
+msgstr "έκδοση"
+
+#: builtin/clone.c:129 builtin/fetch.c:147
+msgid "deepen history of shallow clone, excluding rev"
+msgstr "να γίνει εμβάθυνση του ιστορικού του ρηχού κλώνου, εξαιρώντας το rev"
+
+#: builtin/clone.c:131
+msgid "clone only one branch, HEAD or --branch"
+msgstr "να κλωνοποιηθεί μόνο ένας κλάδος, το HEAD ή --branch"
+
+#: builtin/clone.c:133
+msgid "don't clone any tags, and make later fetches not to follow them"
+msgstr ""
+"να μην κλωνοποιηθεί καμία ετικέτα, και οι μελλοντικές ανακτήσεις να μην τις "
+"ακολουθούν"
+
+#: builtin/clone.c:135
+msgid "any cloned submodules will be shallow"
+msgstr "όλες οι κλωνοποιημένες υποενότητες θα είναι ρηχές"
+
+#: builtin/clone.c:136 builtin/init-db.c:487
+msgid "gitdir"
+msgstr "φάκελος git"
+
+#: builtin/clone.c:137 builtin/init-db.c:488
+msgid "separate git dir from working tree"
+msgstr "να γίνει διαχωρισμός του φακέλου git από το δέντρο εργασίας"
+
+#: builtin/clone.c:138
+msgid "key=value"
+msgstr "κλειδί=τιμή"
+
+#: builtin/clone.c:139
+msgid "set config inside the new repository"
+msgstr "να οριστούν ρυθμίσεις μέσα στο νέο αποθετήριο"
+
+#: builtin/clone.c:140 builtin/fetch.c:165 builtin/pull.c:231
+#: builtin/push.c:586
+msgid "use IPv4 addresses only"
+msgstr "χρήση μόνο διευθύνσεων IPv4"
+
+#: builtin/clone.c:142 builtin/fetch.c:167 builtin/pull.c:234
+#: builtin/push.c:588
+msgid "use IPv6 addresses only"
+msgstr "χρήση μόνο διευθύνσεων IPv6"
+
+#: builtin/clone.c:280
+msgid ""
+"No directory name could be guessed.\n"
+"Please specify a directory on the command line"
+msgstr ""
+"Δεν ήταν δυνατό να μαντέψουμε το όνομα του φακέλου.\n"
+"Παρακαλώ δώστε έναν φάκελο στη γραμμή εντολών"
+
+#: builtin/clone.c:333
+#, c-format
+msgid "info: Could not add alternate for '%s': %s\n"
+msgstr "πληροφορία: Δεν ήταν δυνατό να προστεθεί εναλλακτική για το '%s': %s\n"
+
+#: builtin/clone.c:405
+#, c-format
+msgid "failed to open '%s'"
+msgstr "απέτυχε το άνοιγμα του '%s'"
+
+#: builtin/clone.c:413
+#, c-format
+msgid "%s exists and is not a directory"
+msgstr "το %s υπάρχει ήδη και δεν είναι φάκελος"
+
+#: builtin/clone.c:427
+#, c-format
+msgid "failed to stat %s\n"
+msgstr "απέτυχε το stat του %s\n"
+
+#: builtin/clone.c:444
+#, c-format
+msgid "failed to unlink '%s'"
+msgstr "απέτυχε η αφαίρεση δεσμού '%s'"
+
+#: builtin/clone.c:449
+#, c-format
+msgid "failed to create link '%s'"
+msgstr "απέτυχε η δημιουργία του δεσμού '%s'"
+
+#: builtin/clone.c:453
+#, c-format
+msgid "failed to copy file to '%s'"
+msgstr "απέτυχε η αντιγραφή του αρχείου στο '%s'"
+
+#: builtin/clone.c:479
+#, c-format
+msgid "done.\n"
+msgstr "ολοκληρώθηκε.\n"
+
+#: builtin/clone.c:493
+msgid ""
+"Clone succeeded, but checkout failed.\n"
+"You can inspect what was checked out with 'git status'\n"
+"and retry the checkout with 'git checkout -f HEAD'\n"
+msgstr ""
+"Η κλωνοποίηση πέτυχε, αλλά η εξαγωγή απέτυχε.\n"
+"Μπορείτε να επιθεωρήσετε τι εξήχθη με 'git status'\n"
+"και να προσπαθήσετε πάλι την εξαγωγή με 'git checkout -f HEAD'\n"
+
+#: builtin/clone.c:570
+#, c-format
+msgid "Could not find remote branch %s to clone."
+msgstr "Δεν ήταν δυνατό να βρεθεί ο απομακρυσμένος κλάδος %s προς κλωνοποίηση."
+
+#: builtin/clone.c:687
+#, c-format
+msgid "unable to update %s"
+msgstr "δεν ήταν δυνατό να ενημερωθεί το %s"
+
+#: builtin/clone.c:737
+msgid "remote HEAD refers to nonexistent ref, unable to checkout.\n"
+msgstr ""
+"το απομακρυσμένο HEAD αναφέρεται σε ref που δεν υπάρχει, δεν είναι δυνατή η "
+"εξαγωγή.\n"
+
+#: builtin/clone.c:768
+msgid "unable to checkout working tree"
+msgstr "δεν είναι δυνατή η εξαγωγή του δέντρου εργασίας"
+
+#: builtin/clone.c:813
+msgid "unable to write parameters to config file"
+msgstr "δεν είναι δυνατή η εγγραφή παραμέτρων στο αρχείο ρυθμίσεων"
+
+#: builtin/clone.c:876
+msgid "cannot repack to clean up"
+msgstr "δεν είναι δυνατό το repack για καθαρισμό"
+
+#: builtin/clone.c:878
+msgid "cannot unlink temporary alternates file"
+msgstr ""
+"δεν είναι δυνατή η αφαίρεση δεσμού από το προσωρινό αρχείο εναλλακτικών"
+
+#: builtin/clone.c:918 builtin/receive-pack.c:1941
+msgid "Too many arguments."
+msgstr "Υπερβολικά πολλά ορίσματα."
+
+#: builtin/clone.c:922
+msgid "You must specify a repository to clone."
+msgstr "Πρέπει να ορίσετε ένα αποθετήριο προς κλωνοποίηση."
+
+#: builtin/clone.c:935
+#, c-format
+msgid "--bare and --origin %s options are incompatible."
+msgstr "οι επιλογές --bare και --origin %s δεν είναι συμβατές μεταξύ τους."
+
+#: builtin/clone.c:938
+msgid "--bare and --separate-git-dir are incompatible."
+msgstr "το --bare και το --separate-git-dir δεν είναι συμβατά μεταξύ τους."
+
+#: builtin/clone.c:951
+#, c-format
+msgid "repository '%s' does not exist"
+msgstr "το αποθετήριο '%s' δεν υπάρχει"
+
+#: builtin/clone.c:957 builtin/fetch.c:1608
+#, c-format
+msgid "depth %s is not a positive number"
+msgstr "το βάθος %s δεν είναι θετικός αριθμός"
+
+#: builtin/clone.c:967
+#, c-format
+msgid "destination path '%s' already exists and is not an empty directory."
+msgstr "η διαδρομή προορισμού '%s' υπάρχει ήδη και δεν είναι κενός φάκελος."
+
+#: builtin/clone.c:977
+#, c-format
+msgid "working tree '%s' already exists."
+msgstr "το δέντρο εργασίας '%s' υπάρχει ήδη."
+
+#: builtin/clone.c:992 builtin/clone.c:1013 builtin/difftool.c:272
+#: builtin/worktree.c:296 builtin/worktree.c:326
+#, c-format
+msgid "could not create leading directories of '%s'"
+msgstr "δεν ήταν δυνατή η δημιουργία των αρχικών φακέλων του '%s'"
+
+#: builtin/clone.c:997
+#, c-format
+msgid "could not create work tree dir '%s'"
+msgstr "δεν ήταν δυνατή η δημιουργία του φακέλου δέντρου εργασίας '%s'"
+
+#: builtin/clone.c:1017
+#, c-format
+msgid "Cloning into bare repository '%s'...\n"
+msgstr "Γίνεται κλωνοποίηση μέσα στο γυμνό αποθετήριο '%s'...\n"
+
+#: builtin/clone.c:1019
+#, c-format
+msgid "Cloning into '%s'...\n"
+msgstr "Γίνεται κλωνοποίηση μέσα στο '%s'...\n"
+
+#: builtin/clone.c:1043
+msgid ""
+"clone --recursive is not compatible with both --reference and --reference-if-"
+"able"
+msgstr ""
+"το clone --recursive δεν είναι συμβατό με το --reference και το --reference-"
+"if-able ταυτόχρονα"
+
+#: builtin/clone.c:1104
+msgid "--depth is ignored in local clones; use file:// instead."
+msgstr ""
+"το --depth παραβλέπεται σε τοπικούς κλώνους, χρησιμοποιήστε το file:// αντί "
+"αυτού."
+
+#: builtin/clone.c:1106
+msgid "--shallow-since is ignored in local clones; use file:// instead."
+msgstr ""
+"το --shallow-since παραβλέπεται σε τοπικούς κλώνους, χρησιμοποιήστε το "
+"file:// αντί αυτού."
+
+#: builtin/clone.c:1108
+msgid "--shallow-exclude is ignored in local clones; use file:// instead."
+msgstr ""
+"το --shallow-exclude παραβλέπεται σε τοπικούς κλώνους, χρησιμοποιήστε το "
+"file:// αντί αυτού."
+
+#: builtin/clone.c:1110
+msgid "--filter is ignored in local clones; use file:// instead."
+msgstr ""
+"το --filter παραβλέπεται σε τοπικούς κλώνους, χρησιμοποιήστε το file:// αντί "
+"αυτού."
+
+#: builtin/clone.c:1113
+msgid "source repository is shallow, ignoring --local"
+msgstr "το αποθετήριο πηγής είναι ρηχό, γίνεται παράβλεψη του --local"
+
+#: builtin/clone.c:1118
+msgid "--local is ignored"
+msgstr "γίνεται παράβλεψη του --local"
+
+#: builtin/clone.c:1192 builtin/clone.c:1200
+#, c-format
+msgid "Remote branch %s not found in upstream %s"
+msgstr "Ο απομακρυσμένος κλάδος %s δε βρέθηκε στο από πάνω %s"
+
+#: builtin/clone.c:1203
+msgid "You appear to have cloned an empty repository."
+msgstr "Φαίνεται πως κλωνοποιήσατε ένα κενό αποθετήριο."
+
+#: builtin/column.c:10
+msgid "git column [<options>]"
+msgstr "git column [<επιλογές>]"
+
+#: builtin/column.c:27
+msgid "lookup config vars"
+msgstr ""
+
+#: builtin/column.c:28 builtin/column.c:29
+msgid "layout to use"
+msgstr ""
+
+#: builtin/column.c:30
+msgid "Maximum width"
+msgstr ""
+
+#: builtin/column.c:31
+msgid "Padding space on left border"
+msgstr ""
+
+#: builtin/column.c:32
+msgid "Padding space on right border"
+msgstr ""
+
+#: builtin/column.c:33
+msgid "Padding space between columns"
+msgstr ""
+
+#: builtin/column.c:51
+msgid "--command must be the first argument"
+msgstr ""
+
+#: builtin/commit.c:41
+msgid "git commit [<options>] [--] <pathspec>..."
+msgstr "git commit [<επιλογές>] [--] <περιγραφή διαδρομής>..."
+
+#: builtin/commit.c:46
+msgid "git status [<options>] [--] <pathspec>..."
+msgstr "git status [<επιλογές>] [--] <περιγραφή διαδρομής>..."
+
+#: builtin/commit.c:51
+msgid ""
+"You asked to amend the most recent commit, but doing so would make\n"
+"it empty. You can repeat your command with --allow-empty, or you can\n"
+"remove the commit entirely with \"git reset HEAD^\".\n"
+msgstr ""
+"Ζητήσατε να τροποποιήσετε την πιο πρόσφατη υποβολή, αλλά αυτό θα την άφηνε\n"
+"κενή. Μπορείτε να επαναλάβετε την εντολή σας με --allow-empty, ή να\n"
+"αφαιρέσετε την υποβολή εντελώς με \"git reset HEAD^\".\n"
+
+#: builtin/commit.c:56
+msgid ""
+"The previous cherry-pick is now empty, possibly due to conflict resolution.\n"
+"If you wish to commit it anyway, use:\n"
+"\n"
+"    git commit --allow-empty\n"
+"\n"
+msgstr ""
+"Η προηγούμενη επιλεκτική διαλογή είναι τώρα κενή, πιθανώς λόγω επίλυσης "
+"συγκρούσεων.\n"
+"Αν θέλετε να την υποβάλετε πάραυτα, χρησιμοποιήστε:\n"
+"\n"
+"    git commit --allow-empty\n"
+"\n"
+
+#: builtin/commit.c:63
+msgid "Otherwise, please use 'git reset'\n"
+msgstr "Ειδάλλως, παρακαλώ χρησιμοποιήστε 'git reset'\n"
+
+#: builtin/commit.c:66
+msgid ""
+"If you wish to skip this commit, use:\n"
+"\n"
+"    git reset\n"
+"\n"
+"Then \"git cherry-pick --continue\" will resume cherry-picking\n"
+"the remaining commits.\n"
+msgstr ""
+"Αν θέλετε να προσπεράσετε αυτή την υποβολή, χρησιμοποιήστε:\n"
+"\n"
+"    git reset\n"
+"\n"
+"Έπειτα με \"git cherry-pick --continue\" θα συνεχίσετε την επιλεκτική "
+"διαλογή\n"
+"των υπόλοιπων υποβολών.\n"
+
+#: builtin/commit.c:312
+msgid "failed to unpack HEAD tree object"
+msgstr ""
+
+#: builtin/commit.c:353
+msgid "unable to create temporary index"
+msgstr ""
+
+#: builtin/commit.c:359
+msgid "interactive add failed"
+msgstr ""
+
+#: builtin/commit.c:373
+msgid "unable to update temporary index"
+msgstr ""
+
+#: builtin/commit.c:375
+msgid "Failed to update main cache tree"
+msgstr ""
+
+#: builtin/commit.c:400 builtin/commit.c:423 builtin/commit.c:469
+msgid "unable to write new_index file"
+msgstr ""
+
+#: builtin/commit.c:452
+msgid "cannot do a partial commit during a merge."
+msgstr ""
+
+#: builtin/commit.c:454
+msgid "cannot do a partial commit during a cherry-pick."
+msgstr ""
+
+#: builtin/commit.c:462
+msgid "cannot read the index"
+msgstr ""
+
+#: builtin/commit.c:481
+msgid "unable to write temporary index file"
+msgstr ""
+
+#: builtin/commit.c:579
+#, c-format
+msgid "commit '%s' lacks author header"
+msgstr "η υποβολή '%s' δε διαθέτει επικεφαλίδα δημιουργού"
+
+#: builtin/commit.c:581
+#, c-format
+msgid "commit '%s' has malformed author line"
+msgstr "η υποβολή '%s' έχει εσφαλμένη γραμμή δημιουργού"
+
+#: builtin/commit.c:600
+msgid "malformed --author parameter"
+msgstr ""
+
+#: builtin/commit.c:652
+msgid ""
+"unable to select a comment character that is not used\n"
+"in the current commit message"
+msgstr ""
+
+#: builtin/commit.c:689 builtin/commit.c:722 builtin/commit.c:1052
+#, c-format
+msgid "could not lookup commit %s"
+msgstr ""
+
+#: builtin/commit.c:701 builtin/shortlog.c:319
+#, c-format
+msgid "(reading log message from standard input)\n"
+msgstr ""
+
+#: builtin/commit.c:703
+msgid "could not read log from standard input"
+msgstr ""
+
+#: builtin/commit.c:707
+#, c-format
+msgid "could not read log file '%s'"
+msgstr ""
+
+#: builtin/commit.c:736 builtin/commit.c:744
+msgid "could not read SQUASH_MSG"
+msgstr ""
+
+#: builtin/commit.c:741
+msgid "could not read MERGE_MSG"
+msgstr ""
+
+#: builtin/commit.c:795
+msgid "could not write commit template"
+msgstr ""
+
+#: builtin/commit.c:813
+#, c-format
+msgid ""
+"\n"
+"It looks like you may be committing a merge.\n"
+"If this is not correct, please remove the file\n"
+"\t%s\n"
+"and try again.\n"
+msgstr ""
+"\n"
+"Φαίνεται πως μάλλον υποβάλλετε μια συγχώνευση.\n"
+"Αν αυτό δεν είναι σωστό, παρακαλώ αφαιρέστε το αρχείο\n"
+"\t%s\n"
+"και προσπαθήστε ξανά.\n"
+
+#: builtin/commit.c:818
+#, c-format
+msgid ""
+"\n"
+"It looks like you may be committing a cherry-pick.\n"
+"If this is not correct, please remove the file\n"
+"\t%s\n"
+"and try again.\n"
+msgstr ""
+"\n"
+"Φαίνεται πως μάλλον υποβάλλετε μια επιλεκτική διαλογή.\n"
+"Αν αυτό δεν είναι σωστό, παρακαλώ αφαιρέστε το αρχείο\n"
+"\t%s\n"
+"και προσπαθήστε ξανά.\n"
+
+#: builtin/commit.c:831
+#, c-format
+msgid ""
+"Please enter the commit message for your changes. Lines starting\n"
+"with '%c' will be ignored, and an empty message aborts the commit.\n"
+msgstr ""
+"Παρακαλώ εισάγετε το μήνυμα υποβολής για τις αλλαγές σας. Οι γραμμές που "
+"αρχίζουν\n"
+"με '%c' αγνοούνται, και με κενό μήνυμα εγκαταλείπετε την υποβολή.\n"
+
+#: builtin/commit.c:839
+#, c-format
+msgid ""
+"Please enter the commit message for your changes. Lines starting\n"
+"with '%c' will be kept; you may remove them yourself if you want to.\n"
+"An empty message aborts the commit.\n"
+msgstr ""
+"Παρακαλώ εισάγετε το μήνυμα υποβολής για τις αλλαγές σας. Οι γραμμές που "
+"αρχίζουν\n"
+"με '%c' θα διατηρηθούν, μπορείτε να τις αφαιρέσετε μετά αν θέλετε.\n"
+"Με κενό μήνυμα εγκαταλείπετε την υποβολή.\n"
+
+#: builtin/commit.c:856
+#, c-format
+msgid "%sAuthor:    %.*s <%.*s>"
+msgstr "%sΔημιουργός:    %.*s <%.*s>"
+
+#: builtin/commit.c:864
+#, c-format
+msgid "%sDate:      %s"
+msgstr "%sΗμερομηνία:      %s"
+
+#: builtin/commit.c:871
+#, c-format
+msgid "%sCommitter: %.*s <%.*s>"
+msgstr "%sΥποβάλλων: %.*s <%.*s>"
+
+#: builtin/commit.c:889
+msgid "Cannot read index"
+msgstr ""
+
+#: builtin/commit.c:956
+msgid "Error building trees"
+msgstr ""
+
+#: builtin/commit.c:970 builtin/tag.c:258
+#, c-format
+msgid "Please supply the message using either -m or -F option.\n"
+msgstr "Παρακαλώ εισάγετε το μήνυμα χρησιμοποιώντας την επιλογή -m ή -F.\n"
+
+#: builtin/commit.c:1014
+#, c-format
+msgid "--author '%s' is not 'Name <email>' and matches no existing author"
+msgstr ""
+"--author '%s' δεν είναι 'Όνομα <email>' και δεν ταιριάζει με κάποιον "
+"υπάρχοντα δημιουργό"
+
+#: builtin/commit.c:1028
+#, c-format
+msgid "Invalid ignored mode '%s'"
+msgstr ""
+
+#: builtin/commit.c:1042 builtin/commit.c:1279
+#, c-format
+msgid "Invalid untracked files mode '%s'"
+msgstr ""
+
+#: builtin/commit.c:1080
+msgid "--long and -z are incompatible"
+msgstr "--long και -z είναι ασύμβατα μεταξύ τους"
+
+#: builtin/commit.c:1113
+msgid "Using both --reset-author and --author does not make sense"
+msgstr "Η χρήση των --reset-author και --author ταυτόχρονα δεν έχει νόημα"
+
+#: builtin/commit.c:1122
+msgid "You have nothing to amend."
+msgstr "Δεν έχετε τίποτα προς τροποποίηση."
+
+#: builtin/commit.c:1125
+msgid "You are in the middle of a merge -- cannot amend."
+msgstr "Βρίσκεστε στη μέση μιας συγχώνευσης -- δεν είναι δυνατή η τροποποίηση."
+
+#: builtin/commit.c:1127
+msgid "You are in the middle of a cherry-pick -- cannot amend."
+msgstr ""
+"Βρίσκεστε στη μέση μιας επιλεκτικής διαλογής -- δεν είναι δυνατή η "
+"τροποποίηση."
+
+#: builtin/commit.c:1130
+msgid "Options --squash and --fixup cannot be used together"
+msgstr ""
+
+#: builtin/commit.c:1140
+msgid "Only one of -c/-C/-F/--fixup can be used."
+msgstr ""
+
+#: builtin/commit.c:1142
+msgid "Option -m cannot be combined with -c/-C/-F."
+msgstr ""
+
+#: builtin/commit.c:1150
+msgid "--reset-author can be used only with -C, -c or --amend."
+msgstr "--reset-author μπορεί να χρησιμοποιηθεί μόνο με -C, -c ή --amend."
+
+#: builtin/commit.c:1167
+msgid "Only one of --include/--only/--all/--interactive/--patch can be used."
+msgstr ""
+
+#: builtin/commit.c:1169
+msgid "No paths with --include/--only does not make sense."
+msgstr ""
+
+#: builtin/commit.c:1183 builtin/tag.c:546
+#, c-format
+msgid "Invalid cleanup mode %s"
+msgstr ""
+
+#: builtin/commit.c:1188
+msgid "Paths with -a does not make sense."
+msgstr ""
+
+#: builtin/commit.c:1314 builtin/commit.c:1498
+msgid "show status concisely"
+msgstr ""
+
+#: builtin/commit.c:1316 builtin/commit.c:1500
+msgid "show branch information"
+msgstr ""
+
+#: builtin/commit.c:1318
+msgid "show stash information"
+msgstr ""
+
+#: builtin/commit.c:1320 builtin/commit.c:1502
+msgid "compute full ahead/behind values"
+msgstr ""
+
+#: builtin/commit.c:1322
+msgid "version"
+msgstr ""
+
+#: builtin/commit.c:1322 builtin/commit.c:1504 builtin/push.c:561
+#: builtin/worktree.c:640
+msgid "machine-readable output"
+msgstr "έξοδος σε μηχανικά αναγνώσιμη μορφή"
+
+#: builtin/commit.c:1325 builtin/commit.c:1506
+msgid "show status in long format (default)"
+msgstr ""
+
+#: builtin/commit.c:1328 builtin/commit.c:1509
+msgid "terminate entries with NUL"
+msgstr ""
+
+#: builtin/commit.c:1330 builtin/commit.c:1334 builtin/commit.c:1512
+#: builtin/fast-export.c:1085 builtin/fast-export.c:1088 builtin/rebase.c:1118
+#: builtin/tag.c:400
+msgid "mode"
+msgstr ""
+
+#: builtin/commit.c:1331 builtin/commit.c:1512
+msgid "show untracked files, optional modes: all, normal, no. (Default: all)"
+msgstr ""
+
+#: builtin/commit.c:1335
+msgid ""
+"show ignored files, optional modes: traditional, matching, no. (Default: "
+"traditional)"
+msgstr ""
+
+#: builtin/commit.c:1337 parse-options.h:164
+msgid "when"
+msgstr ""
+
+#: builtin/commit.c:1338
+msgid ""
+"ignore changes to submodules, optional when: all, dirty, untracked. "
+"(Default: all)"
+msgstr ""
+
+#: builtin/commit.c:1340
+msgid "list untracked files in columns"
+msgstr ""
+
+#: builtin/commit.c:1341
+msgid "do not detect renames"
+msgstr ""
+
+#: builtin/commit.c:1343
+msgid "detect renames, optionally set similarity index"
+msgstr ""
+
+#: builtin/commit.c:1363
+msgid "Unsupported combination of ignored and untracked-files arguments"
+msgstr ""
+
+#: builtin/commit.c:1468
+msgid "suppress summary after successful commit"
+msgstr ""
+
+#: builtin/commit.c:1469
+msgid "show diff in commit message template"
+msgstr ""
+
+#: builtin/commit.c:1471
+msgid "Commit message options"
+msgstr "Επιλογές μηνύματος υποβολής"
+
+#: builtin/commit.c:1472 builtin/merge.c:264 builtin/tag.c:397
+msgid "read message from file"
+msgstr ""
+
+#: builtin/commit.c:1473
+msgid "author"
+msgstr "δημιουργός"
+
+#: builtin/commit.c:1473
+msgid "override author for commit"
+msgstr ""
+
+#: builtin/commit.c:1474 builtin/gc.c:518
+msgid "date"
+msgstr ""
+
+#: builtin/commit.c:1474
+msgid "override date for commit"
+msgstr ""
+
+#: builtin/commit.c:1475 builtin/merge.c:260 builtin/notes.c:409
+#: builtin/notes.c:575 builtin/tag.c:395
+msgid "message"
+msgstr ""
+
+#: builtin/commit.c:1475
+msgid "commit message"
+msgstr "μήνυμα υποβολής"
+
+#: builtin/commit.c:1476 builtin/commit.c:1477 builtin/commit.c:1478
+#: builtin/commit.c:1479 parse-options.h:278 ref-filter.h:92
+msgid "commit"
+msgstr "υποβολή"
+
+#: builtin/commit.c:1476
+msgid "reuse and edit message from specified commit"
+msgstr ""
+
+#: builtin/commit.c:1477
+msgid "reuse message from specified commit"
+msgstr ""
+
+#: builtin/commit.c:1478
+msgid "use autosquash formatted message to fixup specified commit"
+msgstr ""
+
+#: builtin/commit.c:1479
+msgid "use autosquash formatted message to squash specified commit"
+msgstr ""
+
+#: builtin/commit.c:1480
+msgid "the commit is authored by me now (used with -C/-c/--amend)"
+msgstr "η υποβολή έχει δημιουργό εμένα τώρα (χρησιμοποιείται με -C/-c/--amend)"
+
+#: builtin/commit.c:1481 builtin/log.c:1533 builtin/merge.c:277
+#: builtin/pull.c:156 builtin/revert.c:107
+msgid "add Signed-off-by:"
+msgstr ""
+
+#: builtin/commit.c:1482
+msgid "use specified template file"
+msgstr ""
+
+#: builtin/commit.c:1483
+msgid "force edit of commit"
+msgstr ""
+
+#: builtin/commit.c:1484
+msgid "default"
+msgstr ""
+
+#: builtin/commit.c:1484 builtin/tag.c:401
+msgid "how to strip spaces and #comments from message"
+msgstr ""
+
+#: builtin/commit.c:1485
+msgid "include status in commit message template"
+msgstr ""
+
+#: builtin/commit.c:1487 builtin/merge.c:275 builtin/pull.c:186
+#: builtin/revert.c:115
+msgid "GPG sign commit"
+msgstr ""
+
+#: builtin/commit.c:1490
+msgid "Commit contents options"
+msgstr "Επιλογές περιεχομένων υποβολής"
+
+#: builtin/commit.c:1491
+msgid "commit all changed files"
+msgstr "να γίνει υποβολή όλων των αλλαγμένων αρχείων"
+
+#: builtin/commit.c:1492
+msgid "add specified files to index for commit"
+msgstr ""
+
+#: builtin/commit.c:1493
+msgid "interactively add files"
+msgstr ""
+
+#: builtin/commit.c:1494
+msgid "interactively add changes"
+msgstr ""
+
+#: builtin/commit.c:1495
+msgid "commit only specified files"
+msgstr "να γίνει υποβολή μόνο των δοθέντων αρχείων"
+
+#: builtin/commit.c:1496
+msgid "bypass pre-commit and commit-msg hooks"
+msgstr ""
+
+#: builtin/commit.c:1497
+msgid "show what would be committed"
+msgstr ""
+
+#: builtin/commit.c:1510
+msgid "amend previous commit"
+msgstr "τροποποίηση της προηγούμενης υποβολής"
+
+#: builtin/commit.c:1511
+msgid "bypass post-rewrite hook"
+msgstr ""
+
+#: builtin/commit.c:1516
+msgid "ok to record an empty change"
+msgstr ""
+
+#: builtin/commit.c:1518
+msgid "ok to record a change with an empty message"
+msgstr ""
+
+#: builtin/commit.c:1591
+#, c-format
+msgid "Corrupt MERGE_HEAD file (%s)"
+msgstr ""
+
+#: builtin/commit.c:1598
+msgid "could not read MERGE_MODE"
+msgstr ""
+
+#: builtin/commit.c:1617
+#, c-format
+msgid "could not read commit message: %s"
+msgstr ""
+
+#: builtin/commit.c:1628
+#, c-format
+msgid "Aborting commit due to empty commit message.\n"
+msgstr "Εγκατάλειψη της υποβολής λόγω κενού μηνύματος υποβολής.\n"
+
+#: builtin/commit.c:1633
+#, c-format
+msgid "Aborting commit; you did not edit the message.\n"
+msgstr "Εγκατάλειψη της υποβολής, δεν επεξεργαστήκατε το μήνυμα.\n"
+
+#: builtin/commit.c:1668
+msgid ""
+"repository has been updated, but unable to write\n"
+"new_index file. Check that disk is not full and quota is\n"
+"not exceeded, and then \"git reset HEAD\" to recover."
+msgstr ""
+"το αποθετήριο ενημερώθηκε, αλλά δεν ήταν δυνατό να γραφεί\n"
+"το αρχείο new_index. Ελέγξτε πως ο δίσκος δεν είναι γεμάτος και πως\n"
+"δεν υπάρχει υπέρβαση ορίου, και μετά κάντε \"git reset HEAD\" για ανάκτηση."
+
+#: builtin/commit-graph.c:10
+msgid "git commit-graph [--object-dir <objdir>]"
+msgstr "git commit-graph [--object-dir <φάκελος αντικειμένων>]"
+
+#: builtin/commit-graph.c:11 builtin/commit-graph.c:23
+msgid "git commit-graph read [--object-dir <objdir>]"
+msgstr "git commit-graph read [--object-dir <φάκελος αντικειμένων>]"
+
+#: builtin/commit-graph.c:12 builtin/commit-graph.c:18
+msgid "git commit-graph verify [--object-dir <objdir>]"
+msgstr "git commit-graph verify [--object-dir <φάκελος αντικειμένων>]"
+
+#: builtin/commit-graph.c:13 builtin/commit-graph.c:28
+msgid ""
+"git commit-graph write [--object-dir <objdir>] [--append] [--reachable|--"
+"stdin-packs|--stdin-commits]"
+msgstr ""
+"git commit-graph write [--object-dir <φάκελος αντικειμένων>] [--append] [--"
+"reachable|--stdin-packs|--stdin-commits]"
+
+#: builtin/commit-graph.c:48 builtin/commit-graph.c:78
+#: builtin/commit-graph.c:132 builtin/commit-graph.c:190 builtin/fetch.c:153
+#: builtin/log.c:1553
+msgid "dir"
+msgstr "φάκελος"
+
+#: builtin/commit-graph.c:49 builtin/commit-graph.c:79
+#: builtin/commit-graph.c:133 builtin/commit-graph.c:191
+msgid "The object directory to store the graph"
+msgstr "Ο φάκελος αντικειμένων που θα αποθηκευτεί ο γράφος"
+
+#: builtin/commit-graph.c:135
+msgid "start walk at all refs"
+msgstr ""
+
+#: builtin/commit-graph.c:137
+msgid "scan pack-indexes listed by stdin for commits"
+msgstr ""
+
+#: builtin/commit-graph.c:139
+msgid "start walk at commits listed by stdin"
+msgstr ""
+
+#: builtin/commit-graph.c:141
+msgid "include all commits already in the commit-graph file"
+msgstr ""
+
+#: builtin/commit-graph.c:150
+msgid "use at most one of --reachable, --stdin-commits, or --stdin-packs"
+msgstr ""
+
+#: builtin/config.c:11
+msgid "git config [<options>]"
+msgstr "git config [<επιλογές>]"
+
+#: builtin/config.c:103
+#, c-format
+msgid "unrecognized --type argument, %s"
+msgstr ""
+
+#: builtin/config.c:115
+msgid "only one type at a time"
+msgstr "μόνο ένας τύπος κάθε φορά"
+
+#: builtin/config.c:124
+msgid "Config file location"
+msgstr "Τοποθεσία αρχείου ρυθμίσεων"
+
+#: builtin/config.c:125
+msgid "use global config file"
+msgstr "να γίνει χρήση του καθολικού αρχείου ρυθμίσεων"
+
+#: builtin/config.c:126
+msgid "use system config file"
+msgstr "να γίνει χρήση του αρχείου ρυθμίσεων συστήματος"
+
+#: builtin/config.c:127
+msgid "use repository config file"
+msgstr "να γίνει χρήση του αρχείου ρυθμίσεων αποθετηρίου"
+
+#: builtin/config.c:128
+msgid "use per-worktree config file"
+msgstr "να γίνει χρήση αρχείου ρυθμίσεων ανά δέντρο εργασίας"
+
+#: builtin/config.c:129
+msgid "use given config file"
+msgstr "να γίνει χρήση του δοθέντος αρχείου ρυθμίσεων"
+
+#: builtin/config.c:130
+msgid "blob-id"
+msgstr "αναγνωριστικό blob"
+
+#: builtin/config.c:130
+msgid "read config from given blob object"
+msgstr "ανάγνωση ρυθμίσεων από το δοθέν αντικείμενο blob"
+
+#: builtin/config.c:131
+msgid "Action"
+msgstr "Ενέργεια"
+
+#: builtin/config.c:132
+msgid "get value: name [value-regex]"
+msgstr ""
+
+#: builtin/config.c:133
+msgid "get all values: key [value-regex]"
+msgstr ""
+
+#: builtin/config.c:134
+msgid "get values for regexp: name-regex [value-regex]"
+msgstr ""
+
+#: builtin/config.c:135
+msgid "get value specific for the URL: section[.var] URL"
+msgstr ""
+
+#: builtin/config.c:136
+msgid "replace all matching variables: name value [value_regex]"
+msgstr ""
+
+#: builtin/config.c:137
+msgid "add a new variable: name value"
+msgstr ""
+
+#: builtin/config.c:138
+msgid "remove a variable: name [value-regex]"
+msgstr ""
+
+#: builtin/config.c:139
+msgid "remove all matches: name [value-regex]"
+msgstr ""
+
+#: builtin/config.c:140
+msgid "rename section: old-name new-name"
+msgstr ""
+
+#: builtin/config.c:141
+msgid "remove a section: name"
+msgstr ""
+
+#: builtin/config.c:142
+msgid "list all"
+msgstr ""
+
+#: builtin/config.c:143
+msgid "open an editor"
+msgstr ""
+
+#: builtin/config.c:144
+msgid "find the color configured: slot [default]"
+msgstr ""
+
+#: builtin/config.c:145
+msgid "find the color setting: slot [stdout-is-tty]"
+msgstr ""
+
+#: builtin/config.c:146
+msgid "Type"
+msgstr ""
+
+#: builtin/config.c:147
+msgid "value is given this type"
+msgstr ""
+
+#: builtin/config.c:148
+msgid "value is \"true\" or \"false\""
+msgstr ""
+
+#: builtin/config.c:149
+msgid "value is decimal number"
+msgstr ""
+
+#: builtin/config.c:150
+msgid "value is --bool or --int"
+msgstr ""
+
+#: builtin/config.c:151
+msgid "value is a path (file or directory name)"
+msgstr ""
+
+#: builtin/config.c:152
+msgid "value is an expiry date"
+msgstr ""
+
+#: builtin/config.c:153
+msgid "Other"
+msgstr "Άλλο"
+
+#: builtin/config.c:154
+msgid "terminate values with NUL byte"
+msgstr ""
+
+#: builtin/config.c:155
+msgid "show variable names only"
+msgstr ""
+
+#: builtin/config.c:156
+msgid "respect include directives on lookup"
+msgstr ""
+
+#: builtin/config.c:157
+msgid "show origin of config (file, standard input, blob, command line)"
+msgstr ""
+"προβολή προέλευσης ρυθμίσεων (αρχείο, standard input, blob, γραμμή εντολών)"
+
+#: builtin/config.c:158
+msgid "value"
+msgstr ""
+
+#: builtin/config.c:158
+msgid "with --get, use default value when missing entry"
+msgstr ""
+
+#: builtin/config.c:172
+#, c-format
+msgid "wrong number of arguments, should be %d"
+msgstr ""
+
+#: builtin/config.c:174
+#, c-format
+msgid "wrong number of arguments, should be from %d to %d"
+msgstr ""
+
+#: builtin/config.c:308
+#, c-format
+msgid "invalid key pattern: %s"
+msgstr ""
+
+#: builtin/config.c:344
+#, c-format
+msgid "failed to format default config value: %s"
+msgstr ""
+
+#: builtin/config.c:401
+#, c-format
+msgid "cannot parse color '%s'"
+msgstr ""
+
+#: builtin/config.c:443
+msgid "unable to parse default color value"
+msgstr ""
+
+#: builtin/config.c:496 builtin/config.c:742
+msgid "not in a git directory"
+msgstr ""
+
+#: builtin/config.c:499
+msgid "writing to stdin is not supported"
+msgstr ""
+
+#: builtin/config.c:502
+msgid "writing config blobs is not supported"
+msgstr "η εγγραφή blob ρυθμίσων δεν υποστηρίζεται"
+
+#: builtin/config.c:587
+#, c-format
+msgid ""
+"# This is Git's per-user configuration file.\n"
+"[user]\n"
+"# Please adapt and uncomment the following lines:\n"
+"#\tname = %s\n"
+"#\temail = %s\n"
+msgstr ""
+
+#: builtin/config.c:611
+msgid "only one config file at a time"
+msgstr ""
+
+#: builtin/config.c:616
+msgid "--local can only be used inside a git repository"
+msgstr "το --local μπορεί να χρησιμοποιηθεί μόνο μέσα σε αποθετήριο git"
+
+#: builtin/config.c:619
+msgid "--blob can only be used inside a git repository"
+msgstr "το --blob μπορεί να χρησιμοποιηθεί μόνο μέσα σε αποθετήριο git"
+
+#: builtin/config.c:638
+msgid "$HOME not set"
+msgstr "Το $HOME δεν έχει οριστεί"
+
+#: builtin/config.c:658
+msgid ""
+"--worktree cannot be used with multiple working trees unless the config\n"
+"extension worktreeConfig is enabled. Please read \"CONFIGURATION FILE\"\n"
+"section in \"git help worktree\" for details"
+msgstr ""
+
+#: builtin/config.c:688
+msgid "--get-color and variable type are incoherent"
+msgstr ""
+
+#: builtin/config.c:693
+msgid "only one action at a time"
+msgstr ""
+
+#: builtin/config.c:706
+msgid "--name-only is only applicable to --list or --get-regexp"
+msgstr ""
+
+#: builtin/config.c:712
+msgid ""
+"--show-origin is only applicable to --get, --get-all, --get-regexp, and --"
+"list"
+msgstr ""
+
+#: builtin/config.c:718
+msgid "--default is only applicable to --get"
+msgstr ""
+
+#: builtin/config.c:731
+#, c-format
+msgid "unable to read config file '%s'"
+msgstr ""
+
+#: builtin/config.c:734
+msgid "error processing config file(s)"
+msgstr ""
+
+#: builtin/config.c:744
+msgid "editing stdin is not supported"
+msgstr ""
+
+#: builtin/config.c:746
+msgid "editing blobs is not supported"
+msgstr "η διόρθωση blob δεν υποστηρίζεται"
+
+#: builtin/config.c:760
+#, c-format
+msgid "cannot create configuration file %s"
+msgstr ""
+
+#: builtin/config.c:773
+#, c-format
+msgid ""
+"cannot overwrite multiple values with a single value\n"
+"       Use a regexp, --add or --replace-all to change %s."
+msgstr ""
+
+#: builtin/config.c:847 builtin/config.c:858
+#, c-format
+msgid "no such section: %s"
+msgstr "δεν υπάρχει τέτοια ενότητα: %s"
+
+#: builtin/count-objects.c:90
+msgid "git count-objects [-v] [-H | --human-readable]"
+msgstr "git count-objects [-v] [-H | --human-readable]"
+
+#: builtin/count-objects.c:100
+msgid "print sizes in human readable format"
+msgstr ""
+
+#: builtin/describe.c:27
+msgid "git describe [<options>] [<commit-ish>...]"
+msgstr "git describe [<επιλογές>] [<υποβολή ή φαινομενική>...]"
+
+#: builtin/describe.c:28
+msgid "git describe [<options>] --dirty"
+msgstr "git describe [<επιλογές>] --dirty"
+
+#: builtin/describe.c:63
+msgid "head"
+msgstr ""
+
+#: builtin/describe.c:63
+msgid "lightweight"
+msgstr ""
+
+#: builtin/describe.c:63
+msgid "annotated"
+msgstr ""
+
+#: builtin/describe.c:273
+#, c-format
+msgid "annotated tag %s not available"
+msgstr ""
+
+#: builtin/describe.c:277
+#, c-format
+msgid "annotated tag %s has no embedded name"
+msgstr ""
+
+#: builtin/describe.c:279
+#, c-format
+msgid "tag '%s' is really '%s' here"
+msgstr ""
+
+#: builtin/describe.c:323
+#, c-format
+msgid "no tag exactly matches '%s'"
+msgstr "καμία ετικέτα δεν ταιριάζει ακριβώς με το '%s'"
+
+#: builtin/describe.c:325
+#, c-format
+msgid "No exact match on refs or tags, searching to describe\n"
+msgstr ""
+
+#: builtin/describe.c:379
+#, c-format
+msgid "finished search at %s\n"
+msgstr ""
+
+#: builtin/describe.c:405
+#, c-format
+msgid ""
+"No annotated tags can describe '%s'.\n"
+"However, there were unannotated tags: try --tags."
+msgstr ""
+"Καμία σχολιασμένη ετικέτα δεν περιγράφει το '%s'.\n"
+"Πάραυτα, υπήρχαν μη σχολιασμένες ετικέτες: δοκιμάστε το --tags."
+
+#: builtin/describe.c:409
+#, c-format
+msgid ""
+"No tags can describe '%s'.\n"
+"Try --always, or create some tags."
+msgstr ""
+"Καμία ετικέτα δεν περιγράφει το '%s'.\n"
+"Δοκιμάστε το --always, ή δημιουργήστε ετικέτες."
+
+#: builtin/describe.c:439
+#, c-format
+msgid "traversed %lu commits\n"
+msgstr ""
+
+#: builtin/describe.c:442
+#, c-format
+msgid ""
+"more than %i tags found; listed %i most recent\n"
+"gave up search at %s\n"
+msgstr ""
+
+#: builtin/describe.c:510
+#, c-format
+msgid "describe %s\n"
+msgstr ""
+
+#: builtin/describe.c:513 builtin/log.c:516
+#, c-format
+msgid "Not a valid object name %s"
+msgstr "Μη έγκυρο όνομα αντικειμένου %s"
+
+#: builtin/describe.c:521
+#, c-format
+msgid "%s is neither a commit nor blob"
+msgstr "%s δεν είναι ούτε υποβολή ούτε blob"
+
+#: builtin/describe.c:535
+msgid "find the tag that comes after the commit"
+msgstr ""
+
+#: builtin/describe.c:536
+msgid "debug search strategy on stderr"
+msgstr ""
+
+#: builtin/describe.c:537
+msgid "use any ref"
+msgstr "να γίνει χρήση οποιουδήποτε ref"
+
+#: builtin/describe.c:538
+msgid "use any tag, even unannotated"
+msgstr "να γίνει χρήση οποιασδήποτε ετικέτας, ακόμα και μη σχολιασμένης"
+
+#: builtin/describe.c:539
+msgid "always use long format"
+msgstr ""
+
+#: builtin/describe.c:540
+msgid "only follow first parent"
+msgstr ""
+
+#: builtin/describe.c:543
+msgid "only output exact matches"
+msgstr ""
+
+#: builtin/describe.c:545
+msgid "consider <n> most recent tags (default: 10)"
+msgstr ""
+
+#: builtin/describe.c:547
+msgid "only consider tags matching <pattern>"
+msgstr ""
+
+#: builtin/describe.c:549
+msgid "do not consider tags matching <pattern>"
+msgstr ""
+
+#: builtin/describe.c:551 builtin/name-rev.c:424
+msgid "show abbreviated commit object as fallback"
+msgstr ""
+
+#: builtin/describe.c:552 builtin/describe.c:555
+msgid "mark"
+msgstr ""
+
+#: builtin/describe.c:553
+msgid "append <mark> on dirty working tree (default: \"-dirty\")"
+msgstr ""
+
+#: builtin/describe.c:556
+msgid "append <mark> on broken working tree (default: \"-broken\")"
+msgstr ""
+
+#: builtin/describe.c:574
+msgid "--long is incompatible with --abbrev=0"
+msgstr ""
+
+#: builtin/describe.c:603
+msgid "No names found, cannot describe anything."
+msgstr ""
+
+#: builtin/describe.c:654
+msgid "--dirty is incompatible with commit-ishes"
+msgstr ""
+
+#: builtin/describe.c:656
+msgid "--broken is incompatible with commit-ishes"
+msgstr ""
+
+#: builtin/diff.c:84
+#, c-format
+msgid "'%s': not a regular file or symlink"
+msgstr ""
+
+#: builtin/diff.c:235
+#, c-format
+msgid "invalid option: %s"
+msgstr ""
+
+#: builtin/diff.c:364
+msgid "Not a git repository"
+msgstr "Δεν είναι αποθετήριο git"
+
+#: builtin/diff.c:408
+#, c-format
+msgid "invalid object '%s' given."
+msgstr ""
+
+#: builtin/diff.c:417
+#, c-format
+msgid "more than two blobs given: '%s'"
+msgstr "δόθηκαν περισσότερα από δύο blob: '%s'"
+
+#: builtin/diff.c:422
+#, c-format
+msgid "unhandled object '%s' given."
+msgstr ""
+
+#: builtin/difftool.c:31
+msgid "git difftool [<options>] [<commit> [<commit>]] [--] [<path>...]"
+msgstr "git difftool [<επιλογές>] [<υποβολή> [<υποβολή>]] [--] [<διαδρομή>...]"
+
+#: builtin/difftool.c:261
+#, c-format
+msgid "failed: %d"
+msgstr ""
+
+#: builtin/difftool.c:303
+#, c-format
+msgid "could not read symlink %s"
+msgstr ""
+
+#: builtin/difftool.c:305
+#, c-format
+msgid "could not read symlink file %s"
+msgstr ""
+
+#: builtin/difftool.c:313
+#, c-format
+msgid "could not read object %s for symlink %s"
+msgstr ""
+
+#: builtin/difftool.c:414
+msgid ""
+"combined diff formats('-c' and '--cc') are not supported in\n"
+"directory diff mode('-d' and '--dir-diff')."
+msgstr ""
+
+#: builtin/difftool.c:634
+#, c-format
+msgid "both files modified: '%s' and '%s'."
+msgstr ""
+
+#: builtin/difftool.c:636
+msgid "working tree file has been left."
+msgstr ""
+
+#: builtin/difftool.c:647
+#, c-format
+msgid "temporary files exist in '%s'."
+msgstr ""
+
+#: builtin/difftool.c:648
+msgid "you may want to cleanup or recover these."
+msgstr "μπορείτε να δοκιμάσετε να τα εκκαθαρίσετε ή να τα ανακτήσετε."
+
+#: builtin/difftool.c:697
+msgid "use `diff.guitool` instead of `diff.tool`"
+msgstr ""
+
+#: builtin/difftool.c:699
+msgid "perform a full-directory diff"
+msgstr ""
+
+#: builtin/difftool.c:701
+msgid "do not prompt before launching a diff tool"
+msgstr ""
+
+#: builtin/difftool.c:706
+msgid "use symlinks in dir-diff mode"
+msgstr ""
+
+#: builtin/difftool.c:707
+msgid "tool"
+msgstr ""
+
+#: builtin/difftool.c:708
+msgid "use the specified diff tool"
+msgstr ""
+
+#: builtin/difftool.c:710
+msgid "print a list of diff tools that may be used with `--tool`"
+msgstr ""
+
+#: builtin/difftool.c:713
+msgid ""
+"make 'git-difftool' exit when an invoked diff tool returns a non - zero exit "
+"code"
+msgstr ""
+
+#: builtin/difftool.c:716
+msgid "specify a custom command for viewing diffs"
+msgstr ""
+
+#: builtin/difftool.c:740
+msgid "no <tool> given for --tool=<tool>"
+msgstr ""
+
+#: builtin/difftool.c:747
+msgid "no <cmd> given for --extcmd=<cmd>"
+msgstr "δε δόθηκε <εντολή> για το --extcmd=<εντολή>"
+
+#: builtin/fast-export.c:29
+msgid "git fast-export [rev-list-opts]"
+msgstr "git fast-export [επιλογές παράθεσης εκδόσεων]"
+
+#: builtin/fast-export.c:1084
+msgid "show progress after <n> objects"
+msgstr ""
+
+#: builtin/fast-export.c:1086
+msgid "select handling of signed tags"
+msgstr ""
+
+#: builtin/fast-export.c:1089
+msgid "select handling of tags that tag filtered objects"
+msgstr ""
+
+#: builtin/fast-export.c:1092
+msgid "Dump marks to this file"
+msgstr ""
+
+#: builtin/fast-export.c:1094
+msgid "Import marks from this file"
+msgstr ""
+
+#: builtin/fast-export.c:1096
+msgid "Fake a tagger when tags lack one"
+msgstr ""
+
+#: builtin/fast-export.c:1098
+msgid "Output full tree for each commit"
+msgstr ""
+
+#: builtin/fast-export.c:1100
+msgid "Use the done feature to terminate the stream"
+msgstr ""
+
+#: builtin/fast-export.c:1101
+msgid "Skip output of blob data"
+msgstr "Προσπέραση εξόδου των δεδομένων blob"
+
+#: builtin/fast-export.c:1102 builtin/log.c:1601
+msgid "refspec"
+msgstr ""
+
+#: builtin/fast-export.c:1103
+msgid "Apply refspec to exported refs"
+msgstr ""
+
+#: builtin/fast-export.c:1104
+msgid "anonymize output"
+msgstr ""
+
+#: builtin/fast-export.c:1106
+msgid "Reference parents which are not in fast-export stream by object id"
+msgstr ""
+
+#: builtin/fast-export.c:1108
+msgid "Show original object ids of blobs/commits"
+msgstr "Προβολή αρχικών αναγνωριστικών των blob/υποβολών"
+
+#: builtin/fetch.c:28
+msgid "git fetch [<options>] [<repository> [<refspec>...]]"
+msgstr "git fetch [<επιλογές>] [<αποθετήριο> [<refspec>...]]"
+
+#: builtin/fetch.c:29
+msgid "git fetch [<options>] <group>"
+msgstr "git fetch [<επιλογές>] <ομάδα>"
+
+#: builtin/fetch.c:30
+msgid "git fetch --multiple [<options>] [(<repository> | <group>)...]"
+msgstr "git fetch --multiple [<επιλογές>] [(<αποθετήριο> | <ομάδα>)...]"
+
+#: builtin/fetch.c:31
+msgid "git fetch --all [<options>]"
+msgstr "git fetch --all [<επιλογές>]"
+
+#: builtin/fetch.c:115 builtin/pull.c:195
+msgid "fetch from all remotes"
+msgstr "να γίνει ανάκτηση από όλους τους απομακρυσμένους εξυπηρετητές"
+
+#: builtin/fetch.c:117 builtin/pull.c:198
+msgid "append to .git/FETCH_HEAD instead of overwriting"
+msgstr ""
+
+#: builtin/fetch.c:119 builtin/pull.c:201
+msgid "path to upload pack on remote end"
+msgstr ""
+
+#: builtin/fetch.c:120
+msgid "force overwrite of local reference"
+msgstr ""
+
+#: builtin/fetch.c:122
+msgid "fetch from multiple remotes"
+msgstr "να γίνει ανάκτηση από πολλαπλούς απομακρυσμένους εξυπηρετητές"
+
+#: builtin/fetch.c:124 builtin/pull.c:205
+msgid "fetch all tags and associated objects"
+msgstr "να γίνει ανάκτηση όλων των ετικετών και σχετικών αντικειμένων"
+
+#: builtin/fetch.c:126
+msgid "do not fetch all tags (--no-tags)"
+msgstr "να μη γίνει ανάκτηση όλων των ετικετών (--no-tags)"
+
+#: builtin/fetch.c:128
+msgid "number of submodules fetched in parallel"
+msgstr "αριθμός υποενοτήτων προς παράλληλη ανάκτηση"
+
+#: builtin/fetch.c:130 builtin/pull.c:208
+msgid "prune remote-tracking branches no longer on remote"
+msgstr ""
+
+#: builtin/fetch.c:132
+msgid "prune local tags no longer on remote and clobber changed tags"
+msgstr ""
+
+#: builtin/fetch.c:133 builtin/fetch.c:156 builtin/pull.c:133
+msgid "on-demand"
+msgstr ""
+
+#: builtin/fetch.c:134
+msgid "control recursive fetching of submodules"
+msgstr "έλεγχος αναδρομικής ανάκτησης των υποενοτήτων"
+
+#: builtin/fetch.c:138 builtin/pull.c:216
+msgid "keep downloaded pack"
+msgstr ""
+
+#: builtin/fetch.c:140
+msgid "allow updating of HEAD ref"
+msgstr ""
+
+#: builtin/fetch.c:143 builtin/fetch.c:149 builtin/pull.c:219
+msgid "deepen history of shallow clone"
+msgstr ""
+
+#: builtin/fetch.c:145
+msgid "deepen history of shallow repository based on time"
+msgstr ""
+
+#: builtin/fetch.c:151 builtin/pull.c:222
+msgid "convert to a complete repository"
+msgstr ""
+
+#: builtin/fetch.c:154
+msgid "prepend this to submodule path output"
+msgstr ""
+
+#: builtin/fetch.c:157
+msgid ""
+"default for recursive fetching of submodules (lower priority than config "
+"files)"
+msgstr ""
+
+#: builtin/fetch.c:161 builtin/pull.c:225
+msgid "accept refs that update .git/shallow"
+msgstr ""
+
+#: builtin/fetch.c:162 builtin/pull.c:227
+msgid "refmap"
+msgstr ""
+
+#: builtin/fetch.c:163 builtin/pull.c:228
+msgid "specify fetch refmap"
+msgstr ""
+
+#: builtin/fetch.c:164 builtin/ls-remote.c:77 builtin/push.c:585
+#: builtin/send-pack.c:172
+msgid "server-specific"
+msgstr "για συγκεκριμένο εξυπηρετητή"
+
+#: builtin/fetch.c:164 builtin/ls-remote.c:77 builtin/push.c:585
+#: builtin/send-pack.c:173
+msgid "option to transmit"
+msgstr "επιλογή να μεταδοθεί"
+
+#: builtin/fetch.c:170
+msgid "report that we have only objects reachable from this object"
+msgstr ""
+
+#: builtin/fetch.c:469
+msgid "Couldn't find remote ref HEAD"
+msgstr ""
+
+#: builtin/fetch.c:608
+#, c-format
+msgid "configuration fetch.output contains invalid value %s"
+msgstr "η ρύθμιση fetch.output περιέχει μη έγκυρη τιμή %s"
+
+#: builtin/fetch.c:705
+#, c-format
+msgid "object %s not found"
+msgstr ""
+
+#: builtin/fetch.c:709
+msgid "[up to date]"
+msgstr "[πλήρως ενήμερο]"
+
+#: builtin/fetch.c:722 builtin/fetch.c:738 builtin/fetch.c:801
+msgid "[rejected]"
+msgstr "[απορρίφθηκε]"
+
+#: builtin/fetch.c:723
+msgid "can't fetch in current branch"
+msgstr ""
+
+#: builtin/fetch.c:733
+msgid "[tag update]"
+msgstr ""
+
+#: builtin/fetch.c:734 builtin/fetch.c:771 builtin/fetch.c:784
+#: builtin/fetch.c:796
+msgid "unable to update local ref"
+msgstr ""
+
+#: builtin/fetch.c:738
+msgid "would clobber existing tag"
+msgstr ""
+
+#: builtin/fetch.c:760
+msgid "[new tag]"
+msgstr "[νέα ετικέτα]"
+
+#: builtin/fetch.c:763
+msgid "[new branch]"
+msgstr "[νέος κλάδος]"
+
+#: builtin/fetch.c:766
+msgid "[new ref]"
+msgstr "[νέο ref]"
+
+#: builtin/fetch.c:796
+msgid "forced update"
+msgstr ""
+
+#: builtin/fetch.c:801
+msgid "non-fast-forward"
+msgstr ""
+
+#: builtin/fetch.c:847
+#, c-format
+msgid "%s did not send all necessary objects\n"
+msgstr ""
+
+#: builtin/fetch.c:868
+#, c-format
+msgid "reject %s because shallow roots are not allowed to be updated"
+msgstr ""
+
+#: builtin/fetch.c:959 builtin/fetch.c:1081
+#, c-format
+msgid "From %.*s\n"
+msgstr "Από το %.*s\n"
+
+#: builtin/fetch.c:970
+#, c-format
+msgid ""
+"some local refs could not be updated; try running\n"
+" 'git remote prune %s' to remove any old, conflicting branches"
+msgstr ""
+
+#: builtin/fetch.c:1051
+#, c-format
+msgid "   (%s will become dangling)"
+msgstr "   (το %s θα μείνει εκκρεμές)"
+
+#: builtin/fetch.c:1052
+#, c-format
+msgid "   (%s has become dangling)"
+msgstr ""
+
+#: builtin/fetch.c:1084
+msgid "[deleted]"
+msgstr ""
+
+#: builtin/fetch.c:1085 builtin/remote.c:1036
+msgid "(none)"
+msgstr ""
+
+#: builtin/fetch.c:1108
+#, c-format
+msgid "Refusing to fetch into current branch %s of non-bare repository"
+msgstr ""
+"Αρνούμαι να κάνω ανάκτηση μέσα στον τρέχοντα κλάδο %s μη γυμνού αποθετηρίου"
+
+#: builtin/fetch.c:1127
+#, c-format
+msgid "Option \"%s\" value \"%s\" is not valid for %s"
+msgstr ""
+
+#: builtin/fetch.c:1130
+#, c-format
+msgid "Option \"%s\" is ignored for %s\n"
+msgstr ""
+
+#: builtin/fetch.c:1434
+#, c-format
+msgid "Fetching %s\n"
+msgstr "Ανάκτηση %s\n"
+
+#: builtin/fetch.c:1436 builtin/remote.c:100
+#, c-format
+msgid "Could not fetch %s"
+msgstr "Δεν ήταν δυνατή η ανάκτηση του %s"
+
+#: builtin/fetch.c:1482
+msgid ""
+"--filter can only be used with the remote configured in extensions."
+"partialClone"
+msgstr ""
+
+#: builtin/fetch.c:1506
+msgid ""
+"No remote repository specified.  Please, specify either a URL or a\n"
+"remote name from which new revisions should be fetched."
+msgstr ""
+
+#: builtin/fetch.c:1543
+msgid "You need to specify a tag name."
+msgstr "Χρειάζεται να ορίσετε ένα όνομα ετικέτας."
+
+#: builtin/fetch.c:1592
+msgid "Negative depth in --deepen is not supported"
+msgstr ""
+
+#: builtin/fetch.c:1594
+msgid "--deepen and --depth are mutually exclusive"
+msgstr ""
+
+#: builtin/fetch.c:1599
+msgid "--depth and --unshallow cannot be used together"
+msgstr ""
+
+#: builtin/fetch.c:1601
+msgid "--unshallow on a complete repository does not make sense"
+msgstr ""
+
+#: builtin/fetch.c:1617
+msgid "fetch --all does not take a repository argument"
+msgstr ""
+
+#: builtin/fetch.c:1619
+msgid "fetch --all does not make sense with refspecs"
+msgstr ""
+
+#: builtin/fetch.c:1628
+#, c-format
+msgid "No such remote or remote group: %s"
+msgstr ""
+"Δεν υπάρχει τέτοιος απομακρυσμένος εξυπηρετητής ή απομακρυσμένη ομάδα: %s"
+
+#: builtin/fetch.c:1635
+msgid "Fetching a group and specifying refspecs does not make sense"
+msgstr ""
+
+#: builtin/fetch.c:1651
+msgid ""
+"--filter can only be used with the remote configured in extensions."
+"partialclone"
+msgstr ""
+
+#: builtin/fmt-merge-msg.c:18
+msgid ""
+"git fmt-merge-msg [-m <message>] [--log[=<n>] | --no-log] [--file <file>]"
+msgstr ""
+
+#: builtin/fmt-merge-msg.c:672
+msgid "populate log with at most <n> entries from shortlog"
+msgstr ""
+
+#: builtin/fmt-merge-msg.c:675
+msgid "alias for --log (deprecated)"
+msgstr ""
+
+#: builtin/fmt-merge-msg.c:678
+msgid "text"
+msgstr ""
+
+#: builtin/fmt-merge-msg.c:679
+msgid "use <text> as start of message"
+msgstr ""
+
+#: builtin/fmt-merge-msg.c:680
+msgid "file to read from"
+msgstr ""
+
+#: builtin/for-each-ref.c:10
+msgid "git for-each-ref [<options>] [<pattern>]"
+msgstr ""
+
+#: builtin/for-each-ref.c:11
+msgid "git for-each-ref [--points-at <object>]"
+msgstr ""
+
+#: builtin/for-each-ref.c:12
+msgid "git for-each-ref [(--merged | --no-merged) [<commit>]]"
+msgstr ""
+
+#: builtin/for-each-ref.c:13
+msgid "git for-each-ref [--contains [<commit>]] [--no-contains [<commit>]]"
+msgstr ""
+
+#: builtin/for-each-ref.c:28
+msgid "quote placeholders suitably for shells"
+msgstr ""
+
+#: builtin/for-each-ref.c:30
+msgid "quote placeholders suitably for perl"
+msgstr ""
+
+#: builtin/for-each-ref.c:32
+msgid "quote placeholders suitably for python"
+msgstr ""
+
+#: builtin/for-each-ref.c:34
+msgid "quote placeholders suitably for Tcl"
+msgstr ""
+
+#: builtin/for-each-ref.c:37
+msgid "show only <n> matched refs"
+msgstr ""
+
+#: builtin/for-each-ref.c:39 builtin/tag.c:424
+msgid "respect format colors"
+msgstr ""
+
+#: builtin/for-each-ref.c:43
+msgid "print only refs which points at the given object"
+msgstr ""
+
+#: builtin/for-each-ref.c:45
+msgid "print only refs that are merged"
+msgstr ""
+
+#: builtin/for-each-ref.c:46
+msgid "print only refs that are not merged"
+msgstr ""
+
+#: builtin/for-each-ref.c:47
+msgid "print only refs which contain the commit"
+msgstr ""
+
+#: builtin/for-each-ref.c:48
+msgid "print only refs which don't contain the commit"
+msgstr ""
+
+#: builtin/fsck.c:88 builtin/fsck.c:160 builtin/fsck.c:161
+msgid "unknown"
+msgstr ""
+
+#. TRANSLATORS: e.g. error in tree 01bfda: <more explanation>
+#: builtin/fsck.c:120 builtin/fsck.c:136
+#, c-format
+msgid "error in %s %s: %s"
+msgstr ""
+
+#. TRANSLATORS: e.g. warning in tree 01bfda: <more explanation>
+#: builtin/fsck.c:131
+#, c-format
+msgid "warning in %s %s: %s"
+msgstr "προσοχή στο %s %s: %s"
+
+#: builtin/fsck.c:157 builtin/fsck.c:159
+#, c-format
+msgid "broken link from %7s %s"
+msgstr ""
+
+#: builtin/fsck.c:168
+msgid "wrong object type in link"
+msgstr ""
+
+#: builtin/fsck.c:184
+#, c-format
+msgid ""
+"broken link from %7s %s\n"
+"              to %7s %s"
+msgstr ""
+
+#: builtin/fsck.c:253
+#, c-format
+msgid "missing %s %s"
+msgstr ""
+
+#: builtin/fsck.c:279
+#, c-format
+msgid "unreachable %s %s"
+msgstr ""
+
+#: builtin/fsck.c:298
+#, c-format
+msgid "dangling %s %s"
+msgstr ""
+
+#: builtin/fsck.c:307
+msgid "could not create lost-found"
+msgstr ""
+
+#: builtin/fsck.c:318
+#, c-format
+msgid "could not finish '%s'"
+msgstr ""
+
+#: builtin/fsck.c:335
+#, c-format
+msgid "Checking %s"
+msgstr ""
+
+#: builtin/fsck.c:353
+#, c-format
+msgid "Checking connectivity (%d objects)"
+msgstr ""
+
+#: builtin/fsck.c:372
+#, c-format
+msgid "Checking %s %s"
+msgstr ""
+
+#: builtin/fsck.c:376
+msgid "broken links"
+msgstr ""
+
+#: builtin/fsck.c:385
+#, c-format
+msgid "root %s"
+msgstr ""
+
+#: builtin/fsck.c:393
+#, c-format
+msgid "tagged %s %s (%s) in %s"
+msgstr ""
+
+#: builtin/fsck.c:422
+#, c-format
+msgid "%s: object corrupt or missing"
+msgstr ""
+
+#: builtin/fsck.c:447
+#, c-format
+msgid "%s: invalid reflog entry %s"
+msgstr ""
+
+#: builtin/fsck.c:461
+#, c-format
+msgid "Checking reflog %s->%s"
+msgstr ""
+
+#: builtin/fsck.c:495
+#, c-format
+msgid "%s: invalid sha1 pointer %s"
+msgstr ""
+
+#: builtin/fsck.c:502
+#, c-format
+msgid "%s: not a commit"
+msgstr ""
+
+#: builtin/fsck.c:557
+msgid "notice: No default references"
+msgstr ""
+
+#: builtin/fsck.c:572
+#, c-format
+msgid "%s: object corrupt or missing: %s"
+msgstr ""
+
+#: builtin/fsck.c:585
+#, c-format
+msgid "%s: object could not be parsed: %s"
+msgstr ""
+
+#: builtin/fsck.c:605
+#, c-format
+msgid "bad sha1 file: %s"
+msgstr ""
+
+#: builtin/fsck.c:620
+msgid "Checking object directory"
+msgstr ""
+
+#: builtin/fsck.c:623
+msgid "Checking object directories"
+msgstr ""
+
+#: builtin/fsck.c:638
+#, c-format
+msgid "Checking %s link"
+msgstr ""
+
+#: builtin/fsck.c:643 builtin/index-pack.c:833
+#, c-format
+msgid "invalid %s"
+msgstr "μη έγκυρο %s"
+
+#: builtin/fsck.c:650
+#, c-format
+msgid "%s points to something strange (%s)"
+msgstr ""
+
+#: builtin/fsck.c:656
+#, c-format
+msgid "%s: detached HEAD points at nothing"
+msgstr ""
+
+#: builtin/fsck.c:660
+#, c-format
+msgid "notice: %s points to an unborn branch (%s)"
+msgstr ""
+
+#: builtin/fsck.c:672
+msgid "Checking cache tree"
+msgstr ""
+
+#: builtin/fsck.c:677
+#, c-format
+msgid "%s: invalid sha1 pointer in cache-tree"
+msgstr ""
+
+#: builtin/fsck.c:688
+msgid "non-tree in cache-tree"
+msgstr ""
+
+#: builtin/fsck.c:719
+msgid "git fsck [<options>] [<object>...]"
+msgstr ""
+
+#: builtin/fsck.c:725
+msgid "show unreachable objects"
+msgstr ""
+
+#: builtin/fsck.c:726
+msgid "show dangling objects"
+msgstr ""
+
+#: builtin/fsck.c:727
+msgid "report tags"
+msgstr ""
+
+#: builtin/fsck.c:728
+msgid "report root nodes"
+msgstr ""
+
+#: builtin/fsck.c:729
+msgid "make index objects head nodes"
+msgstr ""
+
+#: builtin/fsck.c:730
+msgid "make reflogs head nodes (default)"
+msgstr ""
+
+#: builtin/fsck.c:731
+msgid "also consider packs and alternate objects"
+msgstr ""
+
+#: builtin/fsck.c:732
+msgid "check only connectivity"
+msgstr ""
+
+#: builtin/fsck.c:733
+msgid "enable more strict checking"
+msgstr ""
+
+#: builtin/fsck.c:735
+msgid "write dangling objects in .git/lost-found"
+msgstr ""
+
+#: builtin/fsck.c:736 builtin/prune.c:110
+msgid "show progress"
+msgstr ""
+
+#: builtin/fsck.c:737
+msgid "show verbose names for reachable objects"
+msgstr ""
+
+#: builtin/fsck.c:797
+msgid "Checking objects"
+msgstr ""
+
+#: builtin/fsck.c:825
+#, c-format
+msgid "%s: object missing"
+msgstr ""
+
+#: builtin/fsck.c:837
+#, c-format
+msgid "invalid parameter: expected sha1, got '%s'"
+msgstr ""
+
+#: builtin/gc.c:34
+msgid "git gc [<options>]"
+msgstr "git gc [<επιλογές>]"
+
+#: builtin/gc.c:90
+#, c-format
+msgid "Failed to fstat %s: %s"
+msgstr ""
+
+#: builtin/gc.c:461 builtin/init-db.c:55
+#, c-format
+msgid "cannot stat '%s'"
+msgstr ""
+
+#: builtin/gc.c:470 builtin/notes.c:240 builtin/tag.c:510
+#, c-format
+msgid "cannot read '%s'"
+msgstr ""
+
+#: builtin/gc.c:477
+#, c-format
+msgid ""
+"The last gc run reported the following. Please correct the root cause\n"
+"and remove %s.\n"
+"Automatic cleanup will not be performed until the file is removed.\n"
+"\n"
+"%s"
+msgstr ""
+
+#: builtin/gc.c:519
+msgid "prune unreferenced objects"
+msgstr ""
+
+#: builtin/gc.c:521
+msgid "be more thorough (increased runtime)"
+msgstr ""
+
+#: builtin/gc.c:522
+msgid "enable auto-gc mode"
+msgstr ""
+
+#: builtin/gc.c:525
+msgid "force running gc even if there may be another gc running"
+msgstr ""
+
+#: builtin/gc.c:528
+msgid "repack all other packs except the largest pack"
+msgstr ""
+
+#: builtin/gc.c:545
+#, c-format
+msgid "failed to parse gc.logexpiry value %s"
+msgstr ""
+
+#: builtin/gc.c:556
+#, c-format
+msgid "failed to parse prune expiry value %s"
+msgstr ""
+
+#: builtin/gc.c:576
+#, c-format
+msgid "Auto packing the repository in background for optimum performance.\n"
+msgstr ""
+
+#: builtin/gc.c:578
+#, c-format
+msgid "Auto packing the repository for optimum performance.\n"
+msgstr ""
+
+#: builtin/gc.c:579
+#, c-format
+msgid "See \"git help gc\" for manual housekeeping.\n"
+msgstr ""
+
+#: builtin/gc.c:619
+#, c-format
+msgid ""
+"gc is already running on machine '%s' pid %<PRIuMAX> (use --force if not)"
+msgstr ""
+
+#: builtin/gc.c:672
+msgid ""
+"There are too many unreachable loose objects; run 'git prune' to remove them."
+msgstr ""
+
+#: builtin/grep.c:29
+msgid "git grep [<options>] [-e] <pattern> [<rev>...] [[--] <path>...]"
+msgstr ""
+
+#: builtin/grep.c:225
+#, c-format
+msgid "grep: failed to create thread: %s"
+msgstr ""
+
+#: builtin/grep.c:279
+#, c-format
+msgid "invalid number of threads specified (%d) for %s"
+msgstr ""
+
+#. TRANSLATORS: %s is the configuration
+#. variable for tweaking threads, currently
+#. grep.threads
+#.
+#: builtin/grep.c:287 builtin/index-pack.c:1506 builtin/index-pack.c:1697
+#: builtin/pack-objects.c:2717
+#, c-format
+msgid "no threads support, ignoring %s"
+msgstr "δεν υποστηρίζονται νήματα, παραβλέπεται το %s"
+
+#: builtin/grep.c:466 builtin/grep.c:590 builtin/grep.c:631
+#, c-format
+msgid "unable to read tree (%s)"
+msgstr ""
+
+#: builtin/grep.c:646
+#, c-format
+msgid "unable to grep from object of type %s"
+msgstr ""
+
+#: builtin/grep.c:712
+#, c-format
+msgid "switch `%c' expects a numerical value"
+msgstr ""
+
+#: builtin/grep.c:811
+msgid "search in index instead of in the work tree"
+msgstr ""
+
+#: builtin/grep.c:813
+msgid "find in contents not managed by git"
+msgstr ""
+
+#: builtin/grep.c:815
+msgid "search in both tracked and untracked files"
+msgstr ""
+
+#: builtin/grep.c:817
+msgid "ignore files specified via '.gitignore'"
+msgstr ""
+
+#: builtin/grep.c:819
+msgid "recursively search in each submodule"
+msgstr ""
+
+#: builtin/grep.c:822
+msgid "show non-matching lines"
+msgstr ""
+
+#: builtin/grep.c:824
+msgid "case insensitive matching"
+msgstr ""
+
+#: builtin/grep.c:826
+msgid "match patterns only at word boundaries"
+msgstr ""
+
+#: builtin/grep.c:828
+msgid "process binary files as text"
+msgstr ""
+
+#: builtin/grep.c:830
+msgid "don't match patterns in binary files"
+msgstr ""
+
+#: builtin/grep.c:833
+msgid "process binary files with textconv filters"
+msgstr ""
+
+#: builtin/grep.c:835
+msgid "search in subdirectories (default)"
+msgstr ""
+
+#: builtin/grep.c:837
+msgid "descend at most <depth> levels"
+msgstr ""
+
+#: builtin/grep.c:841
+msgid "use extended POSIX regular expressions"
+msgstr ""
+
+#: builtin/grep.c:844
+msgid "use basic POSIX regular expressions (default)"
+msgstr ""
+
+#: builtin/grep.c:847
+msgid "interpret patterns as fixed strings"
+msgstr ""
+
+#: builtin/grep.c:850
+msgid "use Perl-compatible regular expressions"
+msgstr ""
+
+#: builtin/grep.c:853
+msgid "show line numbers"
+msgstr ""
+
+#: builtin/grep.c:854
+msgid "show column number of first match"
+msgstr ""
+
+#: builtin/grep.c:855
+msgid "don't show filenames"
+msgstr ""
+
+#: builtin/grep.c:856
+msgid "show filenames"
+msgstr ""
+
+#: builtin/grep.c:858
+msgid "show filenames relative to top directory"
+msgstr ""
+
+#: builtin/grep.c:860
+msgid "show only filenames instead of matching lines"
+msgstr ""
+
+#: builtin/grep.c:862
+msgid "synonym for --files-with-matches"
+msgstr ""
+
+#: builtin/grep.c:865
+msgid "show only the names of files without match"
+msgstr ""
+
+#: builtin/grep.c:867
+msgid "print NUL after filenames"
+msgstr ""
+
+#: builtin/grep.c:870
+msgid "show only matching parts of a line"
+msgstr ""
+
+#: builtin/grep.c:872
+msgid "show the number of matches instead of matching lines"
+msgstr ""
+
+#: builtin/grep.c:873
+msgid "highlight matches"
+msgstr ""
+
+#: builtin/grep.c:875
+msgid "print empty line between matches from different files"
+msgstr ""
+
+#: builtin/grep.c:877
+msgid "show filename only once above matches from same file"
+msgstr ""
+
+#: builtin/grep.c:880
+msgid "show <n> context lines before and after matches"
+msgstr ""
+
+#: builtin/grep.c:883
+msgid "show <n> context lines before matches"
+msgstr ""
+
+#: builtin/grep.c:885
+msgid "show <n> context lines after matches"
+msgstr ""
+
+#: builtin/grep.c:887
+msgid "use <n> worker threads"
+msgstr ""
+
+#: builtin/grep.c:888
+msgid "shortcut for -C NUM"
+msgstr ""
+
+#: builtin/grep.c:891
+msgid "show a line with the function name before matches"
+msgstr ""
+
+#: builtin/grep.c:893
+msgid "show the surrounding function"
+msgstr ""
+
+#: builtin/grep.c:896
+msgid "read patterns from file"
+msgstr ""
+
+#: builtin/grep.c:898
+msgid "match <pattern>"
+msgstr ""
+
+#: builtin/grep.c:900
+msgid "combine patterns specified with -e"
+msgstr ""
+
+#: builtin/grep.c:912
+msgid "indicate hit with exit status without output"
+msgstr ""
+
+#: builtin/grep.c:914
+msgid "show only matches from files that match all patterns"
+msgstr ""
+
+#: builtin/grep.c:916
+msgid "show parse tree for grep expression"
+msgstr ""
+
+#: builtin/grep.c:920
+msgid "pager"
+msgstr ""
+
+#: builtin/grep.c:920
+msgid "show matching files in the pager"
+msgstr ""
+
+#: builtin/grep.c:924
+msgid "allow calling of grep(1) (ignored by this build)"
+msgstr ""
+
+#: builtin/grep.c:988
+msgid "no pattern given"
+msgstr ""
+
+#: builtin/grep.c:1024
+msgid "--no-index or --untracked cannot be used with revs"
+msgstr ""
+
+#: builtin/grep.c:1032
+#, c-format
+msgid "unable to resolve revision: %s"
+msgstr "δεν ήταν δυνατή η ταύτιση της έκδοσης: %s"
+
+#: builtin/grep.c:1063
+msgid "invalid option combination, ignoring --threads"
+msgstr ""
+
+#: builtin/grep.c:1066 builtin/pack-objects.c:3400
+msgid "no threads support, ignoring --threads"
+msgstr ""
+
+#: builtin/grep.c:1069 builtin/index-pack.c:1503 builtin/pack-objects.c:2714
+#, c-format
+msgid "invalid number of threads specified (%d)"
+msgstr "δόθηκε μη έγκυρος αριθμός νημάτων (%d)"
+
+#: builtin/grep.c:1092
+msgid "--open-files-in-pager only works on the worktree"
+msgstr ""
+
+#: builtin/grep.c:1115
+msgid "option not supported with --recurse-submodules"
+msgstr ""
+
+#: builtin/grep.c:1121
+msgid "--cached or --untracked cannot be used with --no-index"
+msgstr ""
+
+#: builtin/grep.c:1127
+msgid "--[no-]exclude-standard cannot be used for tracked contents"
+msgstr ""
+
+#: builtin/grep.c:1135
+msgid "both --cached and trees are given"
+msgstr ""
+
+#: builtin/hash-object.c:85
+msgid ""
+"git hash-object [-t <type>] [-w] [--path=<file> | --no-filters] [--stdin] "
+"[--] <file>..."
+msgstr ""
+
+#: builtin/hash-object.c:86
+msgid "git hash-object  --stdin-paths"
+msgstr "git hash-object  --stdin-paths"
+
+#: builtin/hash-object.c:98
+msgid "type"
+msgstr ""
+
+#: builtin/hash-object.c:98
+msgid "object type"
+msgstr "τύπος αντικειμένου"
+
+#: builtin/hash-object.c:99
+msgid "write the object into the object database"
+msgstr ""
+
+#: builtin/hash-object.c:101
+msgid "read the object from stdin"
+msgstr ""
+
+#: builtin/hash-object.c:103
+msgid "store file as is without filters"
+msgstr ""
+
+#: builtin/hash-object.c:104
+msgid ""
+"just hash any random garbage to create corrupt objects for debugging Git"
+msgstr ""
+
+#: builtin/hash-object.c:105
+msgid "process file as it were from this path"
+msgstr ""
+
+#: builtin/help.c:46
+msgid "print all available commands"
+msgstr ""
+
+#: builtin/help.c:47
+msgid "exclude guides"
+msgstr ""
+
+#: builtin/help.c:48
+msgid "print list of useful guides"
+msgstr ""
+
+#: builtin/help.c:49
+msgid "print all configuration variable names"
+msgstr ""
+
+#: builtin/help.c:51
+msgid "show man page"
+msgstr ""
+
+#: builtin/help.c:52
+msgid "show manual in web browser"
+msgstr ""
+
+#: builtin/help.c:54
+msgid "show info page"
+msgstr ""
+
+#: builtin/help.c:56
+msgid "print command description"
+msgstr ""
+
+#: builtin/help.c:61
+msgid "git help [--all] [--guides] [--man | --web | --info] [<command>]"
+msgstr ""
+
+#: builtin/help.c:73
+#, c-format
+msgid "unrecognized help format '%s'"
+msgstr ""
+
+#: builtin/help.c:100
+msgid "Failed to start emacsclient."
+msgstr ""
+
+#: builtin/help.c:113
+msgid "Failed to parse emacsclient version."
+msgstr ""
+
+#: builtin/help.c:121
+#, c-format
+msgid "emacsclient version '%d' too old (< 22)."
+msgstr ""
+
+#: builtin/help.c:139 builtin/help.c:161 builtin/help.c:171 builtin/help.c:179
+#, c-format
+msgid "failed to exec '%s'"
+msgstr ""
+
+#: builtin/help.c:217
+#, c-format
+msgid ""
+"'%s': path for unsupported man viewer.\n"
+"Please consider using 'man.<tool>.cmd' instead."
+msgstr ""
+
+#: builtin/help.c:229
+#, c-format
+msgid ""
+"'%s': cmd for supported man viewer.\n"
+"Please consider using 'man.<tool>.path' instead."
+msgstr ""
+
+#: builtin/help.c:346
+#, c-format
+msgid "'%s': unknown man viewer."
+msgstr ""
+
+#: builtin/help.c:363
+msgid "no man viewer handled the request"
+msgstr ""
+
+#: builtin/help.c:371
+msgid "no info viewer handled the request"
+msgstr ""
+
+#: builtin/help.c:430 builtin/help.c:441 git.c:323
+#, c-format
+msgid "'%s' is aliased to '%s'"
+msgstr ""
+
+#: builtin/help.c:444 git.c:347
+#, c-format
+msgid "bad alias.%s string: %s"
+msgstr ""
+
+#: builtin/help.c:473 builtin/help.c:503
+#, c-format
+msgid "usage: %s%s"
+msgstr "χρήση: %s%s"
+
+#: builtin/help.c:487
+msgid "'git help config' for more information"
+msgstr "'git help config' για περισσότερες πληροφορίες"
+
+#: builtin/index-pack.c:184
+#, c-format
+msgid "object type mismatch at %s"
+msgstr "ασυμφωνία τύπου αντικειμένου στο %s"
+
+#: builtin/index-pack.c:204
+#, c-format
+msgid "did not receive expected object %s"
+msgstr "δεν ελήφθη το αναμενόμενο αντικείμενο %s"
+
+#: builtin/index-pack.c:207
+#, c-format
+msgid "object %s: expected type %s, found %s"
+msgstr "αντικείμενο %s: αναμενόταν τύπος %s, βρέθηκε %s"
+
+#: builtin/index-pack.c:249
+#, c-format
+msgid "cannot fill %d byte"
+msgid_plural "cannot fill %d bytes"
+msgstr[0] ""
+msgstr[1] ""
+
+#: builtin/index-pack.c:259
+msgid "early EOF"
+msgstr "πρόωρο EOF"
+
+#: builtin/index-pack.c:260
+msgid "read error on input"
+msgstr "σφάλμα ανάγνωσης κατά την εισαγωγή"
+
+#: builtin/index-pack.c:272
+msgid "used more bytes than were available"
+msgstr "χρησιμοποίησε περισσότερα bytes από όσα ήταν διαθέσιμα"
+
+#: builtin/index-pack.c:279 builtin/pack-objects.c:599
+msgid "pack too large for current definition of off_t"
+msgstr "το πακέτο παραείναι μεγάλο για τον τρέχοντα ορισμό του off_t"
+
+#: builtin/index-pack.c:282 builtin/unpack-objects.c:94
+msgid "pack exceeds maximum allowed size"
+msgstr "το πακέτο υπερβαίνει το μέγιστο επιτρεπτό μέγεθος"
+
+#: builtin/index-pack.c:297 builtin/repack.c:250
+#, c-format
+msgid "unable to create '%s'"
+msgstr "δεν ήταν δυνατή η δημιουργία του '%s'"
+
+#: builtin/index-pack.c:303
+#, c-format
+msgid "cannot open packfile '%s'"
+msgstr "δεν ήταν δυνατό το άνοιγμα του αρχείου πακέτου '%s'"
+
+#: builtin/index-pack.c:317
+msgid "pack signature mismatch"
+msgstr "ασυμφωνία υπογραφής πακέτου"
+
+#: builtin/index-pack.c:319
+#, c-format
+msgid "pack version %<PRIu32> unsupported"
+msgstr "δεν υποστηρίζεται η έκδοση %<PRIu32> του πακέτου"
+
+#: builtin/index-pack.c:337
+#, c-format
+msgid "pack has bad object at offset %<PRIuMAX>: %s"
+msgstr "το πακέτο έχει λάθος αντικείμενο στο σημείο %<PRIuMAX>: %s"
+
+#: builtin/index-pack.c:457
+#, c-format
+msgid "inflate returned %d"
+msgstr "η αποσυμπίεση επέστρεψε %d"
+
+#: builtin/index-pack.c:506
+msgid "offset value overflow for delta base object"
+msgstr "υπερχείλιση τιμής σημείου για το βασικό αντικείμενο delta"
+
+#: builtin/index-pack.c:514
+msgid "delta base offset is out of bound"
+msgstr "το σημείο της βάσης delta είναι εκτός ορίων"
+
+#: builtin/index-pack.c:522
+#, c-format
+msgid "unknown object type %d"
+msgstr "άγνωστος τύπος αντικειμένου %d"
+
+#: builtin/index-pack.c:553
+msgid "cannot pread pack file"
+msgstr "δεν είναι δυνατό να γίνει pread το αρχείο πακέτου"
+
+#: builtin/index-pack.c:555
+#, c-format
+msgid "premature end of pack file, %<PRIuMAX> byte missing"
+msgid_plural "premature end of pack file, %<PRIuMAX> bytes missing"
+msgstr[0] ""
+msgstr[1] ""
+
+#: builtin/index-pack.c:581
+msgid "serious inflate inconsistency"
+msgstr "σοβαρή αντίφαση στην αποσυμπίεση"
+
+#: builtin/index-pack.c:726 builtin/index-pack.c:732 builtin/index-pack.c:755
+#: builtin/index-pack.c:794 builtin/index-pack.c:803
+#, c-format
+msgid "SHA1 COLLISION FOUND WITH %s !"
+msgstr "ΒΡΕΘΗΚΕ ΣΥΓΚΡΟΥΣΗ SHA1 ΜΕ ΤΟ %s !"
+
+#: builtin/index-pack.c:729 builtin/pack-objects.c:152
+#: builtin/pack-objects.c:212 builtin/pack-objects.c:306
+#, c-format
+msgid "unable to read %s"
+msgstr "δεν ήταν δυνατή η ανάγνωση του %s"
+
+#: builtin/index-pack.c:792
+#, c-format
+msgid "cannot read existing object info %s"
+msgstr ""
+"δεν είναι δυνατή η ανάγνωση των πληροφοριών του υπάρχοντος αντικειμένου %s"
+
+#: builtin/index-pack.c:800
+#, c-format
+msgid "cannot read existing object %s"
+msgstr "δεν είναι δυνατή η ανάγνωση του υπάρχοντος αντικειμένου %s"
+
+#: builtin/index-pack.c:814
+#, c-format
+msgid "invalid blob object %s"
+msgstr "μη έγκυρο αντικείμενο blob %s"
+
+#: builtin/index-pack.c:817 builtin/index-pack.c:836
+msgid "fsck error in packed object"
+msgstr "σφάλμα fsck στο πακεταρισμένο αντικείμενο"
+
+#: builtin/index-pack.c:838
+#, c-format
+msgid "Not all child objects of %s are reachable"
+msgstr "Δεν είναι προσβάσιμα όλα τα αντικείμενα παιδιά του %s"
+
+#: builtin/index-pack.c:910 builtin/index-pack.c:941
+msgid "failed to apply delta"
+msgstr "απέτυχε η εφαρμογή του delta"
+
+#: builtin/index-pack.c:1109
+msgid "Receiving objects"
+msgstr "Λήψη αντικειμένων"
+
+#: builtin/index-pack.c:1109
+msgid "Indexing objects"
+msgstr "Προσθήκη σε ευρετήριο αντικειμένων"
+
+#: builtin/index-pack.c:1143
+msgid "pack is corrupted (SHA1 mismatch)"
+msgstr "το πακέτο είναι κατεστραμμένο (ασυμφωνία SHA1)"
+
+#: builtin/index-pack.c:1148
+msgid "cannot fstat packfile"
+msgstr "δεν είναι δυνατό το fstat του αρχείου πακέτου"
+
+#: builtin/index-pack.c:1151
+msgid "pack has junk at the end"
+msgstr "το πακέτο έχει σκουπίδια στο τέλος του"
+
+#: builtin/index-pack.c:1163
+msgid "confusion beyond insanity in parse_pack_objects()"
+msgstr "ασύλληπτο μπέρδεμα στο parse_pack_objects()"
+
+#: builtin/index-pack.c:1186
+msgid "Resolving deltas"
+msgstr "Επίλυση delta"
+
+#: builtin/index-pack.c:1196 builtin/pack-objects.c:2486
+#, c-format
+msgid "unable to create thread: %s"
+msgstr "δεν είναι δυνατή η δημιουργία νήματος: %s"
+
+#: builtin/index-pack.c:1237
+msgid "confusion beyond insanity"
+msgstr "ασύλληπτο μπέρδεμα"
+
+#: builtin/index-pack.c:1243
+#, c-format
+msgid "completed with %d local object"
+msgid_plural "completed with %d local objects"
+msgstr[0] "ολοκληρώθηκε με %d τοπικό αντικείμενο"
+msgstr[1] "ολοκληρώθηκε με %d τοπικά αντικείμενα"
+
+#: builtin/index-pack.c:1255
+#, c-format
+msgid "Unexpected tail checksum for %s (disk corruption?)"
+msgstr ""
+"Μη αναμενόμενο τελικό άθροισμα ελέγχου για το %s (κατεστραμμένος δίσκος;)"
+
+#: builtin/index-pack.c:1259
+#, c-format
+msgid "pack has %d unresolved delta"
+msgid_plural "pack has %d unresolved deltas"
+msgstr[0] "το πακέτο έχει %d ανεπίλυτο delta"
+msgstr[1] "το πακέτο έχει %d ανεπίλυτα delta"
+
+#: builtin/index-pack.c:1283
+#, c-format
+msgid "unable to deflate appended object (%d)"
+msgstr "δεν είναι δυνατό να αποσυμπιστεί το συνημμένο αντικείμενο (%d)"
+
+#: builtin/index-pack.c:1360
+#, c-format
+msgid "local object %s is corrupt"
+msgstr "το τοπικό αντικείμενο %s είναι κατεστραμμένο"
+
+#: builtin/index-pack.c:1374
+#, c-format
+msgid "packfile name '%s' does not end with '.pack'"
+msgstr "το όνομα του αρχείου πακέτου '%s' δεν τελειώνει σε '.pack'"
+
+#: builtin/index-pack.c:1399
+#, c-format
+msgid "cannot write %s file '%s'"
+msgstr "δεν είναι δυνατή η εγγραφή %s αρχείου '%s'"
+
+#: builtin/index-pack.c:1407
+#, c-format
+msgid "cannot close written %s file '%s'"
+msgstr "δεν είναι δυνατό το κλείσιμο του εγγεγραμμένου %s αρχείου '%s'"
+
+#: builtin/index-pack.c:1431
+msgid "error while closing pack file"
+msgstr "σφάλμα κατά το κλείσιμο του αρχείου πακέτου"
+
+#: builtin/index-pack.c:1445
+msgid "cannot store pack file"
+msgstr "δεν είναι δυνατή η αποθήκευση του αρχείου πακέτου"
+
+#: builtin/index-pack.c:1453
+msgid "cannot store index file"
+msgstr "δεν είναι δυνατή η αποθήκευση του αρχείου ευρετηρίου"
+
+#: builtin/index-pack.c:1497 builtin/pack-objects.c:2725
+#, c-format
+msgid "bad pack.indexversion=%<PRIu32>"
+msgstr "λάθος pack.indexversion=%<PRIu32>"
+
+#: builtin/index-pack.c:1565
+#, c-format
+msgid "Cannot open existing pack file '%s'"
+msgstr "Δεν είναι δυνατό το άνοιγμα του υπάρχοντος αρχείου πακέτου '%s'"
+
+#: builtin/index-pack.c:1567
+#, c-format
+msgid "Cannot open existing pack idx file for '%s'"
+msgstr ""
+"Δεν είναι δυνατό το άνοιγμα του υπάρχοντος αρχείου ευρετηρίου πακέτου για "
+"'%s'"
+
+#: builtin/index-pack.c:1615
+#, c-format
+msgid "non delta: %d object"
+msgid_plural "non delta: %d objects"
+msgstr[0] ""
+msgstr[1] ""
+
+#: builtin/index-pack.c:1622
+#, c-format
+msgid "chain length = %d: %lu object"
+msgid_plural "chain length = %d: %lu objects"
+msgstr[0] ""
+msgstr[1] ""
+
+#: builtin/index-pack.c:1659
+msgid "Cannot come back to cwd"
+msgstr "Δεν είναι δυνατή η επιστροφή στον τρέχοντα φάκελο εργασίας"
+
+#: builtin/index-pack.c:1708 builtin/index-pack.c:1711
+#: builtin/index-pack.c:1727 builtin/index-pack.c:1731
+#, c-format
+msgid "bad %s"
+msgstr "λάθος %s"
+
+#: builtin/index-pack.c:1747
+msgid "--fix-thin cannot be used without --stdin"
+msgstr "το --fix-thin δε γίνεται να χρησιμοποιηθεί χωρίς το --stdin"
+
+#: builtin/index-pack.c:1749
+msgid "--stdin requires a git repository"
+msgstr "το --stdin απαιτεί ένα αποθετήριο git"
+
+#: builtin/index-pack.c:1755
+msgid "--verify with no packfile name given"
+msgstr "δόθηκε --verify χωρίς όνομα αρχείου πακέτου"
+
+#: builtin/index-pack.c:1803 builtin/unpack-objects.c:580
+msgid "fsck error in pack objects"
+msgstr "σφάλμα fsck στα αντικείμενα του πακέτου"
+
+#: builtin/init-db.c:61
+#, c-format
+msgid "cannot stat template '%s'"
+msgstr ""
+
+#: builtin/init-db.c:66
+#, c-format
+msgid "cannot opendir '%s'"
+msgstr ""
+
+#: builtin/init-db.c:78
+#, c-format
+msgid "cannot readlink '%s'"
+msgstr ""
+
+#: builtin/init-db.c:80
+#, c-format
+msgid "cannot symlink '%s' '%s'"
+msgstr ""
+
+#: builtin/init-db.c:86
+#, c-format
+msgid "cannot copy '%s' to '%s'"
+msgstr ""
+
+#: builtin/init-db.c:90
+#, c-format
+msgid "ignoring template %s"
+msgstr ""
+
+#: builtin/init-db.c:121
+#, c-format
+msgid "templates not found in %s"
+msgstr ""
+
+#: builtin/init-db.c:136
+#, c-format
+msgid "not copying templates from '%s': %s"
+msgstr ""
+
+#: builtin/init-db.c:329
+#, c-format
+msgid "unable to handle file type %d"
+msgstr ""
+
+#: builtin/init-db.c:332
+#, c-format
+msgid "unable to move %s to %s"
+msgstr ""
+
+#: builtin/init-db.c:349 builtin/init-db.c:352
+#, c-format
+msgid "%s already exists"
+msgstr ""
+
+#: builtin/init-db.c:405
+#, c-format
+msgid "Reinitialized existing shared Git repository in %s%s\n"
+msgstr ""
+
+#: builtin/init-db.c:406
+#, c-format
+msgid "Reinitialized existing Git repository in %s%s\n"
+msgstr ""
+
+#: builtin/init-db.c:410
+#, c-format
+msgid "Initialized empty shared Git repository in %s%s\n"
+msgstr ""
+
+#: builtin/init-db.c:411
+#, c-format
+msgid "Initialized empty Git repository in %s%s\n"
+msgstr ""
+
+#: builtin/init-db.c:460
+msgid ""
+"git init [-q | --quiet] [--bare] [--template=<template-directory>] [--"
+"shared[=<permissions>]] [<directory>]"
+msgstr ""
+"git init [-q | --quiet] [--bare] [--template=<φάκελος προτύπου>] [--"
+"shared[=<δικαιώματα>]] [<φάκελος>]"
+
+#: builtin/init-db.c:483
+msgid "permissions"
+msgstr "δικαιώματα"
+
+#: builtin/init-db.c:484
+msgid "specify that the git repository is to be shared amongst several users"
+msgstr ""
+
+#: builtin/init-db.c:518 builtin/init-db.c:523
+#, c-format
+msgid "cannot mkdir %s"
+msgstr ""
+
+#: builtin/init-db.c:527
+#, c-format
+msgid "cannot chdir to %s"
+msgstr ""
+
+#: builtin/init-db.c:548
+#, c-format
+msgid ""
+"%s (or --work-tree=<directory>) not allowed without specifying %s (or --git-"
+"dir=<directory>)"
+msgstr ""
+
+#: builtin/init-db.c:576
+#, c-format
+msgid "Cannot access work tree '%s'"
+msgstr ""
+
+#: builtin/interpret-trailers.c:15
+msgid ""
+"git interpret-trailers [--in-place] [--trim-empty] [(--trailer "
+"<token>[(=|:)<value>])...] [<file>...]"
+msgstr ""
+
+#: builtin/interpret-trailers.c:94
+msgid "edit files in place"
+msgstr ""
+
+#: builtin/interpret-trailers.c:95
+msgid "trim empty trailers"
+msgstr ""
+
+#: builtin/interpret-trailers.c:98
+msgid "where to place the new trailer"
+msgstr ""
+
+#: builtin/interpret-trailers.c:100
+msgid "action if trailer already exists"
+msgstr "ενέργεια αν υπάρχει ήδη υποσημείωση"
+
+#: builtin/interpret-trailers.c:102
+msgid "action if trailer is missing"
+msgstr "ενέργεια αν δεν υπάρχει υποσημείωση"
+
+#: builtin/interpret-trailers.c:104
+msgid "output only the trailers"
+msgstr ""
+
+#: builtin/interpret-trailers.c:105
+msgid "do not apply config rules"
+msgstr ""
+
+#: builtin/interpret-trailers.c:106
+msgid "join whitespace-continued values"
+msgstr ""
+
+#: builtin/interpret-trailers.c:107
+msgid "set parsing options"
+msgstr ""
+
+#: builtin/interpret-trailers.c:109
+msgid "do not treat --- specially"
+msgstr ""
+
+#: builtin/interpret-trailers.c:110
+msgid "trailer"
+msgstr ""
+
+#: builtin/interpret-trailers.c:111
+msgid "trailer(s) to add"
+msgstr ""
+
+#: builtin/interpret-trailers.c:120
+msgid "--trailer with --only-input does not make sense"
+msgstr ""
+
+#: builtin/interpret-trailers.c:130
+msgid "no input file given for in-place editing"
+msgstr ""
+
+#: builtin/log.c:55
+msgid "git log [<options>] [<revision-range>] [[--] <path>...]"
+msgstr "git log [<επιλογές>] [<εύρος εκδόσεων>] [[--] <διαδρομή>...]"
+
+#: builtin/log.c:56
+msgid "git show [<options>] <object>..."
+msgstr ""
+
+#: builtin/log.c:100
+#, c-format
+msgid "invalid --decorate option: %s"
+msgstr ""
+
+#: builtin/log.c:163
+msgid "suppress diff output"
+msgstr ""
+
+#: builtin/log.c:164
+msgid "show source"
+msgstr ""
+
+#: builtin/log.c:165
+msgid "Use mail map file"
+msgstr ""
+
+#: builtin/log.c:167
+msgid "only decorate refs that match <pattern>"
+msgstr ""
+
+#: builtin/log.c:169
+msgid "do not decorate refs that match <pattern>"
+msgstr ""
+
+#: builtin/log.c:170
+msgid "decorate options"
+msgstr ""
+
+#: builtin/log.c:173
+msgid "Process line range n,m in file, counting from 1"
+msgstr ""
+
+#: builtin/log.c:271
+#, c-format
+msgid "Final output: %d %s\n"
+msgstr ""
+
+#: builtin/log.c:525
+#, c-format
+msgid "git show %s: bad file"
+msgstr ""
+
+#: builtin/log.c:540 builtin/log.c:634
+#, c-format
+msgid "Could not read object %s"
+msgstr ""
+
+#: builtin/log.c:659
+#, c-format
+msgid "Unknown type: %d"
+msgstr ""
+
+#: builtin/log.c:780
+msgid "format.headers without value"
+msgstr ""
+
+#: builtin/log.c:881
+msgid "name of output directory is too long"
+msgstr ""
+
+#: builtin/log.c:897
+#, c-format
+msgid "Cannot open patch file %s"
+msgstr ""
+
+#: builtin/log.c:914
+msgid "Need exactly one range."
+msgstr ""
+
+#: builtin/log.c:924
+msgid "Not a range."
+msgstr "Δεν είναι εύρος."
+
+#: builtin/log.c:1047
+msgid "Cover letter needs email format"
+msgstr ""
+
+#: builtin/log.c:1132
+#, c-format
+msgid "insane in-reply-to: %s"
+msgstr ""
+
+#: builtin/log.c:1159
+msgid "git format-patch [<options>] [<since> | <revision-range>]"
+msgstr ""
+
+#: builtin/log.c:1217
+msgid "Two output directories?"
+msgstr ""
+
+#: builtin/log.c:1324 builtin/log.c:2068 builtin/log.c:2070 builtin/log.c:2082
+#, c-format
+msgid "Unknown commit %s"
+msgstr ""
+
+#: builtin/log.c:1334 builtin/notes.c:897 builtin/tag.c:526
+#, c-format
+msgid "Failed to resolve '%s' as a valid ref."
+msgstr ""
+
+#: builtin/log.c:1339
+msgid "Could not find exact merge base."
+msgstr ""
+
+#: builtin/log.c:1343
+msgid ""
+"Failed to get upstream, if you want to record base commit automatically,\n"
+"please use git branch --set-upstream-to to track a remote branch.\n"
+"Or you could specify base commit by --base=<base-commit-id> manually."
+msgstr ""
+
+#: builtin/log.c:1363
+msgid "Failed to find exact merge base"
+msgstr ""
+
+#: builtin/log.c:1374
+msgid "base commit should be the ancestor of revision list"
+msgstr ""
+
+#: builtin/log.c:1378
+msgid "base commit shouldn't be in revision list"
+msgstr ""
+
+#: builtin/log.c:1431
+msgid "cannot get patch id"
+msgstr ""
+
+#: builtin/log.c:1483
+msgid "failed to infer range-diff ranges"
+msgstr ""
+
+#: builtin/log.c:1528
+msgid "use [PATCH n/m] even with a single patch"
+msgstr ""
+
+#: builtin/log.c:1531
+msgid "use [PATCH] even with multiple patches"
+msgstr ""
+
+#: builtin/log.c:1535
+msgid "print patches to standard out"
+msgstr ""
+
+#: builtin/log.c:1537
+msgid "generate a cover letter"
+msgstr ""
+
+#: builtin/log.c:1539
+msgid "use simple number sequence for output file names"
+msgstr ""
+
+#: builtin/log.c:1540
+msgid "sfx"
+msgstr ""
+
+#: builtin/log.c:1541
+msgid "use <sfx> instead of '.patch'"
+msgstr ""
+
+#: builtin/log.c:1543
+msgid "start numbering patches at <n> instead of 1"
+msgstr ""
+
+#: builtin/log.c:1545
+msgid "mark the series as Nth re-roll"
+msgstr ""
+
+#: builtin/log.c:1547
+msgid "Use [RFC PATCH] instead of [PATCH]"
+msgstr ""
+
+#: builtin/log.c:1550
+msgid "Use [<prefix>] instead of [PATCH]"
+msgstr ""
+
+#: builtin/log.c:1553
+msgid "store resulting files in <dir>"
+msgstr ""
+
+#: builtin/log.c:1556
+msgid "don't strip/add [PATCH]"
+msgstr ""
+
+#: builtin/log.c:1559
+msgid "don't output binary diffs"
+msgstr ""
+
+#: builtin/log.c:1561
+msgid "output all-zero hash in From header"
+msgstr ""
+
+#: builtin/log.c:1563
+msgid "don't include a patch matching a commit upstream"
+msgstr ""
+
+#: builtin/log.c:1565
+msgid "show patch format instead of default (patch + stat)"
+msgstr ""
+
+#: builtin/log.c:1567
+msgid "Messaging"
+msgstr ""
+
+#: builtin/log.c:1568
+msgid "header"
+msgstr ""
+
+#: builtin/log.c:1569
+msgid "add email header"
+msgstr ""
+
+#: builtin/log.c:1570 builtin/log.c:1572
+msgid "email"
+msgstr ""
+
+#: builtin/log.c:1570
+msgid "add To: header"
+msgstr ""
+
+#: builtin/log.c:1572
+msgid "add Cc: header"
+msgstr ""
+
+#: builtin/log.c:1574
+msgid "ident"
+msgstr ""
+
+#: builtin/log.c:1575
+msgid "set From address to <ident> (or committer ident if absent)"
+msgstr ""
+
+#: builtin/log.c:1577
+msgid "message-id"
+msgstr ""
+
+#: builtin/log.c:1578
+msgid "make first mail a reply to <message-id>"
+msgstr ""
+
+#: builtin/log.c:1579 builtin/log.c:1582
+msgid "boundary"
+msgstr ""
+
+#: builtin/log.c:1580
+msgid "attach the patch"
+msgstr ""
+
+#: builtin/log.c:1583
+msgid "inline the patch"
+msgstr ""
+
+#: builtin/log.c:1587
+msgid "enable message threading, styles: shallow, deep"
+msgstr ""
+
+#: builtin/log.c:1589
+msgid "signature"
+msgstr ""
+
+#: builtin/log.c:1590
+msgid "add a signature"
+msgstr ""
+
+#: builtin/log.c:1591
+msgid "base-commit"
+msgstr ""
+
+#: builtin/log.c:1592
+msgid "add prerequisite tree info to the patch series"
+msgstr ""
+
+#: builtin/log.c:1594
+msgid "add a signature from a file"
+msgstr ""
+
+#: builtin/log.c:1595
+msgid "don't print the patch filenames"
+msgstr ""
+
+#: builtin/log.c:1597
+msgid "show progress while generating patches"
+msgstr ""
+
+#: builtin/log.c:1598
+msgid "rev"
+msgstr ""
+
+#: builtin/log.c:1599
+msgid "show changes against <rev> in cover letter or single patch"
+msgstr ""
+
+#: builtin/log.c:1602
+msgid "show changes against <refspec> in cover letter or single patch"
+msgstr ""
+
+#: builtin/log.c:1604
+msgid "percentage by which creation is weighted"
+msgstr ""
+
+#: builtin/log.c:1679
+#, c-format
+msgid "invalid ident line: %s"
+msgstr ""
+
+#: builtin/log.c:1694
+msgid "-n and -k are mutually exclusive"
+msgstr ""
+
+#: builtin/log.c:1696
+msgid "--subject-prefix/--rfc and -k are mutually exclusive"
+msgstr ""
+
+#: builtin/log.c:1704
+msgid "--name-only does not make sense"
+msgstr ""
+
+#: builtin/log.c:1706
+msgid "--name-status does not make sense"
+msgstr ""
+
+#: builtin/log.c:1708
+msgid "--check does not make sense"
+msgstr ""
+
+#: builtin/log.c:1740
+msgid "standard output, or directory, which one?"
+msgstr ""
+
+#: builtin/log.c:1742
+#, c-format
+msgid "Could not create directory '%s'"
+msgstr ""
+
+#: builtin/log.c:1829
+msgid "--interdiff requires --cover-letter or single patch"
+msgstr ""
+
+#: builtin/log.c:1833
+msgid "Interdiff:"
+msgstr ""
+
+#: builtin/log.c:1834
+#, c-format
+msgid "Interdiff against v%d:"
+msgstr ""
+
+#: builtin/log.c:1840
+msgid "--creation-factor requires --range-diff"
+msgstr ""
+
+#: builtin/log.c:1844
+msgid "--range-diff requires --cover-letter or single patch"
+msgstr ""
+
+#: builtin/log.c:1852
+msgid "Range-diff:"
+msgstr ""
+
+#: builtin/log.c:1853
+#, c-format
+msgid "Range-diff against v%d:"
+msgstr ""
+
+#: builtin/log.c:1864
+#, c-format
+msgid "unable to read signature file '%s'"
+msgstr ""
+
+#: builtin/log.c:1900
+msgid "Generating patches"
+msgstr ""
+
+#: builtin/log.c:1944
+msgid "Failed to create output files"
+msgstr ""
+
+#: builtin/log.c:2003
+msgid "git cherry [-v] [<upstream> [<head> [<limit>]]]"
+msgstr "git cherry [-v] [<προς τα πάνω> [<head> [<όριο>]]]"
+
+#: builtin/log.c:2057
+#, c-format
+msgid ""
+"Could not find a tracked remote branch, please specify <upstream> manually.\n"
+msgstr ""
+
+#: builtin/ls-files.c:470
+msgid "git ls-files [<options>] [<file>...]"
+msgstr ""
+
+#: builtin/ls-files.c:526
+msgid "identify the file status with tags"
+msgstr ""
+
+#: builtin/ls-files.c:528
+msgid "use lowercase letters for 'assume unchanged' files"
+msgstr ""
+
+#: builtin/ls-files.c:530
+msgid "use lowercase letters for 'fsmonitor clean' files"
+msgstr ""
+
+#: builtin/ls-files.c:532
+msgid "show cached files in the output (default)"
+msgstr ""
+
+#: builtin/ls-files.c:534
+msgid "show deleted files in the output"
+msgstr ""
+
+#: builtin/ls-files.c:536
+msgid "show modified files in the output"
+msgstr ""
+
+#: builtin/ls-files.c:538
+msgid "show other files in the output"
+msgstr ""
+
+#: builtin/ls-files.c:540
+msgid "show ignored files in the output"
+msgstr ""
+
+#: builtin/ls-files.c:543
+msgid "show staged contents' object name in the output"
+msgstr ""
+
+#: builtin/ls-files.c:545
+msgid "show files on the filesystem that need to be removed"
+msgstr ""
+
+#: builtin/ls-files.c:547
+msgid "show 'other' directories' names only"
+msgstr ""
+
+#: builtin/ls-files.c:549
+msgid "show line endings of files"
+msgstr ""
+
+#: builtin/ls-files.c:551
+msgid "don't show empty directories"
+msgstr ""
+
+#: builtin/ls-files.c:554
+msgid "show unmerged files in the output"
+msgstr ""
+
+#: builtin/ls-files.c:556
+msgid "show resolve-undo information"
+msgstr ""
+
+#: builtin/ls-files.c:558
+msgid "skip files matching pattern"
+msgstr ""
+
+#: builtin/ls-files.c:561
+msgid "exclude patterns are read from <file>"
+msgstr ""
+
+#: builtin/ls-files.c:564
+msgid "read additional per-directory exclude patterns in <file>"
+msgstr ""
+
+#: builtin/ls-files.c:566
+msgid "add the standard git exclusions"
+msgstr ""
+
+#: builtin/ls-files.c:570
+msgid "make the output relative to the project top directory"
+msgstr ""
+
+#: builtin/ls-files.c:573
+msgid "recurse through submodules"
+msgstr ""
+
+#: builtin/ls-files.c:575
+msgid "if any <file> is not in the index, treat this as an error"
+msgstr ""
+
+#: builtin/ls-files.c:576
+msgid "tree-ish"
+msgstr ""
+
+#: builtin/ls-files.c:577
+msgid "pretend that paths removed since <tree-ish> are still present"
+msgstr ""
+
+#: builtin/ls-files.c:579
+msgid "show debugging data"
+msgstr ""
+
+#: builtin/ls-remote.c:9
+msgid ""
+"git ls-remote [--heads] [--tags] [--refs] [--upload-pack=<exec>]\n"
+"                     [-q | --quiet] [--exit-code] [--get-url]\n"
+"                     [--symref] [<repository> [<refs>...]]"
+msgstr ""
+
+#: builtin/ls-remote.c:59
+msgid "do not print remote URL"
+msgstr ""
+
+#: builtin/ls-remote.c:60 builtin/ls-remote.c:62 builtin/rebase.c:1111
+msgid "exec"
+msgstr ""
+
+#: builtin/ls-remote.c:61 builtin/ls-remote.c:63
+msgid "path of git-upload-pack on the remote host"
+msgstr ""
+
+#: builtin/ls-remote.c:65
+msgid "limit to tags"
+msgstr ""
+
+#: builtin/ls-remote.c:66
+msgid "limit to heads"
+msgstr ""
+
+#: builtin/ls-remote.c:67
+msgid "do not show peeled tags"
+msgstr ""
+
+#: builtin/ls-remote.c:69
+msgid "take url.<base>.insteadOf into account"
+msgstr ""
+
+#: builtin/ls-remote.c:73
+msgid "exit with exit code 2 if no matching refs are found"
+msgstr ""
+
+#: builtin/ls-remote.c:76
+msgid "show underlying ref in addition to the object pointed by it"
+msgstr ""
+
+#: builtin/ls-tree.c:30
+msgid "git ls-tree [<options>] <tree-ish> [<path>...]"
+msgstr ""
+
+#: builtin/ls-tree.c:128
+msgid "only show trees"
+msgstr ""
+
+#: builtin/ls-tree.c:130
+msgid "recurse into subtrees"
+msgstr ""
+
+#: builtin/ls-tree.c:132
+msgid "show trees when recursing"
+msgstr ""
+
+#: builtin/ls-tree.c:135
+msgid "terminate entries with NUL byte"
+msgstr ""
+
+#: builtin/ls-tree.c:136
+msgid "include object size"
+msgstr ""
+
+#: builtin/ls-tree.c:138 builtin/ls-tree.c:140
+msgid "list only filenames"
+msgstr ""
+
+#: builtin/ls-tree.c:143
+msgid "use full path names"
+msgstr "να γίνει χρήση πλήρων ονομάτων διαδρομών"
+
+#: builtin/ls-tree.c:145
+msgid "list entire tree; not just current directory (implies --full-name)"
+msgstr ""
+
+#: builtin/mailsplit.c:241
+#, c-format
+msgid "empty mbox: '%s'"
+msgstr ""
+
+#: builtin/merge.c:53
+msgid "git merge [<options>] [<commit>...]"
+msgstr ""
+
+#: builtin/merge.c:54
+msgid "git merge --abort"
+msgstr "git merge --abort"
+
+#: builtin/merge.c:55
+msgid "git merge --continue"
+msgstr "git merge --continue"
+
+#: builtin/merge.c:112
+msgid "switch `m' requires a value"
+msgstr ""
+
+#: builtin/merge.c:132
+#, c-format
+msgid "option `%s' requires a value"
+msgstr ""
+
+#: builtin/merge.c:178
+#, c-format
+msgid "Could not find merge strategy '%s'.\n"
+msgstr ""
+
+#: builtin/merge.c:179
+#, c-format
+msgid "Available strategies are:"
+msgstr ""
+
+#: builtin/merge.c:184
+#, c-format
+msgid "Available custom strategies are:"
+msgstr ""
+
+#: builtin/merge.c:235 builtin/pull.c:144
+msgid "do not show a diffstat at the end of the merge"
+msgstr ""
+
+#: builtin/merge.c:238 builtin/pull.c:147
+msgid "show a diffstat at the end of the merge"
+msgstr ""
+
+#: builtin/merge.c:239 builtin/pull.c:150
+msgid "(synonym to --stat)"
+msgstr ""
+
+#: builtin/merge.c:241 builtin/pull.c:153
+msgid "add (at most <n>) entries from shortlog to merge commit message"
+msgstr ""
+
+#: builtin/merge.c:244 builtin/pull.c:159
+msgid "create a single commit instead of doing a merge"
+msgstr ""
+
+#: builtin/merge.c:246 builtin/pull.c:162
+msgid "perform a commit if the merge succeeds (default)"
+msgstr ""
+
+#: builtin/merge.c:248 builtin/pull.c:165
+msgid "edit message before committing"
+msgstr ""
+
+#: builtin/merge.c:249
+msgid "allow fast-forward (default)"
+msgstr ""
+
+#: builtin/merge.c:251 builtin/pull.c:171
+msgid "abort if fast-forward is not possible"
+msgstr ""
+
+#: builtin/merge.c:255 builtin/pull.c:174
+msgid "verify that the named commit has a valid GPG signature"
+msgstr ""
+
+#: builtin/merge.c:256 builtin/notes.c:787 builtin/pull.c:178
+#: builtin/rebase.c:1124 builtin/rebase--interactive.c:188 builtin/revert.c:111
+msgid "strategy"
+msgstr ""
+
+#: builtin/merge.c:257 builtin/pull.c:179
+msgid "merge strategy to use"
+msgstr ""
+
+#: builtin/merge.c:258 builtin/pull.c:182
+msgid "option=value"
+msgstr ""
+
+#: builtin/merge.c:259 builtin/pull.c:183
+msgid "option for selected merge strategy"
+msgstr ""
+
+#: builtin/merge.c:261
+msgid "merge commit message (for a non-fast-forward merge)"
+msgstr ""
+
+#: builtin/merge.c:268
+msgid "abort the current in-progress merge"
+msgstr ""
+
+#: builtin/merge.c:270
+msgid "continue the current in-progress merge"
+msgstr ""
+
+#: builtin/merge.c:272 builtin/pull.c:190
+msgid "allow merging unrelated histories"
+msgstr ""
+
+#: builtin/merge.c:278
+msgid "verify commit-msg hook"
+msgstr ""
+
+#: builtin/merge.c:303
+msgid "could not run stash."
+msgstr ""
+
+#: builtin/merge.c:308
+msgid "stash failed"
+msgstr ""
+
+#: builtin/merge.c:313
+#, c-format
+msgid "not a valid object: %s"
+msgstr "δεν είναι έγκυρο αντικείμενο: %s"
+
+#: builtin/merge.c:335 builtin/merge.c:352
+msgid "read-tree failed"
+msgstr ""
+
+#: builtin/merge.c:382
+msgid " (nothing to squash)"
+msgstr " (τίποτα προς σύμπτυξη)"
+
+#: builtin/merge.c:393
+#, c-format
+msgid "Squash commit -- not updating HEAD\n"
+msgstr ""
+
+#: builtin/merge.c:443
+#, c-format
+msgid "No merge message -- not updating HEAD\n"
+msgstr ""
+
+#: builtin/merge.c:494
+#, c-format
+msgid "'%s' does not point to a commit"
+msgstr ""
+
+#: builtin/merge.c:581
+#, c-format
+msgid "Bad branch.%s.mergeoptions string: %s"
+msgstr ""
+
+#: builtin/merge.c:702
+msgid "Not handling anything other than two heads merge."
+msgstr ""
+
+#: builtin/merge.c:716
+#, c-format
+msgid "Unknown option for merge-recursive: -X%s"
+msgstr ""
+
+#: builtin/merge.c:731
+#, c-format
+msgid "unable to write %s"
+msgstr ""
+
+#: builtin/merge.c:783
+#, c-format
+msgid "Could not read from '%s'"
+msgstr ""
+
+#: builtin/merge.c:792
+#, c-format
+msgid "Not committing merge; use 'git commit' to complete the merge.\n"
+msgstr ""
+"Δε γίνεται υποβολή της συγχώνευσης, χρησιμοποιήστε 'git commit' για να "
+"ολοκληρώσετε τη συγχώνευση.\n"
+
+#: builtin/merge.c:798
+#, c-format
+msgid ""
+"Please enter a commit message to explain why this merge is necessary,\n"
+"especially if it merges an updated upstream into a topic branch.\n"
+"\n"
+"Lines starting with '%c' will be ignored, and an empty message aborts\n"
+"the commit.\n"
+msgstr ""
+
+#: builtin/merge.c:834
+msgid "Empty commit message."
+msgstr ""
+
+#: builtin/merge.c:853
+#, c-format
+msgid "Wonderful.\n"
+msgstr "Εξαιρετικά.\n"
+
+#: builtin/merge.c:906
+#, c-format
+msgid "Automatic merge failed; fix conflicts and then commit the result.\n"
+msgstr ""
+
+#: builtin/merge.c:945
+msgid "No current branch."
+msgstr ""
+
+#: builtin/merge.c:947
+msgid "No remote for the current branch."
+msgstr ""
+
+#: builtin/merge.c:949
+msgid "No default upstream defined for the current branch."
+msgstr ""
+
+#: builtin/merge.c:954
+#, c-format
+msgid "No remote-tracking branch for %s from %s"
+msgstr ""
+
+#: builtin/merge.c:1011
+#, c-format
+msgid "Bad value '%s' in environment '%s'"
+msgstr ""
+
+#: builtin/merge.c:1114
+#, c-format
+msgid "not something we can merge in %s: %s"
+msgstr ""
+
+#: builtin/merge.c:1148
+msgid "not something we can merge"
+msgstr ""
+
+#: builtin/merge.c:1251
+msgid "--abort expects no arguments"
+msgstr ""
+
+#: builtin/merge.c:1255
+msgid "There is no merge to abort (MERGE_HEAD missing)."
+msgstr ""
+
+#: builtin/merge.c:1267
+msgid "--continue expects no arguments"
+msgstr ""
+
+#: builtin/merge.c:1271
+msgid "There is no merge in progress (MERGE_HEAD missing)."
+msgstr ""
+
+#: builtin/merge.c:1287
+msgid ""
+"You have not concluded your merge (MERGE_HEAD exists).\n"
+"Please, commit your changes before you merge."
+msgstr ""
+"Δεν έχετε ολοκληρώσει τη συγχώνευσή σας (Υπάρχει το MERGE_HEAD).\n"
+"Παρακαλώ, υποβάλετε τις αλλαγές σας πριν συγχωνεύσετε."
+
+#: builtin/merge.c:1294
+msgid ""
+"You have not concluded your cherry-pick (CHERRY_PICK_HEAD exists).\n"
+"Please, commit your changes before you merge."
+msgstr ""
+"Δεν έχετε ολοκληρώσει την επιλεκτική διαλογή σας (Υπάρχει το "
+"CHERRY_PICK_HEAD).\n"
+"Παρακαλώ, υποβάλετε τις αλλαγές σας πριν συγχωνεύσετε."
+
+#: builtin/merge.c:1297
+msgid "You have not concluded your cherry-pick (CHERRY_PICK_HEAD exists)."
+msgstr ""
+"Δεν έχετε ολοκληρώσει την επιλεκτική διαλογή σας (Υπάρχει το "
+"CHERRY_PICK_HEAD)."
+
+#: builtin/merge.c:1306
+msgid "You cannot combine --squash with --no-ff."
+msgstr "Δε μπορείτε να συνδυάσετε το --squash με το --no-ff."
+
+#: builtin/merge.c:1314
+msgid "No commit specified and merge.defaultToUpstream not set."
+msgstr ""
+
+#: builtin/merge.c:1331
+msgid "Squash commit into empty head not supported yet"
+msgstr ""
+
+#: builtin/merge.c:1333
+msgid "Non-fast-forward commit does not make sense into an empty head"
+msgstr ""
+
+#: builtin/merge.c:1338
+#, c-format
+msgid "%s - not something we can merge"
+msgstr ""
+
+#: builtin/merge.c:1340
+msgid "Can merge only exactly one commit into empty head"
+msgstr ""
+
+#: builtin/merge.c:1422
+msgid "refusing to merge unrelated histories"
+msgstr ""
+
+#: builtin/merge.c:1431
+msgid "Already up to date."
+msgstr "Ήδη πλήρως ενήμερο."
+
+#: builtin/merge.c:1441
+#, c-format
+msgid "Updating %s..%s\n"
+msgstr ""
+
+#: builtin/merge.c:1483
+#, c-format
+msgid "Trying really trivial in-index merge...\n"
+msgstr ""
+
+#: builtin/merge.c:1490
+#, c-format
+msgid "Nope.\n"
+msgstr ""
+
+#: builtin/merge.c:1515
+msgid "Already up to date. Yeeah!"
+msgstr "Ήδη πλήρως ενήμερο. Ναιιι!"
+
+#: builtin/merge.c:1521
+msgid "Not possible to fast-forward, aborting."
+msgstr ""
+
+#: builtin/merge.c:1544 builtin/merge.c:1623
+#, c-format
+msgid "Rewinding the tree to pristine...\n"
+msgstr ""
+
+#: builtin/merge.c:1548
+#, c-format
+msgid "Trying merge strategy %s...\n"
+msgstr ""
+
+#: builtin/merge.c:1614
+#, c-format
+msgid "No merge strategy handled the merge.\n"
+msgstr ""
+
+#: builtin/merge.c:1616
+#, c-format
+msgid "Merge with strategy %s failed.\n"
+msgstr ""
+
+#: builtin/merge.c:1625
+#, c-format
+msgid "Using the %s to prepare resolving by hand.\n"
+msgstr ""
+
+#: builtin/merge.c:1637
+#, c-format
+msgid "Automatic merge went well; stopped before committing as requested\n"
+msgstr ""
+
+#: builtin/merge-base.c:32
+msgid "git merge-base [-a | --all] <commit> <commit>..."
+msgstr ""
+
+#: builtin/merge-base.c:33
+msgid "git merge-base [-a | --all] --octopus <commit>..."
+msgstr ""
+
+#: builtin/merge-base.c:34
+msgid "git merge-base --independent <commit>..."
+msgstr ""
+
+#: builtin/merge-base.c:35
+msgid "git merge-base --is-ancestor <commit> <commit>"
+msgstr ""
+
+#: builtin/merge-base.c:36
+msgid "git merge-base --fork-point <ref> [<commit>]"
+msgstr ""
+
+#: builtin/merge-base.c:153
+msgid "output all common ancestors"
+msgstr ""
+
+#: builtin/merge-base.c:155
+msgid "find ancestors for a single n-way merge"
+msgstr ""
+
+#: builtin/merge-base.c:157
+msgid "list revs not reachable from others"
+msgstr ""
+
+#: builtin/merge-base.c:159
+msgid "is the first one ancestor of the other?"
+msgstr ""
+
+#: builtin/merge-base.c:161
+msgid "find where <commit> forked from reflog of <ref>"
+msgstr ""
+
+#: builtin/merge-file.c:9
+msgid ""
+"git merge-file [<options>] [-L <name1> [-L <orig> [-L <name2>]]] <file1> "
+"<orig-file> <file2>"
+msgstr ""
+
+#: builtin/merge-file.c:35
+msgid "send results to standard output"
+msgstr ""
+
+#: builtin/merge-file.c:36
+msgid "use a diff3 based merge"
+msgstr ""
+
+#: builtin/merge-file.c:37
+msgid "for conflicts, use our version"
+msgstr ""
+
+#: builtin/merge-file.c:39
+msgid "for conflicts, use their version"
+msgstr ""
+
+#: builtin/merge-file.c:41
+msgid "for conflicts, use a union version"
+msgstr ""
+
+#: builtin/merge-file.c:44
+msgid "for conflicts, use this marker size"
+msgstr ""
+
+#: builtin/merge-file.c:45
+msgid "do not warn about conflicts"
+msgstr ""
+
+#: builtin/merge-file.c:47
+msgid "set labels for file1/orig-file/file2"
+msgstr ""
+
+#: builtin/merge-recursive.c:46
+#, c-format
+msgid "unknown option %s"
+msgstr ""
+
+#: builtin/merge-recursive.c:52
+#, c-format
+msgid "could not parse object '%s'"
+msgstr ""
+
+#: builtin/merge-recursive.c:56
+#, c-format
+msgid "cannot handle more than %d base. Ignoring %s."
+msgid_plural "cannot handle more than %d bases. Ignoring %s."
+msgstr[0] ""
+msgstr[1] ""
+
+#: builtin/merge-recursive.c:64
+msgid "not handling anything other than two heads merge."
+msgstr ""
+
+#: builtin/merge-recursive.c:70 builtin/merge-recursive.c:72
+#, c-format
+msgid "could not resolve ref '%s'"
+msgstr "δεν ήταν δυνατή η ταύτιση του ref '%s'"
+
+#: builtin/merge-recursive.c:78
+#, c-format
+msgid "Merging %s with %s\n"
+msgstr ""
+
+#: builtin/mktree.c:66
+msgid "git mktree [-z] [--missing] [--batch]"
+msgstr ""
+
+#: builtin/mktree.c:154
+msgid "input is NUL terminated"
+msgstr ""
+
+#: builtin/mktree.c:155 builtin/write-tree.c:26
+msgid "allow missing objects"
+msgstr ""
+
+#: builtin/mktree.c:156
+msgid "allow creation of more than one tree"
+msgstr ""
+
+#: builtin/multi-pack-index.c:8
+msgid "git multi-pack-index [--object-dir=<dir>] (write|verify)"
+msgstr ""
+
+#: builtin/multi-pack-index.c:21
+msgid "object directory containing set of packfile and pack-index pairs"
+msgstr ""
+
+#: builtin/multi-pack-index.c:39
+msgid "too many arguments"
+msgstr ""
+
+#: builtin/multi-pack-index.c:48
+#, c-format
+msgid "unrecognized verb: %s"
+msgstr ""
+
+#: builtin/mv.c:18
+msgid "git mv [<options>] <source>... <destination>"
+msgstr ""
+
+#: builtin/mv.c:83
+#, c-format
+msgid "Directory %s is in index and no submodule?"
+msgstr ""
+
+#: builtin/mv.c:85
+msgid "Please stage your changes to .gitmodules or stash them to proceed"
+msgstr ""
+
+#: builtin/mv.c:103
+#, c-format
+msgid "%.*s is in index"
+msgstr ""
+
+#: builtin/mv.c:125
+msgid "force move/rename even if target exists"
+msgstr ""
+
+#: builtin/mv.c:127
+msgid "skip move/rename errors"
+msgstr ""
+
+#: builtin/mv.c:169
+#, c-format
+msgid "destination '%s' is not a directory"
+msgstr ""
+
+#: builtin/mv.c:180
+#, c-format
+msgid "Checking rename of '%s' to '%s'\n"
+msgstr ""
+
+#: builtin/mv.c:184
+msgid "bad source"
+msgstr ""
+
+#: builtin/mv.c:187
+msgid "can not move directory into itself"
+msgstr ""
+
+#: builtin/mv.c:190
+msgid "cannot move directory over file"
+msgstr ""
+
+#: builtin/mv.c:199
+msgid "source directory is empty"
+msgstr ""
+
+#: builtin/mv.c:224
+msgid "not under version control"
+msgstr ""
+
+#: builtin/mv.c:227
+msgid "destination exists"
+msgstr ""
+
+#: builtin/mv.c:235
+#, c-format
+msgid "overwriting '%s'"
+msgstr ""
+
+#: builtin/mv.c:238
+msgid "Cannot overwrite"
+msgstr ""
+
+#: builtin/mv.c:241
+msgid "multiple sources for the same target"
+msgstr ""
+
+#: builtin/mv.c:243
+msgid "destination directory does not exist"
+msgstr ""
+
+#: builtin/mv.c:250
+#, c-format
+msgid "%s, source=%s, destination=%s"
+msgstr ""
+
+#: builtin/mv.c:271
+#, c-format
+msgid "Renaming %s to %s\n"
+msgstr ""
+
+#: builtin/mv.c:277 builtin/remote.c:717 builtin/repack.c:513
+#, c-format
+msgid "renaming '%s' failed"
+msgstr ""
+
+#: builtin/name-rev.c:355
+msgid "git name-rev [<options>] <commit>..."
+msgstr ""
+
+#: builtin/name-rev.c:356
+msgid "git name-rev [<options>] --all"
+msgstr ""
+
+#: builtin/name-rev.c:357
+msgid "git name-rev [<options>] --stdin"
+msgstr ""
+
+#: builtin/name-rev.c:413
+msgid "print only names (no SHA-1)"
+msgstr ""
+
+#: builtin/name-rev.c:414
+msgid "only use tags to name the commits"
+msgstr ""
+
+#: builtin/name-rev.c:416
+msgid "only use refs matching <pattern>"
+msgstr ""
+
+#: builtin/name-rev.c:418
+msgid "ignore refs matching <pattern>"
+msgstr ""
+
+#: builtin/name-rev.c:420
+msgid "list all commits reachable from all refs"
+msgstr ""
+
+#: builtin/name-rev.c:421
+msgid "read from stdin"
+msgstr ""
+
+#: builtin/name-rev.c:422
+msgid "allow to print `undefined` names (default)"
+msgstr ""
+
+#: builtin/name-rev.c:428
+msgid "dereference tags in the input (internal use)"
+msgstr ""
+
+#: builtin/notes.c:28
+msgid "git notes [--ref <notes-ref>] [list [<object>]]"
+msgstr ""
+
+#: builtin/notes.c:29
+msgid ""
+"git notes [--ref <notes-ref>] add [-f] [--allow-empty] [-m <msg> | -F <file> "
+"| (-c | -C) <object>] [<object>]"
+msgstr ""
+
+#: builtin/notes.c:30
+msgid "git notes [--ref <notes-ref>] copy [-f] <from-object> <to-object>"
+msgstr ""
+
+#: builtin/notes.c:31
+msgid ""
+"git notes [--ref <notes-ref>] append [--allow-empty] [-m <msg> | -F <file> | "
+"(-c | -C) <object>] [<object>]"
+msgstr ""
+
+#: builtin/notes.c:32
+msgid "git notes [--ref <notes-ref>] edit [--allow-empty] [<object>]"
+msgstr ""
+
+#: builtin/notes.c:33
+msgid "git notes [--ref <notes-ref>] show [<object>]"
+msgstr ""
+
+#: builtin/notes.c:34
+msgid ""
+"git notes [--ref <notes-ref>] merge [-v | -q] [-s <strategy>] <notes-ref>"
+msgstr ""
+
+#: builtin/notes.c:35
+msgid "git notes merge --commit [-v | -q]"
+msgstr ""
+
+#: builtin/notes.c:36
+msgid "git notes merge --abort [-v | -q]"
+msgstr ""
+
+#: builtin/notes.c:37
+msgid "git notes [--ref <notes-ref>] remove [<object>...]"
+msgstr ""
+
+#: builtin/notes.c:38
+msgid "git notes [--ref <notes-ref>] prune [-n] [-v]"
+msgstr ""
+
+#: builtin/notes.c:39
+msgid "git notes [--ref <notes-ref>] get-ref"
+msgstr ""
+
+#: builtin/notes.c:44
+msgid "git notes [list [<object>]]"
+msgstr ""
+
+#: builtin/notes.c:49
+msgid "git notes add [<options>] [<object>]"
+msgstr ""
+
+#: builtin/notes.c:54
+msgid "git notes copy [<options>] <from-object> <to-object>"
+msgstr ""
+
+#: builtin/notes.c:55
+msgid "git notes copy --stdin [<from-object> <to-object>]..."
+msgstr ""
+
+#: builtin/notes.c:60
+msgid "git notes append [<options>] [<object>]"
+msgstr ""
+
+#: builtin/notes.c:65
+msgid "git notes edit [<object>]"
+msgstr ""
+
+#: builtin/notes.c:70
+msgid "git notes show [<object>]"
+msgstr ""
+
+#: builtin/notes.c:75
+msgid "git notes merge [<options>] <notes-ref>"
+msgstr ""
+
+#: builtin/notes.c:76
+msgid "git notes merge --commit [<options>]"
+msgstr ""
+
+#: builtin/notes.c:77
+msgid "git notes merge --abort [<options>]"
+msgstr ""
+
+#: builtin/notes.c:82
+msgid "git notes remove [<object>]"
+msgstr ""
+
+#: builtin/notes.c:87
+msgid "git notes prune [<options>]"
+msgstr ""
+
+#: builtin/notes.c:92
+msgid "git notes get-ref"
+msgstr "git notes get-ref"
+
+#: builtin/notes.c:97
+msgid "Write/edit the notes for the following object:"
+msgstr ""
+
+#: builtin/notes.c:150
+#, c-format
+msgid "unable to start 'show' for object '%s'"
+msgstr ""
+
+#: builtin/notes.c:154
+msgid "could not read 'show' output"
+msgstr ""
+
+#: builtin/notes.c:162
+#, c-format
+msgid "failed to finish 'show' for object '%s'"
+msgstr ""
+
+#: builtin/notes.c:197
+msgid "please supply the note contents using either -m or -F option"
+msgstr ""
+
+#: builtin/notes.c:206
+msgid "unable to write note object"
+msgstr ""
+
+#: builtin/notes.c:208
+#, c-format
+msgid "the note contents have been left in %s"
+msgstr ""
+
+#: builtin/notes.c:242 builtin/tag.c:513
+#, c-format
+msgid "could not open or read '%s'"
+msgstr "δεν ήταν δυνατό το άνοιγμα ή η ανάγνωση του '%s'"
+
+#: builtin/notes.c:263 builtin/notes.c:313 builtin/notes.c:315
+#: builtin/notes.c:383 builtin/notes.c:438 builtin/notes.c:526
+#: builtin/notes.c:531 builtin/notes.c:610 builtin/notes.c:672
+#, c-format
+msgid "failed to resolve '%s' as a valid ref."
+msgstr "απέτυχε η ταύτιση του '%s' με κάποιο έγκυρο ref."
+
+#: builtin/notes.c:265
+#, c-format
+msgid "failed to read object '%s'."
+msgstr ""
+
+#: builtin/notes.c:268
+#, c-format
+msgid "cannot read note data from non-blob object '%s'."
+msgstr ""
+"δεν ήταν δυνατή η ανάγνωση δεδομένων σημειώσεων από μη blob αντικείμενο '%s'."
+
+#: builtin/notes.c:309
+#, c-format
+msgid "malformed input line: '%s'."
+msgstr ""
+
+#: builtin/notes.c:324
+#, c-format
+msgid "failed to copy notes from '%s' to '%s'"
+msgstr ""
+
+#. TRANSLATORS: the first %s will be replaced by a git
+#. notes command: 'add', 'merge', 'remove', etc.
+#.
+#: builtin/notes.c:356
+#, c-format
+msgid "refusing to %s notes in %s (outside of refs/notes/)"
+msgstr ""
+
+#: builtin/notes.c:376 builtin/notes.c:431 builtin/notes.c:509
+#: builtin/notes.c:521 builtin/notes.c:598 builtin/notes.c:665
+#: builtin/notes.c:815 builtin/notes.c:963 builtin/notes.c:985
+msgid "too many parameters"
+msgstr ""
+
+#: builtin/notes.c:389 builtin/notes.c:678
+#, c-format
+msgid "no note found for object %s."
+msgstr ""
+
+#: builtin/notes.c:410 builtin/notes.c:576
+msgid "note contents as a string"
+msgstr ""
+
+#: builtin/notes.c:413 builtin/notes.c:579
+msgid "note contents in a file"
+msgstr ""
+
+#: builtin/notes.c:416 builtin/notes.c:582
+msgid "reuse and edit specified note object"
+msgstr ""
+
+#: builtin/notes.c:419 builtin/notes.c:585
+msgid "reuse specified note object"
+msgstr ""
+
+#: builtin/notes.c:422 builtin/notes.c:588
+msgid "allow storing empty note"
+msgstr ""
+
+#: builtin/notes.c:423 builtin/notes.c:496
+msgid "replace existing notes"
+msgstr ""
+
+#: builtin/notes.c:448
+#, c-format
+msgid ""
+"Cannot add notes. Found existing notes for object %s. Use '-f' to overwrite "
+"existing notes"
+msgstr ""
+
+#: builtin/notes.c:463 builtin/notes.c:544
+#, c-format
+msgid "Overwriting existing notes for object %s\n"
+msgstr ""
+
+#: builtin/notes.c:475 builtin/notes.c:637 builtin/notes.c:902
+#, c-format
+msgid "Removing note for object %s\n"
+msgstr ""
+
+#: builtin/notes.c:497
+msgid "read objects from stdin"
+msgstr ""
+
+#: builtin/notes.c:499
+msgid "load rewriting config for <command> (implies --stdin)"
+msgstr ""
+
+#: builtin/notes.c:517
+msgid "too few parameters"
+msgstr ""
+
+#: builtin/notes.c:538
+#, c-format
+msgid ""
+"Cannot copy notes. Found existing notes for object %s. Use '-f' to overwrite "
+"existing notes"
+msgstr ""
+
+#: builtin/notes.c:550
+#, c-format
+msgid "missing notes on source object %s. Cannot copy."
+msgstr ""
+
+#: builtin/notes.c:603
+#, c-format
+msgid ""
+"The -m/-F/-c/-C options have been deprecated for the 'edit' subcommand.\n"
+"Please use 'git notes add -f -m/-F/-c/-C' instead.\n"
+msgstr ""
+
+#: builtin/notes.c:698
+msgid "failed to delete ref NOTES_MERGE_PARTIAL"
+msgstr ""
+
+#: builtin/notes.c:700
+msgid "failed to delete ref NOTES_MERGE_REF"
+msgstr ""
+
+#: builtin/notes.c:702
+msgid "failed to remove 'git notes merge' worktree"
+msgstr ""
+
+#: builtin/notes.c:722
+msgid "failed to read ref NOTES_MERGE_PARTIAL"
+msgstr ""
+
+#: builtin/notes.c:724
+msgid "could not find commit from NOTES_MERGE_PARTIAL."
+msgstr ""
+
+#: builtin/notes.c:726
+msgid "could not parse commit from NOTES_MERGE_PARTIAL."
+msgstr ""
+
+#: builtin/notes.c:739
+msgid "failed to resolve NOTES_MERGE_REF"
+msgstr "απέτυχε η ταύτιση του NOTES_MERGE_REF"
+
+#: builtin/notes.c:742
+msgid "failed to finalize notes merge"
+msgstr ""
+
+#: builtin/notes.c:768
+#, c-format
+msgid "unknown notes merge strategy %s"
+msgstr ""
+
+#: builtin/notes.c:784
+msgid "General options"
+msgstr ""
+
+#: builtin/notes.c:786
+msgid "Merge options"
+msgstr ""
+
+#: builtin/notes.c:788
+msgid ""
+"resolve notes conflicts using the given strategy (manual/ours/theirs/union/"
+"cat_sort_uniq)"
+msgstr ""
+"επιλύστε τις συγκρούσεις σημειώσεων χρησιμοποιώντας την επιλεγμένη "
+"στρατηγική (manual/ours/theirs/union/cat_sort_uniq)"
+
+#: builtin/notes.c:790
+msgid "Committing unmerged notes"
+msgstr ""
+
+#: builtin/notes.c:792
+msgid "finalize notes merge by committing unmerged notes"
+msgstr ""
+
+#: builtin/notes.c:794
+msgid "Aborting notes merge resolution"
+msgstr ""
+
+#: builtin/notes.c:796
+msgid "abort notes merge"
+msgstr ""
+
+#: builtin/notes.c:807
+msgid "cannot mix --commit, --abort or -s/--strategy"
+msgstr ""
+
+#: builtin/notes.c:812
+msgid "must specify a notes ref to merge"
+msgstr ""
+
+#: builtin/notes.c:836
+#, c-format
+msgid "unknown -s/--strategy: %s"
+msgstr ""
+
+#: builtin/notes.c:873
+#, c-format
+msgid "a notes merge into %s is already in-progress at %s"
+msgstr ""
+
+#: builtin/notes.c:876
+#, c-format
+msgid "failed to store link to current notes ref (%s)"
+msgstr ""
+
+#: builtin/notes.c:878
+#, c-format
+msgid ""
+"Automatic notes merge failed. Fix conflicts in %s and commit the result with "
+"'git notes merge --commit', or abort the merge with 'git notes merge --"
+"abort'.\n"
+msgstr ""
+
+#: builtin/notes.c:900
+#, c-format
+msgid "Object %s has no note\n"
+msgstr ""
+
+#: builtin/notes.c:912
+msgid "attempt to remove non-existent note is not an error"
+msgstr ""
+
+#: builtin/notes.c:915
+msgid "read object names from the standard input"
+msgstr ""
+
+#: builtin/notes.c:954 builtin/prune.c:108 builtin/worktree.c:165
+msgid "do not remove, show only"
+msgstr ""
+
+#: builtin/notes.c:955
+msgid "report pruned notes"
+msgstr ""
+
+#: builtin/notes.c:998
+msgid "notes-ref"
+msgstr ""
+
+#: builtin/notes.c:999
+msgid "use notes from <notes-ref>"
+msgstr ""
+
+#: builtin/notes.c:1034
+#, c-format
+msgid "unknown subcommand: %s"
+msgstr ""
+
+#: builtin/pack-objects.c:51
+msgid ""
+"git pack-objects --stdout [<options>...] [< <ref-list> | < <object-list>]"
+msgstr ""
+
+#: builtin/pack-objects.c:52
+msgid ""
+"git pack-objects [<options>...] <base-name> [< <ref-list> | < <object-list>]"
+msgstr ""
+
+#: builtin/pack-objects.c:423
+#, c-format
+msgid "bad packed object CRC for %s"
+msgstr ""
+
+#: builtin/pack-objects.c:434
+#, c-format
+msgid "corrupt packed object for %s"
+msgstr ""
+
+#: builtin/pack-objects.c:565
+#, c-format
+msgid "recursive delta detected for object %s"
+msgstr ""
+
+#: builtin/pack-objects.c:776
+#, c-format
+msgid "ordered %u objects, expected %<PRIu32>"
+msgstr ""
+
+#: builtin/pack-objects.c:789
+#, c-format
+msgid "packfile is invalid: %s"
+msgstr ""
+
+#: builtin/pack-objects.c:793
+#, c-format
+msgid "unable to open packfile for reuse: %s"
+msgstr ""
+
+#: builtin/pack-objects.c:797
+msgid "unable to seek in reused packfile"
+msgstr ""
+
+#: builtin/pack-objects.c:808
+msgid "unable to read from reused packfile"
+msgstr ""
+
+#: builtin/pack-objects.c:836
+msgid "disabling bitmap writing, packs are split due to pack.packSizeLimit"
+msgstr ""
+
+#: builtin/pack-objects.c:849
+msgid "Writing objects"
+msgstr ""
+
+#: builtin/pack-objects.c:911 builtin/update-index.c:89
+#, c-format
+msgid "failed to stat %s"
+msgstr ""
+
+#: builtin/pack-objects.c:964
+#, c-format
+msgid "wrote %<PRIu32> objects while expecting %<PRIu32>"
+msgstr ""
+
+#: builtin/pack-objects.c:1158
+msgid "disabling bitmap writing, as some objects are not being packed"
+msgstr ""
+
+#: builtin/pack-objects.c:1586
+#, c-format
+msgid "delta base offset overflow in pack for %s"
+msgstr ""
+
+#: builtin/pack-objects.c:1595
+#, c-format
+msgid "delta base offset out of bound for %s"
+msgstr ""
+
+#: builtin/pack-objects.c:1864
+msgid "Counting objects"
+msgstr "Καταμέτρηση αντικειμένων"
+
+#: builtin/pack-objects.c:1994
+#, c-format
+msgid "unable to get size of %s"
+msgstr ""
+
+#: builtin/pack-objects.c:2009
+#, c-format
+msgid "unable to parse object header of %s"
+msgstr ""
+
+#: builtin/pack-objects.c:2079 builtin/pack-objects.c:2095
+#: builtin/pack-objects.c:2105
+#, c-format
+msgid "object %s cannot be read"
+msgstr ""
+
+#: builtin/pack-objects.c:2082 builtin/pack-objects.c:2109
+#, c-format
+msgid "object %s inconsistent object length (%<PRIuMAX> vs %<PRIuMAX>)"
+msgstr ""
+
+#: builtin/pack-objects.c:2119
+msgid "suboptimal pack - out of memory"
+msgstr ""
+
+#: builtin/pack-objects.c:2445
+#, c-format
+msgid "Delta compression using up to %d threads"
+msgstr ""
+
+#: builtin/pack-objects.c:2577
+#, c-format
+msgid "unable to pack objects reachable from tag %s"
+msgstr ""
+
+#: builtin/pack-objects.c:2664
+msgid "Compressing objects"
+msgstr "Συμπίεση αντικειμένων"
+
+#: builtin/pack-objects.c:2670
+msgid "inconsistency with delta count"
+msgstr ""
+
+#: builtin/pack-objects.c:2751
+#, c-format
+msgid ""
+"expected edge object ID, got garbage:\n"
+" %s"
+msgstr ""
+
+#: builtin/pack-objects.c:2757
+#, c-format
+msgid ""
+"expected object ID, got garbage:\n"
+" %s"
+msgstr ""
+
+#: builtin/pack-objects.c:2855
+msgid "invalid value for --missing"
+msgstr ""
+
+#: builtin/pack-objects.c:2914 builtin/pack-objects.c:3022
+msgid "cannot open pack index"
+msgstr ""
+
+#: builtin/pack-objects.c:2945
+#, c-format
+msgid "loose object at %s could not be examined"
+msgstr ""
+
+#: builtin/pack-objects.c:3030
+msgid "unable to force loose object"
+msgstr ""
+
+#: builtin/pack-objects.c:3122
+#, c-format
+msgid "not a rev '%s'"
+msgstr "δεν είναι έκδοση η '%s'"
+
+#: builtin/pack-objects.c:3125
+#, c-format
+msgid "bad revision '%s'"
+msgstr ""
+
+#: builtin/pack-objects.c:3150
+msgid "unable to add recent objects"
+msgstr ""
+
+#: builtin/pack-objects.c:3203
+#, c-format
+msgid "unsupported index version %s"
+msgstr ""
+
+#: builtin/pack-objects.c:3207
+#, c-format
+msgid "bad index version '%s'"
+msgstr ""
+
+#: builtin/pack-objects.c:3237
+msgid "do not show progress meter"
+msgstr ""
+
+#: builtin/pack-objects.c:3239
+msgid "show progress meter"
+msgstr ""
+
+#: builtin/pack-objects.c:3241
+msgid "show progress meter during object writing phase"
+msgstr ""
+
+#: builtin/pack-objects.c:3244
+msgid "similar to --all-progress when progress meter is shown"
+msgstr ""
+
+#: builtin/pack-objects.c:3245
+msgid "<version>[,<offset>]"
+msgstr ""
+
+#: builtin/pack-objects.c:3246
+msgid "write the pack index file in the specified idx format version"
+msgstr ""
+
+#: builtin/pack-objects.c:3249
+msgid "maximum size of each output pack file"
+msgstr ""
+
+#: builtin/pack-objects.c:3251
+msgid "ignore borrowed objects from alternate object store"
+msgstr ""
+
+#: builtin/pack-objects.c:3253
+msgid "ignore packed objects"
+msgstr ""
+
+#: builtin/pack-objects.c:3255
+msgid "limit pack window by objects"
+msgstr ""
+
+#: builtin/pack-objects.c:3257
+msgid "limit pack window by memory in addition to object limit"
+msgstr ""
+
+#: builtin/pack-objects.c:3259
+msgid "maximum length of delta chain allowed in the resulting pack"
+msgstr ""
+
+#: builtin/pack-objects.c:3261
+msgid "reuse existing deltas"
+msgstr ""
+
+#: builtin/pack-objects.c:3263
+msgid "reuse existing objects"
+msgstr ""
+
+#: builtin/pack-objects.c:3265
+msgid "use OFS_DELTA objects"
+msgstr ""
+
+#: builtin/pack-objects.c:3267
+msgid "use threads when searching for best delta matches"
+msgstr ""
+
+#: builtin/pack-objects.c:3269
+msgid "do not create an empty pack output"
+msgstr ""
+
+#: builtin/pack-objects.c:3271
+msgid "read revision arguments from standard input"
+msgstr ""
+
+#: builtin/pack-objects.c:3273
+msgid "limit the objects to those that are not yet packed"
+msgstr ""
+
+#: builtin/pack-objects.c:3276
+msgid "include objects reachable from any reference"
+msgstr ""
+
+#: builtin/pack-objects.c:3279
+msgid "include objects referred by reflog entries"
+msgstr ""
+
+#: builtin/pack-objects.c:3282
+msgid "include objects referred to by the index"
+msgstr ""
+
+#: builtin/pack-objects.c:3285
+msgid "output pack to stdout"
+msgstr ""
+
+#: builtin/pack-objects.c:3287
+msgid "include tag objects that refer to objects to be packed"
+msgstr ""
+
+#: builtin/pack-objects.c:3289
+msgid "keep unreachable objects"
+msgstr ""
+
+#: builtin/pack-objects.c:3291
+msgid "pack loose unreachable objects"
+msgstr ""
+
+#: builtin/pack-objects.c:3293
+msgid "unpack unreachable objects newer than <time>"
+msgstr ""
+
+#: builtin/pack-objects.c:3296
+msgid "use the sparse reachability algorithm"
+msgstr ""
+
+#: builtin/pack-objects.c:3298
+msgid "create thin packs"
+msgstr ""
+
+#: builtin/pack-objects.c:3300
+msgid "create packs suitable for shallow fetches"
+msgstr ""
+
+#: builtin/pack-objects.c:3302
+msgid "ignore packs that have companion .keep file"
+msgstr ""
+
+#: builtin/pack-objects.c:3304
+msgid "ignore this pack"
+msgstr ""
+
+#: builtin/pack-objects.c:3306
+msgid "pack compression level"
+msgstr ""
+
+#: builtin/pack-objects.c:3308
+msgid "do not hide commits by grafts"
+msgstr ""
+
+#: builtin/pack-objects.c:3310
+msgid "use a bitmap index if available to speed up counting objects"
+msgstr ""
+
+#: builtin/pack-objects.c:3312
+msgid "write a bitmap index together with the pack index"
+msgstr ""
+
+#: builtin/pack-objects.c:3315
+msgid "handling for missing objects"
+msgstr ""
+
+#: builtin/pack-objects.c:3318
+msgid "do not pack objects in promisor packfiles"
+msgstr ""
+
+#: builtin/pack-objects.c:3320
+msgid "respect islands during delta compression"
+msgstr ""
+
+#: builtin/pack-objects.c:3345
+#, c-format
+msgid "delta chain depth %d is too deep, forcing %d"
+msgstr ""
+
+#: builtin/pack-objects.c:3350
+#, c-format
+msgid "pack.deltaCacheLimit is too high, forcing %d"
+msgstr ""
+
+#: builtin/pack-objects.c:3404
+msgid "--max-pack-size cannot be used to build a pack for transfer"
+msgstr ""
+
+#: builtin/pack-objects.c:3406
+msgid "minimum pack size limit is 1 MiB"
+msgstr ""
+
+#: builtin/pack-objects.c:3411
+msgid "--thin cannot be used to build an indexable pack"
+msgstr ""
+
+#: builtin/pack-objects.c:3414
+msgid "--keep-unreachable and --unpack-unreachable are incompatible"
+msgstr ""
+
+#: builtin/pack-objects.c:3420
+msgid "cannot use --filter without --stdout"
+msgstr ""
+
+#: builtin/pack-objects.c:3479
+msgid "Enumerating objects"
+msgstr "Απαρίθμηση αντικειμένων"
+
+#: builtin/pack-objects.c:3498
+#, c-format
+msgid "Total %<PRIu32> (delta %<PRIu32>), reused %<PRIu32> (delta %<PRIu32>)"
+msgstr ""
+"Συνολικά %<PRIu32> (delta %<PRIu32>), επαναχρησιμοποιημένα %<PRIu32> (delta "
+"%<PRIu32>)"
+
+#: builtin/pack-refs.c:7
+msgid "git pack-refs [<options>]"
+msgstr ""
+
+#: builtin/pack-refs.c:15
+msgid "pack everything"
+msgstr ""
+
+#: builtin/pack-refs.c:16
+msgid "prune loose refs (default)"
+msgstr ""
+
+#: builtin/prune-packed.c:9
+msgid "git prune-packed [-n | --dry-run] [-q | --quiet]"
+msgstr ""
+
+#: builtin/prune-packed.c:42
+msgid "Removing duplicate objects"
+msgstr ""
+
+#: builtin/prune.c:12
+msgid "git prune [-n] [-v] [--progress] [--expire <time>] [--] [<head>...]"
+msgstr ""
+
+#: builtin/prune.c:109
+msgid "report pruned objects"
+msgstr ""
+
+#: builtin/prune.c:112
+msgid "expire objects older than <time>"
+msgstr ""
+
+#: builtin/prune.c:114
+msgid "limit traversal to objects outside promisor packfiles"
+msgstr ""
+
+#: builtin/prune.c:128
+msgid "cannot prune in a precious-objects repo"
+msgstr ""
+
+#: builtin/pull.c:61 builtin/pull.c:63
+#, c-format
+msgid "Invalid value for %s: %s"
+msgstr ""
+
+#: builtin/pull.c:83
+msgid "git pull [<options>] [<repository> [<refspec>...]]"
+msgstr ""
+
+#: builtin/pull.c:134
+msgid "control for recursive fetching of submodules"
+msgstr ""
+
+#: builtin/pull.c:138
+msgid "Options related to merging"
+msgstr ""
+
+#: builtin/pull.c:141
+msgid "incorporate changes by rebasing rather than merging"
+msgstr ""
+
+#: builtin/pull.c:168 builtin/rebase--interactive.c:149 builtin/revert.c:123
+msgid "allow fast-forward"
+msgstr ""
+
+#: builtin/pull.c:177
+msgid "automatically stash/stash pop before and after rebase"
+msgstr ""
+
+#: builtin/pull.c:193
+msgid "Options related to fetching"
+msgstr ""
+
+#: builtin/pull.c:203
+msgid "force overwrite of local branch"
+msgstr ""
+
+#: builtin/pull.c:211
+msgid "number of submodules pulled in parallel"
+msgstr ""
+
+#: builtin/pull.c:306
+#, c-format
+msgid "Invalid value for pull.ff: %s"
+msgstr ""
+
+#: builtin/pull.c:422
+msgid ""
+"There is no candidate for rebasing against among the refs that you just "
+"fetched."
+msgstr ""
+
+#: builtin/pull.c:424
+msgid ""
+"There are no candidates for merging among the refs that you just fetched."
+msgstr ""
+
+#: builtin/pull.c:425
+msgid ""
+"Generally this means that you provided a wildcard refspec which had no\n"
+"matches on the remote end."
+msgstr ""
+
+#: builtin/pull.c:428
+#, c-format
+msgid ""
+"You asked to pull from the remote '%s', but did not specify\n"
+"a branch. Because this is not the default configured remote\n"
+"for your current branch, you must specify a branch on the command line."
+msgstr ""
+"Ζητήσατε να ενσωματώσετε από το απομακρυσμένο '%s', αλλά δε δώσατε\n"
+"κάποιον κλάδο. Αφού αυτό δεν είναι το προεπιλεγμένο απομακρυσμένο\n"
+"για τον τρέχοντά σας κλάδο, πρέπει να δώσετε έναν κλάδο στη γραμμή εντολών."
+
+#: builtin/pull.c:433 builtin/rebase.c:956 git-parse-remote.sh:73
+msgid "You are not currently on a branch."
+msgstr "Δε βρίσκεστε αυτή τη στιγμή σε κάποιον κλάδο."
+
+#: builtin/pull.c:435 builtin/pull.c:450 git-parse-remote.sh:79
+msgid "Please specify which branch you want to rebase against."
+msgstr ""
+
+#: builtin/pull.c:437 builtin/pull.c:452 git-parse-remote.sh:82
+msgid "Please specify which branch you want to merge with."
+msgstr ""
+
+#: builtin/pull.c:438 builtin/pull.c:453
+msgid "See git-pull(1) for details."
+msgstr ""
+
+#: builtin/pull.c:440 builtin/pull.c:446 builtin/pull.c:455
+#: builtin/rebase.c:962 git-parse-remote.sh:64
+msgid "<remote>"
+msgstr "<απομακρυσμένο>"
+
+#: builtin/pull.c:440 builtin/pull.c:455 builtin/pull.c:460
+#: git-legacy-rebase.sh:564 git-parse-remote.sh:65
+msgid "<branch>"
+msgstr ""
+
+#: builtin/pull.c:448 builtin/rebase.c:954 git-parse-remote.sh:75
+msgid "There is no tracking information for the current branch."
+msgstr ""
+
+#: builtin/pull.c:457 git-parse-remote.sh:95
+msgid ""
+"If you wish to set tracking information for this branch you can do so with:"
+msgstr ""
+
+#: builtin/pull.c:462
+#, c-format
+msgid ""
+"Your configuration specifies to merge with the ref '%s'\n"
+"from the remote, but no such ref was fetched."
+msgstr ""
+"Οι ρυθμίσεις σας ορίζουν να γίνει συγχώνευση με το ref '%s'\n"
+"από τον απομακρυσμένο εξυπηρετητή, αλλά δεν έχει γίνει ανάκτηση τέτοιου ref."
+
+#: builtin/pull.c:566
+#, c-format
+msgid "unable to access commit %s"
+msgstr ""
+
+#: builtin/pull.c:844
+msgid "ignoring --verify-signatures for rebase"
+msgstr ""
+
+#: builtin/pull.c:892
+msgid "--[no-]autostash option is only valid with --rebase."
+msgstr "η επιλογή --[no-]autostash ισχύει μόνο με το --rebase."
+
+#: builtin/pull.c:900
+msgid "Updating an unborn branch with changes added to the index."
+msgstr ""
+
+#: builtin/pull.c:904
+msgid "pull with rebase"
+msgstr "ενσωμάτωση με rebase"
+
+#: builtin/pull.c:905
+msgid "please commit or stash them."
+msgstr ""
+
+#: builtin/pull.c:930
+#, c-format
+msgid ""
+"fetch updated the current branch head.\n"
+"fast-forwarding your working tree from\n"
+"commit %s."
+msgstr ""
+
+#: builtin/pull.c:936
+#, c-format
+msgid ""
+"Cannot fast-forward your working tree.\n"
+"After making sure that you saved anything precious from\n"
+"$ git diff %s\n"
+"output, run\n"
+"$ git reset --hard\n"
+"to recover."
+msgstr ""
+
+#: builtin/pull.c:951
+msgid "Cannot merge multiple branches into empty head."
+msgstr ""
+
+#: builtin/pull.c:955
+msgid "Cannot rebase onto multiple branches."
+msgstr ""
+
+#: builtin/pull.c:962
+msgid "cannot rebase with locally recorded submodule modifications"
+msgstr ""
+
+#: builtin/push.c:19
+msgid "git push [<options>] [<repository> [<refspec>...]]"
+msgstr "git push [<επιλογές>] [<αποθετήριο> [<refspec>...]]"
+
+#: builtin/push.c:111
+msgid "tag shorthand without <tag>"
+msgstr "συντομογραφία ετικέτας χωρίς <ετικέτα>"
+
+#: builtin/push.c:121
+msgid "--delete only accepts plain target ref names"
+msgstr "το --delete δέχεται μόνο απλά ονόματα ref προορισμού"
+
+#: builtin/push.c:167
+msgid ""
+"\n"
+"To choose either option permanently, see push.default in 'git help config'."
+msgstr ""
+"\n"
+"Για να διαλέξετε οποιαδήποτε από τις δύο επιλογές μόνιμα, δείτε το push."
+"default στο 'git help config'."
+
+#: builtin/push.c:170
+#, c-format
+msgid ""
+"The upstream branch of your current branch does not match\n"
+"the name of your current branch.  To push to the upstream branch\n"
+"on the remote, use\n"
+"\n"
+"    git push %s HEAD:%s\n"
+"\n"
+"To push to the branch of the same name on the remote, use\n"
+"\n"
+"    git push %s HEAD\n"
+"%s"
+msgstr ""
+"Ο προς τα πάνω κλάδος του τρέχοντος κλάδου σας δεν ταιριάζει με\n"
+"το όνομα του τρέχοντος κλάδου σας.  Για να δημοσιεύσετε στον κλάδο προς τα "
+"πάνω\n"
+"στον απομακρυσμένο εξυπηρετητή, χρησιμοποιήστε\n"
+"\n"
+"    git push %s HEAD:%s\n"
+"\n"
+"Για να δημοσιεύσετε στον κλάδο με το ίδιο όνομα στον απομακρυσμένο "
+"εξυπηρετητή, χρησιμοποιήστε\n"
+"\n"
+"    git push %s HEAD\n"
+"%s"
+
+#: builtin/push.c:185
+#, c-format
+msgid ""
+"You are not currently on a branch.\n"
+"To push the history leading to the current (detached HEAD)\n"
+"state now, use\n"
+"\n"
+"    git push %s HEAD:<name-of-remote-branch>\n"
+msgstr ""
+"Δε βρίσκεστε αυτή τη στιγμή σε κάποιον κλάδο.\n"
+"Για να δημοσιεύσετε το ιστορικό που οδηγεί στην τρέχουσα κατάσταση\n"
+"(αποσυνδεδεμένου HEAD) τώρα, χρησιμοποιήστε\n"
+"\n"
+"    git push %s HEAD:<όνομα-του-απομακρυσμένου-κλάδου>\n"
+
+#: builtin/push.c:199
+#, c-format
+msgid ""
+"The current branch %s has no upstream branch.\n"
+"To push the current branch and set the remote as upstream, use\n"
+"\n"
+"    git push --set-upstream %s %s\n"
+msgstr ""
+"Ο τρέχων κλάδος %s δεν έχει προς τα πάνω κλάδο.\n"
+"Για να δημοσιεύσετε τον τρέχοντα κλάδο και να ορίσετε τον απομακρυσμένο ως "
+"προς τα πάνω του, χρησιμοποιήστε\n"
+"\n"
+"    git push --set-upstream %s %s\n"
+
+#: builtin/push.c:207
+#, c-format
+msgid "The current branch %s has multiple upstream branches, refusing to push."
+msgstr ""
+"Ο τρέχων κλάδος %s έχει πολλαπλούς προς τα πάνω κλάδους, αρνούμαι να "
+"δημοσιεύσω."
+
+#: builtin/push.c:210
+#, c-format
+msgid ""
+"You are pushing to remote '%s', which is not the upstream of\n"
+"your current branch '%s', without telling me what to push\n"
+"to update which remote branch."
+msgstr ""
+"Δημοσιεύετε στο απομακρυσμένο '%s', που δεν είναι το προς τα πάνω του\n"
+"τρέχοντός σας κλάδου '%s', χωρίς να μου πείτε τι να δημοσιεύσω\n"
+"και ποιον απομακρυσμένο κλάδο να ενημερώσω."
+
+#: builtin/push.c:269
+msgid ""
+"You didn't specify any refspecs to push, and push.default is \"nothing\"."
+msgstr ""
+"Δεν προσδιορίσατε refspecs προς δημοσίευση, και το προεπιλεγμένο push."
+"default είναι τίποτα: \"nothing\"."
+
+#: builtin/push.c:276
+msgid ""
+"Updates were rejected because the tip of your current branch is behind\n"
+"its remote counterpart. Integrate the remote changes (e.g.\n"
+"'git pull ...') before pushing again.\n"
+"See the 'Note about fast-forwards' in 'git push --help' for details."
+msgstr ""
+"Απορρίφθηκαν οι ενημερώσεις επειδή η άκρη του τρέχοντος κλάδου είναι πίσω "
+"από\n"
+"το απομακρυσμένο αντίστοιχό του. Ενσωματώστε τις απομακρυσμένες αλλαγές (π."
+"χ.\n"
+"'git pull ...') πριν δημοσιεύσετε ξανά.\n"
+"Δείτε τη 'Σημείωση για ταχείες προωθήσεις' στο 'git push --help' για "
+"λεπτομέρειες."
+
+#: builtin/push.c:282
+msgid ""
+"Updates were rejected because a pushed branch tip is behind its remote\n"
+"counterpart. Check out this branch and integrate the remote changes\n"
+"(e.g. 'git pull ...') before pushing again.\n"
+"See the 'Note about fast-forwards' in 'git push --help' for details."
+msgstr ""
+"Απορρίφθηκαν οι ενημερώσεις επειδή η άκρη ενός κλάδου που δημοσιεύτηκε είναι "
+"πίσω από\n"
+"το απομακρυσμένο αντίστοιχό του. Εξάγετε αυτόν τον κλάδο και ενσωματώστε τις "
+"απομακρυσμένες αλλαγές\n"
+"(π.χ. 'git pull ...') πριν δημοσιεύσετε ξανά.\n"
+"Δείτε τη 'Σημείωση για ταχείες προωθήσεις' στο 'git push --help' για "
+"λεπτομέρειες."
+
+#: builtin/push.c:288
+msgid ""
+"Updates were rejected because the remote contains work that you do\n"
+"not have locally. This is usually caused by another repository pushing\n"
+"to the same ref. You may want to first integrate the remote changes\n"
+"(e.g., 'git pull ...') before pushing again.\n"
+"See the 'Note about fast-forwards' in 'git push --help' for details."
+msgstr ""
+"Απορρίφθηκαν οι ενημερώσεις επειδή ο απομακρυσμένος εξυπηρετητής περιέχει "
+"έργο που\n"
+"δε διαθέτετε τοπικά. Αυτό προκαλείται συνήθως όταν ένα άλλο αποθετήριο έχει "
+"δημοσιεύσει\n"
+"στο ίδιο ref. Μπορεί να θέλετε να ενσωματώσετε πρώτα τις απομακρυσμένες "
+"αλλαγές\n"
+"(π.χ. 'git pull ...') πριν δημοσιεύσετε ξανά.\n"
+"Δείτε τη 'Σημείωση για ταχείες προωθήσεις' στο 'git push --help' για "
+"λεπτομέρειες."
+
+#: builtin/push.c:295
+msgid "Updates were rejected because the tag already exists in the remote."
+msgstr ""
+"Απορρίφθηκαν οι ενημερώσεις επειδή η ετικέτα υπάρχει ήδη στον απομακρυσμένο "
+"εξυπηρετητή."
+
+#: builtin/push.c:298
+msgid ""
+"You cannot update a remote ref that points at a non-commit object,\n"
+"or update a remote ref to make it point at a non-commit object,\n"
+"without using the '--force' option.\n"
+msgstr ""
+"Δε μπορείτε να ενημερώσετε ένα απομακρυσμένο ref που δείχνει σε αντικείμενο "
+"που δεν είναι υποβολή,\n"
+"ή να ενημερώσετε ένα απομακρυσμένο ref για να το κάνετε να δείχνει σε "
+"αντικείμενο που δεν είναι υποβολή,\n"
+"χωρίς να χρησιμοποιήσετε την επιλογή εξανάγκασης '--force'.\n"
+
+#: builtin/push.c:359
+#, c-format
+msgid "Pushing to %s\n"
+msgstr "Δημοσίευση στο %s\n"
+
+#: builtin/push.c:364
+#, c-format
+msgid "failed to push some refs to '%s'"
+msgstr "απέτυχε η δημοσίευση κάποιων ref στο '%s'"
+
+#: builtin/push.c:398
+#, c-format
+msgid "bad repository '%s'"
+msgstr "λάθος αποθετήριο '%s'"
+
+#: builtin/push.c:399
+msgid ""
+"No configured push destination.\n"
+"Either specify the URL from the command-line or configure a remote "
+"repository using\n"
+"\n"
+"    git remote add <name> <url>\n"
+"\n"
+"and then push using the remote name\n"
+"\n"
+"    git push <name>\n"
+msgstr ""
+"Δεν έχει ρυθμιστεί προορισμός δημοσίευσης.\n"
+"Ορίστε το URL από τη γραμμή εντολών ή ρυθμίστε ένα απομακρυσμένο αποθετήριο "
+"χρησιμοποιώντας\n"
+"\n"
+"    git remote add <όνομα> <url>\n"
+"\n"
+"και έπειτα δημοσιεύστε χρησιμοποιώντας το όνομα του απομακρυσμένου\n"
+"\n"
+"    git push <όνομα>\n"
+
+#: builtin/push.c:554
+msgid "repository"
+msgstr "αποθετήριο"
+
+#: builtin/push.c:555 builtin/send-pack.c:164
+msgid "push all refs"
+msgstr "να γίνει δημοσίευση όλων των ref"
+
+#: builtin/push.c:556 builtin/send-pack.c:166
+msgid "mirror all refs"
+msgstr "να γίνει αντιγραφή όλων των ref"
+
+#: builtin/push.c:558
+msgid "delete refs"
+msgstr "να γίνει διαγραφή των ref"
+
+#: builtin/push.c:559
+msgid "push tags (can't be used with --all or --mirror)"
+msgstr ""
+"να γίνει δημοσίευση των ετικετών (δε γίνεται να χρησιμοποιηθεί με το --all ή "
+"το --mirror)"
+
+#: builtin/push.c:562 builtin/send-pack.c:167
+msgid "force updates"
+msgstr "να γίνουν αναγκαστικά ενημερώσεις"
+
+#: builtin/push.c:564 builtin/send-pack.c:181
+msgid "<refname>:<expect>"
+msgstr "<refname>:<expect>"
+
+#: builtin/push.c:565 builtin/send-pack.c:182
+msgid "require old value of ref to be at this value"
+msgstr "να απαιτηθεί η παλιά τιμή του ref να είναι η εξής"
+
+#: builtin/push.c:568
+msgid "control recursive pushing of submodules"
+msgstr "έλεγχος αναδρομικής δημοσίευσης των υποενοτήτων"
+
+#: builtin/push.c:570 builtin/send-pack.c:175
+msgid "use thin pack"
+msgstr "να γίνει χρήση λεπτού πακέτου"
+
+#: builtin/push.c:571 builtin/push.c:572 builtin/send-pack.c:161
+#: builtin/send-pack.c:162
+msgid "receive pack program"
+msgstr "λήψη προγράμματος πακέτου"
+
+#: builtin/push.c:573
+msgid "set upstream for git pull/status"
+msgstr "να οριστεί το προς τα πάνω για το git pull/status"
+
+#: builtin/push.c:576
+msgid "prune locally removed refs"
+msgstr "να γίνει κλάδεμα των τοπικά διεγραμμένων ref"
+
+#: builtin/push.c:578
+msgid "bypass pre-push hook"
+msgstr "να γίνει παράκαμψη του αγκίστρου προ δημοσίευσης"
+
+#: builtin/push.c:579
+msgid "push missing but relevant tags"
+msgstr "να γίνει δημοσίευση των ετικετών που λείπουν αλλά είναι σχετικές"
+
+#: builtin/push.c:582 builtin/send-pack.c:169
+msgid "GPG sign the push"
+msgstr "να υπογραφεί με GPG η δημοσίευση"
+
+#: builtin/push.c:584 builtin/send-pack.c:176
+msgid "request atomic transaction on remote side"
+msgstr "να ζητηθεί ατομική συναλλαγή στην απομακρυσμένη πλευρά"
+
+#: builtin/push.c:602
+msgid "--delete is incompatible with --all, --mirror and --tags"
+msgstr "το --delete δεν είναι συμβατό με τα --all, --mirror και --tags"
+
+#: builtin/push.c:604
+msgid "--delete doesn't make sense without any refs"
+msgstr "το --delete δεν έχει νόημα χωρίς κανένα ref"
+
+#: builtin/push.c:607
+msgid "--all and --tags are incompatible"
+msgstr "το --all και το --tags δεν είναι συμβατά μεταξύ τους"
+
+#: builtin/push.c:609
+msgid "--all can't be combined with refspecs"
+msgstr "το --all δε γίνεται να συνδυαστεί με refspec"
+
+#: builtin/push.c:613
+msgid "--mirror and --tags are incompatible"
+msgstr "το --mirror και το --tags δεν είναι συμβατά μεταξύ τους"
+
+#: builtin/push.c:615
+msgid "--mirror can't be combined with refspecs"
+msgstr "το --mirror δε γίνεται να συνδυαστεί με refspec"
+
+#: builtin/push.c:618
+msgid "--all and --mirror are incompatible"
+msgstr "το --all και το --mirror δεν είναι συμβατά μεταξύ τους"
+
+#: builtin/push.c:637
+msgid "push options must not have new line characters"
+msgstr "οι επιλογές δημοσίευσης δεν πρέπει να έχουν χαρακτήρες newline"
+
+#: builtin/range-diff.c:8
+msgid "git range-diff [<options>] <old-base>..<old-tip> <new-base>..<new-tip>"
+msgstr ""
+
+#: builtin/range-diff.c:9
+msgid "git range-diff [<options>] <old-tip>...<new-tip>"
+msgstr ""
+
+#: builtin/range-diff.c:10
+msgid "git range-diff [<options>] <base> <old-tip> <new-tip>"
+msgstr ""
+
+#: builtin/range-diff.c:21
+msgid "Percentage by which creation is weighted"
+msgstr ""
+
+#: builtin/range-diff.c:23
+msgid "use simple diff colors"
+msgstr ""
+
+#: builtin/range-diff.c:61 builtin/range-diff.c:65
+#, c-format
+msgid "no .. in range: '%s'"
+msgstr ""
+
+#: builtin/range-diff.c:75
+msgid "single arg format must be symmetric range"
+msgstr ""
+
+#: builtin/range-diff.c:90
+msgid "need two commit ranges"
+msgstr ""
+
+#: builtin/read-tree.c:41
+msgid ""
+"git read-tree [(-m [--trivial] [--aggressive] | --reset | --prefix=<prefix>) "
+"[-u [--exclude-per-directory=<gitignore>] | -i]] [--no-sparse-checkout] [--"
+"index-output=<file>] (--empty | <tree-ish1> [<tree-ish2> [<tree-ish3>]])"
+msgstr ""
+
+#: builtin/read-tree.c:124
+msgid "write resulting index to <file>"
+msgstr ""
+
+#: builtin/read-tree.c:127
+msgid "only empty the index"
+msgstr ""
+
+#: builtin/read-tree.c:129
+msgid "Merging"
+msgstr ""
+
+#: builtin/read-tree.c:131
+msgid "perform a merge in addition to a read"
+msgstr ""
+
+#: builtin/read-tree.c:133
+msgid "3-way merge if no file level merging required"
+msgstr ""
+
+#: builtin/read-tree.c:135
+msgid "3-way merge in presence of adds and removes"
+msgstr ""
+
+#: builtin/read-tree.c:137
+msgid "same as -m, but discard unmerged entries"
+msgstr ""
+
+#: builtin/read-tree.c:138
+msgid "<subdirectory>/"
+msgstr ""
+
+#: builtin/read-tree.c:139
+msgid "read the tree into the index under <subdirectory>/"
+msgstr ""
+
+#: builtin/read-tree.c:142
+msgid "update working tree with merge result"
+msgstr ""
+
+#: builtin/read-tree.c:144
+msgid "gitignore"
+msgstr ""
+
+#: builtin/read-tree.c:145
+msgid "allow explicitly ignored files to be overwritten"
+msgstr ""
+
+#: builtin/read-tree.c:148
+msgid "don't check the working tree after merging"
+msgstr ""
+
+#: builtin/read-tree.c:149
+msgid "don't update the index or the work tree"
+msgstr ""
+
+#: builtin/read-tree.c:151
+msgid "skip applying sparse checkout filter"
+msgstr ""
+
+#: builtin/read-tree.c:153
+msgid "debug unpack-trees"
+msgstr ""
+
+#: builtin/rebase.c:30
+msgid ""
+"git rebase [-i] [options] [--exec <cmd>] [--onto <newbase>] [<upstream>] "
+"[<branch>]"
+msgstr ""
+
+#: builtin/rebase.c:32
+msgid ""
+"git rebase [-i] [options] [--exec <cmd>] [--onto <newbase>] --root [<branch>]"
+msgstr ""
+
+#: builtin/rebase.c:34
+msgid "git rebase --continue | --abort | --skip | --edit-todo"
+msgstr ""
+
+#: builtin/rebase.c:121 builtin/rebase.c:1437
+#, c-format
+msgid "%s requires an interactive rebase"
+msgstr ""
+
+#: builtin/rebase.c:173
+#, c-format
+msgid "could not get 'onto': '%s'"
+msgstr ""
+
+#: builtin/rebase.c:188
+#, c-format
+msgid "invalid orig-head: '%s'"
+msgstr ""
+
+#: builtin/rebase.c:213
+#, c-format
+msgid "ignoring invalid allow_rerere_autoupdate: '%s'"
+msgstr ""
+
+#: builtin/rebase.c:289
+#, c-format
+msgid "Could not read '%s'"
+msgstr ""
+
+#: builtin/rebase.c:307
+#, c-format
+msgid "Cannot store %s"
+msgstr ""
+
+#: builtin/rebase.c:402
+msgid "could not determine HEAD revision"
+msgstr ""
+
+#: builtin/rebase.c:522
+msgid ""
+"Resolve all conflicts manually, mark them as resolved with\n"
+"\"git add/rm <conflicted_files>\", then run \"git rebase --continue\".\n"
+"You can instead skip this commit: run \"git rebase --skip\".\n"
+"To abort and get back to the state before \"git rebase\", run \"git rebase --"
+"abort\"."
+msgstr ""
+"Επιλύστε όλες τις συγκρούσεις χειροκίνητα, επισημάνετέ τις ως επιλυμένες με\n"
+"\"git add/rm <συγκρουόμενα αρχεία>\", έπειτα τρέξτε \"git rebase --continue"
+"\".\n"
+"Ειδάλλως μπορείτε να προσπεράσετε αυτή την υποβολή: τρέξτε \"git rebase --"
+"skip\".\n"
+"Για να εγκαταλείψετε και να επιστρέψετε στην κατάσταση πριν από το \"git "
+"rebase\", τρέξτε \"git rebase --abort\"."
+
+#: builtin/rebase.c:603
+#, c-format
+msgid ""
+"\n"
+"git encountered an error while preparing the patches to replay\n"
+"these revisions:\n"
+"\n"
+"    %s\n"
+"\n"
+"As a result, git cannot rebase them."
+msgstr ""
+
+#: builtin/rebase.c:948
+#, c-format
+msgid ""
+"%s\n"
+"Please specify which branch you want to rebase against.\n"
+"See git-rebase(1) for details.\n"
+"\n"
+"    git rebase '<branch>'\n"
+"\n"
+msgstr ""
+
+#: builtin/rebase.c:964
+#, c-format
+msgid ""
+"If you wish to set tracking information for this branch you can do so with:\n"
+"\n"
+"    git branch --set-upstream-to=%s/<branch> %s\n"
+"\n"
+msgstr ""
+
+#: builtin/rebase.c:994
+msgid "exec commands cannot contain newlines"
+msgstr ""
+
+#: builtin/rebase.c:998
+msgid "empty exec command"
+msgstr ""
+
+#: builtin/rebase.c:1040
+msgid "rebase onto given branch instead of upstream"
+msgstr ""
+
+#: builtin/rebase.c:1042
+msgid "allow pre-rebase hook to run"
+msgstr ""
+
+#: builtin/rebase.c:1044
+msgid "be quiet. implies --no-stat"
+msgstr ""
+
+#: builtin/rebase.c:1047
+msgid "display a diffstat of what changed upstream"
+msgstr ""
+
+#: builtin/rebase.c:1050
+msgid "do not show diffstat of what changed upstream"
+msgstr ""
+
+#: builtin/rebase.c:1053
+msgid "add a Signed-off-by: line to each commit"
+msgstr ""
+
+#: builtin/rebase.c:1055 builtin/rebase.c:1059 builtin/rebase.c:1061
+msgid "passed to 'git am'"
+msgstr ""
+
+#: builtin/rebase.c:1063 builtin/rebase.c:1065
+msgid "passed to 'git apply'"
+msgstr ""
+
+#: builtin/rebase.c:1067 builtin/rebase.c:1070
+msgid "cherry-pick all commits, even if unchanged"
+msgstr ""
+
+#: builtin/rebase.c:1072
+msgid "continue"
+msgstr "συνέχεια"
+
+#: builtin/rebase.c:1075
+msgid "skip current patch and continue"
+msgstr ""
+
+#: builtin/rebase.c:1077
+msgid "abort and check out the original branch"
+msgstr ""
+
+#: builtin/rebase.c:1080
+msgid "abort but keep HEAD where it is"
+msgstr ""
+
+#: builtin/rebase.c:1081
+msgid "edit the todo list during an interactive rebase"
+msgstr ""
+
+#: builtin/rebase.c:1084
+msgid "show the patch file being applied or merged"
+msgstr ""
+
+#: builtin/rebase.c:1087
+msgid "use merging strategies to rebase"
+msgstr ""
+
+#: builtin/rebase.c:1091
+msgid "let the user edit the list of commits to rebase"
+msgstr ""
+
+#: builtin/rebase.c:1095
+msgid "try to recreate merges instead of ignoring them"
+msgstr ""
+
+#: builtin/rebase.c:1099
+msgid "allow rerere to update index with resolved conflict"
+msgstr ""
+
+#: builtin/rebase.c:1102
+msgid "preserve empty commits during rebase"
+msgstr ""
+
+#: builtin/rebase.c:1104
+msgid "move commits that begin with squash!/fixup! under -i"
+msgstr ""
+
+#: builtin/rebase.c:1110
+msgid "automatically stash/stash pop before and after"
+msgstr ""
+
+#: builtin/rebase.c:1112
+msgid "add exec lines after each commit of the editable list"
+msgstr ""
+
+#: builtin/rebase.c:1116
+msgid "allow rebasing commits with empty messages"
+msgstr ""
+
+#: builtin/rebase.c:1119
+msgid "try to rebase merges instead of skipping them"
+msgstr ""
+
+#: builtin/rebase.c:1122
+msgid "use 'merge-base --fork-point' to refine upstream"
+msgstr ""
+
+#: builtin/rebase.c:1124
+msgid "use the given merge strategy"
+msgstr ""
+
+#: builtin/rebase.c:1126 builtin/revert.c:112
+msgid "option"
+msgstr ""
+
+#: builtin/rebase.c:1127
+msgid "pass the argument through to the merge strategy"
+msgstr ""
+
+#: builtin/rebase.c:1130
+msgid "rebase all reachable commits up to the root(s)"
+msgstr ""
+
+#: builtin/rebase.c:1133 builtin/rebase--interactive.c:198
+msgid "automatically re-schedule any `exec` that fails"
+msgstr ""
+
+#: builtin/rebase.c:1149
+#, c-format
+msgid "could not exec %s"
+msgstr ""
+
+#: builtin/rebase.c:1167 git-legacy-rebase.sh:220
+msgid "It looks like 'git am' is in progress. Cannot rebase."
+msgstr ""
+
+#: builtin/rebase.c:1208 git-legacy-rebase.sh:406
+msgid "No rebase in progress?"
+msgstr ""
+
+#: builtin/rebase.c:1212 git-legacy-rebase.sh:417
+msgid "The --edit-todo action can only be used during interactive rebase."
+msgstr ""
+
+#: builtin/rebase.c:1226 git-legacy-rebase.sh:424
+msgid "Cannot read HEAD"
+msgstr ""
+
+#: builtin/rebase.c:1238 git-legacy-rebase.sh:427
+msgid ""
+"You must edit all merge conflicts and then\n"
+"mark them as resolved using git add"
+msgstr ""
+"Πρέπει να επεξεργαστείτε όλες τις συγκρούσεις συγχώνευσης και μετά\n"
+"να τις επισημάνετε ως επιλυμένες χρησιμοποιώντας git add"
+
+#: builtin/rebase.c:1257
+msgid "could not discard worktree changes"
+msgstr ""
+
+#: builtin/rebase.c:1276
+#, c-format
+msgid "could not move back to %s"
+msgstr ""
+
+#: builtin/rebase.c:1287 builtin/rm.c:369
+#, c-format
+msgid "could not remove '%s'"
+msgstr "δεν ήταν δυνατή η αφαίρεση του '%s'"
+
+#: builtin/rebase.c:1313
+#, c-format
+msgid ""
+"It seems that there is already a %s directory, and\n"
+"I wonder if you are in the middle of another rebase.  If that is the\n"
+"case, please try\n"
+"\t%s\n"
+"If that is not the case, please\n"
+"\t%s\n"
+"and run me again.  I am stopping in case you still have something\n"
+"valuable there.\n"
+msgstr ""
+
+#: builtin/rebase.c:1334
+msgid "switch `C' expects a numerical value"
+msgstr ""
+
+#: builtin/rebase.c:1375
+#, c-format
+msgid "Unknown mode: %s"
+msgstr ""
+
+#: builtin/rebase.c:1397
+msgid "--strategy requires --merge or --interactive"
+msgstr ""
+
+#: builtin/rebase.c:1446
+msgid "cannot combine am options with either interactive or merge options"
+msgstr ""
+
+#: builtin/rebase.c:1465
+msgid "cannot combine '--preserve-merges' with '--rebase-merges'"
+msgstr ""
+
+#: builtin/rebase.c:1469 git-legacy-rebase.sh:544
+msgid ""
+"error: cannot combine '--preserve-merges' with '--reschedule-failed-exec'"
+msgstr ""
+
+#: builtin/rebase.c:1475
+msgid "cannot combine '--rebase-merges' with '--strategy-option'"
+msgstr ""
+
+#: builtin/rebase.c:1478
+msgid "cannot combine '--rebase-merges' with '--strategy'"
+msgstr ""
+
+#: builtin/rebase.c:1502
+#, c-format
+msgid "invalid upstream '%s'"
+msgstr ""
+
+#: builtin/rebase.c:1508
+msgid "Could not create new root commit"
+msgstr ""
+
+#: builtin/rebase.c:1526
+#, c-format
+msgid "'%s': need exactly one merge base"
+msgstr ""
+
+#: builtin/rebase.c:1533
+#, c-format
+msgid "Does not point to a valid commit '%s'"
+msgstr ""
+
+#: builtin/rebase.c:1558
+#, c-format
+msgid "fatal: no such branch/commit '%s'"
+msgstr ""
+
+#: builtin/rebase.c:1566 builtin/submodule--helper.c:38
+#: builtin/submodule--helper.c:1934
+#, c-format
+msgid "No such ref: %s"
+msgstr "Δεν υπάρχει ref: %s"
+
+#: builtin/rebase.c:1578
+msgid "Could not resolve HEAD to a revision"
+msgstr "Δεν ήταν δυνατή η ταύτιση του HEAD με κάποια έκδοση"
+
+#: builtin/rebase.c:1619 git-legacy-rebase.sh:673
+msgid "Cannot autostash"
+msgstr ""
+
+#: builtin/rebase.c:1622
+#, c-format
+msgid "Unexpected stash response: '%s'"
+msgstr ""
+
+#: builtin/rebase.c:1628
+#, c-format
+msgid "Could not create directory for '%s'"
+msgstr ""
+
+#: builtin/rebase.c:1631
+#, c-format
+msgid "Created autostash: %s\n"
+msgstr ""
+
+#: builtin/rebase.c:1634
+msgid "could not reset --hard"
+msgstr "δεν ήταν δυνατή η --hard επαναφορά"
+
+#: builtin/rebase.c:1635 builtin/reset.c:114
+#, c-format
+msgid "HEAD is now at %s"
+msgstr "Το HEAD τώρα βρίσκεται στο %s"
+
+#: builtin/rebase.c:1651 git-legacy-rebase.sh:682
+msgid "Please commit or stash them."
+msgstr ""
+
+#: builtin/rebase.c:1678
+#, c-format
+msgid "could not parse '%s'"
+msgstr ""
+
+#: builtin/rebase.c:1691
+#, c-format
+msgid "could not switch to %s"
+msgstr ""
+
+#: builtin/rebase.c:1702 git-legacy-rebase.sh:705
+#, sh-format
+msgid "HEAD is up to date."
+msgstr ""
+
+#: builtin/rebase.c:1704
+#, c-format
+msgid "Current branch %s is up to date.\n"
+msgstr ""
+
+#: builtin/rebase.c:1712 git-legacy-rebase.sh:715
+#, sh-format
+msgid "HEAD is up to date, rebase forced."
+msgstr ""
+
+#: builtin/rebase.c:1714
+#, c-format
+msgid "Current branch %s is up to date, rebase forced.\n"
+msgstr ""
+
+#: builtin/rebase.c:1722 git-legacy-rebase.sh:215
+msgid "The pre-rebase hook refused to rebase."
+msgstr ""
+
+#: builtin/rebase.c:1729
+#, c-format
+msgid "Changes to %s:\n"
+msgstr ""
+
+#: builtin/rebase.c:1732
+#, c-format
+msgid "Changes from %s to %s:\n"
+msgstr ""
+
+#: builtin/rebase.c:1757
+#, c-format
+msgid "First, rewinding head to replay your work on top of it...\n"
+msgstr ""
+"Πρώτα, γίνεται γύρισμα προς τα πίσω του head για να γίνει επανάληψη της "
+"δουλειάς σας πάνω σε αυτό...\n"
+
+#: builtin/rebase.c:1765
+msgid "Could not detach HEAD"
+msgstr ""
+
+#: builtin/rebase.c:1774
+#, c-format
+msgid "Fast-forwarded %s to %s.\n"
+msgstr ""
+
+#: builtin/rebase--interactive.c:25
+msgid "no HEAD?"
+msgstr ""
+
+#: builtin/rebase--interactive.c:52
+#, c-format
+msgid "could not create temporary %s"
+msgstr ""
+
+#: builtin/rebase--interactive.c:58
+msgid "could not mark as interactive"
+msgstr ""
+
+#: builtin/rebase--interactive.c:102
+#, c-format
+msgid "could not open %s"
+msgstr "δεν ήταν δυνατό το άνοιγμα του %s"
+
+#: builtin/rebase--interactive.c:115
+msgid "could not generate todo list"
+msgstr ""
+
+#: builtin/rebase--interactive.c:131
+msgid "git rebase--interactive [<options>]"
+msgstr ""
+
+#: builtin/rebase--interactive.c:150
+msgid "keep empty commits"
+msgstr ""
+
+#: builtin/rebase--interactive.c:152 builtin/revert.c:125
+msgid "allow commits with empty messages"
+msgstr ""
+
+#: builtin/rebase--interactive.c:153
+msgid "rebase merge commits"
+msgstr ""
+
+#: builtin/rebase--interactive.c:155
+msgid "keep original branch points of cousins"
+msgstr ""
+
+#: builtin/rebase--interactive.c:157
+msgid "move commits that begin with squash!/fixup!"
+msgstr ""
+
+#: builtin/rebase--interactive.c:158
+msgid "sign commits"
+msgstr ""
+
+#: builtin/rebase--interactive.c:160
+msgid "continue rebase"
+msgstr "συνέχεια; rebase"
+
+#: builtin/rebase--interactive.c:162
+msgid "skip commit"
+msgstr ""
+
+#: builtin/rebase--interactive.c:163
+msgid "edit the todo list"
+msgstr ""
+
+#: builtin/rebase--interactive.c:165
+msgid "show the current patch"
+msgstr ""
+
+#: builtin/rebase--interactive.c:168
+msgid "shorten commit ids in the todo list"
+msgstr ""
+
+#: builtin/rebase--interactive.c:170
+msgid "expand commit ids in the todo list"
+msgstr ""
+
+#: builtin/rebase--interactive.c:172
+msgid "check the todo list"
+msgstr ""
+
+#: builtin/rebase--interactive.c:174
+msgid "rearrange fixup/squash lines"
+msgstr ""
+
+#: builtin/rebase--interactive.c:176
+msgid "insert exec commands in todo list"
+msgstr ""
+
+#: builtin/rebase--interactive.c:177
+msgid "onto"
+msgstr ""
+
+#: builtin/rebase--interactive.c:179
+msgid "restrict-revision"
+msgstr ""
+
+#: builtin/rebase--interactive.c:179
+msgid "restrict revision"
+msgstr ""
+
+#: builtin/rebase--interactive.c:180
+msgid "squash-onto"
+msgstr ""
+
+#: builtin/rebase--interactive.c:181
+msgid "squash onto"
+msgstr ""
+
+#: builtin/rebase--interactive.c:183
+msgid "the upstream commit"
+msgstr ""
+
+#: builtin/rebase--interactive.c:184
+msgid "head-name"
+msgstr ""
+
+#: builtin/rebase--interactive.c:184
+msgid "head name"
+msgstr ""
+
+#: builtin/rebase--interactive.c:189
+msgid "rebase strategy"
+msgstr ""
+
+#: builtin/rebase--interactive.c:190
+msgid "strategy-opts"
+msgstr ""
+
+#: builtin/rebase--interactive.c:191
+msgid "strategy options"
+msgstr ""
+
+#: builtin/rebase--interactive.c:192
+msgid "switch-to"
+msgstr "αλλαγή σε"
+
+#: builtin/rebase--interactive.c:193
+msgid "the branch or commit to checkout"
+msgstr ""
+
+#: builtin/rebase--interactive.c:194
+msgid "onto-name"
+msgstr ""
+
+#: builtin/rebase--interactive.c:194
+msgid "onto name"
+msgstr ""
+
+#: builtin/rebase--interactive.c:195
+msgid "cmd"
+msgstr ""
+
+#: builtin/rebase--interactive.c:195
+msgid "the command to run"
+msgstr ""
+
+#: builtin/rebase--interactive.c:224
+msgid "--[no-]rebase-cousins has no effect without --rebase-merges"
+msgstr ""
+
+#: builtin/rebase--interactive.c:230
+msgid "a base commit must be provided with --upstream or --onto"
+msgstr ""
+
+#: builtin/receive-pack.c:33
+msgid "git receive-pack <git-dir>"
+msgstr ""
+
+#: builtin/receive-pack.c:830
+msgid ""
+"By default, updating the current branch in a non-bare repository\n"
+"is denied, because it will make the index and work tree inconsistent\n"
+"with what you pushed, and will require 'git reset --hard' to match\n"
+"the work tree to HEAD.\n"
+"\n"
+"You can set the 'receive.denyCurrentBranch' configuration variable\n"
+"to 'ignore' or 'warn' in the remote repository to allow pushing into\n"
+"its current branch; however, this is not recommended unless you\n"
+"arranged to update its work tree to match what you pushed in some\n"
+"other way.\n"
+"\n"
+"To squelch this message and still keep the default behaviour, set\n"
+"'receive.denyCurrentBranch' configuration variable to 'refuse'."
+msgstr ""
+
+#: builtin/receive-pack.c:850
+msgid ""
+"By default, deleting the current branch is denied, because the next\n"
+"'git clone' won't result in any file checked out, causing confusion.\n"
+"\n"
+"You can set 'receive.denyDeleteCurrent' configuration variable to\n"
+"'warn' or 'ignore' in the remote repository to allow deleting the\n"
+"current branch, with or without a warning message.\n"
+"\n"
+"To squelch this message, you can set it to 'refuse'."
+msgstr ""
+
+#: builtin/receive-pack.c:1929
+msgid "quiet"
+msgstr "σιωπηλά"
+
+#: builtin/receive-pack.c:1943
+msgid "You must specify a directory."
+msgstr "Πρέπει να ορίσετε έναν φάκελο."
+
+#: builtin/reflog.c:17
+msgid ""
+"git reflog expire [--expire=<time>] [--expire-unreachable=<time>] [--"
+"rewrite] [--updateref] [--stale-fix] [--dry-run | -n] [--verbose] [--all] "
+"<refs>..."
+msgstr ""
+
+#: builtin/reflog.c:22
+msgid ""
+"git reflog delete [--rewrite] [--updateref] [--dry-run | -n] [--verbose] "
+"<refs>..."
+msgstr ""
+
+#: builtin/reflog.c:25
+msgid "git reflog exists <ref>"
+msgstr ""
+
+#: builtin/reflog.c:567 builtin/reflog.c:572
+#, c-format
+msgid "'%s' is not a valid timestamp"
+msgstr ""
+
+#: builtin/reflog.c:605
+#, c-format
+msgid "Marking reachable objects..."
+msgstr ""
+
+#: builtin/reflog.c:643
+#, c-format
+msgid "%s points nowhere!"
+msgstr ""
+
+#: builtin/reflog.c:695
+msgid "no reflog specified to delete"
+msgstr ""
+
+#: builtin/reflog.c:704
+#, c-format
+msgid "not a reflog: %s"
+msgstr "δεν είναι reflog: %s"
+
+#: builtin/reflog.c:709
+#, c-format
+msgid "no reflog for '%s'"
+msgstr ""
+
+#: builtin/reflog.c:755
+#, c-format
+msgid "invalid ref format: %s"
+msgstr ""
+
+#: builtin/reflog.c:764
+msgid "git reflog [ show | expire | delete | exists ]"
+msgstr ""
+
+#: builtin/remote.c:16
+msgid "git remote [-v | --verbose]"
+msgstr ""
+
+#: builtin/remote.c:17
+msgid ""
+"git remote add [-t <branch>] [-m <master>] [-f] [--tags | --no-tags] [--"
+"mirror=<fetch|push>] <name> <url>"
+msgstr ""
+
+#: builtin/remote.c:18 builtin/remote.c:38
+msgid "git remote rename <old> <new>"
+msgstr ""
+
+#: builtin/remote.c:19 builtin/remote.c:43
+msgid "git remote remove <name>"
+msgstr ""
+
+#: builtin/remote.c:20 builtin/remote.c:48
+msgid "git remote set-head <name> (-a | --auto | -d | --delete | <branch>)"
+msgstr ""
+
+#: builtin/remote.c:21
+msgid "git remote [-v | --verbose] show [-n] <name>"
+msgstr ""
+
+#: builtin/remote.c:22
+msgid "git remote prune [-n | --dry-run] <name>"
+msgstr ""
+
+#: builtin/remote.c:23
+msgid ""
+"git remote [-v | --verbose] update [-p | --prune] [(<group> | <remote>)...]"
+msgstr ""
+
+#: builtin/remote.c:24
+msgid "git remote set-branches [--add] <name> <branch>..."
+msgstr ""
+
+#: builtin/remote.c:25 builtin/remote.c:74
+msgid "git remote get-url [--push] [--all] <name>"
+msgstr ""
+
+#: builtin/remote.c:26 builtin/remote.c:79
+msgid "git remote set-url [--push] <name> <newurl> [<oldurl>]"
+msgstr ""
+
+#: builtin/remote.c:27 builtin/remote.c:80
+msgid "git remote set-url --add <name> <newurl>"
+msgstr ""
+
+#: builtin/remote.c:28 builtin/remote.c:81
+msgid "git remote set-url --delete <name> <url>"
+msgstr ""
+
+#: builtin/remote.c:33
+msgid "git remote add [<options>] <name> <url>"
+msgstr ""
+
+#: builtin/remote.c:53
+msgid "git remote set-branches <name> <branch>..."
+msgstr ""
+
+#: builtin/remote.c:54
+msgid "git remote set-branches --add <name> <branch>..."
+msgstr ""
+
+#: builtin/remote.c:59
+msgid "git remote show [<options>] <name>"
+msgstr ""
+
+#: builtin/remote.c:64
+msgid "git remote prune [<options>] <name>"
+msgstr ""
+
+#: builtin/remote.c:69
+msgid "git remote update [<options>] [<group> | <remote>]..."
+msgstr ""
+
+#: builtin/remote.c:98
+#, c-format
+msgid "Updating %s"
+msgstr ""
+
+#: builtin/remote.c:130
+msgid ""
+"--mirror is dangerous and deprecated; please\n"
+"\t use --mirror=fetch or --mirror=push instead"
+msgstr ""
+
+#: builtin/remote.c:147
+#, c-format
+msgid "unknown mirror argument: %s"
+msgstr ""
+
+#: builtin/remote.c:163
+msgid "fetch the remote branches"
+msgstr ""
+
+#: builtin/remote.c:165
+msgid "import all tags and associated objects when fetching"
+msgstr ""
+
+#: builtin/remote.c:168
+msgid "or do not fetch any tag at all (--no-tags)"
+msgstr ""
+
+#: builtin/remote.c:170
+msgid "branch(es) to track"
+msgstr ""
+
+#: builtin/remote.c:171
+msgid "master branch"
+msgstr ""
+
+#: builtin/remote.c:173
+msgid "set up remote as a mirror to push to or fetch from"
+msgstr ""
+
+#: builtin/remote.c:185
+msgid "specifying a master branch makes no sense with --mirror"
+msgstr ""
+
+#: builtin/remote.c:187
+msgid "specifying branches to track makes sense only with fetch mirrors"
+msgstr ""
+
+#: builtin/remote.c:194 builtin/remote.c:636
+#, c-format
+msgid "remote %s already exists."
+msgstr ""
+
+#: builtin/remote.c:198 builtin/remote.c:640
+#, c-format
+msgid "'%s' is not a valid remote name"
+msgstr ""
+
+#: builtin/remote.c:238
+#, c-format
+msgid "Could not setup master '%s'"
+msgstr ""
+
+#: builtin/remote.c:344
+#, c-format
+msgid "Could not get fetch map for refspec %s"
+msgstr ""
+
+#: builtin/remote.c:443 builtin/remote.c:451
+msgid "(matching)"
+msgstr ""
+
+#: builtin/remote.c:455
+msgid "(delete)"
+msgstr ""
+
+#: builtin/remote.c:629 builtin/remote.c:765 builtin/remote.c:864
+#, c-format
+msgid "No such remote: '%s'"
+msgstr "Δεν υπάρχει τέτοιος απομακρυσμένος εξυπηρετητής: '%s'"
+
+#: builtin/remote.c:646
+#, c-format
+msgid "Could not rename config section '%s' to '%s'"
+msgstr ""
+
+#: builtin/remote.c:666
+#, c-format
+msgid ""
+"Not updating non-default fetch refspec\n"
+"\t%s\n"
+"\tPlease update the configuration manually if necessary."
+msgstr ""
+
+#: builtin/remote.c:702
+#, c-format
+msgid "deleting '%s' failed"
+msgstr ""
+
+#: builtin/remote.c:736
+#, c-format
+msgid "creating '%s' failed"
+msgstr ""
+
+#: builtin/remote.c:802
+msgid ""
+"Note: A branch outside the refs/remotes/ hierarchy was not removed;\n"
+"to delete it, use:"
+msgid_plural ""
+"Note: Some branches outside the refs/remotes/ hierarchy were not removed;\n"
+"to delete them, use:"
+msgstr[0] ""
+"Σημείωση: Ένας κλάδος εκτός της ιεραρχίας refs/remotes/ hierarchy δεν "
+"αφαιρέθηκε,\n"
+"για να τον διαγράψετε, χρησιμοποιήστε:"
+msgstr[1] ""
+"Σημείωση: Κάποιοι κλάδοι εκτός της ιεραρχίας refs/remotes/ hierarchy δεν "
+"αφαιρέθηκαν,\n"
+"για να τους διαγράψετε, χρησιμοποιήστε:"
+
+#: builtin/remote.c:816
+#, c-format
+msgid "Could not remove config section '%s'"
+msgstr ""
+
+#: builtin/remote.c:917
+#, c-format
+msgid " new (next fetch will store in remotes/%s)"
+msgstr " νέο (η επόμενη ανάκτηση θα αποθηκεύσει μέσα στο remotes/%s)"
+
+#: builtin/remote.c:920
+msgid " tracked"
+msgstr ""
+
+#: builtin/remote.c:922
+msgid " stale (use 'git remote prune' to remove)"
+msgstr ""
+
+#: builtin/remote.c:924
+msgid " ???"
+msgstr " ;;;"
+
+#: builtin/remote.c:965
+#, c-format
+msgid "invalid branch.%s.merge; cannot rebase onto > 1 branch"
+msgstr ""
+
+#: builtin/remote.c:974
+#, c-format
+msgid "rebases interactively onto remote %s"
+msgstr ""
+
+#: builtin/remote.c:976
+#, c-format
+msgid "rebases interactively (with merges) onto remote %s"
+msgstr ""
+
+#: builtin/remote.c:979
+#, c-format
+msgid "rebases onto remote %s"
+msgstr ""
+
+#: builtin/remote.c:983
+#, c-format
+msgid " merges with remote %s"
+msgstr ""
+
+#: builtin/remote.c:986
+#, c-format
+msgid "merges with remote %s"
+msgstr ""
+
+#: builtin/remote.c:989
+#, c-format
+msgid "%-*s    and with remote %s\n"
+msgstr ""
+
+#: builtin/remote.c:1032
+msgid "create"
+msgstr ""
+
+#: builtin/remote.c:1035
+msgid "delete"
+msgstr ""
+
+#: builtin/remote.c:1039
+msgid "up to date"
+msgstr "πλήρως ενήμερο"
+
+#: builtin/remote.c:1042
+msgid "fast-forwardable"
+msgstr ""
+
+#: builtin/remote.c:1045
+msgid "local out of date"
+msgstr ""
+
+#: builtin/remote.c:1052
+#, c-format
+msgid "    %-*s forces to %-*s (%s)"
+msgstr ""
+
+#: builtin/remote.c:1055
+#, c-format
+msgid "    %-*s pushes to %-*s (%s)"
+msgstr ""
+
+#: builtin/remote.c:1059
+#, c-format
+msgid "    %-*s forces to %s"
+msgstr ""
+
+#: builtin/remote.c:1062
+#, c-format
+msgid "    %-*s pushes to %s"
+msgstr ""
+
+#: builtin/remote.c:1130
+msgid "do not query remotes"
+msgstr ""
+
+#: builtin/remote.c:1157
+#, c-format
+msgid "* remote %s"
+msgstr ""
+
+#: builtin/remote.c:1158
+#, c-format
+msgid "  Fetch URL: %s"
+msgstr "  URL  ανάκτησης: %s"
+
+#: builtin/remote.c:1159 builtin/remote.c:1175 builtin/remote.c:1314
+msgid "(no URL)"
+msgstr "(κανένα URL)"
+
+#. TRANSLATORS: the colon ':' should align
+#. with the one in " Fetch URL: %s"
+#. translation.
+#.
+#: builtin/remote.c:1173 builtin/remote.c:1175
+#, c-format
+msgid "  Push  URL: %s"
+msgstr "  URL  δημοσίευσης: %s"
+
+#: builtin/remote.c:1177 builtin/remote.c:1179 builtin/remote.c:1181
+#, c-format
+msgid "  HEAD branch: %s"
+msgstr ""
+
+#: builtin/remote.c:1177
+msgid "(not queried)"
+msgstr ""
+
+#: builtin/remote.c:1179
+msgid "(unknown)"
+msgstr ""
+
+#: builtin/remote.c:1183
+#, c-format
+msgid ""
+"  HEAD branch (remote HEAD is ambiguous, may be one of the following):\n"
+msgstr ""
+
+#: builtin/remote.c:1195
+#, c-format
+msgid "  Remote branch:%s"
+msgid_plural "  Remote branches:%s"
+msgstr[0] "  Απομακρυσμένος κλάδος:%s"
+msgstr[1] "  Απομακρυσμένοι κλάδοι:%s"
+
+#: builtin/remote.c:1198 builtin/remote.c:1224
+msgid " (status not queried)"
+msgstr ""
+
+#: builtin/remote.c:1207
+msgid "  Local branch configured for 'git pull':"
+msgid_plural "  Local branches configured for 'git pull':"
+msgstr[0] ""
+msgstr[1] ""
+
+#: builtin/remote.c:1215
+msgid "  Local refs will be mirrored by 'git push'"
+msgstr ""
+
+#: builtin/remote.c:1221
+#, c-format
+msgid "  Local ref configured for 'git push'%s:"
+msgid_plural "  Local refs configured for 'git push'%s:"
+msgstr[0] ""
+msgstr[1] ""
+
+#: builtin/remote.c:1242
+msgid "set refs/remotes/<name>/HEAD according to remote"
+msgstr ""
+
+#: builtin/remote.c:1244
+msgid "delete refs/remotes/<name>/HEAD"
+msgstr ""
+
+#: builtin/remote.c:1259
+msgid "Cannot determine remote HEAD"
+msgstr ""
+
+#: builtin/remote.c:1261
+msgid "Multiple remote HEAD branches. Please choose one explicitly with:"
+msgstr ""
+
+#: builtin/remote.c:1271
+#, c-format
+msgid "Could not delete %s"
+msgstr ""
+
+#: builtin/remote.c:1279
+#, c-format
+msgid "Not a valid ref: %s"
+msgstr "Δεν είναι έγκυρο ref: %s"
+
+#: builtin/remote.c:1281
+#, c-format
+msgid "Could not setup %s"
+msgstr ""
+
+#: builtin/remote.c:1299
+#, c-format
+msgid " %s will become dangling!"
+msgstr " το %s θα μείνει εκκρεμές!"
+
+#: builtin/remote.c:1300
+#, c-format
+msgid " %s has become dangling!"
+msgstr ""
+
+#: builtin/remote.c:1310
+#, c-format
+msgid "Pruning %s"
+msgstr ""
+
+#: builtin/remote.c:1311
+#, c-format
+msgid "URL: %s"
+msgstr "URL: %s"
+
+#: builtin/remote.c:1327
+#, c-format
+msgid " * [would prune] %s"
+msgstr " * [θα κλάδευε το] %s"
+
+#: builtin/remote.c:1330
+#, c-format
+msgid " * [pruned] %s"
+msgstr " * [κλαδεμένο] %s"
+
+#: builtin/remote.c:1375
+msgid "prune remotes after fetching"
+msgstr ""
+
+#: builtin/remote.c:1438 builtin/remote.c:1492 builtin/remote.c:1560
+#, c-format
+msgid "No such remote '%s'"
+msgstr "Δεν υπάρχει τέτοιος απομακρυσμένος εξυπηρετητής '%s'"
+
+#: builtin/remote.c:1454
+msgid "add branch"
+msgstr ""
+
+#: builtin/remote.c:1461
+msgid "no remote specified"
+msgstr ""
+
+#: builtin/remote.c:1478
+msgid "query push URLs rather than fetch URLs"
+msgstr ""
+
+#: builtin/remote.c:1480
+msgid "return all URLs"
+msgstr ""
+
+#: builtin/remote.c:1508
+#, c-format
+msgid "no URLs configured for remote '%s'"
+msgstr ""
+
+#: builtin/remote.c:1534
+msgid "manipulate push URLs"
+msgstr ""
+
+#: builtin/remote.c:1536
+msgid "add URL"
+msgstr ""
+
+#: builtin/remote.c:1538
+msgid "delete URLs"
+msgstr ""
+
+#: builtin/remote.c:1545
+msgid "--add --delete doesn't make sense"
+msgstr ""
+
+#: builtin/remote.c:1584
+#, c-format
+msgid "Invalid old URL pattern: %s"
+msgstr ""
+
+#: builtin/remote.c:1592
+#, c-format
+msgid "No such URL found: %s"
+msgstr "Δε βρέθηκε τέτοιο URL: %s"
+
+#: builtin/remote.c:1594
+msgid "Will not delete all non-push URLs"
+msgstr ""
+
+#: builtin/remote.c:1610
+msgid "be verbose; must be placed before a subcommand"
+msgstr ""
+
+#: builtin/remote.c:1641
+#, c-format
+msgid "Unknown subcommand: %s"
+msgstr ""
+
+#: builtin/repack.c:22
+msgid "git repack [<options>]"
+msgstr ""
+
+#: builtin/repack.c:27
+msgid ""
+"Incremental repacks are incompatible with bitmap indexes.  Use\n"
+"--no-write-bitmap-index or disable the pack.writebitmaps configuration."
+msgstr ""
+
+#: builtin/repack.c:200
+msgid "could not start pack-objects to repack promisor objects"
+msgstr ""
+
+#: builtin/repack.c:239 builtin/repack.c:411
+msgid "repack: Expecting full hex object ID lines only from pack-objects."
+msgstr ""
+
+#: builtin/repack.c:256
+msgid "could not finish pack-objects to repack promisor objects"
+msgstr ""
+
+#: builtin/repack.c:294
+msgid "pack everything in a single pack"
+msgstr ""
+
+#: builtin/repack.c:296
+msgid "same as -a, and turn unreachable objects loose"
+msgstr ""
+
+#: builtin/repack.c:299
+msgid "remove redundant packs, and run git-prune-packed"
+msgstr ""
+
+#: builtin/repack.c:301
+msgid "pass --no-reuse-delta to git-pack-objects"
+msgstr ""
+
+#: builtin/repack.c:303
+msgid "pass --no-reuse-object to git-pack-objects"
+msgstr ""
+
+#: builtin/repack.c:305
+msgid "do not run git-update-server-info"
+msgstr ""
+
+#: builtin/repack.c:308
+msgid "pass --local to git-pack-objects"
+msgstr ""
+
+#: builtin/repack.c:310
+msgid "write bitmap index"
+msgstr ""
+
+#: builtin/repack.c:312
+msgid "pass --delta-islands to git-pack-objects"
+msgstr ""
+
+#: builtin/repack.c:313
+msgid "approxidate"
+msgstr ""
+
+#: builtin/repack.c:314
+msgid "with -A, do not loosen objects older than this"
+msgstr ""
+
+#: builtin/repack.c:316
+msgid "with -a, repack unreachable objects"
+msgstr ""
+
+#: builtin/repack.c:318
+msgid "size of the window used for delta compression"
+msgstr ""
+
+#: builtin/repack.c:319 builtin/repack.c:325
+msgid "bytes"
+msgstr ""
+
+#: builtin/repack.c:320
+msgid "same as the above, but limit memory size instead of entries count"
+msgstr ""
+
+#: builtin/repack.c:322
+msgid "limits the maximum delta depth"
+msgstr ""
+
+#: builtin/repack.c:324
+msgid "limits the maximum number of threads"
+msgstr ""
+
+#: builtin/repack.c:326
+msgid "maximum size of each packfile"
+msgstr ""
+
+#: builtin/repack.c:328
+msgid "repack objects in packs marked with .keep"
+msgstr ""
+
+#: builtin/repack.c:330
+msgid "do not repack this pack"
+msgstr ""
+
+#: builtin/repack.c:340
+msgid "cannot delete packs in a precious-objects repo"
+msgstr ""
+
+#: builtin/repack.c:344
+msgid "--keep-unreachable and -A are incompatible"
+msgstr ""
+
+#: builtin/repack.c:420
+msgid "Nothing new to pack."
+msgstr ""
+
+#: builtin/repack.c:481
+#, c-format
+msgid ""
+"WARNING: Some packs in use have been renamed by\n"
+"WARNING: prefixing old- to their name, in order to\n"
+"WARNING: replace them with the new version of the\n"
+"WARNING: file.  But the operation failed, and the\n"
+"WARNING: attempt to rename them back to their\n"
+"WARNING: original names also failed.\n"
+"WARNING: Please rename them in %s manually:\n"
+msgstr ""
+
+#: builtin/repack.c:529
+#, c-format
+msgid "failed to remove '%s'"
+msgstr ""
+
+#: builtin/replace.c:22
+msgid "git replace [-f] <object> <replacement>"
+msgstr ""
+
+#: builtin/replace.c:23
+msgid "git replace [-f] --edit <object>"
+msgstr ""
+
+#: builtin/replace.c:24
+msgid "git replace [-f] --graft <commit> [<parent>...]"
+msgstr ""
+
+#: builtin/replace.c:25
+msgid "git replace [-f] --convert-graft-file"
+msgstr ""
+
+#: builtin/replace.c:26
+msgid "git replace -d <object>..."
+msgstr ""
+
+#: builtin/replace.c:27
+msgid "git replace [--format=<format>] [-l [<pattern>]]"
+msgstr ""
+
+#: builtin/replace.c:58 builtin/replace.c:203 builtin/replace.c:206
+#, c-format
+msgid "failed to resolve '%s' as a valid ref"
+msgstr "απέτυχε η ταύτιση του '%s' με κάποιο έγκυρο ref"
+
+#: builtin/replace.c:86
+#, c-format
+msgid ""
+"invalid replace format '%s'\n"
+"valid formats are 'short', 'medium' and 'long'"
+msgstr ""
+
+#: builtin/replace.c:121
+#, c-format
+msgid "replace ref '%s' not found"
+msgstr ""
+
+#: builtin/replace.c:137
+#, c-format
+msgid "Deleted replace ref '%s'"
+msgstr ""
+
+#: builtin/replace.c:149
+#, c-format
+msgid "'%s' is not a valid ref name"
+msgstr ""
+
+#: builtin/replace.c:154
+#, c-format
+msgid "replace ref '%s' already exists"
+msgstr ""
+
+#: builtin/replace.c:174
+#, c-format
+msgid ""
+"Objects must be of the same type.\n"
+"'%s' points to a replaced object of type '%s'\n"
+"while '%s' points to a replacement object of type '%s'."
+msgstr ""
+
+#: builtin/replace.c:225
+#, c-format
+msgid "unable to open %s for writing"
+msgstr ""
+
+#: builtin/replace.c:238
+msgid "cat-file reported failure"
+msgstr ""
+
+#: builtin/replace.c:254
+#, c-format
+msgid "unable to open %s for reading"
+msgstr ""
+
+#: builtin/replace.c:268
+msgid "unable to spawn mktree"
+msgstr ""
+
+#: builtin/replace.c:272
+msgid "unable to read from mktree"
+msgstr ""
+
+#: builtin/replace.c:281
+msgid "mktree reported failure"
+msgstr ""
+
+#: builtin/replace.c:285
+msgid "mktree did not return an object name"
+msgstr ""
+
+#: builtin/replace.c:294
+#, c-format
+msgid "unable to fstat %s"
+msgstr ""
+
+#: builtin/replace.c:299
+msgid "unable to write object to database"
+msgstr ""
+
+#: builtin/replace.c:318 builtin/replace.c:371 builtin/replace.c:415
+#: builtin/replace.c:445
+#, c-format
+msgid "not a valid object name: '%s'"
+msgstr "μη έγκυρο όνομα αντικειμένου: '%s'"
+
+#: builtin/replace.c:322
+#, c-format
+msgid "unable to get object type for %s"
+msgstr ""
+
+#: builtin/replace.c:338
+msgid "editing object file failed"
+msgstr ""
+
+#: builtin/replace.c:347
+#, c-format
+msgid "new object is the same as the old one: '%s'"
+msgstr "το νέο αντικείμενο είναι ίδιο με το παλιό: '%s'"
+
+#: builtin/replace.c:407
+#, c-format
+msgid "bad mergetag in commit '%s'"
+msgstr ""
+
+#: builtin/replace.c:409
+#, c-format
+msgid "malformed mergetag in commit '%s'"
+msgstr ""
+
+#: builtin/replace.c:421
+#, c-format
+msgid ""
+"original commit '%s' contains mergetag '%s' that is discarded; use --edit "
+"instead of --graft"
+msgstr ""
+
+#: builtin/replace.c:460
+#, c-format
+msgid "the original commit '%s' has a gpg signature"
+msgstr ""
+
+#: builtin/replace.c:461
+msgid "the signature will be removed in the replacement commit!"
+msgstr ""
+
+#: builtin/replace.c:471
+#, c-format
+msgid "could not write replacement commit for: '%s'"
+msgstr ""
+
+#: builtin/replace.c:479
+#, c-format
+msgid "graft for '%s' unnecessary"
+msgstr ""
+
+#: builtin/replace.c:482
+#, c-format
+msgid "new commit is the same as the old one: '%s'"
+msgstr "η νέα υποβολή είναι ίδια με την παλιά: '%s'"
+
+#: builtin/replace.c:515
+#, c-format
+msgid ""
+"could not convert the following graft(s):\n"
+"%s"
+msgstr ""
+
+#: builtin/replace.c:536
+msgid "list replace refs"
+msgstr ""
+
+#: builtin/replace.c:537
+msgid "delete replace refs"
+msgstr ""
+
+#: builtin/replace.c:538
+msgid "edit existing object"
+msgstr ""
+
+#: builtin/replace.c:539
+msgid "change a commit's parents"
+msgstr ""
+
+#: builtin/replace.c:540
+msgid "convert existing graft file"
+msgstr ""
+
+#: builtin/replace.c:541
+msgid "replace the ref if it exists"
+msgstr ""
+
+#: builtin/replace.c:543
+msgid "do not pretty-print contents for --edit"
+msgstr ""
+
+#: builtin/replace.c:544
+msgid "use this format"
+msgstr ""
+
+#: builtin/replace.c:557
+msgid "--format cannot be used when not listing"
+msgstr ""
+
+#: builtin/replace.c:565
+msgid "-f only makes sense when writing a replacement"
+msgstr ""
+
+#: builtin/replace.c:569
+msgid "--raw only makes sense with --edit"
+msgstr ""
+
+#: builtin/replace.c:575
+msgid "-d needs at least one argument"
+msgstr ""
+
+#: builtin/replace.c:581
+msgid "bad number of arguments"
+msgstr ""
+
+#: builtin/replace.c:587
+msgid "-e needs exactly one argument"
+msgstr ""
+
+#: builtin/replace.c:593
+msgid "-g needs at least one argument"
+msgstr ""
+
+#: builtin/replace.c:599
+msgid "--convert-graft-file takes no argument"
+msgstr ""
+
+#: builtin/replace.c:605
+msgid "only one pattern can be given with -l"
+msgstr ""
+
+#: builtin/rerere.c:13
+msgid "git rerere [clear | forget <path>... | status | remaining | diff | gc]"
+msgstr ""
+
+#: builtin/rerere.c:60
+msgid "register clean resolutions in index"
+msgstr ""
+
+#: builtin/rerere.c:79
+msgid "'git rerere forget' without paths is deprecated"
+msgstr ""
+
+#: builtin/rerere.c:113
+#, c-format
+msgid "unable to generate diff for '%s'"
+msgstr ""
+
+#: builtin/reset.c:32
+msgid ""
+"git reset [--mixed | --soft | --hard | --merge | --keep] [-q] [<commit>]"
+msgstr ""
+"git reset [--mixed | --soft | --hard | --merge | --keep] [-q] [<υποβολή>]"
+
+#: builtin/reset.c:33
+msgid "git reset [-q] [<tree-ish>] [--] <paths>..."
+msgstr "git reset [-q] [<δέντρο ή φαινομενικό>] [--] <διαδρομές>..."
+
+#: builtin/reset.c:34
+msgid "git reset --patch [<tree-ish>] [--] [<paths>...]"
+msgstr "git reset --patch [<δέντρο ή φαινομενικό>] [--] [<διαδρομές>...]"
+
+#: builtin/reset.c:40
+msgid "mixed"
+msgstr "mixed"
+
+#: builtin/reset.c:40
+msgid "soft"
+msgstr "soft"
+
+#: builtin/reset.c:40
+msgid "hard"
+msgstr "hard"
+
+#: builtin/reset.c:40
+msgid "merge"
+msgstr "συγχώνευση"
+
+#: builtin/reset.c:40
+msgid "keep"
+msgstr "διατήρηση"
+
+#: builtin/reset.c:81
+msgid "You do not have a valid HEAD."
+msgstr "Δεν έχετε έγκυρο HEAD."
+
+#: builtin/reset.c:83
+msgid "Failed to find tree of HEAD."
+msgstr "Δεν ήταν δυνατό να βρεθεί το δέντρο του HEAD."
+
+#: builtin/reset.c:89
+#, c-format
+msgid "Failed to find tree of %s."
+msgstr "Δεν ήταν δυνατό να βρεθεί το δέντρο του %s."
+
+#: builtin/reset.c:193
+#, c-format
+msgid "Cannot do a %s reset in the middle of a merge."
+msgstr "Δεν είναι δυνατό να γίνει επαναφορά %s στη μέση μιας συγχώνευσης."
+
+#: builtin/reset.c:293
+msgid "be quiet, only report errors"
+msgstr "σιωπηλή λειτουργία, αναφορά μόνο σφαλμάτων"
+
+#: builtin/reset.c:295
+msgid "reset HEAD and index"
+msgstr "επαναφορά HEAD και ευρετηρίου"
+
+#: builtin/reset.c:296
+msgid "reset only HEAD"
+msgstr "επαναφορά μόνο HEAD"
+
+#: builtin/reset.c:298 builtin/reset.c:300
+msgid "reset HEAD, index and working tree"
+msgstr "επαναφορά HEAD, ευρετηρίου και δέντρου εργασίας"
+
+#: builtin/reset.c:302
+msgid "reset HEAD but keep local changes"
+msgstr "επαναφορά HEAD αλλά διατήρηση τοπικών αλλαγών"
+
+#: builtin/reset.c:308
+msgid "record only the fact that removed paths will be added later"
+msgstr ""
+"καταγραφή μόνο του γεγονότος ότι οι αφαιρεθείσες διαδρομές θα προστεθούν "
+"αργότερα"
+
+#: builtin/reset.c:326
+#, c-format
+msgid "Failed to resolve '%s' as a valid revision."
+msgstr "Απέτυχε η ταύτιση του '%s' με κάποια έγκυρη έκδοση."
+
+#: builtin/reset.c:334
+#, c-format
+msgid "Failed to resolve '%s' as a valid tree."
+msgstr "Απέτυχε η ταύτιση του '%s' με κάποιο έγκυρο δέντρο."
+
+#: builtin/reset.c:343
+msgid "--patch is incompatible with --{hard,mixed,soft}"
+msgstr "το --patch είναι ασύμβατο με --{hard,mixed,soft}"
+
+#: builtin/reset.c:352
+msgid "--mixed with paths is deprecated; use 'git reset -- <paths>' instead."
+msgstr ""
+"το --mixed με διαδρομές έχει καταργηθεί, χρησιμοποιήστε αντί αυτού 'git "
+"reset -- <διαδρομές>'."
+
+#: builtin/reset.c:354
+#, c-format
+msgid "Cannot do %s reset with paths."
+msgstr "Δεν είναι δυνατή η επαναφορά %s με διαδρομές."
+
+#: builtin/reset.c:364
+#, c-format
+msgid "%s reset is not allowed in a bare repository"
+msgstr "η επαναφορά %s δεν επιτρέπεται σε γυμνό αποθετήριο"
+
+#: builtin/reset.c:368
+msgid "-N can only be used with --mixed"
+msgstr "το -N μπορεί να χρησιμοποιηθεί μόνο με το --mixed"
+
+#: builtin/reset.c:388
+msgid "Unstaged changes after reset:"
+msgstr "Μη προετοιμασμένες αλλαγές μετά την επαναφορά:"
+
+#: builtin/reset.c:391
+#, c-format
+msgid ""
+"\n"
+"It took %.2f seconds to enumerate unstaged changes after reset.  You can\n"
+"use '--quiet' to avoid this.  Set the config setting reset.quiet to true\n"
+"to make this the default.\n"
+msgstr ""
+"\n"
+"Η απαρίθμηση μη προετοιμασμένων αλλαγών μετά την επαναφορά πήρε %.2f "
+"δευτερόλεπτα.  Μπορείτε να\n"
+"χρησιμοποιήσετε το '--quiet' για να το αποφύγετε αυτό.  Αλλάξτε την επιλογή "
+"ρύθμισης reset.quiet σε true\n"
+"για να το κάνετε προεπιλεγμένο.\n"
+
+#: builtin/reset.c:401
+#, c-format
+msgid "Could not reset index file to revision '%s'."
+msgstr "Δεν ήταν δυνατή η επαναφορά του αρχείου ευρετηρίου στην έκδοση '%s'."
+
+#: builtin/reset.c:405
+msgid "Could not write new index file."
+msgstr "Δεν ήταν δυνατή η εγγραφή του νέου αρχείου ευρετηρίου."
+
+#: builtin/rev-list.c:406
+msgid "cannot combine --exclude-promisor-objects and --missing"
+msgstr ""
+
+#: builtin/rev-list.c:464
+msgid "object filtering requires --objects"
+msgstr ""
+
+#: builtin/rev-list.c:467
+#, c-format
+msgid "invalid sparse value '%s'"
+msgstr ""
+
+#: builtin/rev-list.c:508
+msgid "rev-list does not support display of notes"
+msgstr ""
+
+#: builtin/rev-list.c:511
+msgid "cannot combine --use-bitmap-index with object filtering"
+msgstr ""
+
+#: builtin/rev-parse.c:408
+msgid "git rev-parse --parseopt [<options>] -- [<args>...]"
+msgstr ""
+
+#: builtin/rev-parse.c:413
+msgid "keep the `--` passed as an arg"
+msgstr ""
+
+#: builtin/rev-parse.c:415
+msgid "stop parsing after the first non-option argument"
+msgstr ""
+
+#: builtin/rev-parse.c:418
+msgid "output in stuck long form"
+msgstr ""
+
+#: builtin/rev-parse.c:551
+msgid ""
+"git rev-parse --parseopt [<options>] -- [<args>...]\n"
+"   or: git rev-parse --sq-quote [<arg>...]\n"
+"   or: git rev-parse [<options>] [<arg>...]\n"
+"\n"
+"Run \"git rev-parse --parseopt -h\" for more information on the first usage."
+msgstr ""
+
+#: builtin/revert.c:24
+msgid "git revert [<options>] <commit-ish>..."
+msgstr ""
+
+#: builtin/revert.c:25
+msgid "git revert <subcommand>"
+msgstr "git revert <υποεντολή>"
+
+#: builtin/revert.c:30
+msgid "git cherry-pick [<options>] <commit-ish>..."
+msgstr "git cherry-pick [<επιλογές>] <υποβολή ή φαινομενική>..."
+
+#: builtin/revert.c:31
+msgid "git cherry-pick <subcommand>"
+msgstr "git cherry-pick <υποεντολή>"
+
+#: builtin/revert.c:72
+#, c-format
+msgid "option `%s' expects a number greater than zero"
+msgstr ""
+
+#: builtin/revert.c:92
+#, c-format
+msgid "%s: %s cannot be used with %s"
+msgstr ""
+
+#: builtin/revert.c:101
+msgid "end revert or cherry-pick sequence"
+msgstr ""
+
+#: builtin/revert.c:102
+msgid "resume revert or cherry-pick sequence"
+msgstr ""
+
+#: builtin/revert.c:103
+msgid "cancel revert or cherry-pick sequence"
+msgstr ""
+
+#: builtin/revert.c:104
+msgid "don't automatically commit"
+msgstr ""
+
+#: builtin/revert.c:105
+msgid "edit the commit message"
+msgstr ""
+
+#: builtin/revert.c:108
+msgid "parent-number"
+msgstr ""
+
+#: builtin/revert.c:109
+msgid "select mainline parent"
+msgstr ""
+
+#: builtin/revert.c:111
+msgid "merge strategy"
+msgstr ""
+
+#: builtin/revert.c:113
+msgid "option for merge strategy"
+msgstr ""
+
+#: builtin/revert.c:122
+msgid "append commit name"
+msgstr ""
+
+#: builtin/revert.c:124
+msgid "preserve initially empty commits"
+msgstr ""
+
+#: builtin/revert.c:126
+msgid "keep redundant, empty commits"
+msgstr ""
+
+#: builtin/revert.c:220
+msgid "revert failed"
+msgstr ""
+
+#: builtin/revert.c:233
+msgid "cherry-pick failed"
+msgstr ""
+
+#: builtin/rm.c:19
+msgid "git rm [<options>] [--] <file>..."
+msgstr "git rm [<επιλογές>] [--] <αρχείο>..."
+
+#: builtin/rm.c:207
+msgid ""
+"the following file has staged content different from both the\n"
+"file and the HEAD:"
+msgid_plural ""
+"the following files have staged content different from both the\n"
+"file and the HEAD:"
+msgstr[0] ""
+msgstr[1] ""
+
+#: builtin/rm.c:212
+msgid ""
+"\n"
+"(use -f to force removal)"
+msgstr ""
+"\n"
+"(χρησιμοποιήστε το -f για να εξαναγκάσετε την αφαίρεση)"
+
+#: builtin/rm.c:216
+msgid "the following file has changes staged in the index:"
+msgid_plural "the following files have changes staged in the index:"
+msgstr[0] ""
+msgstr[1] ""
+
+#: builtin/rm.c:220 builtin/rm.c:229
+msgid ""
+"\n"
+"(use --cached to keep the file, or -f to force removal)"
+msgstr ""
+
+#: builtin/rm.c:226
+msgid "the following file has local modifications:"
+msgid_plural "the following files have local modifications:"
+msgstr[0] ""
+msgstr[1] ""
+
+#: builtin/rm.c:242
+msgid "do not list removed files"
+msgstr ""
+
+#: builtin/rm.c:243
+msgid "only remove from the index"
+msgstr ""
+
+#: builtin/rm.c:244
+msgid "override the up-to-date check"
+msgstr ""
+
+#: builtin/rm.c:245
+msgid "allow recursive removal"
+msgstr ""
+
+#: builtin/rm.c:247
+msgid "exit with a zero status even if nothing matched"
+msgstr ""
+
+#: builtin/rm.c:289
+msgid "please stage your changes to .gitmodules or stash them to proceed"
+msgstr ""
+
+#: builtin/rm.c:307
+#, c-format
+msgid "not removing '%s' recursively without -r"
+msgstr ""
+
+#: builtin/rm.c:346
+#, c-format
+msgid "git rm: unable to remove %s"
+msgstr ""
+
+#: builtin/send-pack.c:20
+msgid ""
+"git send-pack [--all | --mirror] [--dry-run] [--force] [--receive-pack=<git-"
+"receive-pack>] [--verbose] [--thin] [--atomic] [<host>:]<directory> "
+"[<ref>...]\n"
+"  --all and explicit <ref> specification are mutually exclusive."
+msgstr ""
+
+#: builtin/send-pack.c:163
+msgid "remote name"
+msgstr ""
+
+#: builtin/send-pack.c:177
+msgid "use stateless RPC protocol"
+msgstr ""
+
+#: builtin/send-pack.c:178
+msgid "read refs from stdin"
+msgstr ""
+
+#: builtin/send-pack.c:179
+msgid "print status from remote helper"
+msgstr ""
+
+#: builtin/serve.c:7
+msgid "git serve [<options>]"
+msgstr ""
+
+#: builtin/serve.c:17 builtin/upload-pack.c:23
+msgid "quit after a single request/response exchange"
+msgstr ""
+
+#: builtin/serve.c:19
+msgid "exit immediately after advertising capabilities"
+msgstr ""
+
+#: builtin/shortlog.c:14
+msgid "git shortlog [<options>] [<revision-range>] [[--] <path>...]"
+msgstr ""
+
+#: builtin/shortlog.c:15
+msgid "git log --pretty=short | git shortlog [<options>]"
+msgstr "git log --pretty=short | git shortlog [<επιλογές>]"
+
+#: builtin/shortlog.c:264
+msgid "Group by committer rather than author"
+msgstr ""
+
+#: builtin/shortlog.c:266
+msgid "sort output according to the number of commits per author"
+msgstr ""
+
+#: builtin/shortlog.c:268
+msgid "Suppress commit descriptions, only provides commit count"
+msgstr ""
+
+#: builtin/shortlog.c:270
+msgid "Show the email address of each author"
+msgstr ""
+
+#: builtin/shortlog.c:271
+msgid "<w>[,<i1>[,<i2>]]"
+msgstr "<w>[,<i1>[,<i2>]]"
+
+#: builtin/shortlog.c:272
+msgid "Linewrap output"
+msgstr ""
+
+#: builtin/shortlog.c:301
+msgid "too many arguments given outside repository"
+msgstr ""
+
+#: builtin/show-branch.c:13
+msgid ""
+"git show-branch [-a | --all] [-r | --remotes] [--topo-order | --date-order]\n"
+"\t\t[--current] [--color[=<when>] | --no-color] [--sparse]\n"
+"\t\t[--more=<n> | --list | --independent | --merge-base]\n"
+"\t\t[--no-name | --sha1-name] [--topics] [(<rev> | <glob>)...]"
+msgstr ""
+
+#: builtin/show-branch.c:17
+msgid "git show-branch (-g | --reflog)[=<n>[,<base>]] [--list] [<ref>]"
+msgstr ""
+
+#: builtin/show-branch.c:395
+#, c-format
+msgid "ignoring %s; cannot handle more than %d ref"
+msgid_plural "ignoring %s; cannot handle more than %d refs"
+msgstr[0] ""
+msgstr[1] ""
+
+#: builtin/show-branch.c:549
+#, c-format
+msgid "no matching refs with %s"
+msgstr ""
+
+#: builtin/show-branch.c:646
+msgid "show remote-tracking and local branches"
+msgstr ""
+
+#: builtin/show-branch.c:648
+msgid "show remote-tracking branches"
+msgstr ""
+
+#: builtin/show-branch.c:650
+msgid "color '*!+-' corresponding to the branch"
+msgstr ""
+
+#: builtin/show-branch.c:652
+msgid "show <n> more commits after the common ancestor"
+msgstr ""
+
+#: builtin/show-branch.c:654
+msgid "synonym to more=-1"
+msgstr ""
+
+#: builtin/show-branch.c:655
+msgid "suppress naming strings"
+msgstr ""
+
+#: builtin/show-branch.c:657
+msgid "include the current branch"
+msgstr ""
+
+#: builtin/show-branch.c:659
+msgid "name commits with their object names"
+msgstr ""
+
+#: builtin/show-branch.c:661
+msgid "show possible merge bases"
+msgstr ""
+
+#: builtin/show-branch.c:663
+msgid "show refs unreachable from any other ref"
+msgstr ""
+
+#: builtin/show-branch.c:665
+msgid "show commits in topological order"
+msgstr ""
+
+#: builtin/show-branch.c:668
+msgid "show only commits not on the first branch"
+msgstr ""
+
+#: builtin/show-branch.c:670
+msgid "show merges reachable from only one tip"
+msgstr ""
+
+#: builtin/show-branch.c:672
+msgid "topologically sort, maintaining date order where possible"
+msgstr ""
+
+#: builtin/show-branch.c:675
+msgid "<n>[,<base>]"
+msgstr ""
+
+#: builtin/show-branch.c:676
+msgid "show <n> most recent ref-log entries starting at base"
+msgstr ""
+
+#: builtin/show-branch.c:712
+msgid ""
+"--reflog is incompatible with --all, --remotes, --independent or --merge-base"
+msgstr ""
+
+#: builtin/show-branch.c:736
+msgid "no branches given, and HEAD is not valid"
+msgstr "δε δόθηκαν κλάδοι, και το HEAD δεν είναι έγκυρο"
+
+#: builtin/show-branch.c:739
+msgid "--reflog option needs one branch name"
+msgstr ""
+
+#: builtin/show-branch.c:742
+#, c-format
+msgid "only %d entry can be shown at one time."
+msgid_plural "only %d entries can be shown at one time."
+msgstr[0] ""
+msgstr[1] ""
+
+#: builtin/show-branch.c:746
+#, c-format
+msgid "no such ref %s"
+msgstr "δεν υπάρχει ref %s"
+
+#: builtin/show-branch.c:830
+#, c-format
+msgid "cannot handle more than %d rev."
+msgid_plural "cannot handle more than %d revs."
+msgstr[0] ""
+msgstr[1] ""
+
+#: builtin/show-branch.c:834
+#, c-format
+msgid "'%s' is not a valid ref."
+msgstr ""
+
+#: builtin/show-branch.c:837
+#, c-format
+msgid "cannot find commit %s (%s)"
+msgstr ""
+
+#: builtin/show-ref.c:11
+msgid ""
+"git show-ref [-q | --quiet] [--verify] [--head] [-d | --dereference] [-s | --"
+"hash[=<n>]] [--abbrev[=<n>]] [--tags] [--heads] [--] [<pattern>...]"
+msgstr ""
+
+#: builtin/show-ref.c:12
+msgid "git show-ref --exclude-existing[=<pattern>]"
+msgstr ""
+
+#: builtin/show-ref.c:161
+msgid "only show tags (can be combined with heads)"
+msgstr ""
+
+#: builtin/show-ref.c:162
+msgid "only show heads (can be combined with tags)"
+msgstr ""
+
+#: builtin/show-ref.c:163
+msgid "stricter reference checking, requires exact ref path"
+msgstr ""
+
+#: builtin/show-ref.c:166 builtin/show-ref.c:168
+msgid "show the HEAD reference, even if it would be filtered out"
+msgstr ""
+
+#: builtin/show-ref.c:170
+msgid "dereference tags into object IDs"
+msgstr ""
+
+#: builtin/show-ref.c:172
+msgid "only show SHA1 hash using <n> digits"
+msgstr ""
+
+#: builtin/show-ref.c:176
+msgid "do not print results to stdout (useful with --verify)"
+msgstr ""
+
+#: builtin/show-ref.c:178
+msgid "show refs from stdin that aren't in local repository"
+msgstr ""
+
+#: builtin/stripspace.c:18
+msgid "git stripspace [-s | --strip-comments]"
+msgstr "git stripspace [-s | --strip-comments]"
+
+#: builtin/stripspace.c:19
+msgid "git stripspace [-c | --comment-lines]"
+msgstr "git stripspace [-c | --comment-lines]"
+
+#: builtin/stripspace.c:37
+msgid "skip and remove all lines starting with comment character"
+msgstr ""
+
+#: builtin/stripspace.c:40
+msgid "prepend comment character and space to each line"
+msgstr ""
+
+#: builtin/submodule--helper.c:45 builtin/submodule--helper.c:1943
+#, c-format
+msgid "Expecting a full ref name, got %s"
+msgstr ""
+
+#: builtin/submodule--helper.c:62
+msgid "submodule--helper print-default-remote takes no arguments"
+msgstr ""
+
+#: builtin/submodule--helper.c:100
+#, c-format
+msgid "cannot strip one component off url '%s'"
+msgstr ""
+
+#: builtin/submodule--helper.c:408 builtin/submodule--helper.c:1367
+msgid "alternative anchor for relative paths"
+msgstr ""
+
+#: builtin/submodule--helper.c:413
+msgid "git submodule--helper list [--prefix=<path>] [<path>...]"
+msgstr ""
+
+#: builtin/submodule--helper.c:470 builtin/submodule--helper.c:627
+#: builtin/submodule--helper.c:650
+#, c-format
+msgid "No url found for submodule path '%s' in .gitmodules"
+msgstr ""
+
+#: builtin/submodule--helper.c:522
+#, c-format
+msgid "Entering '%s'\n"
+msgstr ""
+
+#: builtin/submodule--helper.c:525
+#, c-format
+msgid ""
+"run_command returned non-zero status for %s\n"
+"."
+msgstr ""
+
+#: builtin/submodule--helper.c:546
+#, c-format
+msgid ""
+"run_command returned non-zero status while recursing in the nested "
+"submodules of %s\n"
+"."
+msgstr ""
+
+#: builtin/submodule--helper.c:562
+msgid "Suppress output of entering each submodule command"
+msgstr ""
+
+#: builtin/submodule--helper.c:564 builtin/submodule--helper.c:1049
+msgid "Recurse into nested submodules"
+msgstr ""
+
+#: builtin/submodule--helper.c:569
+msgid "git submodule--helper foreach [--quiet] [--recursive] <command>"
+msgstr ""
+
+#: builtin/submodule--helper.c:596
+#, c-format
+msgid ""
+"could not look up configuration '%s'. Assuming this repository is its own "
+"authoritative upstream."
+msgstr ""
+
+#: builtin/submodule--helper.c:664
+#, c-format
+msgid "Failed to register url for submodule path '%s'"
+msgstr ""
+
+#: builtin/submodule--helper.c:668
+#, c-format
+msgid "Submodule '%s' (%s) registered for path '%s'\n"
+msgstr ""
+
+#: builtin/submodule--helper.c:678
+#, c-format
+msgid "warning: command update mode suggested for submodule '%s'\n"
+msgstr ""
+
+#: builtin/submodule--helper.c:685
+#, c-format
+msgid "Failed to register update mode for submodule path '%s'"
+msgstr ""
+
+#: builtin/submodule--helper.c:707
+msgid "Suppress output for initializing a submodule"
+msgstr ""
+
+#: builtin/submodule--helper.c:712
+msgid "git submodule--helper init [<path>]"
+msgstr ""
+
+#: builtin/submodule--helper.c:784 builtin/submodule--helper.c:910
+#, c-format
+msgid "no submodule mapping found in .gitmodules for path '%s'"
+msgstr ""
+
+#: builtin/submodule--helper.c:823
+#, c-format
+msgid "could not resolve HEAD ref inside the submodule '%s'"
+msgstr "δεν ήταν δυνατή η ταύτιση του HEAD ref μέσα στην υποενότητα '%s'"
+
+#: builtin/submodule--helper.c:850 builtin/submodule--helper.c:1019
+#, c-format
+msgid "failed to recurse into submodule '%s'"
+msgstr "απέτυχε η αναδρομή μέσα στην υποενότητα '%s'"
+
+#: builtin/submodule--helper.c:874 builtin/submodule--helper.c:1185
+msgid "Suppress submodule status output"
+msgstr ""
+
+#: builtin/submodule--helper.c:875
+msgid ""
+"Use commit stored in the index instead of the one stored in the submodule "
+"HEAD"
+msgstr ""
+
+#: builtin/submodule--helper.c:876
+msgid "recurse into nested submodules"
+msgstr ""
+
+#: builtin/submodule--helper.c:881
+msgid "git submodule status [--quiet] [--cached] [--recursive] [<path>...]"
+msgstr ""
+
+#: builtin/submodule--helper.c:905
+msgid "git submodule--helper name <path>"
+msgstr ""
+
+#: builtin/submodule--helper.c:969
+#, c-format
+msgid "Synchronizing submodule url for '%s'\n"
+msgstr ""
+
+#: builtin/submodule--helper.c:975
+#, c-format
+msgid "failed to register url for submodule path '%s'"
+msgstr ""
+
+#: builtin/submodule--helper.c:989
+#, c-format
+msgid "failed to get the default remote for submodule '%s'"
+msgstr ""
+
+#: builtin/submodule--helper.c:1000
+#, c-format
+msgid "failed to update remote for submodule '%s'"
+msgstr ""
+
+#: builtin/submodule--helper.c:1047
+msgid "Suppress output of synchronizing submodule url"
+msgstr ""
+
+#: builtin/submodule--helper.c:1054
+msgid "git submodule--helper sync [--quiet] [--recursive] [<path>]"
+msgstr ""
+
+#: builtin/submodule--helper.c:1108
+#, c-format
+msgid ""
+"Submodule work tree '%s' contains a .git directory (use 'rm -rf' if you "
+"really want to remove it including all of its history)"
+msgstr ""
+
+#: builtin/submodule--helper.c:1120
+#, c-format
+msgid ""
+"Submodule work tree '%s' contains local modifications; use '-f' to discard "
+"them"
+msgstr ""
+
+#: builtin/submodule--helper.c:1128
+#, c-format
+msgid "Cleared directory '%s'\n"
+msgstr ""
+
+#: builtin/submodule--helper.c:1130
+#, c-format
+msgid "Could not remove submodule work tree '%s'\n"
+msgstr ""
+
+#: builtin/submodule--helper.c:1141
+#, c-format
+msgid "could not create empty submodule directory %s"
+msgstr ""
+
+#: builtin/submodule--helper.c:1157
+#, c-format
+msgid "Submodule '%s' (%s) unregistered for path '%s'\n"
+msgstr ""
+
+#: builtin/submodule--helper.c:1186
+msgid "Remove submodule working trees even if they contain local changes"
+msgstr ""
+
+#: builtin/submodule--helper.c:1187
+msgid "Unregister all submodules"
+msgstr ""
+
+#: builtin/submodule--helper.c:1192
+msgid ""
+"git submodule deinit [--quiet] [-f | --force] [--all | [--] [<path>...]]"
+msgstr ""
+
+#: builtin/submodule--helper.c:1206
+msgid "Use '--all' if you really want to deinitialize all submodules"
+msgstr ""
+
+#: builtin/submodule--helper.c:1301 builtin/submodule--helper.c:1304
+#, c-format
+msgid "submodule '%s' cannot add alternate: %s"
+msgstr ""
+
+#: builtin/submodule--helper.c:1340
+#, c-format
+msgid "Value '%s' for submodule.alternateErrorStrategy is not recognized"
+msgstr ""
+
+#: builtin/submodule--helper.c:1347
+#, c-format
+msgid "Value '%s' for submodule.alternateLocation is not recognized"
+msgstr ""
+
+#: builtin/submodule--helper.c:1370
+msgid "where the new submodule will be cloned to"
+msgstr ""
+
+#: builtin/submodule--helper.c:1373
+msgid "name of the new submodule"
+msgstr ""
+
+#: builtin/submodule--helper.c:1376
+msgid "url where to clone the submodule from"
+msgstr ""
+
+#: builtin/submodule--helper.c:1384
+msgid "depth for shallow clones"
+msgstr ""
+
+#: builtin/submodule--helper.c:1387 builtin/submodule--helper.c:1872
+msgid "force cloning progress"
+msgstr ""
+
+#: builtin/submodule--helper.c:1392
+msgid ""
+"git submodule--helper clone [--prefix=<path>] [--quiet] [--reference "
+"<repository>] [--name <name>] [--depth <depth>] --url <url> --path <path>"
+msgstr ""
+
+#: builtin/submodule--helper.c:1423
+#, c-format
+msgid "clone of '%s' into submodule path '%s' failed"
+msgstr ""
+
+#: builtin/submodule--helper.c:1437
+#, c-format
+msgid "could not get submodule directory for '%s'"
+msgstr ""
+
+#: builtin/submodule--helper.c:1473
+#, c-format
+msgid "Invalid update mode '%s' for submodule path '%s'"
+msgstr ""
+
+#: builtin/submodule--helper.c:1477
+#, c-format
+msgid "Invalid update mode '%s' configured for submodule path '%s'"
+msgstr ""
+
+#: builtin/submodule--helper.c:1570
+#, c-format
+msgid "Submodule path '%s' not initialized"
+msgstr ""
+
+#: builtin/submodule--helper.c:1574
+msgid "Maybe you want to use 'update --init'?"
+msgstr ""
+
+#: builtin/submodule--helper.c:1604
+#, c-format
+msgid "Skipping unmerged submodule %s"
+msgstr ""
+
+#: builtin/submodule--helper.c:1633
+#, c-format
+msgid "Skipping submodule '%s'"
+msgstr ""
+
+#: builtin/submodule--helper.c:1777
+#, c-format
+msgid "Failed to clone '%s'. Retry scheduled"
+msgstr ""
+
+#: builtin/submodule--helper.c:1788
+#, c-format
+msgid "Failed to clone '%s' a second time, aborting"
+msgstr ""
+
+#: builtin/submodule--helper.c:1851 builtin/submodule--helper.c:2093
+msgid "path into the working tree"
+msgstr ""
+
+#: builtin/submodule--helper.c:1854
+msgid "path into the working tree, across nested submodule boundaries"
+msgstr ""
+
+#: builtin/submodule--helper.c:1858
+msgid "rebase, merge, checkout or none"
+msgstr ""
+
+#: builtin/submodule--helper.c:1864
+msgid "Create a shallow clone truncated to the specified number of revisions"
+msgstr ""
+
+#: builtin/submodule--helper.c:1867
+msgid "parallel jobs"
+msgstr ""
+
+#: builtin/submodule--helper.c:1869
+msgid "whether the initial clone should follow the shallow recommendation"
+msgstr ""
+
+#: builtin/submodule--helper.c:1870
+msgid "don't print cloning progress"
+msgstr ""
+
+#: builtin/submodule--helper.c:1877
+msgid "git submodule--helper update_clone [--prefix=<path>] [<path>...]"
+msgstr ""
+
+#: builtin/submodule--helper.c:1890
+msgid "bad value for update parameter"
+msgstr ""
+
+#: builtin/submodule--helper.c:1938
+#, c-format
+msgid ""
+"Submodule (%s) branch configured to inherit branch from superproject, but "
+"the superproject is not on any branch"
+msgstr ""
+
+#: builtin/submodule--helper.c:2061
+#, c-format
+msgid "could not get a repository handle for submodule '%s'"
+msgstr ""
+
+#: builtin/submodule--helper.c:2094
+msgid "recurse into submodules"
+msgstr ""
+
+#: builtin/submodule--helper.c:2100
+msgid "git submodule--helper embed-git-dir [<path>...]"
+msgstr ""
+
+#: builtin/submodule--helper.c:2156
+msgid "check if it is safe to write to the .gitmodules file"
+msgstr ""
+
+#: builtin/submodule--helper.c:2161
+msgid "git submodule--helper config name [value]"
+msgstr ""
+
+#: builtin/submodule--helper.c:2162
+msgid "git submodule--helper config --check-writeable"
+msgstr "git submodule--helper config --check-writeable"
+
+#: builtin/submodule--helper.c:2179 git-submodule.sh:169
+#, sh-format
+msgid "please make sure that the .gitmodules file is in the working tree"
+msgstr ""
+
+#: builtin/submodule--helper.c:2229 git.c:413 git.c:658
+#, c-format
+msgid "%s doesn't support --super-prefix"
+msgstr ""
+
+#: builtin/submodule--helper.c:2235
+#, c-format
+msgid "'%s' is not a valid submodule--helper subcommand"
+msgstr ""
+
+#: builtin/symbolic-ref.c:8
+msgid "git symbolic-ref [<options>] <name> [<ref>]"
+msgstr ""
+
+#: builtin/symbolic-ref.c:9
+msgid "git symbolic-ref -d [-q] <name>"
+msgstr ""
+
+#: builtin/symbolic-ref.c:40
+msgid "suppress error message for non-symbolic (detached) refs"
+msgstr ""
+
+#: builtin/symbolic-ref.c:41
+msgid "delete symbolic ref"
+msgstr ""
+
+#: builtin/symbolic-ref.c:42
+msgid "shorten ref output"
+msgstr ""
+
+#: builtin/symbolic-ref.c:43 builtin/update-ref.c:363
+msgid "reason"
+msgstr ""
+
+#: builtin/symbolic-ref.c:43 builtin/update-ref.c:363
+msgid "reason of the update"
+msgstr ""
+
+#: builtin/tag.c:25
+msgid ""
+"git tag [-a | -s | -u <key-id>] [-f] [-m <msg> | -F <file>] <tagname> "
+"[<head>]"
+msgstr ""
+"git tag [-a | -s | -u <αναγνωριστικό κλειδί>] [-f] [-m <μήνυμα> | -F "
+"<αρχείο>] <όνομα ετικέτας> [<head>]"
+
+#: builtin/tag.c:26
+msgid "git tag -d <tagname>..."
+msgstr "git tag -d <όνομα ετικέτας>..."
+
+#: builtin/tag.c:27
+msgid ""
+"git tag -l [-n[<num>]] [--contains <commit>] [--no-contains <commit>] [--"
+"points-at <object>]\n"
+"\t\t[--format=<format>] [--[no-]merged [<commit>]] [<pattern>...]"
+msgstr ""
+"git tag -l [-n[<αριθ.>]] [--contains <υποβολή>] [--no-contains <υποβολή>] [--"
+"points-at <αντικείμενο>]\n"
+"\t\t[--format=<μορφή>] [--[no-]merged [<υποβολή>]] [<μοτίβο>...]"
+
+#: builtin/tag.c:29
+msgid "git tag -v [--format=<format>] <tagname>..."
+msgstr "git tag -v [--format=<μορφή>] <όνομα ετικέτας>..."
+
+#: builtin/tag.c:87
+#, c-format
+msgid "tag '%s' not found."
+msgstr ""
+
+#: builtin/tag.c:103
+#, c-format
+msgid "Deleted tag '%s' (was %s)\n"
+msgstr ""
+
+#: builtin/tag.c:133
+#, c-format
+msgid ""
+"\n"
+"Write a message for tag:\n"
+"  %s\n"
+"Lines starting with '%c' will be ignored.\n"
+msgstr ""
+
+#: builtin/tag.c:137
+#, c-format
+msgid ""
+"\n"
+"Write a message for tag:\n"
+"  %s\n"
+"Lines starting with '%c' will be kept; you may remove them yourself if you "
+"want to.\n"
+msgstr ""
+
+#: builtin/tag.c:191
+msgid "unable to sign the tag"
+msgstr ""
+
+#: builtin/tag.c:193
+msgid "unable to write tag file"
+msgstr ""
+
+#: builtin/tag.c:218
+msgid "bad object type."
+msgstr ""
+
+#: builtin/tag.c:267
+msgid "no tag message?"
+msgstr "δεν υπάρχει μήνυμα ετικέτας;"
+
+#: builtin/tag.c:274
+#, c-format
+msgid "The tag message has been left in %s\n"
+msgstr ""
+
+#: builtin/tag.c:385
+msgid "list tag names"
+msgstr ""
+
+#: builtin/tag.c:387
+msgid "print <n> lines of each tag message"
+msgstr ""
+
+#: builtin/tag.c:389
+msgid "delete tags"
+msgstr ""
+
+#: builtin/tag.c:390
+msgid "verify tags"
+msgstr ""
+
+#: builtin/tag.c:392
+msgid "Tag creation options"
+msgstr ""
+
+#: builtin/tag.c:394
+msgid "annotated tag, needs a message"
+msgstr ""
+
+#: builtin/tag.c:396
+msgid "tag message"
+msgstr ""
+
+#: builtin/tag.c:398
+msgid "force edit of tag message"
+msgstr ""
+
+#: builtin/tag.c:399
+msgid "annotated and GPG-signed tag"
+msgstr ""
+
+#: builtin/tag.c:403
+msgid "use another key to sign the tag"
+msgstr ""
+
+#: builtin/tag.c:404
+msgid "replace the tag if exists"
+msgstr ""
+
+#: builtin/tag.c:405 builtin/update-ref.c:369
+msgid "create a reflog"
+msgstr ""
+
+#: builtin/tag.c:407
+msgid "Tag listing options"
+msgstr ""
+
+#: builtin/tag.c:408
+msgid "show tag list in columns"
+msgstr ""
+
+#: builtin/tag.c:409 builtin/tag.c:411
+msgid "print only tags that contain the commit"
+msgstr ""
+
+#: builtin/tag.c:410 builtin/tag.c:412
+msgid "print only tags that don't contain the commit"
+msgstr ""
+
+#: builtin/tag.c:413
+msgid "print only tags that are merged"
+msgstr ""
+
+#: builtin/tag.c:414
+msgid "print only tags that are not merged"
+msgstr ""
+
+#: builtin/tag.c:419
+msgid "print only tags of the object"
+msgstr ""
+
+#: builtin/tag.c:463
+msgid "--column and -n are incompatible"
+msgstr ""
+
+#: builtin/tag.c:485
+msgid "-n option is only allowed in list mode"
+msgstr ""
+
+#: builtin/tag.c:487
+msgid "--contains option is only allowed in list mode"
+msgstr ""
+
+#: builtin/tag.c:489
+msgid "--no-contains option is only allowed in list mode"
+msgstr ""
+
+#: builtin/tag.c:491
+msgid "--points-at option is only allowed in list mode"
+msgstr ""
+
+#: builtin/tag.c:493
+msgid "--merged and --no-merged options are only allowed in list mode"
+msgstr ""
+
+#: builtin/tag.c:504
+msgid "only one -F or -m option is allowed."
+msgstr ""
+
+#: builtin/tag.c:523
+msgid "too many params"
+msgstr ""
+
+#: builtin/tag.c:529
+#, c-format
+msgid "'%s' is not a valid tag name."
+msgstr ""
+
+#: builtin/tag.c:534
+#, c-format
+msgid "tag '%s' already exists"
+msgstr ""
+
+#: builtin/tag.c:565
+#, c-format
+msgid "Updated tag '%s' (was %s)\n"
+msgstr ""
+
+#: builtin/unpack-objects.c:500
+msgid "Unpacking objects"
+msgstr ""
+
+#: builtin/update-index.c:83
+#, c-format
+msgid "failed to create directory %s"
+msgstr ""
+
+#: builtin/update-index.c:99
+#, c-format
+msgid "failed to create file %s"
+msgstr ""
+
+#: builtin/update-index.c:107
+#, c-format
+msgid "failed to delete file %s"
+msgstr ""
+
+#: builtin/update-index.c:114 builtin/update-index.c:220
+#, c-format
+msgid "failed to delete directory %s"
+msgstr ""
+
+#: builtin/update-index.c:139
+#, c-format
+msgid "Testing mtime in '%s' "
+msgstr ""
+
+#: builtin/update-index.c:153
+msgid "directory stat info does not change after adding a new file"
+msgstr ""
+
+#: builtin/update-index.c:166
+msgid "directory stat info does not change after adding a new directory"
+msgstr ""
+
+#: builtin/update-index.c:179
+msgid "directory stat info changes after updating a file"
+msgstr ""
+
+#: builtin/update-index.c:190
+msgid "directory stat info changes after adding a file inside subdirectory"
+msgstr ""
+
+#: builtin/update-index.c:201
+msgid "directory stat info does not change after deleting a file"
+msgstr ""
+
+#: builtin/update-index.c:214
+msgid "directory stat info does not change after deleting a directory"
+msgstr ""
+
+#: builtin/update-index.c:221
+msgid " OK"
+msgstr " OK"
+
+#: builtin/update-index.c:589
+msgid "git update-index [<options>] [--] [<file>...]"
+msgstr ""
+
+#: builtin/update-index.c:962
+msgid "continue refresh even when index needs update"
+msgstr ""
+
+#: builtin/update-index.c:965
+msgid "refresh: ignore submodules"
+msgstr ""
+
+#: builtin/update-index.c:968
+msgid "do not ignore new files"
+msgstr ""
+
+#: builtin/update-index.c:970
+msgid "let files replace directories and vice-versa"
+msgstr ""
+
+#: builtin/update-index.c:972
+msgid "notice files missing from worktree"
+msgstr ""
+
+#: builtin/update-index.c:974
+msgid "refresh even if index contains unmerged entries"
+msgstr ""
+
+#: builtin/update-index.c:977
+msgid "refresh stat information"
+msgstr ""
+
+#: builtin/update-index.c:981
+msgid "like --refresh, but ignore assume-unchanged setting"
+msgstr ""
+
+#: builtin/update-index.c:985
+msgid "<mode>,<object>,<path>"
+msgstr ""
+
+#: builtin/update-index.c:986
+msgid "add the specified entry to the index"
+msgstr ""
+
+#: builtin/update-index.c:995
+msgid "mark files as \"not changing\""
+msgstr ""
+
+#: builtin/update-index.c:998
+msgid "clear assumed-unchanged bit"
+msgstr ""
+
+#: builtin/update-index.c:1001
+msgid "mark files as \"index-only\""
+msgstr ""
+
+#: builtin/update-index.c:1004
+msgid "clear skip-worktree bit"
+msgstr ""
+
+#: builtin/update-index.c:1007
+msgid "add to index only; do not add content to object database"
+msgstr ""
+
+#: builtin/update-index.c:1009
+msgid "remove named paths even if present in worktree"
+msgstr ""
+
+#: builtin/update-index.c:1011
+msgid "with --stdin: input lines are terminated by null bytes"
+msgstr ""
+
+#: builtin/update-index.c:1013
+msgid "read list of paths to be updated from standard input"
+msgstr ""
+
+#: builtin/update-index.c:1017
+msgid "add entries from standard input to the index"
+msgstr ""
+
+#: builtin/update-index.c:1021
+msgid "repopulate stages #2 and #3 for the listed paths"
+msgstr ""
+
+#: builtin/update-index.c:1025
+msgid "only update entries that differ from HEAD"
+msgstr ""
+
+#: builtin/update-index.c:1029
+msgid "ignore files missing from worktree"
+msgstr ""
+
+#: builtin/update-index.c:1032
+msgid "report actions to standard output"
+msgstr ""
+
+#: builtin/update-index.c:1034
+msgid "(for porcelains) forget saved unresolved conflicts"
+msgstr "(για εντολές porcelain) ξέχνα τις σωσμένες μη επιλυμένες συγκρούσεις"
+
+#: builtin/update-index.c:1038
+msgid "write index in this format"
+msgstr ""
+
+#: builtin/update-index.c:1040
+msgid "enable or disable split index"
+msgstr ""
+
+#: builtin/update-index.c:1042
+msgid "enable/disable untracked cache"
+msgstr ""
+
+#: builtin/update-index.c:1044
+msgid "test if the filesystem supports untracked cache"
+msgstr ""
+
+#: builtin/update-index.c:1046
+msgid "enable untracked cache without testing the filesystem"
+msgstr ""
+
+#: builtin/update-index.c:1048
+msgid "write out the index even if is not flagged as changed"
+msgstr ""
+
+#: builtin/update-index.c:1050
+msgid "enable or disable file system monitor"
+msgstr ""
+
+#: builtin/update-index.c:1052
+msgid "mark files as fsmonitor valid"
+msgstr ""
+
+#: builtin/update-index.c:1055
+msgid "clear fsmonitor valid bit"
+msgstr ""
+
+#: builtin/update-index.c:1156
+msgid ""
+"core.splitIndex is set to false; remove or change it, if you really want to "
+"enable split index"
+msgstr ""
+
+#: builtin/update-index.c:1165
+msgid ""
+"core.splitIndex is set to true; remove or change it, if you really want to "
+"disable split index"
+msgstr ""
+
+#: builtin/update-index.c:1176
+msgid ""
+"core.untrackedCache is set to true; remove or change it, if you really want "
+"to disable the untracked cache"
+msgstr ""
+
+#: builtin/update-index.c:1180
+msgid "Untracked cache disabled"
+msgstr ""
+
+#: builtin/update-index.c:1188
+msgid ""
+"core.untrackedCache is set to false; remove or change it, if you really want "
+"to enable the untracked cache"
+msgstr ""
+
+#: builtin/update-index.c:1192
+#, c-format
+msgid "Untracked cache enabled for '%s'"
+msgstr ""
+
+#: builtin/update-index.c:1200
+msgid "core.fsmonitor is unset; set it if you really want to enable fsmonitor"
+msgstr ""
+
+#: builtin/update-index.c:1204
+msgid "fsmonitor enabled"
+msgstr ""
+
+#: builtin/update-index.c:1207
+msgid ""
+"core.fsmonitor is set; remove it if you really want to disable fsmonitor"
+msgstr ""
+
+#: builtin/update-index.c:1211
+msgid "fsmonitor disabled"
+msgstr ""
+
+#: builtin/update-ref.c:10
+msgid "git update-ref [<options>] -d <refname> [<old-val>]"
+msgstr ""
+
+#: builtin/update-ref.c:11
+msgid "git update-ref [<options>]    <refname> <new-val> [<old-val>]"
+msgstr ""
+
+#: builtin/update-ref.c:12
+msgid "git update-ref [<options>] --stdin [-z]"
+msgstr ""
+
+#: builtin/update-ref.c:364
+msgid "delete the reference"
+msgstr ""
+
+#: builtin/update-ref.c:366
+msgid "update <refname> not the one it points to"
+msgstr ""
+
+#: builtin/update-ref.c:367
+msgid "stdin has NUL-terminated arguments"
+msgstr ""
+
+#: builtin/update-ref.c:368
+msgid "read updates from stdin"
+msgstr ""
+
+#: builtin/update-server-info.c:7
+msgid "git update-server-info [--force]"
+msgstr "git update-server-info [--force]"
+
+#: builtin/update-server-info.c:15
+msgid "update the info files from scratch"
+msgstr ""
+
+#: builtin/upload-pack.c:11
+msgid "git upload-pack [<options>] <dir>"
+msgstr ""
+
+#: builtin/upload-pack.c:25
+msgid "exit immediately after initial ref advertisement"
+msgstr ""
+
+#: builtin/upload-pack.c:27
+msgid "do not try <directory>/.git/ if <directory> is no Git directory"
+msgstr ""
+
+#: builtin/upload-pack.c:29
+msgid "interrupt transfer after <n> seconds of inactivity"
+msgstr ""
+
+#: builtin/verify-commit.c:20
+msgid "git verify-commit [-v | --verbose] <commit>..."
+msgstr ""
+
+#: builtin/verify-commit.c:76
+msgid "print commit contents"
+msgstr ""
+
+#: builtin/verify-commit.c:77 builtin/verify-tag.c:38
+msgid "print raw gpg status output"
+msgstr ""
+
+#: builtin/verify-pack.c:55
+msgid "git verify-pack [-v | --verbose] [-s | --stat-only] <pack>..."
+msgstr ""
+
+#: builtin/verify-pack.c:65
+msgid "verbose"
+msgstr ""
+
+#: builtin/verify-pack.c:67
+msgid "show statistics only"
+msgstr ""
+
+#: builtin/verify-tag.c:19
+msgid "git verify-tag [-v | --verbose] [--format=<format>] <tag>..."
+msgstr ""
+
+#: builtin/verify-tag.c:37
+msgid "print tag contents"
+msgstr ""
+
+#: builtin/worktree.c:18
+msgid "git worktree add [<options>] <path> [<commit-ish>]"
+msgstr ""
+
+#: builtin/worktree.c:19
+msgid "git worktree list [<options>]"
+msgstr ""
+
+#: builtin/worktree.c:20
+msgid "git worktree lock [<options>] <path>"
+msgstr ""
+
+#: builtin/worktree.c:21
+msgid "git worktree move <worktree> <new-path>"
+msgstr ""
+
+#: builtin/worktree.c:22
+msgid "git worktree prune [<options>]"
+msgstr ""
+
+#: builtin/worktree.c:23
+msgid "git worktree remove [<options>] <worktree>"
+msgstr ""
+
+#: builtin/worktree.c:24
+msgid "git worktree unlock <path>"
+msgstr ""
+
+#: builtin/worktree.c:61 builtin/worktree.c:888
+#, c-format
+msgid "failed to delete '%s'"
+msgstr ""
+
+#: builtin/worktree.c:80
+#, c-format
+msgid "Removing worktrees/%s: not a valid directory"
+msgstr ""
+
+#: builtin/worktree.c:86
+#, c-format
+msgid "Removing worktrees/%s: gitdir file does not exist"
+msgstr ""
+
+#: builtin/worktree.c:91 builtin/worktree.c:100
+#, c-format
+msgid "Removing worktrees/%s: unable to read gitdir file (%s)"
+msgstr ""
+
+#: builtin/worktree.c:110
+#, c-format
+msgid ""
+"Removing worktrees/%s: short read (expected %<PRIuMAX> bytes, read "
+"%<PRIuMAX>)"
+msgstr ""
+
+#: builtin/worktree.c:118
+#, c-format
+msgid "Removing worktrees/%s: invalid gitdir file"
+msgstr ""
+
+#: builtin/worktree.c:127
+#, c-format
+msgid "Removing worktrees/%s: gitdir file points to non-existent location"
+msgstr ""
+
+#: builtin/worktree.c:166
+msgid "report pruned working trees"
+msgstr ""
+
+#: builtin/worktree.c:168
+msgid "expire working trees older than <time>"
+msgstr ""
+
+#: builtin/worktree.c:235
+#, c-format
+msgid "'%s' already exists"
+msgstr ""
+
+#: builtin/worktree.c:252
+#, c-format
+msgid "unable to re-add worktree '%s'"
+msgstr ""
+
+#: builtin/worktree.c:257
+#, c-format
+msgid ""
+"'%s' is a missing but locked worktree;\n"
+"use 'add -f -f' to override, or 'unlock' and 'prune' or 'remove' to clear"
+msgstr ""
+
+#: builtin/worktree.c:259
+#, c-format
+msgid ""
+"'%s' is a missing but already registered worktree;\n"
+"use 'add -f' to override, or 'prune' or 'remove' to clear"
+msgstr ""
+
+#: builtin/worktree.c:310
+#, c-format
+msgid "could not create directory of '%s'"
+msgstr ""
+
+#: builtin/worktree.c:429 builtin/worktree.c:435
+#, c-format
+msgid "Preparing worktree (new branch '%s')"
+msgstr ""
+
+#: builtin/worktree.c:431
+#, c-format
+msgid "Preparing worktree (resetting branch '%s'; was at %s)"
+msgstr ""
+
+#: builtin/worktree.c:440
+#, c-format
+msgid "Preparing worktree (checking out '%s')"
+msgstr ""
+
+#: builtin/worktree.c:446
+#, c-format
+msgid "Preparing worktree (detached HEAD %s)"
+msgstr ""
+
+#: builtin/worktree.c:487
+msgid "checkout <branch> even if already checked out in other worktree"
+msgstr ""
+
+#: builtin/worktree.c:490
+msgid "create a new branch"
+msgstr ""
+
+#: builtin/worktree.c:492
+msgid "create or reset a branch"
+msgstr ""
+
+#: builtin/worktree.c:494
+msgid "populate the new working tree"
+msgstr ""
+
+#: builtin/worktree.c:495
+msgid "keep the new working tree locked"
+msgstr ""
+
+#: builtin/worktree.c:498
+msgid "set up tracking mode (see git-branch(1))"
+msgstr ""
+
+#: builtin/worktree.c:501
+msgid "try to match the new branch name with a remote-tracking branch"
+msgstr ""
+
+#: builtin/worktree.c:509
+msgid "-b, -B, and --detach are mutually exclusive"
+msgstr ""
+
+#: builtin/worktree.c:570
+msgid "--[no-]track can only be used if a new branch is created"
+msgstr ""
+
+#: builtin/worktree.c:670
+msgid "reason for locking"
+msgstr ""
+
+#: builtin/worktree.c:682 builtin/worktree.c:715 builtin/worktree.c:789
+#: builtin/worktree.c:916
+#, c-format
+msgid "'%s' is not a working tree"
+msgstr ""
+
+#: builtin/worktree.c:684 builtin/worktree.c:717
+msgid "The main working tree cannot be locked or unlocked"
+msgstr ""
+
+#: builtin/worktree.c:689
+#, c-format
+msgid "'%s' is already locked, reason: %s"
+msgstr ""
+
+#: builtin/worktree.c:691
+#, c-format
+msgid "'%s' is already locked"
+msgstr ""
+
+#: builtin/worktree.c:719
+#, c-format
+msgid "'%s' is not locked"
+msgstr ""
+
+#: builtin/worktree.c:760
+msgid "working trees containing submodules cannot be moved or removed"
+msgstr ""
+
+#: builtin/worktree.c:768
+msgid "force move even if worktree is dirty or locked"
+msgstr ""
+
+#: builtin/worktree.c:791 builtin/worktree.c:918
+#, c-format
+msgid "'%s' is a main working tree"
+msgstr ""
+
+#: builtin/worktree.c:796
+#, c-format
+msgid "could not figure out destination name from '%s'"
+msgstr ""
+
+#: builtin/worktree.c:802
+#, c-format
+msgid "target '%s' already exists"
+msgstr ""
+
+#: builtin/worktree.c:810
+#, c-format
+msgid ""
+"cannot move a locked working tree, lock reason: %s\n"
+"use 'move -f -f' to override or unlock first"
+msgstr ""
+
+#: builtin/worktree.c:812
+msgid ""
+"cannot move a locked working tree;\n"
+"use 'move -f -f' to override or unlock first"
+msgstr ""
+
+#: builtin/worktree.c:815
+#, c-format
+msgid "validation failed, cannot move working tree: %s"
+msgstr ""
+
+#: builtin/worktree.c:820
+#, c-format
+msgid "failed to move '%s' to '%s'"
+msgstr ""
+
+#: builtin/worktree.c:868
+#, c-format
+msgid "failed to run 'git status' on '%s'"
+msgstr ""
+
+#: builtin/worktree.c:872
+#, c-format
+msgid "'%s' is dirty, use --force to delete it"
+msgstr ""
+
+#: builtin/worktree.c:877
+#, c-format
+msgid "failed to run 'git status' on '%s', code %d"
+msgstr ""
+
+#: builtin/worktree.c:900
+msgid "force removal even if worktree is dirty or locked"
+msgstr ""
+
+#: builtin/worktree.c:923
+#, c-format
+msgid ""
+"cannot remove a locked working tree, lock reason: %s\n"
+"use 'remove -f -f' to override or unlock first"
+msgstr ""
+
+#: builtin/worktree.c:925
+msgid ""
+"cannot remove a locked working tree;\n"
+"use 'remove -f -f' to override or unlock first"
+msgstr ""
+
+#: builtin/worktree.c:928
+#, c-format
+msgid "validation failed, cannot remove working tree: %s"
+msgstr ""
+
+#: builtin/write-tree.c:15
+msgid "git write-tree [--missing-ok] [--prefix=<prefix>/]"
+msgstr ""
+
+#: builtin/write-tree.c:28
+msgid "<prefix>/"
+msgstr "<πρόθεμα>/"
+
+#: builtin/write-tree.c:29
+msgid "write tree object for a subdirectory <prefix>"
+msgstr ""
+
+#: builtin/write-tree.c:31
+msgid "only useful for debugging"
+msgstr ""
+
+#: credential-cache--daemon.c:223
+#, c-format
+msgid ""
+"The permissions on your socket directory are too loose; other\n"
+"users may be able to read your cached credentials. Consider running:\n"
+"\n"
+"\tchmod 0700 %s"
+msgstr ""
+
+#: credential-cache--daemon.c:272
+msgid "print debugging messages to stderr"
+msgstr ""
+
+#: t/helper/test-reach.c:152
+#, c-format
+msgid "commit %s is not marked reachable"
+msgstr "η υποβολή %s δεν είναι σημειωμένη ως προσβάσιμη"
+
+#: t/helper/test-reach.c:162
+msgid "too many commits marked reachable"
+msgstr ""
+
+#: git.c:27
+msgid ""
+"git [--version] [--help] [-C <path>] [-c <name>=<value>]\n"
+"           [--exec-path[=<path>]] [--html-path] [--man-path] [--info-path]\n"
+"           [-p | --paginate | -P | --no-pager] [--no-replace-objects] [--"
+"bare]\n"
+"           [--git-dir=<path>] [--work-tree=<path>] [--namespace=<name>]\n"
+"           <command> [<args>]"
+msgstr ""
+"git [--version] [--help] [-C <διαδρομή>] [-c <όνομα>=<τιμή>]\n"
+"           [--exec-path[=<διαδρομή>]] [--html-path] [--man-path] [--info-"
+"path]\n"
+"           [-p | --paginate | -P | --no-pager] [--no-replace-objects] [--"
+"bare]\n"
+"           [--git-dir=<διαδρομή>] [--work-tree=<διαδρομή>] [--"
+"namespace=<όνομα>]\n"
+"           <εντολή> [<ορίσματα>]"
+
+#: git.c:34
+msgid ""
+"'git help -a' and 'git help -g' list available subcommands and some\n"
+"concept guides. See 'git help <command>' or 'git help <concept>'\n"
+"to read about a specific subcommand or concept."
+msgstr ""
+
+#: git.c:174
+#, c-format
+msgid "no directory given for --git-dir\n"
+msgstr ""
+
+#: git.c:188
+#, c-format
+msgid "no namespace given for --namespace\n"
+msgstr ""
+
+#: git.c:202
+#, c-format
+msgid "no directory given for --work-tree\n"
+msgstr ""
+
+#: git.c:216
+#, c-format
+msgid "no prefix given for --super-prefix\n"
+msgstr ""
+
+#: git.c:238
+#, c-format
+msgid "-c expects a configuration string\n"
+msgstr ""
+
+#: git.c:276
+#, c-format
+msgid "no directory given for -C\n"
+msgstr ""
+
+#: git.c:301
+#, c-format
+msgid "unknown option: %s\n"
+msgstr ""
+
+#: git.c:342
+#, c-format
+msgid "while expanding alias '%s': '%s'"
+msgstr ""
+
+#: git.c:351
+#, c-format
+msgid ""
+"alias '%s' changes environment variables.\n"
+"You can use '!git' in the alias to do this"
+msgstr ""
+
+#: git.c:359
+#, c-format
+msgid "empty alias for %s"
+msgstr ""
+
+#: git.c:362
+#, c-format
+msgid "recursive alias: %s"
+msgstr ""
+
+#: git.c:437
+msgid "write failure on standard output"
+msgstr ""
+
+#: git.c:439
+msgid "unknown write failure on standard output"
+msgstr ""
+
+#: git.c:441
+msgid "close failed on standard output"
+msgstr ""
+
+#: git.c:720
+#, c-format
+msgid "alias loop detected: expansion of '%s' does not terminate:%s"
+msgstr ""
+
+#: git.c:770
+#, c-format
+msgid "cannot handle %s as a builtin"
+msgstr ""
+
+#: git.c:783
+#, c-format
+msgid ""
+"usage: %s\n"
+"\n"
+msgstr ""
+"χρήση: %s\n"
+"\n"
+
+#: git.c:803
+#, c-format
+msgid "expansion of alias '%s' failed; '%s' is not a git command\n"
+msgstr ""
+
+#: git.c:815
+#, c-format
+msgid "failed to run command '%s': %s\n"
+msgstr ""
+
+#: http.c:378
+#, c-format
+msgid "negative value for http.postbuffer; defaulting to %d"
+msgstr ""
+
+#: http.c:399
+msgid "Delegation control is not supported with cURL < 7.22.0"
+msgstr ""
+
+#: http.c:408
+msgid "Public key pinning not supported with cURL < 7.44.0"
+msgstr ""
+
+#: http.c:876
+msgid "CURLSSLOPT_NO_REVOKE not supported with cURL < 7.44.0"
+msgstr ""
+
+#: http.c:949
+msgid "Protocol restrictions not supported with cURL < 7.19.4"
+msgstr ""
+
+#: http.c:1085
+#, c-format
+msgid "Unsupported SSL backend '%s'. Supported SSL backends:"
+msgstr ""
+
+#: http.c:1092
+#, c-format
+msgid "Could not set SSL backend to '%s': cURL was built without SSL backends"
+msgstr ""
+
+#: http.c:1096
+#, c-format
+msgid "Could not set SSL backend to '%s': already set"
+msgstr ""
+
+#: http.c:1959
+#, c-format
+msgid ""
+"unable to update url base from redirection:\n"
+"  asked for: %s\n"
+"   redirect: %s"
+msgstr ""
+
+#: remote-curl.c:455
+#, c-format
+msgid "redirecting to %s"
+msgstr ""
+
+#: parse-options.h:154
+msgid "expiry-date"
+msgstr ""
+
+#: parse-options.h:169
+msgid "no-op (backward compatibility)"
+msgstr ""
+
+#: parse-options.h:259
+msgid "be more verbose"
+msgstr ""
+
+#: parse-options.h:261
+msgid "be more quiet"
+msgstr ""
+
+#: parse-options.h:267
+msgid "use <n> digits to display SHA-1s"
+msgstr ""
+
+#: command-list.h:50
+msgid "Add file contents to the index"
+msgstr ""
+
+#: command-list.h:51
+msgid "Apply a series of patches from a mailbox"
+msgstr ""
+
+#: command-list.h:52
+msgid "Annotate file lines with commit information"
+msgstr ""
+
+#: command-list.h:53
+msgid "Apply a patch to files and/or to the index"
+msgstr ""
+
+#: command-list.h:54
+msgid "Import a GNU Arch repository into Git"
+msgstr ""
+
+#: command-list.h:55
+msgid "Create an archive of files from a named tree"
+msgstr ""
+
+#: command-list.h:56
+msgid "Use binary search to find the commit that introduced a bug"
+msgstr ""
+
+#: command-list.h:57
+msgid "Show what revision and author last modified each line of a file"
+msgstr ""
+
+#: command-list.h:58
+msgid "List, create, or delete branches"
+msgstr ""
+
+#: command-list.h:59
+msgid "Move objects and refs by archive"
+msgstr ""
+
+#: command-list.h:60
+msgid "Provide content or type and size information for repository objects"
+msgstr ""
+
+#: command-list.h:61
+msgid "Display gitattributes information"
+msgstr ""
+
+#: command-list.h:62
+msgid "Debug gitignore / exclude files"
+msgstr ""
+
+#: command-list.h:63
+msgid "Show canonical names and email addresses of contacts"
+msgstr ""
+
+#: command-list.h:64
+msgid "Switch branches or restore working tree files"
+msgstr ""
+
+#: command-list.h:65
+msgid "Copy files from the index to the working tree"
+msgstr ""
+
+#: command-list.h:66
+msgid "Ensures that a reference name is well formed"
+msgstr ""
+
+#: command-list.h:67
+msgid "Find commits yet to be applied to upstream"
+msgstr ""
+
+#: command-list.h:68
+msgid "Apply the changes introduced by some existing commits"
+msgstr ""
+
+#: command-list.h:69
+msgid "Graphical alternative to git-commit"
+msgstr ""
+
+#: command-list.h:70
+msgid "Remove untracked files from the working tree"
+msgstr ""
+
+#: command-list.h:71
+msgid "Clone a repository into a new directory"
+msgstr ""
+
+#: command-list.h:72
+msgid "Display data in columns"
+msgstr ""
+
+#: command-list.h:73
+msgid "Record changes to the repository"
+msgstr ""
+
+#: command-list.h:74
+msgid "Write and verify Git commit-graph files"
+msgstr ""
+
+#: command-list.h:75
+msgid "Create a new commit object"
+msgstr ""
+
+#: command-list.h:76
+msgid "Get and set repository or global options"
+msgstr ""
+
+#: command-list.h:77
+msgid "Count unpacked number of objects and their disk consumption"
+msgstr ""
+
+#: command-list.h:78
+msgid "Retrieve and store user credentials"
+msgstr ""
+
+#: command-list.h:79
+msgid "Helper to temporarily store passwords in memory"
+msgstr ""
+
+#: command-list.h:80
+msgid "Helper to store credentials on disk"
+msgstr ""
+
+#: command-list.h:81
+msgid "Export a single commit to a CVS checkout"
+msgstr ""
+
+#: command-list.h:82
+msgid "Salvage your data out of another SCM people love to hate"
+msgstr ""
+
+#: command-list.h:83
+msgid "A CVS server emulator for Git"
+msgstr ""
+
+#: command-list.h:84
+msgid "A really simple server for Git repositories"
+msgstr ""
+
+#: command-list.h:85
+msgid "Give an object a human readable name based on an available ref"
+msgstr ""
+
+#: command-list.h:86
+msgid "Show changes between commits, commit and working tree, etc"
+msgstr ""
+
+#: command-list.h:87
+msgid "Compares files in the working tree and the index"
+msgstr ""
+
+#: command-list.h:88
+msgid "Compare a tree to the working tree or index"
+msgstr ""
+
+#: command-list.h:89
+msgid "Compares the content and mode of blobs found via two tree objects"
+msgstr ""
+"Συγκρίνει το περιεχόμενο και τη λειτουργία των blob που βρέθηκαν μέσω δύο "
+"αντικειμένων δέντρων"
+
+#: command-list.h:90
+msgid "Show changes using common diff tools"
+msgstr ""
+
+#: command-list.h:91
+msgid "Git data exporter"
+msgstr "Εξαγωγέας δεδομένων Git"
+
+#: command-list.h:92
+msgid "Backend for fast Git data importers"
+msgstr ""
+
+#: command-list.h:93
+msgid "Download objects and refs from another repository"
+msgstr ""
+
+#: command-list.h:94
+msgid "Receive missing objects from another repository"
+msgstr ""
+
+#: command-list.h:95
+msgid "Rewrite branches"
+msgstr ""
+
+#: command-list.h:96
+msgid "Produce a merge commit message"
+msgstr ""
+
+#: command-list.h:97
+msgid "Output information on each ref"
+msgstr ""
+
+#: command-list.h:98
+msgid "Prepare patches for e-mail submission"
+msgstr ""
+
+#: command-list.h:99
+msgid "Verifies the connectivity and validity of the objects in the database"
+msgstr ""
+
+#: command-list.h:100
+msgid "Cleanup unnecessary files and optimize the local repository"
+msgstr ""
+
+#: command-list.h:101
+msgid "Extract commit ID from an archive created using git-archive"
+msgstr ""
+
+#: command-list.h:102
+msgid "Print lines matching a pattern"
+msgstr ""
+
+#: command-list.h:103
+msgid "A portable graphical interface to Git"
+msgstr ""
+
+#: command-list.h:104
+msgid "Compute object ID and optionally creates a blob from a file"
+msgstr ""
+"Υπολογισμός αναγνωριστικού αντικειμένου και προαιρετικά δημιουργία blob από "
+"ένα αρχείο"
+
+#: command-list.h:105
+msgid "Display help information about Git"
+msgstr ""
+
+#: command-list.h:106
+msgid "Server side implementation of Git over HTTP"
+msgstr ""
+
+#: command-list.h:107
+msgid "Download from a remote Git repository via HTTP"
+msgstr ""
+
+#: command-list.h:108
+msgid "Push objects over HTTP/DAV to another repository"
+msgstr ""
+
+#: command-list.h:109
+msgid "Send a collection of patches from stdin to an IMAP folder"
+msgstr ""
+
+#: command-list.h:110
+msgid "Build pack index file for an existing packed archive"
+msgstr ""
+
+#: command-list.h:111
+msgid "Create an empty Git repository or reinitialize an existing one"
+msgstr ""
+
+#: command-list.h:112
+msgid "Instantly browse your working repository in gitweb"
+msgstr ""
+
+#: command-list.h:113
+msgid "add or parse structured information in commit messages"
+msgstr ""
+
+#: command-list.h:114
+msgid "The Git repository browser"
+msgstr ""
+
+#: command-list.h:115
+msgid "Show commit logs"
+msgstr ""
+
+#: command-list.h:116
+msgid "Show information about files in the index and the working tree"
+msgstr ""
+
+#: command-list.h:117
+msgid "List references in a remote repository"
+msgstr ""
+
+#: command-list.h:118
+msgid "List the contents of a tree object"
+msgstr ""
+
+#: command-list.h:119
+msgid "Extracts patch and authorship from a single e-mail message"
+msgstr ""
+
+#: command-list.h:120
+msgid "Simple UNIX mbox splitter program"
+msgstr ""
+
+#: command-list.h:121
+msgid "Join two or more development histories together"
+msgstr ""
+
+#: command-list.h:122
+msgid "Find as good common ancestors as possible for a merge"
+msgstr ""
+
+#: command-list.h:123
+msgid "Run a three-way file merge"
+msgstr ""
+
+#: command-list.h:124
+msgid "Run a merge for files needing merging"
+msgstr ""
+
+#: command-list.h:125
+msgid "The standard helper program to use with git-merge-index"
+msgstr ""
+
+#: command-list.h:126
+msgid "Run merge conflict resolution tools to resolve merge conflicts"
+msgstr ""
+"Τρέξτε εργαλεία επίλυσης συγκρούσεων συγχώνευσης για να επιλύσετε τις "
+"συγκρούσεις συγχώνευσης"
+
+#: command-list.h:127
+msgid "Show three-way merge without touching index"
+msgstr ""
+
+#: command-list.h:128
+msgid "Write and verify multi-pack-indexes"
+msgstr ""
+
+#: command-list.h:129
+msgid "Creates a tag object"
+msgstr ""
+
+#: command-list.h:130
+msgid "Build a tree-object from ls-tree formatted text"
+msgstr ""
+
+#: command-list.h:131
+msgid "Move or rename a file, a directory, or a symlink"
+msgstr ""
+
+#: command-list.h:132
+msgid "Find symbolic names for given revs"
+msgstr ""
+
+#: command-list.h:133
+msgid "Add or inspect object notes"
+msgstr ""
+
+#: command-list.h:134
+msgid "Import from and submit to Perforce repositories"
+msgstr ""
+
+#: command-list.h:135
+msgid "Create a packed archive of objects"
+msgstr ""
+
+#: command-list.h:136
+msgid "Find redundant pack files"
+msgstr ""
+
+#: command-list.h:137
+msgid "Pack heads and tags for efficient repository access"
+msgstr ""
+
+#: command-list.h:138
+msgid "Routines to help parsing remote repository access parameters"
+msgstr ""
+
+#: command-list.h:139
+msgid "Compute unique ID for a patch"
+msgstr ""
+
+#: command-list.h:140
+msgid "Prune all unreachable objects from the object database"
+msgstr ""
+
+#: command-list.h:141
+msgid "Remove extra objects that are already in pack files"
+msgstr ""
+
+#: command-list.h:142
+msgid "Fetch from and integrate with another repository or a local branch"
+msgstr ""
+
+#: command-list.h:143
+msgid "Update remote refs along with associated objects"
+msgstr ""
+
+#: command-list.h:144
+msgid "Applies a quilt patchset onto the current branch"
+msgstr "Κάνει εφαρμογή ενός πακέτου διορθώσεων πάνω στον τρέχοντα κλάδο"
+
+#: command-list.h:145
+msgid "Compare two commit ranges (e.g. two versions of a branch)"
+msgstr ""
+
+#: command-list.h:146
+msgid "Reads tree information into the index"
+msgstr ""
+
+#: command-list.h:147
+msgid "Reapply commits on top of another base tip"
+msgstr ""
+
+#: command-list.h:148
+msgid "Receive what is pushed into the repository"
+msgstr ""
+
+#: command-list.h:149
+msgid "Manage reflog information"
+msgstr ""
+
+#: command-list.h:150
+msgid "Manage set of tracked repositories"
+msgstr ""
+
+#: command-list.h:151
+msgid "Pack unpacked objects in a repository"
+msgstr ""
+
+#: command-list.h:152
+msgid "Create, list, delete refs to replace objects"
+msgstr ""
+
+#: command-list.h:153
+msgid "Generates a summary of pending changes"
+msgstr ""
+
+#: command-list.h:154
+msgid "Reuse recorded resolution of conflicted merges"
+msgstr ""
+
+#: command-list.h:155
+msgid "Reset current HEAD to the specified state"
+msgstr ""
+
+#: command-list.h:156
+msgid "Revert some existing commits"
+msgstr ""
+
+#: command-list.h:157
+msgid "Lists commit objects in reverse chronological order"
+msgstr ""
+
+#: command-list.h:158
+msgid "Pick out and massage parameters"
+msgstr ""
+
+#: command-list.h:159
+msgid "Remove files from the working tree and from the index"
+msgstr ""
+
+#: command-list.h:160
+msgid "Send a collection of patches as emails"
+msgstr ""
+
+#: command-list.h:161
+msgid "Push objects over Git protocol to another repository"
+msgstr ""
+
+#: command-list.h:162
+msgid "Restricted login shell for Git-only SSH access"
+msgstr ""
+
+#: command-list.h:163
+msgid "Summarize 'git log' output"
+msgstr ""
+
+#: command-list.h:164
+msgid "Show various types of objects"
+msgstr ""
+
+#: command-list.h:165
+msgid "Show branches and their commits"
+msgstr ""
+
+#: command-list.h:166
+msgid "Show packed archive index"
+msgstr ""
+
+#: command-list.h:167
+msgid "List references in a local repository"
+msgstr ""
+
+#: command-list.h:168
+msgid "Git's i18n setup code for shell scripts"
+msgstr ""
+
+#: command-list.h:169
+msgid "Common Git shell script setup code"
+msgstr ""
+
+#: command-list.h:170
+msgid "Stash the changes in a dirty working directory away"
+msgstr ""
+
+#: command-list.h:171
+msgid "Add file contents to the staging area"
+msgstr ""
+
+#: command-list.h:172
+msgid "Show the working tree status"
+msgstr ""
+
+#: command-list.h:173
+msgid "Remove unnecessary whitespace"
+msgstr ""
+
+#: command-list.h:174
+msgid "Initialize, update or inspect submodules"
+msgstr ""
+
+#: command-list.h:175
+msgid "Bidirectional operation between a Subversion repository and Git"
+msgstr ""
+
+#: command-list.h:176
+msgid "Read, modify and delete symbolic refs"
+msgstr ""
+
+#: command-list.h:177
+msgid "Create, list, delete or verify a tag object signed with GPG"
+msgstr ""
+
+#: command-list.h:178
+msgid "Creates a temporary file with a blob's contents"
+msgstr "Δημιουργεί προσωρινό αρχείο με τα περιεχόμενα ενός blob"
+
+#: command-list.h:179
+msgid "Unpack objects from a packed archive"
+msgstr ""
+
+#: command-list.h:180
+msgid "Register file contents in the working tree to the index"
+msgstr ""
+
+#: command-list.h:181
+msgid "Update the object name stored in a ref safely"
+msgstr ""
+
+#: command-list.h:182
+msgid "Update auxiliary info file to help dumb servers"
+msgstr ""
+
+#: command-list.h:183
+msgid "Send archive back to git-archive"
+msgstr ""
+
+#: command-list.h:184
+msgid "Send objects packed back to git-fetch-pack"
+msgstr ""
+
+#: command-list.h:185
+msgid "Show a Git logical variable"
+msgstr ""
+
+#: command-list.h:186
+msgid "Check the GPG signature of commits"
+msgstr ""
+
+#: command-list.h:187
+msgid "Validate packed Git archive files"
+msgstr ""
+
+#: command-list.h:188
+msgid "Check the GPG signature of tags"
+msgstr ""
+
+#: command-list.h:189
+msgid "Git web interface (web frontend to Git repositories)"
+msgstr ""
+
+#: command-list.h:190
+msgid "Show logs with difference each commit introduces"
+msgstr ""
+
+#: command-list.h:191
+msgid "Manage multiple working trees"
+msgstr ""
+
+#: command-list.h:192
+msgid "Create a tree object from the current index"
+msgstr ""
+
+#: command-list.h:193
+msgid "Defining attributes per path"
+msgstr ""
+
+#: command-list.h:194
+msgid "Git command-line interface and conventions"
+msgstr "Διεπαφή γραμμής εντολών Git και συμβάσεις"
+
+#: command-list.h:195
+msgid "A Git core tutorial for developers"
+msgstr "Ένα μάθημα του πυρήνα του Git για προγραμματιστές"
+
+#: command-list.h:196
+msgid "Git for CVS users"
+msgstr ""
+
+#: command-list.h:197
+msgid "Tweaking diff output"
+msgstr ""
+
+#: command-list.h:198
+msgid "A useful minimum set of commands for Everyday Git"
+msgstr ""
+
+#: command-list.h:199
+msgid "A Git Glossary"
+msgstr "Ένα Γλωσσάρι του Git"
+
+#: command-list.h:200
+msgid "Hooks used by Git"
+msgstr ""
+
+#: command-list.h:201
+msgid "Specifies intentionally untracked files to ignore"
+msgstr ""
+
+#: command-list.h:202
+msgid "Defining submodule properties"
+msgstr ""
+
+#: command-list.h:203
+msgid "Git namespaces"
+msgstr "Ονόματα xώρων Git"
+
+#: command-list.h:204
+msgid "Git Repository Layout"
+msgstr ""
+
+#: command-list.h:205
+msgid "Specifying revisions and ranges for Git"
+msgstr ""
+
+#: command-list.h:206
+msgid "A tutorial introduction to Git: part two"
+msgstr ""
+
+#: command-list.h:207
+msgid "A tutorial introduction to Git"
+msgstr ""
+
+#: command-list.h:208
+msgid "An overview of recommended workflows with Git"
+msgstr ""
+
+#: list-objects-filter-options.h:63
+msgid "args"
+msgstr "ορίσματα"
+
+#: list-objects-filter-options.h:64
+msgid "object filtering"
+msgstr ""
+
+#: rerere.h:44
+msgid "update the index with reused conflict resolution if possible"
+msgstr ""
+
+#: git-bisect.sh:54
+msgid "You need to start by \"git bisect start\""
+msgstr "Χρειάζεται να αρχίσετε με \"git bisect start\""
+
+#. TRANSLATORS: Make sure to include [Y] and [n] in your
+#. translation. The program will only accept English input
+#. at this point.
+#: git-bisect.sh:60
+msgid "Do you want me to do it for you [Y/n]? "
+msgstr ""
+
+#: git-bisect.sh:101
+#, sh-format
+msgid "Bad rev input: $arg"
+msgstr ""
+
+#: git-bisect.sh:121
+#, sh-format
+msgid "Bad rev input: $bisected_head"
+msgstr ""
+
+#: git-bisect.sh:130
+#, sh-format
+msgid "Bad rev input: $rev"
+msgstr ""
+
+#: git-bisect.sh:139
+#, sh-format
+msgid "'git bisect $TERM_BAD' can take only one argument."
+msgstr "'git bisect $TERM_BAD' δέχεται μόνο ένα όρισμα."
+
+#: git-bisect.sh:209
+msgid "No logfile given"
+msgstr ""
+
+#: git-bisect.sh:210
+#, sh-format
+msgid "cannot read $file for replaying"
+msgstr ""
+
+#: git-bisect.sh:232
+msgid "?? what are you talking about?"
+msgstr ";;  τι εννοείτε;"
+
+#: git-bisect.sh:241
+msgid "bisect run failed: no command provided."
+msgstr ""
+
+#: git-bisect.sh:246
+#, sh-format
+msgid "running $command"
+msgstr ""
+
+#: git-bisect.sh:253
+#, sh-format
+msgid ""
+"bisect run failed:\n"
+"exit code $res from '$command' is < 0 or >= 128"
+msgstr ""
+
+#: git-bisect.sh:279
+msgid "bisect run cannot continue any more"
+msgstr ""
+
+#: git-bisect.sh:285
+#, sh-format
+msgid ""
+"bisect run failed:\n"
+"'bisect_state $state' exited with error code $res"
+msgstr ""
+
+#: git-bisect.sh:292
+msgid "bisect run success"
+msgstr ""
+
+#: git-bisect.sh:300
+msgid "We are not bisecting."
+msgstr ""
+
+#: git-merge-octopus.sh:46
+msgid ""
+"Error: Your local changes to the following files would be overwritten by "
+"merge"
+msgstr ""
+
+#: git-merge-octopus.sh:61
+msgid "Automated merge did not work."
+msgstr ""
+
+#: git-merge-octopus.sh:62
+msgid "Should not be doing an octopus."
+msgstr ""
+
+#: git-merge-octopus.sh:73
+#, sh-format
+msgid "Unable to find common commit with $pretty_name"
+msgstr ""
+
+#: git-merge-octopus.sh:77
+#, sh-format
+msgid "Already up to date with $pretty_name"
+msgstr "Ήδη πλήρως ενήμερο με το $pretty_name"
+
+#: git-merge-octopus.sh:89
+#, sh-format
+msgid "Fast-forwarding to: $pretty_name"
+msgstr ""
+
+#: git-merge-octopus.sh:97
+#, sh-format
+msgid "Trying simple merge with $pretty_name"
+msgstr ""
+
+#: git-merge-octopus.sh:102
+msgid "Simple merge did not work, trying automatic merge."
+msgstr ""
+
+#: git-legacy-rebase.sh:445
+#, sh-format
+msgid "Could not move back to $head_name"
+msgstr ""
+
+#: git-legacy-rebase.sh:471
+#, sh-format
+msgid ""
+"It seems that there is already a $state_dir_base directory, and\n"
+"I wonder if you are in the middle of another rebase.  If that is the\n"
+"case, please try\n"
+"\t$cmd_live_rebase\n"
+"If that is not the case, please\n"
+"\t$cmd_clear_stale_rebase\n"
+"and run me again.  I am stopping in case you still have something\n"
+"valuable there."
+msgstr ""
+
+#: git-legacy-rebase.sh:523
+msgid ""
+"fatal: cannot combine am options with either interactive or merge options"
+msgstr ""
+
+#: git-legacy-rebase.sh:530
+msgid "fatal: cannot combine '--signoff' with '--preserve-merges'"
+msgstr ""
+
+#: git-legacy-rebase.sh:541
+msgid "fatal: cannot combine '--preserve-merges' with '--rebase-merges'"
+msgstr ""
+
+#: git-legacy-rebase.sh:550
+msgid "fatal: cannot combine '--rebase-merges' with '--strategy-option'"
+msgstr ""
+
+#: git-legacy-rebase.sh:552
+msgid "fatal: cannot combine '--rebase-merges' with '--strategy'"
+msgstr ""
+
+#: git-legacy-rebase.sh:578
+#, sh-format
+msgid "invalid upstream '$upstream_name'"
+msgstr ""
+
+#: git-legacy-rebase.sh:602
+#, sh-format
+msgid "$onto_name: there are more than one merge bases"
+msgstr ""
+
+#: git-legacy-rebase.sh:605 git-legacy-rebase.sh:609
+#, sh-format
+msgid "$onto_name: there is no merge base"
+msgstr ""
+
+#: git-legacy-rebase.sh:614
+#, sh-format
+msgid "Does not point to a valid commit: $onto_name"
+msgstr ""
+
+#: git-legacy-rebase.sh:640
+#, sh-format
+msgid "fatal: no such branch/commit '$branch_name'"
+msgstr ""
+
+#: git-legacy-rebase.sh:678
+#, sh-format
+msgid "Created autostash: $stash_abbrev"
+msgstr ""
+
+#: git-legacy-rebase.sh:707
+#, sh-format
+msgid "Current branch $branch_name is up to date."
+msgstr ""
+
+#: git-legacy-rebase.sh:717
+#, sh-format
+msgid "Current branch $branch_name is up to date, rebase forced."
+msgstr ""
+
+#: git-legacy-rebase.sh:731
+#, sh-format
+msgid "Changes to $onto:"
+msgstr ""
+
+#: git-legacy-rebase.sh:733
+#, sh-format
+msgid "Changes from $mb to $onto:"
+msgstr ""
+
+#: git-legacy-rebase.sh:743
+#, sh-format
+msgid "Fast-forwarded $branch_name to $onto_name."
+msgstr ""
+
+#: git-legacy-rebase.sh:757
+msgid "First, rewinding head to replay your work on top of it..."
+msgstr ""
+"Πρώτα, γίνεται γύρισμα προς τα πίσω του head για να γίνει επανάληψη της "
+"δουλειάς σας πάνω σε αυτό..."
+
+#: git-stash.sh:75
+msgid "git stash clear with parameters is unimplemented"
+msgstr ""
+
+#: git-stash.sh:125
+msgid "You do not have the initial commit yet"
+msgstr "Δεν έχετε ακόμα την αρχική υποβολή"
+
+#: git-stash.sh:140
+msgid "Cannot save the current index state"
+msgstr ""
+
+#: git-stash.sh:155
+msgid "Cannot save the untracked files"
+msgstr ""
+
+#: git-stash.sh:175 git-stash.sh:188
+msgid "Cannot save the current worktree state"
+msgstr ""
+
+#: git-stash.sh:192
+msgid "No changes selected"
+msgstr "Δεν επιλέχτηκε καμία αλλαγή"
+
+#: git-stash.sh:195
+msgid "Cannot remove temporary index (can't happen)"
+msgstr ""
+
+#: git-stash.sh:208
+msgid "Cannot record working tree state"
+msgstr ""
+
+#: git-stash.sh:246
+#, sh-format
+msgid "Cannot update $ref_stash with $w_commit"
+msgstr ""
+
+#: git-stash.sh:298
+#, sh-format
+msgid "error: unknown option for 'stash push': $option"
+msgstr ""
+
+#: git-stash.sh:312
+msgid "Can't use --patch and --include-untracked or --all at the same time"
+msgstr ""
+
+#: git-stash.sh:320
+msgid "No local changes to save"
+msgstr ""
+
+#: git-stash.sh:325
+msgid "Cannot initialize stash"
+msgstr ""
+
+#: git-stash.sh:329
+msgid "Cannot save the current status"
+msgstr ""
+
+#: git-stash.sh:330
+#, sh-format
+msgid "Saved working directory and index state $stash_msg"
+msgstr ""
+
+#: git-stash.sh:359
+msgid "Cannot remove worktree changes"
+msgstr ""
+
+#: git-stash.sh:507
+#, sh-format
+msgid "unknown option: $opt"
+msgstr ""
+
+#: git-stash.sh:520
+msgid "No stash entries found."
+msgstr ""
+
+#: git-stash.sh:527
+#, sh-format
+msgid "Too many revisions specified: $REV"
+msgstr ""
+
+#: git-stash.sh:542
+#, sh-format
+msgid "$reference is not a valid reference"
+msgstr ""
+
+#: git-stash.sh:570
+#, sh-format
+msgid "'$args' is not a stash-like commit"
+msgstr ""
+
+#: git-stash.sh:581
+#, sh-format
+msgid "'$args' is not a stash reference"
+msgstr ""
+
+#: git-stash.sh:589
+msgid "unable to refresh index"
+msgstr ""
+
+#: git-stash.sh:593
+msgid "Cannot apply a stash in the middle of a merge"
+msgstr ""
+
+#: git-stash.sh:601
+msgid "Conflicts in index. Try without --index."
+msgstr "Συγκρούσεις στο ευρετήριο. Δοκιμάστε χωρίς το --index."
+
+#: git-stash.sh:603
+msgid "Could not save index tree"
+msgstr ""
+
+#: git-stash.sh:612
+msgid "Could not restore untracked files from stash entry"
+msgstr ""
+
+#: git-stash.sh:637
+msgid "Cannot unstage modified files"
+msgstr ""
+
+#: git-stash.sh:652
+msgid "Index was not unstashed."
+msgstr ""
+
+#: git-stash.sh:666
+msgid "The stash entry is kept in case you need it again."
+msgstr ""
+
+#: git-stash.sh:675
+#, sh-format
+msgid "Dropped ${REV} ($s)"
+msgstr ""
+
+#: git-stash.sh:676
+#, sh-format
+msgid "${REV}: Could not drop stash entry"
+msgstr ""
+
+#: git-stash.sh:684
+msgid "No branch name specified"
+msgstr "Δε δόθηκε όνομα κλάδου"
+
+#: git-stash.sh:763
+msgid "(To restore them type \"git stash apply\")"
+msgstr ""
+
+#: git-submodule.sh:198
+msgid "Relative path can only be used from the toplevel of the working tree"
+msgstr ""
+
+#: git-submodule.sh:208
+#, sh-format
+msgid "repo URL: '$repo' must be absolute or begin with ./|../"
+msgstr ""
+
+#: git-submodule.sh:227
+#, sh-format
+msgid "'$sm_path' already exists in the index"
+msgstr ""
+
+#: git-submodule.sh:230
+#, sh-format
+msgid "'$sm_path' already exists in the index and is not a submodule"
+msgstr ""
+
+#: git-submodule.sh:236
+#, sh-format
+msgid ""
+"The following path is ignored by one of your .gitignore files:\n"
+"$sm_path\n"
+"Use -f if you really want to add it."
+msgstr ""
+
+#: git-submodule.sh:259
+#, sh-format
+msgid "Adding existing repo at '$sm_path' to the index"
+msgstr ""
+
+#: git-submodule.sh:261
+#, sh-format
+msgid "'$sm_path' already exists and is not a valid git repo"
+msgstr ""
+
+#: git-submodule.sh:269
+#, sh-format
+msgid "A git directory for '$sm_name' is found locally with remote(s):"
+msgstr ""
+
+#: git-submodule.sh:271
+#, sh-format
+msgid ""
+"If you want to reuse this local git directory instead of cloning again from\n"
+"  $realrepo\n"
+"use the '--force' option. If the local git directory is not the correct "
+"repo\n"
+"or you are unsure what this means choose another name with the '--name' "
+"option."
+msgstr ""
+
+#: git-submodule.sh:277
+#, sh-format
+msgid "Reactivating local git directory for submodule '$sm_name'."
+msgstr ""
+
+#: git-submodule.sh:289
+#, sh-format
+msgid "Unable to checkout submodule '$sm_path'"
+msgstr ""
+
+#: git-submodule.sh:294
+#, sh-format
+msgid "Failed to add submodule '$sm_path'"
+msgstr ""
+
+#: git-submodule.sh:303
+#, sh-format
+msgid "Failed to register submodule '$sm_path'"
+msgstr ""
+
+#: git-submodule.sh:563
+#, sh-format
+msgid "Unable to find current revision in submodule path '$displaypath'"
+msgstr ""
+
+#: git-submodule.sh:573
+#, sh-format
+msgid "Unable to fetch in submodule path '$sm_path'"
+msgstr ""
+
+#: git-submodule.sh:578
+#, sh-format
+msgid ""
+"Unable to find current ${remote_name}/${branch} revision in submodule path "
+"'$sm_path'"
+msgstr ""
+
+#: git-submodule.sh:596
+#, sh-format
+msgid "Unable to fetch in submodule path '$displaypath'"
+msgstr ""
+
+#: git-submodule.sh:602
+#, sh-format
+msgid ""
+"Fetched in submodule path '$displaypath', but it did not contain $sha1. "
+"Direct fetching of that commit failed."
+msgstr ""
+
+#: git-submodule.sh:609
+#, sh-format
+msgid "Unable to checkout '$sha1' in submodule path '$displaypath'"
+msgstr ""
+
+#: git-submodule.sh:610
+#, sh-format
+msgid "Submodule path '$displaypath': checked out '$sha1'"
+msgstr ""
+
+#: git-submodule.sh:614
+#, sh-format
+msgid "Unable to rebase '$sha1' in submodule path '$displaypath'"
+msgstr ""
+
+#: git-submodule.sh:615
+#, sh-format
+msgid "Submodule path '$displaypath': rebased into '$sha1'"
+msgstr ""
+
+#: git-submodule.sh:620
+#, sh-format
+msgid "Unable to merge '$sha1' in submodule path '$displaypath'"
+msgstr ""
+
+#: git-submodule.sh:621
+#, sh-format
+msgid "Submodule path '$displaypath': merged in '$sha1'"
+msgstr ""
+
+#: git-submodule.sh:626
+#, sh-format
+msgid "Execution of '$command $sha1' failed in submodule path '$displaypath'"
+msgstr ""
+
+#: git-submodule.sh:627
+#, sh-format
+msgid "Submodule path '$displaypath': '$command $sha1'"
+msgstr ""
+
+#: git-submodule.sh:658
+#, sh-format
+msgid "Failed to recurse into submodule path '$displaypath'"
+msgstr ""
+
+#: git-submodule.sh:754
+msgid "The --cached option cannot be used with the --files option"
+msgstr ""
+
+#: git-submodule.sh:806
+#, sh-format
+msgid "unexpected mode $mod_dst"
+msgstr ""
+
+#: git-submodule.sh:826
+#, sh-format
+msgid "  Warn: $display_name doesn't contain commit $sha1_src"
+msgstr ""
+
+#: git-submodule.sh:829
+#, sh-format
+msgid "  Warn: $display_name doesn't contain commit $sha1_dst"
+msgstr ""
+
+#: git-submodule.sh:832
+#, sh-format
+msgid "  Warn: $display_name doesn't contain commits $sha1_src and $sha1_dst"
+msgstr ""
+
+#: git-parse-remote.sh:89
+#, sh-format
+msgid "See git-${cmd}(1) for details."
+msgstr ""
+
+#: git-rebase--preserve-merges.sh:136
+#, sh-format
+msgid "Rebasing ($new_count/$total)"
+msgstr ""
+
+#: git-rebase--preserve-merges.sh:152
+msgid ""
+"\n"
+"Commands:\n"
+"p, pick <commit> = use commit\n"
+"r, reword <commit> = use commit, but edit the commit message\n"
+"e, edit <commit> = use commit, but stop for amending\n"
+"s, squash <commit> = use commit, but meld into previous commit\n"
+"f, fixup <commit> = like \"squash\", but discard this commit's log message\n"
+"x, exec <commit> = run command (the rest of the line) using shell\n"
+"d, drop <commit> = remove commit\n"
+"l, label <label> = label current HEAD with a name\n"
+"t, reset <label> = reset HEAD to a label\n"
+"m, merge [-C <commit> | -c <commit>] <label> [# <oneline>]\n"
+".       create a merge commit using the original merge commit's\n"
+".       message (or the oneline, if no original merge commit was\n"
+".       specified). Use -c <commit> to reword the commit message.\n"
+"\n"
+"These lines can be re-ordered; they are executed from top to bottom.\n"
+msgstr ""
+
+#: git-rebase--preserve-merges.sh:215
+#, sh-format
+msgid ""
+"You can amend the commit now, with\n"
+"\n"
+"\tgit commit --amend $gpg_sign_opt_quoted\n"
+"\n"
+"Once you are satisfied with your changes, run\n"
+"\n"
+"\tgit rebase --continue"
+msgstr ""
+"Μπορείτε να τροποποιήσετε την υποβολή τώρα, με\n"
+"\n"
+"\tgit commit --amend $gpg_sign_opt_quoted\n"
+"\n"
+"Όταν οι αλλαγές σας σας ικανοποιούν, τρέξτε\n"
+"\n"
+"\tgit rebase --continue"
+
+#: git-rebase--preserve-merges.sh:240
+#, sh-format
+msgid "$sha1: not a commit that can be picked"
+msgstr ""
+
+#: git-rebase--preserve-merges.sh:279
+#, sh-format
+msgid "Invalid commit name: $sha1"
+msgstr ""
+
+#: git-rebase--preserve-merges.sh:309
+msgid "Cannot write current commit's replacement sha1"
+msgstr ""
+
+#: git-rebase--preserve-merges.sh:360
+#, sh-format
+msgid "Fast-forward to $sha1"
+msgstr ""
+
+#: git-rebase--preserve-merges.sh:362
+#, sh-format
+msgid "Cannot fast-forward to $sha1"
+msgstr ""
+
+#: git-rebase--preserve-merges.sh:371
+#, sh-format
+msgid "Cannot move HEAD to $first_parent"
+msgstr ""
+
+#: git-rebase--preserve-merges.sh:376
+#, sh-format
+msgid "Refusing to squash a merge: $sha1"
+msgstr ""
+
+#: git-rebase--preserve-merges.sh:394
+#, sh-format
+msgid "Error redoing merge $sha1"
+msgstr ""
+
+#: git-rebase--preserve-merges.sh:403
+#, sh-format
+msgid "Could not pick $sha1"
+msgstr ""
+
+#: git-rebase--preserve-merges.sh:412
+#, sh-format
+msgid "This is the commit message #${n}:"
+msgstr ""
+
+#: git-rebase--preserve-merges.sh:417
+#, sh-format
+msgid "The commit message #${n} will be skipped:"
+msgstr ""
+
+#: git-rebase--preserve-merges.sh:428
+#, sh-format
+msgid "This is a combination of $count commit."
+msgid_plural "This is a combination of $count commits."
+msgstr[0] ""
+msgstr[1] ""
+
+#: git-rebase--preserve-merges.sh:437
+#, sh-format
+msgid "Cannot write $fixup_msg"
+msgstr ""
+
+#: git-rebase--preserve-merges.sh:440
+msgid "This is a combination of 2 commits."
+msgstr ""
+
+#: git-rebase--preserve-merges.sh:481 git-rebase--preserve-merges.sh:524
+#: git-rebase--preserve-merges.sh:527
+#, sh-format
+msgid "Could not apply $sha1... $rest"
+msgstr ""
+
+#: git-rebase--preserve-merges.sh:556
+#, sh-format
+msgid ""
+"Could not amend commit after successfully picking $sha1... $rest\n"
+"This is most likely due to an empty commit message, or the pre-commit hook\n"
+"failed. If the pre-commit hook failed, you may need to resolve the issue "
+"before\n"
+"you are able to reword the commit."
+msgstr ""
+"Δεν ήταν δυνατή η τροποποίηση της υποβολής μετά από την επιτυχή διαλογή του "
+"$sha1... $rest\n"
+"Κατά πάσα πιθανότητα οφείλεται σε κενό μήνυμα υποβολής, ή απέτυχε το "
+"άγκιστρο προ υποβολής.\n"
+"Αν απέτυχε το άγκιστρο προ υποβολής, μπορεί να χρειαστεί να επιλύσετε το "
+"θέμα πριν να\n"
+"μπορέσετε να αναδιατυπώσετε την υποβολή."
+
+#: git-rebase--preserve-merges.sh:571
+#, sh-format
+msgid "Stopped at $sha1_abbrev... $rest"
+msgstr ""
+
+#: git-rebase--preserve-merges.sh:586
+#, sh-format
+msgid "Cannot '$squash_style' without a previous commit"
+msgstr ""
+
+#: git-rebase--preserve-merges.sh:628
+#, sh-format
+msgid "Executing: $rest"
+msgstr ""
+
+#: git-rebase--preserve-merges.sh:636
+#, sh-format
+msgid "Execution failed: $rest"
+msgstr ""
+
+#: git-rebase--preserve-merges.sh:638
+msgid "and made changes to the index and/or the working tree"
+msgstr ""
+
+#: git-rebase--preserve-merges.sh:640
+msgid ""
+"You can fix the problem, and then run\n"
+"\n"
+"\tgit rebase --continue"
+msgstr ""
+"Μπορείτε να διορθώσετε το πρόβλημα, και μετά να τρέξετε\n"
+"\n"
+"\tgit rebase --continue"
+
+#. TRANSLATORS: after these lines is a command to be issued by the user
+#: git-rebase--preserve-merges.sh:653
+#, sh-format
+msgid ""
+"Execution succeeded: $rest\n"
+"but left changes to the index and/or the working tree\n"
+"Commit or stash your changes, and then run\n"
+"\n"
+"\tgit rebase --continue"
+msgstr ""
+
+#: git-rebase--preserve-merges.sh:664
+#, sh-format
+msgid "Unknown command: $command $sha1 $rest"
+msgstr ""
+
+#: git-rebase--preserve-merges.sh:665
+msgid "Please fix this using 'git rebase --edit-todo'."
+msgstr ""
+
+#: git-rebase--preserve-merges.sh:700
+#, sh-format
+msgid "Successfully rebased and updated $head_name."
+msgstr ""
+
+#: git-rebase--preserve-merges.sh:757
+msgid "Could not remove CHERRY_PICK_HEAD"
+msgstr ""
+
+#: git-rebase--preserve-merges.sh:762
+#, sh-format
+msgid ""
+"You have staged changes in your working tree.\n"
+"If these changes are meant to be\n"
+"squashed into the previous commit, run:\n"
+"\n"
+"  git commit --amend $gpg_sign_opt_quoted\n"
+"\n"
+"If they are meant to go into a new commit, run:\n"
+"\n"
+"  git commit $gpg_sign_opt_quoted\n"
+"\n"
+"In both cases, once you're done, continue with:\n"
+"\n"
+"  git rebase --continue\n"
+msgstr ""
+"Έχετε προετοιμασμένες αλλαγές στο δέντρο εργασίας σας.\n"
+"Αν αυτές οι αλλαγές πρέπει να \n"
+"συμπτυχθούν μέσα στην προηγούμενη υποβολή, τρέξτε:\n"
+"\n"
+"  git commit --amend $gpg_sign_opt_quoted\n"
+"\n"
+"Αν πρέπει να πάνε σε νέα υποβολή, τρέξτε:\n"
+"\n"
+"  git commit $gpg_sign_opt_quoted\n"
+"\n"
+"Και στις δύο περιπτώσεις, μόλις τελειώσετε, συνεχίστε με:\n"
+"\n"
+"  git rebase --continue\n"
+
+#: git-rebase--preserve-merges.sh:779
+msgid "Error trying to find the author identity to amend commit"
+msgstr ""
+
+#: git-rebase--preserve-merges.sh:784
+msgid ""
+"You have uncommitted changes in your working tree. Please commit them\n"
+"first and then run 'git rebase --continue' again."
+msgstr ""
+"Έχετε μη συγχωνευμένες αλλαγές στο δέντρο εργασίας σας. Παρακαλώ υποβάλετέ "
+"τις\n"
+"πρώτα και μετά τρέξτε 'git rebase --continue' πάλι."
+
+#: git-rebase--preserve-merges.sh:789 git-rebase--preserve-merges.sh:793
+msgid "Could not commit staged changes."
+msgstr ""
+
+#: git-rebase--preserve-merges.sh:824 git-rebase--preserve-merges.sh:910
+msgid "Could not execute editor"
+msgstr ""
+
+#: git-rebase--preserve-merges.sh:845
+#, sh-format
+msgid "Could not checkout $switch_to"
+msgstr ""
+
+#: git-rebase--preserve-merges.sh:852
+msgid "No HEAD?"
+msgstr ""
+
+#: git-rebase--preserve-merges.sh:853
+#, sh-format
+msgid "Could not create temporary $state_dir"
+msgstr ""
+
+#: git-rebase--preserve-merges.sh:856
+msgid "Could not mark as interactive"
+msgstr ""
+
+#: git-rebase--preserve-merges.sh:888
+#, sh-format
+msgid "Rebase $shortrevisions onto $shortonto ($todocount command)"
+msgid_plural "Rebase $shortrevisions onto $shortonto ($todocount commands)"
+msgstr[0] ""
+msgstr[1] ""
+
+#: git-rebase--preserve-merges.sh:942 git-rebase--preserve-merges.sh:947
+msgid "Could not init rewritten commits"
+msgstr ""
+
+#: git-sh-setup.sh:89 git-sh-setup.sh:94
+#, sh-format
+msgid "usage: $dashless $USAGE"
+msgstr "χρήση: $dashless $USAGE"
+
+#: git-sh-setup.sh:190
+#, sh-format
+msgid "Cannot chdir to $cdup, the toplevel of the working tree"
+msgstr ""
+
+#: git-sh-setup.sh:199 git-sh-setup.sh:206
+#, sh-format
+msgid "fatal: $program_name cannot be used without a working tree."
+msgstr ""
+
+#: git-sh-setup.sh:220
+msgid "Cannot rebase: You have unstaged changes."
+msgstr ""
+
+#: git-sh-setup.sh:223
+msgid "Cannot rewrite branches: You have unstaged changes."
+msgstr ""
+
+#: git-sh-setup.sh:226
+msgid "Cannot pull with rebase: You have unstaged changes."
+msgstr ""
+
+#: git-sh-setup.sh:229
+#, sh-format
+msgid "Cannot $action: You have unstaged changes."
+msgstr ""
+
+#: git-sh-setup.sh:242
+msgid "Cannot rebase: Your index contains uncommitted changes."
+msgstr ""
+
+#: git-sh-setup.sh:245
+msgid "Cannot pull with rebase: Your index contains uncommitted changes."
+msgstr ""
+
+#: git-sh-setup.sh:248
+#, sh-format
+msgid "Cannot $action: Your index contains uncommitted changes."
+msgstr ""
+
+#: git-sh-setup.sh:252
+msgid "Additionally, your index contains uncommitted changes."
+msgstr "Επιπρόσθετα, το ευρετήριό σας περιέχει μη υποβεβλημένες αλλαγές."
+
+#: git-sh-setup.sh:372
+msgid "You need to run this command from the toplevel of the working tree."
+msgstr ""
+"Χρειάζεται να τρέξετε αυτή την εντολή από το ψηλότερο επίπεδο του δέντρου "
+"εργασίας."
+
+#: git-sh-setup.sh:377
+msgid "Unable to determine absolute path of git directory"
+msgstr ""
+
+#. TRANSLATORS: you can adjust this to align "git add -i" status menu
+#: git-add--interactive.perl:196
+#, perl-format
+msgid "%12s %12s %s"
+msgstr ""
+
+#: git-add--interactive.perl:197
+msgid "staged"
+msgstr ""
+
+#: git-add--interactive.perl:197
+msgid "unstaged"
+msgstr ""
+
+#: git-add--interactive.perl:253 git-add--interactive.perl:278
+msgid "binary"
+msgstr ""
+
+#: git-add--interactive.perl:262 git-add--interactive.perl:316
+msgid "nothing"
+msgstr ""
+
+#: git-add--interactive.perl:298 git-add--interactive.perl:313
+msgid "unchanged"
+msgstr ""
+
+#: git-add--interactive.perl:609
+#, perl-format
+msgid "added %d path\n"
+msgid_plural "added %d paths\n"
+msgstr[0] ""
+msgstr[1] ""
+
+#: git-add--interactive.perl:612
+#, perl-format
+msgid "updated %d path\n"
+msgid_plural "updated %d paths\n"
+msgstr[0] ""
+msgstr[1] ""
+
+#: git-add--interactive.perl:615
+#, perl-format
+msgid "reverted %d path\n"
+msgid_plural "reverted %d paths\n"
+msgstr[0] ""
+msgstr[1] ""
+
+#: git-add--interactive.perl:618
+#, perl-format
+msgid "touched %d path\n"
+msgid_plural "touched %d paths\n"
+msgstr[0] ""
+msgstr[1] ""
+
+#: git-add--interactive.perl:627
+msgid "Update"
+msgstr ""
+
+#: git-add--interactive.perl:639
+msgid "Revert"
+msgstr ""
+
+#: git-add--interactive.perl:662
+#, perl-format
+msgid "note: %s is untracked now.\n"
+msgstr "σημείωση: το %s δεν παρακολουθείται τώρα.\n"
+
+#: git-add--interactive.perl:673
+msgid "Add untracked"
+msgstr ""
+
+#: git-add--interactive.perl:679
+msgid "No untracked files.\n"
+msgstr ""
+
+#: git-add--interactive.perl:1033
+msgid ""
+"If the patch applies cleanly, the edited hunk will immediately be\n"
+"marked for staging."
+msgstr ""
+
+#: git-add--interactive.perl:1036
+msgid ""
+"If the patch applies cleanly, the edited hunk will immediately be\n"
+"marked for stashing."
+msgstr ""
+
+#: git-add--interactive.perl:1039
+msgid ""
+"If the patch applies cleanly, the edited hunk will immediately be\n"
+"marked for unstaging."
+msgstr ""
+
+#: git-add--interactive.perl:1042 git-add--interactive.perl:1051
+msgid ""
+"If the patch applies cleanly, the edited hunk will immediately be\n"
+"marked for applying."
+msgstr ""
+
+#: git-add--interactive.perl:1045 git-add--interactive.perl:1048
+msgid ""
+"If the patch applies cleanly, the edited hunk will immediately be\n"
+"marked for discarding."
+msgstr ""
+
+#: git-add--interactive.perl:1085
+#, perl-format
+msgid "failed to open hunk edit file for writing: %s"
+msgstr ""
+
+#: git-add--interactive.perl:1086
+msgid "Manual hunk edit mode -- see bottom for a quick guide.\n"
+msgstr ""
+
+#: git-add--interactive.perl:1092
+#, perl-format
+msgid ""
+"---\n"
+"To remove '%s' lines, make them ' ' lines (context).\n"
+"To remove '%s' lines, delete them.\n"
+"Lines starting with %s will be removed.\n"
+msgstr ""
+
+#. TRANSLATORS: 'it' refers to the patch mentioned in the previous messages.
+#: git-add--interactive.perl:1100
+msgid ""
+"If it does not apply cleanly, you will be given an opportunity to\n"
+"edit again.  If all lines of the hunk are removed, then the edit is\n"
+"aborted and the hunk is left unchanged.\n"
+msgstr ""
+
+#: git-add--interactive.perl:1114
+#, perl-format
+msgid "failed to open hunk edit file for reading: %s"
+msgstr ""
+
+#. TRANSLATORS: do not translate [y/n]
+#. The program will only accept that input
+#. at this point.
+#. Consider translating (saying "no" discards!) as
+#. (saying "n" for "no" discards!) if the translation
+#. of the word "no" does not start with n.
+#: git-add--interactive.perl:1213
+msgid ""
+"Your edited hunk does not apply. Edit again (saying \"no\" discards!) [y/n]? "
+msgstr ""
+"Η επεξεργασμένη αλλαγή σας δεν εφαρμόζεται. Να γίνει επεξεργασία πάλι (με \"n"
+"\" απορρίπτεται!) [y/n];"
+
+#: git-add--interactive.perl:1222
+msgid ""
+"y - stage this hunk\n"
+"n - do not stage this hunk\n"
+"q - quit; do not stage this hunk or any of the remaining ones\n"
+"a - stage this hunk and all later hunks in the file\n"
+"d - do not stage this hunk or any of the later hunks in the file"
+msgstr ""
+"y - προετοιμασία αυτής της αλλαγής\n"
+"n - όχι προετοιμασία αυτής της αλλαγής\n"
+"q - έξοδος, όχι προετοιμασία αυτής της αλλαγής ή καμίας από όσες απομένουν\n"
+"a - προετοιμασία αυτής της αλλαγής και όλων των επόμενων αλλαγών στο αρχείο\n"
+"d - όχι προετοιμασία αυτής της αλλαγής ή καμίας από τις επόμενες αλλαγές στο "
+"αρχείο"
+
+#: git-add--interactive.perl:1228
+msgid ""
+"y - stash this hunk\n"
+"n - do not stash this hunk\n"
+"q - quit; do not stash this hunk or any of the remaining ones\n"
+"a - stash this hunk and all later hunks in the file\n"
+"d - do not stash this hunk or any of the later hunks in the file"
+msgstr ""
+"y - αποθήκευση αυτής της αλλαγής\n"
+"n - όχι αποθήκευση αυτής της αλλαγής\n"
+"q - έξοδος, όχι αποθήκευση αυτής της αλλαγής ή καμίας από όσες απομένουν\n"
+"a - αποθήκευση αυτής της αλλαγής και όλων των επόμενων αλλαγών στο αρχείο\n"
+"d - όχι αποθήκευση αυτής της αλλαγής ή καμίας από τις επόμενες αλλαγές στο "
+"αρχείο"
+
+#: git-add--interactive.perl:1234
+msgid ""
+"y - unstage this hunk\n"
+"n - do not unstage this hunk\n"
+"q - quit; do not unstage this hunk or any of the remaining ones\n"
+"a - unstage this hunk and all later hunks in the file\n"
+"d - do not unstage this hunk or any of the later hunks in the file"
+msgstr ""
+"y - αποπροετοιμασία αυτής της αλλαγής\n"
+"n - όχι αποπροετοιμασία αυτής της αλλαγής\n"
+"q - έξοδος, όχι αποπροετοιμασία αυτής της αλλαγής ή καμίας από όσες "
+"απομένουν\n"
+"a - αποπροετοιμασία αυτής της αλλαγής και όλων των επόμενων αλλαγών στο "
+"αρχείο\n"
+"d - όχι αποπροετοιμασία αυτής της αλλαγής ή καμίας από τις επόμενες αλλαγές "
+"στο αρχείο"
+
+#: git-add--interactive.perl:1240
+msgid ""
+"y - apply this hunk to index\n"
+"n - do not apply this hunk to index\n"
+"q - quit; do not apply this hunk or any of the remaining ones\n"
+"a - apply this hunk and all later hunks in the file\n"
+"d - do not apply this hunk or any of the later hunks in the file"
+msgstr ""
+
+#: git-add--interactive.perl:1246
+msgid ""
+"y - discard this hunk from worktree\n"
+"n - do not discard this hunk from worktree\n"
+"q - quit; do not discard this hunk or any of the remaining ones\n"
+"a - discard this hunk and all later hunks in the file\n"
+"d - do not discard this hunk or any of the later hunks in the file"
+msgstr ""
+
+#: git-add--interactive.perl:1252
+msgid ""
+"y - discard this hunk from index and worktree\n"
+"n - do not discard this hunk from index and worktree\n"
+"q - quit; do not discard this hunk or any of the remaining ones\n"
+"a - discard this hunk and all later hunks in the file\n"
+"d - do not discard this hunk or any of the later hunks in the file"
+msgstr ""
+
+#: git-add--interactive.perl:1258
+msgid ""
+"y - apply this hunk to index and worktree\n"
+"n - do not apply this hunk to index and worktree\n"
+"q - quit; do not apply this hunk or any of the remaining ones\n"
+"a - apply this hunk and all later hunks in the file\n"
+"d - do not apply this hunk or any of the later hunks in the file"
+msgstr ""
+
+#: git-add--interactive.perl:1273
+msgid ""
+"g - select a hunk to go to\n"
+"/ - search for a hunk matching the given regex\n"
+"j - leave this hunk undecided, see next undecided hunk\n"
+"J - leave this hunk undecided, see next hunk\n"
+"k - leave this hunk undecided, see previous undecided hunk\n"
+"K - leave this hunk undecided, see previous hunk\n"
+"s - split the current hunk into smaller hunks\n"
+"e - manually edit the current hunk\n"
+"? - print help\n"
+msgstr ""
+"g - επιλογή αλλαγής για να πάτε\n"
+"/ - αναζήτηση για αλλαγή που ταιριάζει με τη δοθείσα κανονική έκφραση\n"
+"j - όχι απόφαση για αυτή την αλλαγή, δες την επόμενη αλλαγή χωρίς απόφαση\n"
+"J - όχι απόφαση για αυτή την αλλαγή, δες την επόμενη αλλαγή\n"
+"k - όχι απόφαση για αυτή την αλλαγή, δες την προηγούμενη αλλαγή χωρίς "
+"απόφαση\n"
+"K - όχι απόφαση για αυτή την αλλαγή, δες την προηγούμενη αλλαγή\n"
+"s - τεμάχισε την τρέχουσα αλλαγή σε μικρότερες αλλαγές\n"
+"e - χειροκίνητη επεξεργασία της παρούσας αλλαγής\n"
+"? - προβολή βοήθειας\n"
+
+#: git-add--interactive.perl:1304
+msgid "The selected hunks do not apply to the index!\n"
+msgstr ""
+
+#: git-add--interactive.perl:1305
+msgid "Apply them to the worktree anyway? "
+msgstr "Να γίνει πάραυτα εφαρμογή τους στο δέντρο εργασίας; "
+
+#: git-add--interactive.perl:1308
+msgid "Nothing was applied.\n"
+msgstr "Δεν εφαρμόστηκε τίποτα.\n"
+
+#: git-add--interactive.perl:1319
+#, perl-format
+msgid "ignoring unmerged: %s\n"
+msgstr ""
+
+#: git-add--interactive.perl:1328
+msgid "Only binary files changed.\n"
+msgstr ""
+
+#: git-add--interactive.perl:1330
+msgid "No changes.\n"
+msgstr "Δεν υπάρχουν αλλαγές.\n"
+
+#: git-add--interactive.perl:1338
+msgid "Patch update"
+msgstr ""
+
+#: git-add--interactive.perl:1390
+#, perl-format
+msgid "Stage mode change [y,n,q,a,d%s,?]? "
+msgstr ""
+
+#: git-add--interactive.perl:1391
+#, perl-format
+msgid "Stage deletion [y,n,q,a,d%s,?]? "
+msgstr ""
+
+#: git-add--interactive.perl:1392
+#, perl-format
+msgid "Stage this hunk [y,n,q,a,d%s,?]? "
+msgstr ""
+
+#: git-add--interactive.perl:1395
+#, perl-format
+msgid "Stash mode change [y,n,q,a,d%s,?]? "
+msgstr ""
+
+#: git-add--interactive.perl:1396
+#, perl-format
+msgid "Stash deletion [y,n,q,a,d%s,?]? "
+msgstr ""
+
+#: git-add--interactive.perl:1397
+#, perl-format
+msgid "Stash this hunk [y,n,q,a,d%s,?]? "
+msgstr ""
+
+#: git-add--interactive.perl:1400
+#, perl-format
+msgid "Unstage mode change [y,n,q,a,d%s,?]? "
+msgstr ""
+
+#: git-add--interactive.perl:1401
+#, perl-format
+msgid "Unstage deletion [y,n,q,a,d%s,?]? "
+msgstr ""
+
+#: git-add--interactive.perl:1402
+#, perl-format
+msgid "Unstage this hunk [y,n,q,a,d%s,?]? "
+msgstr ""
+
+#: git-add--interactive.perl:1405
+#, perl-format
+msgid "Apply mode change to index [y,n,q,a,d%s,?]? "
+msgstr ""
+"Να γίνει εφαρμογή της αλλαγής λειτουργίας στο ευρετήριο [y,n,q,a,d%s,?]; "
+
+#: git-add--interactive.perl:1406
+#, perl-format
+msgid "Apply deletion to index [y,n,q,a,d%s,?]? "
+msgstr ""
+
+#: git-add--interactive.perl:1407
+#, perl-format
+msgid "Apply this hunk to index [y,n,q,a,d%s,?]? "
+msgstr ""
+
+#: git-add--interactive.perl:1410
+#, perl-format
+msgid "Discard mode change from worktree [y,n,q,a,d%s,?]? "
+msgstr ""
+
+#: git-add--interactive.perl:1411
+#, perl-format
+msgid "Discard deletion from worktree [y,n,q,a,d%s,?]? "
+msgstr ""
+
+#: git-add--interactive.perl:1412
+#, perl-format
+msgid "Discard this hunk from worktree [y,n,q,a,d%s,?]? "
+msgstr ""
+
+#: git-add--interactive.perl:1415
+#, perl-format
+msgid "Discard mode change from index and worktree [y,n,q,a,d%s,?]? "
+msgstr ""
+
+#: git-add--interactive.perl:1416
+#, perl-format
+msgid "Discard deletion from index and worktree [y,n,q,a,d%s,?]? "
+msgstr ""
+
+#: git-add--interactive.perl:1417
+#, perl-format
+msgid "Discard this hunk from index and worktree [y,n,q,a,d%s,?]? "
+msgstr ""
+
+#: git-add--interactive.perl:1420
+#, perl-format
+msgid "Apply mode change to index and worktree [y,n,q,a,d%s,?]? "
+msgstr ""
+"Να γίνει εφαρμογή της αλλαγής λειτουργίας στο ευρετήριο και το δέντρο "
+"εργασίας [y,n,q,a,d%s,?]; "
+
+#: git-add--interactive.perl:1421
+#, perl-format
+msgid "Apply deletion to index and worktree [y,n,q,a,d%s,?]? "
+msgstr ""
+
+#: git-add--interactive.perl:1422
+#, perl-format
+msgid "Apply this hunk to index and worktree [y,n,q,a,d%s,?]? "
+msgstr ""
+
+#: git-add--interactive.perl:1522
+msgid "No other hunks to goto\n"
+msgstr ""
+
+#: git-add--interactive.perl:1529
+msgid "go to which hunk (<ret> to see more)? "
+msgstr ""
+
+#: git-add--interactive.perl:1531
+msgid "go to which hunk? "
+msgstr ""
+
+#: git-add--interactive.perl:1540
+#, perl-format
+msgid "Invalid number: '%s'\n"
+msgstr ""
+
+#: git-add--interactive.perl:1545
+#, perl-format
+msgid "Sorry, only %d hunk available.\n"
+msgid_plural "Sorry, only %d hunks available.\n"
+msgstr[0] ""
+msgstr[1] ""
+
+#: git-add--interactive.perl:1571
+msgid "No other hunks to search\n"
+msgstr ""
+
+#: git-add--interactive.perl:1575
+msgid "search for regex? "
+msgstr ""
+
+#: git-add--interactive.perl:1588
+#, perl-format
+msgid "Malformed search regexp %s: %s\n"
+msgstr ""
+
+#: git-add--interactive.perl:1598
+msgid "No hunk matches the given pattern\n"
+msgstr ""
+
+#: git-add--interactive.perl:1610 git-add--interactive.perl:1632
+msgid "No previous hunk\n"
+msgstr ""
+
+#: git-add--interactive.perl:1619 git-add--interactive.perl:1638
+msgid "No next hunk\n"
+msgstr ""
+
+#: git-add--interactive.perl:1644
+msgid "Sorry, cannot split this hunk\n"
+msgstr ""
+
+#: git-add--interactive.perl:1650
+#, perl-format
+msgid "Split into %d hunk.\n"
+msgid_plural "Split into %d hunks.\n"
+msgstr[0] ""
+msgstr[1] ""
+
+#: git-add--interactive.perl:1660
+msgid "Sorry, cannot edit this hunk\n"
+msgstr ""
+
+#: git-add--interactive.perl:1706
+msgid "Review diff"
+msgstr ""
+
+#. TRANSLATORS: please do not translate the command names
+#. 'status', 'update', 'revert', etc.
+#: git-add--interactive.perl:1725
+msgid ""
+"status        - show paths with changes\n"
+"update        - add working tree state to the staged set of changes\n"
+"revert        - revert staged set of changes back to the HEAD version\n"
+"patch         - pick hunks and update selectively\n"
+"diff          - view diff between HEAD and index\n"
+"add untracked - add contents of untracked files to the staged set of "
+"changes\n"
+msgstr ""
+
+#: git-add--interactive.perl:1742 git-add--interactive.perl:1747
+#: git-add--interactive.perl:1750 git-add--interactive.perl:1757
+#: git-add--interactive.perl:1761 git-add--interactive.perl:1767
+msgid "missing --"
+msgstr ""
+
+#: git-add--interactive.perl:1763
+#, perl-format
+msgid "unknown --patch mode: %s"
+msgstr ""
+
+#: git-add--interactive.perl:1769 git-add--interactive.perl:1775
+#, perl-format
+msgid "invalid argument %s, expecting --"
+msgstr ""
+
+#: git-send-email.perl:138
+msgid "local zone differs from GMT by a non-minute interval\n"
+msgstr ""
+
+#: git-send-email.perl:145 git-send-email.perl:151
+msgid "local time offset greater than or equal to 24 hours\n"
+msgstr ""
+
+#: git-send-email.perl:219 git-send-email.perl:225
+msgid "the editor exited uncleanly, aborting everything"
+msgstr ""
+
+#: git-send-email.perl:302
+#, perl-format
+msgid ""
+"'%s' contains an intermediate version of the email you were composing.\n"
+msgstr ""
+
+#: git-send-email.perl:307
+#, perl-format
+msgid "'%s.final' contains the composed email.\n"
+msgstr ""
+
+#: git-send-email.perl:326
+msgid "--dump-aliases incompatible with other options\n"
+msgstr ""
+
+#: git-send-email.perl:395 git-send-email.perl:650
+msgid "Cannot run git format-patch from outside a repository\n"
+msgstr ""
+
+#: git-send-email.perl:398
+msgid ""
+"`batch-size` and `relogin` must be specified together (via command-line or "
+"configuration option)\n"
+msgstr ""
+
+#: git-send-email.perl:468
+#, perl-format
+msgid "Unknown --suppress-cc field: '%s'\n"
+msgstr ""
+
+#: git-send-email.perl:497
+#, perl-format
+msgid "Unknown --confirm setting: '%s'\n"
+msgstr ""
+
+#: git-send-email.perl:525
+#, perl-format
+msgid "warning: sendmail alias with quotes is not supported: %s\n"
+msgstr ""
+
+#: git-send-email.perl:527
+#, perl-format
+msgid "warning: `:include:` not supported: %s\n"
+msgstr ""
+
+#: git-send-email.perl:529
+#, perl-format
+msgid "warning: `/file` or `|pipe` redirection not supported: %s\n"
+msgstr ""
+
+#: git-send-email.perl:534
+#, perl-format
+msgid "warning: sendmail line is not recognized: %s\n"
+msgstr ""
+
+#: git-send-email.perl:616
+#, perl-format
+msgid ""
+"File '%s' exists but it could also be the range of commits\n"
+"to produce patches for.  Please disambiguate by...\n"
+"\n"
+"    * Saying \"./%s\" if you mean a file; or\n"
+"    * Giving --format-patch option if you mean a range.\n"
+msgstr ""
+
+#: git-send-email.perl:637
+#, perl-format
+msgid "Failed to opendir %s: %s"
+msgstr ""
+
+#: git-send-email.perl:661
+#, perl-format
+msgid ""
+"fatal: %s: %s\n"
+"warning: no patches were sent\n"
+msgstr ""
+
+#: git-send-email.perl:672
+msgid ""
+"\n"
+"No patch files specified!\n"
+"\n"
+msgstr ""
+
+#: git-send-email.perl:685
+#, perl-format
+msgid "No subject line in %s?"
+msgstr ""
+
+#: git-send-email.perl:695
+#, perl-format
+msgid "Failed to open for writing %s: %s"
+msgstr ""
+
+#: git-send-email.perl:706
+msgid ""
+"Lines beginning in \"GIT:\" will be removed.\n"
+"Consider including an overall diffstat or table of contents\n"
+"for the patch you are writing.\n"
+"\n"
+"Clear the body content if you don't wish to send a summary.\n"
+msgstr ""
+
+#: git-send-email.perl:730
+#, perl-format
+msgid "Failed to open %s: %s"
+msgstr ""
+
+#: git-send-email.perl:747
+#, perl-format
+msgid "Failed to open %s.final: %s"
+msgstr ""
+
+#: git-send-email.perl:790
+msgid "Summary email is empty, skipping it\n"
+msgstr ""
+
+#. TRANSLATORS: please keep [y/N] as is.
+#: git-send-email.perl:825
+#, perl-format
+msgid "Are you sure you want to use <%s> [y/N]? "
+msgstr "Επιβεβαιώνετε πως θέλετε να χρησιμοποιήσετε <%s> [y/N]? "
+
+#: git-send-email.perl:880
+msgid ""
+"The following files are 8bit, but do not declare a Content-Transfer-"
+"Encoding.\n"
+msgstr ""
+
+#: git-send-email.perl:885
+msgid "Which 8bit encoding should I declare [UTF-8]? "
+msgstr ""
+
+#: git-send-email.perl:893
+#, perl-format
+msgid ""
+"Refusing to send because the patch\n"
+"\t%s\n"
+"has the template subject '*** SUBJECT HERE ***'. Pass --force if you really "
+"want to send.\n"
+msgstr ""
+
+#: git-send-email.perl:912
+msgid "To whom should the emails be sent (if anyone)?"
+msgstr ""
+
+#: git-send-email.perl:930
+#, perl-format
+msgid "fatal: alias '%s' expands to itself\n"
+msgstr ""
+
+#: git-send-email.perl:942
+msgid "Message-ID to be used as In-Reply-To for the first email (if any)? "
+msgstr ""
+
+#: git-send-email.perl:1000 git-send-email.perl:1008
+#, perl-format
+msgid "error: unable to extract a valid address from: %s\n"
+msgstr ""
+
+#. TRANSLATORS: Make sure to include [q] [d] [e] in your
+#. translation. The program will only accept English input
+#. at this point.
+#: git-send-email.perl:1012
+msgid "What to do with this address? ([q]uit|[d]rop|[e]dit): "
+msgstr ""
+
+#: git-send-email.perl:1329
+#, perl-format
+msgid "CA path \"%s\" does not exist"
+msgstr ""
+
+#: git-send-email.perl:1412
+msgid ""
+"    The Cc list above has been expanded by additional\n"
+"    addresses found in the patch commit message. By default\n"
+"    send-email prompts before sending whenever this occurs.\n"
+"    This behavior is controlled by the sendemail.confirm\n"
+"    configuration setting.\n"
+"\n"
+"    For additional information, run 'git send-email --help'.\n"
+"    To retain the current behavior, but squelch this message,\n"
+"    run 'git config --global sendemail.confirm auto'.\n"
+"\n"
+msgstr ""
+
+#. TRANSLATORS: Make sure to include [y] [n] [e] [q] [a] in your
+#. translation. The program will only accept English input
+#. at this point.
+#: git-send-email.perl:1427
+msgid "Send this email? ([y]es|[n]o|[e]dit|[q]uit|[a]ll): "
+msgstr "Να γίνει αποστολή αυτού του email; ([y]es|[n]o|[e]dit|[q]uit|[a]ll): "
+
+#: git-send-email.perl:1430
+msgid "Send this email reply required"
+msgstr ""
+
+#: git-send-email.perl:1458
+msgid "The required SMTP server is not properly defined."
+msgstr ""
+
+#: git-send-email.perl:1505
+#, perl-format
+msgid "Server does not support STARTTLS! %s"
+msgstr ""
+
+#: git-send-email.perl:1510 git-send-email.perl:1514
+#, perl-format
+msgid "STARTTLS failed! %s"
+msgstr "Το STARTTLS απέτυχε! %s"
+
+#: git-send-email.perl:1523
+msgid "Unable to initialize SMTP properly. Check config and use --smtp-debug."
+msgstr ""
+
+#: git-send-email.perl:1541
+#, perl-format
+msgid "Failed to send %s\n"
+msgstr ""
+
+#: git-send-email.perl:1544
+#, perl-format
+msgid "Dry-Sent %s\n"
+msgstr ""
+
+#: git-send-email.perl:1544
+#, perl-format
+msgid "Sent %s\n"
+msgstr ""
+
+#: git-send-email.perl:1546
+msgid "Dry-OK. Log says:\n"
+msgstr ""
+
+#: git-send-email.perl:1546
+msgid "OK. Log says:\n"
+msgstr ""
+
+#: git-send-email.perl:1558
+msgid "Result: "
+msgstr "Αποτέλεσμα: "
+
+#: git-send-email.perl:1561
+msgid "Result: OK\n"
+msgstr "Αποτέλεσμα: OK\n"
+
+#: git-send-email.perl:1579
+#, perl-format
+msgid "can't open file %s"
+msgstr "δεν ήταν δυνατό να ανοιχτεί το αρχείο %s"
+
+#: git-send-email.perl:1626 git-send-email.perl:1646
+#, perl-format
+msgid "(mbox) Adding cc: %s from line '%s'\n"
+msgstr ""
+
+#: git-send-email.perl:1632
+#, perl-format
+msgid "(mbox) Adding to: %s from line '%s'\n"
+msgstr ""
+
+#: git-send-email.perl:1685
+#, perl-format
+msgid "(non-mbox) Adding cc: %s from line '%s'\n"
+msgstr ""
+
+#: git-send-email.perl:1720
+#, perl-format
+msgid "(body) Adding cc: %s from line '%s'\n"
+msgstr ""
+
+#: git-send-email.perl:1831
+#, perl-format
+msgid "(%s) Could not execute '%s'"
+msgstr ""
+
+#: git-send-email.perl:1838
+#, perl-format
+msgid "(%s) Adding %s: %s from: '%s'\n"
+msgstr ""
+
+#: git-send-email.perl:1842
+#, perl-format
+msgid "(%s) failed to close pipe to '%s'"
+msgstr ""
+
+#: git-send-email.perl:1872
+msgid "cannot send message as 7bit"
+msgstr ""
+
+#: git-send-email.perl:1880
+msgid "invalid transfer encoding"
+msgstr ""
+
+#: git-send-email.perl:1921 git-send-email.perl:1973 git-send-email.perl:1983
+#, perl-format
+msgid "unable to open %s: %s\n"
+msgstr ""
+
+#: git-send-email.perl:1924
+#, perl-format
+msgid "%s: patch contains a line longer than 998 characters"
+msgstr ""
+
+#: git-send-email.perl:1941
+#, perl-format
+msgid "Skipping %s with backup suffix '%s'.\n"
+msgstr ""
+
+#. TRANSLATORS: please keep "[y|N]" as is.
+#: git-send-email.perl:1945
+#, perl-format
+msgid "Do you really want to send %s? [y|N]: "
+msgstr ""
diff -pruN 1.2.1+git2.18.0-1/git/po/es.po 1.2.3+git2.25.1-1/git/po/es.po
--- 1.2.1+git2.18.0-1/git/po/es.po	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/po/es.po	2020-02-17 04:47:35.000000000 +0000
@@ -7,8 +7,8 @@ msgid ""
 msgstr ""
 "Project-Id-Version: Git\n"
 "Report-Msgid-Bugs-To: Git Mailing List <git@vger.kernel.org>\n"
-"POT-Creation-Date: 2018-06-16 22:06+0800\n"
-"PO-Revision-Date: 2018-06-16 09:57-0500\n"
+"POT-Creation-Date: 2019-12-30 08:48+0800\n"
+"PO-Revision-Date: 2020-01-06 09:12-0500\n"
 "Last-Translator: christopher.diaz.riv@gmail.com\n"
 "Language-Team: CodeLabora <codelabora@gmail.com>\n"
 "Language: es\n"
@@ -16,40 +16,468 @@ msgstr ""
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
 "Plural-Forms: nplurals=2; plural=(n != 1);\n"
-"X-Generator: Poedit 2.0.7\n"
+"X-Generator: Poedit 2.2.4\n"
 
-#: advice.c:92
+#: add-interactive.c:347
+#, c-format
+msgid "Huh (%s)?"
+msgstr "¿Ahh (%s)?"
+
+#: add-interactive.c:500 add-interactive.c:801 sequencer.c:3216
+#: sequencer.c:3656 builtin/rebase.c:871 builtin/rebase.c:1643
+#: builtin/rebase.c:2019 builtin/rebase.c:2063
+msgid "could not read index"
+msgstr "no se pudo leer índice"
+
+#: add-interactive.c:555 git-add--interactive.perl:269
+#: git-add--interactive.perl:294
+msgid "binary"
+msgstr "binario"
+
+#: add-interactive.c:613 git-add--interactive.perl:278
+#: git-add--interactive.perl:332
+msgid "nothing"
+msgstr "nada"
+
+#: add-interactive.c:614 git-add--interactive.perl:314
+#: git-add--interactive.perl:329
+msgid "unchanged"
+msgstr "sin cambios"
+
+#: add-interactive.c:651 git-add--interactive.perl:643
+msgid "Update"
+msgstr "Actualizar"
+
+#: add-interactive.c:668 add-interactive.c:856
+#, c-format
+msgid "could not stage '%s'"
+msgstr "no se pudo poner en stage '%s'"
+
+#: add-interactive.c:674 add-interactive.c:863 sequencer.c:3409
+#: builtin/rebase.c:895
+msgid "could not write index"
+msgstr "no se pudo escribir índice"
+
+#: add-interactive.c:677 git-add--interactive.perl:628
+#, c-format, perl-format
+msgid "updated %d path\n"
+msgid_plural "updated %d paths\n"
+msgstr[0] "actualizada %d ruta\n"
+msgstr[1] "actualizadas %d rutas\n"
+
+#: add-interactive.c:695 git-add--interactive.perl:678
+#, c-format, perl-format
+msgid "note: %s is untracked now.\n"
+msgstr "nota: %s no es rastreado ahora.\n"
+
+#: add-interactive.c:700 apply.c:4108 builtin/checkout.c:281
+#: builtin/reset.c:144
+#, c-format
+msgid "make_cache_entry failed for path '%s'"
+msgstr "make_cache_entry falló para la ruta '%s'"
+
+#: add-interactive.c:730 git-add--interactive.perl:655
+msgid "Revert"
+msgstr "Revertir"
+
+#: add-interactive.c:746
+msgid "Could not parse HEAD^{tree}"
+msgstr "no se pudo analizar HEAD^{tree}"
+
+#: add-interactive.c:784 git-add--interactive.perl:631
+#, c-format, perl-format
+msgid "reverted %d path\n"
+msgid_plural "reverted %d paths\n"
+msgstr[0] "revertida %d ruta\n"
+msgstr[1] "revertidas %d rutas\n"
+
+#: add-interactive.c:835 git-add--interactive.perl:695
+#, c-format
+msgid "No untracked files.\n"
+msgstr "No hay archivos sin rastrear.\n"
+
+#: add-interactive.c:839 git-add--interactive.perl:689
+msgid "Add untracked"
+msgstr "Agregar no rastreados"
+
+#: add-interactive.c:866 git-add--interactive.perl:625
+#, c-format, perl-format
+msgid "added %d path\n"
+msgid_plural "added %d paths\n"
+msgstr[0] "agregada %d ruta\n"
+msgstr[1] "agregadas %d rutas\n"
+
+#: add-interactive.c:896
+#, c-format
+msgid "ignoring unmerged: %s"
+msgstr "ignorando lo no fusionado: %s"
+
+#: add-interactive.c:908 add-patch.c:1331 git-add--interactive.perl:1366
+#, c-format
+msgid "Only binary files changed.\n"
+msgstr "Solo cambiaron archivos binarios.\n"
+
+#: add-interactive.c:910 add-patch.c:1329 git-add--interactive.perl:1368
+#, c-format
+msgid "No changes.\n"
+msgstr "Sin cambios.\n"
+
+#: add-interactive.c:914 git-add--interactive.perl:1376
+msgid "Patch update"
+msgstr "Actualización del parche"
+
+#: add-interactive.c:953 git-add--interactive.perl:1754
+msgid "Review diff"
+msgstr "Revisión de  diff"
+
+#: add-interactive.c:981
+msgid "show paths with changes"
+msgstr "mostrar rutas con cambios"
+
+#: add-interactive.c:983
+msgid "add working tree state to the staged set of changes"
+msgstr "agregar estado del árbol de trabajo al conjunto de cambios en stage"
+
+#: add-interactive.c:985
+msgid "revert staged set of changes back to the HEAD version"
+msgstr "revertir conjunto de cambios en stage a la versión de HEAD"
+
+#: add-interactive.c:987
+msgid "pick hunks and update selectively"
+msgstr "elegir hunks y actualizar de forma selectiva"
+
+#: add-interactive.c:989
+msgid "view diff between HEAD and index"
+msgstr "ver diff entre HEAD e index"
+
+#: add-interactive.c:991
+msgid "add contents of untracked files to the staged set of changes"
+msgstr ""
+"agregar contenidos de archivos sin rastrear al conjunto de cambios de stage"
+
+#: add-interactive.c:999 add-interactive.c:1048
+msgid "Prompt help:"
+msgstr "Mostrar ayuda:"
+
+#: add-interactive.c:1001
+msgid "select a single item"
+msgstr "selecciona un único objeto"
+
+#: add-interactive.c:1003
+msgid "select a range of items"
+msgstr "selecciona un rango de objetos"
+
+#: add-interactive.c:1005
+msgid "select multiple ranges"
+msgstr "selecciona multiples rangos"
+
+#: add-interactive.c:1007 add-interactive.c:1052
+msgid "select item based on unique prefix"
+msgstr "seleccionar objeto basado en prefijo único"
+
+#: add-interactive.c:1009
+msgid "unselect specified items"
+msgstr "quitar objetos especificados"
+
+#: add-interactive.c:1011
+msgid "choose all items"
+msgstr "escoger todos los objetos"
+
+#: add-interactive.c:1013
+msgid "(empty) finish selecting"
+msgstr "(vacío) finalizar selección"
+
+#: add-interactive.c:1050
+msgid "select a numbered item"
+msgstr "selecciona un objeto numerado"
+
+#: add-interactive.c:1054
+msgid "(empty) select nothing"
+msgstr "(vacío) selecciona nada"
+
+#: add-interactive.c:1062 builtin/clean.c:822 git-add--interactive.perl:1851
+msgid "*** Commands ***"
+msgstr "*** Comandos ***"
+
+#: add-interactive.c:1063 builtin/clean.c:823 git-add--interactive.perl:1848
+msgid "What now"
+msgstr "Ahora que"
+
+#: add-interactive.c:1115 git-add--interactive.perl:213
+msgid "staged"
+msgstr "rastreado"
+
+#: add-interactive.c:1115 git-add--interactive.perl:213
+msgid "unstaged"
+msgstr "no rastreado"
+
+#: add-interactive.c:1115 apply.c:4965 apply.c:4968 builtin/am.c:2197
+#: builtin/am.c:2200 builtin/clone.c:123 builtin/fetch.c:144
+#: builtin/merge.c:273 builtin/pull.c:209 builtin/submodule--helper.c:409
+#: builtin/submodule--helper.c:1379 builtin/submodule--helper.c:1382
+#: builtin/submodule--helper.c:1875 builtin/submodule--helper.c:1878
+#: builtin/submodule--helper.c:2119 git-add--interactive.perl:213
+msgid "path"
+msgstr "ruta"
+
+#: add-interactive.c:1122
+msgid "could not refresh index"
+msgstr "no se pudo refrescar el index"
+
+#: add-interactive.c:1136 builtin/clean.c:787 git-add--interactive.perl:1765
+#, c-format
+msgid "Bye.\n"
+msgstr "Adiós.\n"
+
+#: add-patch.c:15
+#, c-format
+msgid "Stage mode change [y,n,a,q,d%s,?]? "
+msgstr "¿Cambio de modo de stage [y,n,a,q,d%s,?]? "
+
+#: add-patch.c:16
+#, c-format
+msgid "Stage deletion [y,n,a,q,d%s,?]? "
+msgstr "¿Aplicar stage al borrado [y,n,a,q,d%s,?]? "
+
+#: add-patch.c:17
+#, c-format
+msgid "Stage this hunk [y,n,a,q,d%s,?]? "
+msgstr "¿Aplicar stage a este hunk [y,n,a,q,d%s,?]? "
+
+#: add-patch.c:111
+#, c-format
+msgid "could not parse hunk header '%.*s'"
+msgstr "no se puede analizar hunk header '%.*s'"
+
+#: add-patch.c:130 add-patch.c:134
+#, c-format
+msgid "could not parse colored hunk header '%.*s'"
+msgstr "no se puede analizar hunk header '%.*s'"
+
+#: add-patch.c:176
+msgid "could not parse diff"
+msgstr "no se puede analizar diff"
+
+#: add-patch.c:194
+msgid "could not parse colored diff"
+msgstr "no se pudo analizar diff a colores"
+
+#: add-patch.c:508
+#, c-format
+msgid ""
+"expected context line #%d in\n"
+"%.*s"
+msgstr ""
+"se esperaba línea de contexto #%d en\n"
+"%.*s"
+
+#: add-patch.c:523
+#, c-format
+msgid ""
+"hunks do not overlap:\n"
+"%.*s\n"
+"\tdoes not end with:\n"
+"%.*s"
+msgstr ""
+"hunks no hacen overlap:\n"
+"%.*s\n"
+"\tno acaba con:\n"
+"%.*s"
+
+#: add-patch.c:799 git-add--interactive.perl:1112
+msgid "Manual hunk edit mode -- see bottom for a quick guide.\n"
+msgstr "Modo de edición manual de hunk -- vea abajo para una guía rápida.\n"
+
+#: add-patch.c:803
+#, c-format
+msgid ""
+"---\n"
+"To remove '%c' lines, make them ' ' lines (context).\n"
+"To remove '%c' lines, delete them.\n"
+"Lines starting with %c will be removed.\n"
+msgstr ""
+"---\n"
+"Para eliminar '%c' líneas, haga de ellas líneas  ' '  (contexto).\n"
+"Para eliminar '%c' líneas, bórrelas.\n"
+"Lineas comenzando con  %c serán eliminadas.\n"
+
+#: add-patch.c:810
+msgid ""
+"If the patch applies cleanly, the edited hunk will immediately be\n"
+"marked for staging.\n"
+msgstr ""
+"Si el parche aplica limpiamente, el hunk editado sera marcado\n"
+"inmediatamente para el área de stage.\n"
+
+#. TRANSLATORS: 'it' refers to the patch mentioned in the previous messages.
+#: add-patch.c:818 git-add--interactive.perl:1126
+msgid ""
+"If it does not apply cleanly, you will be given an opportunity to\n"
+"edit again.  If all lines of the hunk are removed, then the edit is\n"
+"aborted and the hunk is left unchanged.\n"
+msgstr ""
+"Si esto no aplica de manera limpia, se te da la oportunidad de \n"
+"editar nuevamente. Si todas las líneas del hunk son eliminadas, entonces \n"
+"la edición es abortada y el hunk queda sin cambios.\n"
+
+#: add-patch.c:851
+msgid "could not parse hunk header"
+msgstr "no se puede analizar hunk header"
+
+#: add-patch.c:895 add-patch.c:1294
+msgid "'git apply --cached' failed"
+msgstr "falló 'git apply --cached'"
+
+#. TRANSLATORS: do not translate [y/n]
+#. The program will only accept that input at this point.
+#. Consider translating (saying "no" discards!) as
+#. (saying "n" for "no" discards!) if the translation
+#. of the word "no" does not start with n.
+#.
+#. TRANSLATORS: do not translate [y/n]
+#. The program will only accept that input
+#. at this point.
+#. Consider translating (saying "no" discards!) as
+#. (saying "n" for "no" discards!) if the translation
+#. of the word "no" does not start with n.
+#: add-patch.c:952 git-add--interactive.perl:1239
+msgid ""
+"Your edited hunk does not apply. Edit again (saying \"no\" discards!) [y/n]? "
+msgstr ""
+"Tu hunk editado no aplica. ¿Editar nuevamente (¡decir \"no\" descarta!) [y/"
+"n]? "
+
+#: add-patch.c:1009
+msgid ""
+"y - stage this hunk\n"
+"n - do not stage this hunk\n"
+"q - quit; do not stage this hunk or any of the remaining ones\n"
+"a - stage this and all the remaining hunks\n"
+"d - do not stage this hunk nor any of the remaining hunks\n"
+msgstr ""
+"y - aplicar stage a este hunk\n"
+"n - no aplicar stage a este hunk\n"
+"q - quit; no aplicar stage a este hunk o ninguno de los restantes\n"
+"a - aplicar stage a este hunk y a todos los posteriores en el archivo \n"
+"d - no aplicar stage a este hunk o a ninguno de los posteriores en este "
+"archivo\n"
+
+#: add-patch.c:1016
+msgid ""
+"j - leave this hunk undecided, see next undecided hunk\n"
+"J - leave this hunk undecided, see next hunk\n"
+"k - leave this hunk undecided, see previous undecided hunk\n"
+"K - leave this hunk undecided, see previous hunk\n"
+"g - select a hunk to go to\n"
+"/ - search for a hunk matching the given regex\n"
+"s - split the current hunk into smaller hunks\n"
+"e - manually edit the current hunk\n"
+"? - print help\n"
+msgstr ""
+"j - deja este hunk sin decidir, ver el siguiente hunk sin decisión\n"
+"J - deja este hunk sin decidir, ver siguiente hunk\n"
+"k - deja este hunk sin decidir, ver hunk previo sin decidir\n"
+"K - deja este hunk sin decidir, ver hunk anterior\n"
+"g - selecciona un hunk a dónde ir\n"
+"/ - buscar un hunk que cumpla con el regex dado\n"
+"s - separar el hunk actual en más pequeños\n"
+"e - editar manualmente el hunk actual\n"
+"? - imprimir ayuda\n"
+
+#: add-patch.c:1137 add-patch.c:1147
+msgid "No previous hunk"
+msgstr "No el anterior hunk"
+
+#: add-patch.c:1142 add-patch.c:1152
+msgid "No next hunk"
+msgstr "No el siguiente hunk"
+
+#: add-patch.c:1158
+msgid "No other hunks to goto"
+msgstr "No hay más pedazos para el ir"
+
+#: add-patch.c:1169 git-add--interactive.perl:1577
+msgid "go to which hunk (<ret> to see more)? "
+msgstr "¿a que hunk ir (<enter> para ver más)? "
+
+#: add-patch.c:1170 git-add--interactive.perl:1579
+msgid "go to which hunk? "
+msgstr "¿a que hunk ir? "
+
+#: add-patch.c:1181
+#, c-format
+msgid "Invalid number: '%s'"
+msgstr "Numero inválido: '%s'"
+
+#: add-patch.c:1186
+#, c-format
+msgid "Sorry, only %d hunk available."
+msgid_plural "Sorry, only %d hunks available."
+msgstr[0] "Lo siento, solo %d hunk disponible."
+msgstr[1] "Lo siento, solo %d hunks disponibles."
+
+#: add-patch.c:1195
+msgid "No other hunks to search"
+msgstr "No hay más pedazos para buscar"
+
+#: add-patch.c:1201 git-add--interactive.perl:1623
+msgid "search for regex? "
+msgstr "¿buscar para regexp? "
+
+#: add-patch.c:1216
+#, c-format
+msgid "Malformed search regexp %s: %s"
+msgstr "Regexp para la búsqueda mal formado %s: %s"
+
+#: add-patch.c:1233
+msgid "No hunk matches the given pattern"
+msgstr "No hay hunks que concuerden con el patrón entregado."
+
+#: add-patch.c:1240
+msgid "Sorry, cannot split this hunk"
+msgstr "Perdón, no se puede dividir este pedazo"
+
+#: add-patch.c:1244
+#, c-format
+msgid "Split into %d hunks."
+msgstr "Cortar en %d hunk."
+
+#: add-patch.c:1248
+msgid "Sorry, cannot edit this hunk"
+msgstr "Perdón, no se puede editar este pedazo"
+
+#: advice.c:111
 #, c-format
 msgid "%shint: %.*s%s\n"
 msgstr "%sayuda: %.*s%s\n"
 
-#: advice.c:137
+#: advice.c:164
 msgid "Cherry-picking is not possible because you have unmerged files."
 msgstr ""
 "No es posible ejecutar cherry-picking porque tienes archivos sin fusionar."
 
-#: advice.c:139
+#: advice.c:166
 msgid "Committing is not possible because you have unmerged files."
 msgstr "No es posible realizar un commit porque tienes archivos sin fusionar."
 
-#: advice.c:141
+#: advice.c:168
 msgid "Merging is not possible because you have unmerged files."
 msgstr "No es posible hacer merge porque tienes archivos sin fusionar."
 
-#: advice.c:143
+#: advice.c:170
 msgid "Pulling is not possible because you have unmerged files."
 msgstr "No es posible hacer pull porque tienes archivos sin fusionar."
 
-#: advice.c:145
+#: advice.c:172
 msgid "Reverting is not possible because you have unmerged files."
 msgstr "No es posible revertir porque tienes archivos sin fusionar."
 
-#: advice.c:147
+#: advice.c:174
 #, c-format
 msgid "It is not possible to %s because you have unmerged files."
 msgstr "No es posible %s porque tienes archivos sin fusionar."
 
-#: advice.c:155
+#: advice.c:182
 msgid ""
 "Fix them up in the work tree, and then use 'git add/rm <file>'\n"
 "as appropriate to mark resolution and make a commit."
@@ -57,144 +485,156 @@ msgstr ""
 "Corrígelos en el árbol de trabajo y entonces usa 'git add/rm <archivo>',\n"
 "como sea apropiado, para marcar la resolución y realizar un commit."
 
-#: advice.c:163
+#: advice.c:190
 msgid "Exiting because of an unresolved conflict."
 msgstr "Saliendo porque existe un conflicto sin resolver."
 
-#: advice.c:168 builtin/merge.c:1250
+#: advice.c:195 builtin/merge.c:1332
 msgid "You have not concluded your merge (MERGE_HEAD exists)."
 msgstr "No has concluido tu fusión (MERGE_HEAD existe)."
 
-#: advice.c:170
+#: advice.c:197
 msgid "Please, commit your changes before merging."
 msgstr "Por favor, realiza un commit antes de fusionar."
 
-#: advice.c:171
+#: advice.c:198
 msgid "Exiting because of unfinished merge."
 msgstr "Saliendo por una fusión inconclusa."
 
-#: advice.c:177
+#: advice.c:204
 #, c-format
 msgid ""
-"Note: checking out '%s'.\n"
+"Note: switching to '%s'.\n"
 "\n"
 "You are in 'detached HEAD' state. You can look around, make experimental\n"
 "changes and commit them, and you can discard any commits you make in this\n"
-"state without impacting any branches by performing another checkout.\n"
+"state without impacting any branches by switching back to a branch.\n"
 "\n"
 "If you want to create a new branch to retain commits you create, you may\n"
-"do so (now or later) by using -b with the checkout command again. Example:\n"
+"do so (now or later) by using -c with the switch command. Example:\n"
 "\n"
-"  git checkout -b <new-branch-name>\n"
+"  git switch -c <new-branch-name>\n"
+"\n"
+"Or undo this operation with:\n"
+"\n"
+"  git switch -\n"
+"\n"
+"Turn off this advice by setting config variable advice.detachedHead to "
+"false\n"
 "\n"
 msgstr ""
-"Nota: actualizando el árbol de trabajo '%s'.\n"
+"Nota: cambiando a '%s'.\n"
 "\n"
 "Te encuentras en estado 'detached HEAD'. Puedes revisar por aquí, hacer\n"
-"cambios experimentales y confirmarlos, y puedes descartar cualquier\n"
+"cambios experimentales y hacer commits, y puedes descartar cualquier\n"
 "commit que hayas hecho en este estado sin impactar a tu rama realizando\n"
 "otro checkout.\n"
 "\n"
 "Si quieres crear una nueva rama para mantener los commits que has creado,\n"
-"puedes hacerlo (ahora o después) usando -b con el comando checkout. "
+"puedes hacerlo (ahora o después) usando -c con el comando checkout. "
 "Ejemplo:\n"
 "\n"
-"  git checkout -b <nombre-de-nueva-rama>\n"
+"  git switch -c <nombre-de-nueva-rama>\n"
+"\n"
+"O deshacer la operación con:\n"
 "\n"
+"  git switch -\n"
+"\n"
+"Desactiva este aviso poniendo la variable de config advice.detachedHead en "
+"false\n"
+"\n"
+
+#: alias.c:50
+msgid "cmdline ends with \\"
+msgstr "cmdline termina en \\"
+
+#: alias.c:51
+msgid "unclosed quote"
+msgstr "comillas incompletas"
 
-#: apply.c:58
+#: apply.c:69
 #, c-format
 msgid "unrecognized whitespace option '%s'"
 msgstr "opción de espacios en blanco no reconocida '%s'"
 
-#: apply.c:74
+#: apply.c:85
 #, c-format
 msgid "unrecognized whitespace ignore option '%s'"
 msgstr "opción de ignorar espacios en blanco no reconocida '%s'"
 
-#: apply.c:122
+#: apply.c:135
 msgid "--reject and --3way cannot be used together."
 msgstr "--reject y --3way no se pueden utilizar juntas."
 
-#: apply.c:124
+#: apply.c:137
 msgid "--cached and --3way cannot be used together."
 msgstr "--cached y --3way no se pueden utilizar juntas."
 
-#: apply.c:127
+#: apply.c:140
 msgid "--3way outside a repository"
 msgstr "--3way está fuera de un repositorio"
 
-#: apply.c:138
+#: apply.c:151
 msgid "--index outside a repository"
 msgstr "--index está fuera de un repositorio"
 
-#: apply.c:141
+#: apply.c:154
 msgid "--cached outside a repository"
 msgstr "--cached está fuera de un repositorio"
 
-#: apply.c:821
+#: apply.c:801
 #, c-format
 msgid "Cannot prepare timestamp regexp %s"
 msgstr "No se puede preparar una marca de tiempo para la expresión regular %s"
 
-#: apply.c:830
+#: apply.c:810
 #, c-format
 msgid "regexec returned %d for input: %s"
-msgstr "regexec retornó %d para la entrada: %s"
+msgstr "regexec devolvió %d para la entrada: %s"
 
-#: apply.c:904
+#: apply.c:884
 #, c-format
 msgid "unable to find filename in patch at line %d"
 msgstr ""
 "no se puede encontrar el nombre del archivo en el parche en la línea %d"
 
-#: apply.c:942
+#: apply.c:922
 #, c-format
 msgid "git apply: bad git-diff - expected /dev/null, got %s on line %d"
 msgstr ""
-"git apply: mal git-diff - se esperaba /dev/null, se encontró %s en la línea "
-"%d"
+"git apply: git-diff erróneo - se esperaba /dev/null, se encontró %s en "
+"lalínea %d"
 
-#: apply.c:948
+#: apply.c:928
 #, c-format
 msgid "git apply: bad git-diff - inconsistent new filename on line %d"
 msgstr ""
-"git apply: mal git-diff - nuevo nombre de archivo inconsistente en la línea "
-"%d"
+"git apply: git-diff erróneo - nuevo nombre de archivo inconsistente en "
+"lalínea %d"
 
-#: apply.c:949
+#: apply.c:929
 #, c-format
 msgid "git apply: bad git-diff - inconsistent old filename on line %d"
 msgstr ""
-"git apply: mal git-diff - viejo nombre de archivo inconsistente en la línea "
-"%d"
+"git apply: git-diff erróneo - viejo nombre de archivo inconsistente en "
+"lalínea %d"
 
-#: apply.c:954
+#: apply.c:934
 #, c-format
 msgid "git apply: bad git-diff - expected /dev/null on line %d"
-msgstr "git apply: mal git-diff - se esperaba /dev/null en la línea %d"
+msgstr "git apply: git-diff erróneo - se esperaba /dev/null en la línea %d"
 
-#: apply.c:983
+#: apply.c:963
 #, c-format
 msgid "invalid mode on line %d: %s"
 msgstr "modo inválido en la línea %d: %s"
 
-#: apply.c:1301
+#: apply.c:1282
 #, c-format
 msgid "inconsistent header lines %d and %d"
 msgstr "header inconsistente en las líneas %d y %d"
 
-#: apply.c:1473
-#, c-format
-msgid "recount: unexpected line: %.*s"
-msgstr "recount: línea inesperada: %.*s"
-
-#: apply.c:1542
-#, c-format
-msgid "patch fragment without header at line %d: %.*s"
-msgstr "fragmento de parche sin header en la línea %d: %.*s"
-
-#: apply.c:1562
+#: apply.c:1372
 #, c-format
 msgid ""
 "git diff header lacks filename information when removing %d leading pathname "
@@ -204,88 +644,98 @@ msgid_plural ""
 "components (line %d)"
 msgstr[0] ""
 "al header de git diff carece de información del nombre del archivo %d cuando "
-"lo remueve de la ruta principal componente (línea %d)"
+"lo elimina de la ruta principal componente (línea %d)"
 msgstr[1] ""
 "los headers de git diff carecen de información de los nombres de los "
-"archivos %d cuando los remueven de la ruta principal componentes (línea %d)"
+"archivos %d cuando los eliminan de la ruta principal componentes (línea %d)"
 
-#: apply.c:1575
+#: apply.c:1385
 #, c-format
 msgid "git diff header lacks filename information (line %d)"
 msgstr ""
-"el header de git diff carece de información del nombre del archivo (línea %d)"
+"la cabecera de git diff carece de información del nombre del archivo (línea %d)"
+
+#: apply.c:1481
+#, c-format
+msgid "recount: unexpected line: %.*s"
+msgstr "recount: línea inesperada: %.*s"
 
-#: apply.c:1763
+#: apply.c:1550
+#, c-format
+msgid "patch fragment without header at line %d: %.*s"
+msgstr "fragmento de parche sin header en la línea %d: %.*s"
+
+#: apply.c:1753
 msgid "new file depends on old contents"
 msgstr "el nuevo archivo depende de contenidos viejos"
 
-#: apply.c:1765
+#: apply.c:1755
 msgid "deleted file still has contents"
 msgstr "el archivo eliminado todavía tiene contenido"
 
-#: apply.c:1799
+#: apply.c:1789
 #, c-format
 msgid "corrupt patch at line %d"
 msgstr "parche corrupto en la línea %d"
 
-#: apply.c:1836
+#: apply.c:1826
 #, c-format
 msgid "new file %s depends on old contents"
 msgstr "nuevo archivo %s depende en contenidos viejos"
 
-#: apply.c:1838
+#: apply.c:1828
 #, c-format
 msgid "deleted file %s still has contents"
 msgstr "el archivo borrado %s todavía tiene contenido"
 
-#: apply.c:1841
+#: apply.c:1831
 #, c-format
 msgid "** warning: file %s becomes empty but is not deleted"
-msgstr "** peligro: el archivo %s esta vacío pero no es borrado"
+msgstr "** peligro: el archivo %s está vacío pero no es borrado"
 
-#: apply.c:1988
+#: apply.c:1978
 #, c-format
 msgid "corrupt binary patch at line %d: %.*s"
 msgstr "parche binario corrupto en la línea %d: %.*s"
 
-#: apply.c:2025
+#: apply.c:2015
 #, c-format
 msgid "unrecognized binary patch at line %d"
 msgstr "parche binario no reconocido en la línea %d"
 
-#: apply.c:2185
+#: apply.c:2177
 #, c-format
 msgid "patch with only garbage at line %d"
 msgstr "parche que solo contiene basura en la línea %d"
 
-#: apply.c:2271
+#: apply.c:2263
 #, c-format
 msgid "unable to read symlink %s"
 msgstr "no es posible leer el enlace simbólico %s"
 
-#: apply.c:2275
+#: apply.c:2267
 #, c-format
 msgid "unable to open or read %s"
 msgstr "no es posible abrir o leer %s"
 
-#: apply.c:2934
+#: apply.c:2936
 #, c-format
 msgid "invalid start of line: '%c'"
-msgstr "comienzo invalido de línea: '%c'"
+msgstr "comienzo inválido de línea: '%c'"
 
-#: apply.c:3055
+#: apply.c:3057
 #, c-format
 msgid "Hunk #%d succeeded at %d (offset %d line)."
 msgid_plural "Hunk #%d succeeded at %d (offset %d lines)."
 msgstr[0] "Hunk #%d tuvo éxito en %d (%d línea compensada)."
 msgstr[1] "Hunk #%d tuvo éxito en %d (%d líneas compensadas)."
 
-#: apply.c:3067
+#: apply.c:3069
 #, c-format
 msgid "Context reduced to (%ld/%ld) to apply fragment at %d"
 msgstr "Contexto reducido a (%ld/%ld) para aplicar el fragmento en %d"
 
-#: apply.c:3073
+#: apply.c:3075
 #, c-format
 msgid ""
 "while searching for:\n"
@@ -294,23 +744,23 @@ msgstr ""
 "mientras se busca:\n"
 "%.*s"
 
-#: apply.c:3095
+#: apply.c:3097
 #, c-format
 msgid "missing binary patch data for '%s'"
 msgstr "data perdida en parche binario para '%s'"
 
-#: apply.c:3103
+#: apply.c:3105
 #, c-format
 msgid "cannot reverse-apply a binary patch without the reverse hunk to '%s'"
 msgstr ""
 "no se puede revertir-aplicar un parche binario sin el hunk revertido a '%s'"
 
-#: apply.c:3149
+#: apply.c:3152
 #, c-format
 msgid "cannot apply binary patch to '%s' without full index line"
 msgstr "no se puede aplicar el parche binario a '%s' sin un índice completo"
 
-#: apply.c:3159
+#: apply.c:3162
 #, c-format
 msgid ""
 "the patch applies to '%s' (%s), which does not match the current contents."
@@ -318,288 +768,284 @@ msgstr ""
 "el parche aplica a '%s' (%s), lo cual no concuerda con los contenidos "
 "actuales."
 
-#: apply.c:3167
+#: apply.c:3170
 #, c-format
 msgid "the patch applies to an empty '%s' but it is not empty"
 msgstr "el parche aplica a un '%s' vacío, pero este no lo esta"
 
-#: apply.c:3185
+#: apply.c:3188
 #, c-format
 msgid "the necessary postimage %s for '%s' cannot be read"
 msgstr "la postimagen necesaria %s para '%s' no se puede leer"
 
-#: apply.c:3198
+#: apply.c:3201
 #, c-format
 msgid "binary patch does not apply to '%s'"
 msgstr "el parche binario no aplica para '%s'"
 
-#: apply.c:3204
+#: apply.c:3207
 #, c-format
 msgid "binary patch to '%s' creates incorrect result (expecting %s, got %s)"
 msgstr ""
 "el parche binario para '%s' crea un resultado incorrecto (saliendo %s, se "
 "obtuvo %s)"
 
-#: apply.c:3225
+#: apply.c:3228
 #, c-format
 msgid "patch failed: %s:%ld"
 msgstr "el parche falló: %s:%ld"
 
-#: apply.c:3347
+#: apply.c:3351
 #, c-format
 msgid "cannot checkout %s"
 msgstr "no se puede hacer checkout a %s"
 
-#: apply.c:3396 apply.c:3407 apply.c:3453 setup.c:278
+#: apply.c:3403 apply.c:3414 apply.c:3460 midx.c:61 setup.c:280
 #, c-format
 msgid "failed to read %s"
 msgstr "no se pudo leer %s"
 
-#: apply.c:3404
+#: apply.c:3411
 #, c-format
 msgid "reading from '%s' beyond a symbolic link"
 msgstr "leyendo de '%s' tras un enlace simbólico"
 
-#: apply.c:3433 apply.c:3673
+#: apply.c:3440 apply.c:3683
 #, c-format
 msgid "path %s has been renamed/deleted"
 msgstr "la ruta %s ha sido renombrada/suprimida"
 
-#: apply.c:3516 apply.c:3687
+#: apply.c:3526 apply.c:3698
 #, c-format
 msgid "%s: does not exist in index"
 msgstr "%s: no existe en el índice"
 
-#: apply.c:3525 apply.c:3695
+#: apply.c:3535 apply.c:3706
 #, c-format
 msgid "%s: does not match index"
 msgstr "%s: no concuerda con el índice"
 
-#: apply.c:3560
+#: apply.c:3570
 msgid "repository lacks the necessary blob to fall back on 3-way merge."
 msgstr ""
 "el repositorio carece del blob necesario para regresar en un merge de tres-"
 "vías."
 
-#: apply.c:3563
+#: apply.c:3573
 #, c-format
 msgid "Falling back to three-way merge...\n"
 msgstr "Retrocediendo en un merge de tres-vías...\n"
 
-#: apply.c:3579 apply.c:3583
+#: apply.c:3589 apply.c:3593
 #, c-format
 msgid "cannot read the current contents of '%s'"
 msgstr "no se pueden leer los contenidos actuales de '%s'"
 
-#: apply.c:3595
+#: apply.c:3605
 #, c-format
 msgid "Failed to fall back on three-way merge...\n"
 msgstr "Falló el merge en retroceso de tres-vías...\n"
 
-#: apply.c:3609
+#: apply.c:3619
 #, c-format
 msgid "Applied patch to '%s' with conflicts.\n"
 msgstr "Parche aplicado a '%s' con conflictos.\n"
 
-#: apply.c:3614
+#: apply.c:3624
 #, c-format
 msgid "Applied patch to '%s' cleanly.\n"
 msgstr "Parche aplicado a '%s' limpiamente\n"
 
-#: apply.c:3640
+#: apply.c:3650
 msgid "removal patch leaves file contents"
-msgstr "parche de remoción deja contenidos en el archivo"
+msgstr "parche de eliminación deja contenidos en el archivo"
 
-#: apply.c:3712
+#: apply.c:3723
 #, c-format
 msgid "%s: wrong type"
 msgstr "%s: tipo incorrecto"
 
-#: apply.c:3714
+#: apply.c:3725
 #, c-format
 msgid "%s has type %o, expected %o"
 msgstr "%s tiene tipo %o, se esperaba %o"
 
-#: apply.c:3864 apply.c:3866
+#: apply.c:3876 apply.c:3878 read-cache.c:830 read-cache.c:856
+#: read-cache.c:1320
 #, c-format
 msgid "invalid path '%s'"
-msgstr "ruta invalida '%s'"
+msgstr "ruta inválida '%s'"
 
-#: apply.c:3922
+#: apply.c:3934
 #, c-format
 msgid "%s: already exists in index"
 msgstr "%s: ya existe en el índice"
 
-#: apply.c:3925
+#: apply.c:3937
 #, c-format
 msgid "%s: already exists in working directory"
 msgstr "%s: ya existe en el directorio de trabajo"
 
-#: apply.c:3945
+#: apply.c:3957
 #, c-format
 msgid "new mode (%o) of %s does not match old mode (%o)"
 msgstr "nuevo modo (%o) de %s no concuerda con el viejo modo (%o)"
 
-#: apply.c:3950
+#: apply.c:3962
 #, c-format
 msgid "new mode (%o) of %s does not match old mode (%o) of %s"
 msgstr "nuevo modo (%o) de %s no concuerda con el viejo modo (%o) de %s"
 
-#: apply.c:3970
+#: apply.c:3982
 #, c-format
 msgid "affected file '%s' is beyond a symbolic link"
-msgstr "archivo afectado '%s' esta tras un enlace simbólico"
+msgstr "archivo afectado '%s' está tras un enlace simbólico"
 
-#: apply.c:3974
+#: apply.c:3986
 #, c-format
 msgid "%s: patch does not apply"
 msgstr "%s: el parche no aplica"
 
-#: apply.c:3989
+#: apply.c:4001
 #, c-format
 msgid "Checking patch %s..."
 msgstr "Revisando el parche %s..."
 
-#: apply.c:4080
+#: apply.c:4093
 #, c-format
 msgid "sha1 information is lacking or useless for submodule %s"
 msgstr "falta información del sha1 o es inútil para el submódulo %s"
 
-#: apply.c:4087
+#: apply.c:4100
 #, c-format
 msgid "mode change for %s, which is not in current HEAD"
 msgstr "modo cambiado para %s, el cual no se encuentra en el HEAD actual"
 
-#: apply.c:4090
+#: apply.c:4103
 #, c-format
 msgid "sha1 information is lacking or useless (%s)."
 msgstr "falta información sha1 o es inútil (%s)."
 
-#: apply.c:4095 builtin/checkout.c:235 builtin/reset.c:140
-#, c-format
-msgid "make_cache_entry failed for path '%s'"
-msgstr "make_cache_entry falló para la ruta '%s'"
-
-#: apply.c:4099
+#: apply.c:4112
 #, c-format
 msgid "could not add %s to temporary index"
 msgstr "no se pudo añadir %s al índice temporal"
 
-#: apply.c:4109
+#: apply.c:4122
 #, c-format
 msgid "could not write temporary index to %s"
 msgstr "no se pudo escribir un índice temporal para %s"
 
-#: apply.c:4247
+#: apply.c:4260
 #, c-format
 msgid "unable to remove %s from index"
-msgstr "no se puede remover %s del índice"
+msgstr "no se puede eliminar %s del índice"
 
-#: apply.c:4282
+#: apply.c:4294
 #, c-format
 msgid "corrupt patch for submodule %s"
 msgstr "parche corrupto para el submódulo %s"
 
-#: apply.c:4288
+#: apply.c:4300
 #, c-format
 msgid "unable to stat newly created file '%s'"
 msgstr "no es posible establecer el archivo recién creado '%s'"
 
-#: apply.c:4296
+#: apply.c:4308
 #, c-format
 msgid "unable to create backing store for newly created file %s"
 msgstr ""
 "no es posible crear una copia de seguridad para el archivo recién creado %s"
 
-#: apply.c:4302 apply.c:4446
+#: apply.c:4314 apply.c:4459
 #, c-format
 msgid "unable to add cache entry for %s"
 msgstr "no es posible agregar una entrada en el cache para %s"
 
-#: apply.c:4343
+#: apply.c:4357
 #, c-format
 msgid "failed to write to '%s'"
 msgstr "falló escribir para '%s'"
 
-#: apply.c:4347
+#: apply.c:4361
 #, c-format
 msgid "closing file '%s'"
 msgstr "cerrando archivo '%s'"
 
-#: apply.c:4417
+#: apply.c:4431
 #, c-format
 msgid "unable to write file '%s' mode %o"
 msgstr "no es posible escribir el archivo '%s' modo %o"
 
-#: apply.c:4515
+#: apply.c:4529
 #, c-format
 msgid "Applied patch %s cleanly."
 msgstr "Parche %s aplicado limpiamente."
 
-#: apply.c:4523
+#: apply.c:4537
 msgid "internal error"
 msgstr "error interno"
 
-#: apply.c:4526
+#: apply.c:4540
 #, c-format
 msgid "Applying patch %%s with %d reject..."
 msgid_plural "Applying patch %%s with %d rejects..."
 msgstr[0] "Aplicando parche %%s con %d rechazo..."
 msgstr[1] "Aplicando parche %%s con %d rechazos..."
 
-#: apply.c:4537
+#: apply.c:4551
 #, c-format
 msgid "truncating .rej filename to %.*s.rej"
 msgstr "truncando el nombre de archivo .rej a %.*s.rej"
 
-#: apply.c:4545 builtin/fetch.c:786 builtin/fetch.c:1036
+#: apply.c:4559 builtin/fetch.c:901 builtin/fetch.c:1192
 #, c-format
 msgid "cannot open %s"
 msgstr "no se puede abrir %s"
 
-#: apply.c:4559
+#: apply.c:4573
 #, c-format
 msgid "Hunk #%d applied cleanly."
 msgstr "Hunk #%d aplicado limpiamente."
 
-#: apply.c:4563
+#: apply.c:4577
 #, c-format
 msgid "Rejected hunk #%d."
 msgstr "Hunk #%d rechazado."
 
-#: apply.c:4673
+#: apply.c:4696
 #, c-format
 msgid "Skipped patch '%s'."
 msgstr "Parche '%s' saltado."
 
-#: apply.c:4681
+#: apply.c:4704
 msgid "unrecognized input"
 msgstr "input no reconocido"
 
-#: apply.c:4700
+#: apply.c:4724
 msgid "unable to read index file"
 msgstr "no es posible leer el archivo índice"
 
-#: apply.c:4837
+#: apply.c:4881
 #, c-format
 msgid "can't open patch '%s': %s"
 msgstr "no se puede abrir el parche '%s': %s"
 
-#: apply.c:4864
+#: apply.c:4908
 #, c-format
 msgid "squelched %d whitespace error"
 msgid_plural "squelched %d whitespace errors"
 msgstr[0] "%d error de espacios en blanco aplastado"
 msgstr[1] "%d errores de espacios en blanco aplastados"
 
-#: apply.c:4870 apply.c:4885
+#: apply.c:4914 apply.c:4929
 #, c-format
 msgid "%d line adds whitespace errors."
 msgid_plural "%d lines add whitespace errors."
 msgstr[0] "%d línea agrega errores de espacios en blanco."
 msgstr[1] "%d líneas agregan errores de espacios en blanco."
 
-#: apply.c:4878
+#: apply.c:4922
 #, c-format
 msgid "%d line applied after fixing whitespace errors."
 msgid_plural "%d lines applied after fixing whitespace errors."
@@ -608,266 +1054,336 @@ msgstr[0] ""
 msgstr[1] ""
 "%d líneas aplicadas después de arreglar los errores de espacios en blanco."
 
-#: apply.c:4894 builtin/add.c:538 builtin/mv.c:300 builtin/rm.c:389
+#: apply.c:4938 builtin/add.c:579 builtin/mv.c:301 builtin/rm.c:390
 msgid "Unable to write new index file"
 msgstr "No es posible escribir el archivo índice"
 
-#: apply.c:4921 apply.c:4924 builtin/am.c:2254 builtin/am.c:2257
-#: builtin/clone.c:120 builtin/fetch.c:126 builtin/pull.c:198
-#: builtin/submodule--helper.c:405 builtin/submodule--helper.c:1210
-#: builtin/submodule--helper.c:1213 builtin/submodule--helper.c:1584
-#: builtin/submodule--helper.c:1587 builtin/submodule--helper.c:1807
-#: git-add--interactive.perl:197
-msgid "path"
-msgstr "ruta"
-
-#: apply.c:4922
+#: apply.c:4966
 msgid "don't apply changes matching the given path"
 msgstr "no aplicar cambios que concuerden con la ruta suministrada"
 
-#: apply.c:4925
+#: apply.c:4969
 msgid "apply changes matching the given path"
 msgstr "aplicar cambios que concuerden con la ruta suministrada"
 
-#: apply.c:4927 builtin/am.c:2263
+#: apply.c:4971 builtin/am.c:2206
 msgid "num"
 msgstr "num"
 
-#: apply.c:4928
+#: apply.c:4972
 msgid "remove <num> leading slashes from traditional diff paths"
-msgstr "remover <num> slashes iniciales de las rutas diff tradicionales"
+msgstr "eliminar <num> slashes iniciales de las rutas diff tradicionales"
 
-#: apply.c:4931
+#: apply.c:4975
 msgid "ignore additions made by the patch"
 msgstr "ignorar adiciones hechas por el parche"
 
-#: apply.c:4933
+#: apply.c:4977
 msgid "instead of applying the patch, output diffstat for the input"
 msgstr "en lugar de aplicar el parche, mostrar diffstat para la entrada"
 
-#: apply.c:4937
+#: apply.c:4981
 msgid "show number of added and deleted lines in decimal notation"
 msgstr "mostrar el numero de líneas agregadas y eliminadas en notación decimal"
 
-#: apply.c:4939
+#: apply.c:4983
 msgid "instead of applying the patch, output a summary for the input"
 msgstr "en lugar de aplicar el parche, mostrar un resumen para la entrada"
 
-#: apply.c:4941
+#: apply.c:4985
 msgid "instead of applying the patch, see if the patch is applicable"
 msgstr "en lugar de aplicar el parche, ver si el parche es aplicable"
 
-#: apply.c:4943
+#: apply.c:4987
 msgid "make sure the patch is applicable to the current index"
 msgstr "asegurar que el parche es aplicable al índice actual"
 
-#: apply.c:4945
+#: apply.c:4989
+msgid "mark new files with `git add --intent-to-add`"
+msgstr "marca los nuevos archivos con `git add --intent-to-add`"
+
+#: apply.c:4991
 msgid "apply a patch without touching the working tree"
 msgstr "aplicar un parche sin tocar el árbol de trabajo"
 
-#: apply.c:4947
+#: apply.c:4993
 msgid "accept a patch that touches outside the working area"
 msgstr "aceptar un parche que toca fuera del área de trabajo"
 
-#: apply.c:4950
+#: apply.c:4996
 msgid "also apply the patch (use with --stat/--summary/--check)"
 msgstr "también aplicar el parche ( usar con --stat/--summary/--check"
 
-#: apply.c:4952
+#: apply.c:4998
 msgid "attempt three-way merge if a patch does not apply"
 msgstr "intentar merge de tres-vías si el parche no aplica"
 
-#: apply.c:4954
+#: apply.c:5000
 msgid "build a temporary index based on embedded index information"
 msgstr ""
 "construir un índice temporal basado en la información del índice incrustado"
 
-#: apply.c:4957 builtin/checkout-index.c:168 builtin/ls-files.c:515
+#: apply.c:5003 builtin/checkout-index.c:173 builtin/ls-files.c:524
 msgid "paths are separated with NUL character"
 msgstr "rutas están separadas con un carácter NULL"
 
-#: apply.c:4959
+#: apply.c:5005
 msgid "ensure at least <n> lines of context match"
-msgstr "asegure que por lo menos <n> líneas del contexto concuerden"
+msgstr "asegurar que al menos concuerden <n> líneas del contexto concuerden"
 
-#: apply.c:4960 builtin/am.c:2242 builtin/interpret-trailers.c:95
-#: builtin/interpret-trailers.c:97 builtin/interpret-trailers.c:99
-#: builtin/pack-objects.c:3177
+#: apply.c:5006 builtin/am.c:2185 builtin/interpret-trailers.c:98
+#: builtin/interpret-trailers.c:100 builtin/interpret-trailers.c:102
+#: builtin/pack-objects.c:3310 builtin/rebase.c:1474
 msgid "action"
 msgstr "acción"
 
-#: apply.c:4961
+#: apply.c:5007
 msgid "detect new or modified lines that have whitespace errors"
 msgstr ""
 "detectar líneas nuevas o modificadas que contienen errores de espacios en "
 "blanco"
 
-#: apply.c:4964 apply.c:4967
+#: apply.c:5010 apply.c:5013
 msgid "ignore changes in whitespace when finding context"
 msgstr ""
 "ignorar cambios en los espacios en blanco cuando se encuentra el contexto"
 
-#: apply.c:4970
+#: apply.c:5016
 msgid "apply the patch in reverse"
 msgstr "aplicar el parche en reversa"
 
-#: apply.c:4972
+#: apply.c:5018
 msgid "don't expect at least one line of context"
 msgstr "no espera al menos una línea del contexto"
 
-#: apply.c:4974
+#: apply.c:5020
 msgid "leave the rejected hunks in corresponding *.rej files"
 msgstr "dejar los hunks rechazados en los archivos *.rej correspontientes"
 
-#: apply.c:4976
+#: apply.c:5022
 msgid "allow overlapping hunks"
 msgstr "permitir solapamiento de hunks"
 
-#: apply.c:4977 builtin/add.c:290 builtin/check-ignore.c:21
-#: builtin/commit.c:1301 builtin/count-objects.c:98 builtin/fsck.c:666
-#: builtin/log.c:1901 builtin/mv.c:122 builtin/read-tree.c:124
+#: apply.c:5023 builtin/add.c:309 builtin/check-ignore.c:22
+#: builtin/commit.c:1355 builtin/count-objects.c:98 builtin/fsck.c:774
+#: builtin/log.c:2166 builtin/mv.c:123 builtin/read-tree.c:128
 msgid "be verbose"
 msgstr "ser verboso"
 
-#: apply.c:4979
+#: apply.c:5025
 msgid "tolerate incorrectly detected missing new-line at the end of file"
 msgstr ""
 "tolerar nuevas líneas faltantes detectadas incorrectamente al final del "
 "archivo"
 
-#: apply.c:4982
+#: apply.c:5028
 msgid "do not trust the line counts in the hunk headers"
 msgstr "no confiar en el conteo de líneas en los headers del hunk"
 
-#: apply.c:4984 builtin/am.c:2251
+#: apply.c:5030 builtin/am.c:2194
 msgid "root"
 msgstr "raíz"
 
-#: apply.c:4985
+#: apply.c:5031
 msgid "prepend <root> to all filenames"
 msgstr "anteponer <root> a todos los nombres de archivos"
 
-#: archive.c:13
+#: archive.c:14
 msgid "git archive [<options>] <tree-ish> [<path>...]"
 msgstr "git archive [<opciones>] <parte-del-árbol> [<ruta>...]"
 
-#: archive.c:14
+#: archive.c:15
 msgid "git archive --list"
 msgstr "git archive --list"
 
-#: archive.c:15
+#: archive.c:16
 msgid ""
 "git archive --remote <repo> [--exec <cmd>] [<options>] <tree-ish> [<path>...]"
 msgstr ""
 "git archive --remote <repo> [--exec <comando> ] [<opciones>] <parte-del-"
 "árbol> [<ruta>...]"
 
-#: archive.c:16
+#: archive.c:17
 msgid "git archive --remote <repo> [--exec <cmd>] --list"
 msgstr "git archive --remote <repo> [--exec <comando>] --list"
 
-#: archive.c:351 builtin/add.c:176 builtin/add.c:514 builtin/rm.c:298
+#: archive.c:372 builtin/add.c:180 builtin/add.c:555 builtin/rm.c:299
 #, c-format
 msgid "pathspec '%s' did not match any files"
 msgstr "ruta especificada '%s' no concordó con ninguna carpeta"
 
-#: archive.c:434
+#: archive.c:396
+#, c-format
+msgid "no such ref: %.*s"
+msgstr "no existe el ref: %.*s"
+
+#: archive.c:401
+#, c-format
+msgid "not a valid object name: %s"
+msgstr "nombre de objeto no válido: %s"
+
+#: archive.c:414
+#, c-format
+msgid "not a tree object: %s"
+msgstr "no es un objeto tree: %s"
+
+#: archive.c:426
+msgid "current working directory is untracked"
+msgstr "directorio de trabajo actual no rastreado"
+
+#: archive.c:457
 msgid "fmt"
 msgstr "fmt"
 
-#: archive.c:434
+#: archive.c:457
 msgid "archive format"
 msgstr "formato del archivo"
 
-#: archive.c:435 builtin/log.c:1462
+#: archive.c:458 builtin/log.c:1653
 msgid "prefix"
 msgstr "prefijo"
 
-#: archive.c:436
+#: archive.c:459
 msgid "prepend prefix to each pathname in the archive"
 msgstr "anteponer prefijo a cada ruta en el archivo"
 
-#: archive.c:437 builtin/blame.c:813 builtin/blame.c:814 builtin/config.c:127
-#: builtin/fast-export.c:1007 builtin/fast-export.c:1009 builtin/grep.c:869
-#: builtin/hash-object.c:103 builtin/ls-files.c:551 builtin/ls-files.c:554
-#: builtin/notes.c:405 builtin/notes.c:568 builtin/read-tree.c:119
-#: parse-options.h:165
+#: archive.c:460 builtin/blame.c:861 builtin/blame.c:865 builtin/blame.c:866
+#: builtin/commit-tree.c:117 builtin/config.c:129 builtin/fast-export.c:1162
+#: builtin/fast-export.c:1164 builtin/fast-export.c:1168 builtin/grep.c:899
+#: builtin/hash-object.c:105 builtin/ls-files.c:560 builtin/ls-files.c:563
+#: builtin/notes.c:412 builtin/notes.c:578 builtin/read-tree.c:123
+#: parse-options.h:190
 msgid "file"
 msgstr "carpeta"
 
-#: archive.c:438 builtin/archive.c:89
+#: archive.c:461 builtin/archive.c:90
 msgid "write the archive to this file"
 msgstr "escribe el archivo en esta carpeta"
 
-#: archive.c:440
+#: archive.c:463
 msgid "read .gitattributes in working directory"
 msgstr "leer .gitattributes en el directorio de trabajo"
 
-#: archive.c:441
+#: archive.c:464
 msgid "report archived files on stderr"
 msgstr "reportar archivos archivados por stderr"
 
-#: archive.c:442
+#: archive.c:465
 msgid "store only"
 msgstr "solo guardar"
 
-#: archive.c:443
+#: archive.c:466
 msgid "compress faster"
-msgstr "comprimir mas rápido"
+msgstr "comprimir más rápido"
 
-#: archive.c:451
+#: archive.c:474
 msgid "compress better"
 msgstr "comprimir mejor"
 
-#: archive.c:454
+#: archive.c:477
 msgid "list supported archive formats"
 msgstr "listar los formatos de carpeta soportados"
 
-#: archive.c:456 builtin/archive.c:90 builtin/clone.c:110 builtin/clone.c:113
-#: builtin/submodule--helper.c:1222 builtin/submodule--helper.c:1593
+#: archive.c:479 builtin/archive.c:91 builtin/clone.c:113 builtin/clone.c:116
+#: builtin/submodule--helper.c:1391 builtin/submodule--helper.c:1884
 msgid "repo"
 msgstr "repo"
 
-#: archive.c:457 builtin/archive.c:91
+#: archive.c:480 builtin/archive.c:92
 msgid "retrieve the archive from remote repository <repo>"
 msgstr "obtener la carpeta del repositorio remoto <repo>"
 
-#: archive.c:458 builtin/archive.c:92 builtin/notes.c:489
+#: archive.c:481 builtin/archive.c:93 builtin/difftool.c:715
+#: builtin/notes.c:498
 msgid "command"
 msgstr "comando"
 
-#: archive.c:459 builtin/archive.c:93
+#: archive.c:482 builtin/archive.c:94
 msgid "path to the remote git-upload-archive command"
 msgstr "ruta para el comando git-upload-archivo remoto"
 
-#: archive.c:466
+#: archive.c:489
 msgid "Unexpected option --remote"
 msgstr "Opción inesperada --remote"
 
-#: archive.c:468
+#: archive.c:491
 msgid "Option --exec can only be used together with --remote"
 msgstr "Opción --exec solo puede ser utilizada con --remote"
 
-#: archive.c:470
+#: archive.c:493
 msgid "Unexpected option --output"
 msgstr "Opción inesperada --output"
 
-#: archive.c:492
+#: archive.c:515
 #, c-format
 msgid "Unknown archive format '%s'"
 msgstr "Formato de carpeta desconocido '%s'"
 
-#: archive.c:499
+#: archive.c:522
 #, c-format
 msgid "Argument not supported for format '%s': -%d"
 msgstr "Argumento no soportado para formato '%s': -%d"
 
-#: attr.c:218
+#: archive-tar.c:125 archive-zip.c:350
+#, c-format
+msgid "cannot stream blob %s"
+msgstr "no se puede transmitir el blob %s"
+
+#: archive-tar.c:266 archive-zip.c:368
+#, c-format
+msgid "unsupported file mode: 0%o (SHA1: %s)"
+msgstr "modo de archivo no soportado: 0%o (SHA1: %s)"
+
+#: archive-tar.c:293 archive-zip.c:358
+#, c-format
+msgid "cannot read %s"
+msgstr "no se puede leer %s"
+
+#: archive-tar.c:465
+#, c-format
+msgid "unable to start '%s' filter"
+msgstr "no se puede comenzar filtro '%s'"
+
+#: archive-tar.c:468
+msgid "unable to redirect descriptor"
+msgstr "incapaz de redirigir descriptor"
+
+#: archive-tar.c:475
+#, c-format
+msgid "'%s' filter reported error"
+msgstr "filtro '%s' reportó un error"
+
+#: archive-zip.c:319
+#, c-format
+msgid "path is not valid UTF-8: %s"
+msgstr "ruta no válida UTF-8: %s"
+
+#: archive-zip.c:323
+#, c-format
+msgid "path too long (%d chars, SHA1: %s): %s"
+msgstr "ruta muy larga (%d chars, SHA1: %s): %s"
+
+#: archive-zip.c:479 builtin/pack-objects.c:230 builtin/pack-objects.c:233
+#, c-format
+msgid "deflate error (%d)"
+msgstr "error al desinflar (%d)"
+
+#: archive-zip.c:614
+#, c-format
+msgid "timestamp too large for this system: %<PRIuMAX>"
+msgstr "timestamp muy largo para este sistema: %<PRIuMAX>"
+
+#: attr.c:212
 #, c-format
 msgid "%.*s is not a valid attribute name"
-msgstr "%.*s no es un nombre de atributo valido"
+msgstr "%.*s no es un nombre de atributo válido"
 
-#: attr.c:415
+#: attr.c:369
+#, c-format
+msgid "%s not allowed: %s:%d"
+msgstr "%s no permitido: %s:%d"
+
+#: attr.c:409
 msgid ""
 "Negative patterns are ignored in git attributes\n"
 "Use '\\!' for literal leading exclamation."
@@ -875,31 +1391,31 @@ msgstr ""
 "Los patrones negativos son ignorados en los atributos de git\n"
 "Usa '\\!' para comenzar literalmente con exclamación."
 
-#: bisect.c:461
+#: bisect.c:468
 #, c-format
 msgid "Badly quoted content in file '%s': %s"
 msgstr "Revisa las comillas en el archivo '%s': %s"
 
-#: bisect.c:669
+#: bisect.c:678
 #, c-format
 msgid "We cannot bisect more!\n"
-msgstr "No podemos bisecar mas!\n"
+msgstr "¡No podemos biseccionar más!\n"
 
-#: bisect.c:723
+#: bisect.c:733
 #, c-format
 msgid "Not a valid commit name %s"
-msgstr "No es un nombre de commit valido %s"
+msgstr "No es un nombre de commit válido %s"
 
-#: bisect.c:747
+#: bisect.c:758
 #, c-format
 msgid ""
 "The merge base %s is bad.\n"
 "This means the bug has been fixed between %s and [%s].\n"
 msgstr ""
-"La base de fisión %s esta mal.\n"
+"La base de fisión %s está mal.\n"
 "Esto quiere decir que el bug ha sido arreglado entre %s y [%s].\n"
 
-#: bisect.c:752
+#: bisect.c:763
 #, c-format
 msgid ""
 "The merge base %s is new.\n"
@@ -908,16 +1424,16 @@ msgstr ""
 "La base de fisión %s es nueva.\n"
 "Esta propiedad ha cambiado entre %s y [%s].\n"
 
-#: bisect.c:757
+#: bisect.c:768
 #, c-format
 msgid ""
 "The merge base %s is %s.\n"
 "This means the first '%s' commit is between %s and [%s].\n"
 msgstr ""
 "La base de fisión %s es %s.\n"
-"Esto quiere decir que el primer '%s' commit esta entre %s y [%s].\n"
+"Esto quiere decir que el primer '%s' commit está entre %s y [%s].\n"
 
-#: bisect.c:765
+#: bisect.c:776
 #, c-format
 msgid ""
 "Some %s revs are not ancestors of the %s rev.\n"
@@ -926,9 +1442,9 @@ msgid ""
 msgstr ""
 "Algunas %s revisiones no son ancestros de la revisión %s.\n"
 "git bisect no puede trabajar bien en este caso.\n"
-"Tal vez confundió la revisión %s y %s?\n"
+"¿Tal vez confundiste la revisión %s y %s?\n"
 
-#: bisect.c:778
+#: bisect.c:789
 #, c-format
 msgid ""
 "the merge base between %s and [%s] must be skipped.\n"
@@ -936,39 +1452,39 @@ msgid ""
 "We continue anyway."
 msgstr ""
 "la base de fusión entre %s y [%s] tiene que ser saltada.\n"
-"Así que no podemos estar seguros que el primer %s commit esta entre%s y %s.\n"
+"Así que no podemos estar seguros que el primer %s commit está entre%s y %s.\n"
 "Vamos a continuar de todas maneras."
 
-#: bisect.c:811
+#: bisect.c:822
 #, c-format
 msgid "Bisecting: a merge base must be tested\n"
-msgstr "Bisectando: una base de fisión debe ser probada\n"
+msgstr "Biseccionando: una base de fisión debe ser probada\n"
 
-#: bisect.c:851
+#: bisect.c:865
 #, c-format
 msgid "a %s revision is needed"
 msgstr "una %s revisión es necesaria"
 
-#: bisect.c:870 builtin/notes.c:175 builtin/tag.c:236
+#: bisect.c:884 builtin/notes.c:177 builtin/tag.c:254
 #, c-format
 msgid "could not create file '%s'"
 msgstr "no se pudo crear el archivo '%s'"
 
-#: bisect.c:921
+#: bisect.c:928 builtin/merge.c:148
 #, c-format
 msgid "could not read file '%s'"
 msgstr "no se pudo leer el archivo '%s'"
 
-#: bisect.c:951
+#: bisect.c:958
 msgid "reading bisect refs failed"
 msgstr "falló leer las refs de bisect"
 
-#: bisect.c:970
+#: bisect.c:977
 #, c-format
 msgid "%s was both %s and %s\n"
 msgstr "%s fue tanto %s como %s\n"
 
-#: bisect.c:978
+#: bisect.c:985
 #, c-format
 msgid ""
 "No testable commit found.\n"
@@ -977,7 +1493,7 @@ msgstr ""
 "No se encontró commit que se pueda probar.\n"
 "¿Quizás iniciaste con parámetros de rutas incorrectos?\n"
 
-#: bisect.c:997
+#: bisect.c:1004
 #, c-format
 msgid "(roughly %d step)"
 msgid_plural "(roughly %d steps)"
@@ -987,51 +1503,52 @@ msgstr[1] "(aproximadamente %d pasos)"
 #. TRANSLATORS: the last %s will be replaced with "(roughly %d
 #. steps)" translation.
 #.
-#: bisect.c:1003
+#: bisect.c:1010
 #, c-format
 msgid "Bisecting: %d revision left to test after this %s\n"
 msgid_plural "Bisecting: %d revisions left to test after this %s\n"
-msgstr[0] "Bisectando: falta %d revisión por probar después de esto %s\n"
-msgstr[1] "Bisectando: faltan %d revisiones por probar después de esto %s\n"
+msgstr[0] "Biseccionando: falta %d revisión por probar después de esto %s\n"
+msgstr[1] "Biseccionando: faltan %d revisiones por probar después de esto %s\n"
 
-#: blame.c:1756
+#: blame.c:2700
 msgid "--contents and --reverse do not blend well."
 msgstr "--contents y --reverse no se mezclan bien."
 
-#: blame.c:1767
+#: blame.c:2714
 msgid "cannot use --contents with final commit object name"
 msgstr "no se puede usar --contents con el nombre de objeto commit final"
 
-#: blame.c:1787
+#: blame.c:2735
 msgid "--reverse and --first-parent together require specified latest commit"
 msgstr ""
 "--reverse y --first-parent juntos requieren especificar el último commit"
 
-#: blame.c:1796 bundle.c:160 ref-filter.c:2075 sequencer.c:1861
-#: sequencer.c:3632 builtin/commit.c:981 builtin/log.c:366 builtin/log.c:920
-#: builtin/log.c:1371 builtin/log.c:1702 builtin/log.c:1950 builtin/merge.c:372
+#: blame.c:2744 bundle.c:167 ref-filter.c:2203 remote.c:1941 sequencer.c:2093
+#: sequencer.c:4460 builtin/commit.c:1040 builtin/log.c:388 builtin/log.c:991
+#: builtin/log.c:1520 builtin/log.c:1925 builtin/log.c:2215 builtin/merge.c:411
+#: builtin/pack-objects.c:3128 builtin/pack-objects.c:3143
 #: builtin/shortlog.c:192
 msgid "revision walk setup failed"
 msgstr "falló la configuración del camino de revisión"
 
-#: blame.c:1814
+#: blame.c:2762
 msgid ""
 "--reverse --first-parent together require range along first-parent chain"
 msgstr ""
 "--reverse --first-parent juntos requieren un rango a lo largo de la cadena "
 "del primer padre"
 
-#: blame.c:1825
+#: blame.c:2773
 #, c-format
 msgid "no such path %s in %s"
 msgstr "no hay una ruta %s en %s"
 
-#: blame.c:1836
+#: blame.c:2784
 #, c-format
 msgid "cannot read blob %s for path %s"
 msgstr "no se puede leer el blob %s para la ruta %s"
 
-#: branch.c:54
+#: branch.c:53
 #, c-format
 msgid ""
 "\n"
@@ -1044,97 +1561,97 @@ msgstr ""
 "la infamación del rastreo remoto invocando\n"
 "\"git branch --set-upstream-to=%s%s%s\"."
 
-#: branch.c:68
+#: branch.c:67
 #, c-format
 msgid "Not setting branch %s as its own upstream."
 msgstr "La rama %s no se configura como su propio upstream."
 
-#: branch.c:94
+#: branch.c:93
 #, c-format
 msgid "Branch '%s' set up to track remote branch '%s' from '%s' by rebasing."
 msgstr ""
 "Rama '%s' configurada para hacer seguimiento a la rama remota '%s' de '%s' "
 "por rebase."
 
-#: branch.c:95
+#: branch.c:94
 #, c-format
 msgid "Branch '%s' set up to track remote branch '%s' from '%s'."
 msgstr ""
 "Rama '%s' configurada para hacer seguimiento a la rama remota '%s' de '%s'."
 
-#: branch.c:99
+#: branch.c:98
 #, c-format
 msgid "Branch '%s' set up to track local branch '%s' by rebasing."
 msgstr ""
 "Rama '%s' configurada para hacer seguimiento a la rama local '%s' por rebase."
 
-#: branch.c:100
+#: branch.c:99
 #, c-format
 msgid "Branch '%s' set up to track local branch '%s'."
 msgstr "Rama '%s' configurada para hacer seguimiento a la rama local '%s'."
 
-#: branch.c:105
+#: branch.c:104
 #, c-format
 msgid "Branch '%s' set up to track remote ref '%s' by rebasing."
 msgstr ""
 "Rama '%s' configurada para hacer seguimiento a la referencia remota '%s' por "
 "rebase."
 
-#: branch.c:106
+#: branch.c:105
 #, c-format
 msgid "Branch '%s' set up to track remote ref '%s'."
 msgstr ""
 "Rama '%s' configurada para hacer seguimiento a la referencia remota '%s'."
 
-#: branch.c:110
+#: branch.c:109
 #, c-format
 msgid "Branch '%s' set up to track local ref '%s' by rebasing."
 msgstr ""
 "Rama '%s' configurada para hacer seguimiento a la referencia local '%s' por "
 "rebase."
 
-#: branch.c:111
+#: branch.c:110
 #, c-format
 msgid "Branch '%s' set up to track local ref '%s'."
 msgstr ""
 "Rama '%s' configurada para hacer seguimiento a la referencia local '%s'."
 
-#: branch.c:120
+#: branch.c:119
 msgid "Unable to write upstream branch configuration"
 msgstr "No es posible escribir la configuración de la rama upstream"
 
-#: branch.c:157
+#: branch.c:156
 #, c-format
 msgid "Not tracking: ambiguous information for ref %s"
 msgstr "No rastreando: información ambigua para la referencia %s"
 
-#: branch.c:190
+#: branch.c:189
 #, c-format
 msgid "'%s' is not a valid branch name."
-msgstr "'%s' no es un nombre valido de rama."
+msgstr "'%s' no es un nombre válido de rama."
 
-#: branch.c:209
+#: branch.c:208
 #, c-format
 msgid "A branch named '%s' already exists."
 msgstr "Una rama llamada '%s' ya existe."
 
-#: branch.c:214
+#: branch.c:213
 msgid "Cannot force update the current branch."
 msgstr "No se puede forzar la actualización de la rama actual."
 
-#: branch.c:234
+#: branch.c:233
 #, c-format
 msgid "Cannot setup tracking information; starting point '%s' is not a branch."
 msgstr ""
 "No se puede configurar el rastreo de información; el punto de partida '%s' "
 "no es una rama."
 
-#: branch.c:236
+#: branch.c:235
 #, c-format
 msgid "the requested upstream branch '%s' does not exist"
 msgstr "la rama de upstream solicitada '%s' no existe"
 
-#: branch.c:238
+#: branch.c:237
 msgid ""
 "\n"
 "If you are planning on basing your work on an upstream\n"
@@ -1146,7 +1663,7 @@ msgid ""
 "\"git push -u\" to set the upstream config as you push."
 msgstr ""
 "\n"
-"Si estas planeando basar tu trabajo en una rama upstream\n"
+"Si estás planeando basar tu trabajo en una rama upstream\n"
 "que ya existe en el remoto, tal vez necesites ejecutar\n"
 "\"git fetch\" para recibirla.\n"
 "\n"
@@ -1158,7 +1675,7 @@ msgstr ""
 #: branch.c:281
 #, c-format
 msgid "Not a valid object name: '%s'."
-msgstr "Nombre de objeto no valido: '%s'."
+msgstr "Nombre de objeto no válido: '%s'."
 
 #: branch.c:301
 #, c-format
@@ -1168,87 +1685,96 @@ msgstr "Nombre de objeto ambiguo: '%s'."
 #: branch.c:306
 #, c-format
 msgid "Not a valid branch point: '%s'."
-msgstr "Punto de rama no valido: '%s'."
+msgstr "Punto de rama no válido: '%s'."
 
-#: branch.c:360
+#: branch.c:364
 #, c-format
 msgid "'%s' is already checked out at '%s'"
 msgstr "'%s' ya ha sido marcado en '%s'"
 
-#: branch.c:383
+#: branch.c:387
 #, c-format
 msgid "HEAD of working tree %s is not updated"
-msgstr "HEAD del árbol de trabajo %s no esta actualizada"
+msgstr "HEAD del árbol de trabajo %s no está actualizada"
 
-#: bundle.c:34
+#: bundle.c:36
 #, c-format
 msgid "'%s' does not look like a v2 bundle file"
 msgstr "'%s' no se ve como un archivo bundle v2"
 
-#: bundle.c:62
+#: bundle.c:64
 #, c-format
 msgid "unrecognized header: %s%s (%d)"
 msgstr "header no reconocido %s%s (%d)"
 
-#: bundle.c:88 sequencer.c:2081 sequencer.c:2558 builtin/commit.c:755
+#: bundle.c:90 rerere.c:480 rerere.c:690 sequencer.c:2344 sequencer.c:3108
+#: builtin/commit.c:811
 #, c-format
 msgid "could not open '%s'"
 msgstr "no se pudo abrir '%s'"
 
-#: bundle.c:139
+#: bundle.c:143
 msgid "Repository lacks these prerequisite commits:"
 msgstr "Al repositorio le falta estos commits prerrequisito:"
 
-#: bundle.c:190
+#: bundle.c:146
+msgid "need a repository to verify a bundle"
+msgstr "se necesita un repositorio para verificar un bundle"
+
+#: bundle.c:197
 #, c-format
 msgid "The bundle contains this ref:"
 msgid_plural "The bundle contains these %d refs:"
 msgstr[0] "El bundle contiene esta referencia:"
 msgstr[1] "El bundle contiene estas %d referencias:"
 
-#: bundle.c:197
+#: bundle.c:204
 msgid "The bundle records a complete history."
 msgstr "El bundle registra una historia completa."
 
-#: bundle.c:199
+#: bundle.c:206
 #, c-format
 msgid "The bundle requires this ref:"
 msgid_plural "The bundle requires these %d refs:"
 msgstr[0] "El bundle requiere esta referencia:"
 msgstr[1] "El bundle requiere estas %d referencias:"
 
-#: bundle.c:258
+#: bundle.c:273
+msgid "unable to dup bundle descriptor"
+msgstr "incapaz de duplicar bundle descriptor"
+
+#: bundle.c:280
 msgid "Could not spawn pack-objects"
 msgstr "No se pudo crear los pack-objetcts"
 
-#: bundle.c:269
+#: bundle.c:291
 msgid "pack-objects died"
 msgstr "pack-objects murió"
 
-#: bundle.c:311
+#: bundle.c:333
 msgid "rev-list died"
 msgstr "rev-list murió"
 
-#: bundle.c:360
+#: bundle.c:382
 #, c-format
 msgid "ref '%s' is excluded by the rev-list options"
 msgstr "referencia '%s' es excluida por las opciones de rev-list"
 
-#: bundle.c:450 builtin/log.c:183 builtin/log.c:1607 builtin/shortlog.c:303
+#: bundle.c:461 builtin/log.c:203 builtin/log.c:1814 builtin/shortlog.c:306
 #, c-format
 msgid "unrecognized argument: %s"
 msgstr "argumento no reconocido: %s"
 
-#: bundle.c:458
+#: bundle.c:469
 msgid "Refusing to create empty bundle."
 msgstr "Rechazando crear un bundle vacío."
 
-#: bundle.c:470
+#: bundle.c:479
 #, c-format
 msgid "cannot create '%s'"
 msgstr "no se puede crear '%s'"
 
-#: bundle.c:498
+#: bundle.c:504
 msgid "index-pack died"
 msgstr "index-pack murió"
 
@@ -1257,19 +1783,18 @@ msgstr "index-pack murió"
 msgid "invalid color value: %.*s"
 msgstr "color inválido: %.*s"
 
-#: commit.c:43 sequencer.c:2364 builtin/am.c:421 builtin/am.c:465
-#: builtin/am.c:1436 builtin/am.c:2072 builtin/replace.c:376
-#: builtin/replace.c:448
+#: commit.c:51 sequencer.c:2811 builtin/am.c:354 builtin/am.c:398
+#: builtin/am.c:1366 builtin/am.c:2009 builtin/replace.c:456
 #, c-format
 msgid "could not parse %s"
 msgstr "no se puede analizar %s"
 
-#: commit.c:45
+#: commit.c:53
 #, c-format
 msgid "%s %s is not a commit!"
-msgstr "%s %s no es un commit!"
+msgstr "¡%s %s no es un commit!"
 
-#: commit.c:182
+#: commit.c:193
 msgid ""
 "Support for <GIT_DIR>/info/grafts is deprecated\n"
 "and will be removed in a future Git version.\n"
@@ -1281,7 +1806,7 @@ msgid ""
 "\"git config advice.graftFileDeprecated false\""
 msgstr ""
 "El soporte para <GIT_DIR>/info/grafts ha sido deprecado\n"
-"y será removido en una versión futura de Git.\n"
+"y será eliminado en una versión futura de Git.\n"
 "\n"
 "Por favor use \"git replace --convert-graft-file\"\n"
 "para convertir los grafts en refs.\n"
@@ -1289,199 +1814,610 @@ msgstr ""
 "Apapa este mensaje ejecutando\n"
 "\"git config advice.graftFileDeprecated false\""
 
-#: commit.c:1540
+#: commit.c:1152
+#, c-format
+msgid "Commit %s has an untrusted GPG signature, allegedly by %s."
+msgstr "Commit %s tiene una firma GPG no confiable, pretendidamente por %s."
+
+#: commit.c:1155
+#, c-format
+msgid "Commit %s has a bad GPG signature allegedly by %s."
+msgstr "Commit %s tiene una mala firma GPG pretendidamente por %s."
+
+#: commit.c:1158
+#, c-format
+msgid "Commit %s does not have a GPG signature."
+msgstr "Commit %s no tiene una firma GPG."
+
+#: commit.c:1161
+#, c-format
+msgid "Commit %s has a good GPG signature by %s\n"
+msgstr "El Commit %s tiene una buena firma GPG por %s\n"
+
+#: commit.c:1415
 msgid ""
 "Warning: commit message did not conform to UTF-8.\n"
 "You may want to amend it after fixing the message, or set the config\n"
 "variable i18n.commitencoding to the encoding your project uses.\n"
 msgstr ""
 "Peligro: el mensaje del commit no se ajusta a UTF-8.\n"
-"Tal vez quiera enmendarlo después de arreglar el mensaje, o arreglar la\n"
+"Tal vez quieras enmendarlo después de arreglar el mensaje, o arreglar la\n"
 "variable de configuración i18n.commitencoding para la codificación que usa "
-"su proyecto.\n"
+"tu proyecto.\n"
+
+#: commit-graph.c:130
+msgid "commit-graph file is too small"
+msgstr "archivo commit-graph es muy pequeño"
+
+#: commit-graph.c:195
+#, c-format
+msgid "commit-graph signature %X does not match signature %X"
+msgstr "firma %X en commit-graph no concuerda con firma %X"
+
+#: commit-graph.c:202
+#, c-format
+msgid "commit-graph version %X does not match version %X"
+msgstr "versión de commit-graph %X no concuerda con versión %X"
+
+#: commit-graph.c:209
+#, c-format
+msgid "commit-graph hash version %X does not match version %X"
+msgstr "versión de hash de commit-graph %X no concuerda con versión %X"
+
+#: commit-graph.c:232
+msgid "commit-graph chunk lookup table entry missing; file may be incomplete"
+msgstr ""
+"falta tabla de lookup del chunk en commit-graph; el archivo puede estar "
+"incompleto"
+
+#: commit-graph.c:243
+#, c-format
+msgid "commit-graph improper chunk offset %08x%08x"
+msgstr "offset del chunk de commit-graph inapropiado %08x%08x"
+
+#: commit-graph.c:286
+#, c-format
+msgid "commit-graph chunk id %08x appears multiple times"
+msgstr "id de chunk de commit-graph %08x parece tener múltiples tiempos"
+
+#: commit-graph.c:350
+msgid "commit-graph has no base graphs chunk"
+msgstr "commit-graph no tiene una chunk base de graphs"
+
+#: commit-graph.c:360
+msgid "commit-graph chain does not match"
+msgstr "cadena commit-graph no concuerda"
+
+#: commit-graph.c:407
+#, c-format
+msgid "invalid commit-graph chain: line '%s' not a hash"
+msgstr "cadena de commit-graph inválida: línea '%s' no es un hash"
+
+#: commit-graph.c:433
+msgid "unable to find all commit-graph files"
+msgstr "no es posible encontrar los archivos commit-graph"
+
+#: commit-graph.c:564 commit-graph.c:624
+msgid "invalid commit position. commit-graph is likely corrupt"
+msgstr "posición de commit inválida. commit-graph está probablemente corrupto"
+
+#: commit-graph.c:585
+#, c-format
+msgid "could not find commit %s"
+msgstr "no se pudo encontrar commit %s"
+
+#: commit-graph.c:858 builtin/am.c:1287
+#, c-format
+msgid "unable to parse commit %s"
+msgstr "no es posible analizar el commit %s"
+
+#: commit-graph.c:1017 builtin/pack-objects.c:2641
+#, c-format
+msgid "unable to get type of object %s"
+msgstr "incapaz de obtener el tipo de objeto: %s"
+
+#: commit-graph.c:1049
+msgid "Loading known commits in commit graph"
+msgstr "Cargando commits conocidos en commit graph"
+
+#: commit-graph.c:1066
+msgid "Expanding reachable commits in commit graph"
+msgstr "Expandiendo commits alcanzables en commit graph"
+
+#: commit-graph.c:1085
+msgid "Clearing commit marks in commit graph"
+msgstr "Limpiando marcas de commits en commit graph"
+
+#: commit-graph.c:1104
+msgid "Computing commit graph generation numbers"
+msgstr "Calculando números de generación de commit graph"
+
+#: commit-graph.c:1179
+#, c-format
+msgid "Finding commits for commit graph in %d pack"
+msgid_plural "Finding commits for commit graph in %d packs"
+msgstr[0] "Encontrando commits para commit graph en %d pack"
+msgstr[1] "Encontrando commits para commit graph en %d packs"
+
+#: commit-graph.c:1192
+#, c-format
+msgid "error adding pack %s"
+msgstr "error agregando pack %s"
+
+#: commit-graph.c:1196
+#, c-format
+msgid "error opening index for %s"
+msgstr "error abriendo index para %s"
+
+#: commit-graph.c:1220
+#, c-format
+msgid "Finding commits for commit graph from %d ref"
+msgid_plural "Finding commits for commit graph from %d refs"
+msgstr[0] "Encontrando commits para commit graph de %d ref"
+msgstr[1] "Encontrando commits para commit graph de %d refs"
+
+#: commit-graph.c:1240
+#, c-format
+msgid "invalid commit object id: %s"
+msgstr "id de objeto commit: %s inválido"
+
+#: commit-graph.c:1255
+msgid "Finding commits for commit graph among packed objects"
+msgstr "Encontrando commits para commit graph entre los objetos empaquetados"
+
+#: commit-graph.c:1270
+msgid "Counting distinct commits in commit graph"
+msgstr "Contando commits distintos en commit graph"
+
+#: commit-graph.c:1300
+msgid "Finding extra edges in commit graph"
+msgstr "Encontrando esquinas extra en commit graph"
+
+#: commit-graph.c:1346
+msgid "failed to write correct number of base graph ids"
+msgstr "falló al escribir el número correcto de ids de base graph"
+
+#: commit-graph.c:1379 midx.c:814
+#, c-format
+msgid "unable to create leading directories of %s"
+msgstr "no se pudo crear directorios principales para %s"
+
+#: commit-graph.c:1391 builtin/index-pack.c:306 builtin/repack.c:248
+#, c-format
+msgid "unable to create '%s'"
+msgstr "no se puede crear '%s'"
+
+#: commit-graph.c:1451
+#, c-format
+msgid "Writing out commit graph in %d pass"
+msgid_plural "Writing out commit graph in %d passes"
+msgstr[0] "Escribiendo commit graph en %d paso"
+msgstr[1] "Escribiendo commit graph en %d pasos"
+
+#: commit-graph.c:1492
+msgid "unable to open commit-graph chain file"
+msgstr "no se pudo abrir la cadena de archivos commit-graph"
+
+#: commit-graph.c:1504
+msgid "failed to rename base commit-graph file"
+msgstr "no se pudo renombrar el archivo base commit-graph"
+
+#: commit-graph.c:1524
+msgid "failed to rename temporary commit-graph file"
+msgstr "falló al renombrar el archivo temporal commit-graph"
+
+#: commit-graph.c:1635
+msgid "Scanning merged commits"
+msgstr "Escaneando commits fusionados"
+
+#: commit-graph.c:1646
+#, c-format
+msgid "unexpected duplicate commit id %s"
+msgstr "id de commit duplicado inesperado %s"
+
+#: commit-graph.c:1670
+msgid "Merging commit-graph"
+msgstr "Fusionando commit-graph"
 
-#: commit-graph.c:669
+#: commit-graph.c:1860
 #, c-format
 msgid "the commit graph format cannot write %d commits"
 msgstr "el formato de gráficos de commit no pudede escribir %d commits"
 
-#: commit-graph.c:696
+#: commit-graph.c:1871
 msgid "too many commits to write graph"
 msgstr "demasiados commits para escribir el gráfico"
 
-#: commit-graph.c:707 builtin/init-db.c:516 builtin/init-db.c:521
+#: commit-graph.c:1961
+msgid "the commit-graph file has incorrect checksum and is likely corrupt"
+msgstr ""
+"el archivo de commit-graph tiene checksums incorrectos y probablemente está "
+"corrupto"
+
+#: commit-graph.c:1971
 #, c-format
-msgid "cannot mkdir %s"
-msgstr "no se pude crear directorio %s"
+msgid "commit-graph has incorrect OID order: %s then %s"
+msgstr "commit-graph tiene un orden de OID incorrecto: %s luego %s"
+
+#: commit-graph.c:1981 commit-graph.c:1996
+#, c-format
+msgid "commit-graph has incorrect fanout value: fanout[%d] = %u != %u"
+msgstr "commit-graph tiene un valor fanout incorrecto: fanout[%d] = %u != %u"
+
+#: commit-graph.c:1988
+#, c-format
+msgid "failed to parse commit %s from commit-graph"
+msgstr "falló al analizar commit %s para commit-graph"
+
+#: commit-graph.c:2006
+msgid "Verifying commits in commit graph"
+msgstr "Verificando commits en commit graph"
+
+#: commit-graph.c:2020
+#, c-format
+msgid "failed to parse commit %s from object database for commit-graph"
+msgstr ""
+"falló al analizar el commit %s de la base de datos de objetos para commit-"
+"graph"
+
+#: commit-graph.c:2027
+#, c-format
+msgid "root tree OID for commit %s in commit-graph is %s != %s"
+msgstr "árbol raíz OID para commit %s en commit-graph es %s != %s"
+
+#: commit-graph.c:2037
+#, c-format
+msgid "commit-graph parent list for commit %s is too long"
+msgstr "lista padre de commit-graph para commit %s es muy larga"
+
+#: commit-graph.c:2046
+#, c-format
+msgid "commit-graph parent for %s is %s != %s"
+msgstr "padre de commit-graph para %s es %s != %s"
+
+#: commit-graph.c:2059
+#, c-format
+msgid "commit-graph parent list for commit %s terminates early"
+msgstr "lista padre de commit-graph para commit %s termina antes"
+
+#: commit-graph.c:2064
+#, c-format
+msgid ""
+"commit-graph has generation number zero for commit %s, but non-zero elsewhere"
+msgstr ""
+"commit-graph ha generado número cero para %s, pero no-cero para los demás"
+
+#: commit-graph.c:2068
+#, c-format
+msgid ""
+"commit-graph has non-zero generation number for commit %s, but zero elsewhere"
+msgstr ""
+"commit-graph tiene generación no-cero para %s, pero cero para los demás"
+
+#: commit-graph.c:2083
+#, c-format
+msgid "commit-graph generation for commit %s is %u != %u"
+msgstr "generación commit-graph para commit %s es %u != %u"
 
-#: compat/obstack.c:405 compat/obstack.c:407
+#: commit-graph.c:2089
+#, c-format
+msgid "commit date for commit %s in commit-graph is %<PRIuMAX> != %<PRIuMAX>"
+msgstr ""
+"fecha de commit para commit %s en commit-graph es %<PRIuMAX> != %<PRIuMAX>"
+
+#: compat/obstack.c:406 compat/obstack.c:408
 msgid "memory exhausted"
 msgstr "memoria agotada"
 
-#: config.c:187
+#: config.c:124
+#, c-format
+msgid ""
+"exceeded maximum include depth (%d) while including\n"
+"\t%s\n"
+"from\n"
+"\t%s\n"
+"This might be due to circular includes."
+msgstr ""
+"profundidad máxima de inclusión excedida (%d) mientras se incluía\n"
+"\t%s\n"
+"de\n"
+"\t%s\n"
+"Esto puede ser causado por inclusiones circulares."
+
+#: config.c:140
+#, c-format
+msgid "could not expand include path '%s'"
+msgstr "no se pudo expandir rutas de inclusión '%s'"
+
+#: config.c:151
+msgid "relative config includes must come from files"
+msgstr "inclusiones de configuración relativas tienen que venir de archivos"
+
+#: config.c:197
 msgid "relative config include conditionals must come from files"
 msgstr ""
 "la configuración relativa incluye condicionales que deben venir de archivos"
 
-#: config.c:788
+#: config.c:376
+#, c-format
+msgid "key does not contain a section: %s"
+msgstr "llave no contiene una sección: %s"
+
+#: config.c:382
+#, c-format
+msgid "key does not contain variable name: %s"
+msgstr "llave no contiene el nombre de variable: %s"
+
+#: config.c:406 sequencer.c:2530
+#, c-format
+msgid "invalid key: %s"
+msgstr "llave inválida: %s"
+
+#: config.c:412
+#, c-format
+msgid "invalid key (newline): %s"
+msgstr "llave inválida (nueva línea): %s"
+
+#: config.c:448 config.c:460
+#, c-format
+msgid "bogus config parameter: %s"
+msgstr "parámetro de configuración malogrado: %s"
+
+#: config.c:495
+#, c-format
+msgid "bogus format in %s"
+msgstr "formato malogrado en %s"
+
+#: config.c:821
 #, c-format
 msgid "bad config line %d in blob %s"
 msgstr "mala línea de config %d en el blob %s"
 
-#: config.c:792
+#: config.c:825
 #, c-format
 msgid "bad config line %d in file %s"
 msgstr "mala línea de config %d en el archivo %s"
 
-#: config.c:796
+#: config.c:829
 #, c-format
 msgid "bad config line %d in standard input"
 msgstr "mala línea de config %d en la entrada standard"
 
-#: config.c:800
+#: config.c:833
 #, c-format
 msgid "bad config line %d in submodule-blob %s"
 msgstr "mala línea de config %d en el submódulo-blob %s"
 
-#: config.c:804
+#: config.c:837
 #, c-format
 msgid "bad config line %d in command line %s"
 msgstr "mala línea de config %d en la línea de comando %s"
 
-#: config.c:808
+#: config.c:841
 #, c-format
 msgid "bad config line %d in %s"
 msgstr "mala línea de config %d en %s"
 
-#: config.c:936
+#: config.c:978
 msgid "out of range"
 msgstr "fuera de rango"
 
-#: config.c:936
+#: config.c:978
 msgid "invalid unit"
-msgstr "unidad invalida"
+msgstr "unidad inválida"
 
-#: config.c:942
+#: config.c:979
 #, c-format
 msgid "bad numeric config value '%s' for '%s': %s"
 msgstr "mal valor de config numérica '%s' para '%s': %s"
 
-#: config.c:947
+#: config.c:998
 #, c-format
 msgid "bad numeric config value '%s' for '%s' in blob %s: %s"
 msgstr "mal valor de config numérica '%s' para '%s' en el blob %s: %s"
 
-#: config.c:950
+#: config.c:1001
 #, c-format
 msgid "bad numeric config value '%s' for '%s' in file %s: %s"
 msgstr "mal valor de config numérica '%s' para '%s' en el archivo %s: %s"
 
-#: config.c:953
+#: config.c:1004
 #, c-format
 msgid "bad numeric config value '%s' for '%s' in standard input: %s"
 msgstr "mal valor de config numérica '%s' para '%s' en la entrada standard: %s"
 
-#: config.c:956
+#: config.c:1007
 #, c-format
 msgid "bad numeric config value '%s' for '%s' in submodule-blob %s: %s"
 msgstr ""
 "mal valor de config numérica '%s' para '%s' en el submódulo-blob %s: %s"
 
-#: config.c:959
+#: config.c:1010
 #, c-format
 msgid "bad numeric config value '%s' for '%s' in command line %s: %s"
 msgstr ""
 "mal valor de config numérica '%s' para '%s' en la línea de comando %s: %s"
 
-#: config.c:962
+#: config.c:1013
 #, c-format
 msgid "bad numeric config value '%s' for '%s' in %s: %s"
 msgstr "mal valor de config numérica '%s' para '%s' en %s: %s"
 
-#: config.c:1057
+#: config.c:1108
 #, c-format
 msgid "failed to expand user dir in: '%s'"
 msgstr "falló al expandir el directorio de usuario en: '%s'"
 
-#: config.c:1066
+#: config.c:1117
 #, c-format
 msgid "'%s' for '%s' is not a valid timestamp"
 msgstr "'%s' para '%s' no es una marca de tiempo válida"
 
-#: config.c:1171 config.c:1182
+#: config.c:1208
+#, c-format
+msgid "abbrev length out of range: %d"
+msgstr "largo de abreviatura fuera de rango: %d"
+
+#: config.c:1222 config.c:1233
 #, c-format
 msgid "bad zlib compression level %d"
-msgstr "mala compresión zlib en nivel %d"
+msgstr "nivel de compresión de zlib erróneo %d"
+
+#: config.c:1325
+msgid "core.commentChar should only be one character"
+msgstr "core.commentChar debería tener solo un caracter"
 
-#: config.c:1307
+#: config.c:1358
 #, c-format
 msgid "invalid mode for object creation: %s"
-msgstr "modo invalido de creación de objetos: %s"
+msgstr "modo inválido de creación de objetos: %s"
+
+#: config.c:1430
+#, c-format
+msgid "malformed value for %s"
+msgstr "valor malformado para %s"
 
-#: config.c:1473
+#: config.c:1456
+#, c-format
+msgid "malformed value for %s: %s"
+msgstr "valor malformado para %s: %s"
+
+#: config.c:1457
+msgid "must be one of nothing, matching, simple, upstream or current"
+msgstr "debe ser uno de nothing, matching, simple, upstream o current"
+
+#: config.c:1518 builtin/pack-objects.c:3394
 #, c-format
 msgid "bad pack compression level %d"
-msgstr "mala compresión pack en el nivel %d"
+msgstr "nivel de compresión de pack erróneo %d"
+
+#: config.c:1639
+#, c-format
+msgid "unable to load config blob object '%s'"
+msgstr "incapaz de cargar configuración de objeto blob '%s'"
+
+#: config.c:1642
+#, c-format
+msgid "reference '%s' does not point to a blob"
+msgstr "referencia '%s' no apunta a un blob"
+
+#: config.c:1659
+#, c-format
+msgid "unable to resolve config blob '%s'"
+msgstr "no se posible resolver configuración de blob '%s'"
+
+#: config.c:1689
+#, c-format
+msgid "failed to parse %s"
+msgstr "no se pudo analizar %s"
 
-#: config.c:1681
+#: config.c:1745
 msgid "unable to parse command-line config"
 msgstr "no es posible analizar la configuración de la línea de comando"
 
-#: config.c:2013
+#: config.c:2096
 msgid "unknown error occurred while reading the configuration files"
 msgstr ""
 "error desconocido ocurrió mientras se leían los archivos de configuración"
 
-#: config.c:2200
+#: config.c:2266
 #, c-format
 msgid "Invalid %s: '%s'"
-msgstr "Invalido %s: '%s'"
-
-#: config.c:2243
-#, c-format
-msgid "unknown core.untrackedCache value '%s'; using 'keep' default value"
-msgstr ""
-"valor core.untrackedCache '%s' desconocido; usando 'keep' como valor por "
-"defecto"
+msgstr "Inválido %s: '%s'"
 
-#: config.c:2269
+#: config.c:2311
 #, c-format
 msgid "splitIndex.maxPercentChange value '%d' should be between 0 and 100"
 msgstr "valor splitIndex.maxPercentChange '%d' debe estar entre 0 y 100"
 
-#: config.c:2294
+#: config.c:2357
 #, c-format
 msgid "unable to parse '%s' from command-line config"
 msgstr "no es posible analizar '%s' de la configuración de la línea de comando"
 
-#: config.c:2296
+#: config.c:2359
 #, c-format
 msgid "bad config variable '%s' in file '%s' at line %d"
 msgstr "mala variable de config '%s' en el archivo '%s' en la línea %d"
 
-#: config.c:2402
+#: config.c:2440
+#, c-format
+msgid "invalid section name '%s'"
+msgstr "nombre de sección inválido '%s'"
+
+#: config.c:2472
 #, c-format
 msgid "%s has multiple values"
 msgstr "%s tiene múltiples valores"
 
-#: config.c:2766 config.c:3019
+#: config.c:2501
+#, c-format
+msgid "failed to write new configuration file %s"
+msgstr "falló al escribir nuevo archivo de configuración %s"
+
+#: config.c:2753 config.c:3077
+#, c-format
+msgid "could not lock config file %s"
+msgstr "no se pudo bloquear archivo de configuración %s"
+
+#: config.c:2764
+#, c-format
+msgid "opening %s"
+msgstr "abriendo %s"
+
+#: config.c:2799 builtin/config.c:328
+#, c-format
+msgid "invalid pattern: %s"
+msgstr "patrón inválido: %s"
+
+#: config.c:2824
+#, c-format
+msgid "invalid config file %s"
+msgstr "archivo de configuración inválido: %s"
+
+#: config.c:2837 config.c:3090
 #, c-format
 msgid "fstat on %s failed"
 msgstr "fstat en %s falló"
 
-#: config.c:2905
+#: config.c:2848
+#, c-format
+msgid "unable to mmap '%s'"
+msgstr "no es posible hacer mmap '%s'"
+
+#: config.c:2857 config.c:3095
+#, c-format
+msgid "chmod on %s failed"
+msgstr "chmod en %s falló"
+
+#: config.c:2942 config.c:3192
+#, c-format
+msgid "could not write config file %s"
+msgstr "no se pudo escribir el archivo de configuración %s"
+
+#: config.c:2976
 #, c-format
 msgid "could not set '%s' to '%s'"
 msgstr "no se pudo configurar '%s' a '%s'"
 
-#: config.c:2907 builtin/remote.c:779
+#: config.c:2978 builtin/remote.c:781
 #, c-format
 msgid "could not unset '%s'"
 msgstr "no se pudo desactivar '%s'"
 
+#: config.c:3068
+#, c-format
+msgid "invalid section name: %s"
+msgstr "sección de nombre inválida: %s"
+
+#: config.c:3235
+#, c-format
+msgid "missing value for '%s'"
+msgstr "valor faltante para '%s'"
+
 #: connect.c:61
-msgid "The remote end hung up upon initial contact"
-msgstr "El remoto se colgó en el contacto inicial"
+msgid "the remote end hung up upon initial contact"
+msgstr "el remoto se colgó en el contacto inicial"
 
 #: connect.c:63
 msgid ""
@@ -1492,68 +2428,215 @@ msgid ""
 msgstr ""
 "No se pudo leer del repositorio remoto.\n"
 "\n"
-"Por favor asegúrese que tiene los permisos de acceso correctos\n"
+"Por favor asegúrate que tienes los permisos de acceso correctos\n"
 "y que el repositorio existe."
 
-#: connected.c:66 builtin/fsck.c:201 builtin/prune.c:145
-msgid "Checking connectivity"
-msgstr "Verificando conectividad"
+#: connect.c:81
+#, c-format
+msgid "server doesn't support '%s'"
+msgstr "servidor no soporta '%s'"
 
-#: connected.c:78
-msgid "Could not run 'git rev-list'"
-msgstr "No se pudo correr 'git rev-list'"
+#: connect.c:103
+#, c-format
+msgid "server doesn't support feature '%s'"
+msgstr "servidor no soporta feature '%s'"
 
-#: connected.c:98
-msgid "failed write to rev-list"
-msgstr "falló escribir a rev-list"
+#: connect.c:114
+msgid "expected flush after capabilities"
+msgstr "se espera flush tras capacidades"
 
-#: connected.c:105
-msgid "failed to close rev-list's stdin"
-msgstr "falló al cerrar la entrada standard de rev-list"
+#: connect.c:233
+#, c-format
+msgid "ignoring capabilities after first line '%s'"
+msgstr "ignorando capacidades tras primera línea '%s'"
+
+#: connect.c:252
+msgid "protocol error: unexpected capabilities^{}"
+msgstr "error de protocolo: capacidades imprevistas^{}"
 
-#: convert.c:206
+#: connect.c:273
 #, c-format
-msgid "CRLF would be replaced by LF in %s."
-msgstr "CRLF será reemplazado por LF en %s."
+msgid "protocol error: expected shallow sha-1, got '%s'"
+msgstr "error de protocolo: sha-1 superficial esperado, se obtuvo '%s'"
 
-#: convert.c:208
+#: connect.c:275
+msgid "repository on the other end cannot be shallow"
+msgstr "el repositorio en el otro final no puede ser superficial"
+
+#: connect.c:313
+msgid "invalid packet"
+msgstr "paquete inválido"
+
+#: connect.c:333
 #, c-format
-msgid ""
-"CRLF will be replaced by LF in %s.\n"
-"The file will have its original line endings in your working directory."
-msgstr ""
-"CRLF será remplazado por LF en %s.\n"
-"El archivo tendrá sus finales de línea originales en tu directorio de "
-"trabajo."
+msgid "protocol error: unexpected '%s'"
+msgstr "error de protocolo: '%s' inesperado"
 
-#: convert.c:216
+#: connect.c:441
 #, c-format
-msgid "LF would be replaced by CRLF in %s"
-msgstr "LF será reemplazado por CRLF en %s"
+msgid "invalid ls-refs response: %s"
+msgstr "respuesta de referencias ls-refs inválida: %s"
+
+#: connect.c:445
+msgid "expected flush after ref listing"
+msgstr "flush esperado tras listado de refs"
 
-#: convert.c:218
+#: connect.c:544
 #, c-format
-msgid ""
-"LF will be replaced by CRLF in %s.\n"
-"The file will have its original line endings in your working directory."
-msgstr ""
-"LF será reemplazado por CRLF en %s.\n"
-"El archivo tendrá sus finales de línea originales en tu directorio de "
-"trabajo."
+msgid "protocol '%s' is not supported"
+msgstr "protocolo '%s' no es soportado"
+
+#: connect.c:595
+msgid "unable to set SO_KEEPALIVE on socket"
+msgstr "no es posible configurar SO_KEEPALIVE en el socket"
 
-#: convert.c:279
+#: connect.c:635 connect.c:698
+#, c-format
+msgid "Looking up %s ... "
+msgstr "Revisando %s... "
+
+#: connect.c:639
+#, c-format
+msgid "unable to look up %s (port %s) (%s)"
+msgstr "no se puede revisar %s (puerto %s) (%s)"
+
+#. TRANSLATORS: this is the end of "Looking up %s ... "
+#: connect.c:643 connect.c:714
+#, c-format
+msgid ""
+"done.\n"
+"Connecting to %s (port %s) ... "
+msgstr ""
+"hecho.\n"
+"Conectando a %s (puerto %s) ... "
+
+#: connect.c:665 connect.c:742
+#, c-format
+msgid ""
+"unable to connect to %s:\n"
+"%s"
+msgstr ""
+"no es posible conectar a %s:\n"
+"%s"
+
+#. TRANSLATORS: this is the end of "Connecting to %s (port %s) ... "
+#: connect.c:671 connect.c:748
+msgid "done."
+msgstr "hecho."
+
+#: connect.c:702
+#, c-format
+msgid "unable to look up %s (%s)"
+msgstr "no es posible revisar %s (%s)"
+
+#: connect.c:708
+#, c-format
+msgid "unknown port %s"
+msgstr "puerto desconocido %s"
+
+#: connect.c:845 connect.c:1175
+#, c-format
+msgid "strange hostname '%s' blocked"
+msgstr "hostname extraño '%s' bloqueado"
+
+#: connect.c:847
+#, c-format
+msgid "strange port '%s' blocked"
+msgstr "puerto extraño '%s' bloqueado"
+
+#: connect.c:857
+#, c-format
+msgid "cannot start proxy %s"
+msgstr "no se puede comenzar proxy %s"
+
+#: connect.c:928
+msgid "no path specified; see 'git help pull' for valid url syntax"
+msgstr ""
+"no hay ruta especificada; vea 'git help pull' para sintaxis de url válidas"
+
+#: connect.c:1123
+msgid "ssh variant 'simple' does not support -4"
+msgstr "variante 'simple' de ssh no soporta -4"
+
+#: connect.c:1135
+msgid "ssh variant 'simple' does not support -6"
+msgstr "variante 'simple' de ssh no soporta -6"
+
+#: connect.c:1152
+msgid "ssh variant 'simple' does not support setting port"
+msgstr "variante ssh 'simple' no soporta configurar puerto"
+
+#: connect.c:1264
+#, c-format
+msgid "strange pathname '%s' blocked"
+msgstr "ruta extraña '%s' bloqueada"
+
+#: connect.c:1311
+msgid "unable to fork"
+msgstr "no es posible hacer fork"
+
+#: connected.c:89 builtin/fsck.c:208 builtin/prune.c:43
+msgid "Checking connectivity"
+msgstr "Verificando conectividad"
+
+#: connected.c:101
+msgid "Could not run 'git rev-list'"
+msgstr "No se pudo correr 'git rev-list'"
+
+#: connected.c:121
+msgid "failed write to rev-list"
+msgstr "falló escribir a rev-list"
+
+#: connected.c:128
+msgid "failed to close rev-list's stdin"
+msgstr "falló al cerrar la entrada standard de rev-list"
+
+#: convert.c:194
+#, c-format
+msgid "illegal crlf_action %d"
+msgstr "crlf_action %d ilegal"
+
+#: convert.c:207
+#, c-format
+msgid "CRLF would be replaced by LF in %s"
+msgstr "CRLF será reemplazado por LF en %s"
+
+#: convert.c:209
+#, c-format
+msgid ""
+"CRLF will be replaced by LF in %s.\n"
+"The file will have its original line endings in your working directory"
+msgstr ""
+"CRLF será remplazado por LF en %s.\n"
+"El archivo tendrá sus finales de línea originales en tu directorio de trabajo"
+
+#: convert.c:217
+#, c-format
+msgid "LF would be replaced by CRLF in %s"
+msgstr "LF será reemplazado por CRLF en %s"
+
+#: convert.c:219
+#, c-format
+msgid ""
+"LF will be replaced by CRLF in %s.\n"
+"The file will have its original line endings in your working directory"
+msgstr ""
+"LF será reemplazado por CRLF en %s.\n"
+"El archivo tendrá sus finales de línea originales en tu directorio de trabajo"
+
+#: convert.c:284
 #, c-format
 msgid "BOM is prohibited in '%s' if encoded as %s"
 msgstr "BOM está prohibido en '%s' si es codificado como %s"
 
-#: convert.c:286
+#: convert.c:291
 #, c-format
 msgid ""
-"The file '%s' contains a byte order mark (BOM). Please use UTF-%s as working-"
-"tree-encoding."
-msgstr ""
-"El archivo '%s' contiene una marca de byte (BOM). Por favor usa UTF-%s como "
+"The file '%s' contains a byte order mark (BOM). Please use UTF-%.*s as "
 "working-tree-encoding."
+msgstr ""
+"El archivo '%s' contiene una marca de byte (BOM). Por favor usa UTF-%.*s "
+"como working-tree-encoding."
 
 #: convert.c:304
 #, c-format
@@ -1569,67 +2652,119 @@ msgstr ""
 "Al archivo '%s' le falta una marca de byte (BOM). Por favor usa UTF-%sBE o "
 "UTF-%sLE (dependiendo en el orden de byte) como working-tree-encoding."
 
-#: convert.c:424
+#: convert.c:419 convert.c:490
 #, c-format
 msgid "failed to encode '%s' from %s to %s"
 msgstr "falló al codificar '%s' de %s a %s"
 
-#: convert.c:467
+#: convert.c:462
 #, c-format
 msgid "encoding '%s' from %s to %s and back is not the same"
 msgstr "codificación '%s' de %s a %s y de vuelta no son iguales"
 
-#: convert.c:1225
+#: convert.c:668
+#, c-format
+msgid "cannot fork to run external filter '%s'"
+msgstr "no se puede hacer fork para ejecutar filtros externos '%s'"
+
+#: convert.c:688
+#, c-format
+msgid "cannot feed the input to external filter '%s'"
+msgstr "no se pueden alimentar de input a los filtros externos '%s'"
+
+#: convert.c:695
+#, c-format
+msgid "external filter '%s' failed %d"
+msgstr "filtro externo '%s' falló %d"
+
+#: convert.c:730 convert.c:733
+#, c-format
+msgid "read from external filter '%s' failed"
+msgstr "lectura de filtro externo '%s' falló"
+
+#: convert.c:736 convert.c:791
+#, c-format
+msgid "external filter '%s' failed"
+msgstr "filtro externo '%s' falló"
+
+#: convert.c:839
+msgid "unexpected filter type"
+msgstr "tipo de filtro inesperado"
+
+#: convert.c:850
+msgid "path name too long for external filter"
+msgstr "nombre de ruta muy largo para filtro externo"
+
+#: convert.c:924
+#, c-format
+msgid ""
+"external filter '%s' is not available anymore although not all paths have "
+"been filtered"
+msgstr ""
+"filtro externo '%s' ya no está disponible aunque no todas las rutas han sido "
+"filtradas"
+
+#: convert.c:1223
 msgid "true/false are no valid working-tree-encodings"
 msgstr "true/false no son working-tree-encodings válidos"
 
-#: date.c:116
+#: convert.c:1411 convert.c:1445
+#, c-format
+msgid "%s: clean filter '%s' failed"
+msgstr "%s: falló al limpiar filtro '%s'"
+
+#: convert.c:1489
+#, c-format
+msgid "%s: smudge filter %s failed"
+msgstr "%s: filtro smudge %s falló"
+
+#: date.c:138
 msgid "in the future"
 msgstr "en el futuro"
 
-#: date.c:122
+#: date.c:144
 #, c-format
 msgid "%<PRIuMAX> second ago"
 msgid_plural "%<PRIuMAX> seconds ago"
 msgstr[0] "hace %<PRIuMAX> segundo"
 msgstr[1] "hace %<PRIuMAX> segundos"
 
-#: date.c:129
+#: date.c:151
 #, c-format
 msgid "%<PRIuMAX> minute ago"
 msgid_plural "%<PRIuMAX> minutes ago"
 msgstr[0] "hace %<PRIuMAX> minuto"
 msgstr[1] "hace %<PRIuMAX> minutos"
 
-#: date.c:136
+#: date.c:158
 #, c-format
 msgid "%<PRIuMAX> hour ago"
 msgid_plural "%<PRIuMAX> hours ago"
 msgstr[0] "hace %<PRIuMAX> hora"
 msgstr[1] "hace %<PRIuMAX> horas"
 
-#: date.c:143
+#: date.c:165
 #, c-format
 msgid "%<PRIuMAX> day ago"
 msgid_plural "%<PRIuMAX> days ago"
 msgstr[0] "hace %<PRIuMAX> día"
 msgstr[1] "hace %<PRIuMAX> días"
 
-#: date.c:149
+#: date.c:171
 #, c-format
 msgid "%<PRIuMAX> week ago"
 msgid_plural "%<PRIuMAX> weeks ago"
 msgstr[0] "hace %<PRIuMAX> semana"
 msgstr[1] "hace %<PRIuMAX> semanas"
 
-#: date.c:156
+#: date.c:178
 #, c-format
 msgid "%<PRIuMAX> month ago"
 msgid_plural "%<PRIuMAX> months ago"
 msgstr[0] "hace %<PRIuMAX> mes"
 msgstr[1] "hace %<PRIuMAX> meses"
 
-#: date.c:167
+#: date.c:189
 #, c-format
 msgid "%<PRIuMAX> year"
 msgid_plural "%<PRIuMAX> years"
@@ -1637,59 +2772,108 @@ msgstr[0] "%<PRIuMAX> año"
 msgstr[1] "%<PRIuMAX> años"
 
 #. TRANSLATORS: "%s" is "<n> years"
-#: date.c:170
+#: date.c:192
 #, c-format
 msgid "%s, %<PRIuMAX> month ago"
 msgid_plural "%s, %<PRIuMAX> months ago"
 msgstr[0] "%s, y %<PRIuMAX> mes atrás"
 msgstr[1] "%s, y %<PRIuMAX> meses atrás"
 
-#: date.c:175 date.c:180
+#: date.c:197 date.c:202
 #, c-format
 msgid "%<PRIuMAX> year ago"
 msgid_plural "%<PRIuMAX> years ago"
 msgstr[0] "hace %<PRIuMAX> año"
 msgstr[1] "hace %<PRIuMAX> años"
 
+#: delta-islands.c:272
+msgid "Propagating island marks"
+msgstr "Propagando marcas isla"
+
+#: delta-islands.c:290
+#, c-format
+msgid "bad tree object %s"
+msgstr "mal objeto árbol %s"
+
+#: delta-islands.c:334
+#, c-format
+msgid "failed to load island regex for '%s': %s"
+msgstr "falló al cargar isla de regex para '%s': %s"
+
+#: delta-islands.c:390
+#, c-format
+msgid "island regex from config has too many capture groups (max=%d)"
+msgstr "regex isla de config tiene muchos grupos de captura (max=%d)"
+
+#: delta-islands.c:467
+#, c-format
+msgid "Marked %d islands, done.\n"
+msgstr "%d islas marcadas, listo.\n"
+
 #: diffcore-order.c:24
 #, c-format
 msgid "failed to read orderfile '%s'"
 msgstr "falló al leer orden de archivos '%s'"
 
-#: diffcore-rename.c:535
+#: diffcore-rename.c:543
 msgid "Performing inexact rename detection"
 msgstr "Realizando una detección de cambios de nombre inexacta"
 
-#: diff.c:74
-#, c-format
-msgid "option '%s' requires a value"
-msgstr "opción '%s' requiere un valor"
+#: diff-no-index.c:238
+msgid "git diff --no-index [<options>] <path> <path>"
+msgstr "git diff --no-index [<opciones>] <path> <path>"
+
+#: diff-no-index.c:263
+msgid ""
+"Not a git repository. Use --no-index to compare two paths outside a working "
+"tree"
+msgstr ""
+"No es un repositorio git. Use --no-index para comparar dos paths fuera del "
+"árbol de trabajo"
 
-#: diff.c:152
+#: diff.c:155
 #, c-format
 msgid "  Failed to parse dirstat cut-off percentage '%s'\n"
 msgstr "  Falló al analizar dirstat porcentaje de corte '%s'\n"
 
-#: diff.c:157
+#: diff.c:160
 #, c-format
 msgid "  Unknown dirstat parameter '%s'\n"
 msgstr "  parámetro '%s' de dirstat desconocido\n"
 
-#: diff.c:281
+#: diff.c:296
+msgid ""
+"color moved setting must be one of 'no', 'default', 'blocks', 'zebra', "
+"'dimmed-zebra', 'plain'"
+msgstr ""
+"opción de color tiene que ser una de 'no', 'default', 'blocks', 'zebra', "
+"'dimmed_zebra', 'plain'"
+
+#: diff.c:324
+#, c-format
+msgid ""
+"unknown color-moved-ws mode '%s', possible values are 'ignore-space-change', "
+"'ignore-space-at-eol', 'ignore-all-space', 'allow-indentation-change'"
+msgstr ""
+"modo color-moved-ws desconocido '%s', valores posibles son 'ignore-space-"
+"change', 'ignore-space-at-eol', 'ignore-all-space', 'allow-indentation-"
+"change'"
+
+#: diff.c:332
 msgid ""
-"color moved setting must be one of 'no', 'default', 'zebra', 'dimmed_zebra', "
-"'plain'"
+"color-moved-ws: allow-indentation-change cannot be combined with other "
+"whitespace modes"
 msgstr ""
-"opción de color debe ser una entre 'no', 'default', 'zebra', 'dimmed_zebra, "
-"'plain'"
+"color-moved-ws: allow-indentation-change no puede ser combinado con otros "
+"modos de espacios en blanco"
 
-#: diff.c:341
+#: diff.c:405
 #, c-format
 msgid "Unknown value for 'diff.submodule' config variable: '%s'"
 msgstr ""
 "Valor para la variable de configuración 'diff.submodule' desconocido: '%s'"
 
-#: diff.c:401
+#: diff.c:465
 #, c-format
 msgid ""
 "Found errors in 'diff.dirstat' config variable:\n"
@@ -1698,24 +2882,35 @@ msgstr ""
 "Errores en la variable de config 'diff.dirstat' encontrados:\n"
 "%s"
 
-#: diff.c:3823
+#: diff.c:4202
 #, c-format
 msgid "external diff died, stopping at %s"
 msgstr "diff externo murió, deteniendo en %s"
 
-#: diff.c:4153
+#: diff.c:4547
 msgid "--name-only, --name-status, --check and -s are mutually exclusive"
 msgstr "--name-only, --name-status, --check y -s son mutuamente exclusivas"
 
-#: diff.c:4156
+#: diff.c:4550
 msgid "-G, -S and --find-object are mutually exclusive"
 msgstr "-G, -S y --find-object son mutuamente exclusivas"
 
-#: diff.c:4244
+#: diff.c:4628
 msgid "--follow requires exactly one pathspec"
 msgstr "--follow requiere exactamente un pathspec"
 
-#: diff.c:4410
+#: diff.c:4676
+#, c-format
+msgid "invalid --stat value: %s"
+msgstr "valor --stat inválido: %s"
+
+#: diff.c:4681 diff.c:4686 diff.c:4691 diff.c:4696 diff.c:5209
+#: parse-options.c:199 parse-options.c:203
+#, c-format
+msgid "%s expects a numerical value"
+msgstr "%s espera un valor numérico"
+
+#: diff.c:4713
 #, c-format
 msgid ""
 "Failed to parse --dirstat/-X option parameter:\n"
@@ -1724,11075 +2919,15443 @@ msgstr ""
 "Falló al analizar parámetro de opción --dirstat/-X:\n"
 "%s"
 
-#: diff.c:4424
+#: diff.c:4798
 #, c-format
-msgid "Failed to parse --submodule option parameter: '%s'"
-msgstr "Falló al analizar parámetro de opción --submodule: '%s'"
+msgid "unknown change class '%c' in --diff-filter=%s"
+msgstr "cambio de clase desconocido '%c' en --diff-filter=%s"
 
-#: diff.c:5500
-msgid "inexact rename detection was skipped due to too many files."
-msgstr ""
-"detección de cambio de nombre inexacta fue saltada por haber muchos archivos."
+#: diff.c:4822
+#, c-format
+msgid "unknown value after ws-error-highlight=%.*s"
+msgstr "valor desconocido luego de ws-error-highlight=%.*s"
 
-#: diff.c:5503
-msgid "only found copies from modified paths due to too many files."
-msgstr ""
-"solo se encontraron copias de rutas modificadas por haber muchos archivos."
+#: diff.c:4836
+#, c-format
+msgid "unable to resolve '%s'"
+msgstr "no se puede resolver '%s'"
 
-#: diff.c:5506
+#: diff.c:4886 diff.c:4892
 #, c-format
-msgid ""
-"you may want to set your %s variable to at least %d and retry the command."
-msgstr ""
-"tal vez quiera configurar la variable %s para por lo menos %d y volver a "
-"intentar el comando."
+msgid "%s expects <n>/<m> form"
+msgstr "%s espera forma <n>/<m>"
 
-#: dir.c:1867
+#: diff.c:4904
 #, c-format
-msgid "could not open directory '%s'"
-msgstr "no se pudo abrir el directorio '%s'"
+msgid "%s expects a character, got '%s'"
+msgstr "%s esperaba un char, se obtuvo '%s'"
 
-#: dir.c:2109
-msgid "failed to get kernel name and information"
-msgstr "falló al conseguir la información y nombre del kernel"
+#: diff.c:4925
+#, c-format
+msgid "bad --color-moved argument: %s"
+msgstr "mal argumento --color-moved: %s"
+
+#: diff.c:4944
+#, c-format
+msgid "invalid mode '%s' in --color-moved-ws"
+msgstr "modo inválido '%s' en --color-moved-ws"
 
-#: dir.c:2233
-msgid "Untracked cache is disabled on this system or location."
-msgstr "Untracked cache esta desactivado en este sistema o ubicación."
+#: diff.c:4984
+msgid ""
+"option diff-algorithm accepts \"myers\", \"minimal\", \"patience\" and "
+"\"histogram\""
+msgstr ""
+"opción diff-algorithm acepta \"myers\", \"minimal\", \"patience\" e "
+"\"histogram\""
 
-#: dir.c:3075 dir.c:3080
+#: diff.c:5020 diff.c:5040
 #, c-format
-msgid "could not create directories for %s"
-msgstr "no se pudo crear directorios para %s"
+msgid "invalid argument to %s"
+msgstr "argumento inválido para %s"
 
-#: dir.c:3109
+#: diff.c:5178
 #, c-format
-msgid "could not migrate git directory from '%s' to '%s'"
-msgstr "no se pudo migrar el directorio git de '%s' a '%s'"
+msgid "failed to parse --submodule option parameter: '%s'"
+msgstr "falló al analizar parámetro de opción --submodule: '%s'"
 
-#: editor.c:61
+#: diff.c:5234
 #, c-format
-msgid "hint: Waiting for your editor to close the file...%c"
-msgstr "ayuda: Esperando que tu editor cierre el archivo ...%c"
+msgid "bad --word-diff argument: %s"
+msgstr "mal argumento --word-diff: %s"
 
-#: entry.c:177
-msgid "Filtering content"
-msgstr "Filtrando contenido"
+#: diff.c:5257
+msgid "Diff output format options"
+msgstr "Opciones de formato de salida para diff"
 
-#: entry.c:435
-#, c-format
-msgid "could not stat file '%s'"
-msgstr "no se pudo establecer el archivo '%s'"
+#: diff.c:5259 diff.c:5265
+msgid "generate patch"
+msgstr "generar parche"
 
-#: fetch-object.c:17
-msgid "Remote with no URL"
-msgstr "Remoto sin URL"
+#: diff.c:5262 builtin/log.c:173
+msgid "suppress diff output"
+msgstr "suprimir salida de diff"
 
-#: fetch-pack.c:254
-msgid "git fetch-pack: expected shallow list"
-msgstr "git fetch-pack: lista poco profunda esperada"
+#: diff.c:5267 diff.c:5381 diff.c:5388
+msgid "<n>"
+msgstr "<n>"
 
-#: fetch-pack.c:266
-msgid "git fetch-pack: expected ACK/NAK, got a flush packet"
-msgstr "git fetch-pack: se esperaba ACK/NAK, se obtuvo un flush packet"
+#: diff.c:5268 diff.c:5271
+msgid "generate diffs with <n> lines context"
+msgstr "genera diffs con <n> líneas de contexto"
 
-#: fetch-pack.c:285 builtin/archive.c:63
-#, c-format
-msgid "remote error: %s"
-msgstr "error remoto: %s"
+#: diff.c:5273
+msgid "generate the diff in raw format"
+msgstr "genera el diff en formato raw"
 
-#: fetch-pack.c:286
-#, c-format
-msgid "git fetch-pack: expected ACK/NAK, got '%s'"
-msgstr "git fetch-pack: se esperaba ACK/NAK, se obtuvo '%s'"
+#: diff.c:5276
+msgid "synonym for '-p --raw'"
+msgstr "sinónimo para '-p --stat'"
 
-#: fetch-pack.c:338
-msgid "--stateless-rpc requires multi_ack_detailed"
-msgstr "--stateless-rpc requiere multi_ack_detailed"
+#: diff.c:5280
+msgid "synonym for '-p --stat'"
+msgstr "sinónimo para '-p --stat'"
 
-#: fetch-pack.c:429 fetch-pack.c:1310
-#, c-format
-msgid "invalid shallow line: %s"
-msgstr "línea poco profunda invalida: %s"
+#: diff.c:5284
+msgid "machine friendly --stat"
+msgstr "--stat amigable para máquina"
 
-#: fetch-pack.c:435 fetch-pack.c:1316
-#, c-format
-msgid "invalid unshallow line: %s"
-msgstr "línea superficial inválida: %s"
+#: diff.c:5287
+msgid "output only the last line of --stat"
+msgstr "mostrar solo la última línea para --stat"
 
-#: fetch-pack.c:437 fetch-pack.c:1318
-#, c-format
-msgid "object not found: %s"
-msgstr "objeto no encontrado: %s"
+#: diff.c:5289 diff.c:5297
+msgid "<param1,param2>..."
+msgstr "<param1,param2>..."
 
-#: fetch-pack.c:440 fetch-pack.c:1321
-#, c-format
-msgid "error in object: %s"
-msgstr "error en objeto: %s"
+#: diff.c:5290
+msgid ""
+"output the distribution of relative amount of changes for each sub-directory"
+msgstr ""
+"muestra la distribución de cantidades de cambios relativa para cada "
+"subdirectorio"
 
-#: fetch-pack.c:442 fetch-pack.c:1323
-#, c-format
-msgid "no shallow found: %s"
-msgstr "superficie no encontrada: %s"
+#: diff.c:5294
+msgid "synonym for --dirstat=cumulative"
+msgstr "sinónimo para --dirstat=cumulative"
 
-#: fetch-pack.c:445 fetch-pack.c:1326
-#, c-format
-msgid "expected shallow/unshallow, got %s"
-msgstr "se esperaba shallow/unshallow, se obtuvo %s"
+#: diff.c:5298
+msgid "synonym for --dirstat=files,param1,param2..."
+msgstr "sinonimo para --dirstat=archivos,param1,param2..."
 
-#: fetch-pack.c:486
-#, c-format
-msgid "got %s %d %s"
-msgstr "se obtuvo %s %d %s"
+#: diff.c:5302
+msgid "warn if changes introduce conflict markers or whitespace errors"
+msgstr ""
+"advierte si cambios introducen conflictos de markers o errores de espacios "
+"en blanco"
 
-#: fetch-pack.c:500
-#, c-format
-msgid "invalid commit %s"
-msgstr "commit inválido %s"
+#: diff.c:5305
+msgid "condensed summary such as creations, renames and mode changes"
+msgstr ""
+"resumen condensado de creaciones, cambios de nombres y cambios de modos"
 
-#: fetch-pack.c:533
-msgid "giving up"
-msgstr "rindiéndose"
+#: diff.c:5308
+msgid "show only names of changed files"
+msgstr "mostrar solo nombres de archivos cambiados"
 
-#: fetch-pack.c:543 progress.c:229
-msgid "done"
-msgstr "listo"
+#: diff.c:5311
+msgid "show only names and status of changed files"
+msgstr "mostrar solo nombres y estados de archivos cambiados"
 
-#: fetch-pack.c:555
-#, c-format
-msgid "got %s (%d) %s"
-msgstr "se obtuvo %s (%d) %s"
+#: diff.c:5313
+msgid "<width>[,<name-width>[,<count>]]"
+msgstr "<ancho>[,<nombre-ancho>[,<cantidad>]]"
 
-#: fetch-pack.c:601
-#, c-format
-msgid "Marking %s as complete"
-msgstr "Marcando %s como completa"
+#: diff.c:5314
+msgid "generate diffstat"
+msgstr "generar diffstat"
 
-#: fetch-pack.c:828
-#, c-format
-msgid "already have %s (%s)"
-msgstr "ya se tiene %s (%s)"
+#: diff.c:5316 diff.c:5319 diff.c:5322
+msgid "<width>"
+msgstr "<ancho>"
 
-#: fetch-pack.c:869
-msgid "fetch-pack: unable to fork off sideband demultiplexer"
-msgstr "fetch-pack: no se puede extraer un demultiplexor de banda lateral"
+#: diff.c:5317
+msgid "generate diffstat with a given width"
+msgstr "genera diffstat con un ancho dado"
 
-#: fetch-pack.c:877
-msgid "protocol error: bad pack header"
-msgstr "error de protocolo: mal paquete de header"
+#: diff.c:5320
+msgid "generate diffstat with a given name width"
+msgstr "genera diffstat con un nombre de ancho dado"
 
-#: fetch-pack.c:944
-#, c-format
-msgid "fetch-pack: unable to fork off %s"
-msgstr "fetch-pack: no se puede quitar %s"
+#: diff.c:5323
+msgid "generate diffstat with a given graph width"
+msgstr "genera diffstat con un ancho de graph dado"
 
-#: fetch-pack.c:960
-#, c-format
-msgid "%s failed"
-msgstr "%s falló"
+#: diff.c:5325
+msgid "<count>"
+msgstr "<cantidad>"
 
-#: fetch-pack.c:962
-msgid "error in sideband demultiplexer"
-msgstr "error en demultiplexor de banda lateral"
+#: diff.c:5326
+msgid "generate diffstat with limited lines"
+msgstr "genera diffstat con líneas limitadas"
 
-#: fetch-pack.c:989
-msgid "Server does not support shallow clients"
-msgstr "Servidor no soporta clientes superficiales"
+#: diff.c:5329
+msgid "generate compact summary in diffstat"
+msgstr "genera un resumen compacto de diffstat"
 
-#: fetch-pack.c:993
-msgid "Server supports multi_ack_detailed"
-msgstr "Servidor soporta ulti_ack_detailed"
+#: diff.c:5332
+msgid "output a binary diff that can be applied"
+msgstr "muestra un diff binario que puede ser aplicado"
 
-#: fetch-pack.c:996
-msgid "Server supports no-done"
-msgstr "Servidor soporta no-done"
+#: diff.c:5335
+msgid "show full pre- and post-image object names on the \"index\" lines"
+msgstr ""
+"mostrar todo un pre- y post-image de nombres de objetos en las líneas \"index"
+"\""
 
-#: fetch-pack.c:1002
-msgid "Server supports multi_ack"
-msgstr "Servidor soporta multi_ack"
+#: diff.c:5337
+msgid "show colored diff"
+msgstr "mostrar diff colorido"
 
-#: fetch-pack.c:1006
-msgid "Server supports side-band-64k"
-msgstr "Servidor soporta side-band-64k"
+#: diff.c:5338
+msgid "<kind>"
+msgstr "<tipo>"
 
-#: fetch-pack.c:1010
-msgid "Server supports side-band"
-msgstr "Servidor soporta side-band"
+#: diff.c:5339
+msgid ""
+"highlight whitespace errors in the 'context', 'old' or 'new' lines in the "
+"diff"
+msgstr ""
+"resaltar errores de espacios en blanco en las líneas 'context', 'old' o "
+"'new' del diff"
 
-#: fetch-pack.c:1014
-msgid "Server supports allow-tip-sha1-in-want"
-msgstr "Servidor soporta allow-tip-sha1-in-want"
+#: diff.c:5342
+msgid ""
+"do not munge pathnames and use NULs as output field terminators in --raw or "
+"--numstat"
+msgstr ""
+"no consolidar los pathnames y usar NULs como terminadores de campos en --raw "
+"o --numstat"
 
-#: fetch-pack.c:1018
-msgid "Server supports allow-reachable-sha1-in-want"
-msgstr "Servidor soporta allow-reachable-sha1-in-want"
+#: diff.c:5345 diff.c:5348 diff.c:5351 diff.c:5457
+msgid "<prefix>"
+msgstr "<prefijo>"
 
-#: fetch-pack.c:1028
-msgid "Server supports ofs-delta"
-msgstr "Servidor soporta ofs-delta"
+#: diff.c:5346
+msgid "show the given source prefix instead of \"a/\""
+msgstr "mostrar el prefijo de fuente dado en lugar de \"a/\""
 
-#: fetch-pack.c:1034 fetch-pack.c:1204
-msgid "Server supports filter"
-msgstr "Servidor soporta filtro"
+#: diff.c:5349
+msgid "show the given destination prefix instead of \"b/\""
+msgstr "mostrar el prefijo de destino en lugar de \"b/\""
 
-#: fetch-pack.c:1042
-#, c-format
-msgid "Server version is %.*s"
-msgstr "Versión de servidor es %.*s"
+#: diff.c:5352
+msgid "prepend an additional prefix to every line of output"
+msgstr "anteponer un prefijo adicional a cada línea mostrada"
 
-#: fetch-pack.c:1048
-msgid "Server does not support --shallow-since"
-msgstr "Servidor no soporta --shalow-since"
+#: diff.c:5355
+msgid "do not show any source or destination prefix"
+msgstr "no mostrar ningún prefijo de fuente o destino"
 
-#: fetch-pack.c:1052
-msgid "Server does not support --shallow-exclude"
-msgstr "Servidor no soporta --shalow-exclude"
+#: diff.c:5358
+msgid "show context between diff hunks up to the specified number of lines"
+msgstr ""
+"muestra el contexto entre hunks de diff hasta el número especificado de "
+"líneas"
 
-#: fetch-pack.c:1054
-msgid "Server does not support --deepen"
-msgstr "Servidor no soporta --deepen"
+#: diff.c:5362 diff.c:5367 diff.c:5372
+msgid "<char>"
+msgstr "<char>"
 
-#: fetch-pack.c:1065
-msgid "no common commits"
-msgstr "no hay commits comunes"
+#: diff.c:5363
+msgid "specify the character to indicate a new line instead of '+'"
+msgstr "especifica el char para indicar una nueva línea en lugar de '+'"
 
-#: fetch-pack.c:1077 fetch-pack.c:1414
-msgid "git fetch-pack: fetch failed."
-msgstr "git fetch-pack: fetch falló."
+#: diff.c:5368
+msgid "specify the character to indicate an old line instead of '-'"
+msgstr "especifica el char para indicar una línea vieja en lugar de '-'"
 
-#: fetch-pack.c:1199
-msgid "Server does not support shallow requests"
-msgstr "Servidor no soporta peticiones superficiales"
+#: diff.c:5373
+msgid "specify the character to indicate a context instead of ' '"
+msgstr "especifica el char para indicar un contexto en lugar de ' '"
 
-#: fetch-pack.c:1584
-msgid "no matching remote head"
-msgstr "no concuerda el head remoto"
+#: diff.c:5376
+msgid "Diff rename options"
+msgstr "Opciones de diff rename"
 
-#: fetch-pack.c:1610
-#, c-format
-msgid "no such remote ref %s"
-msgstr "no existe ref remota %s"
+#: diff.c:5377
+msgid "<n>[/<m>]"
+msgstr "<n>[/<m>]"
 
-#: fetch-pack.c:1613
-#, c-format
-msgid "Server does not allow request for unadvertised object %s"
-msgstr "Servidor no permite solicitudes de objetos inadvertidos %s"
+#: diff.c:5378
+msgid "break complete rewrite changes into pairs of delete and create"
+msgstr "descomponer los cambios de reescritura en pares de borrar y crear"
 
-#: gpg-interface.c:185
-msgid "gpg failed to sign the data"
-msgstr "gpg falló al firmar la data"
+#: diff.c:5382
+msgid "detect renames"
+msgstr "detectar renombrados"
 
-#: gpg-interface.c:210
-msgid "could not create temporary file"
-msgstr "no se pudo crear archivo temporal"
+#: diff.c:5386
+msgid "omit the preimage for deletes"
+msgstr "omite la preimage para borrados"
 
-#: gpg-interface.c:213
-#, c-format
-msgid "failed writing detached signature to '%s'"
-msgstr "falló al escribir la firma separada para '%s'"
+#: diff.c:5389
+msgid "detect copies"
+msgstr "detectar copias"
 
-#: graph.c:97
-#, c-format
-msgid "ignore invalid color '%.*s' in log.graphColors"
-msgstr "ignora color invalido '%.*s' en log.graphColors"
+#: diff.c:5393
+msgid "use unmodified files as source to find copies"
+msgstr "usa archivos no modificados como fuente para encontrar copias"
 
-#: grep.c:2020
-#, c-format
-msgid "'%s': unable to read %s"
-msgstr "'%s': no es posible leer %s"
+#: diff.c:5395
+msgid "disable rename detection"
+msgstr "deshabilita detección de renombres"
 
-#: grep.c:2037 setup.c:164 builtin/clone.c:409 builtin/diff.c:81
-#: builtin/rm.c:134
-#, c-format
-msgid "failed to stat '%s'"
-msgstr "falló al marcar '%s'"
+#: diff.c:5398
+msgid "use empty blobs as rename source"
+msgstr "usa blobs vacíos como fuente de renombre"
 
-#: grep.c:2048
-#, c-format
-msgid "'%s': short read"
-msgstr "'%s': lectura corta"
+#: diff.c:5400
+msgid "continue listing the history of a file beyond renames"
+msgstr "continua listando el historial de un archivo más allá de renombres"
 
-#: help.c:23
-msgid "start a working area (see also: git help tutorial)"
-msgstr "comienza un área de trabajo (ver también: git help tutorial)"
+#: diff.c:5403
+msgid ""
+"prevent rename/copy detection if the number of rename/copy targets exceeds "
+"given limit"
+msgstr ""
+"previene detección de renombre/copias si el número de objetivos para "
+"renombres/copias excede el límite dado"
 
-#: help.c:24
-msgid "work on the current change (see also: git help everyday)"
-msgstr "trabaja en los cambios actuales (ver también: git help everyday)"
+#: diff.c:5405
+msgid "Diff algorithm options"
+msgstr "Opciones de algoritmos de diff"
 
-#: help.c:25
-msgid "examine the history and state (see also: git help revisions)"
-msgstr "examina el historial y el estado (ver también: git help revisions)"
+#: diff.c:5407
+msgid "produce the smallest possible diff"
+msgstr "produce el diff más pequeño posible"
 
-#: help.c:26
-msgid "grow, mark and tweak your common history"
-msgstr "crece, marca y ajusta tu historial común"
+#: diff.c:5410
+msgid "ignore whitespace when comparing lines"
+msgstr "ignorar espacios en blanco cuando comparando líneas"
 
-#: help.c:27
-msgid "collaborate (see also: git help workflows)"
-msgstr "colabora (mira también: git help workflows)"
+#: diff.c:5413
+msgid "ignore changes in amount of whitespace"
+msgstr "ignorar cambios en la cantidad de líneas en blanco"
 
-#: help.c:31
-msgid "Main Porcelain Commands"
-msgstr "Comandos de Porcelana principales"
+#: diff.c:5416
+msgid "ignore changes in whitespace at EOL"
+msgstr "ignorar cambios en espacios en blanco en EOL"
 
-#: help.c:32
-msgid "Ancillary Commands / Manipulators"
-msgstr "Comandos auxiliares / Manipuladores"
+#: diff.c:5419
+msgid "ignore carrier-return at the end of line"
+msgstr "ignora carrier-return al final de la línea"
 
-#: help.c:33
-msgid "Ancillary Commands / Interrogators"
-msgstr "Comandos auxiliares / Interrogadores"
+#: diff.c:5422
+msgid "ignore changes whose lines are all blank"
+msgstr "ignora cambios cuyas líneas son todas en blanco"
 
-#: help.c:34
-msgid "Interacting with Others"
-msgstr "Interactuando con Otros"
+#: diff.c:5425
+msgid "heuristic to shift diff hunk boundaries for easy reading"
+msgstr "heurística para cambiar los límites de hunk para una fácil lectura"
 
-#: help.c:35
-msgid "Low-level Commands / Manipulators"
-msgstr "Comandos de bajo nivel / Manipuladores"
+#: diff.c:5428
+msgid "generate diff using the \"patience diff\" algorithm"
+msgstr "genera un diff usando algoritmo \"patience diff\""
 
-#: help.c:36
-msgid "Low-level Commands / Interrogators"
-msgstr "Comandos de bajo nivel / Interrogadores"
+#: diff.c:5432
+msgid "generate diff using the \"histogram diff\" algorithm"
+msgstr "genera un diff usando algoritmo \"histogram diff\""
 
-#: help.c:37
-msgid "Low-level Commands / Synching Repositories"
-msgstr "Comandos de bajo nivel / Sincronización de repositorios"
+#: diff.c:5434
+msgid "<algorithm>"
+msgstr "<algoritmo>"
 
-#: help.c:38
-msgid "Low-level Commands / Internal Helpers"
-msgstr "Comandos de bajo nivel / Auxiliares internos"
+#: diff.c:5435
+msgid "choose a diff algorithm"
+msgstr "escoge un algoritmo para diff"
 
-#: help.c:293
-#, c-format
-msgid "available git commands in '%s'"
-msgstr "comandos disponibles de git en '%s'"
+#: diff.c:5437
+msgid "<text>"
+msgstr "<texto>"
 
-#: help.c:300
-msgid "git commands available from elsewhere on your $PATH"
-msgstr "comandos disponibles de git desde otro lugar en tu $PATH"
+#: diff.c:5438
+msgid "generate diff using the \"anchored diff\" algorithm"
+msgstr "genera un diff usando algoritmo \"anchored diff\""
 
-#: help.c:309
-msgid "These are common Git commands used in various situations:"
-msgstr "Estos son comandos comunes de Git usados en varias situaciones:"
+#: diff.c:5440 diff.c:5449 diff.c:5452
+msgid "<mode>"
+msgstr "<modo>"
 
-#: help.c:358 git.c:90
-#, c-format
-msgid "unsupported command listing type '%s'"
-msgstr "comando de listado de tipos no soportado '%s'"
+#: diff.c:5441
+msgid "show word diff, using <mode> to delimit changed words"
+msgstr ""
+"muestra diff por palabras usando <modo> para delimitar las palabras cambiadas"
 
-#: help.c:405
-msgid "The common Git guides are:"
-msgstr "Las guías comunes de Git son:"
+#: diff.c:5443 diff.c:5446 diff.c:5491
+msgid "<regex>"
+msgstr "<regex>"
 
-#: help.c:467
-#, c-format
-msgid ""
-"'%s' appears to be a git command, but we were not\n"
-"able to execute it. Maybe git-%s is broken?"
-msgstr ""
-"'%s' parece ser un comando de git, pero no hemos\n"
-"podido ejecutarlo. Tal vez git-%s se ha roto?"
+#: diff.c:5444
+msgid "use <regex> to decide what a word is"
+msgstr "usa <regex> para decidir que palabra es"
 
-#: help.c:526
-msgid "Uh oh. Your system reports no Git commands at all."
-msgstr "Oh oh. Tu sistema no reporta ningún comando de Git."
+#: diff.c:5447
+msgid "equivalent to --word-diff=color --word-diff-regex=<regex>"
+msgstr "equivalente a --word-diff=color --word-diff-regex=<regex>"
 
-#: help.c:548
-#, c-format
-msgid "WARNING: You called a Git command named '%s', which does not exist."
-msgstr "PELIGRO: Has llamado a un comando de Git '%s', el cual no existe."
+#: diff.c:5450
+msgid "moved lines of code are colored differently"
+msgstr "líneas movidas de código están coloreadas diferente"
 
-#: help.c:553
-#, c-format
-msgid "Continuing under the assumption that you meant '%s'."
-msgstr "Continuando asumiendo que quisiste decir '%s'."
+#: diff.c:5453
+msgid "how white spaces are ignored in --color-moved"
+msgstr "como espacios en blanco son ignorados en --color-moved"
 
-#: help.c:558
-#, c-format
-msgid "Continuing in %0.1f seconds, assuming that you meant '%s'."
-msgstr "Continuando en %0.1f segundos, asumiendo que tu dijiste '%s'."
+#: diff.c:5456
+msgid "Other diff options"
+msgstr "Otras opciones de diff"
 
-#: help.c:566
-#, c-format
-msgid "git: '%s' is not a git command. See 'git --help'."
-msgstr "git: '%s'no es un comando de git. Mira 'git --help'."
+#: diff.c:5458
+msgid "when run from subdir, exclude changes outside and show relative paths"
+msgstr ""
+"cuando ejecutado desde un subdir, excluye cambios del exterior y muestra "
+"paths relativos"
 
-#: help.c:570
-msgid ""
-"\n"
-"The most similar command is"
-msgid_plural ""
-"\n"
-"The most similar commands are"
-msgstr[0] ""
-"\n"
-"El comando mas similar es"
-msgstr[1] ""
-"\n"
-"Los comandos mas similares son"
+#: diff.c:5462
+msgid "treat all files as text"
+msgstr "tratar todos los archivos como texto"
 
-#: help.c:585
-msgid "git version [<options>]"
-msgstr "git versión [<opciones>]"
+#: diff.c:5464
+msgid "swap two inputs, reverse the diff"
+msgstr "cambia dos inputs, invierte el diff"
 
-#: help.c:652
-#, c-format
-msgid "%s: %s - %s"
-msgstr "%s: %s - %s"
+#: diff.c:5466
+msgid "exit with 1 if there were differences, 0 otherwise"
+msgstr "termina con 1 si hubieron diferencias, de lo contrario con 0"
 
-#: help.c:656
-msgid ""
-"\n"
-"Did you mean this?"
-msgid_plural ""
-"\n"
-"Did you mean one of these?"
-msgstr[0] ""
-"\n"
-"Quisiste decir esto?"
-msgstr[1] ""
-"\n"
-"Quisiste decir alguno de estos?"
+#: diff.c:5468
+msgid "disable all output of the program"
+msgstr "deshabilita todo el output del programa"
 
-#: ident.c:342
-msgid ""
-"\n"
-"*** Please tell me who you are.\n"
-"\n"
-"Run\n"
-"\n"
-"  git config --global user.email \"you@example.com\"\n"
-"  git config --global user.name \"Your Name\"\n"
-"\n"
-"to set your account's default identity.\n"
-"Omit --global to set the identity only in this repository.\n"
-"\n"
+#: diff.c:5470
+msgid "allow an external diff helper to be executed"
+msgstr "permite la ejecución de un diff helper externo"
+
+#: diff.c:5472
+msgid "run external text conversion filters when comparing binary files"
 msgstr ""
-"\n"
-"*** Por favor cuéntame quien eres.\n"
-"\n"
-"Corre\n"
-"\n"
-"  git config --global user.email \"you@example.com\"\n"
-"  git config --global user.name \"Tu Nombre\"\n"
-"\n"
-"para configurar la identidad por defecto de tu cuenta.\n"
-"Omite --global para configurar tu identidad solo en este repositorio.\n"
-"\n"
+"ejecuta filtros de conversión de texto externos cuando comparando binarios"
 
-#: ident.c:366
-msgid "no email was given and auto-detection is disabled"
-msgstr "no se entrego ningún email y la detección automática esta desactivada"
+#: diff.c:5474
+msgid "<when>"
+msgstr "<cuando>"
 
-#: ident.c:371
-#, c-format
-msgid "unable to auto-detect email address (got '%s')"
-msgstr "no es posible auto-detectar la dirección de correo (se obtuvo '%s')"
+#: diff.c:5475
+msgid "ignore changes to submodules in the diff generation"
+msgstr "ignorar cambios a submódulos en la generación de diff"
 
-#: ident.c:381
-msgid "no name was given and auto-detection is disabled"
-msgstr "no se entrego ningún nombre y la detección automática esta desactivada"
+#: diff.c:5478
+msgid "<format>"
+msgstr "<formato>"
 
-#: ident.c:387
-#, c-format
-msgid "unable to auto-detect name (got '%s')"
-msgstr "no es posible auto-detectar el nombre (se obtuvo '%s')"
+#: diff.c:5479
+msgid "specify how differences in submodules are shown"
+msgstr "especifica como son mostradas las diferencias en submódulos"
 
-#: ident.c:395
-#, c-format
-msgid "empty ident name (for <%s>) not allowed"
-msgstr "no se puede tener un nombre vacío (para <%s>)"
+#: diff.c:5483
+msgid "hide 'git add -N' entries from the index"
+msgstr "ocultar entradas 'git add -N' del index"
 
-#: ident.c:401
-#, c-format
-msgid "name consists only of disallowed characters: %s"
-msgstr "el nombre consiste solo de caracteres no permitidos: %s"
+#: diff.c:5486
+msgid "treat 'git add -N' entries as real in the index"
+msgstr "trata entradas 'git add -N' como reales en el index"
 
-#: ident.c:416 builtin/commit.c:587
-#, c-format
-msgid "invalid date format: %s"
-msgstr "formato de fecha invalido: %s"
+#: diff.c:5488
+msgid "<string>"
+msgstr "<string>"
 
-#: list-objects-filter-options.c:36
-msgid "multiple filter-specs cannot be combined"
-msgstr "no se pueden combinar múltiples tipos de especificaciones de filtro"
+#: diff.c:5489
+msgid ""
+"look for differences that change the number of occurrences of the specified "
+"string"
+msgstr ""
+"busca por diferencias que cambien el número de ocurrencias para el string "
+"especificado"
 
-#: list-objects-filter-options.c:126
-msgid "cannot change partial clone promisor remote"
-msgstr "no se puede cambiar un clon parcial remoto promisor"
+#: diff.c:5492
+msgid ""
+"look for differences that change the number of occurrences of the specified "
+"regex"
+msgstr ""
+"busca por diferencias que cambien el número de ocurrencias para el regex "
+"especificado"
 
-#: lockfile.c:151
-#, c-format
+#: diff.c:5495
+msgid "show all changes in the changeset with -S or -G"
+msgstr "mostrar todos los cambios en el changeset con -S o -G"
+
+#: diff.c:5498
+msgid "treat <string> in -S as extended POSIX regular expression"
+msgstr "tratar <string> en -S como una expresión regular extendida de POSIX"
+
+#: diff.c:5501
+msgid "control the order in which files appear in the output"
+msgstr "controlar el orden en el que los archivos aparecen en la salida"
+
+#: diff.c:5502
+msgid "<object-id>"
+msgstr "<id-objeto>"
+
+#: diff.c:5503
 msgid ""
-"Unable to create '%s.lock': %s.\n"
-"\n"
-"Another git process seems to be running in this repository, e.g.\n"
-"an editor opened by 'git commit'. Please make sure all processes\n"
-"are terminated then try again. If it still fails, a git process\n"
-"may have crashed in this repository earlier:\n"
-"remove the file manually to continue."
+"look for differences that change the number of occurrences of the specified "
+"object"
 msgstr ""
-"No se puede crear '%s.lock': %s.\n"
-"\n"
-"Otro proceso git parece estar corriendo en el repositorio, es decir\n"
-"un editor abierto con 'git commit'. Por favor asegúrese de que todos los "
-"procesos\n"
-"están terminados y vuelve a intentar. Si el fallo permanece, un proceso git\n"
-"puede haber roto el repositorio antes:\n"
-"borra el archivo manualmente para continuar."
+"busca por diferencias que cambien el número de ocurrencias para el objeto "
+"especificado"
 
-#: lockfile.c:159
-#, c-format
-msgid "Unable to create '%s.lock': %s"
-msgstr "No se pudo crear '%s.lock': %s"
+#: diff.c:5505
+msgid "[(A|C|D|M|R|T|U|X|B)...[*]]"
+msgstr "[(A|C|D|M|R|T|U|X|B)...[*]]"
 
-#: merge.c:71
-msgid "failed to read the cache"
-msgstr "falló al leer la cache"
+#: diff.c:5506
+msgid "select files by diff type"
+msgstr "selecciona archivos por tipo de diff"
 
-#: merge.c:136 builtin/am.c:1946 builtin/am.c:1980 builtin/checkout.c:378
-#: builtin/checkout.c:606 builtin/clone.c:761
-msgid "unable to write new index file"
-msgstr "no es posible escribir el archivo índice"
+#: diff.c:5508
+msgid "<file>"
+msgstr "<archivo>"
+
+#: diff.c:5509
+msgid "Output to a specific file"
+msgstr "Output a un archivo específico"
 
-#: merge-recursive.c:298
-msgid "(bad commit)\n"
-msgstr "(mal commit)\n"
+#: diff.c:6164
+msgid "inexact rename detection was skipped due to too many files."
+msgstr ""
+"detección de cambio de nombre inexacta fue saltada por haber muchos archivos."
+
+#: diff.c:6167
+msgid "only found copies from modified paths due to too many files."
+msgstr ""
+"solo se encontraron copias de rutas modificadas por haber muchos archivos."
 
-#: merge-recursive.c:320
+#: diff.c:6170
 #, c-format
-msgid "add_cacheinfo failed for path '%s'; merge aborting."
-msgstr "add_cacheinfo falló para la ruta '%s'; abortando fusión."
+msgid ""
+"you may want to set your %s variable to at least %d and retry the command."
+msgstr ""
+"tal vez quieras configurar la variable %s para por lo menos %d y volver a "
+"intentar el comando."
 
-#: merge-recursive.c:328
+#: dir.c:554
 #, c-format
-msgid "add_cacheinfo failed to refresh for path '%s'; merge aborting."
-msgstr "add_cacheinfo falló para refrescar la ruta '%s'; abortando fusión."
+msgid "pathspec '%s' did not match any file(s) known to git"
+msgstr ""
+"ruta especificada '%s' no concordó con ningún archivo(s) conocido por git"
 
-#: merge-recursive.c:410
-msgid "error building trees"
-msgstr "error construyendo árboles"
+#: dir.c:664
+#, c-format
+msgid "unrecognized pattern: '%s'"
+msgstr "patrón desconocido: '%s'"
 
-#: merge-recursive.c:881
+#: dir.c:682 dir.c:696
 #, c-format
-msgid "failed to create path '%s'%s"
-msgstr "falló al crear la ruta '%s'%s"
+msgid "unrecognized negative pattern: '%s'"
+msgstr "patrón negativo no reconocido: '%s'"
 
-#: merge-recursive.c:892
+#: dir.c:714
 #, c-format
-msgid "Removing %s to make room for subdirectory\n"
-msgstr "Removiendo %s para hacer espacio para un subdirectorio\n"
+msgid "your sparse-checkout file may have issues: pattern '%s' is repeated"
+msgstr ""
+"tu archivo sparse-checkout tal vez tenga errores: patrón '%s' está repetido"
 
-#: merge-recursive.c:906 merge-recursive.c:925
-msgid ": perhaps a D/F conflict?"
-msgstr ": tal vez un conflicto D/F?"
+#: dir.c:724
+msgid "disabling cone pattern matching"
+msgstr "deshabilitar coincidencia de patrónes cono"
 
-#: merge-recursive.c:915
+#: dir.c:1101
 #, c-format
-msgid "refusing to lose untracked file at '%s'"
-msgstr "rehusando perder el archivo rastreado en '%s'"
+msgid "cannot use %s as an exclude file"
+msgstr "no se puede usar %s como archivo de exclusión"
 
-#: merge-recursive.c:957 builtin/cat-file.c:37
+#: dir.c:2078
 #, c-format
-msgid "cannot read object %s '%s'"
-msgstr "no se puede leer el objeto %s '%s'"
+msgid "could not open directory '%s'"
+msgstr "no se pudo abrir el directorio '%s'"
 
-#: merge-recursive.c:959
-#, c-format
-msgid "blob expected for %s '%s'"
-msgstr "se esperaba blob para %s '%s'"
+#: dir.c:2415
+msgid "failed to get kernel name and information"
+msgstr "falló al conseguir la información y nombre del kernel"
 
-#: merge-recursive.c:983
-#, c-format
-msgid "failed to open '%s': %s"
-msgstr "falló al abrir '%s': %s"
+#: dir.c:2539
+msgid "untracked cache is disabled on this system or location"
+msgstr "untracked cache está desactivado en este sistema o ubicación"
 
-#: merge-recursive.c:994
+#: dir.c:3343
 #, c-format
-msgid "failed to symlink '%s': %s"
-msgstr "falló al crear el enlace simbólico '%s': %s"
+msgid "index file corrupt in repo %s"
+msgstr "archivo índice corrompido en repositorio %s"
 
-#: merge-recursive.c:999
+#: dir.c:3388 dir.c:3393
 #, c-format
-msgid "do not know what to do with %06o %s '%s'"
-msgstr "no se que hacer con %06o %s '%s'"
+msgid "could not create directories for %s"
+msgstr "no se pudo crear directorios para %s"
 
-#: merge-recursive.c:1186
+#: dir.c:3422
 #, c-format
-msgid "Failed to merge submodule %s (not checked out)"
-msgstr "Falló al fusionar el submódulo %s (no revisado)"
+msgid "could not migrate git directory from '%s' to '%s'"
+msgstr "no se pudo migrar el directorio git de '%s' a '%s'"
 
-#: merge-recursive.c:1193
+#: editor.c:73
 #, c-format
-msgid "Failed to merge submodule %s (commits not present)"
-msgstr "Falló al fusionar el submódulo %s (commits no presentes)"
+msgid "hint: Waiting for your editor to close the file...%c"
+msgstr "ayuda: Esperando que tu editor cierre el archivo ...%c"
 
-#: merge-recursive.c:1200
-#, c-format
-msgid "Failed to merge submodule %s (commits don't follow merge-base)"
-msgstr "Falló el fusionar submódulo %s (commits no siguen la fusión base)"
+#: entry.c:178
+msgid "Filtering content"
+msgstr "Filtrando contenido"
 
-#: merge-recursive.c:1208 merge-recursive.c:1220
+#: entry.c:476
 #, c-format
-msgid "Fast-forwarding submodule %s to the following commit:"
-msgstr "Haciendo fast-forward a submódulo %s para el siguiente commit:"
+msgid "could not stat file '%s'"
+msgstr "no se pudo establecer el archivo '%s'"
 
-#: merge-recursive.c:1211 merge-recursive.c:1223
+#: environment.c:149
 #, c-format
-msgid "Fast-forwarding submodule %s"
-msgstr "Avance rápido en submódulo %s"
+msgid "bad git namespace path \"%s\""
+msgstr "ruta de namespace de git mala \"%s\""
 
-#: merge-recursive.c:1245
+#: environment.c:331
 #, c-format
-msgid "Failed to merge submodule %s (merge following commits not found)"
-msgstr ""
-"Falló al fusionar submódulo %s (los siguentes commits no fueron encontrados)"
+msgid "could not set GIT_DIR to '%s'"
+msgstr "no se pudo configurar GIT_DIR a '%s'"
 
-#: merge-recursive.c:1249
+#: exec-cmd.c:363
 #, c-format
-msgid "Failed to merge submodule %s (not fast-forward)"
-msgstr "Falló al fusionar el submódulo %s (no es posible avance rápido)"
+msgid "too many args to run %s"
+msgstr "demasiados argumentos para correr %s"
 
-#: merge-recursive.c:1250
-msgid "Found a possible merge resolution for the submodule:\n"
-msgstr "Se encontró una posible solución de fusión para el submódulo:\n"
+#: fetch-pack.c:150
+msgid "git fetch-pack: expected shallow list"
+msgstr "git fetch-pack: lista poco profunda esperada"
+
+#: fetch-pack.c:153
+msgid "git fetch-pack: expected a flush packet after shallow list"
+msgstr ""
+"git fetch-pack: se esperaba un flush packet luego de la lista superficial"
+
+#: fetch-pack.c:164
+msgid "git fetch-pack: expected ACK/NAK, got a flush packet"
+msgstr "git fetch-pack: se esperaba ACK/NAK, se obtuvo un flush packet"
 
-#: merge-recursive.c:1253
+#: fetch-pack.c:184
 #, c-format
-msgid ""
-"If this is correct simply add it to the index for example\n"
-"by using:\n"
-"\n"
-"  git update-index --cacheinfo 160000 %s \"%s\"\n"
-"\n"
-"which will accept this suggestion.\n"
-msgstr ""
-"Si esto es correcto simplemente agrégalo al índice por ejemplo\n"
-"usando:\n"
-"\n"
-"  git update-index --cacheinfo 160000 %s \"%s\"\n"
-"\n"
-"el cual aceptará esta sugerencia.\n"
+msgid "git fetch-pack: expected ACK/NAK, got '%s'"
+msgstr "git fetch-pack: se esperaba ACK/NAK, se obtuvo '%s'"
 
-#: merge-recursive.c:1262
-#, c-format
-msgid "Failed to merge submodule %s (multiple merges found)"
-msgstr "Falló al fusionar el submódulo %s (fusiones múltiples encontradas)"
+#: fetch-pack.c:195
+msgid "unable to write to remote"
+msgstr "no se puede escribir al remoto"
 
-#: merge-recursive.c:1321
-msgid "Failed to execute internal merge"
-msgstr "Falló al ejecutar la fusión interna"
+#: fetch-pack.c:257
+msgid "--stateless-rpc requires multi_ack_detailed"
+msgstr "--stateless-rpc requiere multi_ack_detailed"
 
-#: merge-recursive.c:1326
+#: fetch-pack.c:356 fetch-pack.c:1340
 #, c-format
-msgid "Unable to add %s to database"
-msgstr "No es posible agregar %s a la base de datos"
+msgid "invalid shallow line: %s"
+msgstr "línea poco profunda inválida: %s"
 
-#: merge-recursive.c:1358
+#: fetch-pack.c:362 fetch-pack.c:1346
 #, c-format
-msgid "Auto-merging %s"
-msgstr "Auto-fusionando %s"
+msgid "invalid unshallow line: %s"
+msgstr "línea superficial inválida: %s"
 
-#: merge-recursive.c:1423
+#: fetch-pack.c:364 fetch-pack.c:1348
 #, c-format
-msgid "Error: Refusing to lose untracked file at %s; writing to %s instead."
-msgstr ""
-"Error: Rehusando perder el archivo no rastreado en %s; escribiéndolo a %s en "
-"cambio."
+msgid "object not found: %s"
+msgstr "objeto no encontrado: %s"
 
-#: merge-recursive.c:1475
+#: fetch-pack.c:367 fetch-pack.c:1351
 #, c-format
-msgid ""
-"CONFLICT (%s/delete): %s deleted in %s and %s in %s. Version %s of %s left "
-"in tree."
-msgstr ""
-"CONFLICTO (%s/borrar): %s borrado en %s y %s en %s. Falta versión %s de %s "
-"en el árbol."
+msgid "error in object: %s"
+msgstr "error en objeto: %s"
 
-#: merge-recursive.c:1480
+#: fetch-pack.c:369 fetch-pack.c:1353
 #, c-format
-msgid ""
-"CONFLICT (%s/delete): %s deleted in %s and %s to %s in %s. Version %s of %s "
-"left in tree."
-msgstr ""
-"CONFLICTO (%s/borrar): %s borrado en %s y %s para %s en %s. Versión %s de %s "
-"permanece en el árbol."
+msgid "no shallow found: %s"
+msgstr "superficie no encontrada: %s"
 
-#: merge-recursive.c:1487
+#: fetch-pack.c:372 fetch-pack.c:1357
 #, c-format
-msgid ""
-"CONFLICT (%s/delete): %s deleted in %s and %s in %s. Version %s of %s left "
-"in tree at %s."
-msgstr ""
-"CONFLICTO (%s/eliminar): %s eliminado en %s y %s en %s. Versión %s de %s "
-"dejada en el árbol, en %s."
+msgid "expected shallow/unshallow, got %s"
+msgstr "se esperaba shallow/unshallow, se obtuvo %s"
 
-#: merge-recursive.c:1492
+#: fetch-pack.c:414
 #, c-format
-msgid ""
-"CONFLICT (%s/delete): %s deleted in %s and %s to %s in %s. Version %s of %s "
-"left in tree at %s."
-msgstr ""
-"CONFLICTO (%s/borrar): %s borrado en %s y %s para %s en %s. Versión %s de %s "
-"permanece en el árbol en %s."
-
-#: merge-recursive.c:1526
-msgid "rename"
-msgstr "renombrar"
-
-#: merge-recursive.c:1526
-msgid "renamed"
-msgstr "renombrado"
+msgid "got %s %d %s"
+msgstr "se obtuvo %s %d %s"
 
-#: merge-recursive.c:1580 merge-recursive.c:1736 merge-recursive.c:2368
-#: merge-recursive.c:3086
+#: fetch-pack.c:431
 #, c-format
-msgid "Refusing to lose dirty file at %s"
-msgstr "Rehusando perder el archivo sucio en %s"
+msgid "invalid commit %s"
+msgstr "commit inválido %s"
 
-#: merge-recursive.c:1594
-#, c-format
-msgid "%s is a directory in %s adding as %s instead"
-msgstr "%s es un directorio en %s agregando como %s más bien"
+#: fetch-pack.c:462
+msgid "giving up"
+msgstr "rindiéndose"
 
-#: merge-recursive.c:1599
-#, c-format
-msgid "Refusing to lose untracked file at %s; adding as %s instead"
-msgstr ""
-"Rehusando perder el archivo no rastreado en %s; agregándolo como %s en cambio"
+#: fetch-pack.c:475 progress.c:323
+msgid "done"
+msgstr "listo"
 
-#: merge-recursive.c:1625
+#: fetch-pack.c:487
 #, c-format
-msgid ""
-"CONFLICT (rename/rename): Rename \"%s\"->\"%s\" in branch \"%s\" rename \"%s"
-"\"->\"%s\" in \"%s\"%s"
-msgstr ""
-"CONFLICTO (renombrar/renombrar): Renombrar \"%s\"->\"%s\" en la rama \"%s\" "
-"renombrar \"%s\"->\"%s\" en \"%s\"%s"
-
-#: merge-recursive.c:1630
-msgid " (left unresolved)"
-msgstr " (dejado sin resolver)"
+msgid "got %s (%d) %s"
+msgstr "se obtuvo %s (%d) %s"
 
-#: merge-recursive.c:1694
+#: fetch-pack.c:533
 #, c-format
-msgid "CONFLICT (rename/rename): Rename %s->%s in %s. Rename %s->%s in %s"
-msgstr ""
-"CONFLICTO (renombrar/renombrar): Renombrar %s->%s en %s. Renombrar %s->%s en "
-"%s"
+msgid "Marking %s as complete"
+msgstr "Marcando %s como completa"
 
-#: merge-recursive.c:1733
+#: fetch-pack.c:754
 #, c-format
-msgid "Renaming %s to %s and %s to %s instead"
-msgstr "Renombrando %s a %s y %s a %s más bien"
+msgid "already have %s (%s)"
+msgstr "ya se tiene %s (%s)"
 
-#: merge-recursive.c:1745
-#, c-format
-msgid "Refusing to lose untracked file at %s, even though it's in the way."
-msgstr ""
-"Rehusando perder el archivo no rastreado en %s, incluso aunque se está "
-"interponiendo."
+#: fetch-pack.c:818
+msgid "fetch-pack: unable to fork off sideband demultiplexer"
+msgstr "fetch-pack: no se puede extraer un demultiplexor de banda lateral"
 
-#: merge-recursive.c:1951
-#, c-format
-msgid ""
-"CONFLICT (directory rename split): Unclear where to place %s because "
-"directory %s was renamed to multiple other directories, with no destination "
-"getting a majority of the files."
-msgstr ""
-"CONFLICTO (división de cambio de nombre de directorio): No es claro dónde "
-"colocar %s porque el directorio %s fue renombrado a otros múltiples "
-"directorios, sin ningún que contenga la mayoría de archivos."
+#: fetch-pack.c:826
+msgid "protocol error: bad pack header"
+msgstr "error de protocolo: paquete de header erróneo"
 
-#: merge-recursive.c:1983
+#: fetch-pack.c:900
 #, c-format
-msgid ""
-"CONFLICT (implicit dir rename): Existing file/dir at %s in the way of "
-"implicit directory rename(s) putting the following path(s) there: %s."
-msgstr ""
-"CONFLICTO (cambio de nombre de directorio implícito): Archivo/directorio "
-"existente en %s se interpone con el cambio de nombres implícito, poniendo "
-"la(s) siguiente(s) ruta(s) aquí: %s."
+msgid "fetch-pack: unable to fork off %s"
+msgstr "fetch-pack: no se puede quitar %s"
 
-#: merge-recursive.c:1993
+#: fetch-pack.c:916
 #, c-format
-msgid ""
-"CONFLICT (implicit dir rename): Cannot map more than one path to %s; "
-"implicit directory renames tried to put these paths there: %s"
-msgstr ""
-"CONFLICTO (cambio de nombre implícito): No se puede mapear más de una ruta "
-"para %s; cambio de nombre implícito intentó poner estas rutas: %s"
+msgid "%s failed"
+msgstr "%s falló"
 
-#: merge-recursive.c:2085
-#, c-format
-msgid ""
-"CONFLICT (rename/rename): Rename directory %s->%s in %s. Rename directory %s-"
-">%s in %s"
-msgstr ""
-"CONFLICTO (renombrar/renombrar): Renombrar directorio %s->%s en %s. "
-"Renombrar directorio %s->%s en %s"
+#: fetch-pack.c:918
+msgid "error in sideband demultiplexer"
+msgstr "error en demultiplexor de banda lateral"
 
-#: merge-recursive.c:2330
+#: fetch-pack.c:965
 #, c-format
-msgid ""
-"WARNING: Avoiding applying %s -> %s rename to %s, because %s itself was "
-"renamed."
-msgstr ""
-"PELIGRO: Evitando aplicar %s -> %s renombrado a %s, porque %s mismo fue "
-"renombrado."
+msgid "Server version is %.*s"
+msgstr "Versión de servidor es %.*s"
 
-#: merge-recursive.c:2736
+#: fetch-pack.c:970 fetch-pack.c:976 fetch-pack.c:979 fetch-pack.c:985
+#: fetch-pack.c:989 fetch-pack.c:993 fetch-pack.c:997 fetch-pack.c:1001
+#: fetch-pack.c:1005 fetch-pack.c:1009 fetch-pack.c:1013 fetch-pack.c:1017
+#: fetch-pack.c:1023 fetch-pack.c:1029 fetch-pack.c:1034 fetch-pack.c:1039
 #, c-format
-msgid "CONFLICT (rename/add): Rename %s->%s in %s. %s added in %s"
-msgstr ""
-"CONFLICTO (renombrar/agregar): Renombrar %s->%s en %s. %s agregado en %s"
+msgid "Server supports %s"
+msgstr "El servidor soporta %s"
 
-#: merge-recursive.c:2751
-#, c-format
-msgid "Adding merged %s"
-msgstr "Agregar %s fusionado"
+#: fetch-pack.c:972
+msgid "Server does not support shallow clients"
+msgstr "El servidor no soporta clientes superficiales"
 
-#: merge-recursive.c:2758 merge-recursive.c:3089
-#, c-format
-msgid "Adding as %s instead"
-msgstr "Agregando más bien como %s"
+#: fetch-pack.c:1032
+msgid "Server does not support --shallow-since"
+msgstr "El servidor no soporta --shalow-since"
 
-#: merge-recursive.c:2914
-#, c-format
-msgid "cannot read object %s"
-msgstr "no se pudo leer el objeto %s"
+#: fetch-pack.c:1037
+msgid "Server does not support --shallow-exclude"
+msgstr "El servidor no soporta --shalow-exclude"
 
-#: merge-recursive.c:2917
-#, c-format
-msgid "object %s is not a blob"
-msgstr "objeto %s no es un blob"
+#: fetch-pack.c:1041
+msgid "Server does not support --deepen"
+msgstr "El servidor no soporta --deepen"
 
-#: merge-recursive.c:2986
-msgid "modify"
-msgstr "modificar"
+#: fetch-pack.c:1058
+msgid "no common commits"
+msgstr "no hay commits comunes"
 
-#: merge-recursive.c:2986
-msgid "modified"
-msgstr "modificado"
+#: fetch-pack.c:1070 fetch-pack.c:1536
+msgid "git fetch-pack: fetch failed."
+msgstr "git fetch-pack: fetch falló."
 
-#: merge-recursive.c:2997
-msgid "content"
-msgstr "contenido"
+#: fetch-pack.c:1209
+msgid "Server does not support shallow requests"
+msgstr "El servidor no soporta peticiones superficiales"
 
-#: merge-recursive.c:3004
-msgid "add/add"
-msgstr "agregar/agregar"
+#: fetch-pack.c:1216
+msgid "Server supports filter"
+msgstr "El servidor soporta filtro"
+
+#: fetch-pack.c:1239
+msgid "unable to write request to remote"
+msgstr "no se puede escribir request al remoto"
 
-#: merge-recursive.c:3046
+#: fetch-pack.c:1257
 #, c-format
-msgid "Skipped %s (merged same as existing)"
-msgstr "Saltado %s (fusionado como existente)"
+msgid "error reading section header '%s'"
+msgstr "error leyendo sección header '%s'"
 
-#: merge-recursive.c:3055 git-submodule.sh:895
-msgid "submodule"
-msgstr "submódulo"
+#: fetch-pack.c:1263
+#, c-format
+msgid "expected '%s', received '%s'"
+msgstr "se esperaba '%s', se recibió '%s'"
 
-#: merge-recursive.c:3056
+#: fetch-pack.c:1303
 #, c-format
-msgid "CONFLICT (%s): Merge conflict in %s"
-msgstr "CONFLICTO (%s): Conflicto de fusión en %s"
+msgid "unexpected acknowledgment line: '%s'"
+msgstr "línea de confirmación inesperada: '%s'"
 
-#: merge-recursive.c:3178
+#: fetch-pack.c:1308
 #, c-format
-msgid "Removing %s"
-msgstr "Eliminando %s"
+msgid "error processing acks: %d"
+msgstr "error procesando acks: %d"
 
-#: merge-recursive.c:3204
-msgid "file/directory"
-msgstr "archivo/directorio"
+#: fetch-pack.c:1318
+msgid "expected packfile to be sent after 'ready'"
+msgstr "espere que el packfile sea mandado luego del 'listo'"
 
-#: merge-recursive.c:3210
-msgid "directory/file"
-msgstr "directorio/archivo"
+#: fetch-pack.c:1320
+msgid "expected no other sections to be sent after no 'ready'"
+msgstr "espere que ninguna otra sección sea enviada luego del 'listo'"
 
-#: merge-recursive.c:3217
+#: fetch-pack.c:1362
 #, c-format
-msgid "CONFLICT (%s): There is a directory with name %s in %s. Adding %s as %s"
-msgstr ""
-"CONFLICTO (%s): Hay un directorio con el nombre %s en %s. Agregando %s como "
-"%s"
+msgid "error processing shallow info: %d"
+msgstr "error procesando información superficial: %d"
 
-#: merge-recursive.c:3226
+#: fetch-pack.c:1409
 #, c-format
-msgid "Adding %s"
-msgstr "Agregando %s"
+msgid "expected wanted-ref, got '%s'"
+msgstr "se esperaba wanted-ref, se obtuvo '%s'"
 
-#: merge-recursive.c:3267
+#: fetch-pack.c:1414
 #, c-format
-msgid "Dirty index: cannot merge (dirty: %s)"
-msgstr "Índice sucio: no se puede fusionar (sucio: %s)"
-
-#: merge-recursive.c:3271
-msgid "Already up to date!"
-msgstr "¡Ya está actualizado!"
+msgid "unexpected wanted-ref: '%s'"
+msgstr "wanted-ref inesperado: '%s'"
 
-#: merge-recursive.c:3280
+#: fetch-pack.c:1419
 #, c-format
-msgid "merging of trees %s and %s failed"
-msgstr "falló la fusión de los árboles %s y %s"
+msgid "error processing wanted refs: %d"
+msgstr "error procesando refs deseadas: %d"
 
-#: merge-recursive.c:3379
-msgid "Merging:"
-msgstr "Fusionando:"
+#: fetch-pack.c:1762
+msgid "no matching remote head"
+msgstr "no concuerda el head remoto"
+
+#: fetch-pack.c:1785 builtin/clone.c:688
+msgid "remote did not send all necessary objects"
+msgstr "remoto no mando todos los objetos necesarios"
 
-#: merge-recursive.c:3392
+#: fetch-pack.c:1812
 #, c-format
-msgid "found %u common ancestor:"
-msgid_plural "found %u common ancestors:"
-msgstr[0] "se encontró %u ancestro común:"
-msgstr[1] "se encontraron %u ancestros comunes:"
+msgid "no such remote ref %s"
+msgstr "no existe ref remota %s"
 
-#: merge-recursive.c:3431
-msgid "merge returned no commit"
-msgstr "la fusión no devolvió ningún commit"
+#: fetch-pack.c:1815
+#, c-format
+msgid "Server does not allow request for unadvertised object %s"
+msgstr "El servidor no permite solicitudes de objetos inadvertidos %s"
+
+#: gpg-interface.c:223
+msgid "could not create temporary file"
+msgstr "no se pudo crear archivo temporal"
 
-#: merge-recursive.c:3495
+#: gpg-interface.c:226
 #, c-format
-msgid "Could not parse object '%s'"
-msgstr "No se pudo analizar el objeto '%s'"
+msgid "failed writing detached signature to '%s'"
+msgstr "falló al escribir la firma separada para '%s'"
 
-#: merge-recursive.c:3511 builtin/merge.c:659 builtin/merge.c:816
-msgid "Unable to write index."
-msgstr "Incapaz de escribir el índice."
+#: gpg-interface.c:390
+msgid "gpg failed to sign the data"
+msgstr "gpg falló al firmar la data"
 
-#: notes-merge.c:272
+#: graph.c:98
 #, c-format
+msgid "ignore invalid color '%.*s' in log.graphColors"
+msgstr "ignora color inválido '%.*s' en log.graphColors"
+
+#: grep.c:668
 msgid ""
-"You have not concluded your previous notes merge (%s exists).\n"
-"Please, use 'git notes merge --commit' or 'git notes merge --abort' to "
-"commit/abort the previous merge before you start a new notes merge."
+"given pattern contains NULL byte (via -f <file>). This is only supported "
+"with -P under PCRE v2"
 msgstr ""
-"No has concluido tus notas previas de fusión (%s existe).\n"
-"Por favor, usa 'git notes merge --commit' o 'git notes merge --abort' para "
-"confirmar/abortar la fusión previa antes de que puedas comenzar una nueva "
-"nota de fusión."
+"el patrón provisto contiene bytes NULL (via -f <archivo>). Esto solo es "
+"soportado con -P bajo PCRE v2"
 
-#: notes-merge.c:279
+#: grep.c:2124
 #, c-format
-msgid "You have not concluded your notes merge (%s exists)."
-msgstr "No has terminado tus notas de fusión (%s existe)."
-
-#: notes-utils.c:43
-msgid "Cannot commit uninitialized/unreferenced notes tree"
-msgstr ""
-"No se puede realizar commit, notas del árbol no inicializadas o no "
-"referenciadas"
+msgid "'%s': unable to read %s"
+msgstr "'%s': no es posible leer %s"
 
-#: notes-utils.c:102
+#: grep.c:2141 setup.c:165 builtin/clone.c:411 builtin/diff.c:82
+#: builtin/rm.c:135
 #, c-format
-msgid "Bad notes.rewriteMode value: '%s'"
-msgstr "Mal valor para notes.rewriteMode: '%s'"
+msgid "failed to stat '%s'"
+msgstr "falló al marcar '%s'"
 
-#: notes-utils.c:112
+#: grep.c:2152
 #, c-format
-msgid "Refusing to rewrite notes in %s (outside of refs/notes/)"
-msgstr "Rehusando reescribir notas en %s (fuera de refs/notes/)"
+msgid "'%s': short read"
+msgstr "'%s': lectura corta"
 
-#. TRANSLATORS: The first %s is the name of
-#. the environment variable, the second %s is
-#. its value.
-#.
-#: notes-utils.c:142
-#, c-format
-msgid "Bad %s value: '%s'"
-msgstr "Mal valor para %s: '%s'"
+#: help.c:23
+msgid "start a working area (see also: git help tutorial)"
+msgstr "comienza un área de trabajo (ver también: git help tutorial)"
 
-#: object.c:242
-#, c-format
-msgid "unable to parse object: %s"
-msgstr "incapaz de analizar objeto: %s"
+#: help.c:24
+msgid "work on the current change (see also: git help everyday)"
+msgstr "trabaja en los cambios actuales (ver también: git help everyday)"
 
-#: packfile.c:563
-msgid "offset before end of packfile (broken .idx?)"
-msgstr "offset antes del final del paquete (broken .idx?)"
+#: help.c:25
+msgid "examine the history and state (see also: git help revisions)"
+msgstr "examina el historial y el estado (ver también: git help revisions)"
 
-#: packfile.c:1742
-#, c-format
-msgid "offset before start of pack index for %s (corrupt index?)"
-msgstr ""
-"offset antes del comienzo del índice del paquete para %s (índice corrupto?)"
+#: help.c:26
+msgid "grow, mark and tweak your common history"
+msgstr "crece, marca y ajusta tu historial común"
 
-#: packfile.c:1746
-#, c-format
-msgid "offset beyond end of pack index for %s (truncated index?)"
-msgstr ""
-"offset más allá del índice de fin de paquete para %s (índice truncado?)"
+#: help.c:27
+msgid "collaborate (see also: git help workflows)"
+msgstr "colabora (mira también: git help workflows)"
 
-#: parse-options.c:621
-msgid "..."
-msgstr "..."
+#: help.c:31
+msgid "Main Porcelain Commands"
+msgstr "Comandos de Porcelana principales"
 
-#: parse-options.c:640
-#, c-format
-msgid "usage: %s"
-msgstr "uso: %s"
+#: help.c:32
+msgid "Ancillary Commands / Manipulators"
+msgstr "Comandos auxiliares / Manipuladores"
 
-#. TRANSLATORS: the colon here should align with the
-#. one in "usage: %s" translation.
-#.
-#: parse-options.c:646
-#, c-format
-msgid "   or: %s"
-msgstr "   o: %s"
+#: help.c:33
+msgid "Ancillary Commands / Interrogators"
+msgstr "Comandos auxiliares / Interrogadores"
 
-#: parse-options.c:649
-#, c-format
-msgid "    %s"
-msgstr "    %s"
+#: help.c:34
+msgid "Interacting with Others"
+msgstr "Interactuando con Otros"
 
-#: parse-options.c:688
-msgid "-NUM"
-msgstr "-NUM"
+#: help.c:35
+msgid "Low-level Commands / Manipulators"
+msgstr "Comandos de bajo nivel / Manipuladores"
 
-#: parse-options-cb.c:44
-#, c-format
-msgid "malformed expiration date '%s'"
-msgstr "fecha de expiración mal formada: '%s'"
+#: help.c:36
+msgid "Low-level Commands / Interrogators"
+msgstr "Comandos de bajo nivel / Interrogadores"
 
-#: parse-options-cb.c:112
-#, c-format
-msgid "malformed object name '%s'"
-msgstr "nombre de objeto mal formado '%s'"
+#: help.c:37
+msgid "Low-level Commands / Syncing Repositories"
+msgstr "Comandos de bajo nivel / Sincronización de repositorios"
 
-#: path.c:892
-#, c-format
-msgid "Could not make %s writable by group"
-msgstr "No se pudo hacer que %s fuera escribible por el grupo"
+#: help.c:38
+msgid "Low-level Commands / Internal Helpers"
+msgstr "Comandos de bajo nivel / Auxiliares internos"
 
-#: pathspec.c:129
-msgid "Escape character '\\' not allowed as last character in attr value"
-msgstr ""
-"Carácter de escape '\\' no permitido como último carácter en el valor attr"
+#: help.c:298
+#, c-format
+msgid "available git commands in '%s'"
+msgstr "comandos disponibles de git en '%s'"
 
-#: pathspec.c:147
-msgid "Only one 'attr:' specification is allowed."
-msgstr "Solo una especificación 'attr' es permitida."
+#: help.c:305
+msgid "git commands available from elsewhere on your $PATH"
+msgstr "comandos disponibles de git desde otro lugar en tu $PATH"
 
-#: pathspec.c:150
-msgid "attr spec must not be empty"
-msgstr "especificación attr no puede estar vacía"
+#: help.c:314
+msgid "These are common Git commands used in various situations:"
+msgstr "Estos son comandos comunes de Git usados en varias situaciones:"
 
-#: pathspec.c:193
+#: help.c:363 git.c:98
 #, c-format
-msgid "invalid attribute name %s"
-msgstr "nombre de atributo %s invalido"
+msgid "unsupported command listing type '%s'"
+msgstr "comando de listado de tipos no soportado '%s'"
 
-#: pathspec.c:258
-msgid "global 'glob' and 'noglob' pathspec settings are incompatible"
-msgstr ""
-"configuraciones globales de pathspec 'glob' y 'noglob' son incompatibles"
+#: help.c:403
+msgid "The common Git guides are:"
+msgstr "Las guías comunes de Git son:"
+
+#: help.c:512
+msgid "See 'git help <command>' to read about a specific subcommand"
+msgstr "Vea 'git help <comando>' para leer sobre los subcomandos específicos"
+
+#: help.c:517
+msgid "External commands"
+msgstr "Comandos externos"
+
+#: help.c:532
+msgid "Command aliases"
+msgstr "Aliases de comando"
 
-#: pathspec.c:265
+#: help.c:596
+#, c-format
 msgid ""
-"global 'literal' pathspec setting is incompatible with all other global "
-"pathspec settings"
+"'%s' appears to be a git command, but we were not\n"
+"able to execute it. Maybe git-%s is broken?"
 msgstr ""
-"la configuración global de 'literal' para patrones de ruta es incompatible "
-"con las demás configuraciones globales de patrones de ruta"
-
-#: pathspec.c:305
-msgid "invalid parameter for pathspec magic 'prefix'"
-msgstr "parámetro no válido para el prefijo 'magic pathspec'"
+"'%s' parece ser un comando de git, pero no hemos\n"
+"podido ejecutarlo. ¿Tal vez git-%s se ha roto?"
 
-#: pathspec.c:326
-#, c-format
-msgid "Invalid pathspec magic '%.*s' in '%s'"
-msgstr "Magic pathspec inválido '%.*s' en '%s'"
+#: help.c:655
+msgid "Uh oh. Your system reports no Git commands at all."
+msgstr "Oh oh. Tu sistema no reporta ningún comando de Git."
 
-#: pathspec.c:331
+#: help.c:677
 #, c-format
-msgid "Missing ')' at the end of pathspec magic in '%s'"
-msgstr "Falta ')' al final del magic pathspec en '%s'"
+msgid "WARNING: You called a Git command named '%s', which does not exist."
+msgstr "PELIGRO: Has llamado a un comando de Git '%s', el cual no existe."
 
-#: pathspec.c:369
+#: help.c:682
 #, c-format
-msgid "Unimplemented pathspec magic '%c' in '%s'"
-msgstr "Magic pathspec '%c' no implementado en '%s'"
+msgid "Continuing under the assumption that you meant '%s'."
+msgstr "Continuando asumiendo que quisiste decir '%s'."
 
-#: pathspec.c:428
+#: help.c:687
 #, c-format
-msgid "%s: 'literal' and 'glob' are incompatible"
-msgstr "%s: 'literal' y 'glob' son incompatibles"
+msgid "Continuing in %0.1f seconds, assuming that you meant '%s'."
+msgstr "Continuando en %0.1f segundos, asumiendo que tu dijiste '%s'."
 
-#: pathspec.c:441
+#: help.c:695
 #, c-format
-msgid "%s: '%s' is outside repository"
-msgstr "%s: '%s' está fuera del repositorio"
+msgid "git: '%s' is not a git command. See 'git --help'."
+msgstr "git: '%s'no es un comando de git. Mira 'git --help'."
 
-#: pathspec.c:515
-#, c-format
-msgid "'%s' (mnemonic: '%c')"
-msgstr "'%s' (nemotécnico: '%c')"
+#: help.c:699
+msgid ""
+"\n"
+"The most similar command is"
+msgid_plural ""
+"\n"
+"The most similar commands are"
+msgstr[0] ""
+"\n"
+"El comando más similar es"
+msgstr[1] ""
+"\n"
+"Los comandos más similares son"
 
-#: pathspec.c:525
-#, c-format
-msgid "%s: pathspec magic not supported by this command: %s"
-msgstr "%s: magic pathspec no soportado por este comando: %s"
+#: help.c:714
+msgid "git version [<options>]"
+msgstr "git versión [<opciones>]"
 
-#: pathspec.c:592
+#: help.c:783
 #, c-format
-msgid "pathspec '%s' is beyond a symbolic link"
-msgstr "el patrón de ruta '%s' está detrás de un enlace simbólico"
+msgid "%s: %s - %s"
+msgstr "%s: %s - %s"
 
-#: pretty.c:962
-msgid "unable to parse --pretty format"
-msgstr "incapaz de analizar el formato --pretty"
+#: help.c:787
+msgid ""
+"\n"
+"Did you mean this?"
+msgid_plural ""
+"\n"
+"Did you mean one of these?"
+msgstr[0] ""
+"\n"
+"¿Quisiste decir esto?"
+msgstr[1] ""
+"\n"
+"¿Quisiste decir alguno de estos?"
 
-#: read-cache.c:1500
-#, c-format
+#: ident.c:349
 msgid ""
-"index.version set, but the value is invalid.\n"
-"Using version %i"
+"\n"
+"*** Please tell me who you are.\n"
+"\n"
+"Run\n"
+"\n"
+"  git config --global user.email \"you@example.com\"\n"
+"  git config --global user.name \"Your Name\"\n"
+"\n"
+"to set your account's default identity.\n"
+"Omit --global to set the identity only in this repository.\n"
+"\n"
 msgstr ""
-"index.version configurado, pero el valor no es válido.\n"
-"Usando versión %i"
+"\n"
+"*** Por favor cuéntame quien eres.\n"
+"\n"
+"Corre\n"
+"\n"
+"  git config --global user.email \"you@example.com\"\n"
+"  git config --global user.name \"Tu Nombre\"\n"
+"\n"
+"para configurar la identidad por defecto de tu cuenta.\n"
+"Omite --global para configurar tu identidad solo en este repositorio.\n"
+"\n"
+
+#: ident.c:379
+msgid "no email was given and auto-detection is disabled"
+msgstr "no se entrego ningún email y la detección automática está desactivada"
 
-#: read-cache.c:1510
+#: ident.c:384
 #, c-format
-msgid ""
-"GIT_INDEX_VERSION set, but the value is invalid.\n"
-"Using version %i"
-msgstr ""
-"GIT_INDEX_VERSION configurado, pero el valor no es válido.\n"
-"Usando versión %i"
+msgid "unable to auto-detect email address (got '%s')"
+msgstr "no es posible auto-detectar la dirección de correo (se obtuvo '%s')"
+
+#: ident.c:401
+msgid "no name was given and auto-detection is disabled"
+msgstr "no se entrego ningún nombre y la detección automática está desactivada"
 
-#: read-cache.c:2404 sequencer.c:4338 wrapper.c:658 builtin/merge.c:1048
+#: ident.c:407
 #, c-format
-msgid "could not close '%s'"
-msgstr "no se pudo cerrar '%s'"
+msgid "unable to auto-detect name (got '%s')"
+msgstr "no es posible auto-detectar el nombre (se obtuvo '%s')"
 
-#: read-cache.c:2477 sequencer.c:2102 sequencer.c:3234
+#: ident.c:415
 #, c-format
-msgid "could not stat '%s'"
-msgstr "no se pudo definir '%s'"
+msgid "empty ident name (for <%s>) not allowed"
+msgstr "no se puede tener un nombre vacío (para <%s>)"
 
-#: read-cache.c:2490
+#: ident.c:421
 #, c-format
-msgid "unable to open git dir: %s"
-msgstr "no es posible abrir el directorio de git: %s"
+msgid "name consists only of disallowed characters: %s"
+msgstr "el nombre consiste solo de caracteres no permitidos: %s"
 
-#: read-cache.c:2502
+#: ident.c:436 builtin/commit.c:631
 #, c-format
-msgid "unable to unlink: %s"
-msgstr "no es posible remover el vinculo: %s"
+msgid "invalid date format: %s"
+msgstr "formato de fecha inválido: %s"
 
-#: refs.c:732 sequencer.c:4334 sequencer.c:4393 wrapper.c:225 wrapper.c:395
-#: builtin/am.c:779
+#: list-objects.c:127
 #, c-format
-msgid "could not open '%s' for writing"
-msgstr "no se pudo abrir '%s' para escritura"
+msgid "entry '%s' in tree %s has tree mode, but is not a tree"
+msgstr "entrada '%s' en árbol %s tiene modo árbol, pero no es uno"
 
-#: refs.c:1880
-msgid "ref updates forbidden inside quarantine environment"
-msgstr "actualizaciones de ref prohibidas dentro de ambiente de cuarentena"
+#: list-objects.c:140
+#, c-format
+msgid "entry '%s' in tree %s has blob mode, but is not a blob"
+msgstr "entrada '%s' en árbol %s tiene modo blob, pero no es uno"
 
-#: refs/files-backend.c:1191
+#: list-objects.c:375
 #, c-format
-msgid "could not remove reference %s"
-msgstr "no se pudo remover la referencia %s"
+msgid "unable to load root tree for commit %s"
+msgstr "no se puede cargar árbol raíz para commit %s"
 
-#: refs/files-backend.c:1205 refs/packed-backend.c:1531
-#: refs/packed-backend.c:1541
+#: list-objects-filter.c:492
 #, c-format
-msgid "could not delete reference %s: %s"
-msgstr "no se pudo eliminar la referencia %s: %s"
+msgid "unable to access sparse blob in '%s'"
+msgstr "no es posible acceder al blob en '%s'"
 
-#: refs/files-backend.c:1208 refs/packed-backend.c:1544
+#: list-objects-filter.c:495
 #, c-format
-msgid "could not delete references: %s"
-msgstr "no se pudo eliminar la referencia: %s"
+msgid "unable to parse sparse filter data in %s"
+msgstr "incapaz de analizar filtro de data en %s"
 
-#: ref-filter.c:35 wt-status.c:1850
-msgid "gone"
-msgstr "desaparecido"
+#: list-objects-filter-options.c:58
+msgid "expected 'tree:<depth>'"
+msgstr "se esperaba 'tree:<depth>'"
 
-#: ref-filter.c:36
-#, c-format
-msgid "ahead %d"
-msgstr "adelante %d"
+#: list-objects-filter-options.c:73
+msgid "sparse:path filters support has been dropped"
+msgstr "soporte para filtros sparse:path ha sido discontinuado"
 
-#: ref-filter.c:37
+#: list-objects-filter-options.c:86
 #, c-format
-msgid "behind %d"
-msgstr "detrás %d"
+msgid "invalid filter-spec '%s'"
+msgstr "filtro -spec inválido '%s'"
 
-#: ref-filter.c:38
+#: list-objects-filter-options.c:102
 #, c-format
-msgid "ahead %d, behind %d"
-msgstr "delante %d, detrás %d"
+msgid "must escape char in sub-filter-spec: '%c'"
+msgstr "tienes que escapar el caracter en sub-filter-spec: '%c'"
 
-#: ref-filter.c:121
-#, c-format
-msgid "expected format: %%(color:<color>)"
-msgstr "formato esperado: %%(color:<color>)"
+#: list-objects-filter-options.c:144
+msgid "expected something after combine:"
+msgstr "se espera algo luego de combine:"
 
-#: ref-filter.c:123
-#, c-format
-msgid "unrecognized color: %%(color:%s)"
-msgstr "color no reconocido: %%(color:%s)"
+#: list-objects-filter-options.c:226
+msgid "multiple filter-specs cannot be combined"
+msgstr "no se pueden combinar múltiples tipos de especificaciones de filtro"
 
-#: ref-filter.c:145
+#: lockfile.c:151
 #, c-format
-msgid "Integer value expected refname:lstrip=%s"
-msgstr "Valor entero esperado refname:lstrip=%s"
+msgid ""
+"Unable to create '%s.lock': %s.\n"
+"\n"
+"Another git process seems to be running in this repository, e.g.\n"
+"an editor opened by 'git commit'. Please make sure all processes\n"
+"are terminated then try again. If it still fails, a git process\n"
+"may have crashed in this repository earlier:\n"
+"remove the file manually to continue."
+msgstr ""
+"No se puede crear '%s.lock': %s.\n"
+"\n"
+"Otro proceso git parece estar corriendo en el repositorio, es decir\n"
+"un editor abierto con 'git commit'. Por favor asegúrese de que todos los "
+"procesos\n"
+"están terminados y vuelve a intentar. Si el fallo permanece, un proceso git\n"
+"puede haber roto el repositorio antes:\n"
+"borra el archivo manualmente para continuar."
 
-#: ref-filter.c:149
+#: lockfile.c:159
 #, c-format
-msgid "Integer value expected refname:rstrip=%s"
-msgstr "Valor entero esperado refname:rstrip=%s"
+msgid "Unable to create '%s.lock': %s"
+msgstr "No se pudo crear '%s.lock': %s"
 
-#: ref-filter.c:151
-#, c-format
-msgid "unrecognized %%(%s) argument: %s"
-msgstr "argumento: %s no reconocido %%(%s)"
+#: merge.c:41
+msgid "failed to read the cache"
+msgstr "falló al leer la cache"
 
-#: ref-filter.c:206
-#, c-format
-msgid "%%(body) does not take arguments"
-msgstr "%%(body) no toma ningún argumento"
+#: merge.c:107 rerere.c:720 builtin/am.c:1874 builtin/am.c:1908
+#: builtin/checkout.c:539 builtin/checkout.c:798 builtin/clone.c:809
+#: builtin/stash.c:264
+msgid "unable to write new index file"
+msgstr "no es posible escribir el archivo índice"
 
-#: ref-filter.c:215
-#, c-format
-msgid "%%(subject) does not take arguments"
-msgstr "%%(subject) no toma ningún argumento"
+#: merge-recursive.c:367
+msgid "(bad commit)\n"
+msgstr "(commit erróneo)\n"
 
-#: ref-filter.c:235
+#: merge-recursive.c:390
 #, c-format
-msgid "unknown %%(trailers) argument: %s"
-msgstr "%%(trailers) desconocidos, argumento: %s"
+msgid "add_cacheinfo failed for path '%s'; merge aborting."
+msgstr "add_cacheinfo falló para la ruta '%s'; abortando fusión."
 
-#: ref-filter.c:264
+#: merge-recursive.c:399
 #, c-format
-msgid "positive value expected contents:lines=%s"
-msgstr "valor positivo esperado contents:lines=%s"
+msgid "add_cacheinfo failed to refresh for path '%s'; merge aborting."
+msgstr "add_cacheinfo falló para refrescar la ruta '%s'; abortando fusión."
 
-#: ref-filter.c:266
+#: merge-recursive.c:885
 #, c-format
-msgid "unrecognized %%(contents) argument: %s"
-msgstr "argumento %s no reconocido %%(contents)"
+msgid "failed to create path '%s'%s"
+msgstr "falló al crear la ruta '%s'%s"
 
-#: ref-filter.c:281
+#: merge-recursive.c:896
 #, c-format
-msgid "positive value expected objectname:short=%s"
-msgstr "valor positivo esperado objectname:short=%s"
+msgid "Removing %s to make room for subdirectory\n"
+msgstr "Removiendo %s para hacer espacio para un subdirectorio\n"
 
-#: ref-filter.c:285
-#, c-format
-msgid "unrecognized %%(objectname) argument: %s"
-msgstr "argumento: %s no reconocido %%(objectname)"
+#: merge-recursive.c:910 merge-recursive.c:929
+msgid ": perhaps a D/F conflict?"
+msgstr ": ¿tal vez un conflicto D/F?"
 
-#: ref-filter.c:315
+#: merge-recursive.c:919
 #, c-format
-msgid "expected format: %%(align:<width>,<position>)"
-msgstr "formato esperado: %%(align:<ancho>,<posición>)"
+msgid "refusing to lose untracked file at '%s'"
+msgstr "rehusando perder el archivo rastreado en '%s'"
 
-#: ref-filter.c:327
+#: merge-recursive.c:960 builtin/cat-file.c:41
 #, c-format
-msgid "unrecognized position:%s"
-msgstr "posición desconocida: %s"
+msgid "cannot read object %s '%s'"
+msgstr "no se puede leer el objeto %s '%s'"
 
-#: ref-filter.c:334
+#: merge-recursive.c:965
 #, c-format
-msgid "unrecognized width:%s"
-msgstr "ancho desconocido: %s"
+msgid "blob expected for %s '%s'"
+msgstr "se esperaba blob para %s '%s'"
 
-#: ref-filter.c:343
+#: merge-recursive.c:990
 #, c-format
-msgid "unrecognized %%(align) argument: %s"
-msgstr "argumento no reconocido para %%(align): %s"
+msgid "failed to open '%s': %s"
+msgstr "falló al abrir '%s': %s"
 
-#: ref-filter.c:351
+#: merge-recursive.c:1001
 #, c-format
-msgid "positive width expected with the %%(align) atom"
-msgstr "se esperaba un ancho positivo con el átomo %%(align)"
+msgid "failed to symlink '%s': %s"
+msgstr "falló al crear el enlace simbólico '%s': %s"
 
-#: ref-filter.c:369
+#: merge-recursive.c:1006
 #, c-format
-msgid "unrecognized %%(if) argument: %s"
-msgstr "argumento: %s no reconocido %%(if)"
+msgid "do not know what to do with %06o %s '%s'"
+msgstr "no se que hacer con %06o %s '%s'"
 
-#: ref-filter.c:464
+#: merge-recursive.c:1199
 #, c-format
-msgid "malformed field name: %.*s"
-msgstr "nombre mal formado de campo: %.*s"
+msgid "Failed to merge submodule %s (not checked out)"
+msgstr "Falló al fusionar el submódulo %s (no revisado)"
 
-#: ref-filter.c:491
+#: merge-recursive.c:1206
 #, c-format
-msgid "unknown field name: %.*s"
-msgstr "nombre de campo desconocido: %.*s"
+msgid "Failed to merge submodule %s (commits not present)"
+msgstr "Falló al fusionar el submódulo %s (commits no presentes)"
 
-#: ref-filter.c:608
+#: merge-recursive.c:1213
 #, c-format
-msgid "format: %%(if) atom used without a %%(then) atom"
-msgstr "formato: átomo %%(if) usado sin un átomo %%(then)"
+msgid "Failed to merge submodule %s (commits don't follow merge-base)"
+msgstr "Falló el fusionar submódulo %s (commits no siguen la fusión base)"
 
-#: ref-filter.c:671
+#: merge-recursive.c:1221 merge-recursive.c:1233
 #, c-format
-msgid "format: %%(then) atom used without an %%(if) atom"
-msgstr "formato: átomo %%(then) usado sin átomo %%(if)"
+msgid "Fast-forwarding submodule %s to the following commit:"
+msgstr "Haciendo fast-forward a submódulo %s para el siguiente commit:"
 
-#: ref-filter.c:673
+#: merge-recursive.c:1224 merge-recursive.c:1236
 #, c-format
-msgid "format: %%(then) atom used more than once"
-msgstr "formato: átomo %%(then) usado mas de una vez"
+msgid "Fast-forwarding submodule %s"
+msgstr "Avance rápido en submódulo %s"
 
-#: ref-filter.c:675
+#: merge-recursive.c:1259
 #, c-format
-msgid "format: %%(then) atom used after %%(else)"
-msgstr "formato: átomo %%(then) usado después de %%(else)"
+msgid "Failed to merge submodule %s (merge following commits not found)"
+msgstr ""
+"Falló al fusionar submódulo %s (los siguentes commits no fueron encontrados)"
 
-#: ref-filter.c:703
+#: merge-recursive.c:1263
 #, c-format
-msgid "format: %%(else) atom used without an %%(if) atom"
-msgstr "formato: átomo %%(else) usado sin un átomo %%(if)"
+msgid "Failed to merge submodule %s (not fast-forward)"
+msgstr "Falló al fusionar el submódulo %s (no es posible avance rápido)"
 
-#: ref-filter.c:705
-#, c-format
-msgid "format: %%(else) atom used without a %%(then) atom"
-msgstr "formato: átomo %%(else) usado sin un átomo %%(then)"
+#: merge-recursive.c:1264
+msgid "Found a possible merge resolution for the submodule:\n"
+msgstr "Se encontró una posible solución de fusión para el submódulo:\n"
 
-#: ref-filter.c:707
+#: merge-recursive.c:1267
 #, c-format
-msgid "format: %%(else) atom used more than once"
-msgstr "formato: átomo %%(else) usado mas de una vez"
+msgid ""
+"If this is correct simply add it to the index for example\n"
+"by using:\n"
+"\n"
+"  git update-index --cacheinfo 160000 %s \"%s\"\n"
+"\n"
+"which will accept this suggestion.\n"
+msgstr ""
+"Si esto es correcto simplemente agrégalo al índice por ejemplo\n"
+"usando:\n"
+"\n"
+"  git update-index --cacheinfo 160000 %s \"%s\"\n"
+"\n"
+"el cual aceptará esta sugerencia.\n"
 
-#: ref-filter.c:722
+#: merge-recursive.c:1276
 #, c-format
-msgid "format: %%(end) atom used without corresponding atom"
-msgstr "formato: átomo %%(end) usado sin átomo correspondiente"
+msgid "Failed to merge submodule %s (multiple merges found)"
+msgstr "Falló al fusionar el submódulo %s (fusiones múltiples encontradas)"
 
-#: ref-filter.c:779
-#, c-format
-msgid "malformed format string %s"
-msgstr "formato de cadena mal formado %s"
+#: merge-recursive.c:1349
+msgid "Failed to execute internal merge"
+msgstr "Falló al ejecutar la fusión interna"
 
-#: ref-filter.c:1387
+#: merge-recursive.c:1354
 #, c-format
-msgid "(no branch, rebasing %s)"
-msgstr "(no hay rama, rebasando %s)"
+msgid "Unable to add %s to database"
+msgstr "No es posible agregar %s a la base de datos"
 
-#: ref-filter.c:1390
+#: merge-recursive.c:1386
 #, c-format
-msgid "(no branch, rebasing detached HEAD %s)"
-msgstr "(no hay rama, rebasando con HEAD desacoplado %s)"
+msgid "Auto-merging %s"
+msgstr "Auto-fusionando %s"
 
-#: ref-filter.c:1393
+#: merge-recursive.c:1410
 #, c-format
-msgid "(no branch, bisect started on %s)"
-msgstr "(no hay rama, comenzando bisecado en %s)"
+msgid "Error: Refusing to lose untracked file at %s; writing to %s instead."
+msgstr ""
+"Error: Rehusando perder el archivo no rastreado en %s; escribiéndolo a %s en "
+"cambio."
 
-#. TRANSLATORS: make sure this matches "HEAD
-#. detached at " in wt-status.c
-#.
-#: ref-filter.c:1401
+#: merge-recursive.c:1482
 #, c-format
-msgid "(HEAD detached at %s)"
-msgstr "(HEAD desacoplado en %s)"
+msgid ""
+"CONFLICT (%s/delete): %s deleted in %s and %s in %s. Version %s of %s left "
+"in tree."
+msgstr ""
+"CONFLICTO (%s/borrar): %s borrado en %s y %s en %s. Falta versión %s de %s "
+"en el árbol."
 
-#. TRANSLATORS: make sure this matches "HEAD
-#. detached from " in wt-status.c
-#.
-#: ref-filter.c:1408
+#: merge-recursive.c:1487
 #, c-format
-msgid "(HEAD detached from %s)"
-msgstr "(HEAD desacoplado de %s)"
-
-#: ref-filter.c:1412
-msgid "(no branch)"
-msgstr "(sin rama)"
+msgid ""
+"CONFLICT (%s/delete): %s deleted in %s and %s to %s in %s. Version %s of %s "
+"left in tree."
+msgstr ""
+"CONFLICTO (%s/borrar): %s borrado en %s y %s para %s en %s. Versión %s de %s "
+"permanece en el árbol."
 
-#: ref-filter.c:1442
+#: merge-recursive.c:1494
 #, c-format
-msgid "missing object %s for %s"
-msgstr "falta objeto %s para %s"
+msgid ""
+"CONFLICT (%s/delete): %s deleted in %s and %s in %s. Version %s of %s left "
+"in tree at %s."
+msgstr ""
+"CONFLICTO (%s/eliminar): %s eliminado en %s y %s en %s. Versión %s de %s "
+"dejada en el árbol, en %s."
 
-#: ref-filter.c:1445
+#: merge-recursive.c:1499
 #, c-format
-msgid "parse_object_buffer failed on %s for %s"
-msgstr "parse_object_buffer falló en %s para %s"
+msgid ""
+"CONFLICT (%s/delete): %s deleted in %s and %s to %s in %s. Version %s of %s "
+"left in tree at %s."
+msgstr ""
+"CONFLICTO (%s/borrar): %s borrado en %s y %s para %s en %s. Versión %s de %s "
+"permanece en el árbol en %s."
 
-#: ref-filter.c:1902
-#, c-format
-msgid "malformed object at '%s'"
-msgstr "objeto mal formado en '%s'"
+#: merge-recursive.c:1534
+msgid "rename"
+msgstr "renombrar"
 
-#: ref-filter.c:1984
-#, c-format
-msgid "ignoring ref with broken name %s"
-msgstr "ignorando referencia con nombre roto %s"
+#: merge-recursive.c:1534
+msgid "renamed"
+msgstr "renombrado"
 
-#: ref-filter.c:1989
+#: merge-recursive.c:1614 merge-recursive.c:2530 merge-recursive.c:3175
 #, c-format
-msgid "ignoring broken ref %s"
-msgstr "ignorando referencia rota %s"
+msgid "Refusing to lose dirty file at %s"
+msgstr "Rehusando perder el archivo sucio en %s"
 
-#: ref-filter.c:2261
+#: merge-recursive.c:1624
 #, c-format
-msgid "format: %%(end) atom missing"
-msgstr "formato: falta átomo %%(end)"
+msgid "Refusing to lose untracked file at %s, even though it's in the way."
+msgstr ""
+"Rehusando perder el archivo no rastreado en %s, incluso aunque se está "
+"interponiendo."
 
-#: ref-filter.c:2365
+#: merge-recursive.c:1682
 #, c-format
-msgid "malformed object name %s"
-msgstr "nombre de objeto mal formado %s"
+msgid "CONFLICT (rename/add): Rename %s->%s in %s.  Added %s in %s"
+msgstr ""
+"CONFLICTO (renombrar/agregar): Renombrar %s->%s en %s.  %s agregado en %s"
 
-#: remote.c:605
+#: merge-recursive.c:1713
 #, c-format
-msgid "Cannot fetch both %s and %s to %s"
-msgstr "No se pueden traer ambos %s y %s a %s"
+msgid "%s is a directory in %s adding as %s instead"
+msgstr "%s es un directorio en %s agregando como %s más bien"
 
-#: remote.c:609
+#: merge-recursive.c:1718
 #, c-format
-msgid "%s usually tracks %s, not %s"
-msgstr "%s por lo general hace seguimiento a %s, no a %s"
+msgid "Refusing to lose untracked file at %s; adding as %s instead"
+msgstr ""
+"Rehusando perder el archivo no rastreado en %s; agregándolo como %s en cambio"
 
-#: remote.c:613
+#: merge-recursive.c:1737
 #, c-format
-msgid "%s tracks both %s and %s"
-msgstr "%s hace seguimiento tanto a %s como a %s"
-
-#: remote.c:621
-msgid "Internal error"
-msgstr "Error interno"
-
-#: remote.c:1534 remote.c:1635
-msgid "HEAD does not point to a branch"
-msgstr "HEAD no apunta a ninguna rama"
+msgid ""
+"CONFLICT (rename/rename): Rename \"%s\"->\"%s\" in branch \"%s\" rename \"%s"
+"\"->\"%s\" in \"%s\"%s"
+msgstr ""
+"CONFLICTO (renombrar/renombrar): Renombrar \"%s\"->\"%s\" en la rama \"%s\" "
+"renombrar \"%s\"->\"%s\" en \"%s\"%s"
 
-#: remote.c:1543
-#, c-format
-msgid "no such branch: '%s'"
-msgstr "no existe tal rama: '%s'"
+#: merge-recursive.c:1742
+msgid " (left unresolved)"
+msgstr " (dejado sin resolver)"
 
-#: remote.c:1546
+#: merge-recursive.c:1851
 #, c-format
-msgid "no upstream configured for branch '%s'"
-msgstr "no se ha configurado upstream para la rama '%s'"
+msgid "CONFLICT (rename/rename): Rename %s->%s in %s. Rename %s->%s in %s"
+msgstr ""
+"CONFLICTO (renombrar/renombrar): Renombrar %s->%s en %s. Renombrar %s->%s en "
+"%s"
 
-#: remote.c:1552
+#: merge-recursive.c:2114
 #, c-format
-msgid "upstream branch '%s' not stored as a remote-tracking branch"
-msgstr "la rama '%s' de upstream no es guardad como rama de rastreo remoto"
+msgid ""
+"CONFLICT (directory rename split): Unclear where to place %s because "
+"directory %s was renamed to multiple other directories, with no destination "
+"getting a majority of the files."
+msgstr ""
+"CONFLICTO (división de cambio de nombre de directorio): No es claro dónde "
+"colocar %s porque el directorio %s fue renombrado a otros múltiples "
+"directorios, sin ningún que contenga la mayoría de archivos."
 
-#: remote.c:1567
+#: merge-recursive.c:2146
 #, c-format
-msgid "push destination '%s' on remote '%s' has no local tracking branch"
+msgid ""
+"CONFLICT (implicit dir rename): Existing file/dir at %s in the way of "
+"implicit directory rename(s) putting the following path(s) there: %s."
 msgstr ""
-"destino de push '%s' en el remoto '%s' no tiene una rama de rastreo local"
+"CONFLICTO (cambio de nombre de directorio implícito): Archivo/directorio "
+"existente en %s se interpone con el cambio de nombres implícito, poniendo "
+"la(s) siguiente(s) ruta(s) aquí: %s."
 
-#: remote.c:1579
+#: merge-recursive.c:2156
 #, c-format
-msgid "branch '%s' has no remote for pushing"
-msgstr "la rama '%s' no tiene remoto para enviar"
+msgid ""
+"CONFLICT (implicit dir rename): Cannot map more than one path to %s; "
+"implicit directory renames tried to put these paths there: %s"
+msgstr ""
+"CONFLICTO (cambio de nombre implícito): No se puede mapear más de una ruta "
+"para %s; cambio de nombre implícito intentó poner estas rutas: %s"
 
-#: remote.c:1589
+#: merge-recursive.c:2248
 #, c-format
-msgid "push refspecs for '%s' do not include '%s'"
-msgstr "refspecs del push para '%s' no incluyen '%s'"
+msgid ""
+"CONFLICT (rename/rename): Rename directory %s->%s in %s. Rename directory %s-"
+">%s in %s"
+msgstr ""
+"CONFLICTO (renombrar/renombrar): Renombrar directorio %s->%s en %s. "
+"Renombrar directorio %s->%s en %s"
 
-#: remote.c:1602
-msgid "push has no destination (push.default is 'nothing')"
-msgstr "push no tiene destino (push.default es 'nada')"
+#: merge-recursive.c:2493
+#, c-format
+msgid ""
+"WARNING: Avoiding applying %s -> %s rename to %s, because %s itself was "
+"renamed."
+msgstr ""
+"PELIGRO: Evitando aplicar %s -> %s renombrado a %s, porque %s mismo fue "
+"renombrado."
 
-#: remote.c:1624
-msgid "cannot resolve 'simple' push to a single destination"
-msgstr "no se puede resolver push 'simple' para un destino único"
+#: merge-recursive.c:3019
+#, c-format
+msgid "cannot read object %s"
+msgstr "no se pudo leer el objeto %s"
 
-#: remote.c:1939
+#: merge-recursive.c:3022
 #, c-format
-msgid "Your branch is based on '%s', but the upstream is gone.\n"
-msgstr "Tu rama esta basada en '%s', pero upstream ha desaparecido.\n"
+msgid "object %s is not a blob"
+msgstr "objeto %s no es un blob"
 
-#: remote.c:1943
-msgid "  (use \"git branch --unset-upstream\" to fixup)\n"
-msgstr "  (usa \"git branch --unset-upstream\" para arreglar)\n"
+#: merge-recursive.c:3086
+msgid "modify"
+msgstr "modificar"
 
-#: remote.c:1946
-#, c-format
-msgid "Your branch is up to date with '%s'.\n"
-msgstr "Tu rama está actualizada con '%s'.\n"
+#: merge-recursive.c:3086
+msgid "modified"
+msgstr "modificado"
 
-#: remote.c:1950
-#, c-format
-msgid "Your branch and '%s' refer to different commits.\n"
-msgstr "Tu rama y '%s' refieren a commits diferentes.\n"
+#: merge-recursive.c:3098
+msgid "content"
+msgstr "contenido"
 
-#: remote.c:1953
-#, c-format
-msgid "  (use \"%s\" for details)\n"
-msgstr "  (usa \"%s\" para detalles)\n"
+#: merge-recursive.c:3102
+msgid "add/add"
+msgstr "agregar/agregar"
 
-#: remote.c:1957
+#: merge-recursive.c:3125
 #, c-format
-msgid "Your branch is ahead of '%s' by %d commit.\n"
-msgid_plural "Your branch is ahead of '%s' by %d commits.\n"
-msgstr[0] "Tu rama está adelantada a '%s' por %d commit.\n"
-msgstr[1] "Tu rama está adelantada a '%s' por %d commits.\n"
+msgid "Skipped %s (merged same as existing)"
+msgstr "Saltado %s (fusionado como existente)"
 
-#: remote.c:1963
-msgid "  (use \"git push\" to publish your local commits)\n"
-msgstr "  (usa \"git push\" para publicar tus commits locales)\n"
+#: merge-recursive.c:3147 git-submodule.sh:993
+msgid "submodule"
+msgstr "submódulo"
 
-#: remote.c:1966
+#: merge-recursive.c:3148
 #, c-format
-msgid "Your branch is behind '%s' by %d commit, and can be fast-forwarded.\n"
-msgid_plural ""
-"Your branch is behind '%s' by %d commits, and can be fast-forwarded.\n"
-msgstr[0] ""
-"Tu rama está detrás de '%s' por %d commit, y puede ser avanzada rápido.\n"
-msgstr[1] ""
-"Tu rama está detrás de '%s' por %d commits, y puede ser avanzada rápido.\n"
+msgid "CONFLICT (%s): Merge conflict in %s"
+msgstr "CONFLICTO (%s): Conflicto de fusión en %s"
 
-#: remote.c:1974
-msgid "  (use \"git pull\" to update your local branch)\n"
-msgstr "  (usa \"git pull\" para actualizar tu rama local)\n"
+#: merge-recursive.c:3178
+#, c-format
+msgid "Adding as %s instead"
+msgstr "Agregando más bien como %s"
 
-#: remote.c:1977
+#: merge-recursive.c:3261
 #, c-format
 msgid ""
-"Your branch and '%s' have diverged,\n"
-"and have %d and %d different commit each, respectively.\n"
-msgid_plural ""
-"Your branch and '%s' have diverged,\n"
-"and have %d and %d different commits each, respectively.\n"
-msgstr[0] ""
-"Tu rama y '%s' han divergido,\n"
-"y se tiene %d y %d commit diferentes en cada una respectivamente.\n"
-msgstr[1] ""
-"Tu rama y '%s' han divergido,\n"
-"y tienen %d y %d commits diferentes cada una respectivamente.\n"
+"Path updated: %s added in %s inside a directory that was renamed in %s; "
+"moving it to %s."
+msgstr ""
+"Path actualizado: %s agregado en %s dentro de un directorio que fue "
+"renombrado en %s; moviéndolo a %s."
 
-#: remote.c:1987
-msgid "  (use \"git pull\" to merge the remote branch into yours)\n"
-msgstr "  (usa \"git pull\" para fusionar la rama remota en la tuya)\n"
+#: merge-recursive.c:3264
+#, c-format
+msgid ""
+"CONFLICT (file location): %s added in %s inside a directory that was renamed "
+"in %s, suggesting it should perhaps be moved to %s."
+msgstr ""
+"CONFLICTO (ubicación de archivo): %s agregado en %s dentro de un directorio "
+"que fue renombrado en %s, sugerimos que debería ser movido a %s."
 
-#: revision.c:2289
-msgid "your current branch appears to be broken"
-msgstr "tu rama actual parece estar rota"
+#: merge-recursive.c:3268
+#, c-format
+msgid ""
+"Path updated: %s renamed to %s in %s, inside a directory that was renamed in "
+"%s; moving it to %s."
+msgstr ""
+"Path actualizado: %s renombrado a %s en %s, dentro de un directorio que fue "
+"renombrado en %s; moviéndolo a %s."
 
-#: revision.c:2292
+#: merge-recursive.c:3271
 #, c-format
-msgid "your current branch '%s' does not have any commits yet"
-msgstr "tu rama actual '%s' no tiene ningún commit todavía"
+msgid ""
+"CONFLICT (file location): %s renamed to %s in %s, inside a directory that "
+"was renamed in %s, suggesting it should perhaps be moved to %s."
+msgstr ""
+"CONFLICTO (ubicación de archivo): %s renombrado a %s en %s, dentro de un "
+"directorio que fue renombrado en %s, sugiriendo que tal vez debería ser "
+"movido a %s."
 
-#: revision.c:2489
-msgid "--first-parent is incompatible with --bisect"
-msgstr "--first-parent es incompatible con --bisect"
+#: merge-recursive.c:3385
+#, c-format
+msgid "Removing %s"
+msgstr "Eliminando %s"
 
-#: run-command.c:728
-msgid "open /dev/null failed"
-msgstr "falló al abrir /dev/null"
+#: merge-recursive.c:3408
+msgid "file/directory"
+msgstr "archivo/directorio"
+
+#: merge-recursive.c:3413
+msgid "directory/file"
+msgstr "directorio/archivo"
 
-#: run-command.c:1271
+#: merge-recursive.c:3420
 #, c-format
-msgid ""
-"The '%s' hook was ignored because it's not set as executable.\n"
-"You can disable this warning with `git config advice.ignoredHook false`."
+msgid "CONFLICT (%s): There is a directory with name %s in %s. Adding %s as %s"
 msgstr ""
-"El hook '%s' fue ignorado porque no ha sido configurado como ejecutable.\n"
-"Puedes desactivar esta advertencias con `git config advice.ignoredHook "
-"false`."
+"CONFLICTO (%s): Hay un directorio con el nombre %s en %s. Agregando %s como "
+"%s"
 
-#: send-pack.c:141
-msgid "unexpected flush packet while reading remote unpack status"
-msgstr ""
-"flush packet inesperado mientras se leía estatus de desempaquetado remoto"
+#: merge-recursive.c:3429
+#, c-format
+msgid "Adding %s"
+msgstr "Agregando %s"
 
-#: send-pack.c:143
+#: merge-recursive.c:3438
 #, c-format
-msgid "unable to parse remote unpack status: %s"
-msgstr "no es posible analizar el estado de desempaquetado remoto: %s"
+msgid "CONFLICT (add/add): Merge conflict in %s"
+msgstr "CONFLICTO (add/add): Conflicto de merge en %s"
+
+#: merge-recursive.c:3482
+msgid "Already up to date!"
+msgstr "¡Ya está actualizado!"
 
-#: send-pack.c:145
+#: merge-recursive.c:3491
 #, c-format
-msgid "remote unpack failed: %s"
-msgstr "desempaquetado remoto falló: %s"
+msgid "merging of trees %s and %s failed"
+msgstr "falló la fusión de los árboles %s y %s"
 
-#: send-pack.c:308
-msgid "failed to sign the push certificate"
-msgstr "falló al firmar el certificado de push"
+#: merge-recursive.c:3595
+msgid "Merging:"
+msgstr "Fusionando:"
 
-#: send-pack.c:421
-msgid "the receiving end does not support --signed push"
-msgstr "el final receptor no soporta --signed push"
+#: merge-recursive.c:3608
+#, c-format
+msgid "found %u common ancestor:"
+msgid_plural "found %u common ancestors:"
+msgstr[0] "se encontró %u ancestro común:"
+msgstr[1] "se encontraron %u ancestros comunes:"
 
-#: send-pack.c:423
+#: merge-recursive.c:3658
+msgid "merge returned no commit"
+msgstr "la fusión no devolvió ningún commit"
+
+#: merge-recursive.c:3717
+#, c-format
 msgid ""
-"not sending a push certificate since the receiving end does not support --"
-"signed push"
+"Your local changes to the following files would be overwritten by merge:\n"
+"  %s"
 msgstr ""
-"no se manda un certificado de push ya que el destino no soporta push firmado "
-"(--signed )"
+"Los cambios locales de los siguientes archivos serán sobreescritos por "
+"merge:\n"
+"  %s"
 
-#: send-pack.c:435
-msgid "the receiving end does not support --atomic push"
-msgstr "el destino no soporta push atómicos (--atomic)"
+#: merge-recursive.c:3814
+#, c-format
+msgid "Could not parse object '%s'"
+msgstr "No se pudo analizar el objeto '%s'"
 
-#: send-pack.c:440
-msgid "the receiving end does not support push options"
-msgstr "el destino no soporta opciones de push"
+#: merge-recursive.c:3832 builtin/merge.c:694 builtin/merge.c:874
+msgid "Unable to write index."
+msgstr "Incapaz de escribir el índice."
 
-#: sequencer.c:175
+#: midx.c:68
 #, c-format
-msgid "invalid commit message cleanup mode '%s'"
-msgstr "mensaje de commit inválido, modo cleanup '%s'"
+msgid "multi-pack-index file %s is too small"
+msgstr "archivo multi-pack-index %s es muy pequeño"
 
-#: sequencer.c:275
+#: midx.c:84
 #, c-format
-msgid "could not delete '%s'"
-msgstr "no se pudo borrar '%s'"
+msgid "multi-pack-index signature 0x%08x does not match signature 0x%08x"
+msgstr "firma de multi-pack-index 0x%08x no concuerda con firma 0x%08x"
 
-#: sequencer.c:301
-msgid "revert"
-msgstr "revertir"
+#: midx.c:89
+#, c-format
+msgid "multi-pack-index version %d not recognized"
+msgstr "versión %d de multi-pack-index no reconocida"
 
-#: sequencer.c:303
-msgid "cherry-pick"
-msgstr "cherry-pick"
+#: midx.c:94
+#, c-format
+msgid "hash version %u does not match"
+msgstr "versión de hash %u no concuerda"
 
-#: sequencer.c:305
-msgid "rebase -i"
-msgstr "rebase -i"
+#: midx.c:108
+msgid "invalid chunk offset (too large)"
+msgstr "offset inválido del conjunto (muy grande)"
+
+#: midx.c:132
+msgid "terminating multi-pack-index chunk id appears earlier than expected"
+msgstr ""
+"terminando multi-pack-index porque el id del conjunto aparece antes de lo "
+"esperado"
+
+#: midx.c:145
+msgid "multi-pack-index missing required pack-name chunk"
+msgstr "multi-pack-index le falta el conjunto pack-name requerido"
+
+#: midx.c:147
+msgid "multi-pack-index missing required OID fanout chunk"
+msgstr "multi-pack-index le falta el conjunto OID fanout requerido"
+
+#: midx.c:149
+msgid "multi-pack-index missing required OID lookup chunk"
+msgstr "multi-pack-index le falta el conjunto OID fanout requerido"
+
+#: midx.c:151
+msgid "multi-pack-index missing required object offsets chunk"
+msgstr "multi-pack-index le falta el conjunto de offset del objeto requerido"
 
-#: sequencer.c:307
+#: midx.c:165
 #, c-format
-msgid "Unknown action: %d"
-msgstr "Acción desconocida: %d"
+msgid "multi-pack-index pack names out of order: '%s' before '%s'"
+msgstr "multi-pack-index nombres de paquete fuera de orden:'%s' antes '%s'"
 
-#: sequencer.c:364
-msgid ""
-"after resolving the conflicts, mark the corrected paths\n"
-"with 'git add <paths>' or 'git rm <paths>'"
-msgstr ""
-"después de resolver los conflictos, marca las rutas corregidas\n"
-"con 'git add <rutas>' o 'git rm <rutas>'"
+#: midx.c:210
+#, c-format
+msgid "bad pack-int-id: %u (%u total packs)"
+msgstr "mal pack-int-id: %u (%u paquetes totales)"
 
-#: sequencer.c:367
-msgid ""
-"after resolving the conflicts, mark the corrected paths\n"
-"with 'git add <paths>' or 'git rm <paths>'\n"
-"and commit the result with 'git commit'"
-msgstr ""
-"tras resolver los conflictos, marca las rutas corregidas\n"
-"con 'git add <rutas>' o 'git rm <rutas>'\n"
-"y haz un commit del resultado con 'git commit'"
+#: midx.c:260
+msgid "multi-pack-index stores a 64-bit offset, but off_t is too small"
+msgstr "multi-pack-index guarda un offset de 64-bit, pero off_t es muy pequeño"
+
+#: midx.c:288
+msgid "error preparing packfile from multi-pack-index"
+msgstr "error preparando packfile de multi-pack-index"
 
-#: sequencer.c:380 sequencer.c:2468
+#: midx.c:472
 #, c-format
-msgid "could not lock '%s'"
-msgstr "no se pudo bloquear '%s'"
+msgid "failed to add packfile '%s'"
+msgstr "falló al agregar packfile '%s'"
 
-#: sequencer.c:382 sequencer.c:2346 sequencer.c:2472 sequencer.c:2486
-#: sequencer.c:2694 sequencer.c:4336 sequencer.c:4399 wrapper.c:656
+#: midx.c:478
 #, c-format
-msgid "could not write to '%s'"
-msgstr "no se pudo escribir en '%s'"
+msgid "failed to open pack-index '%s'"
+msgstr "falló al abrir pack-index '%s'"
 
-#: sequencer.c:387
+#: midx.c:538
 #, c-format
-msgid "could not write eol to '%s'"
-msgstr "no se pudo escribir EOL en '%s'"
+msgid "failed to locate object %d in packfile"
+msgstr "falló al ubicar objeto %d en packfile"
+
+#: midx.c:842
+msgid "Adding packfiles to multi-pack-index"
+msgstr "Agregando packfiles a multi-pack-index"
 
-#: sequencer.c:392 sequencer.c:2351 sequencer.c:2474 sequencer.c:2488
-#: sequencer.c:2702
+#: midx.c:875
 #, c-format
-msgid "failed to finalize '%s'"
-msgstr "falló al finalizar '%s'"
+msgid "did not see pack-file %s to drop"
+msgstr "no se vió pack-file %s caer"
 
-#: sequencer.c:415 sequencer.c:804 sequencer.c:1493 sequencer.c:2371
-#: sequencer.c:2684 sequencer.c:2788 builtin/am.c:259 builtin/commit.c:727
-#: builtin/merge.c:1046
+#: midx.c:973
+msgid "Writing chunks to multi-pack-index"
+msgstr "Escribiendo chunks a multi-pack-index"
+
+#: midx.c:1052
 #, c-format
-msgid "could not read '%s'"
-msgstr "no se pudo leer '%s'"
+msgid "failed to clear multi-pack-index at %s"
+msgstr "falló al limpiar multi-pack-index en %s"
+
+#: midx.c:1108
+msgid "Looking for referenced packfiles"
+msgstr "Buscando por packfiles referidos"
 
-#: sequencer.c:441
+#: midx.c:1123
 #, c-format
-msgid "your local changes would be overwritten by %s."
-msgstr "tus cambios locales serán sobreescritos por %s."
+msgid ""
+"oid fanout out of order: fanout[%d] = %<PRIx32> > %<PRIx32> = fanout[%d]"
+msgstr ""
+"oid fanout fuera de orden: fanout[%d] = %<PRIx32> > %<PRIx32> = fanout[%d]"
 
-#: sequencer.c:445
-msgid "commit your changes or stash them to proceed."
-msgstr "realiza un commit con tus cambios o aplica un stash para proceder."
+#: midx.c:1128
+msgid "Verifying OID order in multi-pack-index"
+msgstr "Verificando orden de OID en multi-pack-index"
 
-#: sequencer.c:474
+#: midx.c:1137
 #, c-format
-msgid "%s: fast-forward"
-msgstr "%s: avance rápido"
+msgid "oid lookup out of order: oid[%d] = %s >= %s = oid[%d]"
+msgstr "oid lookup fuera de orden: oid[%d] = %s >= %s = oid[%d]"
 
-#. TRANSLATORS: %s will be "revert", "cherry-pick" or
-#. "rebase -i".
-#.
-#: sequencer.c:563
+#: midx.c:1157
+msgid "Sorting objects by packfile"
+msgstr "Ordenando objetos por packfile"
+
+#: midx.c:1164
+msgid "Verifying object offsets"
+msgstr "Verificando offsets de objetos"
+
+#: midx.c:1180
 #, c-format
-msgid "%s: Unable to write new index file"
-msgstr "%s: Incapaz de escribir el nuevo archivo índice"
+msgid "failed to load pack entry for oid[%d] = %s"
+msgstr "fallo al cargar entrada pack para oid[%d] = %s"
 
-#: sequencer.c:579
-msgid "unable to update cache tree"
-msgstr "no es posible actualizar el árbol de la caché"
+#: midx.c:1186
+#, c-format
+msgid "failed to load pack-index for packfile %s"
+msgstr "falló al cargar el pack-index para packfile %s"
 
-#: sequencer.c:592
-msgid "could not resolve HEAD commit"
-msgstr "no se pudo resolver el commit de HEAD"
+#: midx.c:1195
+#, c-format
+msgid "incorrect object offset for oid[%d] = %s: %<PRIx64> != %<PRIx64>"
+msgstr "offset para objeto incorrecto oid[%d] = %s: %<PRIx64> != %<PRIx64>"
+
+#: midx.c:1220
+msgid "Counting referenced objects"
+msgstr "Contando objetos no referenciados"
 
-#: sequencer.c:749
+#: midx.c:1230
+msgid "Finding and deleting unreferenced packfiles"
+msgstr "Encontrando y borrando packfiles sin referencias"
+
+#: midx.c:1388
+msgid "could not start pack-objects"
+msgstr "no se pudo empezar los pack-objetcts"
+
+#: midx.c:1407
+msgid "could not finish pack-objects"
+msgstr "no se pudo finalizar pack-objetcts"
+
+#: name-hash.c:537
 #, c-format
-msgid ""
-"you have staged changes in your working tree\n"
-"If these changes are meant to be squashed into the previous commit, run:\n"
-"\n"
-"  git commit --amend %s\n"
-"\n"
-"If they are meant to go into a new commit, run:\n"
-"\n"
-"  git commit %s\n"
-"\n"
-"In both cases, once you're done, continue with:\n"
-"\n"
-"  git rebase --continue\n"
-msgstr ""
-"se ha aplicado un stage a los cambios en el árbol de trabajo\n"
-"si estos cambios están destinados a ser aplastados en el commit previo, "
-"ejecuta:\n"
-"\n"
-"  git commit --amend %s\n"
-"\n"
-"Si estos cambios están destinados a un nuevo commit, ejecuta:\n"
-"\n"
-"  git commit %s\n"
-"\n"
-"en cambos casos, cuando acabes, continua con:\n"
-"\n"
-"  git rebase --continue\n"
+msgid "unable to create lazy_dir thread: %s"
+msgstr "no es posible crear hilo lazy_dir: %s"
 
-#: sequencer.c:818
-msgid "writing root commit"
-msgstr "escribiendo commit raíz"
-
-#: sequencer.c:1043
-msgid "'prepare-commit-msg' hook failed"
-msgstr "hook 'prepare-commit-msg' falló"
+#: name-hash.c:559
+#, c-format
+msgid "unable to create lazy_name thread: %s"
+msgstr "no es posible crear hilo lazy_name: %s"
 
-#: sequencer.c:1050
-msgid ""
-"Your name and email address were configured automatically based\n"
-"on your username and hostname. Please check that they are accurate.\n"
-"You can suppress this message by setting them explicitly. Run the\n"
-"following command and follow the instructions in your editor to edit\n"
-"your configuration file:\n"
-"\n"
-"    git config --global --edit\n"
-"\n"
-"After doing this, you may fix the identity used for this commit with:\n"
-"\n"
-"    git commit --amend --reset-author\n"
-msgstr ""
-"Tu nombre y correo fueron configurados automáticamente basados\n"
-"en tu usuario y nombre de host. Por favor verifica que son correctos.\n"
-"Tu puedes suprimir este mensaje configurándolos de forma explicita. Ejecuta "
-"el \n"
-"siguiente comando y sigue las instrucciones de tu editor\n"
-" para modificar tu archivo de configuración:\n"
-"\n"
-"    git config --global --edit\n"
-"\n"
-"Tras hacer esto, puedes arreglar la identidad usada para este commit con:\n"
-"\n"
-"    git commit --amend --reset-author\n"
+#: name-hash.c:565
+#, c-format
+msgid "unable to join lazy_name thread: %s"
+msgstr "no es posible unir hilo lazy_name: %s"
 
-#: sequencer.c:1063
+#: notes-merge.c:277
+#, c-format
 msgid ""
-"Your name and email address were configured automatically based\n"
-"on your username and hostname. Please check that they are accurate.\n"
-"You can suppress this message by setting them explicitly:\n"
-"\n"
-"    git config --global user.name \"Your Name\"\n"
-"    git config --global user.email you@example.com\n"
-"\n"
-"After doing this, you may fix the identity used for this commit with:\n"
-"\n"
-"    git commit --amend --reset-author\n"
+"You have not concluded your previous notes merge (%s exists).\n"
+"Please, use 'git notes merge --commit' or 'git notes merge --abort' to "
+"commit/abort the previous merge before you start a new notes merge."
 msgstr ""
-"Tu nombre y correo fueron configurados automáticamente basados\n"
-"en tu usuario y nombre de host. Por favor verifica que son correctos.\n"
-"Tu puedes suprimir este mensaje configurándolos de forma explicita: \n"
-"\n"
-"    git config --global user.name \"Tu nombre\"\n"
-"    git config --global user.email you@example.com\n"
-"\n"
-"Tras hacer esto, puedes arreglar tu identidad para este commit con:\n"
-"\n"
-"    git commit --amend --reset-author\n"
-
-#: sequencer.c:1103
-msgid "couldn't look up newly created commit"
-msgstr "no se pudo revisar el commit recién creado"
-
-#: sequencer.c:1105
-msgid "could not parse newly created commit"
-msgstr "no se pudo analizar el commit recién creado"
-
-#: sequencer.c:1151
-msgid "unable to resolve HEAD after creating commit"
-msgstr "no se pudo resolver HEAD tras crear el commit"
-
-#: sequencer.c:1153
-msgid "detached HEAD"
-msgstr "HEAD desacoplado"
-
-#: sequencer.c:1157
-msgid " (root-commit)"
-msgstr " (commit-raíz)"
-
-#: sequencer.c:1178
-msgid "could not parse HEAD"
-msgstr "no se pudo analizar HEAD"
+"No has concluido tus notas previas de fusión (%s existe).\n"
+"Por favor, usa 'git notes merge --commit' o 'git notes merge --abort' para "
+"confirmar/abortar la fusión previa antes de que puedas comenzar una nueva "
+"nota de fusión."
 
-#: sequencer.c:1180
+#: notes-merge.c:284
 #, c-format
-msgid "HEAD %s is not a commit!"
-msgstr "HEAD %s no es un commit!"
-
-#: sequencer.c:1184 builtin/commit.c:1528
-msgid "could not parse HEAD commit"
-msgstr "no se pudo analizar el commit de HEAD"
-
-#: sequencer.c:1235 sequencer.c:1832
-msgid "unable to parse commit author"
-msgstr "no es posible analizar el autor del commit"
+msgid "You have not concluded your notes merge (%s exists)."
+msgstr "No has terminado tus notas de fusión (%s existe)."
 
-#: sequencer.c:1245 builtin/am.c:1630 builtin/merge.c:645
-msgid "git write-tree failed to write a tree"
-msgstr "git write-tree falló al escribir el árbol"
+#: notes-utils.c:46
+msgid "Cannot commit uninitialized/unreferenced notes tree"
+msgstr ""
+"No se puede realizar commit, notas del árbol no inicializadas o no "
+"referenciadas"
 
-#: sequencer.c:1262 sequencer.c:1317
+#: notes-utils.c:105
 #, c-format
-msgid "unable to read commit message from '%s'"
-msgstr "no se puede leer el mensaje del commit de '%s'"
-
-#: sequencer.c:1284 builtin/am.c:1650 builtin/commit.c:1631 builtin/merge.c:825
-#: builtin/merge.c:850
-msgid "failed to write commit object"
-msgstr "falló al escribir el objeto commit"
+msgid "Bad notes.rewriteMode value: '%s'"
+msgstr "Valor erróneo para notes.rewriteMode: '%s'"
 
-#: sequencer.c:1344
+#: notes-utils.c:115
 #, c-format
-msgid "could not parse commit %s"
-msgstr "no se pudo analizar commit %s"
+msgid "Refusing to rewrite notes in %s (outside of refs/notes/)"
+msgstr "Rehusando reescribir notas en %s (fuera de refs/notes/)"
 
-#: sequencer.c:1349
+#. TRANSLATORS: The first %s is the name of
+#. the environment variable, the second %s is
+#. its value.
+#.
+#: notes-utils.c:145
 #, c-format
-msgid "could not parse parent commit %s"
-msgstr "no se pudo analizar el commit padre %s"
+msgid "Bad %s value: '%s'"
+msgstr "Valor erróneo para %s: '%s'"
 
-#: sequencer.c:1500 sequencer.c:1525
+#: object.c:53
 #, c-format
-msgid "This is a combination of %d commits."
-msgstr "Esta es una combinación de %d commits."
+msgid "invalid object type \"%s\""
+msgstr "tipo de objeto \"%s\" inválido"
 
-#: sequencer.c:1510 sequencer.c:4355
-msgid "need a HEAD to fixup"
-msgstr "se necesita un HEAD para arreglar"
+#: object.c:173
+#, c-format
+msgid "object %s is a %s, not a %s"
+msgstr "objeto %s es un %s, no un %s"
 
-#: sequencer.c:1512 sequencer.c:2729
-msgid "could not read HEAD"
-msgstr "no se pudo leer HEAD"
+#: object.c:233
+#, c-format
+msgid "object %s has unknown type id %d"
+msgstr "el objeto %s tiene un id de tipo desconocido %d"
 
-#: sequencer.c:1514
-msgid "could not read HEAD's commit message"
-msgstr "no se pudo leer el mensaje de commit de HEAD"
+#: object.c:246
+#, c-format
+msgid "unable to parse object: %s"
+msgstr "incapaz de analizar objeto: %s"
 
-#: sequencer.c:1520
+#: object.c:266 object.c:277
 #, c-format
-msgid "cannot write '%s'"
-msgstr "no se puede escribir '%s'"
+msgid "hash mismatch %s"
+msgstr "hash no concuerda %s"
 
-#: sequencer.c:1527 git-rebase--interactive.sh:457
-msgid "This is the 1st commit message:"
-msgstr "Este es el mensaje del 1er commit:"
+#: packfile.c:641
+msgid "offset before end of packfile (broken .idx?)"
+msgstr "offset antes del final del paquete (broken .idx?)"
 
-#: sequencer.c:1535
+#: packfile.c:1888
 #, c-format
-msgid "could not read commit message of %s"
-msgstr "no se puede leer el mensaje del commit de %s"
+msgid "offset before start of pack index for %s (corrupt index?)"
+msgstr ""
+"offset antes del comienzo del índice del paquete para %s (¿índice corrupto?)"
 
-#: sequencer.c:1542
+#: packfile.c:1892
 #, c-format
-msgid "This is the commit message #%d:"
-msgstr "Este es el mensaje del commit #%d:"
+msgid "offset beyond end of pack index for %s (truncated index?)"
+msgstr ""
+"offset más allá del índice de fin de paquete para %s (¿índice truncado?)"
 
-#: sequencer.c:1548
+#: parse-options.c:38
 #, c-format
-msgid "The commit message #%d will be skipped:"
-msgstr "El mensaje del commit #%d será saltado:"
+msgid "%s requires a value"
+msgstr "%s requiere un valor"
 
-#: sequencer.c:1553
+#: parse-options.c:73
 #, c-format
-msgid "unknown command: %d"
-msgstr "comando desconocido: %d"
-
-#: sequencer.c:1631
-msgid "your index file is unmerged."
-msgstr "tu archivo índice no esta fusionado."
+msgid "%s is incompatible with %s"
+msgstr "%s es incompatible con %s"
 
-#: sequencer.c:1638
-msgid "cannot fixup root commit"
-msgstr "no se puede arreglar el commit raíz"
+#: parse-options.c:78
+#, c-format
+msgid "%s : incompatible with something else"
+msgstr "%s : incompatible con otra cosa"
 
-#: sequencer.c:1657
+#: parse-options.c:92 parse-options.c:96 parse-options.c:319
 #, c-format
-msgid "commit %s is a merge but no -m option was given."
-msgstr "el commit %s es una fusión pero no se entrego la opción -m."
+msgid "%s takes no value"
+msgstr "%s no toma valores"
 
-#: sequencer.c:1665
+#: parse-options.c:94
 #, c-format
-msgid "commit %s does not have parent %d"
-msgstr "el commit %s no tiene un padre %d"
+msgid "%s isn't available"
+msgstr "%s no está disponible"
 
-#: sequencer.c:1669
+#: parse-options.c:219
 #, c-format
-msgid "mainline was specified but commit %s is not a merge."
-msgstr "línea principal especificada pero el commit %s no es una fusión."
+msgid "%s expects a non-negative integer value with an optional k/m/g suffix"
+msgstr "%s espera un valor entero no negativo con un sufijo opcional k/m/g"
 
-#: sequencer.c:1675
+#: parse-options.c:389
 #, c-format
-msgid "cannot get commit message for %s"
-msgstr "no se puede obtener el mensaje de commit para %s"
+msgid "ambiguous option: %s (could be --%s%s or --%s%s)"
+msgstr "opción ambigua: %s (puede ser --%s%s o --%s%s)"
 
-#. TRANSLATORS: The first %s will be a "todo" command like
-#. "revert" or "pick", the second %s a SHA1.
-#: sequencer.c:1694
+#: parse-options.c:423 parse-options.c:431
 #, c-format
-msgid "%s: cannot parse parent commit %s"
-msgstr "%s: no se puede analizar el commit padre %s"
+msgid "did you mean `--%s` (with two dashes ?)"
+msgstr "¿quisiste decir `--%s` (con dos guiones)?"
 
-#: sequencer.c:1759
+#: parse-options.c:860
 #, c-format
-msgid "could not rename '%s' to '%s'"
-msgstr "no se puede renombrar '%s' a '%s'"
+msgid "unknown option `%s'"
+msgstr "opción `%s' desconocida"
 
-#: sequencer.c:1813
+#: parse-options.c:862
 #, c-format
-msgid "could not revert %s... %s"
-msgstr "no se pudo revertir %s... %s"
+msgid "unknown switch `%c'"
+msgstr "switch desconocido `%c'"
 
-#: sequencer.c:1814
+#: parse-options.c:864
 #, c-format
-msgid "could not apply %s... %s"
-msgstr "no se pudo aplicar %s... %s"
+msgid "unknown non-ascii option in string: `%s'"
+msgstr "opción desconocida en string no ascii: `%s'"
 
-#: sequencer.c:1864
-msgid "empty commit set passed"
-msgstr "conjunto de commits vacío entregado"
+#: parse-options.c:888
+msgid "..."
+msgstr "..."
 
-#: sequencer.c:1874
+#: parse-options.c:907
 #, c-format
-msgid "git %s: failed to read the index"
-msgstr "git %s: falló al leer el índice"
+msgid "usage: %s"
+msgstr "uso: %s"
 
-#: sequencer.c:1881
+#. TRANSLATORS: the colon here should align with the
+#. one in "usage: %s" translation.
+#.
+#: parse-options.c:913
 #, c-format
-msgid "git %s: failed to refresh the index"
-msgstr "git %s: falló al refrescar el índice"
+msgid "   or: %s"
+msgstr "   o: %s"
 
-#: sequencer.c:1961
+#: parse-options.c:916
 #, c-format
-msgid "%s does not accept arguments: '%s'"
-msgstr "%s no acepta los argumentos: '%s'"
+msgid "    %s"
+msgstr "    %s"
 
-#: sequencer.c:1970
-#, c-format
-msgid "missing arguments for %s"
-msgstr "faltan argumentos para para %s"
+#: parse-options.c:955
+msgid "-NUM"
+msgstr "-NUM"
 
-#: sequencer.c:2029
+#: parse-options.c:969
 #, c-format
-msgid "invalid line %d: %.*s"
-msgstr "línea inválida %d: %.*s"
+msgid "alias of --%s"
+msgstr "alias de --%s"
 
-#: sequencer.c:2037
+#: parse-options-cb.c:20 parse-options-cb.c:24
 #, c-format
-msgid "cannot '%s' without a previous commit"
-msgstr "no se puede  '%s' sin un commit previo"
+msgid "option `%s' expects a numerical value"
+msgstr "opción `%s' espera un valor numérico"
 
-#: sequencer.c:2085 sequencer.c:4138 sequencer.c:4173
+#: parse-options-cb.c:41
 #, c-format
-msgid "could not read '%s'."
-msgstr "no se puede leer '%s'."
-
-#: sequencer.c:2108
-msgid "please fix this using 'git rebase --edit-todo'."
-msgstr "por favor arregle esto usando 'git rebase --edit-todo'."
+msgid "malformed expiration date '%s'"
+msgstr "fecha de expiración mal formada: '%s'"
 
-#: sequencer.c:2110
+#: parse-options-cb.c:54
 #, c-format
-msgid "unusable instruction sheet: '%s'"
-msgstr "hoja de instrucciones inutilizable: '%s'"
-
-#: sequencer.c:2115
-msgid "no commits parsed."
-msgstr "ningún commit analizado."
-
-#: sequencer.c:2126
-msgid "cannot cherry-pick during a revert."
-msgstr "no se puede realizar cherry-pick durante un revert."
-
-#: sequencer.c:2128
-msgid "cannot revert during a cherry-pick."
-msgstr "no se puede realizar un revert durante un cherry-pick."
+msgid "option `%s' expects \"always\", \"auto\", or \"never\""
+msgstr "opción `%s' puede usar \"always\", \"auto\", o \"never\""
 
-#: sequencer.c:2195
+#: parse-options-cb.c:130 parse-options-cb.c:147
 #, c-format
-msgid "invalid key: %s"
-msgstr "llave invalida: %s"
+msgid "malformed object name '%s'"
+msgstr "nombre de objeto mal formado '%s'"
 
-#: sequencer.c:2198
+#: path.c:915
 #, c-format
-msgid "invalid value for %s: %s"
-msgstr "valor invalido para %s: %s"
+msgid "Could not make %s writable by group"
+msgstr "No se pudo hacer que %s fuera escribible por el grupo"
 
-#: sequencer.c:2269
-msgid "unusable squash-onto"
-msgstr "squash-onto inservible"
+#: pathspec.c:130
+msgid "Escape character '\\' not allowed as last character in attr value"
+msgstr ""
+"Carácter de escape '\\' no permitido como último carácter en el valor attr"
 
-#: sequencer.c:2285
-#, c-format
-msgid "malformed options sheet: '%s'"
-msgstr "hoja de opciones mal formada: '%s'"
+#: pathspec.c:148
+msgid "Only one 'attr:' specification is allowed."
+msgstr "Solo una especificación 'attr' es permitida."
 
-#: sequencer.c:2323
-msgid "a cherry-pick or revert is already in progress"
-msgstr "un cherry-pick o revert ya esta en progreso"
-
-#: sequencer.c:2324
-msgid "try \"git cherry-pick (--continue | --quit | --abort)\""
-msgstr "intenta \"git cherry-pick (--continue | --quit | --abort)\""
+#: pathspec.c:151
+msgid "attr spec must not be empty"
+msgstr "especificación attr no puede estar vacía"
 
-#: sequencer.c:2327
+#: pathspec.c:194
 #, c-format
-msgid "could not create sequencer directory '%s'"
-msgstr "no se pudo crear un directorio secuenciador '%s'"
+msgid "invalid attribute name %s"
+msgstr "nombre de atributo %s inválido"
 
-#: sequencer.c:2341
-msgid "could not lock HEAD"
-msgstr "no se pudo bloquear HEAD"
+#: pathspec.c:259
+msgid "global 'glob' and 'noglob' pathspec settings are incompatible"
+msgstr ""
+"configuraciones globales de pathspec 'glob' y 'noglob' son incompatibles"
 
-#: sequencer.c:2396 sequencer.c:3403
-msgid "no cherry-pick or revert in progress"
-msgstr "ningún cherry-pick o revert en progreso"
+#: pathspec.c:266
+msgid ""
+"global 'literal' pathspec setting is incompatible with all other global "
+"pathspec settings"
+msgstr ""
+"la configuración global de 'literal' para patrones de ruta es incompatible "
+"con las demás configuraciones globales de patrones de ruta"
 
-#: sequencer.c:2398
-msgid "cannot resolve HEAD"
-msgstr "no se puede resolver HEAD"
+#: pathspec.c:306
+msgid "invalid parameter for pathspec magic 'prefix'"
+msgstr "parámetro no válido para el prefijo 'magic pathspec'"
 
-#: sequencer.c:2400 sequencer.c:2435
-msgid "cannot abort from a branch yet to be born"
-msgstr "no se puede abortar de una rama por nacer"
+#: pathspec.c:327
+#, c-format
+msgid "Invalid pathspec magic '%.*s' in '%s'"
+msgstr "Magic pathspec inválido '%.*s' en '%s'"
 
-#: sequencer.c:2421 builtin/grep.c:720
+#: pathspec.c:332
 #, c-format
-msgid "cannot open '%s'"
-msgstr "no se puede abrir '%s'"
+msgid "Missing ')' at the end of pathspec magic in '%s'"
+msgstr "Falta ')' al final del magic pathspec en '%s'"
 
-#: sequencer.c:2423
+#: pathspec.c:370
 #, c-format
-msgid "cannot read '%s': %s"
-msgstr "no se puede leer '%s': %s"
+msgid "Unimplemented pathspec magic '%c' in '%s'"
+msgstr "Magic pathspec '%c' no implementado en '%s'"
 
-#: sequencer.c:2424
-msgid "unexpected end of file"
-msgstr "final de archivo inesperado"
+#: pathspec.c:429
+#, c-format
+msgid "%s: 'literal' and 'glob' are incompatible"
+msgstr "%s: 'literal' y 'glob' son incompatibles"
 
-#: sequencer.c:2430
+#: pathspec.c:442
 #, c-format
-msgid "stored pre-cherry-pick HEAD file '%s' is corrupt"
-msgstr "archivo HEAD de pre-cherry-pick guardado '%s' esta corrupto"
+msgid "%s: '%s' is outside repository"
+msgstr "%s: '%s' está fuera del repositorio"
 
-#: sequencer.c:2441
-msgid "You seem to have moved HEAD. Not rewinding, check your HEAD!"
-msgstr "Parece que se ha movido HEAD. No se hace rebobinado, revise su HEAD!"
+#: pathspec.c:516
+#, c-format
+msgid "'%s' (mnemonic: '%c')"
+msgstr "'%s' (nemotécnico: '%c')"
 
-#: sequencer.c:2545 sequencer.c:3321
+#: pathspec.c:526
 #, c-format
-msgid "could not update %s"
-msgstr "no se puede actualizar %s"
+msgid "%s: pathspec magic not supported by this command: %s"
+msgstr "%s: magic pathspec no soportado por este comando: %s"
 
-#: sequencer.c:2583 sequencer.c:3301
-msgid "cannot read HEAD"
-msgstr "no se puede leer HEAD"
+#: pathspec.c:593
+#, c-format
+msgid "pathspec '%s' is beyond a symbolic link"
+msgstr "el patrón de ruta '%s' está detrás de un enlace simbólico"
 
-#: sequencer.c:2618 sequencer.c:2622 builtin/difftool.c:639
+#: pathspec.c:638
 #, c-format
-msgid "could not copy '%s' to '%s'"
-msgstr "no se pudo copiar '%s' a '%s'"
+msgid "line is badly quoted: %s"
+msgstr "la línea está mál citada: %s"
 
-#: sequencer.c:2641
-msgid "could not read index"
-msgstr "no se pudo leer índice"
+#: pkt-line.c:92
+msgid "unable to write flush packet"
+msgstr "no es posible escribir flush packet"
 
-#: sequencer.c:2646
-#, c-format
-msgid ""
-"execution failed: %s\n"
-"%sYou can fix the problem, and then run\n"
-"\n"
-"  git rebase --continue\n"
-"\n"
-msgstr ""
-"ejecución fallida: %s\n"
-"%sPuedes arreglar el problema, y luego ejecutar\n"
-"\n"
-"  git rebase --continue\n"
-"\n"
+#: pkt-line.c:99
+msgid "unable to write delim packet"
+msgstr "no es posible escribir delim packet"
 
-#: sequencer.c:2652
-msgid "and made changes to the index and/or the working tree\n"
-msgstr "y se hicieron cambios al índice y/o árbol de trabajo\n"
+#: pkt-line.c:106
+msgid "flush packet write failed"
+msgstr "limpieza de escritura de paquetes falló"
 
-#: sequencer.c:2658
-#, c-format
-msgid ""
-"execution succeeded: %s\n"
-"but left changes to the index and/or the working tree\n"
-"Commit or stash your changes, and then run\n"
-"\n"
-"  git rebase --continue\n"
-"\n"
-msgstr ""
-"ejecución exitosa: %s\n"
-"pero todavía quedan cambios para el índice o árbol de trabajo.\n"
-"Realiza un commit o stash con tus cambios, y luego ejecuta\n"
-"\n"
-"  git rebase --continue\n"
-"\n"
+#: pkt-line.c:146 pkt-line.c:232
+msgid "protocol error: impossibly long line"
+msgstr "error de protocolo: línea imposiblemente larga"
 
-#: sequencer.c:2771
-msgid "writing fake root commit"
-msgstr "escribiendo commit raíz falso"
+#: pkt-line.c:162 pkt-line.c:164
+msgid "packet write with format failed"
+msgstr "escritura de paquetes con formato falló"
 
-#: sequencer.c:2776
-msgid "writing squash-onto"
-msgstr "escribiendo squash-onto"
+#: pkt-line.c:196
+msgid "packet write failed - data exceeds max packet size"
+msgstr "fallo al escribir paquete - la data excede al tamaño máximo de paquete"
 
-#: sequencer.c:2811
-#, c-format
-msgid "failed to find tree of %s"
-msgstr "falló al encontrar árbol de %s"
+#: pkt-line.c:203 pkt-line.c:210
+msgid "packet write failed"
+msgstr "escritura de paquetes falló"
 
-#: sequencer.c:2829
-msgid "could not write index"
-msgstr "no se pudo escribir índice"
+#: pkt-line.c:295
+msgid "read error"
+msgstr "error de lectura"
 
-#: sequencer.c:2861
-msgid "cannot merge without a current revision"
-msgstr "no se puede fusionar sin una versión actual"
+#: pkt-line.c:303
+msgid "the remote end hung up unexpectedly"
+msgstr "el remoto se colgó de manera inesperada"
 
-#: sequencer.c:2884
+#: pkt-line.c:331
 #, c-format
-msgid "could not resolve '%s'"
-msgstr "no se pudo resolver '%s'"
+msgid "protocol error: bad line length character: %.4s"
+msgstr "error de protocolo: mal caracter de largo de línea: %.4s"
 
-#: sequencer.c:2906
+#: pkt-line.c:341 pkt-line.c:346
 #, c-format
-msgid "could not get commit message of '%s'"
-msgstr "no se puede leer el mensaje del commit '%s'"
+msgid "protocol error: bad line length %d"
+msgstr "error de protocolo: mal largo de línea %d"
 
-#: sequencer.c:2916 sequencer.c:2941
+#: pkt-line.c:362
 #, c-format
-msgid "could not write '%s'"
-msgstr "no se pudo escribir '%s'"
+msgid "remote error: %s"
+msgstr "error remoto: %s"
 
-#: sequencer.c:3005
+#: preload-index.c:119
+msgid "Refreshing index"
+msgstr "Refrescando index"
+
+#: preload-index.c:138
 #, c-format
-msgid "could not even attempt to merge '%.*s'"
-msgstr "no se pudo intentar fusionar '%.*s'"
+msgid "unable to create threaded lstat: %s"
+msgstr "no es posible crear lstat hilado: %s"
 
-#: sequencer.c:3021
-msgid "merge: Unable to write new index file"
-msgstr "fusión: No se puede escribir el nuevo archivo índice"
+#: pretty.c:981
+msgid "unable to parse --pretty format"
+msgstr "incapaz de analizar el formato --pretty"
 
-#: sequencer.c:3088
-#, c-format
-msgid "Applied autostash.\n"
-msgstr "Autostash aplicado.\n"
+#: promisor-remote.c:23
+msgid "Remote with no URL"
+msgstr "Remoto sin URL"
 
-#: sequencer.c:3100
+#: promisor-remote.c:58
 #, c-format
-msgid "cannot store %s"
-msgstr "no se puede guardar %s"
+msgid "promisor remote name cannot begin with '/': %s"
+msgstr "nombre remoto promisor no puede comenzar con '/': %s"
+
+#: range-diff.c:75
+msgid "could not start `log`"
+msgstr "no se pudo comenzar `log`"
+
+#: range-diff.c:77
+msgid "could not read `log` output"
+msgstr "no se pudo leer output de `log`"
 
-#: sequencer.c:3103 git-rebase.sh:188
+#: range-diff.c:96 sequencer.c:5163
 #, c-format
-msgid ""
-"Applying autostash resulted in conflicts.\n"
-"Your changes are safe in the stash.\n"
-"You can run \"git stash pop\" or \"git stash drop\" at any time.\n"
-msgstr ""
-"Aplicando autostash resultó en conflictos.\n"
-"Tus cambios están seguros en el stash.\n"
-"Puedes ejecutar \"git stash pop\" o \"git stash drop\" en cualquier "
-"momento.\n"
+msgid "could not parse commit '%s'"
+msgstr "no se pudo analizar commit '%s'"
 
-#: sequencer.c:3134
+#: range-diff.c:122
 #, c-format
-msgid ""
-"Could not execute the todo command\n"
-"\n"
-"    %.*s\n"
-"It has been rescheduled; To edit the command before continuing, please\n"
-"edit the todo list first:\n"
-"\n"
-"    git rebase --edit-todo\n"
-"    git rebase --continue\n"
-msgstr ""
-"No se pudo ejecutar el comando \"todo\"\n"
-"\n"
-"    %.*s\n"
-"Ha sido reprogramado; Para editar el comando antes de continuar, por favor\n"
-"edite la lista de \"todo\" primero:\n"
-"\n"
-"    git rebase --edit-todo\n"
-"    git rebase --continue\n"
+msgid "could not parse git header '%.*s'"
+msgstr "no se puede analizar git header '%.*s'"
+
+#: range-diff.c:285
+msgid "failed to generate diff"
+msgstr "falló al generar diff"
 
-#: sequencer.c:3202
+#: range-diff.c:518 range-diff.c:520
 #, c-format
-msgid "Stopped at %s...  %.*s\n"
-msgstr "Detenido en %s...  %.*s\n"
+msgid "could not parse log for '%s'"
+msgstr "no se pudo leer el log para '%s'"
 
-#: sequencer.c:3264
+#: read-cache.c:680
 #, c-format
-msgid "unknown command %d"
-msgstr "comando desconocido %d"
+msgid "will not add file alias '%s' ('%s' already exists in index)"
+msgstr "no agregará alias de archivo '%s' ('%s' ya existe en el index)"
 
-#: sequencer.c:3309
-msgid "could not read orig-head"
-msgstr "no se puede leer orig-head"
+#: read-cache.c:696
+msgid "cannot create an empty blob in the object database"
+msgstr "no se puede crear un blob vacío en la base de datos de objetos"
 
-#: sequencer.c:3314 sequencer.c:4352
-msgid "could not read 'onto'"
-msgstr "no se puede leer 'onto'"
+#: read-cache.c:718
+#, c-format
+msgid "%s: can only add regular files, symbolic links or git-directories"
+msgstr ""
+"%s: solo puede agregar archivos regulares, symbolic links o git-directories"
 
-#: sequencer.c:3328
+#: read-cache.c:723
 #, c-format
-msgid "could not update HEAD to %s"
-msgstr "no se puede actualizar HEAD a %s"
+msgid "'%s' does not have a commit checked out"
+msgstr "'%s' no tiene un commit checked out"
 
-#: sequencer.c:3414
-msgid "cannot rebase: You have unstaged changes."
-msgstr "no se puede realizar rebase: Tienes cambios fuera del área de stage."
+#: read-cache.c:775
+#, c-format
+msgid "unable to index file '%s'"
+msgstr "no es posible indexar archivo '%s'"
 
-#: sequencer.c:3423
-msgid "cannot amend non-existing commit"
-msgstr "no se puede arreglar un commit no existente"
+#: read-cache.c:794
+#, c-format
+msgid "unable to add '%s' to index"
+msgstr "no es posible agregar '%s' al index"
 
-#: sequencer.c:3425
+#: read-cache.c:805
 #, c-format
-msgid "invalid file: '%s'"
-msgstr "archivo invalido: '%s'"
+msgid "unable to stat '%s'"
+msgstr "incapaz de correr stat en '%s'"
 
-#: sequencer.c:3427
+#: read-cache.c:1325
 #, c-format
-msgid "invalid contents: '%s'"
-msgstr "contenido inválido: '%s'"
+msgid "'%s' appears as both a file and as a directory"
+msgstr "'%s' parece ser un directorio y un archivo a la vez"
+
+#: read-cache.c:1531
+msgid "Refresh index"
+msgstr "Refrescar index"
 
-#: sequencer.c:3430
+#: read-cache.c:1646
+#, c-format
 msgid ""
-"\n"
-"You have uncommitted changes in your working tree. Please, commit them\n"
-"first and then run 'git rebase --continue' again."
+"index.version set, but the value is invalid.\n"
+"Using version %i"
 msgstr ""
-"\n"
-"Tienes cambios fuera de un commit en tu árbol de trabajo. Por favor, realiza "
-"un commit con estos\n"
-"primero y luego ejecuta 'git rebase --continue' de nuevo."
+"index.version configurado, pero el valor no es válido.\n"
+"Usando versión %i"
 
-#: sequencer.c:3455 sequencer.c:3493
+#: read-cache.c:1656
 #, c-format
-msgid "could not write file: '%s'"
-msgstr "no se pudo escribir el archivo: '%s'"
+msgid ""
+"GIT_INDEX_VERSION set, but the value is invalid.\n"
+"Using version %i"
+msgstr ""
+"GIT_INDEX_VERSION configurado, pero el valor no es válido.\n"
+"Usando versión %i"
 
-#: sequencer.c:3508
-msgid "could not remove CHERRY_PICK_HEAD"
-msgstr "no se puede remover CHERRY_PICK_HEAD"
+#: read-cache.c:1712
+#, c-format
+msgid "bad signature 0x%08x"
+msgstr "mala firma 0x%08x"
 
-#: sequencer.c:3515
-msgid "could not commit staged changes."
-msgstr "no se pudo realizar el commit con los cambios en el área de stage."
+#: read-cache.c:1715
+#, c-format
+msgid "bad index version %d"
+msgstr "mala versión del índice %d"
+
+#: read-cache.c:1724
+msgid "bad index file sha1 signature"
+msgstr "mala firma sha1 del archivo index"
 
-#: sequencer.c:3612
+#: read-cache.c:1754
 #, c-format
-msgid "%s: can't cherry-pick a %s"
-msgstr "%s: no se puede aplicar cherry-pick a un %s"
+msgid "index uses %.4s extension, which we do not understand"
+msgstr "index usa %.4s extensiones, cosa que no entendemos"
 
-#: sequencer.c:3616
+#: read-cache.c:1756
 #, c-format
-msgid "%s: bad revision"
-msgstr "%s: mala revision"
+msgid "ignoring %.4s extension"
+msgstr "ignorando extensión %.4s"
 
-#: sequencer.c:3649
-msgid "can't revert as initial commit"
-msgstr "no se puede revertir como commit inicial"
+#: read-cache.c:1793
+#, c-format
+msgid "unknown index entry format 0x%08x"
+msgstr "formato de index desconocido 0x%08x"
 
-#: sequencer.c:4098
-msgid "make_script: unhandled options"
-msgstr "make_script: opciones desconocidas"
+#: read-cache.c:1809
+#, c-format
+msgid "malformed name field in the index, near path '%s'"
+msgstr "campo nombre malformado en el index, cerca a ruta '%s'"
 
-#: sequencer.c:4101
-msgid "make_script: error preparing revisions"
-msgstr "make_script: error preparando revisiones"
+#: read-cache.c:1866
+msgid "unordered stage entries in index"
+msgstr "entradas en stage desordenadas en index"
 
-#: sequencer.c:4142 sequencer.c:4177
+#: read-cache.c:1869
 #, c-format
-msgid "unusable todo list: '%s'"
-msgstr "lista de pendientes inutilizable: '%s'"
+msgid "multiple stage entries for merged file '%s'"
+msgstr "múltiples entradas extrañas para archivo fusionado '%s'"
 
-#: sequencer.c:4236
+#: read-cache.c:1872
 #, c-format
-msgid ""
-"unrecognized setting %s for option rebase.missingCommitsCheck. Ignoring."
-msgstr ""
-"opción %s no reconocida para la opción rebase.missingCommitsCheck. Ignorando."
+msgid "unordered stage entries for '%s'"
+msgstr "entradas de stage desordenadas para '%s'"
+
+#: read-cache.c:1978 read-cache.c:2266 rerere.c:565 rerere.c:599 rerere.c:1111
+#: builtin/add.c:499 builtin/check-ignore.c:178 builtin/checkout.c:470
+#: builtin/checkout.c:654 builtin/clean.c:967 builtin/commit.c:367
+#: builtin/diff-tree.c:120 builtin/grep.c:499 builtin/mv.c:145
+#: builtin/reset.c:246 builtin/rm.c:271 builtin/submodule--helper.c:332
+msgid "index file corrupt"
+msgstr "archivo índice corrompido"
 
-#: sequencer.c:4302
+#: read-cache.c:2119
 #, c-format
-msgid ""
-"Warning: some commits may have been dropped accidentally.\n"
-"Dropped commits (newer to older):\n"
-msgstr ""
-"Peligro: algunos commits pueden haber sido botados de forma accidental.\n"
-"Commits botados (empezando con el mas nuevo):\n"
+msgid "unable to create load_cache_entries thread: %s"
+msgstr "no es posible crear hilo load_cache_entries: %s"
 
-#: sequencer.c:4309
+#: read-cache.c:2132
 #, c-format
-msgid ""
-"To avoid this message, use \"drop\" to explicitly remove a commit.\n"
-"\n"
-"Use 'git config rebase.missingCommitsCheck' to change the level of "
-"warnings.\n"
-"The possible behaviours are: ignore, warn, error.\n"
-"\n"
-msgstr ""
-"Para evitar este mensaje, use \"drop\" para remover de forma explícita un "
-"commit.\n"
-"\n"
-"Use 'git config rebase.missingCommitsCheck' para cambiar el nivel de "
-"advertencias.\n"
-"Los posibles comportamientos son: ignore,warn,error.\n"
-"\n"
+msgid "unable to join load_cache_entries thread: %s"
+msgstr "no es posible unir hilo load_cache_entires: %s"
 
-#: sequencer.c:4321
+#: read-cache.c:2165
 #, c-format
-msgid ""
-"You can fix this with 'git rebase --edit-todo' and then run 'git rebase --"
-"continue'.\n"
-"Or you can abort the rebase with 'git rebase --abort'.\n"
-msgstr ""
-"Se puede arreglar esto con 'git rebase --edit-todo' y después ejecutar 'git "
-"rebase --continue'.\n"
-"O se puede abortar el rebase con 'git rebase --abort'.\n"
+msgid "%s: index file open failed"
+msgstr "%s: falló al abrir el archivo index"
 
-#: sequencer.c:4375
+#: read-cache.c:2169
 #, c-format
-msgid "could not parse commit '%s'"
-msgstr "no se pudo analizar commit '%s'"
+msgid "%s: cannot stat the open index"
+msgstr "%s: no se puede hacer stat del index abierto"
 
-#: sequencer.c:4490
-msgid "the script was already rearranged."
-msgstr "este script ya fue reorganizado."
+#: read-cache.c:2173
+#, c-format
+msgid "%s: index file smaller than expected"
+msgstr "%s: archivo index más pequeño de lo esperado"
 
-#: setup.c:123
+#: read-cache.c:2177
 #, c-format
-msgid "'%s' is outside repository"
-msgstr "'%s' está fuera del repositorio"
+msgid "%s: unable to map index file"
+msgstr "%s: no se pudo mapear el archivo index"
 
-#: setup.c:172
+#: read-cache.c:2219
 #, c-format
-msgid ""
-"%s: no such path in the working tree.\n"
-"Use 'git <command> -- <path>...' to specify paths that do not exist locally."
-msgstr ""
-"%s: no existe la ruta en el árbol de trabajo.\n"
-"Use 'git <comando> -- <ruta>...' para especificar rutas que no existen "
-"localmente."
+msgid "unable to create load_index_extensions thread: %s"
+msgstr "no es posible crear hilo load_index_extensions: %s"
 
-#: setup.c:185
+#: read-cache.c:2246
 #, c-format
-msgid ""
-"ambiguous argument '%s': unknown revision or path not in the working tree.\n"
-"Use '--' to separate paths from revisions, like this:\n"
-"'git <command> [<revision>...] -- [<file>...]'"
-msgstr ""
-"argumento ambiguo '%s': revisión desconocida o ruta fuera del árbol de "
-"trabajo.\n"
-"Use '--' para separar las rutas de las revisiones, de esta manera:\n"
-"'git <comando> [<revisión>...] -- [<archivo>...]'"
+msgid "unable to join load_index_extensions thread: %s"
+msgstr "no es posible unir hilo load_index_extensions: %s"
 
-#: setup.c:234
+#: read-cache.c:2278
 #, c-format
-msgid "option '%s' must come before non-option arguments"
-msgstr "opción '%s' debe venir antes de argumentos no opcionales"
+msgid "could not freshen shared index '%s'"
+msgstr "no se pudo refrescar el index compartido '%s'"
 
-#: setup.c:253
+#: read-cache.c:2325
 #, c-format
-msgid ""
-"ambiguous argument '%s': both revision and filename\n"
-"Use '--' to separate paths from revisions, like this:\n"
-"'git <command> [<revision>...] -- [<file>...]'"
-msgstr ""
-"argumento ambiguo '%s': ambos revisión y nombre de archivo\n"
-"Use '--' para separar rutas de revisiones, de esta manera:\n"
-"'git <comando> [<revisión>...] -- [<archivo>...]'"
-
-#: setup.c:389
-msgid "unable to set up work tree using invalid config"
-msgstr ""
-"no es posible configurar el directorio de trabajo usando una configuración "
-"inválida"
-
-#: setup.c:393
-msgid "this operation must be run in a work tree"
-msgstr "esta operación debe ser realizada en un árbol de trabajo"
+msgid "broken index, expect %s in %s, got %s"
+msgstr "index roto, se esperaba %s en %s, se obtuvo %s"
 
-#: setup.c:503
+#: read-cache.c:3021 strbuf.c:1145 wrapper.c:622 builtin/merge.c:1119
 #, c-format
-msgid "Expected git repo version <= %d, found %d"
-msgstr "Se esperaba versión de git repo  <= %d, encontrada %d"
-
-#: setup.c:511
-msgid "unknown repository extensions found:"
-msgstr "se encontró extensión de repositorio desconocida:"
+msgid "could not close '%s'"
+msgstr "no se pudo cerrar '%s'"
 
-#: setup.c:530
+#: read-cache.c:3124 sequencer.c:2429 sequencer.c:4069
 #, c-format
-msgid "error opening '%s'"
-msgstr "error abriendo '%s'"
+msgid "could not stat '%s'"
+msgstr "no se pudo definir '%s'"
 
-#: setup.c:532
+#: read-cache.c:3137
 #, c-format
-msgid "too large to be a .git file: '%s'"
-msgstr "muy grande para ser un archivo .git: '%s'"
+msgid "unable to open git dir: %s"
+msgstr "no es posible abrir el directorio de git: %s"
 
-#: setup.c:534
+#: read-cache.c:3149
 #, c-format
-msgid "error reading %s"
-msgstr "error leyendo %s"
+msgid "unable to unlink: %s"
+msgstr "no es posible eliminar el vinculo: %s"
 
-#: setup.c:536
+#: read-cache.c:3174
 #, c-format
-msgid "invalid gitfile format: %s"
-msgstr "formato gitfile inválido: %s"
+msgid "cannot fix permission bits on '%s'"
+msgstr "no se pudo arreglar bits de permisos en '%s'"
 
-#: setup.c:538
+#: read-cache.c:3323
 #, c-format
-msgid "no path in gitfile: %s"
-msgstr "no hay ruta en gitfile: %s"
+msgid "%s: cannot drop to stage #0"
+msgstr "%s: no se puede eliminar a stage #0"
 
-#: setup.c:540
+#: rebase-interactive.c:26
 #, c-format
-msgid "not a git repository: %s"
-msgstr "no es un repositorio git: %s"
+msgid ""
+"unrecognized setting %s for option rebase.missingCommitsCheck. Ignoring."
+msgstr ""
+"opción %s no reconocida para la opción rebase.missingCommitsCheck. Ignorando."
 
-#: setup.c:639
-#, c-format
-msgid "'$%s' too big"
-msgstr "'$%s' muy grande"
+#: rebase-interactive.c:35
+msgid ""
+"\n"
+"Commands:\n"
+"p, pick <commit> = use commit\n"
+"r, reword <commit> = use commit, but edit the commit message\n"
+"e, edit <commit> = use commit, but stop for amending\n"
+"s, squash <commit> = use commit, but meld into previous commit\n"
+"f, fixup <commit> = like \"squash\", but discard this commit's log message\n"
+"x, exec <command> = run command (the rest of the line) using shell\n"
+"b, break = stop here (continue rebase later with 'git rebase --continue')\n"
+"d, drop <commit> = remove commit\n"
+"l, label <label> = label current HEAD with a name\n"
+"t, reset <label> = reset HEAD to a label\n"
+"m, merge [-C <commit> | -c <commit>] <label> [# <oneline>]\n"
+".       create a merge commit using the original merge commit's\n"
+".       message (or the oneline, if no original merge commit was\n"
+".       specified). Use -c <commit> to reword the commit message.\n"
+"\n"
+"These lines can be re-ordered; they are executed from top to bottom.\n"
+msgstr ""
+"\n"
+"Comandos:\n"
+"p, pick <commit> = usar commit\n"
+"r, reword <commit> = usar commit, pero editar el mensaje de commit\n"
+"e, edit <commit> = usar commit, pero parar para un amend\n"
+"s, squash <commit> = usar commit, pero fusionarlo en el commit previo\n"
+"f, fixup <commit> = como \"squash\", pero descarta el mensaje del log de "
+"este commit\n"
+"x, exec <commit> = ejecuta comando ( el resto de la línea) usando un shell\n"
+"b, break = parar aquí (continuar rebase luego con 'git rebase --continue')\n"
+"d, drop <commit> = eliminar commit\n"
+"l, label <label> = poner label al HEAD actual con un nombre\n"
+"t, reset <label> = reiniciar HEAD a el label\n"
+"m, merge [-C <commit> | -c <commit>] <label> [# <oneline>]\n"
+".       crea un commit de fusión usando el mensaje original de\n"
+".       fusión (o la línea de oneline, si no se especifica un mensaje\n"
+".       de commit). Use -c <commit> para reescribir el mensaje del commit.\n"
+"\n"
+"Estas líneas pueden ser reordenadas; son ejecutadas desde arriba hacia "
+"abajo.\n"
 
-#: setup.c:653
+#: rebase-interactive.c:56
 #, c-format
-msgid "not a git repository: '%s'"
-msgstr "no es un repositorio git: '%s'"
+msgid "Rebase %s onto %s (%d command)"
+msgid_plural "Rebase %s onto %s (%d commands)"
+msgstr[0] "Rebase %s en %s (%d comando)"
+msgstr[1] "Rebase %s en %s (%d comandos)"
 
-#: setup.c:682 setup.c:684 setup.c:715
-#, c-format
-msgid "cannot chdir to '%s'"
-msgstr "no se puede aplicar chdir a '%s'"
+#: rebase-interactive.c:65 git-rebase--preserve-merges.sh:228
+msgid ""
+"\n"
+"Do not remove any line. Use 'drop' explicitly to remove a commit.\n"
+msgstr ""
+"\n"
+"No eliminar ninguna línea. Usa 'drop' explícitamente para borrar un commit \n"
 
-#: setup.c:687 setup.c:743 setup.c:753 setup.c:792 setup.c:800 setup.c:815
-msgid "cannot come back to cwd"
-msgstr "no se puede volver a cwd"
+#: rebase-interactive.c:68 git-rebase--preserve-merges.sh:232
+msgid ""
+"\n"
+"If you remove a line here THAT COMMIT WILL BE LOST.\n"
+msgstr ""
+"\n"
+"Si eliminas una línea aquí EL COMMIT SE PERDERÁ.\n"
 
-#: setup.c:813
-#, c-format
-msgid "not a git repository (or any of the parent directories): %s"
+#: rebase-interactive.c:74 git-rebase--preserve-merges.sh:871
+msgid ""
+"\n"
+"You are editing the todo file of an ongoing interactive rebase.\n"
+"To continue rebase after editing, run:\n"
+"    git rebase --continue\n"
+"\n"
 msgstr ""
-"no es un repositorio git (ni ninguno de los directorios superiores): %s"
+"\n"
+"Estás editando el archivo TODO de un rebase interactivo.\n"
+"Para continuar el rebase después de editar, ejecuta:\n"
+"    git rebase --continue\n"
+"\n"
 
-#: setup.c:824
-#, c-format
-msgid "failed to stat '%*s%s%s'"
-msgstr "falló al determinar '%*s%s%s'"
+#: rebase-interactive.c:79 git-rebase--preserve-merges.sh:948
+msgid ""
+"\n"
+"However, if you remove everything, the rebase will be aborted.\n"
+"\n"
+msgstr ""
+"\n"
+"Como sea, si quieres borrar todo, el rebase será abortado.\n"
+"\n"
 
-#: setup.c:1054
-msgid "Unable to read current working directory"
-msgstr "Incapaz de leer el directorio de trabajo actual"
+#: rebase-interactive.c:85 git-rebase--preserve-merges.sh:955
+msgid "Note that empty commits are commented out"
+msgstr "Tenga en cuenta que los commits vacíos están comentados"
 
-#: setup.c:1066 setup.c:1072
+#: rebase-interactive.c:105 rerere.c:485 rerere.c:692 sequencer.c:3536
+#: sequencer.c:3562 sequencer.c:5263 builtin/fsck.c:346 builtin/rebase.c:254
 #, c-format
-msgid "cannot change to '%s'"
-msgstr "no se puede cambiar a '%s'"
+msgid "could not write '%s'"
+msgstr "no se pudo escribir '%s'"
 
-#: setup.c:1085
+#: rebase-interactive.c:108
+#, c-format
+msgid "could not copy '%s' to '%s'."
+msgstr "no se pudo copiar '%s' a '%s'."
+
+#: rebase-interactive.c:173
 #, c-format
 msgid ""
-"not a git repository (or any parent up to mount point %s)\n"
-"Stopping at filesystem boundary (GIT_DISCOVERY_ACROSS_FILESYSTEM not set)."
+"Warning: some commits may have been dropped accidentally.\n"
+"Dropped commits (newer to older):\n"
 msgstr ""
-"no es un repositorio git ( o ningún padre en el punto de montado %s)\n"
-"Parando en el límite del sistema de archivos "
-"(GIT_DISCOVERY_ACROSS_FILESYSTEM no establecido)."
+"Peligro: algunos commits pueden haber sido botados de forma accidental.\n"
+"Commits botados (empezando con el más nuevo):\n"
 
-#: setup.c:1168
+#: rebase-interactive.c:180
 #, c-format
 msgid ""
-"problem with core.sharedRepository filemode value (0%.3o).\n"
-"The owner of files must always have read and write permissions."
+"To avoid this message, use \"drop\" to explicitly remove a commit.\n"
+"\n"
+"Use 'git config rebase.missingCommitsCheck' to change the level of "
+"warnings.\n"
+"The possible behaviours are: ignore, warn, error.\n"
+"\n"
 msgstr ""
-"problema con el valor del modo de archivo core.sharedRepository (0%.3o).\n"
-"El dueño de los archivos tiene que tener permisos de lectura y escritura."
-
-#: setup.c:1211
-msgid "open /dev/null or dup failed"
-msgstr "falló al abrir /dev/null o dup"
-
-#: setup.c:1226
-msgid "fork failed"
-msgstr "falló fork"
-
-#: setup.c:1231
-msgid "setsid failed"
-msgstr "falló setsid"
+"Para evitar este mensaje, use \"drop\" para eliminar de forma explícita un "
+"commit.\n"
+"\n"
+"Use 'git config rebase.missingCommitsCheck' para cambiar el nivel de "
+"advertencias.\n"
+"Los posibles comportamientos son: ignore,warn,error.\n"
+"\n"
 
-#: sha1-file.c:625
+#: refs.c:262
 #, c-format
-msgid "path '%s' does not exist"
-msgstr "ruta '%s' no existe"
+msgid "%s does not point to a valid object!"
+msgstr "¡%s no apunta a ningún objeto válido!"
 
-#: sha1-file.c:651
+#: refs.c:667
 #, c-format
-msgid "reference repository '%s' as a linked checkout is not supported yet."
-msgstr ""
-"repositorio de referencia '%s' como un checkout vinculado no es soportado "
-"todavía."
+msgid "ignoring dangling symref %s"
+msgstr "ignorando referencia rota %s"
 
-#: sha1-file.c:657
+#: refs.c:669 ref-filter.c:2098
 #, c-format
-msgid "reference repository '%s' is not a local repository."
-msgstr "repositorio de referencia '%s' no es un repositorio local."
+msgid "ignoring broken ref %s"
+msgstr "ignorando referencia rota %s"
 
-#: sha1-file.c:663
+#: refs.c:804
 #, c-format
-msgid "reference repository '%s' is shallow"
-msgstr "repositorio de referencia '%s' es superficial (shallow)"
+msgid "could not open '%s' for writing: %s"
+msgstr "no se pudo abrir '%s' para escritura: %s"
 
-#: sha1-file.c:671
+#: refs.c:814 refs.c:865
 #, c-format
-msgid "reference repository '%s' is grafted"
-msgstr "repositorio de referencia '% s' está injertado"
+msgid "could not read ref '%s'"
+msgstr "no se pudo leer la referencia '%s'"
 
-#: sha1-name.c:442
+#: refs.c:820
 #, c-format
-msgid "short SHA1 %s is ambiguous"
-msgstr "SHA1 %s corto es ambiguao"
+msgid "ref '%s' already exists"
+msgstr "ref '%s' ya existe"
 
-#: sha1-name.c:453
-msgid "The candidates are:"
-msgstr "Los candidatos son:"
+#: refs.c:825
+#, c-format
+msgid "unexpected object ID when writing '%s'"
+msgstr "ID de objecto inesperado al escribir '%s'"
 
-#: sha1-name.c:695
-msgid ""
-"Git normally never creates a ref that ends with 40 hex characters\n"
-"because it will be ignored when you just specify 40-hex. These refs\n"
-"may be created by mistake. For example,\n"
-"\n"
-"  git checkout -b $br $(git rev-parse ...)\n"
-"\n"
-"where \"$br\" is somehow empty and a 40-hex ref is created. Please\n"
-"examine these refs and maybe delete them. Turn this message off by\n"
-"running \"git config advice.objectNameWarning false\""
-msgstr ""
-"Git normalmente nunca crea una ref que termine con 40 caracteres hex\n"
-"porque esto sería ignorado cuando solo se especifiquen 40-hex. Estas refs\n"
-"tal vez sean creadas por error. Por ejemplo,\n"
-"\n"
-"  git checkout -b $br $(git rev-parse ...)\n"
-"\n"
-"donde \"$br\" está de alguna manera vacía y una ref de 40-hex es creada. Por "
-"favor\n"
-"examine estas refs y tal vez bórrelas. Silencie este mensaje \n"
-"ejecutando \"git config advice.objectNameWarning false\""
+#: refs.c:833 sequencer.c:405 sequencer.c:2793 sequencer.c:2997
+#: sequencer.c:3011 sequencer.c:3269 sequencer.c:5179 strbuf.c:1142
+#: wrapper.c:620
+#, c-format
+msgid "could not write to '%s'"
+msgstr "no se pudo escribir en '%s'"
 
-#: submodule.c:97 submodule.c:131
-msgid "Cannot change unmerged .gitmodules, resolve merge conflicts first"
-msgstr ""
-"No se puede cambiar .gitmodules no fusionados, resuelva este problema primero"
+#: refs.c:860 strbuf.c:1140 wrapper.c:188 wrapper.c:358 builtin/am.c:714
+#: builtin/rebase.c:1031
+#, c-format
+msgid "could not open '%s' for writing"
+msgstr "no se pudo abrir '%s' para escritura"
 
-#: submodule.c:101 submodule.c:135
+#: refs.c:867
 #, c-format
-msgid "Could not find section in .gitmodules where path=%s"
-msgstr "No se pudo encontrar la sección en .gitmodules donde path=%s"
+msgid "unexpected object ID when deleting '%s'"
+msgstr "ID de objecto inesperado al borrar '%s'"
 
-#: submodule.c:109
+#: refs.c:998
 #, c-format
-msgid "Could not update .gitmodules entry %s"
-msgstr "No se pudo actualizar la entrada %s de .gitmodules"
+msgid "log for ref %s has gap after %s"
+msgstr "log de ref %s tiene un vacío tras %s"
 
-#: submodule.c:142
+#: refs.c:1004
 #, c-format
-msgid "Could not remove .gitmodules entry for %s"
-msgstr "No se pudo remover la entrada %s de .gitmodules"
+msgid "log for ref %s unexpectedly ended on %s"
+msgstr "log de ref %s finalizado inesperadamente en %s"
 
-#: submodule.c:153
-msgid "staging updated .gitmodules failed"
-msgstr "falló realizar stage a los .gitmodules actualizados"
+#: refs.c:1063
+#, c-format
+msgid "log for %s is empty"
+msgstr "log de %s está vacío"
 
-#: submodule.c:315
+#: refs.c:1155
 #, c-format
-msgid "in unpopulated submodule '%s'"
-msgstr "en el submódulo no poblado '%s'"
+msgid "refusing to update ref with bad name '%s'"
+msgstr "rehusando actualizar ref con mal nombre '%s'"
 
-#: submodule.c:346
+#: refs.c:1231
 #, c-format
-msgid "Pathspec '%s' is in submodule '%.*s'"
-msgstr "El patrón de ruta '%s' está en el submódulo '%.*s'"
+msgid "update_ref failed for ref '%s': %s"
+msgstr "update_ref falló para ref '%s': %s"
 
-#: submodule.c:837
+#: refs.c:2023
 #, c-format
-msgid "submodule entry '%s' (%s) is a %s, not a commit"
-msgstr "entrada de submódulo '%s' (%s) es un %s, no un commit"
+msgid "multiple updates for ref '%s' not allowed"
+msgstr "múltiples actualizaciones para ref '%s' no permitidas"
 
-#: submodule.c:1069 builtin/branch.c:651 builtin/submodule--helper.c:1743
-msgid "Failed to resolve HEAD as a valid ref."
-msgstr "Falló al resolver HEAD como un ref valido."
+#: refs.c:2055
+msgid "ref updates forbidden inside quarantine environment"
+msgstr "actualizaciones de ref prohibidas dentro de ambiente de cuarentena"
 
-#: submodule.c:1375
+#: refs.c:2151 refs.c:2181
 #, c-format
-msgid "'%s' not recognized as a git repository"
-msgstr "'%s' no reconocido como un repositorio git"
+msgid "'%s' exists; cannot create '%s'"
+msgstr "'%s' existe; no se puede crear '%s'"
 
-#: submodule.c:1513
+#: refs.c:2157 refs.c:2192
 #, c-format
-msgid "could not start 'git status' in submodule '%s'"
-msgstr "no se pudo comenzar 'git status' en el submódulo '%s'"
+msgid "cannot process '%s' and '%s' at the same time"
+msgstr "no se puede procesar '%s' y '%s' al mismo tiempo"
 
-#: submodule.c:1526
+#: refs/files-backend.c:1234
 #, c-format
-msgid "could not run 'git status' in submodule '%s'"
-msgstr "no se pudo ejecutar 'git status' en el submódulo '%s'"
+msgid "could not remove reference %s"
+msgstr "no se pudo eliminar la referencia %s"
 
-#: submodule.c:1619
+#: refs/files-backend.c:1248 refs/packed-backend.c:1541
+#: refs/packed-backend.c:1551
 #, c-format
-msgid "submodule '%s' has dirty index"
-msgstr "submódulo '%s' tiene un índice corrupto"
+msgid "could not delete reference %s: %s"
+msgstr "no se pudo eliminar la referencia %s: %s"
 
-#: submodule.c:1718
+#: refs/files-backend.c:1251 refs/packed-backend.c:1554
 #, c-format
-msgid ""
-"relocate_gitdir for submodule '%s' with more than one worktree not supported"
-msgstr ""
-"relocate_gitdir para el submódulo '%s' con más de un árbol de trabajo no "
-"soportado"
+msgid "could not delete references: %s"
+msgstr "no se pudo eliminar la referencia: %s"
 
-#: submodule.c:1730 submodule.c:1786
+#: refspec.c:137
 #, c-format
-msgid "could not lookup name for submodule '%s'"
-msgstr "no se pudo resolver el nombre para el submódulo '%s'"
+msgid "invalid refspec '%s'"
+msgstr "refspec inválido: '%s'"
 
-#: submodule.c:1734 builtin/submodule--helper.c:1261
-#: builtin/submodule--helper.c:1271
-#, c-format
-msgid "could not create directory '%s'"
-msgstr "no se pudo crear el directorio '%s'"
+#: ref-filter.c:42 wt-status.c:1938
+msgid "gone"
+msgstr "desaparecido"
 
-#: submodule.c:1737
+#: ref-filter.c:43
 #, c-format
-msgid ""
-"Migrating git directory of '%s%s' from\n"
-"'%s' to\n"
-"'%s'\n"
-msgstr ""
-"Migrando directorio git de '%s%s' desde\n"
-"'%s' hacia\n"
-"'%s'\n"
+msgid "ahead %d"
+msgstr "adelante %d"
 
-#: submodule.c:1821
+#: ref-filter.c:44
 #, c-format
-msgid "could not recurse into submodule '%s'"
-msgstr "no pudo recursar en el submódulo '%s'"
-
-#: submodule.c:1865
-msgid "could not start ls-files in .."
-msgstr "no se pudo comenzar ls-files en .."
+msgid "behind %d"
+msgstr "detrás %d"
 
-#: submodule.c:1904
+#: ref-filter.c:45
 #, c-format
-msgid "ls-tree returned unexpected return code %d"
-msgstr "ls-tree retornó un código %d inesperado"
+msgid "ahead %d, behind %d"
+msgstr "delante %d, detrás %d"
 
-#: submodule-config.c:230
+#: ref-filter.c:165
 #, c-format
-msgid "ignoring suspicious submodule name: %s"
-msgstr "ignorando submódulo sospechoso: %s"
-
-#: submodule-config.c:294
-msgid "negative values not allowed for submodule.fetchjobs"
-msgstr "no se permiten valores negativos para submodule.fetchjobs"
+msgid "expected format: %%(color:<color>)"
+msgstr "formato esperado: %%(color:<color>)"
 
-#: submodule-config.c:467
+#: ref-filter.c:167
 #, c-format
-msgid "invalid value for %s"
-msgstr "valor inválido para %s"
+msgid "unrecognized color: %%(color:%s)"
+msgstr "color no reconocido: %%(color:%s)"
 
-#: trailer.c:238
+#: ref-filter.c:189
 #, c-format
-msgid "running trailer command '%s' failed"
-msgstr "ejecución del comando de remolque '%s' falló"
+msgid "Integer value expected refname:lstrip=%s"
+msgstr "Valor entero esperado refname:lstrip=%s"
 
-#: trailer.c:485 trailer.c:490 trailer.c:495 trailer.c:549 trailer.c:553
-#: trailer.c:557
+#: ref-filter.c:193
 #, c-format
-msgid "unknown value '%s' for key '%s'"
-msgstr "valor '%s' desconocido para la clave '%s'"
+msgid "Integer value expected refname:rstrip=%s"
+msgstr "Valor entero esperado refname:rstrip=%s"
 
-#: trailer.c:539 trailer.c:544 builtin/remote.c:293
+#: ref-filter.c:195
 #, c-format
-msgid "more than one %s"
-msgstr "más de un %s"
+msgid "unrecognized %%(%s) argument: %s"
+msgstr "argumento: %s no reconocido %%(%s)"
 
-#: trailer.c:730
+#: ref-filter.c:250
 #, c-format
-msgid "empty trailer token in trailer '%.*s'"
-msgstr "token de remolque vacío en el trailer '%.*s'"
+msgid "%%(objecttype) does not take arguments"
+msgstr "%%(objecttype) no toma ningún argumento"
 
-#: trailer.c:750
+#: ref-filter.c:272
 #, c-format
-msgid "could not read input file '%s'"
-msgstr "no se pudo leer el archivo de entrada '%s'"
+msgid "unrecognized %%(objectsize) argument: %s"
+msgstr "%%(objectsize) no reconocido argumento: %s"
 
-#: trailer.c:753
-msgid "could not read from stdin"
-msgstr "no se pudo leer desde stdin"
-
-#: trailer.c:1008 builtin/am.c:46
+#: ref-filter.c:280
 #, c-format
-msgid "could not stat %s"
-msgstr "no se pudo definir %s"
+msgid "%%(deltabase) does not take arguments"
+msgstr "%%(deltabase) no toma argumentos"
 
-#: trailer.c:1010
+#: ref-filter.c:292
 #, c-format
-msgid "file %s is not a regular file"
-msgstr "el archivo %s no es un archivo regular"
+msgid "%%(body) does not take arguments"
+msgstr "%%(body) no toma ningún argumento"
 
-#: trailer.c:1012
+#: ref-filter.c:301
 #, c-format
-msgid "file %s is not writable by user"
-msgstr "el archivo %s no puede ser escrito por el usuario"
+msgid "%%(subject) does not take arguments"
+msgstr "%%(subject) no toma ningún argumento"
 
-#: trailer.c:1024
-msgid "could not open temporary file"
-msgstr "no se pudo abrir el archivo temporal"
+#: ref-filter.c:323
+#, c-format
+msgid "unknown %%(trailers) argument: %s"
+msgstr "%%(trailers) desconocidos, argumento: %s"
 
-#: trailer.c:1064
+#: ref-filter.c:352
 #, c-format
-msgid "could not rename temporary file to %s"
-msgstr "no se pudo renombrar el archivo temporal a %s"
+msgid "positive value expected contents:lines=%s"
+msgstr "valor positivo esperado contents:lines=%s"
 
-#: transport.c:116
+#: ref-filter.c:354
 #, c-format
-msgid "Would set upstream of '%s' to '%s' of '%s'\n"
-msgstr "Configurará upstream de '%s' a '%s' de '%s'\n"
+msgid "unrecognized %%(contents) argument: %s"
+msgstr "argumento %s no reconocido %%(contents)"
 
-#: transport.c:208
+#: ref-filter.c:369
 #, c-format
-msgid "transport: invalid depth option '%s'"
-msgstr "transport: opción inválida '%s'"
+msgid "positive value expected objectname:short=%s"
+msgstr "valor positivo esperado objectname:short=%s"
 
-#: transport.c:584
-msgid "could not parse transport.color.* config"
-msgstr "no se pudo analizar valor de configuración transport.color.*"
+#: ref-filter.c:373
+#, c-format
+msgid "unrecognized %%(objectname) argument: %s"
+msgstr "argumento: %s no reconocido %%(objectname)"
 
-#: transport.c:996
+#: ref-filter.c:403
 #, c-format
-msgid ""
-"The following submodule paths contain changes that can\n"
-"not be found on any remote:\n"
-msgstr ""
-"La siguiente ruta de submódulo contiene cambios que no\n"
-"pueden ser encontrados en ningún remoto:\n"
+msgid "expected format: %%(align:<width>,<position>)"
+msgstr "formato esperado: %%(align:<ancho>,<posición>)"
 
-#: transport.c:1000
+#: ref-filter.c:415
 #, c-format
-msgid ""
-"\n"
-"Please try\n"
-"\n"
-"\tgit push --recurse-submodules=on-demand\n"
-"\n"
-"or cd to the path and use\n"
-"\n"
-"\tgit push\n"
-"\n"
-"to push them to a remote.\n"
-"\n"
-msgstr ""
-"\n"
-"Por favor intenta\n"
-"\n"
-"\tgit push --recurse-submodules=on-demand\n"
-"\n"
-"o cd a la ruta y usa\n"
-"\n"
-"\tgit push\n"
-"\n"
-"para hacer un push al remoto.\n"
-"\n"
+msgid "unrecognized position:%s"
+msgstr "posición desconocida: %s"
 
-#: transport.c:1008
-msgid "Aborting."
-msgstr "Abortando."
+#: ref-filter.c:422
+#, c-format
+msgid "unrecognized width:%s"
+msgstr "ancho desconocido: %s"
 
-#: transport-helper.c:1087
+#: ref-filter.c:431
 #, c-format
-msgid "Could not read ref %s"
-msgstr "No se pudo leer la referencia %s"
+msgid "unrecognized %%(align) argument: %s"
+msgstr "argumento no reconocido para %%(align): %s"
 
-#: tree-walk.c:31
-msgid "too-short tree object"
-msgstr "objeto de árbol muy corto"
+#: ref-filter.c:439
+#, c-format
+msgid "positive width expected with the %%(align) atom"
+msgstr "se esperaba un ancho positivo con el átomo %%(align)"
 
-#: tree-walk.c:37
-msgid "malformed mode in tree entry"
-msgstr "modo mal formado en la entrada de árbol"
+#: ref-filter.c:457
+#, c-format
+msgid "unrecognized %%(if) argument: %s"
+msgstr "argumento: %s no reconocido %%(if)"
 
-#: tree-walk.c:41
-msgid "empty filename in tree entry"
-msgstr "nombre de archivo vacío en la entrada de árbol"
+#: ref-filter.c:559
+#, c-format
+msgid "malformed field name: %.*s"
+msgstr "nombre mal formado de campo: %.*s"
 
-#: tree-walk.c:113
-msgid "too-short tree file"
-msgstr "archivo de árbol muy corto"
+#: ref-filter.c:586
+#, c-format
+msgid "unknown field name: %.*s"
+msgstr "nombre de campo desconocido: %.*s"
 
-#: unpack-trees.c:111
+#: ref-filter.c:590
 #, c-format
 msgid ""
-"Your local changes to the following files would be overwritten by checkout:\n"
-"%%sPlease commit your changes or stash them before you switch branches."
+"not a git repository, but the field '%.*s' requires access to object data"
 msgstr ""
-"Los cambios locales de los siguientes archivos serán sobrescritos por "
-"checkout:\n"
-"%%sPor favor realiza un commit con los cambios o un stash antes de cambiar "
-"ramas."
+"no es un repositorio git, pero el campo '%.*s' requiere acceso al objeto data"
 
-#: unpack-trees.c:113
+#: ref-filter.c:714
 #, c-format
-msgid ""
-"Your local changes to the following files would be overwritten by checkout:\n"
-"%%s"
-msgstr ""
-"Los cambios locales de los siguientes archivos serán sobreescritos por "
-"checkout:\n"
-"%%s"
+msgid "format: %%(if) atom used without a %%(then) atom"
+msgstr "formato: átomo %%(if) usado sin un átomo %%(then)"
 
-#: unpack-trees.c:116
+#: ref-filter.c:777
 #, c-format
-msgid ""
-"Your local changes to the following files would be overwritten by merge:\n"
-"%%sPlease commit your changes or stash them before you merge."
-msgstr ""
-"Los cambios locales de los siguientes archivos serán sobrescritos al "
-"fusionar:\n"
-"%%sPor favor, confirma tus cambios o aguárdalos antes de fusionar."
+msgid "format: %%(then) atom used without an %%(if) atom"
+msgstr "formato: átomo %%(then) usado sin átomo %%(if)"
 
-#: unpack-trees.c:118
+#: ref-filter.c:779
 #, c-format
-msgid ""
-"Your local changes to the following files would be overwritten by merge:\n"
-"%%s"
-msgstr ""
-"Los cambios locales de los siguientes archivos serán sobreescritos por "
-"merge:\n"
-"%%s"
+msgid "format: %%(then) atom used more than once"
+msgstr "formato: átomo %%(then) usado más de una vez"
 
-#: unpack-trees.c:121
+#: ref-filter.c:781
 #, c-format
-msgid ""
-"Your local changes to the following files would be overwritten by %s:\n"
-"%%sPlease commit your changes or stash them before you %s."
-msgstr ""
-"Los cambios locales de los siguientes archivos serán sobrescritos al %s:\n"
-"%%sPor favor, confirma tus cambios o guárdalos antes de %s."
+msgid "format: %%(then) atom used after %%(else)"
+msgstr "formato: átomo %%(then) usado después de %%(else)"
 
-#: unpack-trees.c:123
+#: ref-filter.c:809
 #, c-format
-msgid ""
-"Your local changes to the following files would be overwritten by %s:\n"
-"%%s"
-msgstr ""
-"Los cambios locales de los siguientes archivos serán sobreescritos por %s:\n"
-"%%s"
+msgid "format: %%(else) atom used without an %%(if) atom"
+msgstr "formato: átomo %%(else) usado sin un átomo %%(if)"
 
-#: unpack-trees.c:128
+#: ref-filter.c:811
 #, c-format
-msgid ""
-"Updating the following directories would lose untracked files in them:\n"
-"%s"
-msgstr ""
-"Al actualizar los siguientes directorios se perderán los archivos sin "
-"seguimiento en ellos:\n"
-"%s"
+msgid "format: %%(else) atom used without a %%(then) atom"
+msgstr "formato: átomo %%(else) usado sin un átomo %%(then)"
 
-#: unpack-trees.c:132
+#: ref-filter.c:813
 #, c-format
-msgid ""
-"The following untracked working tree files would be removed by checkout:\n"
-"%%sPlease move or remove them before you switch branches."
-msgstr ""
-"Los siguientes archivos sin seguimiento en el árbol de trabajo serán "
-"removidos al actualizar el árbol de trabajo:\n"
-"%%sPor favor, muévelos o elimínalos antes de intercambiar ramas."
+msgid "format: %%(else) atom used more than once"
+msgstr "formato: átomo %%(else) usado más de una vez"
 
-#: unpack-trees.c:134
+#: ref-filter.c:828
 #, c-format
-msgid ""
-"The following untracked working tree files would be removed by checkout:\n"
-"%%s"
-msgstr ""
-"Los siguientes archivos sin seguimiento del árbol de trabajo serán removidos "
-"al actualizar el árbol de trabajo:\n"
-"%%s"
+msgid "format: %%(end) atom used without corresponding atom"
+msgstr "formato: átomo %%(end) usado sin átomo correspondiente"
 
-#: unpack-trees.c:137
+#: ref-filter.c:885
 #, c-format
-msgid ""
-"The following untracked working tree files would be removed by merge:\n"
-"%%sPlease move or remove them before you merge."
-msgstr ""
-"Los siguientes archivos sin seguimiento en el árbol de trabajo serán "
-"removidos al fusionar:\n"
-"%%sPor favor, muévelos o elimínalos antes de fusionar."
+msgid "malformed format string %s"
+msgstr "formato de cadena mal formado %s"
 
-#: unpack-trees.c:139
+#: ref-filter.c:1488
 #, c-format
-msgid ""
-"The following untracked working tree files would be removed by merge:\n"
-"%%s"
-msgstr ""
-"Los siguientes archivos sin seguimiento de árbol de trabajo serán removidos "
-"al fusionar:\n"
-"%%s"
+msgid "no branch, rebasing %s"
+msgstr "no hay rama, rebasando %s"
 
-#: unpack-trees.c:142
+#: ref-filter.c:1491
 #, c-format
-msgid ""
-"The following untracked working tree files would be removed by %s:\n"
-"%%sPlease move or remove them before you %s."
-msgstr ""
-"Los siguientes archivos sin seguimiento en el árbol de trabajo serán "
-"removidos al %s:\n"
-"%%sPor favor, muévelos o elimínalos antes de %s."
+msgid "no branch, rebasing detached HEAD %s"
+msgstr "(o hay rama, rebasando con HEAD desacoplado %s"
 
-#: unpack-trees.c:144
+#: ref-filter.c:1494
 #, c-format
-msgid ""
-"The following untracked working tree files would be removed by %s:\n"
-"%%s"
-msgstr ""
-"Los siguientes archivos sin seguimiento en el árbol de trabajo serán "
-"removidos al ejecutar %s:\n"
-"%%s"
-
-#: unpack-trees.c:150
-#, c-format
-msgid ""
-"The following untracked working tree files would be overwritten by "
-"checkout:\n"
-"%%sPlease move or remove them before you switch branches."
-msgstr ""
-"Los siguientes archivos sin seguimiento en el árbol de trabajo serán "
-"sobrescritos al actualizar el árbol de trabajo:\n"
-"%%sPor favor, muévelos o elimínalos antes de intercambiar ramas."
+msgid "no branch, bisect started on %s"
+msgstr "no hay rama, comenzando biseccón en  %s"
 
-#: unpack-trees.c:152
-#, c-format
-msgid ""
-"The following untracked working tree files would be overwritten by "
-"checkout:\n"
-"%%s"
-msgstr ""
-"Los siguientes archivos sin seguimiento de árbol de trabajo serán "
-"sobrescritos al actualizar el árbol de trabajo:\n"
-"%%s"
+#: ref-filter.c:1504
+msgid "no branch"
+msgstr "sin rama"
 
-#: unpack-trees.c:155
+#: ref-filter.c:1540 ref-filter.c:1749
 #, c-format
-msgid ""
-"The following untracked working tree files would be overwritten by merge:\n"
-"%%sPlease move or remove them before you merge."
-msgstr ""
-"Los siguientes archivos sin seguimiento en el árbol de trabajo serán "
-"sobrescritos al fusionar:\n"
-"%%sPor favor, muévelos o elimínalos antes de fusionar."
+msgid "missing object %s for %s"
+msgstr "falta objeto %s para %s"
 
-#: unpack-trees.c:157
+#: ref-filter.c:1550
 #, c-format
-msgid ""
-"The following untracked working tree files would be overwritten by merge:\n"
-"%%s"
-msgstr ""
-"Los siguientes archivos sin seguimiento de árbol de trabajo serán "
-"sobrescritos al fusionar:\n"
-"%%s"
+msgid "parse_object_buffer failed on %s for %s"
+msgstr "parse_object_buffer falló en %s para %s"
 
-#: unpack-trees.c:160
+#: ref-filter.c:2004
 #, c-format
-msgid ""
-"The following untracked working tree files would be overwritten by %s:\n"
-"%%sPlease move or remove them before you %s."
-msgstr ""
-"Los siguientes archivos sin seguimiento en el árbol de trabajo serán "
-"sobrescritos al %s:\n"
-"%%sPor favor, muévelos o elimínalos antes de %s."
+msgid "malformed object at '%s'"
+msgstr "objeto mal formado en '%s'"
 
-#: unpack-trees.c:162
+#: ref-filter.c:2093
 #, c-format
-msgid ""
-"The following untracked working tree files would be overwritten by %s:\n"
-"%%s"
-msgstr ""
-"Los siguientes archivos no rastreados en el árbol de trabajo serán removidos "
-"por %s:\n"
-"%%s"
+msgid "ignoring ref with broken name %s"
+msgstr "ignorando referencia con nombre roto %s"
 
-#: unpack-trees.c:170
+#: ref-filter.c:2389
 #, c-format
-msgid "Entry '%s' overlaps with '%s'.  Cannot bind."
-msgstr "Entrada '%s' se superpone con '%s'.  No se pueden unir."
+msgid "format: %%(end) atom missing"
+msgstr "formato: falta átomo %%(end)"
 
-#: unpack-trees.c:173
+#: ref-filter.c:2489
 #, c-format
-msgid ""
-"Cannot update sparse checkout: the following entries are not up to date:\n"
-"%s"
-msgstr ""
-"No se puede actualizar el sparse checkout: las siguientes entradas no están "
-"actualizadas:\n"
-"%s"
+msgid "option `%s' is incompatible with --merged"
+msgstr "opción `%s' es incompatible con --merged"
 
-#: unpack-trees.c:175
+#: ref-filter.c:2492
 #, c-format
-msgid ""
-"The following working tree files would be overwritten by sparse checkout "
-"update:\n"
-"%s"
-msgstr ""
-"Los siguientes archivos del árbol de trabajo serán sobrescritos por la "
-"actualización sparse checkout:\n"
-"%s"
+msgid "option `%s' is incompatible with --no-merged"
+msgstr "opción `%s' es incompatible con --no-merged"
 
-#: unpack-trees.c:177
+#: ref-filter.c:2502
 #, c-format
-msgid ""
-"The following working tree files would be removed by sparse checkout "
-"update:\n"
-"%s"
-msgstr ""
-"Los siguientes archivos del árbol de trabajo serán removidos por la "
-"actualización sparse checkout:\n"
-"%s"
+msgid "malformed object name %s"
+msgstr "nombre de objeto mal formado %s"
 
-#: unpack-trees.c:179
+#: ref-filter.c:2507
 #, c-format
-msgid ""
-"Cannot update submodule:\n"
-"%s"
-msgstr ""
-"No se puede actualizar le submódulo:\n"
-"%s"
+msgid "option `%s' must point to a commit"
+msgstr "opción '%s' debe apuntar a un commit"
 
-#: unpack-trees.c:262
+#: remote.c:366
 #, c-format
-msgid "Aborting\n"
-msgstr "Abortando\n"
+msgid "config remote shorthand cannot begin with '/': %s"
+msgstr "config remote shorthand no puede comenzar con '/': %s"
 
-#: unpack-trees.c:344
-msgid "Checking out files"
-msgstr "Revisando archivos"
+#: remote.c:413
+msgid "more than one receivepack given, using the first"
+msgstr "más de un receivepack dado, usando el primero"
 
-#: urlmatch.c:163
-msgid "invalid URL scheme name or missing '://' suffix"
-msgstr "nombre de URL invalido o sufijo '://' faltante"
+#: remote.c:421
+msgid "more than one uploadpack given, using the first"
+msgstr "más de un uploadpack dado, usando el primero"
 
-#: urlmatch.c:187 urlmatch.c:346 urlmatch.c:405
+#: remote.c:611
 #, c-format
-msgid "invalid %XX escape sequence"
-msgstr "secuencia de escape %XX invalida"
+msgid "Cannot fetch both %s and %s to %s"
+msgstr "No se pueden traer ambos %s y %s a %s"
 
-#: urlmatch.c:215
-msgid "missing host and scheme is not 'file:'"
-msgstr "falta host y el esquema no es 'file:'"
+#: remote.c:615
+#, c-format
+msgid "%s usually tracks %s, not %s"
+msgstr "%s por lo general hace seguimiento a %s, no a %s"
 
-#: urlmatch.c:232
-msgid "a 'file:' URL may not have a port number"
-msgstr "un 'archivo:' URL puede no tener un número de puerto"
+#: remote.c:619
+#, c-format
+msgid "%s tracks both %s and %s"
+msgstr "%s hace seguimiento tanto a %s como a %s"
 
-#: urlmatch.c:247
-msgid "invalid characters in host name"
-msgstr "carácter inválido en el nombre del host"
+#: remote.c:687
+#, c-format
+msgid "key '%s' of pattern had no '*'"
+msgstr "llave '%s' de patrón no tuvo '*'"
 
-#: urlmatch.c:292 urlmatch.c:303
-msgid "invalid port number"
-msgstr "numero de puerto invalido"
+#: remote.c:697
+#, c-format
+msgid "value '%s' of pattern has no '*'"
+msgstr "valor '%s' del patrón no tiene '*'"
 
-#: urlmatch.c:371
-msgid "invalid '..' path segment"
-msgstr "segmento de ruta '..' invalido"
+#: remote.c:1003
+#, c-format
+msgid "src refspec %s does not match any"
+msgstr "src refsoec %s: no concuerda con ninguno"
 
-#: worktree.c:245 builtin/am.c:2147
+#: remote.c:1008
 #, c-format
-msgid "failed to read '%s'"
-msgstr "falló al leer '%s'"
+msgid "src refspec %s matches more than one"
+msgstr "src refspec %s concuerda con más de uno"
 
-#: worktree.c:291
+#. TRANSLATORS: "matches '%s'%" is the <dst> part of "git push
+#. <remote> <src>:<dst>" push, and "being pushed ('%s')" is
+#. the <src>.
+#.
+#: remote.c:1023
 #, c-format
-msgid "'%s' at main working tree is not the repository directory"
+msgid ""
+"The destination you provided is not a full refname (i.e.,\n"
+"starting with \"refs/\"). We tried to guess what you meant by:\n"
+"\n"
+"- Looking for a ref that matches '%s' on the remote side.\n"
+"- Checking if the <src> being pushed ('%s')\n"
+"  is a ref in \"refs/{heads,tags}/\". If so we add a corresponding\n"
+"  refs/{heads,tags}/ prefix on the remote side.\n"
+"\n"
+"Neither worked, so we gave up. You must fully qualify the ref."
 msgstr ""
-"'%s' en el árbol de trabajo principal no es el directorio del repositorio"
+"El destino que provees no es un full refname (i.e.,\n"
+"comienza con \"refs/\"). Intentamos adivinar lo que quisiste decir:\n"
+"\n"
+"- Buscando un ref que concuerde con '%s' en el lado remoto.\n"
+"- Revisando si el <src> es usado en el push('%s')\n"
+"  es un ref en \"refs/{heads,tags}/\". Si es así, agregamos el prefijo\n"
+"  refs/{heads,tags}/ correspondiente al lado remoto.\n"
+"\n"
+"Ninguno funcionó así que nos dimos por vencidos. Tienes que especificar el "
+"full ref."
 
-#: worktree.c:302
+#: remote.c:1043
 #, c-format
-msgid "'%s' file does not contain absolute path to the working tree location"
+msgid ""
+"The <src> part of the refspec is a commit object.\n"
+"Did you mean to create a new branch by pushing to\n"
+"'%s:refs/heads/%s'?"
 msgstr ""
-"archivo '%s' no contiene una ruta absoluta a la ubicación del árbol de "
-"trabajo"
+"La parte <src> del refspec es un objeto commit.\n"
+"¿Quisiste crear un branch nuevo mediante un push a\n"
+"'%s:refs/heads/%s'?"
 
-#: worktree.c:314
+#: remote.c:1048
 #, c-format
-msgid "'%s' does not exist"
-msgstr "'%s' no existe"
+msgid ""
+"The <src> part of the refspec is a tag object.\n"
+"Did you mean to create a new tag by pushing to\n"
+"'%s:refs/tags/%s'?"
+msgstr ""
+"The <src> part of the refspec is a tag object.\n"
+"Did you mean to create a new tag by pushing to\n"
+"'%s:refs/tags/%s'?"
 
-#: worktree.c:320
+#: remote.c:1053
 #, c-format
-msgid "'%s' is not a .git file, error code %d"
-msgstr "'%s' no es un archivo .git, código de error %d"
+msgid ""
+"The <src> part of the refspec is a tree object.\n"
+"Did you mean to tag a new tree by pushing to\n"
+"'%s:refs/tags/%s'?"
+msgstr ""
+"La parte <src> del refspec es un objeto tree.\n"
+"¿Quisiste crear un tag nuevo mediante un push a\n"
+"'%s:refs/heads/%s'?"
 
-#: worktree.c:328
+#: remote.c:1058
 #, c-format
-msgid "'%s' does not point back to '%s'"
-msgstr "'%s' no apunta de vuelta a '%s'"
+msgid ""
+"The <src> part of the refspec is a blob object.\n"
+"Did you mean to tag a new blob by pushing to\n"
+"'%s:refs/tags/%s'?"
+msgstr ""
+"La parte <src> del refspec es un objeto blob.\n"
+"¿Quisiste crear un tag nuevo mediante un push a\n"
+"'%s:refs/heads/%s'?"
 
-#: wrapper.c:223 wrapper.c:393
+#: remote.c:1094
 #, c-format
-msgid "could not open '%s' for reading and writing"
-msgstr "no se pudo abrir '%s' para lectura y escritura"
+msgid "%s cannot be resolved to branch"
+msgstr "%s no puede ser resolver a un branch"
 
-#: wrapper.c:227 wrapper.c:397 builtin/am.c:320 builtin/am.c:770
-#: builtin/am.c:862 builtin/merge.c:1043
+#: remote.c:1105
 #, c-format
-msgid "could not open '%s' for reading"
-msgstr "no se pudo abrir '%s' para lectura"
+msgid "unable to delete '%s': remote ref does not exist"
+msgstr "no es posible borrar '%s': ref remoto no existe"
 
-#: wrapper.c:424 wrapper.c:624
+#: remote.c:1117
 #, c-format
-msgid "unable to access '%s'"
-msgstr "no es posible acceder '%s'"
+msgid "dst refspec %s matches more than one"
+msgstr "dst refspec %s concuerda con más de uno"
 
-#: wrapper.c:632
-msgid "unable to get current working directory"
-msgstr "no es posible obtener el directorio de trabajo actual"
+#: remote.c:1124
+#, c-format
+msgid "dst ref %s receives from more than one src"
+msgstr "dst ref %s recibe de más de un src"
 
-#: wt-status.c:154
-msgid "Unmerged paths:"
-msgstr "Rutas no fusionadas:"
+#: remote.c:1627 remote.c:1728
+msgid "HEAD does not point to a branch"
+msgstr "HEAD no apunta a ninguna rama"
 
-#: wt-status.c:181 wt-status.c:208
+#: remote.c:1636
 #, c-format
-msgid "  (use \"git reset %s <file>...\" to unstage)"
-msgstr "  (usa \"git reset %s <archivo>...\" para sacar del área de stage)"
+msgid "no such branch: '%s'"
+msgstr "no existe tal rama: '%s'"
 
-#: wt-status.c:183 wt-status.c:210
-msgid "  (use \"git rm --cached <file>...\" to unstage)"
-msgstr "  (usa \"git rm --cached <archivo>...\" para sacar del área de stage)"
+#: remote.c:1639
+#, c-format
+msgid "no upstream configured for branch '%s'"
+msgstr "no se ha configurado upstream para la rama '%s'"
 
-#: wt-status.c:187
-msgid "  (use \"git add <file>...\" to mark resolution)"
-msgstr "  (usa \"git add <archivo>...\" para marcar una resolución)"
+#: remote.c:1645
+#, c-format
+msgid "upstream branch '%s' not stored as a remote-tracking branch"
+msgstr "la rama '%s' de upstream no es guardad como rama de rastreo remoto"
 
-#: wt-status.c:189 wt-status.c:193
-msgid "  (use \"git add/rm <file>...\" as appropriate to mark resolution)"
+#: remote.c:1660
+#, c-format
+msgid "push destination '%s' on remote '%s' has no local tracking branch"
 msgstr ""
-"  (usa \"git add/rm <archivo>...\" como una forma apropiada de marcar la "
-"resolución)"
+"destino de push '%s' en el remoto '%s' no tiene una rama de rastreo local"
 
-#: wt-status.c:191
-msgid "  (use \"git rm <file>...\" to mark resolution)"
-msgstr "  (usa \"git rm <file>...\" para marcar la resolución)"
+#: remote.c:1672
+#, c-format
+msgid "branch '%s' has no remote for pushing"
+msgstr "la rama '%s' no tiene remoto para enviar"
 
-#: wt-status.c:202 wt-status.c:1015
-msgid "Changes to be committed:"
-msgstr "Cambios a ser confirmados:"
+#: remote.c:1682
+#, c-format
+msgid "push refspecs for '%s' do not include '%s'"
+msgstr "refspecs del push para '%s' no incluyen '%s'"
 
-#: wt-status.c:220 wt-status.c:1024
-msgid "Changes not staged for commit:"
-msgstr "Cambios no rastreados para el commit:"
+#: remote.c:1695
+msgid "push has no destination (push.default is 'nothing')"
+msgstr "push no tiene destino (push.default es 'nada')"
 
-#: wt-status.c:224
-msgid "  (use \"git add <file>...\" to update what will be committed)"
-msgstr ""
-"  (usa \"git add <archivo>...\" para actualizar lo que será confirmado)"
+#: remote.c:1717
+msgid "cannot resolve 'simple' push to a single destination"
+msgstr "no se puede resolver push 'simple' para un destino único"
 
-#: wt-status.c:226
-msgid "  (use \"git add/rm <file>...\" to update what will be committed)"
-msgstr ""
-"  (usa \"git add/rm <archivo>...\" para actualizar a lo que se le va a hacer "
-"commit)"
+#: remote.c:1843
+#, c-format
+msgid "couldn't find remote ref %s"
+msgstr "no se puedo encontrar ref remota %s"
 
-#: wt-status.c:227
-msgid ""
-"  (use \"git checkout -- <file>...\" to discard changes in working directory)"
-msgstr ""
-"  (usa \"git checkout -- <archivo>...\" para descartar los cambios en el "
-"directorio de trabajo)"
+#: remote.c:1856
+#, c-format
+msgid "* Ignoring funny ref '%s' locally"
+msgstr "* Ignorando ref graciosa '%s' localmente"
 
-#: wt-status.c:229
-msgid "  (commit or discard the untracked or modified content in submodules)"
-msgstr ""
-"  (confirmar o descartar el contenido sin seguimiento o modificado en los "
-"sub-módulos)"
+#: remote.c:2019
+#, c-format
+msgid "Your branch is based on '%s', but the upstream is gone.\n"
+msgstr "Tu rama está basada en '%s', pero upstream ha desaparecido.\n"
 
-#: wt-status.c:241
+#: remote.c:2023
+msgid "  (use \"git branch --unset-upstream\" to fixup)\n"
+msgstr "  (usa \"git branch --unset-upstream\" para arreglar)\n"
+
+#: remote.c:2026
 #, c-format
-msgid "  (use \"git %s <file>...\" to include in what will be committed)"
-msgstr ""
-"  (usa \"git %s <archivo>...\" para incluirlo a lo que se será confirmado)"
+msgid "Your branch is up to date with '%s'.\n"
+msgstr "Tu rama está actualizada con '%s'.\n"
 
-#: wt-status.c:256
-msgid "both deleted:"
-msgstr "ambos borrados:"
+#: remote.c:2030
+#, c-format
+msgid "Your branch and '%s' refer to different commits.\n"
+msgstr "Tu rama y '%s' refieren a commits diferentes.\n"
 
-#: wt-status.c:258
-msgid "added by us:"
-msgstr "agregado por nosotros:"
+#: remote.c:2033
+#, c-format
+msgid "  (use \"%s\" for details)\n"
+msgstr "  (usa \"%s\" para detalles)\n"
 
-#: wt-status.c:260
-msgid "deleted by them:"
-msgstr "borrados por ellos:"
+#: remote.c:2037
+#, c-format
+msgid "Your branch is ahead of '%s' by %d commit.\n"
+msgid_plural "Your branch is ahead of '%s' by %d commits.\n"
+msgstr[0] "Tu rama está adelantada a '%s' por %d commit.\n"
+msgstr[1] "Tu rama está adelantada a '%s' por %d commits.\n"
 
-#: wt-status.c:262
-msgid "added by them:"
-msgstr "agregado por ellos:"
+#: remote.c:2043
+msgid "  (use \"git push\" to publish your local commits)\n"
+msgstr "  (usa \"git push\" para publicar tus commits locales)\n"
 
-#: wt-status.c:264
-msgid "deleted by us:"
-msgstr "borrado por nosotros:"
+#: remote.c:2046
+#, c-format
+msgid "Your branch is behind '%s' by %d commit, and can be fast-forwarded.\n"
+msgid_plural ""
+"Your branch is behind '%s' by %d commits, and can be fast-forwarded.\n"
+msgstr[0] ""
+"Tu rama está detrás de '%s' por %d commit, y puede ser avanzada rápido.\n"
+msgstr[1] ""
+"Tu rama está detrás de '%s' por %d commits, y puede ser avanzada rápido.\n"
 
-#: wt-status.c:266
-msgid "both added:"
-msgstr "ambos agregados:"
+#: remote.c:2054
+msgid "  (use \"git pull\" to update your local branch)\n"
+msgstr "  (usa \"git pull\" para actualizar tu rama local)\n"
 
-#: wt-status.c:268
-msgid "both modified:"
-msgstr "ambos modificados:"
+#: remote.c:2057
+#, c-format
+msgid ""
+"Your branch and '%s' have diverged,\n"
+"and have %d and %d different commit each, respectively.\n"
+msgid_plural ""
+"Your branch and '%s' have diverged,\n"
+"and have %d and %d different commits each, respectively.\n"
+msgstr[0] ""
+"Tu rama y '%s' han divergido,\n"
+"y se tiene %d y %d commit diferentes en cada una respectivamente.\n"
+msgstr[1] ""
+"Tu rama y '%s' han divergido,\n"
+"y tienen %d y %d commits diferentes cada una respectivamente.\n"
 
-#: wt-status.c:278
-msgid "new file:"
-msgstr "nuevo archivo:"
+#: remote.c:2067
+msgid "  (use \"git pull\" to merge the remote branch into yours)\n"
+msgstr "  (usa \"git pull\" para fusionar la rama remota en la tuya)\n"
 
-#: wt-status.c:280
-msgid "copied:"
-msgstr "copiado:"
+#: remote.c:2250
+#, c-format
+msgid "cannot parse expected object name '%s'"
+msgstr "no se puede leer el nombre de objeto '%s'"
 
-#: wt-status.c:282
-msgid "deleted:"
-msgstr "borrado:"
+#: replace-object.c:21
+#, c-format
+msgid "bad replace ref name: %s"
+msgstr "mal nombre de ref de reemplazo: %s"
 
-#: wt-status.c:284
-msgid "modified:"
-msgstr "modificado:"
+#: replace-object.c:30
+#, c-format
+msgid "duplicate replace ref: %s"
+msgstr "duplicar ref de reemplazo: %s"
 
-#: wt-status.c:286
-msgid "renamed:"
-msgstr "renombrado:"
+#: replace-object.c:73
+#, c-format
+msgid "replace depth too high for object %s"
+msgstr "remplazar profundiad muy elevada para objeto %s"
 
-#: wt-status.c:288
-msgid "typechange:"
-msgstr "cambio de tipo:"
+#: rerere.c:217 rerere.c:226 rerere.c:229
+msgid "corrupt MERGE_RR"
+msgstr "MERGE_RR corrupto"
 
-#: wt-status.c:290
-msgid "unknown:"
-msgstr "desconocido:"
+#: rerere.c:264 rerere.c:269
+msgid "unable to write rerere record"
+msgstr "incapaz de escribir entrada rerere"
 
-#: wt-status.c:292
-msgid "unmerged:"
-msgstr "des-fusionado:"
+#: rerere.c:495
+#, c-format
+msgid "there were errors while writing '%s' (%s)"
+msgstr "hubieron errores mientras se escribía '%s' (%s)"
 
-#: wt-status.c:372
-msgid "new commits, "
-msgstr "nuevos commits, "
+#: rerere.c:498
+#, c-format
+msgid "failed to flush '%s'"
+msgstr "falló al hacer flush '%s'"
 
-#: wt-status.c:374
-msgid "modified content, "
-msgstr "contenido modificado, "
+#: rerere.c:503 rerere.c:1039
+#, c-format
+msgid "could not parse conflict hunks in '%s'"
+msgstr "no se pudo analizar hunks en conflicto en '%s'"
 
-#: wt-status.c:376
-msgid "untracked content, "
-msgstr "contenido no rastreado, "
+#: rerere.c:684
+#, c-format
+msgid "failed utime() on '%s'"
+msgstr "falló utime() en '%s'"
 
-#: wt-status.c:853
+#: rerere.c:694
 #, c-format
-msgid "Your stash currently has %d entry"
-msgid_plural "Your stash currently has %d entries"
-msgstr[0] "Tu stash actualmente tiene %d entrada"
-msgstr[1] "Tu stash actualmente tiene %d entradas"
+msgid "writing '%s' failed"
+msgstr "escribiendo '%s' falló"
 
-#: wt-status.c:885
-msgid "Submodules changed but not updated:"
-msgstr "Submodulos cambiados pero no actualizados:"
+#: rerere.c:714
+#, c-format
+msgid "Staged '%s' using previous resolution."
+msgstr "'%s' puesto en stage usando resolución previa."
 
-#: wt-status.c:887
-msgid "Submodule changes to be committed:"
-msgstr "Submodulos cambiados listos para realizar commit:"
+#: rerere.c:753
+#, c-format
+msgid "Recorded resolution for '%s'."
+msgstr "Resolución guardada para '%s'."
 
-#: wt-status.c:969
-msgid ""
-"Do not modify or remove the line above.\n"
-"Everything below it will be ignored."
-msgstr ""
-"No modifique o borre la línea de encima.\n"
-"Todo lo que este por abajo será removido."
+#: rerere.c:788
+#, c-format
+msgid "Resolved '%s' using previous resolution."
+msgstr "'%s' resuelto usando resolución previa."
 
-#: wt-status.c:1084
-msgid "You have unmerged paths."
-msgstr "Tienes rutas no fusionadas."
+#: rerere.c:803
+#, c-format
+msgid "cannot unlink stray '%s'"
+msgstr "no se puede desvincular stray '%s'"
 
-#: wt-status.c:1087
-msgid "  (fix conflicts and run \"git commit\")"
-msgstr "  (arregla los conflictos y corre \"git commit\""
+#: rerere.c:807
+#, c-format
+msgid "Recorded preimage for '%s'"
+msgstr "Resolución precargada para '%s'"
 
-#: wt-status.c:1089
-msgid "  (use \"git merge --abort\" to abort the merge)"
-msgstr "  (usa \"git merge --abort\" para abortar la fusion)"
+#: rerere.c:881 submodule.c:2067 builtin/log.c:1871
+#: builtin/submodule--helper.c:1436 builtin/submodule--helper.c:1448
+#, c-format
+msgid "could not create directory '%s'"
+msgstr "no se pudo crear el directorio '%s'"
 
-#: wt-status.c:1094
-msgid "All conflicts fixed but you are still merging."
-msgstr "Todos los conflictos resueltos pero sigues fusionando."
+#: rerere.c:1057
+#, c-format
+msgid "failed to update conflicted state in '%s'"
+msgstr "falló al actualizar estado conflictivo en '%s'"
 
-#: wt-status.c:1097
-msgid "  (use \"git commit\" to conclude merge)"
-msgstr "  (usa \"git commit\" para concluir la fusión)"
+#: rerere.c:1068 rerere.c:1075
+#, c-format
+msgid "no remembered resolution for '%s'"
+msgstr "resolución para '%s' no recordada"
 
-#: wt-status.c:1107
-msgid "You are in the middle of an am session."
-msgstr "Estás en medio de una sesión am."
+#: rerere.c:1077
+#, c-format
+msgid "cannot unlink '%s'"
+msgstr "no se puede desvincular '%s'"
 
-#: wt-status.c:1110
-msgid "The current patch is empty."
-msgstr "El parche actual esta vacío."
+#: rerere.c:1087
+#, c-format
+msgid "Updated preimage for '%s'"
+msgstr "Actualizada preimagen para '%s'"
 
-#: wt-status.c:1114
-msgid "  (fix conflicts and then run \"git am --continue\")"
-msgstr "  (arregla los conflictos y luego corre \"git am --continue\""
+#: rerere.c:1096
+#, c-format
+msgid "Forgot resolution for '%s'\n"
+msgstr "Se olvidó resolución para '%s'\n"
 
-#: wt-status.c:1116
-msgid "  (use \"git am --skip\" to skip this patch)"
-msgstr "  (usa \"git am --skip\" para saltar este parche)"
+#: rerere.c:1199
+msgid "unable to open rr-cache directory"
+msgstr "no es posible abrir directorio rr-cache"
 
-#: wt-status.c:1118
-msgid "  (use \"git am --abort\" to restore the original branch)"
-msgstr "  (usa \"git am --abort\" para restaurar la rama original)"
+#: revision.c:2497
+msgid "your current branch appears to be broken"
+msgstr "tu rama actual parece estar rota"
 
-#: wt-status.c:1250
-msgid "git-rebase-todo is missing."
-msgstr "git-rebase-todo no esta presente."
+#: revision.c:2500
+#, c-format
+msgid "your current branch '%s' does not have any commits yet"
+msgstr "tu rama actual '%s' no tiene ningún commit todavía"
 
-#: wt-status.c:1252
-msgid "No commands done."
-msgstr "No se realizaron los comandos."
+#: revision.c:2708
+msgid "--first-parent is incompatible with --bisect"
+msgstr "--first-parent es incompatible con --bisect"
+
+#: revision.c:2712
+msgid "-L does not yet support diff formats besides -p and -s"
+msgstr "-L no soporta todavía formatos de diff fuera de -p y -s"
+
+#: run-command.c:762
+msgid "open /dev/null failed"
+msgstr "falló al abrir /dev/null"
 
-#: wt-status.c:1255
+#: run-command.c:1268
 #, c-format
-msgid "Last command done (%d command done):"
-msgid_plural "Last commands done (%d commands done):"
-msgstr[0] "El último comando realizado (%d comando realizado):"
-msgstr[1] "Los últimos comandos realizados (%d comandos realizados):"
+msgid "cannot create async thread: %s"
+msgstr "no es posible crear hilo async: %s"
 
-#: wt-status.c:1266
+#: run-command.c:1332
 #, c-format
-msgid "  (see more in file %s)"
-msgstr "  (ver mas en el archivo %s)"
+msgid ""
+"The '%s' hook was ignored because it's not set as executable.\n"
+"You can disable this warning with `git config advice.ignoredHook false`."
+msgstr ""
+"El hook '%s' fue ignorado porque no ha sido configurado como ejecutable.\n"
+"Puedes desactivar esta advertencias con `git config advice.ignoredHook "
+"false`."
 
-#: wt-status.c:1271
-msgid "No commands remaining."
-msgstr "No quedan mas comandos."
+#: send-pack.c:144
+msgid "unexpected flush packet while reading remote unpack status"
+msgstr ""
+"flush packet inesperado mientras se leía estatus de desempaquetado remoto"
 
-#: wt-status.c:1274
+#: send-pack.c:146
 #, c-format
-msgid "Next command to do (%d remaining command):"
-msgid_plural "Next commands to do (%d remaining commands):"
-msgstr[0] "Siguiente comando a realizar (%d comando restante):"
-msgstr[1] "Siguiente comandos a realizar (%d comandos faltantes):"
-
-#: wt-status.c:1282
-msgid "  (use \"git rebase --edit-todo\" to view and edit)"
-msgstr "  (usa \"git rebase --edit-todo\" para ver y editar)"
+msgid "unable to parse remote unpack status: %s"
+msgstr "no es posible analizar el estado de desempaquetado remoto: %s"
 
-#: wt-status.c:1295
+#: send-pack.c:148
 #, c-format
-msgid "You are currently rebasing branch '%s' on '%s'."
-msgstr "Estás aplicando un rebase de la rama '%s' en '%s."
+msgid "remote unpack failed: %s"
+msgstr "desempaquetado remoto falló: %s"
 
-#: wt-status.c:1300
-msgid "You are currently rebasing."
-msgstr "Estás aplicando un rebase."
+#: send-pack.c:309
+msgid "failed to sign the push certificate"
+msgstr "falló al firmar el certificado de push"
 
-#: wt-status.c:1314
-msgid "  (fix conflicts and then run \"git rebase --continue\")"
-msgstr "  (corrige los conflictos y ejecuta \"git rebase --continue\")"
+#: send-pack.c:423
+msgid "the receiving end does not support --signed push"
+msgstr "el final receptor no soporta --signed push"
 
-#: wt-status.c:1316
-msgid "  (use \"git rebase --skip\" to skip this patch)"
-msgstr "  (usa \"git rebase --skip\" para omitir este parche)"
+#: send-pack.c:425
+msgid ""
+"not sending a push certificate since the receiving end does not support --"
+"signed push"
+msgstr ""
+"no se manda un certificado de push ya que el destino no soporta push firmado "
+"(--signed )"
 
-#: wt-status.c:1318
-msgid "  (use \"git rebase --abort\" to check out the original branch)"
-msgstr "  (usa \"git rebase --abort\" para volver a tu rama original)"
+#: send-pack.c:437
+msgid "the receiving end does not support --atomic push"
+msgstr "el destino no soporta push atómicos (--atomic)"
 
-#: wt-status.c:1324
-msgid "  (all conflicts fixed: run \"git rebase --continue\")"
-msgstr "  (todos los conflictos corregidos: ejecuta \"git rebase --continue\")"
+#: send-pack.c:442
+msgid "the receiving end does not support push options"
+msgstr "el destino no soporta opciones de push"
 
-#: wt-status.c:1328
+#: sequencer.c:189
 #, c-format
-msgid ""
-"You are currently splitting a commit while rebasing branch '%s' on '%s'."
-msgstr ""
-"Estás dividiendo un commit mientras aplicas un rebase de la rama '%s' en "
-"'%s'."
-
-#: wt-status.c:1333
-msgid "You are currently splitting a commit during a rebase."
-msgstr "Estás dividiendo un commit durante un rebase."
+msgid "invalid commit message cleanup mode '%s'"
+msgstr "mensaje de commit inválido, modo cleanup '%s'"
 
-#: wt-status.c:1336
-msgid "  (Once your working directory is clean, run \"git rebase --continue\")"
-msgstr ""
-"  (Una vez que tu directorio de trabajo esté limpio, ejecuta \"git rebase --"
-"continue\")"
+#: sequencer.c:294
+#, c-format
+msgid "could not delete '%s'"
+msgstr "no se pudo borrar '%s'"
 
-#: wt-status.c:1340
+#: sequencer.c:313 builtin/rebase.c:781 builtin/rebase.c:1706 builtin/rm.c:369
 #, c-format
-msgid "You are currently editing a commit while rebasing branch '%s' on '%s'."
-msgstr ""
-"Estás editando un commit mientras se aplica un rebase de la rama '%s' en "
-"'%s'."
+msgid "could not remove '%s'"
+msgstr "no se pudo eliminar'%s'"
 
-#: wt-status.c:1345
-msgid "You are currently editing a commit during a rebase."
-msgstr "Estás editando un commit durante un rebase."
+#: sequencer.c:323
+msgid "revert"
+msgstr "revertir"
 
-#: wt-status.c:1348
-msgid "  (use \"git commit --amend\" to amend the current commit)"
-msgstr "  (usa \"git commit --amend\" para enmendar el commit actual)"
+#: sequencer.c:325
+msgid "cherry-pick"
+msgstr "cherry-pick"
 
-#: wt-status.c:1350
-msgid ""
-"  (use \"git rebase --continue\" once you are satisfied with your changes)"
-msgstr ""
-"  (usa \"git rebase --continue\" una vez que estés satisfecho con tus "
-"cambios)"
+#: sequencer.c:327
+msgid "rebase -i"
+msgstr "rebase -i"
 
-#: wt-status.c:1360
+#: sequencer.c:329
 #, c-format
-msgid "You are currently cherry-picking commit %s."
-msgstr "Estás realizando un cherry-picking en el commit %s."
-
-#: wt-status.c:1365
-msgid "  (fix conflicts and run \"git cherry-pick --continue\")"
-msgstr "  (corrige los conflictos y ejecuta \"git cherry-pick --continue\")"
+msgid "unknown action: %d"
+msgstr "acción desconocida: %d"
 
-#: wt-status.c:1368
-msgid "  (all conflicts fixed: run \"git cherry-pick --continue\")"
+#: sequencer.c:387
+msgid ""
+"after resolving the conflicts, mark the corrected paths\n"
+"with 'git add <paths>' or 'git rm <paths>'"
 msgstr ""
-"  (todos los conflictos corregidos: ejecuta \"git cherry-pick --continue\")"
+"después de resolver los conflictos, marca las rutas corregidas\n"
+"con 'git add <rutas>' o 'git rm <rutas>'"
 
-#: wt-status.c:1370
-msgid "  (use \"git cherry-pick --abort\" to cancel the cherry-pick operation)"
+#: sequencer.c:390
+msgid ""
+"after resolving the conflicts, mark the corrected paths\n"
+"with 'git add <paths>' or 'git rm <paths>'\n"
+"and commit the result with 'git commit'"
 msgstr ""
-"  (use \"git cherry-pick --abort\" para cancelar la operación cherry-pick)"
+"tras resolver los conflictos, marca las rutas corregidas\n"
+"con 'git add <rutas>' o 'git rm <rutas>'\n"
+"y haz un commit del resultado con 'git commit'"
 
-#: wt-status.c:1379
+#: sequencer.c:403 sequencer.c:2993
 #, c-format
-msgid "You are currently reverting commit %s."
-msgstr "Estás revirtiendo el commit %s."
-
-#: wt-status.c:1384
-msgid "  (fix conflicts and run \"git revert --continue\")"
-msgstr "  (corrige los conflictos y ejecuta \"git revert --continue\")"
+msgid "could not lock '%s'"
+msgstr "no se pudo bloquear '%s'"
 
-#: wt-status.c:1387
-msgid "  (all conflicts fixed: run \"git revert --continue\")"
-msgstr "  (todos los conflictos corregidos: ejecuta \"git revert --continue\")"
+#: sequencer.c:410
+#, c-format
+msgid "could not write eol to '%s'"
+msgstr "no se pudo escribir EOL en '%s'"
 
-#: wt-status.c:1389
-msgid "  (use \"git revert --abort\" to cancel the revert operation)"
-msgstr "  (usa \"git revert --abort\" para cancelar la operación de revertir)"
+#: sequencer.c:415 sequencer.c:2798 sequencer.c:2999 sequencer.c:3013
+#: sequencer.c:3277
+#, c-format
+msgid "failed to finalize '%s'"
+msgstr "falló al finalizar '%s'"
 
-#: wt-status.c:1400
+#: sequencer.c:438 sequencer.c:1707 sequencer.c:2818 sequencer.c:3259
+#: sequencer.c:3368 builtin/am.c:244 builtin/commit.c:783 builtin/merge.c:1117
+#: builtin/rebase.c:589
 #, c-format
-msgid "You are currently bisecting, started from branch '%s'."
-msgstr "Estás aplicando un bisect, comenzando en la rama '%s'."
+msgid "could not read '%s'"
+msgstr "no se pudo leer '%s'"
 
-#: wt-status.c:1404
-msgid "You are currently bisecting."
-msgstr "Estás aplicando un bisect."
+#: sequencer.c:464
+#, c-format
+msgid "your local changes would be overwritten by %s."
+msgstr "tus cambios locales serán sobreescritos por %s."
 
-#: wt-status.c:1407
-msgid "  (use \"git bisect reset\" to get back to the original branch)"
-msgstr "  (usa \"git bisect reset\" para volver a la rama original)"
+#: sequencer.c:468
+msgid "commit your changes or stash them to proceed."
+msgstr "realiza un commit con tus cambios o aplica un stash para proceder."
 
-#: wt-status.c:1604
-msgid "On branch "
-msgstr "En la rama "
+#: sequencer.c:500
+#, c-format
+msgid "%s: fast-forward"
+msgstr "%s: avance rápido"
 
-#: wt-status.c:1610
-msgid "interactive rebase in progress; onto "
-msgstr "rebase interactivo en progreso; en "
+#: sequencer.c:539 builtin/tag.c:565
+#, c-format
+msgid "Invalid cleanup mode %s"
+msgstr "Modo cleanup inválido %s"
 
-#: wt-status.c:1612
-msgid "rebase in progress; onto "
-msgstr "rebase en progreso; en "
+#. TRANSLATORS: %s will be "revert", "cherry-pick" or
+#. "rebase -i".
+#.
+#: sequencer.c:633
+#, c-format
+msgid "%s: Unable to write new index file"
+msgstr "%s: Incapaz de escribir el nuevo archivo índice"
 
-#: wt-status.c:1617
-msgid "HEAD detached at "
-msgstr "HEAD desacoplada en "
+#: sequencer.c:650
+msgid "unable to update cache tree"
+msgstr "no es posible actualizar el árbol de la caché"
 
-#: wt-status.c:1619
-msgid "HEAD detached from "
-msgstr "HEAD desacoplada de "
+#: sequencer.c:664
+msgid "could not resolve HEAD commit"
+msgstr "no se pudo resolver el commit de HEAD"
 
-#: wt-status.c:1622
-msgid "Not currently on any branch."
-msgstr "Actualmente no estás en ninguna rama."
+#: sequencer.c:744
+#, c-format
+msgid "no key present in '%.*s'"
+msgstr "no hay llave presente en '%.*s'"
 
-#: wt-status.c:1642
-msgid "Initial commit"
-msgstr "Confirmación inicial"
+#: sequencer.c:755
+#, c-format
+msgid "unable to dequote value of '%s'"
+msgstr "no es posible dequote para '%s'"
 
-#: wt-status.c:1643
-msgid "No commits yet"
-msgstr "No hay commits todavía"
+#: sequencer.c:792 wrapper.c:190 wrapper.c:360 builtin/am.c:705
+#: builtin/am.c:797 builtin/merge.c:1114 builtin/rebase.c:1074
+#, c-format
+msgid "could not open '%s' for reading"
+msgstr "no se pudo abrir '%s' para lectura"
 
-#: wt-status.c:1657
-msgid "Untracked files"
-msgstr "Archivos sin seguimiento"
+#: sequencer.c:802
+msgid "'GIT_AUTHOR_NAME' already given"
+msgstr "'GIT_AUTHOR_NAME' ya proporcionado"
 
-#: wt-status.c:1659
-msgid "Ignored files"
-msgstr "Archivos ignorados"
+#: sequencer.c:807
+msgid "'GIT_AUTHOR_EMAIL' already given"
+msgstr "'GIT_AUTHOR_EMAIL' ya proporcionado"
 
-#: wt-status.c:1663
-#, c-format
-msgid ""
-"It took %.2f seconds to enumerate untracked files. 'status -uno'\n"
-"may speed it up, but you have to be careful not to forget to add\n"
-"new files yourself (see 'git help status')."
-msgstr ""
-"Tomó %.2f segundos enumerar los archivos no rastreados. 'status -uno'\n"
-"puede acelerarlo, pero tiene que ser cuidadoso de no olvidar agregar\n"
-"nuevos archivos usted mismo (vea 'git help status')."
+#: sequencer.c:812
+msgid "'GIT_AUTHOR_DATE' already given"
+msgstr "'GIT_AUTHOR_DATE' ya proporcionado"
 
-#: wt-status.c:1669
+#: sequencer.c:816
 #, c-format
-msgid "Untracked files not listed%s"
-msgstr "Archivos no rastreados no son mostrados %s"
+msgid "unknown variable '%s'"
+msgstr "variable desconocida '%s'"
 
-#: wt-status.c:1671
-msgid " (use -u option to show untracked files)"
-msgstr " (usa la opción -u para mostrar los archivos sin seguimiento)"
+#: sequencer.c:821
+msgid "missing 'GIT_AUTHOR_NAME'"
+msgstr "falta 'GIT_AUTHOR_NAME'"
 
-#: wt-status.c:1677
-msgid "No changes"
-msgstr "Sin cambios"
+#: sequencer.c:823
+msgid "missing 'GIT_AUTHOR_EMAIL'"
+msgstr "falta 'GIT_AUTHOR_EMAIL'"
 
-#: wt-status.c:1682
-#, c-format
-msgid "no changes added to commit (use \"git add\" and/or \"git commit -a\")\n"
-msgstr ""
-"sin cambios agregados al commit (usa \"git add\" y/o \"git commit -a\")\n"
+#: sequencer.c:825
+msgid "missing 'GIT_AUTHOR_DATE'"
+msgstr "falta 'GIT_AUTHOR_DATE'"
 
-#: wt-status.c:1685
-#, c-format
-msgid "no changes added to commit\n"
-msgstr "no se agregaron cambios al commit\n"
+#: sequencer.c:902 sequencer.c:1427
+msgid "malformed ident line"
+msgstr "línea de entrada mal formada"
 
-#: wt-status.c:1688
+#: sequencer.c:925
 #, c-format
 msgid ""
-"nothing added to commit but untracked files present (use \"git add\" to "
-"track)\n"
+"you have staged changes in your working tree\n"
+"If these changes are meant to be squashed into the previous commit, run:\n"
+"\n"
+"  git commit --amend %s\n"
+"\n"
+"If they are meant to go into a new commit, run:\n"
+"\n"
+"  git commit %s\n"
+"\n"
+"In both cases, once you're done, continue with:\n"
+"\n"
+"  git rebase --continue\n"
 msgstr ""
-"no hay nada agregado al commit pero hay archivos sin seguimiento presentes "
-"(usa \"git add\" para hacerles seguimiento)\n"
+"se ha aplicado un stage a los cambios en el árbol de trabajo\n"
+"si estos cambios están destinados a ser aplastados en el commit previo, "
+"ejecuta:\n"
+"\n"
+"  git commit --amend %s\n"
+"\n"
+"Si estos cambios están destinados a un nuevo commit, ejecuta:\n"
+"\n"
+"  git commit %s\n"
+"\n"
+"en cambos casos, cuando acabes, continua con:\n"
+"\n"
+"  git rebase --continue\n"
 
-#: wt-status.c:1691
-#, c-format
-msgid "nothing added to commit but untracked files present\n"
-msgstr ""
-"no hay nada agregado para confirmar, pero hay archivos sin seguimiento "
-"presentes\n"
+#: sequencer.c:1218
+msgid "'prepare-commit-msg' hook failed"
+msgstr "hook 'prepare-commit-msg' falló"
 
-#: wt-status.c:1694
-#, c-format
-msgid "nothing to commit (create/copy files and use \"git add\" to track)\n"
+#: sequencer.c:1224
+msgid ""
+"Your name and email address were configured automatically based\n"
+"on your username and hostname. Please check that they are accurate.\n"
+"You can suppress this message by setting them explicitly. Run the\n"
+"following command and follow the instructions in your editor to edit\n"
+"your configuration file:\n"
+"\n"
+"    git config --global --edit\n"
+"\n"
+"After doing this, you may fix the identity used for this commit with:\n"
+"\n"
+"    git commit --amend --reset-author\n"
 msgstr ""
-"no hay nada para confirmar (crea/copia archivos y usa \"git add\" para "
-"hacerles seguimiento)\n"
-
-#: wt-status.c:1697 wt-status.c:1702
-#, c-format
-msgid "nothing to commit\n"
-msgstr "nada para hacer commit\n"
+"Tu nombre y correo fueron configurados automáticamente basados\n"
+"en tu usuario y nombre de host. Por favor verifica que son correctos.\n"
+"Tu puedes suprimir este mensaje configurándolos de forma explicita. Ejecuta "
+"el \n"
+"siguiente comando y sigue las instrucciones de tu editor\n"
+" para modificar tu archivo de configuración:\n"
+"\n"
+"    git config --global --edit\n"
+"\n"
+"Tras hacer esto, puedes arreglar la identidad usada para este commit con:\n"
+"\n"
+"    git commit --amend --reset-author\n"
 
-#: wt-status.c:1700
-#, c-format
-msgid "nothing to commit (use -u to show untracked files)\n"
+#: sequencer.c:1237
+msgid ""
+"Your name and email address were configured automatically based\n"
+"on your username and hostname. Please check that they are accurate.\n"
+"You can suppress this message by setting them explicitly:\n"
+"\n"
+"    git config --global user.name \"Your Name\"\n"
+"    git config --global user.email you@example.com\n"
+"\n"
+"After doing this, you may fix the identity used for this commit with:\n"
+"\n"
+"    git commit --amend --reset-author\n"
 msgstr ""
-"nada para hacer commit (usa -u para mostrar los archivos no rastreados)\n"
+"Tu nombre y correo fueron configurados automáticamente basados\n"
+"en tu usuario y nombre de host. Por favor verifica que son correctos.\n"
+"Tu puedes suprimir este mensaje configurándolos de forma explicita: \n"
+"\n"
+"    git config --global user.name \"Tu nombre\"\n"
+"    git config --global user.email you@example.com\n"
+"\n"
+"Tras hacer esto, puedes arreglar tu identidad para este commit con:\n"
+"\n"
+"    git commit --amend --reset-author\n"
 
-#: wt-status.c:1704
-#, c-format
-msgid "nothing to commit, working tree clean\n"
-msgstr "nada para hacer commit, el árbol de trabajo esta limpio\n"
+#: sequencer.c:1279
+msgid "couldn't look up newly created commit"
+msgstr "no se pudo revisar el commit recién creado"
 
-#: wt-status.c:1817
-msgid "No commits yet on "
-msgstr "No hay commits todavía en "
+#: sequencer.c:1281
+msgid "could not parse newly created commit"
+msgstr "no se pudo analizar el commit recién creado"
 
-#: wt-status.c:1821
-msgid "HEAD (no branch)"
-msgstr "HEAD (sin rama)"
+#: sequencer.c:1327
+msgid "unable to resolve HEAD after creating commit"
+msgstr "no se pudo resolver HEAD tras crear el commit"
 
-#: wt-status.c:1852
-msgid "different"
-msgstr "diferente"
+#: sequencer.c:1329
+msgid "detached HEAD"
+msgstr "HEAD desacoplado"
 
-#: wt-status.c:1854 wt-status.c:1862
-msgid "behind "
-msgstr "detrás "
+#: sequencer.c:1333
+msgid " (root-commit)"
+msgstr " (commit-raíz)"
 
-#: wt-status.c:1857 wt-status.c:1860
-msgid "ahead "
-msgstr "adelante "
+#: sequencer.c:1354
+msgid "could not parse HEAD"
+msgstr "no se pudo analizar HEAD"
 
-#. TRANSLATORS: the action is e.g. "pull with rebase"
-#: wt-status.c:2366
+#: sequencer.c:1356
 #, c-format
-msgid "cannot %s: You have unstaged changes."
-msgstr "no se puede %s: Tienes cambios sin marcar."
+msgid "HEAD %s is not a commit!"
+msgstr "¡HEAD %s no es un commit!"
 
-#: wt-status.c:2372
-msgid "additionally, your index contains uncommitted changes."
-msgstr "adicionalmente, tu índice contiene cambios que no están en un commit."
+#: sequencer.c:1360 sequencer.c:1458 builtin/commit.c:1569
+msgid "could not parse HEAD commit"
+msgstr "no se pudo analizar el commit de HEAD"
 
-#: wt-status.c:2374
-#, c-format
-msgid "cannot %s: Your index contains uncommitted changes."
-msgstr "no se puede %s: Tu índice contiene cambios que no están en un commit."
+#: sequencer.c:1411 sequencer.c:2055
+msgid "unable to parse commit author"
+msgstr "no es posible analizar el autor del commit"
 
-#: compat/precompose_utf8.c:58 builtin/clone.c:442
-#, c-format
-msgid "failed to unlink '%s'"
-msgstr "falló al desvincular '%s'"
+#: sequencer.c:1431
+msgid "corrupted author without date information"
+msgstr "autor corrupto sin información de fecha"
 
-#: builtin/add.c:24
-msgid "git add [<options>] [--] <pathspec>..."
-msgstr "git add [<opción>] [--] <especificación-de-ruta>..."
+#: sequencer.c:1447 builtin/am.c:1561 builtin/merge.c:684
+msgid "git write-tree failed to write a tree"
+msgstr "git write-tree falló al escribir el árbol"
 
-#: builtin/add.c:83
+#: sequencer.c:1480 sequencer.c:1550
 #, c-format
-msgid "unexpected diff status %c"
-msgstr "diff status inesperado %c"
+msgid "unable to read commit message from '%s'"
+msgstr "no se puede leer el mensaje del commit de '%s'"
 
-#: builtin/add.c:88 builtin/commit.c:266
-msgid "updating files failed"
-msgstr "falló la actualización de carpetas"
+#: sequencer.c:1516 builtin/am.c:1583 builtin/commit.c:1668 builtin/merge.c:883
+#: builtin/merge.c:908
+msgid "failed to write commit object"
+msgstr "falló al escribir el objeto commit"
 
-#: builtin/add.c:98
+#: sequencer.c:1577
 #, c-format
-msgid "remove '%s'\n"
-msgstr "remover '%s'\n"
+msgid "could not parse commit %s"
+msgstr "no se pudo analizar commit %s"
 
-#: builtin/add.c:173
-msgid "Unstaged changes after refreshing the index:"
-msgstr "Cambios fuera del área de stage tras refrescar el índice:"
+#: sequencer.c:1582
+#, c-format
+msgid "could not parse parent commit %s"
+msgstr "no se pudo analizar el commit padre %s"
 
-#: builtin/add.c:233 builtin/rev-parse.c:892
-msgid "Could not read the index"
-msgstr "No se pudo leer el índice"
+#: sequencer.c:1656 sequencer.c:1767
+#, c-format
+msgid "unknown command: %d"
+msgstr "comando desconocido: %d"
 
-#: builtin/add.c:244
+#: sequencer.c:1714 sequencer.c:1739
 #, c-format
-msgid "Could not open '%s' for writing."
-msgstr "No se pudo abrir '%s' para escritura."
+msgid "This is a combination of %d commits."
+msgstr "Esta es una combinación de %d commits."
 
-#: builtin/add.c:248
-msgid "Could not write patch"
-msgstr "No se puede escribir el parche"
+#: sequencer.c:1724
+msgid "need a HEAD to fixup"
+msgstr "se necesita un HEAD para arreglar"
 
-#: builtin/add.c:251
-msgid "editing patch failed"
-msgstr "falló la edición del parche"
+#: sequencer.c:1726 sequencer.c:3304
+msgid "could not read HEAD"
+msgstr "no se pudo leer HEAD"
+
+#: sequencer.c:1728
+msgid "could not read HEAD's commit message"
+msgstr "no se pudo leer el mensaje de commit de HEAD"
 
-#: builtin/add.c:254
+#: sequencer.c:1734
 #, c-format
-msgid "Could not stat '%s'"
-msgstr "No se pudo definir '%s'"
+msgid "cannot write '%s'"
+msgstr "no se puede escribir '%s'"
 
-#: builtin/add.c:256
-msgid "Empty patch. Aborted."
-msgstr "Parche vacío. Abortado."
+#: sequencer.c:1741 git-rebase--preserve-merges.sh:496
+msgid "This is the 1st commit message:"
+msgstr "Este es el mensaje del 1er commit:"
 
-#: builtin/add.c:261
+#: sequencer.c:1749
 #, c-format
-msgid "Could not apply '%s'"
-msgstr "No se pudo aplicar '%s'"
+msgid "could not read commit message of %s"
+msgstr "no se puede leer el mensaje del commit de %s"
 
-#: builtin/add.c:269
-msgid "The following paths are ignored by one of your .gitignore files:\n"
-msgstr ""
-"Las siguientes rutas son ignoradas por uno de tus archivos .gitignore:\n"
+#: sequencer.c:1756
+#, c-format
+msgid "This is the commit message #%d:"
+msgstr "Este es el mensaje del commit #%d:"
 
-#: builtin/add.c:289 builtin/clean.c:911 builtin/fetch.c:145 builtin/mv.c:123
-#: builtin/prune-packed.c:55 builtin/pull.c:212 builtin/push.c:557
-#: builtin/remote.c:1342 builtin/rm.c:240 builtin/send-pack.c:165
-msgid "dry run"
-msgstr "dry run ( ejecución en seco)"
+#: sequencer.c:1762
+#, c-format
+msgid "The commit message #%d will be skipped:"
+msgstr "El mensaje del commit #%d será saltado:"
 
-#: builtin/add.c:292
-msgid "interactive picking"
-msgstr "selección interactiva"
+#: sequencer.c:1850
+msgid "your index file is unmerged."
+msgstr "tu archivo índice no está fusionado."
 
-#: builtin/add.c:293 builtin/checkout.c:1135 builtin/reset.c:302
-msgid "select hunks interactively"
-msgstr "elegir hunks de forma interactiva"
+#: sequencer.c:1857
+msgid "cannot fixup root commit"
+msgstr "no se puede arreglar el commit raíz"
 
-#: builtin/add.c:294
-msgid "edit current diff and apply"
-msgstr "editar diff actual y aplicar"
+#: sequencer.c:1876
+#, c-format
+msgid "commit %s is a merge but no -m option was given."
+msgstr "el commit %s es una fusión pero no se proporcionó la opción -m."
 
-#: builtin/add.c:295
-msgid "allow adding otherwise ignored files"
-msgstr "permitir agregar caso contrario ignorar archivos"
+#: sequencer.c:1884 sequencer.c:1892
+#, c-format
+msgid "commit %s does not have parent %d"
+msgstr "el commit %s no tiene un padre %d"
 
-#: builtin/add.c:296
-msgid "update tracked files"
-msgstr "actualizado las carpetas rastreadas"
+#: sequencer.c:1898
+#, c-format
+msgid "cannot get commit message for %s"
+msgstr "no se puede obtener el mensaje de commit para %s"
 
-#: builtin/add.c:297
-msgid "renormalize EOL of tracked files (implies -u)"
-msgstr "renormalizar EOL de los archivos rastreados (implica -u)"
+#. TRANSLATORS: The first %s will be a "todo" command like
+#. "revert" or "pick", the second %s a SHA1.
+#: sequencer.c:1917
+#, c-format
+msgid "%s: cannot parse parent commit %s"
+msgstr "%s: no se puede analizar el commit padre %s"
 
-#: builtin/add.c:298
-msgid "record only the fact that the path will be added later"
-msgstr "grabar solo el hecho de que la ruta será agregada después"
+#: sequencer.c:1982
+#, c-format
+msgid "could not rename '%s' to '%s'"
+msgstr "no se puede renombrar '%s' a '%s'"
 
-#: builtin/add.c:299
-msgid "add changes from all tracked and untracked files"
-msgstr "agregar los cambios de todas las carpetas con y sin seguimiento"
+#: sequencer.c:2037
+#, c-format
+msgid "could not revert %s... %s"
+msgstr "no se pudo revertir %s... %s"
 
-#: builtin/add.c:302
-msgid "ignore paths removed in the working tree (same as --no-all)"
-msgstr "ignorar rutas removidas en el árbol de trabajo (lo mismo que --no-all)"
+#: sequencer.c:2038
+#, c-format
+msgid "could not apply %s... %s"
+msgstr "no se pudo aplicar %s... %s"
 
-#: builtin/add.c:304
-msgid "don't add, only refresh the index"
-msgstr "no agregar, solo actualizar el índice"
+#: sequencer.c:2105
+#, c-format
+msgid "git %s: failed to read the index"
+msgstr "git %s: falló al leer el índice"
 
-#: builtin/add.c:305
-msgid "just skip files which cannot be added because of errors"
-msgstr "saltar las carpetas que no pueden ser agregadas a causa de errores"
+#: sequencer.c:2112
+#, c-format
+msgid "git %s: failed to refresh the index"
+msgstr "git %s: falló al refrescar el índice"
 
-#: builtin/add.c:306
-msgid "check if - even missing - files are ignored in dry run"
-msgstr "comprobar si - incluso los archivos que faltan - se ignoran en dry run"
+#: sequencer.c:2189
+#, c-format
+msgid "%s does not accept arguments: '%s'"
+msgstr "%s no acepta los argumentos: '%s'"
 
-#: builtin/add.c:307 builtin/update-index.c:974
-msgid "(+/-)x"
-msgstr "(+/-)x"
+#: sequencer.c:2198
+#, c-format
+msgid "missing arguments for %s"
+msgstr "faltan argumentos para para %s"
 
-#: builtin/add.c:307 builtin/update-index.c:975
-msgid "override the executable bit of the listed files"
-msgstr "sobrescribir el bit ejecutable de los archivos listados"
+#: sequencer.c:2235
+#, c-format
+msgid "could not parse '%.*s'"
+msgstr "no se puede analizar '%.*s'"
 
-#: builtin/add.c:309
-msgid "warn when adding an embedded repository"
-msgstr "avisar cuando se agrega un repositorio incrustado"
+#: sequencer.c:2289
+#, c-format
+msgid "invalid line %d: %.*s"
+msgstr "línea inválida %d: %.*s"
 
-#: builtin/add.c:324
+#: sequencer.c:2300
 #, c-format
-msgid ""
-"You've added another git repository inside your current repository.\n"
-"Clones of the outer repository will not contain the contents of\n"
-"the embedded repository and will not know how to obtain it.\n"
-"If you meant to add a submodule, use:\n"
-"\n"
-"\tgit submodule add <url> %s\n"
-"\n"
-"If you added this path by mistake, you can remove it from the\n"
-"index with:\n"
-"\n"
-"\tgit rm --cached %s\n"
-"\n"
-"See \"git help submodule\" for more information."
-msgstr ""
-"Se ha agregado otro repositorio de git dentro del repositorio actual.\n"
-"Clones del repositorio exterior no tendrán el contenido del \n"
-"repositorio embebido y no sabrán como obtenerla.\n"
-"Si quería agregar un submódulo, use:\n"
-"\n"
-"\tgit submodule add <url> %s\n"
-"\n"
-"Si se agrego esta ruta por error, puede removerla desde el índice \n"
-"usando:\n"
-"\n"
-"\tgit rm --cached %s\n"
-"\n"
-"Vea \"git help submodule\" para mas información."
+msgid "cannot '%s' without a previous commit"
+msgstr "no se puede  '%s' sin un commit previo"
 
-#: builtin/add.c:352
+#: sequencer.c:2348 builtin/rebase.c:172 builtin/rebase.c:197
+#: builtin/rebase.c:223 builtin/rebase.c:248
 #, c-format
-msgid "adding embedded git repository: %s"
-msgstr "agregando repositorio embebido: %s"
+msgid "could not read '%s'."
+msgstr "no se puede leer '%s'."
+
+#: sequencer.c:2384
+msgid "cancelling a cherry picking in progress"
+msgstr "cancelando cherry-pick en progreso"
+
+#: sequencer.c:2391
+msgid "cancelling a revert in progress"
+msgstr "cancelando revert en progreso"
+
+#: sequencer.c:2435
+msgid "please fix this using 'git rebase --edit-todo'."
+msgstr "por favor arregle esto usando 'git rebase --edit-todo'."
 
-#: builtin/add.c:370
+#: sequencer.c:2437
 #, c-format
-msgid "Use -f if you really want to add them.\n"
-msgstr "Use -f si realmente quiere agregarlos.\n"
+msgid "unusable instruction sheet: '%s'"
+msgstr "hoja de instrucciones inutilizable: '%s'"
 
-#: builtin/add.c:378
-msgid "adding files failed"
-msgstr "falló al agregar archivos"
+#: sequencer.c:2442
+msgid "no commits parsed."
+msgstr "ningún commit analizado."
 
-#: builtin/add.c:416
-msgid "-A and -u are mutually incompatible"
-msgstr "-A y -u son mutuamente incompatibles"
+#: sequencer.c:2453
+msgid "cannot cherry-pick during a revert."
+msgstr "no se puede realizar cherry-pick durante un revert."
 
-#: builtin/add.c:423
-msgid "Option --ignore-missing can only be used together with --dry-run"
-msgstr "Opción --ignore-missing solo puede ser usada junto a --dry-run"
+#: sequencer.c:2455
+msgid "cannot revert during a cherry-pick."
+msgstr "no se puede realizar un revert durante un cherry-pick."
 
-#: builtin/add.c:427
+#: sequencer.c:2533
 #, c-format
-msgid "--chmod param '%s' must be either -x or +x"
-msgstr "El parámetro '%s' para --chmod debe ser -x ó +x"
+msgid "invalid value for %s: %s"
+msgstr "valor inválido para %s: %s"
 
-#: builtin/add.c:442
-#, c-format
-msgid "Nothing specified, nothing added.\n"
-msgstr "Nada especificado, nada agregado.\n"
+#: sequencer.c:2630
+msgid "unusable squash-onto"
+msgstr "squash-onto inservible"
 
-#: builtin/add.c:443
+#: sequencer.c:2646
 #, c-format
-msgid "Maybe you wanted to say 'git add .'?\n"
-msgstr "Tal vez quiso decir 'git add .'?\n"
+msgid "malformed options sheet: '%s'"
+msgstr "hoja de opciones mal formada: '%s'"
 
-#: builtin/add.c:448 builtin/check-ignore.c:177 builtin/checkout.c:280
-#: builtin/checkout.c:483 builtin/clean.c:958 builtin/commit.c:325
-#: builtin/diff-tree.c:114 builtin/mv.c:144 builtin/reset.c:241
-#: builtin/rm.c:270 builtin/submodule--helper.c:328
-msgid "index file corrupt"
-msgstr "archivo índice corrompido"
+#: sequencer.c:2736 sequencer.c:4463
+msgid "empty commit set passed"
+msgstr "conjunto de commits vacío entregado"
 
-#: builtin/am.c:414
-msgid "could not parse author script"
-msgstr "no se pudo analizar el script del autor"
+#: sequencer.c:2752
+msgid "revert is already in progress"
+msgstr "revert ya está en progreso"
 
-#: builtin/am.c:498
+#: sequencer.c:2754
 #, c-format
-msgid "'%s' was deleted by the applypatch-msg hook"
-msgstr "'%s' fue borrado por el hook de applypatch-msg"
+msgid "try \"git revert (--continue | %s--abort | --quit)\""
+msgstr "intenta \"git revert (--continue | --quit | %s --abort)\""
 
-#: builtin/am.c:539
-#, c-format
-msgid "Malformed input line: '%s'."
-msgstr "Línea mal formada: '%s'."
+#: sequencer.c:2757
+msgid "cherry-pick is already in progress"
+msgstr "cherry-pick ya está en progreso"
 
-#: builtin/am.c:576
+#: sequencer.c:2759
 #, c-format
-msgid "Failed to copy notes from '%s' to '%s'"
-msgstr "Falló al copiar notas de '%s' a '%s'"
-
-#: builtin/am.c:602
-msgid "fseek failed"
-msgstr "fall de fseek"
+msgid "try \"git cherry-pick (--continue | %s--abort | --quit)\""
+msgstr "intenta \"git cherry-pick (--continue | --quit | %s --abort)\""
 
-#: builtin/am.c:790
+#: sequencer.c:2773
 #, c-format
-msgid "could not parse patch '%s'"
-msgstr "no se pudo analizar el parche '%s'"
-
-#: builtin/am.c:855
-msgid "Only one StGIT patch series can be applied at once"
-msgstr "Solo un parche StGIT puede ser aplicado de una vez"
+msgid "could not create sequencer directory '%s'"
+msgstr "no se pudo crear un directorio secuenciador '%s'"
 
-#: builtin/am.c:903
-msgid "invalid timestamp"
-msgstr "timestamp invalido"
+#: sequencer.c:2788
+msgid "could not lock HEAD"
+msgstr "no se pudo bloquear HEAD"
 
-#: builtin/am.c:908 builtin/am.c:920
-msgid "invalid Date line"
-msgstr "línea Date invalida"
+#: sequencer.c:2848 sequencer.c:4209
+msgid "no cherry-pick or revert in progress"
+msgstr "ningún cherry-pick o revert en progreso"
 
-#: builtin/am.c:915
-msgid "invalid timezone offset"
-msgstr "offset de zona horaria inválido"
+#: sequencer.c:2850 sequencer.c:2861
+msgid "cannot resolve HEAD"
+msgstr "no se puede resolver HEAD"
 
-#: builtin/am.c:1008
-msgid "Patch format detection failed."
-msgstr "Falló al detectar el formato del parche."
+#: sequencer.c:2852 sequencer.c:2896
+msgid "cannot abort from a branch yet to be born"
+msgstr "no se puede abortar de una rama por nacer"
 
-#: builtin/am.c:1013 builtin/clone.c:407
+#: sequencer.c:2882 builtin/grep.c:736
 #, c-format
-msgid "failed to create directory '%s'"
-msgstr "falló al crear el directorio '%s'"
-
-#: builtin/am.c:1018
-msgid "Failed to split patches."
-msgstr "Falló al dividir parches."
-
-#: builtin/am.c:1148 builtin/commit.c:351
-msgid "unable to write index file"
-msgstr "no es posible escribir en el archivo índice"
+msgid "cannot open '%s'"
+msgstr "no se puede abrir '%s'"
 
-#: builtin/am.c:1162
+#: sequencer.c:2884
 #, c-format
-msgid "When you have resolved this problem, run \"%s --continue\"."
-msgstr "Cuando haya resuelto este problema, ejecute \"%s --continue\"."
+msgid "cannot read '%s': %s"
+msgstr "no se puede leer '%s': %s"
 
-#: builtin/am.c:1163
-#, c-format
-msgid "If you prefer to skip this patch, run \"%s --skip\" instead."
-msgstr "Si prefieres saltar este parche, ejecuta \"%s --skip\"."
+#: sequencer.c:2885
+msgid "unexpected end of file"
+msgstr "final de archivo inesperado"
 
-#: builtin/am.c:1164
+#: sequencer.c:2891
 #, c-format
-msgid "To restore the original branch and stop patching, run \"%s --abort\"."
-msgstr ""
-"Para restaurar la rama original y detener el parchado, ejecutar \"%s --abort"
-"\"."
+msgid "stored pre-cherry-pick HEAD file '%s' is corrupt"
+msgstr "archivo HEAD de pre-cherry-pick guardado '%s' está corrupto"
 
-#: builtin/am.c:1271
-msgid "Patch is empty."
-msgstr "El parche esta vacío."
+#: sequencer.c:2902
+msgid "You seem to have moved HEAD. Not rewinding, check your HEAD!"
+msgstr "Parece que se ha movido HEAD. No se hace rebobinado, ¡revisa tu HEAD!"
 
-#: builtin/am.c:1337
-#, c-format
-msgid "invalid ident line: %.*s"
-msgstr "sangría no válida: %.*s"
+#: sequencer.c:2943
+msgid "no revert in progress"
+msgstr "no hay revert en progreso"
 
-#: builtin/am.c:1359
-#, c-format
-msgid "unable to parse commit %s"
-msgstr "no es posible analizar el commit %s"
+#: sequencer.c:2951
+msgid "no cherry-pick in progress"
+msgstr "ningún cherry-pick en progreso"
 
-#: builtin/am.c:1554
-msgid "Repository lacks necessary blobs to fall back on 3-way merge."
-msgstr ""
-"Repositorio carece de los blobs necesarios para retroceder en una fusión de "
-"3-vías."
+#: sequencer.c:2961
+msgid "failed to skip the commit"
+msgstr "falló al escribir el commit"
 
-#: builtin/am.c:1556
-msgid "Using index info to reconstruct a base tree..."
-msgstr "Usando la información del índice para reconstruir un árbol base..."
+#: sequencer.c:2968
+msgid "there is nothing to skip"
+msgstr "no hay nada que saltar"
 
-#: builtin/am.c:1575
+#: sequencer.c:2971
+#, c-format
 msgid ""
-"Did you hand edit your patch?\n"
-"It does not apply to blobs recorded in its index."
+"have you committed already?\n"
+"try \"git %s --continue\""
 msgstr ""
-"Editaste el parche a mano?\n"
-"No aplica a blobs guardados en su índice."
-
-#: builtin/am.c:1581
-msgid "Falling back to patching base and 3-way merge..."
-msgstr "Retrocediendo para parchar base y fusión de 3-vías..."
-
-#: builtin/am.c:1606
-msgid "Failed to merge in the changes."
-msgstr "Falló al fusionar en los cambios."
-
-#: builtin/am.c:1637
-msgid "applying to an empty history"
-msgstr "aplicando a un historial vacío"
+"¿ya has hecho el commit?\n"
+"intenta \"git %s --continue\""
 
-#: builtin/am.c:1683 builtin/am.c:1687
+#: sequencer.c:3095 sequencer.c:4121
 #, c-format
-msgid "cannot resume: %s does not exist."
-msgstr "no se puede continuar: %s no existe."
-
-#: builtin/am.c:1703
-msgid "cannot be interactive without stdin connected to a terminal."
-msgstr "no se puede ser interactivo sin stdin conectado a un terminal."
+msgid "could not update %s"
+msgstr "no se puede actualizar %s"
 
-#: builtin/am.c:1708
-msgid "Commit Body is:"
-msgstr "Cuerpo de commit es:"
+#: sequencer.c:3134 sequencer.c:4101
+msgid "cannot read HEAD"
+msgstr "no se puede leer HEAD"
 
-#. TRANSLATORS: Make sure to include [y], [n], [e], [v] and [a]
-#. in your translation. The program will only accept English
-#. input at this point.
-#.
-#: builtin/am.c:1718
-msgid "Apply? [y]es/[n]o/[e]dit/[v]iew patch/[a]ccept all: "
-msgstr "Aplicar? [y]es/[n]o/[e]dit/[v]iew patch/[a]ccept all: "
+#: sequencer.c:3151
+#, c-format
+msgid "unable to copy '%s' to '%s'"
+msgstr "no se pudo copiar '%s' a '%s'"
 
-#: builtin/am.c:1768
+#: sequencer.c:3159
 #, c-format
-msgid "Dirty index: cannot apply patches (dirty: %s)"
-msgstr "Índice sucio: no se puede aplicar parches (sucio: %s)"
+msgid ""
+"You can amend the commit now, with\n"
+"\n"
+"  git commit --amend %s\n"
+"\n"
+"Once you are satisfied with your changes, run\n"
+"\n"
+"  git rebase --continue\n"
+msgstr ""
+"Puedes enmendar el commit ahora, con\n"
+"\n"
+"\tgit commit --amend %s\n"
+"\n"
+"Una vez que estés satisfecho con los cambios, ejecuta\n"
+"\n"
+"\tgit rebase --continue\n"
 
-#: builtin/am.c:1808 builtin/am.c:1879
+#: sequencer.c:3169
 #, c-format
-msgid "Applying: %.*s"
-msgstr "Aplicando: %.*s"
+msgid "Could not apply %s... %.*s"
+msgstr "No se pudo aplicar %s... %.*s"
 
-#: builtin/am.c:1824
-msgid "No changes -- Patch already applied."
-msgstr "Sin cambios -- parche ya aplicado."
+#: sequencer.c:3176
+#, c-format
+msgid "Could not merge %.*s"
+msgstr "No se pudo fusionar %.*s"
 
-#: builtin/am.c:1832
+#: sequencer.c:3190 sequencer.c:3194 builtin/difftool.c:641
 #, c-format
-msgid "Patch failed at %s %.*s"
-msgstr "El parche falló en %s %.*s"
-
-#: builtin/am.c:1838
-msgid "Use 'git am --show-current-patch' to see the failed patch"
-msgstr "Use 'git am --show-current-patch' para ver el parche fallido"
+msgid "could not copy '%s' to '%s'"
+msgstr "no se pudo copiar '%s' a '%s'"
 
-#: builtin/am.c:1882
+#: sequencer.c:3221
+#, c-format
 msgid ""
-"No changes - did you forget to use 'git add'?\n"
-"If there is nothing left to stage, chances are that something else\n"
-"already introduced the same changes; you might want to skip this patch."
+"execution failed: %s\n"
+"%sYou can fix the problem, and then run\n"
+"\n"
+"  git rebase --continue\n"
+"\n"
 msgstr ""
-"Sin cambios - olvidaste usar 'git add'?\n"
-"Si no hay nada en el área de stage, las posibilidad es que algo mas\n"
-"ya haya introducido el mismo cambio; tal vez quieras omitir este parche."
+"ejecución fallida: %s\n"
+"%sPuedes arreglar el problema, y luego ejecutar\n"
+"\n"
+"  git rebase --continue\n"
+"\n"
+
+#: sequencer.c:3227
+msgid "and made changes to the index and/or the working tree\n"
+msgstr "y se hicieron cambios al índice y/o árbol de trabajo\n"
 
-#: builtin/am.c:1889
+#: sequencer.c:3233
+#, c-format
 msgid ""
-"You still have unmerged paths in your index.\n"
-"You should 'git add' each file with resolved conflicts to mark them as "
-"such.\n"
-"You might run `git rm` on a file to accept \"deleted by them\" for it."
+"execution succeeded: %s\n"
+"but left changes to the index and/or the working tree\n"
+"Commit or stash your changes, and then run\n"
+"\n"
+"  git rebase --continue\n"
+"\n"
 msgstr ""
-"Todavía tiene rutas sin fusionar en su índice.\n"
-"Debe realizar 'git add' cada archivo con conflictos resueltos y marcarlos "
-"como tal.\n"
-"Tal vez ejecute `git rm` en el archivo para aceptar \"borrado por ellos\" en "
-"él."
+"ejecución exitosa: %s\n"
+"pero todavía quedan cambios para el índice o árbol de trabajo.\n"
+"Realiza un commit o stash con tus cambios, y luego ejecuta\n"
+"\n"
+"  git rebase --continue\n"
+"\n"
 
-#: builtin/am.c:1996 builtin/am.c:2000 builtin/am.c:2012 builtin/reset.c:324
-#: builtin/reset.c:332
+#: sequencer.c:3294
 #, c-format
-msgid "Could not parse object '%s'."
-msgstr "No se pudo analizar el objeto '%s'."
+msgid "illegal label name: '%.*s'"
+msgstr "nombre de label ilegal: '%.*s'"
 
-#: builtin/am.c:2048
-msgid "failed to clean index"
-msgstr "falló al limpiar el índice"
+#: sequencer.c:3348
+msgid "writing fake root commit"
+msgstr "escribiendo commit raíz falso"
 
-#: builtin/am.c:2083
-msgid ""
-"You seem to have moved HEAD since the last 'am' failure.\n"
-"Not rewinding to ORIG_HEAD"
-msgstr ""
-"Parece haber movido HEAD desde el último falló 'am'.\n"
-"No rebobinando a ORIG_HEAD"
+#: sequencer.c:3353
+msgid "writing squash-onto"
+msgstr "escribiendo squash-onto"
 
-#: builtin/am.c:2174
+#: sequencer.c:3391 builtin/rebase.c:876 builtin/rebase.c:882
 #, c-format
-msgid "Invalid value for --patch-format: %s"
-msgstr "Valor invalido para --patch-format: %s"
+msgid "failed to find tree of %s"
+msgstr "falló al encontrar árbol de %s"
 
-#: builtin/am.c:2210
-msgid "git am [<options>] [(<mbox> | <Maildir>)...]"
-msgstr "git am [<opciones>] [(<mbox> | <Directorio-de-correo>)...]"
+#: sequencer.c:3436
+#, c-format
+msgid "could not resolve '%s'"
+msgstr "no se pudo resolver '%s'"
 
-#: builtin/am.c:2211
-msgid "git am [<options>] (--continue | --skip | --abort)"
-msgstr "git am [<opciones>] (--continue | --skip | --abort)"
+#: sequencer.c:3467
+msgid "cannot merge without a current revision"
+msgstr "no se puede fusionar sin una versión actual"
 
-#: builtin/am.c:2217
-msgid "run interactively"
-msgstr "ejecutar de manera interactiva"
+#: sequencer.c:3489
+#, c-format
+msgid "unable to parse '%.*s'"
+msgstr "no se puede analizar '%.*s'"
 
-#: builtin/am.c:2219
-msgid "historical option -- no-op"
-msgstr "opción histórica -- no-op"
+#: sequencer.c:3498
+#, c-format
+msgid "nothing to merge: '%.*s'"
+msgstr "nada para fusionar: '%.*s'"
 
-#: builtin/am.c:2221
-msgid "allow fall back on 3way merging if needed"
-msgstr "permitir retroceso en fusión de 3-vías si es necesario"
+#: sequencer.c:3510
+msgid "octopus merge cannot be executed on top of a [new root]"
+msgstr "fusión octopus no puede ser ejecutada en la punta de un [nuevo root]"
 
-#: builtin/am.c:2222 builtin/init-db.c:484 builtin/prune-packed.c:57
-#: builtin/repack.c:192
-msgid "be quiet"
-msgstr "ser silencioso"
+#: sequencer.c:3526
+#, c-format
+msgid "could not get commit message of '%s'"
+msgstr "no se puede leer el mensaje del commit '%s'"
 
-#: builtin/am.c:2224
-msgid "add a Signed-off-by line to the commit message"
-msgstr "agregar una línea \"Firmado-por\" al mensaje del commit"
+#: sequencer.c:3688
+#, c-format
+msgid "could not even attempt to merge '%.*s'"
+msgstr "no se pudo intentar fusionar '%.*s'"
 
-#: builtin/am.c:2227
-msgid "recode into utf8 (default)"
-msgstr "recodificar en utf8 (default)"
+#: sequencer.c:3704
+msgid "merge: Unable to write new index file"
+msgstr "fusión: No se puede escribir el nuevo archivo índice"
 
-#: builtin/am.c:2229
-msgid "pass -k flag to git-mailinfo"
-msgstr "pasar flag -k a git-mailinfo"
+#: sequencer.c:3773 builtin/rebase.c:733
+#, c-format
+msgid "Applied autostash.\n"
+msgstr "Autostash aplicado.\n"
 
-#: builtin/am.c:2231
-msgid "pass -b flag to git-mailinfo"
-msgstr "pasar flag -b a git-mailinfo"
+#: sequencer.c:3785
+#, c-format
+msgid "cannot store %s"
+msgstr "no se puede guardar %s"
 
-#: builtin/am.c:2233
-msgid "pass -m flag to git-mailinfo"
-msgstr "pasar flag -m a git-mailinfo"
+#: sequencer.c:3788 builtin/rebase.c:749 git-rebase--preserve-merges.sh:113
+#, c-format
+msgid ""
+"Applying autostash resulted in conflicts.\n"
+"Your changes are safe in the stash.\n"
+"You can run \"git stash pop\" or \"git stash drop\" at any time.\n"
+msgstr ""
+"Aplicando autostash resultó en conflictos.\n"
+"Tus cambios están seguros en el stash.\n"
+"Puedes ejecutar \"git stash pop\" o \"git stash drop\" en cualquier "
+"momento.\n"
 
-#: builtin/am.c:2235
-msgid "pass --keep-cr flag to git-mailsplit for mbox format"
-msgstr "pasar flag --keep-cr a git-mailsplit para formato mbox"
+#: sequencer.c:3849
+#, c-format
+msgid "could not checkout %s"
+msgstr "no se puede hacer checkout a %s"
 
-#: builtin/am.c:2238
-msgid "do not pass --keep-cr flag to git-mailsplit independent of am.keepcr"
+#: sequencer.c:3863
+#, c-format
+msgid "%s: not a valid OID"
+msgstr "%s no es OID válido"
+
+#: sequencer.c:3868 git-rebase--preserve-merges.sh:779
+msgid "could not detach HEAD"
+msgstr "no se puede desacoplar HEAD"
+
+#: sequencer.c:3883
+#, c-format
+msgid "Stopped at HEAD\n"
+msgstr "Detenido en HEAD\n"
+
+#: sequencer.c:3885
+#, c-format
+msgid "Stopped at %s\n"
+msgstr "Detenido en %s\n"
+
+#: sequencer.c:3893
+#, c-format
+msgid ""
+"Could not execute the todo command\n"
+"\n"
+"    %.*s\n"
+"It has been rescheduled; To edit the command before continuing, please\n"
+"edit the todo list first:\n"
+"\n"
+"    git rebase --edit-todo\n"
+"    git rebase --continue\n"
 msgstr ""
-"no pasar flag --keep-cr a git-mailsplit independientemente de am.keepcr"
+"No se pudo ejecutar el comando \"todo\"\n"
+"\n"
+"    %.*s\n"
+"Ha sido reprogramado; Para editar el comando antes de continuar, por favor\n"
+"edite la lista de \"todo\" primero:\n"
+"\n"
+"    git rebase --edit-todo\n"
+"    git rebase --continue\n"
 
-#: builtin/am.c:2241
-msgid "strip everything before a scissors line"
-msgstr "descubrir todo antes de una línea de tijeras"
+#: sequencer.c:3979
+#, c-format
+msgid "Stopped at %s...  %.*s\n"
+msgstr "Detenido en %s...  %.*s\n"
 
-#: builtin/am.c:2243 builtin/am.c:2246 builtin/am.c:2249 builtin/am.c:2252
-#: builtin/am.c:2255 builtin/am.c:2258 builtin/am.c:2261 builtin/am.c:2264
-#: builtin/am.c:2270
-msgid "pass it through git-apply"
-msgstr "pasarlo a través de git-apply"
+#: sequencer.c:4050
+#, c-format
+msgid "unknown command %d"
+msgstr "comando desconocido %d"
 
-#: builtin/am.c:2260 builtin/commit.c:1332 builtin/fmt-merge-msg.c:665
-#: builtin/fmt-merge-msg.c:668 builtin/grep.c:853 builtin/merge.c:208
-#: builtin/pull.c:150 builtin/pull.c:208 builtin/repack.c:201
-#: builtin/repack.c:205 builtin/repack.c:207 builtin/show-branch.c:631
-#: builtin/show-ref.c:169 builtin/tag.c:383 parse-options.h:144
-#: parse-options.h:146 parse-options.h:258
-msgid "n"
-msgstr "n"
+#: sequencer.c:4109
+msgid "could not read orig-head"
+msgstr "no se puede leer orig-head"
 
-#: builtin/am.c:2266 builtin/branch.c:632 builtin/for-each-ref.c:38
-#: builtin/replace.c:543 builtin/tag.c:419 builtin/verify-tag.c:39
-msgid "format"
-msgstr "formato"
+#: sequencer.c:4114
+msgid "could not read 'onto'"
+msgstr "no se puede leer 'onto'"
 
-#: builtin/am.c:2267
-msgid "format the patch(es) are in"
-msgstr "formatear el parche(s)"
+#: sequencer.c:4128
+#, c-format
+msgid "could not update HEAD to %s"
+msgstr "no se puede actualizar HEAD a %s"
 
-#: builtin/am.c:2273
-msgid "override error message when patch failure occurs"
-msgstr "sobrescribir mensajes de error cuando fallos de parchado ocurran"
+#: sequencer.c:4221
+msgid "cannot rebase: You have unstaged changes."
+msgstr "no se puede realizar rebase: Tienes cambios fuera del área de stage."
 
-#: builtin/am.c:2275
-msgid "continue applying patches after resolving a conflict"
-msgstr "continuar aplicando los parches tras resolver conflictos"
+#: sequencer.c:4230
+msgid "cannot amend non-existing commit"
+msgstr "no se puede arreglar un commit no existente"
 
-#: builtin/am.c:2278
-msgid "synonyms for --continue"
-msgstr "sinónimos para --continue"
+#: sequencer.c:4232
+#, c-format
+msgid "invalid file: '%s'"
+msgstr "archivo inválido: '%s'"
 
-#: builtin/am.c:2281
-msgid "skip the current patch"
-msgstr "saltar el parche actual"
+#: sequencer.c:4234
+#, c-format
+msgid "invalid contents: '%s'"
+msgstr "contenido inválido: '%s'"
 
-#: builtin/am.c:2284
-msgid "restore the original branch and abort the patching operation."
-msgstr "restaurar la rama original y abortar la operación de parchado."
+#: sequencer.c:4237
+msgid ""
+"\n"
+"You have uncommitted changes in your working tree. Please, commit them\n"
+"first and then run 'git rebase --continue' again."
+msgstr ""
+"\n"
+"Tienes cambios fuera de un commit en tu árbol de trabajo. Por favor, realiza "
+"un commit con estos\n"
+"primero y luego ejecuta 'git rebase --continue' de nuevo."
 
-#: builtin/am.c:2287
-msgid "abort the patching operation but keep HEAD where it is."
-msgstr "abortar la operación de parchado pero mantener HEAD donde está."
+#: sequencer.c:4273 sequencer.c:4312
+#, c-format
+msgid "could not write file: '%s'"
+msgstr "no se pudo escribir el archivo: '%s'"
 
-#: builtin/am.c:2290
-msgid "show the patch being applied."
-msgstr "muestra el parche siendo aplicado."
+#: sequencer.c:4327
+msgid "could not remove CHERRY_PICK_HEAD"
+msgstr "no se puede eliminar CHERRY_PICK_HEAD"
 
-#: builtin/am.c:2294
-msgid "lie about committer date"
-msgstr "mentir sobre la fecha del committer"
+#: sequencer.c:4334
+msgid "could not commit staged changes."
+msgstr "no se pudo realizar el commit con los cambios en el área de stage."
 
-#: builtin/am.c:2296
-msgid "use current timestamp for author date"
-msgstr "usar el timestamp actual para la fecha del autor"
+#: sequencer.c:4440
+#, c-format
+msgid "%s: can't cherry-pick a %s"
+msgstr "%s: no se puede aplicar cherry-pick a un %s"
 
-#: builtin/am.c:2298 builtin/commit.c:1468 builtin/merge.c:239
-#: builtin/pull.c:183 builtin/revert.c:112 builtin/tag.c:399
-msgid "key-id"
-msgstr "key-id"
+#: sequencer.c:4444
+#, c-format
+msgid "%s: bad revision"
+msgstr "%s: revisión errónea"
 
-#: builtin/am.c:2299
-msgid "GPG-sign commits"
-msgstr "Commits con firma GPG"
+#: sequencer.c:4479
+msgid "can't revert as initial commit"
+msgstr "no se puede revertir como commit inicial"
 
-#: builtin/am.c:2302
-msgid "(internal use for git-rebase)"
-msgstr "(uso interno para git-rebase)"
+#: sequencer.c:4952
+msgid "make_script: unhandled options"
+msgstr "make_script: opciones desconocidas"
+
+#: sequencer.c:4955
+msgid "make_script: error preparing revisions"
+msgstr "make_script: error preparando revisiones"
 
-#: builtin/am.c:2320
+#: sequencer.c:5113
 msgid ""
-"The -b/--binary option has been a no-op for long time, and\n"
-"it will be removed. Please do not use it anymore."
+"You can fix this with 'git rebase --edit-todo' and then run 'git rebase --"
+"continue'.\n"
+"Or you can abort the rebase with 'git rebase --abort'.\n"
 msgstr ""
-"La opción -b/--binary ha estado deshabilitada por mucho tiempo, y\n"
-"será removida. Por favor no la use más."
+"Se puede arreglar esto con 'git rebase --edit-todo' y después ejecuta 'git "
+"rebase --continue'.\n"
+"O se puede abortar el rebase con 'git rebase --abort'.\n"
 
-#: builtin/am.c:2327
-msgid "failed to read the index"
-msgstr "falló al leer el índice"
+#: sequencer.c:5226 sequencer.c:5243
+msgid "nothing to do"
+msgstr "nada que hacer"
+
+#: sequencer.c:5257
+msgid "could not skip unnecessary pick commands"
+msgstr "no se pudo saltar los comandos pick innecesarios"
+
+#: sequencer.c:5351
+msgid "the script was already rearranged."
+msgstr "este script ya fue reorganizado."
 
-#: builtin/am.c:2342
+#: setup.c:124
 #, c-format
-msgid "previous rebase directory %s still exists but mbox given."
-msgstr "directorio de rebase previo %s todavía existe en el mbox dado."
+msgid "'%s' is outside repository"
+msgstr "'%s' está fuera del repositorio"
 
-#: builtin/am.c:2366
+#: setup.c:174
 #, c-format
 msgid ""
-"Stray %s directory found.\n"
-"Use \"git am --abort\" to remove it."
+"%s: no such path in the working tree.\n"
+"Use 'git <command> -- <path>...' to specify paths that do not exist locally."
 msgstr ""
-"Directorio extraviado %s encontrado.\n"
-"Use \"git am --abort\" para borrarlo."
+"%s: no existe la ruta en el árbol de trabajo.\n"
+"Use 'git <comando> -- <ruta>...' para especificar rutas que no existen "
+"localmente."
 
-#: builtin/am.c:2372
-msgid "Resolve operation not in progress, we are not resuming."
-msgstr "Operación de resolución no está en progreso, no vamos a continuar."
+#: setup.c:187
+#, c-format
+msgid ""
+"ambiguous argument '%s': unknown revision or path not in the working tree.\n"
+"Use '--' to separate paths from revisions, like this:\n"
+"'git <command> [<revision>...] -- [<file>...]'"
+msgstr ""
+"argumento ambiguo '%s': revisión desconocida o ruta fuera del árbol de "
+"trabajo.\n"
+"Use '--' para separar las rutas de las revisiones, de esta manera:\n"
+"'git <comando> [<revisión>...] -- [<archivo>...]'"
 
-#: builtin/apply.c:8
-msgid "git apply [<options>] [<patch>...]"
-msgstr "git apply [<opciones>] [<parche>...]"
+#: setup.c:236
+#, c-format
+msgid "option '%s' must come before non-option arguments"
+msgstr "opción '%s' debe venir antes de argumentos no opcionales"
 
-#: builtin/archive.c:17
+#: setup.c:255
 #, c-format
-msgid "could not create archive file '%s'"
-msgstr "no se pudo crear el archivo comprimido '%s'"
+msgid ""
+"ambiguous argument '%s': both revision and filename\n"
+"Use '--' to separate paths from revisions, like this:\n"
+"'git <command> [<revision>...] -- [<file>...]'"
+msgstr ""
+"argumento ambiguo '%s': ambos revisión y nombre de archivo\n"
+"Use '--' para separar rutas de revisiones, de esta manera:\n"
+"'git <comando> [<revisión>...] -- [<archivo>...]'"
 
-#: builtin/archive.c:20
-msgid "could not redirect output"
-msgstr "no se pudo direccionar la salida"
+#: setup.c:391
+msgid "unable to set up work tree using invalid config"
+msgstr ""
+"no es posible configurar el directorio de trabajo usando una configuración "
+"inválida"
 
-#: builtin/archive.c:37
-msgid "git archive: Remote with no URL"
-msgstr "git archive: Remote sin URL"
+#: setup.c:395
+msgid "this operation must be run in a work tree"
+msgstr "esta operación debe ser realizada en un árbol de trabajo"
 
-#: builtin/archive.c:58
-msgid "git archive: expected ACK/NAK, got a flush packet"
-msgstr "git archive: se esperaba ACK/NAK, se obtuvo flush packet"
+#: setup.c:541
+#, c-format
+msgid "Expected git repo version <= %d, found %d"
+msgstr "Se esperaba versión de git repo  <= %d, encontrada %d"
 
-#: builtin/archive.c:61
+#: setup.c:549
+msgid "unknown repository extensions found:"
+msgstr "se encontró extensión de repositorio desconocida:"
+
+#: setup.c:568
 #, c-format
-msgid "git archive: NACK %s"
-msgstr "git archive: NACK %s"
+msgid "error opening '%s'"
+msgstr "error abriendo '%s'"
 
-#: builtin/archive.c:64
-msgid "git archive: protocol error"
-msgstr "git archive: error de protocolo"
+#: setup.c:570
+#, c-format
+msgid "too large to be a .git file: '%s'"
+msgstr "muy grande para ser un archivo .git: '%s'"
 
-#: builtin/archive.c:68
-msgid "git archive: expected a flush"
-msgstr "git archive: se esperaba un flush"
+#: setup.c:572
+#, c-format
+msgid "error reading %s"
+msgstr "error leyendo %s"
 
-#: builtin/bisect--helper.c:12
-msgid "git bisect--helper --next-all [--no-checkout]"
-msgstr "git bisect--helper --next-all [--no-checkout]"
+#: setup.c:574
+#, c-format
+msgid "invalid gitfile format: %s"
+msgstr "formato gitfile inválido: %s"
 
-#: builtin/bisect--helper.c:13
-msgid "git bisect--helper --write-terms <bad_term> <good_term>"
-msgstr "git bisect--helper --write-terms <mal_término> <buen_término>"
+#: setup.c:576
+#, c-format
+msgid "no path in gitfile: %s"
+msgstr "no hay ruta en gitfile: %s"
 
-#: builtin/bisect--helper.c:14
-msgid "git bisect--helper --bisect-clean-state"
-msgstr "git bisect--helper --bisect-clean-state"
+#: setup.c:578
+#, c-format
+msgid "not a git repository: %s"
+msgstr "no es un repositorio git: %s"
 
-#: builtin/bisect--helper.c:46
+#: setup.c:677
 #, c-format
-msgid "'%s' is not a valid term"
-msgstr "'%s' no es un término válido"
+msgid "'$%s' too big"
+msgstr "'$%s' muy grande"
 
-#: builtin/bisect--helper.c:50
+#: setup.c:691
 #, c-format
-msgid "can't use the builtin command '%s' as a term"
-msgstr "no se puede usar el comando nativo '%s' como un término"
+msgid "not a git repository: '%s'"
+msgstr "no es un repositorio git: '%s'"
 
-#: builtin/bisect--helper.c:60
+#: setup.c:720 setup.c:722 setup.c:753
 #, c-format
-msgid "can't change the meaning of the term '%s'"
-msgstr "no se puede cambiar el significado del término '%s'"
+msgid "cannot chdir to '%s'"
+msgstr "no se puede aplicar chdir a '%s'"
 
-#: builtin/bisect--helper.c:71
-msgid "please use two different terms"
-msgstr "por favor use dos términos diferentes"
+#: setup.c:725 setup.c:781 setup.c:791 setup.c:830 setup.c:838
+msgid "cannot come back to cwd"
+msgstr "no se puede volver a cwd"
 
-#: builtin/bisect--helper.c:78
-msgid "could not open the file BISECT_TERMS"
-msgstr "no se pudo abrir el archivo BISECT_TERMS"
+#: setup.c:852
+#, c-format
+msgid "failed to stat '%*s%s%s'"
+msgstr "falló al determinar '%*s%s%s'"
 
-#: builtin/bisect--helper.c:120
-msgid "perform 'git bisect next'"
-msgstr "realiza 'git bisect next'"
+#: setup.c:1090
+msgid "Unable to read current working directory"
+msgstr "Incapaz de leer el directorio de trabajo actual"
 
-#: builtin/bisect--helper.c:122
-msgid "write the terms to .git/BISECT_TERMS"
-msgstr "escribe los términos a .git/BISECT_TERMS"
+#: setup.c:1099 setup.c:1105
+#, c-format
+msgid "cannot change to '%s'"
+msgstr "no se puede cambiar a '%s'"
 
-#: builtin/bisect--helper.c:124
-msgid "cleanup the bisection state"
-msgstr "limpiar el estado de bisección"
+#: setup.c:1110
+#, c-format
+msgid "not a git repository (or any of the parent directories): %s"
+msgstr ""
+"no es un repositorio git (ni ninguno de los directorios superiores): %s"
 
-#: builtin/bisect--helper.c:126
-msgid "check for expected revs"
-msgstr "revisar por revs esperados"
+#: setup.c:1116
+#, c-format
+msgid ""
+"not a git repository (or any parent up to mount point %s)\n"
+"Stopping at filesystem boundary (GIT_DISCOVERY_ACROSS_FILESYSTEM not set)."
+msgstr ""
+"no es un repositorio git ( o ningún padre en el punto de montado %s)\n"
+"Parando en el límite del sistema de archivos "
+"(GIT_DISCOVERY_ACROSS_FILESYSTEM no establecido)."
 
-#: builtin/bisect--helper.c:128
-msgid "update BISECT_HEAD instead of checking out the current commit"
-msgstr "actualiza BISECT_HEAD en lugar de revisar el commit actual"
+#: setup.c:1227
+#, c-format
+msgid ""
+"problem with core.sharedRepository filemode value (0%.3o).\n"
+"The owner of files must always have read and write permissions."
+msgstr ""
+"problema con el valor del modo de archivo core.sharedRepository (0%.3o).\n"
+"El dueño de los archivos tiene que tener permisos de lectura y escritura."
 
-#: builtin/bisect--helper.c:143
-msgid "--write-terms requires two arguments"
-msgstr "--write-terms requiere dos argumentos"
+#: setup.c:1271
+msgid "open /dev/null or dup failed"
+msgstr "falló al abrir /dev/null o dup"
 
-#: builtin/bisect--helper.c:147
-msgid "--bisect-clean-state requires no arguments"
-msgstr "--bisect-clean-state no requiere argumentos"
+#: setup.c:1286
+msgid "fork failed"
+msgstr "falló fork"
 
-#: builtin/blame.c:29
-msgid "git blame [<options>] [<rev-opts>] [<rev>] [--] <file>"
-msgstr "git blame [<opciones>] [<opciones-rev>] [<revision>] [--] <archivo>"
+#: setup.c:1291
+msgid "setsid failed"
+msgstr "falló setsid"
 
-#: builtin/blame.c:34
-msgid "<rev-opts> are documented in git-rev-list(1)"
-msgstr "<rev-opts> están documentadas en git-rev-list(1)"
+#: sha1-file.c:452
+#, c-format
+msgid "object directory %s does not exist; check .git/objects/info/alternates"
+msgstr "objeto directorio %s no existe; revisa .git/objects/info/alternates"
 
-#: builtin/blame.c:404
+#: sha1-file.c:503
 #, c-format
-msgid "expecting a color: %s"
-msgstr "esperando un color: %s"
+msgid "unable to normalize alternate object path: %s"
+msgstr "incapaz de normalizar la ruta de objeto alterno: %s"
 
-#: builtin/blame.c:411
-msgid "must end with a color"
-msgstr "tiene que terminar con un color"
+#: sha1-file.c:575
+#, c-format
+msgid "%s: ignoring alternate object stores, nesting too deep"
+msgstr "%s: ignorando espacios de objetos alternos, anidado muy profundo"
 
-#: builtin/blame.c:697
+#: sha1-file.c:582
 #, c-format
-msgid "invalid color '%s' in color.blame.repeatedLines"
-msgstr "color invalido '%s' en color.blame.repeatedLines"
+msgid "unable to normalize object directory: %s"
+msgstr "incapaz de normalizar directorio de objeto: %s"
 
-#: builtin/blame.c:715
-msgid "invalid value for blame.coloring"
-msgstr "valor inválido para blame.coloring"
+#: sha1-file.c:625
+msgid "unable to fdopen alternates lockfile"
+msgstr "no es posible hacer fdopen en lockfile alternos"
 
-#: builtin/blame.c:786
-msgid "Show blame entries as we find them, incrementally"
-msgstr "Mostrar las entradas blame como las encontramos, incrementalmente"
+#: sha1-file.c:643
+msgid "unable to read alternates file"
+msgstr "no es posible leer archivos alternos"
+
+#: sha1-file.c:650
+msgid "unable to move new alternates file into place"
+msgstr "no es posible mover archivos alternos en el lugar"
 
-#: builtin/blame.c:787
-msgid "Show blank SHA-1 for boundary commits (Default: off)"
-msgstr "Mostrar SHA-1 en blanco para commits extremos (Default: off)"
+#: sha1-file.c:685
+#, c-format
+msgid "path '%s' does not exist"
+msgstr "ruta '%s' no existe"
 
-#: builtin/blame.c:788
-msgid "Do not treat root commits as boundaries (Default: off)"
-msgstr "No tratar commits raíces como extremos (Default: off)"
+#: sha1-file.c:711
+#, c-format
+msgid "reference repository '%s' as a linked checkout is not supported yet."
+msgstr ""
+"repositorio de referencia '%s' como un checkout vinculado no es soportado "
+"todavía."
 
-#: builtin/blame.c:789
-msgid "Show work cost statistics"
-msgstr "Mostrar estadísticas de costo de trabajo"
+#: sha1-file.c:717
+#, c-format
+msgid "reference repository '%s' is not a local repository."
+msgstr "repositorio de referencia '%s' no es un repositorio local."
 
-#: builtin/blame.c:790
-msgid "Force progress reporting"
-msgstr "Forzar el reporte de progreso"
+#: sha1-file.c:723
+#, c-format
+msgid "reference repository '%s' is shallow"
+msgstr "repositorio de referencia '%s' es superficial (shallow)"
 
-#: builtin/blame.c:791
-msgid "Show output score for blame entries"
-msgstr "Mostrar la puntuación de salida de las entradas de blame"
+#: sha1-file.c:731
+#, c-format
+msgid "reference repository '%s' is grafted"
+msgstr "repositorio de referencia '% s' está injertado"
 
-#: builtin/blame.c:792
-msgid "Show original filename (Default: auto)"
-msgstr "Mostrar nombre original del archivo (Default: auto)"
+#: sha1-file.c:791
+#, c-format
+msgid "invalid line while parsing alternate refs: %s"
+msgstr "línea inválida mientras se analizaban refs alternas: %s"
 
-#: builtin/blame.c:793
-msgid "Show original linenumber (Default: off)"
-msgstr "Mostrar número de línea original (Default: off)"
+#: sha1-file.c:943
+#, c-format
+msgid "attempting to mmap %<PRIuMAX> over limit %<PRIuMAX>"
+msgstr "intentando usar mmap %<PRIuMAX> sobre límite %<PRIuMAX>"
 
-#: builtin/blame.c:794
-msgid "Show in a format designed for machine consumption"
-msgstr "Mostrar en un formato diseñado para consumo de máquina"
+#: sha1-file.c:964
+msgid "mmap failed"
+msgstr "mmap falló"
 
-#: builtin/blame.c:795
-msgid "Show porcelain format with per-line commit information"
-msgstr "Mostrar en formato porcelana con información de commit por línea"
+#: sha1-file.c:1128
+#, c-format
+msgid "object file %s is empty"
+msgstr "archivo de objeto %s está vacío"
 
-#: builtin/blame.c:796
-msgid "Use the same output mode as git-annotate (Default: off)"
-msgstr "Usar el mismo modo salida como git-annotate (Default: off)"
+#: sha1-file.c:1252 sha1-file.c:2392
+#, c-format
+msgid "corrupt loose object '%s'"
+msgstr "objeto perdido corrupto '%s'"
 
-#: builtin/blame.c:797
-msgid "Show raw timestamp (Default: off)"
-msgstr "Mostrar timestamp en formato raw (Default: off)"
+#: sha1-file.c:1254 sha1-file.c:2396
+#, c-format
+msgid "garbage at end of loose object '%s'"
+msgstr "basura al final del objeto perdido '%s'"
 
-#: builtin/blame.c:798
-msgid "Show long commit SHA1 (Default: off)"
-msgstr "Mostrar SHA1 del commit en formato largo (Default: off)"
+#: sha1-file.c:1296
+msgid "invalid object type"
+msgstr "tipo de objeto inválido"
 
-#: builtin/blame.c:799
-msgid "Suppress author name and timestamp (Default: off)"
-msgstr "Suprimir nombre del autor y timestamp (Default: off)"
+#: sha1-file.c:1380
+#, c-format
+msgid "unable to unpack %s header with --allow-unknown-type"
+msgstr "no es posible desempacar header %s con --allow-unknown-type"
 
-#: builtin/blame.c:800
-msgid "Show author email instead of name (Default: off)"
-msgstr "Mostrar en cambio el email del autor (Default: off)"
+#: sha1-file.c:1383
+#, c-format
+msgid "unable to unpack %s header"
+msgstr "incapaz de desempaquetar header %s"
 
-#: builtin/blame.c:801
-msgid "Ignore whitespace differences"
-msgstr "Ignorar diferencias de espacios en blanco"
+#: sha1-file.c:1389
+#, c-format
+msgid "unable to parse %s header with --allow-unknown-type"
+msgstr "no es posible analizar header %s con --allow-unknown-type"
 
-#: builtin/blame.c:802
-msgid "color redundant metadata from previous line differently"
-msgstr "colorear metadata redundante de lineas previas de manera diferente"
+#: sha1-file.c:1392
+#, c-format
+msgid "unable to parse %s header"
+msgstr "incapaz de analizar header %s"
 
-#: builtin/blame.c:803
-msgid "color lines by age"
-msgstr "colorear lineas por edad"
+#: sha1-file.c:1584
+#, c-format
+msgid "failed to read object %s"
+msgstr "falló al leer objeto %s"
 
-#: builtin/blame.c:810
-msgid "Use an experimental heuristic to improve diffs"
-msgstr "Usar un heurístico experimental para mejorar los diffs"
+#: sha1-file.c:1588
+#, c-format
+msgid "replacement %s not found for %s"
+msgstr "reemplazo %s no encontrado para %s"
 
-#: builtin/blame.c:812
-msgid "Spend extra cycles to find better match"
-msgstr "Ocupo más ciclos para encontrar mejoras resultados"
+#: sha1-file.c:1592
+#, c-format
+msgid "loose object %s (stored in %s) is corrupt"
+msgstr "objeto perdido %s (guardado en %s) está corrompido"
 
-#: builtin/blame.c:813
-msgid "Use revisions from <file> instead of calling git-rev-list"
-msgstr "Use revisiones desde <archivo> en lugar de llamar git-rev-list"
+#: sha1-file.c:1596
+#, c-format
+msgid "packed object %s (stored in %s) is corrupt"
+msgstr "paquete de objeto %s (guardado en %s) está corrompido"
 
-#: builtin/blame.c:814
-msgid "Use <file>'s contents as the final image"
-msgstr "Usar contenido de <archivo> como imagen final"
+#: sha1-file.c:1699
+#, c-format
+msgid "unable to write file %s"
+msgstr "no es posible escribir archivo %s"
 
-#: builtin/blame.c:815 builtin/blame.c:816
-msgid "score"
-msgstr "puntaje"
+#: sha1-file.c:1706
+#, c-format
+msgid "unable to set permission to '%s'"
+msgstr "no se pudo poner permisos a '%s'"
 
-#: builtin/blame.c:815
-msgid "Find line copies within and across files"
-msgstr "Encontrar copias de líneas entre y a través de archivos"
+#: sha1-file.c:1713
+msgid "file write error"
+msgstr "falló de escritura"
 
-#: builtin/blame.c:816
-msgid "Find line movements within and across files"
-msgstr "Encontrar movimientos de líneas entre y a través de archivos"
+#: sha1-file.c:1732
+msgid "error when closing loose object file"
+msgstr "error cerrando el archivo de objeto suelto"
 
-#: builtin/blame.c:817
-msgid "n,m"
-msgstr "n,m"
+#: sha1-file.c:1797
+#, c-format
+msgid "insufficient permission for adding an object to repository database %s"
+msgstr ""
+"permisos insuficientes para agregar un objeto a la base de datos del "
+"repositorio %s"
 
-#: builtin/blame.c:817
-msgid "Process only line range n,m, counting from 1"
-msgstr "Procesar solo el rango de líneas n,m, contando desde 1"
+#: sha1-file.c:1799
+msgid "unable to create temporary file"
+msgstr "no es posible crear un archivo temporal"
 
-#: builtin/blame.c:866
-msgid "--progress can't be used with --incremental or porcelain formats"
-msgstr "--progress no puede ser usado con --incremental o formatos porcelana"
+#: sha1-file.c:1823
+msgid "unable to write loose object file"
+msgstr "no es posible escribir el archivo de objeto suelto"
 
-#. TRANSLATORS: This string is used to tell us the
-#. maximum display width for a relative timestamp in
-#. "git blame" output.  For C locale, "4 years, 11
-#. months ago", which takes 22 places, is the longest
-#. among various forms of relative timestamps, but
-#. your language may need more or fewer display
-#. columns.
-#.
-#: builtin/blame.c:917
-msgid "4 years, 11 months ago"
-msgstr "hace 4 años, 11 meses"
-
-#: builtin/blame.c:1003
+#: sha1-file.c:1829
 #, c-format
-msgid "file %s has only %lu line"
-msgid_plural "file %s has only %lu lines"
-msgstr[0] "archivo %s tiene solo %lu línea"
-msgstr[1] "archivo %s tiene solo %lu líneas"
-
-#: builtin/blame.c:1049
-msgid "Blaming lines"
-msgstr "Blaming a líneas"
-
-#: builtin/branch.c:27
-msgid "git branch [<options>] [-r | -a] [--merged | --no-merged]"
-msgstr "git branch [<opciones>] [-r | -a] [--merged | --no-merged]"
+msgid "unable to deflate new object %s (%d)"
+msgstr "no es posible desinflar el objeto nuevo %s (%d)"
 
-#: builtin/branch.c:28
-msgid "git branch [<options>] [-l] [-f] <branch-name> [<start-point>]"
-msgstr "git branch [<opciones>] [-l] [-f] <nombre-de-rama> [<punto-inicial>]"
+#: sha1-file.c:1833
+#, c-format
+msgid "deflateEnd on object %s failed (%d)"
+msgstr "deflateEnd en objeto %s falló (%d)"
 
-#: builtin/branch.c:29
-msgid "git branch [<options>] [-r] (-d | -D) <branch-name>..."
-msgstr "git branch [<opciones>] [-r] (-d | -D) <nombre-de-rama>..."
+#: sha1-file.c:1837
+#, c-format
+msgid "confused by unstable object source data for %s"
+msgstr "confundido por fuente de data de objetos inestable para %s"
 
-#: builtin/branch.c:30
-msgid "git branch [<options>] (-m | -M) [<old-branch>] <new-branch>"
-msgstr "git branch [<opciones>] (-m | -M) [<rama-vieja>] <rama-nueva>"
+#: sha1-file.c:1847 builtin/pack-objects.c:925
+#, c-format
+msgid "failed utime() on %s"
+msgstr "falló utime() en %s"
 
-#: builtin/branch.c:31
-msgid "git branch [<options>] (-c | -C) [<old-branch>] <new-branch>"
-msgstr "git branch [<opciones>] (-c | -C) [<rama-vieja>] <rama-nueva>"
+#: sha1-file.c:1922
+#, c-format
+msgid "cannot read object for %s"
+msgstr "no se pudo leer el objeto para %s"
 
-#: builtin/branch.c:32
-msgid "git branch [<options>] [-r | -a] [--points-at]"
-msgstr "git branch [<opciones>] [-r | -a] [--points-at]"
+#: sha1-file.c:1962
+msgid "corrupt commit"
+msgstr "commit corrupto"
 
-#: builtin/branch.c:33
-msgid "git branch [<options>] [-r | -a] [--format]"
-msgstr "git branch [<opciones>] [-r | -a] [--formato]"
+#: sha1-file.c:1970
+msgid "corrupt tag"
+msgstr "tag corrupto"
 
-#: builtin/branch.c:146
+#: sha1-file.c:2069
 #, c-format
-msgid ""
-"deleting branch '%s' that has been merged to\n"
-"         '%s', but not yet merged to HEAD."
-msgstr ""
-"borrando la rama '%s' que ha sido fusionada en\n"
-"         '%s', pero aún no ha sido fusionada a HEAD."
+msgid "read error while indexing %s"
+msgstr "error leyendo al indexar %s"
 
-#: builtin/branch.c:150
+#: sha1-file.c:2072
 #, c-format
-msgid ""
-"not deleting branch '%s' that is not yet merged to\n"
-"         '%s', even though it is merged to HEAD."
-msgstr ""
-"no borrando rama '%s' que todavía no ha sido fusionada \n"
-"\ta '%s', aunque se fusione con HEAD."
+msgid "short read while indexing %s"
+msgstr "lectura corta al indexar %s"
 
-#: builtin/branch.c:164
+#: sha1-file.c:2145 sha1-file.c:2154
 #, c-format
-msgid "Couldn't look up commit object for '%s'"
-msgstr "No se pudo encontrar el objeto commit para '%s'"
+msgid "%s: failed to insert into database"
+msgstr "%s: falló al insertar en la base de datos"
 
-#: builtin/branch.c:168
+#: sha1-file.c:2160
 #, c-format
-msgid ""
-"The branch '%s' is not fully merged.\n"
-"If you are sure you want to delete it, run 'git branch -D %s'."
-msgstr ""
-"La rama '%s' no ha sido fusionada completamente.\n"
-"Si está seguro de querer borrarla, ejecute 'git branch -D %s'."
-
-#: builtin/branch.c:181
-msgid "Update of config-file failed"
-msgstr "Falló de actualización de config-file"
+msgid "%s: unsupported file type"
+msgstr "%s: tipo de archivo no soportado"
 
-#: builtin/branch.c:212
-msgid "cannot use -a with -d"
-msgstr "no se puede usar-a con -d"
+#: sha1-file.c:2184
+#, c-format
+msgid "%s is not a valid object"
+msgstr "%s no es objeto válido"
 
-#: builtin/branch.c:218
-msgid "Couldn't look up commit object for HEAD"
-msgstr "No se pudo revisar el objeto commit para HEAD"
+#: sha1-file.c:2186
+#, c-format
+msgid "%s is not a valid '%s' object"
+msgstr "%s no es un objeto '%s' válido"
 
-#: builtin/branch.c:232
+#: sha1-file.c:2213 builtin/index-pack.c:155
 #, c-format
-msgid "Cannot delete branch '%s' checked out at '%s'"
-msgstr "No se puede borrar rama '%s' que cuenta con checkout en '%s'"
+msgid "unable to open %s"
+msgstr "no es posible abrir %s"
 
-#: builtin/branch.c:247
+#: sha1-file.c:2403 sha1-file.c:2455
 #, c-format
-msgid "remote-tracking branch '%s' not found."
-msgstr "rama de rastreo remoto '%s' no encontrada."
+msgid "hash mismatch for %s (expected %s)"
+msgstr "hash no concuerda para %s (se esperaba %s)"
 
-#: builtin/branch.c:248
+#: sha1-file.c:2427
 #, c-format
-msgid "branch '%s' not found."
-msgstr "rama '%s' no encontrada."
+msgid "unable to mmap %s"
+msgstr "no es posible hacer mmap a %s"
 
-#: builtin/branch.c:263
+#: sha1-file.c:2432
 #, c-format
-msgid "Error deleting remote-tracking branch '%s'"
-msgstr "Error al eliminar la rama de rastreo remota '%s'"
+msgid "unable to unpack header of %s"
+msgstr "incapaz de desempaquetar header de %s"
 
-#: builtin/branch.c:264
+#: sha1-file.c:2438
 #, c-format
-msgid "Error deleting branch '%s'"
-msgstr "Error al eliminar la rama '%s'"
+msgid "unable to parse header of %s"
+msgstr "incapaz de analizar header de %s"
 
-#: builtin/branch.c:271
+#: sha1-file.c:2449
 #, c-format
-msgid "Deleted remote-tracking branch %s (was %s).\n"
-msgstr "Eliminada la rama de rastreo remota %s (era %s).\n"
+msgid "unable to unpack contents of %s"
+msgstr "no es posible desempaquetar contenidos de %s"
 
-#: builtin/branch.c:272
+#: sha1-name.c:487
 #, c-format
-msgid "Deleted branch %s (was %s).\n"
-msgstr "Eliminada la rama %s (era %s)..\n"
+msgid "short SHA1 %s is ambiguous"
+msgstr "SHA1 %s corto es ambiguo"
 
-#: builtin/branch.c:416 builtin/tag.c:58
-msgid "unable to parse format string"
-msgstr "no es posible analizar el string de formato"
+#: sha1-name.c:498
+msgid "The candidates are:"
+msgstr "Los candidatos son:"
 
-#: builtin/branch.c:453
-#, c-format
-msgid "Branch %s is being rebased at %s"
-msgstr "Rama %s está siendo rebasada en %s"
+#: sha1-name.c:797
+msgid ""
+"Git normally never creates a ref that ends with 40 hex characters\n"
+"because it will be ignored when you just specify 40-hex. These refs\n"
+"may be created by mistake. For example,\n"
+"\n"
+"  git switch -c $br $(git rev-parse ...)\n"
+"\n"
+"where \"$br\" is somehow empty and a 40-hex ref is created. Please\n"
+"examine these refs and maybe delete them. Turn this message off by\n"
+"running \"git config advice.objectNameWarning false\""
+msgstr ""
+"Git normalmente nunca crea una ref que termine con 40 caracteres hex\n"
+"porque esto sería ignorado cuando solo se especifiquen 40-hex. Estas refs\n"
+"tal vez sean creadas por error. Por ejemplo,\n"
+"\n"
+"  git switch -c $br $(git rev-parse ...)\n"
+"\n"
+"donde \"$br\" está de alguna manera vacía y una ref de 40-hex es creada. Por "
+"favor\n"
+"examina estas refs y tal vez bórralas. Silencia este mensaje \n"
+"ejecutando \"git config advice.objectNameWarning false\""
 
-#: builtin/branch.c:457
+#. TRANSLATORS: IEC 80000-13:2008 gibibyte
+#: strbuf.c:822
 #, c-format
-msgid "Branch %s is being bisected at %s"
-msgstr "Rama %s está siendo bisecada en %s"
+msgid "%u.%2.2u GiB"
+msgstr "%u.%2.2u GiB"
 
-#: builtin/branch.c:474
-msgid "cannot copy the current branch while not on any."
-msgstr "no se puede copiar la rama actual mientras no se está en ninguna."
+#. TRANSLATORS: IEC 80000-13:2008 gibibyte/second
+#: strbuf.c:824
+#, c-format
+msgid "%u.%2.2u GiB/s"
+msgstr "%u.%2.2u GiB/s"
 
-#: builtin/branch.c:476
-msgid "cannot rename the current branch while not on any."
-msgstr "no se puede renombrar la rama actual mientras no se está en ninguna."
+#. TRANSLATORS: IEC 80000-13:2008 mebibyte
+#: strbuf.c:832
+#, c-format
+msgid "%u.%2.2u MiB"
+msgstr "%u.%2.2u MiB"
 
-#: builtin/branch.c:487
+#. TRANSLATORS: IEC 80000-13:2008 mebibyte/second
+#: strbuf.c:834
 #, c-format
-msgid "Invalid branch name: '%s'"
-msgstr "Nombre de rama invalido: '%s'"
+msgid "%u.%2.2u MiB/s"
+msgstr "%u.%2.2u MiB/s"
 
-#: builtin/branch.c:514
-msgid "Branch rename failed"
-msgstr "Cambio de nombre de rama fallido"
+#. TRANSLATORS: IEC 80000-13:2008 kibibyte
+#: strbuf.c:841
+#, c-format
+msgid "%u.%2.2u KiB"
+msgstr "%u.%2.2u KiB"
 
-#: builtin/branch.c:516
-msgid "Branch copy failed"
-msgstr "Copiado de rama fallido"
+#. TRANSLATORS: IEC 80000-13:2008 kibibyte/second
+#: strbuf.c:843
+#, c-format
+msgid "%u.%2.2u KiB/s"
+msgstr "%u.%2.2u KiB/s"
 
-#: builtin/branch.c:520
+#. TRANSLATORS: IEC 80000-13:2008 byte
+#: strbuf.c:849
 #, c-format
-msgid "Created a copy of a misnamed branch '%s'"
-msgstr "Copia creada de la rama malnombrada '%s'"
+msgid "%u byte"
+msgid_plural "%u bytes"
+msgstr[0] "%u byte"
+msgstr[1] "%u bytes"
 
-#: builtin/branch.c:523
+#. TRANSLATORS: IEC 80000-13:2008 byte/second
+#: strbuf.c:851
 #, c-format
-msgid "Renamed a misnamed branch '%s' away"
-msgstr "Rama mal llamada '%s' renombrada"
+msgid "%u byte/s"
+msgid_plural "%u bytes/s"
+msgstr[0] "%u bytes/s"
+msgstr[1] "%u bytes/s"
 
-#: builtin/branch.c:529
+#: strbuf.c:1149
 #, c-format
-msgid "Branch renamed to %s, but HEAD is not updated!"
-msgstr "¡Rama renombrada a %s, pero HEAD no está actualizado!"
+msgid "could not edit '%s'"
+msgstr "no se pudo editar '%s'"
 
-#: builtin/branch.c:538
-msgid "Branch is renamed, but update of config-file failed"
+#: submodule.c:114 submodule.c:143
+msgid "Cannot change unmerged .gitmodules, resolve merge conflicts first"
 msgstr ""
-"La rama está renombrada, pero falló la actualización del archivo de "
-"configuración"
+"No se puede cambiar .gitmodules no fusionados, resuelva este problema primero"
 
-#: builtin/branch.c:540
-msgid "Branch is copied, but update of config-file failed"
-msgstr ""
-"La rama está copiada, pero falló la actualización del archivo de "
-"configuración"
+#: submodule.c:118 submodule.c:147
+#, c-format
+msgid "Could not find section in .gitmodules where path=%s"
+msgstr "No se pudo encontrar la sección en .gitmodules donde path=%s"
 
-#: builtin/branch.c:556
+#: submodule.c:154
 #, c-format
-msgid ""
-"Please edit the description for the branch\n"
-"  %s\n"
-"Lines starting with '%c' will be stripped.\n"
-msgstr ""
-"Por favor, edita la descripción para la rama\n"
-"%s\n"
-"Las líneas que comiencen con '%c' serán removidas.\n"
+msgid "Could not remove .gitmodules entry for %s"
+msgstr "No se pudo eliminar la entrada %s de .gitmodules"
 
-#: builtin/branch.c:589
-msgid "Generic options"
-msgstr "Opciones genéricas"
+#: submodule.c:165
+msgid "staging updated .gitmodules failed"
+msgstr "falló realizar stage a los .gitmodules actualizados"
 
-#: builtin/branch.c:591
-msgid "show hash and subject, give twice for upstream branch"
-msgstr "mostrar hash y tema, dar dos veces para rama upstream"
+#: submodule.c:327
+#, c-format
+msgid "in unpopulated submodule '%s'"
+msgstr "en el submódulo no poblado '%s'"
 
-#: builtin/branch.c:592
-msgid "suppress informational messages"
-msgstr "suprimir mensajes informativos"
+#: submodule.c:358
+#, c-format
+msgid "Pathspec '%s' is in submodule '%.*s'"
+msgstr "El patrón de ruta '%s' está en el submódulo '%.*s'"
 
-#: builtin/branch.c:593
-msgid "set up tracking mode (see git-pull(1))"
-msgstr "configurando modo tracking (mirar git-pull(1))"
+#: submodule.c:910
+#, c-format
+msgid "submodule entry '%s' (%s) is a %s, not a commit"
+msgstr "entrada de submódulo '%s' (%s) es un %s, no un commit"
 
-#: builtin/branch.c:595
-msgid "do not use"
-msgstr "no usar"
+#: submodule.c:1147 builtin/branch.c:680 builtin/submodule--helper.c:2016
+msgid "Failed to resolve HEAD as a valid ref."
+msgstr "Falló al resolver HEAD como un ref válido."
 
-#: builtin/branch.c:597
-msgid "upstream"
-msgstr "upstream"
+#: submodule.c:1481
+#, c-format
+msgid "Could not access submodule '%s'"
+msgstr "No pudo acceder al submódulo '%s'"
 
-#: builtin/branch.c:597
-msgid "change the upstream info"
-msgstr "cambiar info de upstream"
+#: submodule.c:1651
+#, c-format
+msgid "'%s' not recognized as a git repository"
+msgstr "'%s' no reconocido como un repositorio git"
 
-#: builtin/branch.c:598
-msgid "Unset the upstream info"
-msgstr "Desconfigurando la info de upstream"
+#: submodule.c:1789
+#, c-format
+msgid "could not start 'git status' in submodule '%s'"
+msgstr "no se pudo comenzar 'git status' en el submódulo '%s'"
 
-#: builtin/branch.c:599
-msgid "use colored output"
-msgstr "usar salida con colores"
+#: submodule.c:1802
+#, c-format
+msgid "could not run 'git status' in submodule '%s'"
+msgstr "no se pudo ejecutar 'git status' en el submódulo '%s'"
 
-#: builtin/branch.c:600
-msgid "act on remote-tracking branches"
-msgstr "actuar en ramas de traqueo remoto"
+#: submodule.c:1817
+#, c-format
+msgid "Could not unset core.worktree setting in submodule '%s'"
+msgstr "No se pudo quitar configuración core.worktree en submódulo '%s'"
 
-#: builtin/branch.c:602 builtin/branch.c:604
-msgid "print only branches that contain the commit"
-msgstr "mostrar solo ramas que contienen el commit"
+#: submodule.c:1907
+#, c-format
+msgid "submodule '%s' has dirty index"
+msgstr "submódulo '%s' tiene un índice corrupto"
 
-#: builtin/branch.c:603 builtin/branch.c:605
-msgid "print only branches that don't contain the commit"
-msgstr "mostrar solo ramas que no contienen el commit"
+#: submodule.c:1959
+#, c-format
+msgid "Submodule '%s' could not be updated."
+msgstr "Submódulo '%s' no pudo ser actualizado."
 
-#: builtin/branch.c:608
-msgid "Specific git-branch actions:"
-msgstr "Acciones específicas de git-branch:"
+#: submodule.c:2027
+#, c-format
+msgid "submodule git dir '%s' is inside git dir '%.*s'"
+msgstr "submódulo git dir '%s' esta dentro de git dir '%.*s'"
 
-#: builtin/branch.c:609
-msgid "list both remote-tracking and local branches"
-msgstr "listar ramas de remote-tracking y locales"
+#: submodule.c:2048
+#, c-format
+msgid ""
+"relocate_gitdir for submodule '%s' with more than one worktree not supported"
+msgstr ""
+"relocate_gitdir para el submódulo '%s' con más de un árbol de trabajo no "
+"soportado"
 
-#: builtin/branch.c:611
-msgid "delete fully merged branch"
-msgstr "borrar ramas totalmente fusionadas"
+#: submodule.c:2060 submodule.c:2119
+#, c-format
+msgid "could not lookup name for submodule '%s'"
+msgstr "no se pudo resolver el nombre para el submódulo '%s'"
 
-#: builtin/branch.c:612
-msgid "delete branch (even if not merged)"
-msgstr "borrar rama (incluso si no esta fusionada)"
+#: submodule.c:2064
+#, c-format
+msgid "refusing to move '%s' into an existing git dir"
+msgstr "rechazando mover '%s' dentro de un directorio git existente"
 
-#: builtin/branch.c:613
-msgid "move/rename a branch and its reflog"
-msgstr "mover/renombrar una rama y su reflog"
+#: submodule.c:2071
+#, c-format
+msgid ""
+"Migrating git directory of '%s%s' from\n"
+"'%s' to\n"
+"'%s'\n"
+msgstr ""
+"Migrando directorio git de '%s%s' desde\n"
+"'%s' hacia\n"
+"'%s'\n"
 
-#: builtin/branch.c:614
-msgid "move/rename a branch, even if target exists"
-msgstr "mover/renombrar una rama, incluso si el destino existe"
+#: submodule.c:2154
+#, c-format
+msgid "could not recurse into submodule '%s'"
+msgstr "no pudo recursar en el submódulo '%s'"
 
-#: builtin/branch.c:615
-msgid "copy a branch and its reflog"
-msgstr "copiar una rama y su reflog"
+#: submodule.c:2198
+msgid "could not start ls-files in .."
+msgstr "no se pudo comenzar ls-files en .."
 
-#: builtin/branch.c:616
-msgid "copy a branch, even if target exists"
-msgstr "copiar una rama, incluso si el objetivo existe"
+#: submodule.c:2237
+#, c-format
+msgid "ls-tree returned unexpected return code %d"
+msgstr "ls-tree devolvió un código %d inesperado"
 
-#: builtin/branch.c:617
-msgid "list branch names"
-msgstr "listar nombres de ramas"
+#: submodule-config.c:236
+#, c-format
+msgid "ignoring suspicious submodule name: %s"
+msgstr "ignorando submódulo sospechoso: %s"
 
-#: builtin/branch.c:618
-msgid "create the branch's reflog"
-msgstr "crea el reflog de la rama"
+#: submodule-config.c:303
+msgid "negative values not allowed for submodule.fetchjobs"
+msgstr "no se permiten valores negativos para submodule.fetchjobs"
 
-#: builtin/branch.c:620
-msgid "edit the description for the branch"
-msgstr "edita la descripción de la rama"
-
-#: builtin/branch.c:621
-msgid "force creation, move/rename, deletion"
-msgstr "fuerza la creación,movimiento/renombrado,borrado"
+#: submodule-config.c:401
+#, c-format
+msgid "ignoring '%s' which may be interpreted as a command-line option: %s"
+msgstr ""
+"ignorando '%s' ya que puede ser interpretado como una opción de línea de "
+"comando: %s"
 
-#: builtin/branch.c:622
-msgid "print only branches that are merged"
-msgstr "muestra solo ramas que han sido fusionadas"
+#: submodule-config.c:498
+#, c-format
+msgid "invalid value for %s"
+msgstr "valor inválido para %s"
 
-#: builtin/branch.c:623
-msgid "print only branches that are not merged"
-msgstr "muestra solo ramas que no han sido fusionadas"
+#: submodule-config.c:769
+#, c-format
+msgid "Could not update .gitmodules entry %s"
+msgstr "No se pudo actualizar la entrada %s de .gitmodules"
 
-#: builtin/branch.c:624
-msgid "list branches in columns"
-msgstr "muestra las ramas en columnas"
+#: trailer.c:238
+#, c-format
+msgid "running trailer command '%s' failed"
+msgstr "ejecución del comando de remolque '%s' falló"
 
-#: builtin/branch.c:625 builtin/for-each-ref.c:40 builtin/ls-remote.c:70
-#: builtin/tag.c:412
-msgid "key"
-msgstr "clave"
+#: trailer.c:485 trailer.c:490 trailer.c:495 trailer.c:549 trailer.c:553
+#: trailer.c:557
+#, c-format
+msgid "unknown value '%s' for key '%s'"
+msgstr "valor '%s' desconocido para la clave '%s'"
 
-#: builtin/branch.c:626 builtin/for-each-ref.c:41 builtin/ls-remote.c:71
-#: builtin/tag.c:413
-msgid "field name to sort on"
-msgstr "nombre del campo por el cuál ordenar"
+#: trailer.c:539 trailer.c:544 builtin/remote.c:295
+#, c-format
+msgid "more than one %s"
+msgstr "más de un %s"
 
-#: builtin/branch.c:628 builtin/for-each-ref.c:43 builtin/notes.c:408
-#: builtin/notes.c:411 builtin/notes.c:571 builtin/notes.c:574
-#: builtin/tag.c:415
-msgid "object"
-msgstr "objeto"
+#: trailer.c:730
+#, c-format
+msgid "empty trailer token in trailer '%.*s'"
+msgstr "token de remolque vacío en el trailer '%.*s'"
 
-#: builtin/branch.c:629
-msgid "print only branches of the object"
-msgstr "imprimir sólo las ramas del objeto"
+#: trailer.c:750
+#, c-format
+msgid "could not read input file '%s'"
+msgstr "no se pudo leer el archivo de entrada '%s'"
 
-#: builtin/branch.c:631 builtin/for-each-ref.c:49 builtin/tag.c:422
-msgid "sorting and filtering are case insensitive"
-msgstr "ordenamiento y filtrado son case-insensitive"
+#: trailer.c:753
+msgid "could not read from stdin"
+msgstr "no se pudo leer desde stdin"
 
-#: builtin/branch.c:632 builtin/for-each-ref.c:38 builtin/tag.c:420
-#: builtin/verify-tag.c:39
-msgid "format to use for the output"
-msgstr "formato para usar para el output"
+#: trailer.c:1011 wrapper.c:665
+#, c-format
+msgid "could not stat %s"
+msgstr "no se pudo definir %s"
 
-#: builtin/branch.c:655 builtin/clone.c:737
-msgid "HEAD not found below refs/heads!"
-msgstr "HEAD no encontrado abajo de refs/heads!"
+#: trailer.c:1013
+#, c-format
+msgid "file %s is not a regular file"
+msgstr "el archivo %s no es un archivo regular"
 
-#: builtin/branch.c:678
-msgid "--column and --verbose are incompatible"
-msgstr "--column y --verbose son incompatibles"
+#: trailer.c:1015
+#, c-format
+msgid "file %s is not writable by user"
+msgstr "el archivo %s no puede ser escrito por el usuario"
 
-#: builtin/branch.c:693 builtin/branch.c:745 builtin/branch.c:754
-msgid "branch name required"
-msgstr "se necesita el nombre de la rama"
+#: trailer.c:1027
+msgid "could not open temporary file"
+msgstr "no se pudo abrir el archivo temporal"
 
-#: builtin/branch.c:721
-msgid "Cannot give description to detached HEAD"
-msgstr "No se puede dar descripción al HEAD desacoplado"
+#: trailer.c:1067
+#, c-format
+msgid "could not rename temporary file to %s"
+msgstr "no se pudo renombrar el archivo temporal a %s"
 
-#: builtin/branch.c:726
-msgid "cannot edit description of more than one branch"
-msgstr "no se puede editar la descripción de más de una rama"
+#: transport.c:116
+#, c-format
+msgid "Would set upstream of '%s' to '%s' of '%s'\n"
+msgstr "Configurará upstream de '%s' a '%s' de '%s'\n"
 
-#: builtin/branch.c:733
+#: transport.c:145
 #, c-format
-msgid "No commit on branch '%s' yet."
-msgstr "Aún no hay commits en la rama '%s'."
+msgid "could not read bundle '%s'"
+msgstr "no se pudo leer el conjunto '%s'"
 
-#: builtin/branch.c:736
+#: transport.c:214
 #, c-format
-msgid "No branch named '%s'."
-msgstr "No hay ninguna rama llamada '%s'."
+msgid "transport: invalid depth option '%s'"
+msgstr "transport: opción inválida '%s'"
 
-#: builtin/branch.c:751
-msgid "too many branches for a copy operation"
-msgstr "demasiadas ramas para una operación de copiado"
+#: transport.c:266
+msgid "see protocol.version in 'git help config' for more details"
+msgstr "ver protocol.version en 'git help config' para más información"
+
+#: transport.c:267
+msgid "server options require protocol version 2 or later"
+msgstr "opciones del servidor requieren protocolo versión 2 o posterior"
 
-#: builtin/branch.c:760
-msgid "too many arguments for a rename operation"
-msgstr "demasiados argumentos para una operación de renombrado"
+#: transport.c:632
+msgid "could not parse transport.color.* config"
+msgstr "no se pudo analizar valor de configuración transport.color.*"
 
-#: builtin/branch.c:765
-msgid "too many arguments to set new upstream"
-msgstr "demasiados argumentos para configurar un nuevo upstream"
+#: transport.c:705
+msgid "support for protocol v2 not implemented yet"
+msgstr "soporte para protocolo v2 no implementado todavía"
+
+#: transport.c:831
+#, c-format
+msgid "unknown value for config '%s': %s"
+msgstr "valor desconocido para configuración '%s': %s"
+
+#: transport.c:897
+#, c-format
+msgid "transport '%s' not allowed"
+msgstr "transporte '%s' no permitido"
+
+#: transport.c:949
+msgid "git-over-rsync is no longer supported"
+msgstr "git-over-rsync ya no es soportado"
 
-#: builtin/branch.c:769
+#: transport.c:1044
 #, c-format
 msgid ""
-"could not set upstream of HEAD to %s when it does not point to any branch."
+"The following submodule paths contain changes that can\n"
+"not be found on any remote:\n"
 msgstr ""
-"no se pudo configurar upstream de HEAD a %s cuando este no apunta a ninguna "
-"rama."
+"La siguiente ruta de submódulo contiene cambios que no\n"
+"pueden ser encontrados en ningún remoto:\n"
 
-#: builtin/branch.c:772 builtin/branch.c:794 builtin/branch.c:810
+#: transport.c:1048
 #, c-format
-msgid "no such branch '%s'"
-msgstr "no hay tal rama '%s'"
+msgid ""
+"\n"
+"Please try\n"
+"\n"
+"\tgit push --recurse-submodules=on-demand\n"
+"\n"
+"or cd to the path and use\n"
+"\n"
+"\tgit push\n"
+"\n"
+"to push them to a remote.\n"
+"\n"
+msgstr ""
+"\n"
+"Por favor intenta\n"
+"\n"
+"\tgit push --recurse-submodules=on-demand\n"
+"\n"
+"o cd a la ruta y usa\n"
+"\n"
+"\tgit push\n"
+"\n"
+"para hacer un push al remoto.\n"
+"\n"
 
-#: builtin/branch.c:776
-#, c-format
-msgid "branch '%s' does not exist"
-msgstr "la rama '%s' no existe"
+#: transport.c:1056
+msgid "Aborting."
+msgstr "Abortando."
 
-#: builtin/branch.c:788
-msgid "too many arguments to unset upstream"
-msgstr "demasiados argumentos para desconfigurar upstream"
+#: transport.c:1201
+msgid "failed to push all needed submodules"
+msgstr "falló al hacer push a todos los submódulos necesarios"
 
-#: builtin/branch.c:792
-msgid "could not unset upstream of HEAD when it does not point to any branch."
-msgstr ""
-"no se puede desconfigurar upstream de HEAD cuando este no apunta a ninguna "
-"rama."
+#: transport.c:1345 transport-helper.c:656
+msgid "operation not supported by protocol"
+msgstr "operación no soportada por protocolo"
+
+#: transport-helper.c:61 transport-helper.c:90
+msgid "full write to remote helper failed"
+msgstr "escritura total al helper remoto falló"
 
-#: builtin/branch.c:798
+#: transport-helper.c:144
 #, c-format
-msgid "Branch '%s' has no upstream information"
-msgstr "Rama '%s' no tiene información de upstream"
+msgid "unable to find remote helper for '%s'"
+msgstr "no es posible encontrar helper remoto para '%s'"
 
-#: builtin/branch.c:813
-msgid "-a and -r options to 'git branch' do not make sense with a branch name"
-msgstr ""
-"opciones -a y -r para 'git branch' no tienen sentido con un nombre de rama"
+#: transport-helper.c:160 transport-helper.c:570
+msgid "can't dup helper output fd"
+msgstr "no se puede duplicar output de fd del helper"
 
-#: builtin/branch.c:816
+#: transport-helper.c:211
+#, c-format
 msgid ""
-"the '--set-upstream' option is no longer supported. Please use '--track' or "
-"'--set-upstream-to' instead."
+"unknown mandatory capability %s; this remote helper probably needs newer "
+"version of Git"
 msgstr ""
-"la opción '--set-upstream' ya no es soportada. Considere usar '--track' o '--"
-"set-upstream-to' en cambio."
+"capacidad mandatoria desconocida %s; este helper remoto probablemente "
+"necesita una nueva versión de Git"
 
-#: builtin/bundle.c:45
+#: transport-helper.c:217
+msgid "this remote helper should implement refspec capability"
+msgstr "este helper remoto debería implementar capacidad refspec"
+
+#: transport-helper.c:284 transport-helper.c:424
 #, c-format
-msgid "%s is okay\n"
-msgstr "%s está bien\n"
+msgid "%s unexpectedly said: '%s'"
+msgstr "%s dijo inesperadamente: '%s'"
 
-#: builtin/bundle.c:58
-msgid "Need a repository to create a bundle."
-msgstr "Se necesita un repositorio para agrupar."
+#: transport-helper.c:413
+#, c-format
+msgid "%s also locked %s"
+msgstr "%s también bloqueó %s"
 
-#: builtin/bundle.c:62
-msgid "Need a repository to unbundle."
-msgstr "Se necesita un repositorio para desagrupar."
+#: transport-helper.c:492
+msgid "couldn't run fast-import"
+msgstr "no se pudo ejecutar fast-import"
 
-#: builtin/cat-file.c:525
-msgid ""
-"git cat-file (-t [--allow-unknown-type] | -s [--allow-unknown-type] | -e | -"
-"p | <type> | --textconv | --filters) [--path=<path>] <object>"
-msgstr ""
-"git cat-file (-t [--allow-unknown-type] | -s [--allow-unknown-type] | -e | -"
-"p | <tipo> | --textconv | --filters) [--path=<ruta>] <objeto>"
+#: transport-helper.c:515
+msgid "error while running fast-import"
+msgstr "error al ejecutar fast-import"
 
-#: builtin/cat-file.c:526
-msgid ""
-"git cat-file (--batch | --batch-check) [--follow-symlinks] [--textconv | --"
-"filters]"
-msgstr ""
-"git cat-file (--batch | --batch-check) [--follow-symlinks] [--textconv | --"
-"filters]"
+#: transport-helper.c:544 transport-helper.c:1133
+#, c-format
+msgid "could not read ref %s"
+msgstr "no se pudo leer la referencia %s"
 
-#: builtin/cat-file.c:563
-msgid "<type> can be one of: blob, tree, commit, tag"
-msgstr "<tipo> puede ser: blob, tree, commit, tag"
+#: transport-helper.c:589
+#, c-format
+msgid "unknown response to connect: %s"
+msgstr "respuesta para conectar desconocida: %s"
 
-#: builtin/cat-file.c:564
-msgid "show object type"
-msgstr "mostrar el tipo del objeto"
+#: transport-helper.c:611
+msgid "setting remote service path not supported by protocol"
+msgstr "configurando servicio de ruta remota no soportado por el protocolo"
 
-#: builtin/cat-file.c:565
-msgid "show object size"
-msgstr "mostrar el tamaño del objeto"
+#: transport-helper.c:613
+msgid "invalid remote service path"
+msgstr "ruta de servicio remoto inválida"
 
-#: builtin/cat-file.c:567
-msgid "exit with zero when there's no error"
-msgstr "salir con cero cuando no haya error"
+#: transport-helper.c:659
+#, c-format
+msgid "can't connect to subservice %s"
+msgstr "no se puede conectar al subservicio %s"
 
-#: builtin/cat-file.c:568
-msgid "pretty-print object's content"
-msgstr "realizar pretty-print del contenido del objeto"
+#: transport-helper.c:735
+#, c-format
+msgid "expected ok/error, helper said '%s'"
+msgstr "se esperaba ok/error, helper dijo '%s'"
 
-#: builtin/cat-file.c:570
-msgid "for blob objects, run textconv on object's content"
-msgstr "para objetos blob, ejecuta textconv en el contenido del objeto"
+#: transport-helper.c:788
+#, c-format
+msgid "helper reported unexpected status of %s"
+msgstr "helper reportó estado inesperado de %s"
 
-#: builtin/cat-file.c:572
-msgid "for blob objects, run filters on object's content"
-msgstr "para objetos blob, ejecuta filters en el contenido del objeto"
+#: transport-helper.c:849
+#, c-format
+msgid "helper %s does not support dry-run"
+msgstr "helper %s no soporta dry-run"
 
-#: builtin/cat-file.c:573 git-submodule.sh:894
-msgid "blob"
-msgstr "blob"
+#: transport-helper.c:852
+#, c-format
+msgid "helper %s does not support --signed"
+msgstr "helper %s no soporta --signed"
 
-#: builtin/cat-file.c:574
-msgid "use a specific path for --textconv/--filters"
-msgstr "use una ruta específica para --textconv/--filters"
+#: transport-helper.c:855
+#, c-format
+msgid "helper %s does not support --signed=if-asked"
+msgstr "helper %s no soporta --signed=if-asked"
 
-#: builtin/cat-file.c:576
-msgid "allow -s and -t to work with broken/corrupt objects"
-msgstr "permita -s y -t para trabajar con objetos rotos o corruptos"
+#: transport-helper.c:860
+#, c-format
+msgid "helper %s does not support --atomic"
+msgstr "helper %s no soporta --atomic"
 
-#: builtin/cat-file.c:577
-msgid "buffer --batch output"
-msgstr "salida buffer --batch"
+#: transport-helper.c:866
+#, c-format
+msgid "helper %s does not support 'push-option'"
+msgstr "helper %s no soporta 'push-option'"
 
-#: builtin/cat-file.c:579
-msgid "show info and content of objects fed from the standard input"
-msgstr "mostrar info y content de los objetos alimentados por standard input"
+#: transport-helper.c:964
+msgid "remote-helper doesn't support push; refspec needed"
+msgstr "remote-helper no soporta push; se necesita refspec"
 
-#: builtin/cat-file.c:582
-msgid "show info about objects fed from the standard input"
-msgstr "mostrar info de los objetos alimentados por standard input"
+#: transport-helper.c:969
+#, c-format
+msgid "helper %s does not support 'force'"
+msgstr "helper %s no soporta 'force'"
 
-#: builtin/cat-file.c:585
-msgid "follow in-tree symlinks (used with --batch or --batch-check)"
-msgstr ""
-"seguir los enlaces simbólicos en el árbol (usado con --batch o --batch-check)"
+#: transport-helper.c:1016
+msgid "couldn't run fast-export"
+msgstr "no se pudo ejecutar fast-export"
 
-#: builtin/cat-file.c:587
-msgid "show all objects with --batch or --batch-check"
-msgstr "mostrar todos los objetos con --batch o --batch-check"
+#: transport-helper.c:1021
+msgid "error while running fast-export"
+msgstr "error al ejecutar fast-export"
 
-#: builtin/check-attr.c:12
-msgid "git check-attr [-a | --all | <attr>...] [--] <pathname>..."
-msgstr "git check-attr [-a | --all | <attr>...] [--] <nombre-de-ruta>..."
+#: transport-helper.c:1046
+#, c-format
+msgid ""
+"No refs in common and none specified; doing nothing.\n"
+"Perhaps you should specify a branch such as 'master'.\n"
+msgstr ""
+"No hay refs comunes y ninguno especificado; no se hace nada.\n"
+"Tal vez deberías especificar un branch como 'master'.\n"
 
-#: builtin/check-attr.c:13
-msgid "git check-attr --stdin [-z] [-a | --all | <attr>...]"
-msgstr "git check-attr --stdin [-z] [-a | --all | <attr>...]"
+#: transport-helper.c:1119
+#, c-format
+msgid "malformed response in ref list: %s"
+msgstr "respuesta malformada en lista de refs: %s"
 
-#: builtin/check-attr.c:20
-msgid "report all attributes set on file"
-msgstr "reportar todos los atributos configurados en el archivo"
+#: transport-helper.c:1271
+#, c-format
+msgid "read(%s) failed"
+msgstr "leer(%s) falló"
 
-#: builtin/check-attr.c:21
-msgid "use .gitattributes only from the index"
-msgstr "use .gitattributes solo desde el índice"
+#: transport-helper.c:1298
+#, c-format
+msgid "write(%s) failed"
+msgstr "escribir(%s) falló"
 
-#: builtin/check-attr.c:22 builtin/check-ignore.c:24 builtin/hash-object.c:100
-msgid "read file names from stdin"
-msgstr "leer nombres de archivos de stdin"
+#: transport-helper.c:1347
+#, c-format
+msgid "%s thread failed"
+msgstr "hilo %s falló"
 
-#: builtin/check-attr.c:24 builtin/check-ignore.c:26
-msgid "terminate input and output records by a NUL character"
-msgstr "terminar registros de entrada y salida con un carácter NUL"
+#: transport-helper.c:1351
+#, c-format
+msgid "%s thread failed to join: %s"
+msgstr "hilo %s falló al unirse: %s"
 
-#: builtin/check-ignore.c:20 builtin/checkout.c:1113 builtin/gc.c:500
-msgid "suppress progress reporting"
-msgstr "suprimir el reporte de progreso"
+#: transport-helper.c:1370 transport-helper.c:1374
+#, c-format
+msgid "can't start thread for copying data: %s"
+msgstr "no se puede iniciar el hilo para copiar data: %s"
 
-#: builtin/check-ignore.c:28
-msgid "show non-matching input paths"
-msgstr "mostrar rutas de entrada que no concuerdan"
+#: transport-helper.c:1411
+#, c-format
+msgid "%s process failed to wait"
+msgstr "proceso %s falló al esperar"
 
-#: builtin/check-ignore.c:30
-msgid "ignore index when checking"
-msgstr "ignorar el índice cuando se revise"
+#: transport-helper.c:1415
+#, c-format
+msgid "%s process failed"
+msgstr "proceso %s falló"
 
-#: builtin/check-ignore.c:159
-msgid "cannot specify pathnames with --stdin"
-msgstr "no se puede especificar los nombres de rutas con --stdin"
+#: transport-helper.c:1433 transport-helper.c:1442
+msgid "can't start thread for copying data"
+msgstr "no se puede iniciar hilo para copiar data"
 
-#: builtin/check-ignore.c:162
-msgid "-z only makes sense with --stdin"
-msgstr "-z sólo tiene sentido con --stdin"
-
-#: builtin/check-ignore.c:164
-msgid "no path specified"
-msgstr "ruta no especificada"
-
-#: builtin/check-ignore.c:168
-msgid "--quiet is only valid with a single pathname"
-msgstr "--quiet solo es válido con un nombre de ruta único"
-
-#: builtin/check-ignore.c:170
-msgid "cannot have both --quiet and --verbose"
-msgstr "no se puede tener ambos --quiet y --verbose"
-
-#: builtin/check-ignore.c:173
-msgid "--non-matching is only valid with --verbose"
-msgstr "--non-matching sólo es válida con --verbose"
+#: tree-walk.c:33
+msgid "too-short tree object"
+msgstr "objeto de árbol muy corto"
 
-#: builtin/check-mailmap.c:9
-msgid "git check-mailmap [<options>] <contact>..."
-msgstr "git check-mailmap [<opciones>] <contacto>..."
+#: tree-walk.c:39
+msgid "malformed mode in tree entry"
+msgstr "modo mal formado en la entrada de árbol"
 
-#: builtin/check-mailmap.c:14
-msgid "also read contacts from stdin"
-msgstr "también leer contactos desde stdin"
+#: tree-walk.c:43
+msgid "empty filename in tree entry"
+msgstr "nombre de archivo vacío en la entrada de árbol"
 
-#: builtin/check-mailmap.c:25
+#: tree-walk.c:48
 #, c-format
-msgid "unable to parse contact: %s"
-msgstr "no es posible analizar el contacto: %s"
-
-#: builtin/check-mailmap.c:48
-msgid "no contacts specified"
-msgstr "contactos no especificados"
+msgid "filename in tree entry contains backslash: '%s'"
+msgstr "nombre de archivo en el árbol contiene un backslash: '%s'"
 
-#: builtin/checkout-index.c:128
-msgid "git checkout-index [<options>] [--] [<file>...]"
-msgstr "git checkout-index [<opciones>] [--] [<archivo>...]"
-
-#: builtin/checkout-index.c:143
-msgid "stage should be between 1 and 3 or all"
-msgstr "stage tiene que estar entre 1 y 3 o all"
-
-#: builtin/checkout-index.c:159
-msgid "check out all files in the index"
-msgstr "revisar todos los archivos en el índice"
-
-#: builtin/checkout-index.c:160
-msgid "force overwrite of existing files"
-msgstr "forzar sobreescritura de los archivos existentes"
+#: tree-walk.c:124
+msgid "too-short tree file"
+msgstr "archivo de árbol muy corto"
 
-#: builtin/checkout-index.c:162
-msgid "no warning for existing files and files not in index"
+#: unpack-trees.c:110
+#, c-format
+msgid ""
+"Your local changes to the following files would be overwritten by checkout:\n"
+"%%sPlease commit your changes or stash them before you switch branches."
 msgstr ""
-"no hay advertencias para los archivos existentes y los archivos no están en "
-"el índice"
-
-#: builtin/checkout-index.c:164
-msgid "don't checkout new files"
-msgstr "no revisar archivos nuevos"
-
-#: builtin/checkout-index.c:166
-msgid "update stat information in the index file"
-msgstr "actualizar información de estado en el archivo índice"
-
-#: builtin/checkout-index.c:170
-msgid "read list of paths from the standard input"
-msgstr "leer lista de rutas desde standard input"
-
-#: builtin/checkout-index.c:172
-msgid "write the content to temporary files"
-msgstr "escribir el contenido en un archivo temporal"
-
-#: builtin/checkout-index.c:173 builtin/column.c:31
-#: builtin/submodule--helper.c:1216 builtin/submodule--helper.c:1219
-#: builtin/submodule--helper.c:1227 builtin/submodule--helper.c:1591
-#: builtin/worktree.c:610
-msgid "string"
-msgstr "string"
-
-#: builtin/checkout-index.c:174
-msgid "when creating files, prepend <string>"
-msgstr "cuando cree archivos, anteponer <string>"
-
-#: builtin/checkout-index.c:176
-msgid "copy out the files from named stage"
-msgstr "copiar los archivos del stage nombrado"
-
-#: builtin/checkout.c:27
-msgid "git checkout [<options>] <branch>"
-msgstr "git checkout [<opciones>]  <rama>"
-
-#: builtin/checkout.c:28
-msgid "git checkout [<options>] [<branch>] -- <file>..."
-msgstr "git checkout [<opciones>] [<rama>] -- <archivo>..."
+"Los cambios locales de los siguientes archivos serán sobrescritos por "
+"checkout:\n"
+"%%sPor favor realiza un commit con los cambios o un stash antes de cambiar "
+"ramas."
 
-#: builtin/checkout.c:136 builtin/checkout.c:169
+#: unpack-trees.c:112
 #, c-format
-msgid "path '%s' does not have our version"
-msgstr "ruta '%s' no tiene nuestra versión"
+msgid ""
+"Your local changes to the following files would be overwritten by checkout:\n"
+"%%s"
+msgstr ""
+"Los cambios locales de los siguientes archivos serán sobreescritos por "
+"checkout:\n"
+"%%s"
 
-#: builtin/checkout.c:138 builtin/checkout.c:171
+#: unpack-trees.c:115
 #, c-format
-msgid "path '%s' does not have their version"
-msgstr "ruta '%s' no tiene su versión"
+msgid ""
+"Your local changes to the following files would be overwritten by merge:\n"
+"%%sPlease commit your changes or stash them before you merge."
+msgstr ""
+"Los cambios locales de los siguientes archivos serán sobrescritos al "
+"fusionar:\n"
+"%%sPor favor, confirma tus cambios o aguárdalos antes de fusionar."
 
-#: builtin/checkout.c:154
+#: unpack-trees.c:117
 #, c-format
-msgid "path '%s' does not have all necessary versions"
-msgstr "ruta '%s' no tiene todas las versiones necesarias"
+msgid ""
+"Your local changes to the following files would be overwritten by merge:\n"
+"%%s"
+msgstr ""
+"Los cambios locales de los siguientes archivos serán sobreescritos por "
+"merge:\n"
+"%%s"
 
-#: builtin/checkout.c:198
+#: unpack-trees.c:120
 #, c-format
-msgid "path '%s' does not have necessary versions"
-msgstr "ruta '%s' no tiene versiones necesarias"
+msgid ""
+"Your local changes to the following files would be overwritten by %s:\n"
+"%%sPlease commit your changes or stash them before you %s."
+msgstr ""
+"Los cambios locales de los siguientes archivos serán sobrescritos al %s:\n"
+"%%sPor favor, confirma tus cambios o guárdalos antes de %s."
 
-#: builtin/checkout.c:215
+#: unpack-trees.c:122
 #, c-format
-msgid "path '%s': cannot merge"
-msgstr "ruta '%s': no se puede fusionar"
+msgid ""
+"Your local changes to the following files would be overwritten by %s:\n"
+"%%s"
+msgstr ""
+"Los cambios locales de los siguientes archivos serán sobreescritos por %s:\n"
+"%%s"
 
-#: builtin/checkout.c:231
+#: unpack-trees.c:127
 #, c-format
-msgid "Unable to add merge result for '%s'"
-msgstr "Incapaz de agregar resultados de fusión a '%s'"
+msgid ""
+"Updating the following directories would lose untracked files in them:\n"
+"%s"
+msgstr ""
+"Al actualizar los siguientes directorios se perderán los archivos sin "
+"seguimiento en ellos:\n"
+"%s"
 
-#: builtin/checkout.c:253 builtin/checkout.c:256 builtin/checkout.c:259
-#: builtin/checkout.c:262
+#: unpack-trees.c:131
 #, c-format
-msgid "'%s' cannot be used with updating paths"
-msgstr "'%s' no puede ser usada con rutas actualizadas"
+msgid ""
+"The following untracked working tree files would be removed by checkout:\n"
+"%%sPlease move or remove them before you switch branches."
+msgstr ""
+"Los siguientes archivos sin seguimiento en el árbol de trabajo serán "
+"eliminados al actualizar el árbol de trabajo:\n"
+"%%sPor favor, muévelos o elimínalos antes de intercambiar ramas."
 
-#: builtin/checkout.c:265 builtin/checkout.c:268
+#: unpack-trees.c:133
 #, c-format
-msgid "'%s' cannot be used with %s"
-msgstr "'%s' no puede ser usado con %s"
+msgid ""
+"The following untracked working tree files would be removed by checkout:\n"
+"%%s"
+msgstr ""
+"Los siguientes archivos sin seguimiento del árbol de trabajo serán "
+"eliminadosal actualizar el árbol de trabajo:\n"
+"%%s"
 
-#: builtin/checkout.c:271
+#: unpack-trees.c:136
 #, c-format
-msgid "Cannot update paths and switch to branch '%s' at the same time."
-msgstr "No se puede actualizar rutas y cambiar a la rama '%s' al mismo tiempo."
+msgid ""
+"The following untracked working tree files would be removed by merge:\n"
+"%%sPlease move or remove them before you merge."
+msgstr ""
+"Los siguientes archivos sin seguimiento en el árbol de trabajo serán "
+"eliminados al fusionar:\n"
+"%%sPor favor, muévelos o elimínalos antes de fusionar."
 
-#: builtin/checkout.c:340 builtin/checkout.c:347
+#: unpack-trees.c:138
 #, c-format
-msgid "path '%s' is unmerged"
-msgstr "ruta '%s' no esta fusionada"
+msgid ""
+"The following untracked working tree files would be removed by merge:\n"
+"%%s"
+msgstr ""
+"Los siguientes archivos sin seguimiento de árbol de trabajo serán "
+"eliminadosal fusionar:\n"
+"%%s"
 
-#: builtin/checkout.c:506
-msgid "you need to resolve your current index first"
-msgstr "necesita resolver su índice actual primero"
+#: unpack-trees.c:141
+#, c-format
+msgid ""
+"The following untracked working tree files would be removed by %s:\n"
+"%%sPlease move or remove them before you %s."
+msgstr ""
+"Los siguientes archivos sin seguimiento en el árbol de trabajo serán "
+"eliminados al %s:\n"
+"%%sPor favor, muévelos o elimínalos antes de %s."
 
-#: builtin/checkout.c:643
+#: unpack-trees.c:143
 #, c-format
-msgid "Can not do reflog for '%s': %s\n"
-msgstr "No se puede hacer reflog para '%s': %s\n"
+msgid ""
+"The following untracked working tree files would be removed by %s:\n"
+"%%s"
+msgstr ""
+"Los siguientes archivos sin seguimiento en el árbol de trabajo serán "
+"eliminados al ejecutar %s:\n"
+"%%s"
 
-#: builtin/checkout.c:684
-msgid "HEAD is now at"
-msgstr "HEAD está ahora en"
+#: unpack-trees.c:149
+#, c-format
+msgid ""
+"The following untracked working tree files would be overwritten by "
+"checkout:\n"
+"%%sPlease move or remove them before you switch branches."
+msgstr ""
+"Los siguientes archivos sin seguimiento en el árbol de trabajo serán "
+"sobrescritos al actualizar el árbol de trabajo:\n"
+"%%sPor favor, muévelos o elimínalos antes de intercambiar ramas."
 
-#: builtin/checkout.c:688 builtin/clone.c:691
-msgid "unable to update HEAD"
-msgstr "no es posible actualizar  HEAD"
+#: unpack-trees.c:151
+#, c-format
+msgid ""
+"The following untracked working tree files would be overwritten by "
+"checkout:\n"
+"%%s"
+msgstr ""
+"Los siguientes archivos sin seguimiento de árbol de trabajo serán "
+"sobrescritos al actualizar el árbol de trabajo:\n"
+"%%s"
 
-#: builtin/checkout.c:692
+#: unpack-trees.c:154
 #, c-format
-msgid "Reset branch '%s'\n"
-msgstr "Reiniciar rama '%s'\n"
+msgid ""
+"The following untracked working tree files would be overwritten by merge:\n"
+"%%sPlease move or remove them before you merge."
+msgstr ""
+"Los siguientes archivos sin seguimiento en el árbol de trabajo serán "
+"sobrescritos al fusionar:\n"
+"%%sPor favor, muévelos o elimínalos antes de fusionar."
 
-#: builtin/checkout.c:695
+#: unpack-trees.c:156
 #, c-format
-msgid "Already on '%s'\n"
-msgstr "Ya en '%s'\n"
+msgid ""
+"The following untracked working tree files would be overwritten by merge:\n"
+"%%s"
+msgstr ""
+"Los siguientes archivos sin seguimiento de árbol de trabajo serán "
+"sobrescritos al fusionar:\n"
+"%%s"
 
-#: builtin/checkout.c:699
+#: unpack-trees.c:159
 #, c-format
-msgid "Switched to and reset branch '%s'\n"
-msgstr "Rama reiniciada y cambiada a '%s'\n"
+msgid ""
+"The following untracked working tree files would be overwritten by %s:\n"
+"%%sPlease move or remove them before you %s."
+msgstr ""
+"Los siguientes archivos sin seguimiento en el árbol de trabajo serán "
+"sobrescritos al %s:\n"
+"%%sPor favor, muévelos o elimínalos antes de %s."
 
-#: builtin/checkout.c:701 builtin/checkout.c:1046
+#: unpack-trees.c:161
 #, c-format
-msgid "Switched to a new branch '%s'\n"
-msgstr "Cambiado a nueva rama '%s'\n"
+msgid ""
+"The following untracked working tree files would be overwritten by %s:\n"
+"%%s"
+msgstr ""
+"Los siguientes archivos no rastreados en el árbol de trabajo serán "
+"eliminadospor %s:\n"
+"%%s"
 
-#: builtin/checkout.c:703
+#: unpack-trees.c:169
 #, c-format
-msgid "Switched to branch '%s'\n"
-msgstr "Cambiado a rama '%s'\n"
+msgid "Entry '%s' overlaps with '%s'.  Cannot bind."
+msgstr "Entrada '%s' se superpone con '%s'.  No se pueden unir."
 
-#: builtin/checkout.c:754
+#: unpack-trees.c:172
 #, c-format
-msgid " ... and %d more.\n"
-msgstr " ... y %d más.\n"
+msgid ""
+"Cannot update sparse checkout: the following entries are not up to date:\n"
+"%s"
+msgstr ""
+"No se puede actualizar el sparse checkout: las siguientes entradas no están "
+"actualizadas:\n"
+"%s"
 
-#: builtin/checkout.c:760
+#: unpack-trees.c:174
 #, c-format
 msgid ""
-"Warning: you are leaving %d commit behind, not connected to\n"
-"any of your branches:\n"
-"\n"
-"%s\n"
-msgid_plural ""
-"Warning: you are leaving %d commits behind, not connected to\n"
-"any of your branches:\n"
-"\n"
-"%s\n"
-msgstr[0] ""
-"Peligro: está saliendo %d commit atrás, no está conectado\n"
-"a ninguna rama:\n"
-"\n"
-"%s\n"
-msgstr[1] ""
-"Peligro: está saliendo %d commits atrás, no está conectado\n"
-"a ninguna rama:\n"
-"\n"
-"%s\n"
+"The following working tree files would be overwritten by sparse checkout "
+"update:\n"
+"%s"
+msgstr ""
+"Los siguientes archivos del árbol de trabajo serán sobrescritos por la "
+"actualización sparse checkout:\n"
+"%s"
 
-#: builtin/checkout.c:779
+#: unpack-trees.c:176
 #, c-format
 msgid ""
-"If you want to keep it by creating a new branch, this may be a good time\n"
-"to do so with:\n"
-"\n"
-" git branch <new-branch-name> %s\n"
-"\n"
-msgid_plural ""
-"If you want to keep them by creating a new branch, this may be a good time\n"
-"to do so with:\n"
-"\n"
-" git branch <new-branch-name> %s\n"
-"\n"
-msgstr[0] ""
-"Si quiere conservarlo creando una nueva rama, este es un buen momento\n"
-"para hacerlo:\n"
-"\n"
-" git branch <nuevo-nombre-de-rama> %s\n"
-"\n"
-msgstr[1] ""
-"Si quiere conservarlos creando una nueva rama, este es un buen momento\n"
-"para hacerlo:\n"
-"\n"
-" git branch <nombre-de-rama> %s\n"
-"\n"
+"The following working tree files would be removed by sparse checkout "
+"update:\n"
+"%s"
+msgstr ""
+"Los siguientes archivos del árbol de trabajo serán eliminados por la "
+"actualización sparse checkout:\n"
+"%s"
 
-#: builtin/checkout.c:811
-msgid "internal error in revision walk"
-msgstr "error interno en camino de revisión"
+#: unpack-trees.c:178
+#, c-format
+msgid ""
+"Cannot update submodule:\n"
+"%s"
+msgstr ""
+"No se puede actualizar le submódulo:\n"
+"%s"
 
-#: builtin/checkout.c:815
-msgid "Previous HEAD position was"
-msgstr "La posición previa de HEAD era"
+#: unpack-trees.c:255
+#, c-format
+msgid "Aborting\n"
+msgstr "Abortando\n"
 
-#: builtin/checkout.c:843 builtin/checkout.c:1041
-msgid "You are on a branch yet to be born"
-msgstr "Estás en una rama por nacer"
+#: unpack-trees.c:317
+msgid "Updating files"
+msgstr "Actualizando archivos"
+
+#: unpack-trees.c:349
+msgid ""
+"the following paths have collided (e.g. case-sensitive paths\n"
+"on a case-insensitive filesystem) and only one from the same\n"
+"colliding group is in the working tree:\n"
+msgstr ""
+"las siguientes rutas han colisionado (p.e. rutas con case-sensitive\n"
+"en un filesystem case-insensitive) y solo una del grupo\n"
+"colisionando está en el árbol de trabajo:\n"
+
+#: unpack-trees.c:1441
+msgid "Updating index flags"
+msgstr "Actualizando flags del index"
 
-#: builtin/checkout.c:947
+#: urlmatch.c:163
+msgid "invalid URL scheme name or missing '://' suffix"
+msgstr "nombre de URL inválido o sufijo '://' faltante"
+
+#: urlmatch.c:187 urlmatch.c:346 urlmatch.c:405
 #, c-format
-msgid "only one reference expected, %d given."
-msgstr "solo una referencia esperada, %d entregadas."
+msgid "invalid %XX escape sequence"
+msgstr "secuencia de escape %XX inválida"
+
+#: urlmatch.c:215
+msgid "missing host and scheme is not 'file:'"
+msgstr "falta host y el esquema no es 'file:'"
+
+#: urlmatch.c:232
+msgid "a 'file:' URL may not have a port number"
+msgstr "un 'archivo:' URL puede no tener un número de puerto"
+
+#: urlmatch.c:247
+msgid "invalid characters in host name"
+msgstr "carácter inválido en el nombre del host"
+
+#: urlmatch.c:292 urlmatch.c:303
+msgid "invalid port number"
+msgstr "numero de puerto inválido"
+
+#: urlmatch.c:371
+msgid "invalid '..' path segment"
+msgstr "segmento de ruta '..' inválido"
 
-#: builtin/checkout.c:987 builtin/worktree.c:240 builtin/worktree.c:389
+#: worktree.c:258 builtin/am.c:2084
 #, c-format
-msgid "invalid reference: %s"
-msgstr "referencia invalida: %s"
+msgid "failed to read '%s'"
+msgstr "falló al leer '%s'"
 
-#: builtin/checkout.c:1016
+#: worktree.c:304
 #, c-format
-msgid "reference is not a tree: %s"
-msgstr "la referencia no es n árbol: %s"
+msgid "'%s' at main working tree is not the repository directory"
+msgstr ""
+"'%s' en el árbol de trabajo principal no es el directorio del repositorio"
 
-#: builtin/checkout.c:1055
-msgid "paths cannot be used with switching branches"
-msgstr "rutas no pueden ser usadas con cambios de rama"
+#: worktree.c:315
+#, c-format
+msgid "'%s' file does not contain absolute path to the working tree location"
+msgstr ""
+"archivo '%s' no contiene una ruta absoluta a la ubicación del árbol de "
+"trabajo"
 
-#: builtin/checkout.c:1058 builtin/checkout.c:1062
+#: worktree.c:327
 #, c-format
-msgid "'%s' cannot be used with switching branches"
-msgstr "'%s' no puede ser usado con cambios de ramas"
+msgid "'%s' does not exist"
+msgstr "'%s' no existe"
 
-#: builtin/checkout.c:1066 builtin/checkout.c:1069 builtin/checkout.c:1074
-#: builtin/checkout.c:1077
+#: worktree.c:333
 #, c-format
-msgid "'%s' cannot be used with '%s'"
-msgstr "'%s' no puede ser usado con '%s'"
+msgid "'%s' is not a .git file, error code %d"
+msgstr "'%s' no es un archivo .git, código de error %d"
 
-#: builtin/checkout.c:1082
+#: worktree.c:341
 #, c-format
-msgid "Cannot switch branch to a non-commit '%s'"
-msgstr "No se puede cambiar rama a un '%s' sin commits"
+msgid "'%s' does not point back to '%s'"
+msgstr "'%s' no apunta de vuelta a '%s'"
 
-#: builtin/checkout.c:1114 builtin/checkout.c:1116 builtin/clone.c:118
-#: builtin/remote.c:167 builtin/remote.c:169 builtin/worktree.c:433
-#: builtin/worktree.c:435
-msgid "branch"
-msgstr "rama"
+#: wrapper.c:186 wrapper.c:356
+#, c-format
+msgid "could not open '%s' for reading and writing"
+msgstr "no se pudo abrir '%s' para lectura y escritura"
 
-#: builtin/checkout.c:1115
-msgid "create and checkout a new branch"
-msgstr "crear y hacer checkout a una nueva rama"
+#: wrapper.c:387 wrapper.c:588
+#, c-format
+msgid "unable to access '%s'"
+msgstr "no es posible acceder '%s'"
 
-#: builtin/checkout.c:1117
-msgid "create/reset and checkout a branch"
-msgstr "crear/reiniciar y hacer checkout a una rama"
+#: wrapper.c:596
+msgid "unable to get current working directory"
+msgstr "no es posible obtener el directorio de trabajo actual"
 
-#: builtin/checkout.c:1118
-msgid "create reflog for new branch"
-msgstr "crear un reflog para una nueva rama"
+#: wt-status.c:158
+msgid "Unmerged paths:"
+msgstr "Rutas no fusionadas:"
 
-#: builtin/checkout.c:1119 builtin/worktree.c:437
-msgid "detach HEAD at named commit"
-msgstr "desacoplar HEAD en el commit nombrado"
+#: wt-status.c:187 wt-status.c:219
+msgid "  (use \"git restore --staged <file>...\" to unstage)"
+msgstr ""
+"  (usa \"git restore --staged <archivo>...\" para sacar del área de stage)"
 
-#: builtin/checkout.c:1120
-msgid "set upstream info for new branch"
-msgstr "configurar info de upstream para una rama nueva"
+#: wt-status.c:190 wt-status.c:222
+#, c-format
+msgid "  (use \"git restore --source=%s --staged <file>...\" to unstage)"
+msgstr ""
+"  (usa \"git restore --source=%s --staged <archivo>...\" para sacar del área "
+"de stage)"
 
-#: builtin/checkout.c:1122
-msgid "new-branch"
-msgstr "nueva-rama"
+#: wt-status.c:193 wt-status.c:225
+msgid "  (use \"git rm --cached <file>...\" to unstage)"
+msgstr "  (usa \"git rm --cached <archivo>...\" para sacar del área de stage)"
 
-#: builtin/checkout.c:1122
-msgid "new unparented branch"
-msgstr "nueva rama no emparentada"
+#: wt-status.c:197
+msgid "  (use \"git add <file>...\" to mark resolution)"
+msgstr "  (usa \"git add <archivo>...\" para marcar una resolución)"
 
-#: builtin/checkout.c:1123
-msgid "checkout our version for unmerged files"
-msgstr "hacer checkout a  nuestra versión para archivos sin fusionar"
+#: wt-status.c:199 wt-status.c:203
+msgid "  (use \"git add/rm <file>...\" as appropriate to mark resolution)"
+msgstr ""
+"  (usa \"git add/rm <archivo>...\" como una forma apropiada de marcar la "
+"resolución)"
 
-#: builtin/checkout.c:1125
-msgid "checkout their version for unmerged files"
-msgstr "hacer checkout a su versión para los archivos sin fusionar"
+#: wt-status.c:201
+msgid "  (use \"git rm <file>...\" to mark resolution)"
+msgstr "  (usa \"git rm <file>...\" para marcar la resolución)"
 
-#: builtin/checkout.c:1127
-msgid "force checkout (throw away local modifications)"
-msgstr "forzar el checkout (descartar modificaciones locales)"
+#: wt-status.c:211 wt-status.c:1074
+msgid "Changes to be committed:"
+msgstr "Cambios a ser confirmados:"
 
-#: builtin/checkout.c:1129
-msgid "perform a 3-way merge with the new branch"
-msgstr "realizar una fusión de tres vías con la rama nueva"
+#: wt-status.c:234 wt-status.c:1083
+msgid "Changes not staged for commit:"
+msgstr "Cambios no rastreados para el commit:"
 
-#: builtin/checkout.c:1131 builtin/merge.c:241
-msgid "update ignored files (default)"
-msgstr "actualizar archivos ignorados (default)"
+#: wt-status.c:238
+msgid "  (use \"git add <file>...\" to update what will be committed)"
+msgstr ""
+"  (usa \"git add <archivo>...\" para actualizar lo que será confirmado)"
 
-#: builtin/checkout.c:1133 builtin/log.c:1499 parse-options.h:264
-msgid "style"
-msgstr "estilo"
+#: wt-status.c:240
+msgid "  (use \"git add/rm <file>...\" to update what will be committed)"
+msgstr ""
+"  (usa \"git add/rm <archivo>...\" para actualizar a lo que se le va a hacer "
+"commit)"
 
-#: builtin/checkout.c:1134
-msgid "conflict style (merge or diff3)"
-msgstr "conflicto de estilos (merge o diff3)"
+#: wt-status.c:241
+msgid ""
+"  (use \"git restore <file>...\" to discard changes in working directory)"
+msgstr ""
+"  (usa \"git restore <archivo>...\" para descartar los cambios en el "
+"directorio de trabajo)"
 
-#: builtin/checkout.c:1137
-msgid "do not limit pathspecs to sparse entries only"
-msgstr "no limitar pathspecs a dispersar entradas solamente"
+#: wt-status.c:243
+msgid "  (commit or discard the untracked or modified content in submodules)"
+msgstr ""
+"  (confirmar o descartar el contenido sin seguimiento o modificado en los "
+"sub-módulos)"
 
-#: builtin/checkout.c:1139
-msgid "second guess 'git checkout <no-such-branch>'"
-msgstr "segunda opción 'git checkout <no-hay-tal-rama>'"
+#: wt-status.c:254
+#, c-format
+msgid "  (use \"git %s <file>...\" to include in what will be committed)"
+msgstr ""
+"  (usa \"git %s <archivo>...\" para incluirlo a lo que se será confirmado)"
 
-#: builtin/checkout.c:1141
-msgid "do not check if another worktree is holding the given ref"
-msgstr "no revise si otro árbol de trabajo contiene la ref entregada"
+#: wt-status.c:268
+msgid "both deleted:"
+msgstr "ambos borrados:"
 
-#: builtin/checkout.c:1145 builtin/clone.c:85 builtin/fetch.c:149
-#: builtin/merge.c:238 builtin/pull.c:128 builtin/push.c:572
-#: builtin/send-pack.c:174
-msgid "force progress reporting"
-msgstr "forzar el reporte de progreso"
+#: wt-status.c:270
+msgid "added by us:"
+msgstr "agregado por nosotros:"
 
-#: builtin/checkout.c:1175
-msgid "-b, -B and --orphan are mutually exclusive"
-msgstr "-b, -B y --orphan son mutuamente exclusivas"
+#: wt-status.c:272
+msgid "deleted by them:"
+msgstr "borrados por ellos:"
 
-#: builtin/checkout.c:1192
-msgid "--track needs a branch name"
-msgstr "--track necesita el nombre de una rama"
+#: wt-status.c:274
+msgid "added by them:"
+msgstr "agregado por ellos:"
 
-#: builtin/checkout.c:1197
-msgid "Missing branch name; try -b"
-msgstr "Falta nombre de rama; prueba -b"
+#: wt-status.c:276
+msgid "deleted by us:"
+msgstr "borrado por nosotros:"
 
-#: builtin/checkout.c:1233
-msgid "invalid path specification"
-msgstr "especificación de ruta invalida"
+#: wt-status.c:278
+msgid "both added:"
+msgstr "ambos agregados:"
 
-#: builtin/checkout.c:1240
-#, c-format
-msgid "'%s' is not a commit and a branch '%s' cannot be created from it"
-msgstr "'%s' no es un commit y una rama '%s' no puede ser creada desde este"
+#: wt-status.c:280
+msgid "both modified:"
+msgstr "ambos modificados:"
 
-#: builtin/checkout.c:1244
-#, c-format
-msgid "git checkout: --detach does not take a path argument '%s'"
-msgstr "git checkout: --detach no toma un argumento de ruta '%s'"
+#: wt-status.c:290
+msgid "new file:"
+msgstr "nuevo archivo:"
 
-#: builtin/checkout.c:1248
-msgid ""
-"git checkout: --ours/--theirs, --force and --merge are incompatible when\n"
-"checking out of the index."
-msgstr ""
-"git checkout: --ours/--theirs, --force y --merge son incompatibles cuando\n"
-"se revisa fuera del índice."
+#: wt-status.c:292
+msgid "copied:"
+msgstr "copiado:"
 
-#: builtin/clean.c:26
-msgid ""
-"git clean [-d] [-f] [-i] [-n] [-q] [-e <pattern>] [-x | -X] [--] <paths>..."
-msgstr ""
-"git clean [-d] [-f] [-i] [-n] [-q] [-e <patrón>] [-x | -X] [--] <rutas>..."
+#: wt-status.c:294
+msgid "deleted:"
+msgstr "borrado:"
 
-#: builtin/clean.c:30
-#, c-format
-msgid "Removing %s\n"
-msgstr "Borrando %s\n"
+#: wt-status.c:296
+msgid "modified:"
+msgstr "modificado:"
 
-#: builtin/clean.c:31
-#, c-format
-msgid "Would remove %s\n"
-msgstr "Sera borrado %s\n"
+#: wt-status.c:298
+msgid "renamed:"
+msgstr "renombrado:"
 
-#: builtin/clean.c:32
-#, c-format
-msgid "Skipping repository %s\n"
-msgstr "Saltando repositorio %s\n"
+#: wt-status.c:300
+msgid "typechange:"
+msgstr "cambio de tipo:"
 
-#: builtin/clean.c:33
-#, c-format
-msgid "Would skip repository %s\n"
-msgstr "Se saltara repositorio %s\n"
+#: wt-status.c:302
+msgid "unknown:"
+msgstr "desconocido:"
 
-#: builtin/clean.c:34
-#, c-format
-msgid "failed to remove %s"
-msgstr "falló al borrar %s"
+#: wt-status.c:304
+msgid "unmerged:"
+msgstr "des-fusionado:"
+
+#: wt-status.c:384
+msgid "new commits, "
+msgstr "nuevos commits, "
+
+#: wt-status.c:386
+msgid "modified content, "
+msgstr "contenido modificado, "
+
+#: wt-status.c:388
+msgid "untracked content, "
+msgstr "contenido no rastreado, "
 
-#: builtin/clean.c:302 git-add--interactive.perl:579
+#: wt-status.c:906
 #, c-format
+msgid "Your stash currently has %d entry"
+msgid_plural "Your stash currently has %d entries"
+msgstr[0] "Tu stash actualmente tiene %d entrada"
+msgstr[1] "Tu stash actualmente tiene %d entradas"
+
+#: wt-status.c:938
+msgid "Submodules changed but not updated:"
+msgstr "Submódulos cambiados pero no actualizados:"
+
+#: wt-status.c:940
+msgid "Submodule changes to be committed:"
+msgstr "Submódulos cambiados listos para realizar commit:"
+
+#: wt-status.c:1022
 msgid ""
-"Prompt help:\n"
-"1          - select a numbered item\n"
-"foo        - select item based on unique prefix\n"
-"           - (empty) select nothing\n"
+"Do not modify or remove the line above.\n"
+"Everything below it will be ignored."
 msgstr ""
-"Ayuda rápida:\n"
-"1          - selecciona un objeto por numero\n"
-"foo        - selecciona un objeto basado en un prefijo único\n"
-"           - (vacío) no elegir nada\n"
+"No modifique o borre la línea de encima.\n"
+"Todo lo que este por abajo será eliminado."
 
-#: builtin/clean.c:306 git-add--interactive.perl:588
+#: wt-status.c:1114
 #, c-format
 msgid ""
-"Prompt help:\n"
-"1          - select a single item\n"
-"3-5        - select a range of items\n"
-"2-3,6-9    - select multiple ranges\n"
-"foo        - select item based on unique prefix\n"
-"-...       - unselect specified items\n"
-"*          - choose all items\n"
-"           - (empty) finish selecting\n"
+"\n"
+"It took %.2f seconds to compute the branch ahead/behind values.\n"
+"You can use '--no-ahead-behind' to avoid this.\n"
 msgstr ""
-"Ayuda rápida:\n"
-"1          - selecciona un objeto único\n"
-"3-5        - selecciona un rango de objetos\n"
-"2-3,6-9    - selecciona múltiples rangos\n"
-"foo        - selecciona un objeto basado en un prefijo único\n"
-"-...       - de-seleccionar objetos especificados\n"
-"*          - escoger todos los objetos\n"
-"           - (vacío) terminar selección\n"
+"\n"
+"Tomó %.2f segundos para calcular los valores anterior/posterior del branch.\n"
+"Puedes usar '--no-ahead-behind' para evitar esto.\n"
 
-#: builtin/clean.c:522 git-add--interactive.perl:554
-#: git-add--interactive.perl:559
-#, c-format, perl-format
-msgid "Huh (%s)?\n"
-msgstr "Ahh (%s)?\n"
+#: wt-status.c:1144
+msgid "You have unmerged paths."
+msgstr "Tienes rutas no fusionadas."
 
-#: builtin/clean.c:664
-#, c-format
-msgid "Input ignore patterns>> "
-msgstr "Input ignora los patrones >> "
+#: wt-status.c:1147
+msgid "  (fix conflicts and run \"git commit\")"
+msgstr "  (arregla los conflictos y corre \"git commit\""
 
-#: builtin/clean.c:701
-#, c-format
-msgid "WARNING: Cannot find items matched by: %s"
-msgstr "PELIGRO: No se puede encontrar objetos que concuerden con: %s"
+#: wt-status.c:1149
+msgid "  (use \"git merge --abort\" to abort the merge)"
+msgstr "  (usa \"git merge --abort\" para abortar la fusion)"
 
-#: builtin/clean.c:722
-msgid "Select items to delete"
-msgstr "Seleccionar objetos para borrar"
+#: wt-status.c:1153
+msgid "All conflicts fixed but you are still merging."
+msgstr "Todos los conflictos resueltos pero sigues fusionando."
 
-#. TRANSLATORS: Make sure to keep [y/N] as is
-#: builtin/clean.c:763
-#, c-format
-msgid "Remove %s [y/N]? "
-msgstr "Borrar %s [y/N]? "
+#: wt-status.c:1156
+msgid "  (use \"git commit\" to conclude merge)"
+msgstr "  (usa \"git commit\" para concluir la fusión)"
 
-#: builtin/clean.c:788 git-add--interactive.perl:1717
-#, c-format
-msgid "Bye.\n"
-msgstr "Adiós.\n"
+#: wt-status.c:1165
+msgid "You are in the middle of an am session."
+msgstr "Estás en medio de una sesión am."
 
-#: builtin/clean.c:796
-msgid ""
-"clean               - start cleaning\n"
-"filter by pattern   - exclude items from deletion\n"
-"select by numbers   - select items to be deleted by numbers\n"
-"ask each            - confirm each deletion (like \"rm -i\")\n"
-"quit                - stop cleaning\n"
-"help                - this screen\n"
-"?                   - help for prompt selection"
-msgstr ""
-"clean               - comenzar la limpieza\n"
-"filtrar por patrón   - excluye objetos del borrado \n"
-"elegir por números   - selecciona objetos a ser borrados por numero\n"
-"preguntar cada uno     - confirmar cada borrado (como \"rm -i\")\n"
-"quit                - parar limpieza\n"
-"help                - esta ventana\n"
-"?                   - ayuda para selección de opciones"
+#: wt-status.c:1168
+msgid "The current patch is empty."
+msgstr "El parche actual está vacío."
 
-#: builtin/clean.c:823 git-add--interactive.perl:1793
-msgid "*** Commands ***"
-msgstr "*** Comandos ***"
+#: wt-status.c:1172
+msgid "  (fix conflicts and then run \"git am --continue\")"
+msgstr "  (arregla los conflictos y luego corre \"git am --continue\""
 
-#: builtin/clean.c:824 git-add--interactive.perl:1790
-msgid "What now"
-msgstr "Ahora que"
+#: wt-status.c:1174
+msgid "  (use \"git am --skip\" to skip this patch)"
+msgstr "  (usa \"git am --skip\" para saltar este parche)"
 
-#: builtin/clean.c:832
-msgid "Would remove the following item:"
-msgid_plural "Would remove the following items:"
-msgstr[0] "Se removerá el siguiente objeto:"
-msgstr[1] "Se removerán los siguientes objetos:"
+#: wt-status.c:1176
+msgid "  (use \"git am --abort\" to restore the original branch)"
+msgstr "  (usa \"git am --abort\" para restaurar la rama original)"
 
-#: builtin/clean.c:848
-msgid "No more files to clean, exiting."
-msgstr "No hay mas archivos para limpiar, saliendo."
+#: wt-status.c:1309
+msgid "git-rebase-todo is missing."
+msgstr "git-rebase-todo no está presente."
 
-#: builtin/clean.c:910
-msgid "do not print names of files removed"
-msgstr "no imprimir nombres de archivos borrados"
+#: wt-status.c:1311
+msgid "No commands done."
+msgstr "No se realizaron los comandos."
 
-#: builtin/clean.c:912
-msgid "force"
-msgstr "forzar"
+#: wt-status.c:1314
+#, c-format
+msgid "Last command done (%d command done):"
+msgid_plural "Last commands done (%d commands done):"
+msgstr[0] "El último comando realizado (%d comando realizado):"
+msgstr[1] "Los últimos comandos realizados (%d comandos realizados):"
 
-#: builtin/clean.c:913
-msgid "interactive cleaning"
-msgstr "limpieza interactiva"
+#: wt-status.c:1325
+#, c-format
+msgid "  (see more in file %s)"
+msgstr "  (ver más en el archivo %s)"
 
-#: builtin/clean.c:915
-msgid "remove whole directories"
-msgstr "borrar directorios completos"
+#: wt-status.c:1330
+msgid "No commands remaining."
+msgstr "No quedan más comandos."
 
-#: builtin/clean.c:916 builtin/describe.c:533 builtin/describe.c:535
-#: builtin/grep.c:871 builtin/log.c:157 builtin/log.c:159
-#: builtin/ls-files.c:548 builtin/name-rev.c:397 builtin/name-rev.c:399
-#: builtin/show-ref.c:176
-msgid "pattern"
-msgstr "patrón"
+#: wt-status.c:1333
+#, c-format
+msgid "Next command to do (%d remaining command):"
+msgid_plural "Next commands to do (%d remaining commands):"
+msgstr[0] "Siguiente comando a realizar (%d comando restante):"
+msgstr[1] "Siguiente comandos a realizar (%d comandos faltantes):"
 
-#: builtin/clean.c:917
-msgid "add <pattern> to ignore rules"
-msgstr "agregar <patrón> para ignorar reglas"
+#: wt-status.c:1341
+msgid "  (use \"git rebase --edit-todo\" to view and edit)"
+msgstr "  (usa \"git rebase --edit-todo\" para ver y editar)"
 
-#: builtin/clean.c:918
-msgid "remove ignored files, too"
-msgstr "borrar archivos ignorados, también"
+#: wt-status.c:1353
+#, c-format
+msgid "You are currently rebasing branch '%s' on '%s'."
+msgstr "Estás aplicando un rebase de la rama '%s' en '%s."
 
-#: builtin/clean.c:920
-msgid "remove only ignored files"
-msgstr "borrar solo archivos ignorados"
+#: wt-status.c:1358
+msgid "You are currently rebasing."
+msgstr "Estás aplicando un rebase."
 
-#: builtin/clean.c:938
-msgid "-x and -X cannot be used together"
-msgstr "-x y -X no pueden ser usadas juntas"
+#: wt-status.c:1371
+msgid "  (fix conflicts and then run \"git rebase --continue\")"
+msgstr "  (corrige los conflictos y ejecuta \"git rebase --continue\")"
 
-#: builtin/clean.c:942
-msgid ""
-"clean.requireForce set to true and neither -i, -n, nor -f given; refusing to "
-"clean"
-msgstr ""
-"clean.requireForce configurado como true y ninguno -i, -n, ni -f entregados; "
-"rehusando el clean"
+#: wt-status.c:1373
+msgid "  (use \"git rebase --skip\" to skip this patch)"
+msgstr "  (usa \"git rebase --skip\" para omitir este parche)"
+
+#: wt-status.c:1375
+msgid "  (use \"git rebase --abort\" to check out the original branch)"
+msgstr "  (usa \"git rebase --abort\" para volver a tu rama original)"
+
+#: wt-status.c:1382
+msgid "  (all conflicts fixed: run \"git rebase --continue\")"
+msgstr "  (todos los conflictos corregidos: ejecuta \"git rebase --continue\")"
 
-#: builtin/clean.c:945
+#: wt-status.c:1386
+#, c-format
 msgid ""
-"clean.requireForce defaults to true and neither -i, -n, nor -f given; "
-"refusing to clean"
+"You are currently splitting a commit while rebasing branch '%s' on '%s'."
 msgstr ""
-"clean.requireForce default en true y ninguno -i, -n, ni -f entregados; "
-"rehusando el clean"
-
-#: builtin/clone.c:42
-msgid "git clone [<options>] [--] <repo> [<dir>]"
-msgstr "git clone [<opciones>] [--] <repo> [<directorio>]"
+"Estás dividiendo un commit mientras aplicas un rebase de la rama '%s' en "
+"'%s'."
 
-#: builtin/clone.c:87
-msgid "don't create a checkout"
-msgstr "no crear checkout"
+#: wt-status.c:1391
+msgid "You are currently splitting a commit during a rebase."
+msgstr "Estás dividiendo un commit durante un rebase."
 
-#: builtin/clone.c:88 builtin/clone.c:90 builtin/init-db.c:479
-msgid "create a bare repository"
-msgstr "crear un repositorio vacío"
+#: wt-status.c:1394
+msgid "  (Once your working directory is clean, run \"git rebase --continue\")"
+msgstr ""
+"  (Una vez que tu directorio de trabajo esté limpio, ejecuta \"git rebase --"
+"continue\")"
 
-#: builtin/clone.c:92
-msgid "create a mirror repository (implies bare)"
-msgstr "crear un repositorio espejo (implica vacío)"
+#: wt-status.c:1398
+#, c-format
+msgid "You are currently editing a commit while rebasing branch '%s' on '%s'."
+msgstr ""
+"Estás editando un commit mientras se aplica un rebase de la rama '%s' en "
+"'%s'."
 
-#: builtin/clone.c:94
-msgid "to clone from a local repository"
-msgstr "clonar de un repositorio local"
+#: wt-status.c:1403
+msgid "You are currently editing a commit during a rebase."
+msgstr "Estás editando un commit durante un rebase."
 
-#: builtin/clone.c:96
-msgid "don't use local hardlinks, always copy"
-msgstr "no usar hardlinks, siempre copiar"
+#: wt-status.c:1406
+msgid "  (use \"git commit --amend\" to amend the current commit)"
+msgstr "  (usa \"git commit --amend\" para enmendar el commit actual)"
 
-#: builtin/clone.c:98
-msgid "setup as shared repository"
-msgstr "configurar como repositorio compartido"
+#: wt-status.c:1408
+msgid ""
+"  (use \"git rebase --continue\" once you are satisfied with your changes)"
+msgstr ""
+"  (usa \"git rebase --continue\" una vez que estés satisfecho con tus "
+"cambios)"
 
-#: builtin/clone.c:100 builtin/clone.c:104
-msgid "pathspec"
-msgstr "pathspec"
+#: wt-status.c:1419
+msgid "Cherry-pick currently in progress."
+msgstr "Cherry-pick en progreso actualmente."
 
-#: builtin/clone.c:100 builtin/clone.c:104
-msgid "initialize submodules in the clone"
-msgstr "inicializar submódulos en el clonado"
+#: wt-status.c:1422
+#, c-format
+msgid "You are currently cherry-picking commit %s."
+msgstr "Estás realizando un cherry-picking en el commit %s."
 
-#: builtin/clone.c:107
-msgid "number of submodules cloned in parallel"
-msgstr "numero de submódulos clonados en paralelo"
+#: wt-status.c:1429
+msgid "  (fix conflicts and run \"git cherry-pick --continue\")"
+msgstr "  (corrige los conflictos y ejecuta \"git cherry-pick --continue\")"
 
-#: builtin/clone.c:108 builtin/init-db.c:476
-msgid "template-directory"
-msgstr "directorio-template"
+#: wt-status.c:1432
+msgid "  (run \"git cherry-pick --continue\" to continue)"
+msgstr "  (ejecuta \"git cherry-pick --continue\" para continuar)"
 
-#: builtin/clone.c:109 builtin/init-db.c:477
-msgid "directory from which templates will be used"
-msgstr "directorio del cual los templates serán usados"
+#: wt-status.c:1435
+msgid "  (all conflicts fixed: run \"git cherry-pick --continue\")"
+msgstr ""
+"  (todos los conflictos corregidos: ejecuta \"git cherry-pick --continue\")"
 
-#: builtin/clone.c:111 builtin/clone.c:113 builtin/submodule--helper.c:1223
-#: builtin/submodule--helper.c:1594
-msgid "reference repository"
-msgstr "repositorio de referencia"
+#: wt-status.c:1437
+msgid "  (use \"git cherry-pick --skip\" to skip this patch)"
+msgstr "  (usa \"git cherry-pick --skip\" para saltar este parche)"
 
-#: builtin/clone.c:115 builtin/submodule--helper.c:1225
-#: builtin/submodule--helper.c:1596
-msgid "use --reference only while cloning"
-msgstr "usa--reference  solamente si estas clonado"
+#: wt-status.c:1439
+msgid "  (use \"git cherry-pick --abort\" to cancel the cherry-pick operation)"
+msgstr ""
+"  (use \"git cherry-pick --abort\" para cancelar la operación cherry-pick)"
 
-#: builtin/clone.c:116 builtin/column.c:27 builtin/merge-file.c:44
-#: builtin/pack-objects.c:3166 builtin/repack.c:213
-msgid "name"
-msgstr "nombre"
+#: wt-status.c:1449
+msgid "Revert currently in progress."
+msgstr "Revierte el estado en progreso actual."
 
-#: builtin/clone.c:117
-msgid "use <name> instead of 'origin' to track upstream"
-msgstr "use <nombre> en lugar de 'origin' para rastrear upstream"
-
-#: builtin/clone.c:119
-msgid "checkout <branch> instead of the remote's HEAD"
-msgstr "checkout <rama> en lugar de HEAD remota"
+#: wt-status.c:1452
+#, c-format
+msgid "You are currently reverting commit %s."
+msgstr "Estás revirtiendo el commit %s."
 
-#: builtin/clone.c:121
-msgid "path to git-upload-pack on the remote"
-msgstr "ruta para git-upload-pack en el remoto"
+#: wt-status.c:1458
+msgid "  (fix conflicts and run \"git revert --continue\")"
+msgstr "  (corrige los conflictos y ejecuta \"git revert --continue\")"
 
-#: builtin/clone.c:122 builtin/fetch.c:150 builtin/grep.c:813
-#: builtin/pull.c:216
-msgid "depth"
-msgstr "profundidad"
+#: wt-status.c:1461
+msgid "  (run \"git revert --continue\" to continue)"
+msgstr "  (ejecuta \"git revert --continue\" para continuar)"
 
-#: builtin/clone.c:123
-msgid "create a shallow clone of that depth"
-msgstr "crear un clon superficial para esa profundidad"
+#: wt-status.c:1464
+msgid "  (all conflicts fixed: run \"git revert --continue\")"
+msgstr "  (todos los conflictos corregidos: ejecuta \"git revert --continue\")"
 
-#: builtin/clone.c:124 builtin/fetch.c:152 builtin/pack-objects.c:3157
-#: parse-options.h:154
-msgid "time"
-msgstr "tiempo"
+#: wt-status.c:1466
+msgid "  (use \"git revert --skip\" to skip this patch)"
+msgstr "  (usa \"git revert --skip\" para omitir este parche)"
 
-#: builtin/clone.c:125
-msgid "create a shallow clone since a specific time"
-msgstr "crear un clon superficial desde el tiempo específico"
+#: wt-status.c:1468
+msgid "  (use \"git revert --abort\" to cancel the revert operation)"
+msgstr "  (usa \"git revert --abort\" para cancelar la operación de revertir)"
 
-#: builtin/clone.c:126 builtin/fetch.c:154
-msgid "revision"
-msgstr "revision"
+#: wt-status.c:1478
+#, c-format
+msgid "You are currently bisecting, started from branch '%s'."
+msgstr "Estás aplicando un bisect, comenzando en la rama '%s'."
 
-#: builtin/clone.c:127 builtin/fetch.c:155
-msgid "deepen history of shallow clone, excluding rev"
-msgstr "ahondando historia de clon superficial, excluyendo rev"
+#: wt-status.c:1482
+msgid "You are currently bisecting."
+msgstr "Estás aplicando un bisect."
 
-#: builtin/clone.c:129
-msgid "clone only one branch, HEAD or --branch"
-msgstr "clonar solo una rama,HEAD o --branch"
+#: wt-status.c:1485
+msgid "  (use \"git bisect reset\" to get back to the original branch)"
+msgstr "  (usa \"git bisect reset\" para volver a la rama original)"
 
-#: builtin/clone.c:131
-msgid "don't clone any tags, and make later fetches not to follow them"
-msgstr "no clonar ningún tag, y hacer que los subsiguientes fetch no los sigan"
+#: wt-status.c:1694
+msgid "On branch "
+msgstr "En la rama "
 
-#: builtin/clone.c:133
-msgid "any cloned submodules will be shallow"
-msgstr "cualquier submódulo clonado será superficial"
+#: wt-status.c:1701
+msgid "interactive rebase in progress; onto "
+msgstr "rebase interactivo en progreso; en "
 
-#: builtin/clone.c:134 builtin/init-db.c:485
-msgid "gitdir"
-msgstr "gitdir"
+#: wt-status.c:1703
+msgid "rebase in progress; onto "
+msgstr "rebase en progreso; en "
 
-#: builtin/clone.c:135 builtin/init-db.c:486
-msgid "separate git dir from working tree"
-msgstr "separa git dir del árbol de trabajo"
+#: wt-status.c:1713
+msgid "Not currently on any branch."
+msgstr "Actualmente no estás en ninguna rama."
 
-#: builtin/clone.c:136
-msgid "key=value"
-msgstr "llave=valor"
+#: wt-status.c:1730
+msgid "Initial commit"
+msgstr "Confirmación inicial"
 
-#: builtin/clone.c:137
-msgid "set config inside the new repository"
-msgstr "configurar config dentro del nuevo repositorio"
+#: wt-status.c:1731
+msgid "No commits yet"
+msgstr "No hay commits todavía"
 
-#: builtin/clone.c:138 builtin/fetch.c:173 builtin/pull.c:229
-#: builtin/push.c:583
-msgid "use IPv4 addresses only"
-msgstr "solo usar direcciones IPv4"
+#: wt-status.c:1745
+msgid "Untracked files"
+msgstr "Archivos sin seguimiento"
 
-#: builtin/clone.c:140 builtin/fetch.c:175 builtin/pull.c:232
-#: builtin/push.c:585
-msgid "use IPv6 addresses only"
-msgstr "solo usar direcciones IPv6"
+#: wt-status.c:1747
+msgid "Ignored files"
+msgstr "Archivos ignorados"
 
-#: builtin/clone.c:278
+#: wt-status.c:1751
+#, c-format
 msgid ""
-"No directory name could be guessed.\n"
-"Please specify a directory on the command line"
+"It took %.2f seconds to enumerate untracked files. 'status -uno'\n"
+"may speed it up, but you have to be careful not to forget to add\n"
+"new files yourself (see 'git help status')."
 msgstr ""
-"No se pudo adivinar ningún nombre de directorio.\n"
-"Por favor especifique un directorio en la línea de comando"
-
-#: builtin/clone.c:331
-#, c-format
-msgid "info: Could not add alternate for '%s': %s\n"
-msgstr "info: No se pudo agregar un alterno para '%s': %s\n"
+"Tomó %.2f segundos enumerar los archivos no rastreados. 'status -uno'\n"
+"puede acelerarlo, pero tienes que ser cuidadoso de no olvidar agregar\n"
+"nuevos archivos tú mismo (vea 'git help status')."
 
-#: builtin/clone.c:403
+#: wt-status.c:1757
 #, c-format
-msgid "failed to open '%s'"
-msgstr "falló al abrir '%s'"
+msgid "Untracked files not listed%s"
+msgstr "Archivos no rastreados no son mostrados %s"
 
-#: builtin/clone.c:411
-#, c-format
-msgid "%s exists and is not a directory"
-msgstr "%s existe pero no es un directorio"
+#: wt-status.c:1759
+msgid " (use -u option to show untracked files)"
+msgstr " (usa la opción -u para mostrar los archivos sin seguimiento)"
 
-#: builtin/clone.c:425
-#, c-format
-msgid "failed to stat %s\n"
-msgstr "falló al analizar %s\n"
+#: wt-status.c:1765
+msgid "No changes"
+msgstr "Sin cambios"
 
-#: builtin/clone.c:447
+#: wt-status.c:1770
 #, c-format
-msgid "failed to create link '%s'"
-msgstr "falló al crear link '%s'"
+msgid "no changes added to commit (use \"git add\" and/or \"git commit -a\")\n"
+msgstr ""
+"sin cambios agregados al commit (usa \"git add\" y/o \"git commit -a\")\n"
 
-#: builtin/clone.c:451
+#: wt-status.c:1773
 #, c-format
-msgid "failed to copy file to '%s'"
-msgstr "falló al copiar archivo a '%s'"
+msgid "no changes added to commit\n"
+msgstr "no se agregaron cambios al commit\n"
 
-#: builtin/clone.c:477
+#: wt-status.c:1776
 #, c-format
-msgid "done.\n"
-msgstr "hecho.\n"
-
-#: builtin/clone.c:491
 msgid ""
-"Clone succeeded, but checkout failed.\n"
-"You can inspect what was checked out with 'git status'\n"
-"and retry the checkout with 'git checkout -f HEAD'\n"
+"nothing added to commit but untracked files present (use \"git add\" to "
+"track)\n"
 msgstr ""
-"Clonado exitoso, pero falló el checkout.\n"
-"Puede inspeccionar a qué se hizo checkout con 'git status'\n"
-"y volver a intentarlo con 'git checkout -f HEAD'\n"
+"no hay nada agregado al commit pero hay archivos sin seguimiento presentes "
+"(usa \"git add\" para hacerles seguimiento)\n"
 
-#: builtin/clone.c:568
+#: wt-status.c:1779
 #, c-format
-msgid "Could not find remote branch %s to clone."
-msgstr "No se pudo encontrar la rama remota %s para clonar."
+msgid "nothing added to commit but untracked files present\n"
+msgstr ""
+"no hay nada agregado para confirmar, pero hay archivos sin seguimiento "
+"presentes\n"
 
-#: builtin/clone.c:663
-msgid "remote did not send all necessary objects"
-msgstr "remoto no mando todos los objetos necesarios"
+#: wt-status.c:1782
+#, c-format
+msgid "nothing to commit (create/copy files and use \"git add\" to track)\n"
+msgstr ""
+"no hay nada para confirmar (crea/copia archivos y usa \"git add\" para "
+"hacerles seguimiento)\n"
 
-#: builtin/clone.c:679
+#: wt-status.c:1785 wt-status.c:1790
 #, c-format
-msgid "unable to update %s"
-msgstr "incapaz de actualizar %s"
+msgid "nothing to commit\n"
+msgstr "nada para hacer commit\n"
 
-#: builtin/clone.c:728
-msgid "remote HEAD refers to nonexistent ref, unable to checkout.\n"
+#: wt-status.c:1788
+#, c-format
+msgid "nothing to commit (use -u to show untracked files)\n"
 msgstr ""
-"remoto HEAD refiere a un ref inexistente, no se puede hacer checkout.\n"
+"nada para hacer commit (usa -u para mostrar los archivos no rastreados)\n"
 
-#: builtin/clone.c:758
-msgid "unable to checkout working tree"
-msgstr "no es posible realizar checkout en el árbol de trabajo"
+#: wt-status.c:1792
+#, c-format
+msgid "nothing to commit, working tree clean\n"
+msgstr "nada para hacer commit, el árbol de trabajo está limpio\n"
 
-#: builtin/clone.c:803
-msgid "unable to write parameters to config file"
-msgstr "no es posible escribir parámetros al archivo config"
+#: wt-status.c:1905
+msgid "No commits yet on "
+msgstr "No hay commits todavía en "
 
-#: builtin/clone.c:866
-msgid "cannot repack to clean up"
-msgstr "no se puede reempaquetar para limpiar"
+#: wt-status.c:1909
+msgid "HEAD (no branch)"
+msgstr "HEAD (sin rama)"
 
-#: builtin/clone.c:868
-msgid "cannot unlink temporary alternates file"
-msgstr "no se puede desvincular archivos alternos temporales"
+#: wt-status.c:1940
+msgid "different"
+msgstr "diferente"
 
-#: builtin/clone.c:907 builtin/receive-pack.c:1947
-msgid "Too many arguments."
-msgstr "Muchos argumentos."
+#: wt-status.c:1942 wt-status.c:1950
+msgid "behind "
+msgstr "detrás "
 
-#: builtin/clone.c:911
-msgid "You must specify a repository to clone."
-msgstr "Tienes que especificar un repositorio para clonar."
+#: wt-status.c:1945 wt-status.c:1948
+msgid "ahead "
+msgstr "adelante "
 
-#: builtin/clone.c:924
+#. TRANSLATORS: the action is e.g. "pull with rebase"
+#: wt-status.c:2470
 #, c-format
-msgid "--bare and --origin %s options are incompatible."
-msgstr "Las opciones --bare y --origin %s son incompatibles."
+msgid "cannot %s: You have unstaged changes."
+msgstr "no se puede %s: Tienes cambios sin marcar."
 
-#: builtin/clone.c:927
-msgid "--bare and --separate-git-dir are incompatible."
-msgstr "--bare y --separate-git-dir son incompatibles."
+#: wt-status.c:2476
+msgid "additionally, your index contains uncommitted changes."
+msgstr "adicionalmente, tu índice contiene cambios que no están en un commit."
 
-#: builtin/clone.c:940
+#: wt-status.c:2478
 #, c-format
-msgid "repository '%s' does not exist"
-msgstr "repositorio '%s' no existe"
+msgid "cannot %s: Your index contains uncommitted changes."
+msgstr "no se puede %s: Tu índice contiene cambios que no están en un commit."
 
-#: builtin/clone.c:946 builtin/fetch.c:1460
+#: compat/precompose_utf8.c:58 builtin/clone.c:455
 #, c-format
-msgid "depth %s is not a positive number"
-msgstr "profundidad %s no es un numero positivo"
+msgid "failed to unlink '%s'"
+msgstr "falló al desvincular '%s'"
 
-#: builtin/clone.c:956
-#, c-format
-msgid "destination path '%s' already exists and is not an empty directory."
-msgstr "la ruta de destino '%s' ya existe y no es un directorio vacío."
+#: builtin/add.c:26
+msgid "git add [<options>] [--] <pathspec>..."
+msgstr "git add [<opción>] [--] <especificación-de-ruta>..."
 
-#: builtin/clone.c:966
+#: builtin/add.c:87
 #, c-format
-msgid "working tree '%s' already exists."
-msgstr "directorio de trabajo '%s' ya existe."
+msgid "unexpected diff status %c"
+msgstr "diff status inesperado %c"
+
+#: builtin/add.c:92 builtin/commit.c:288
+msgid "updating files failed"
+msgstr "falló la actualización de carpetas"
 
-#: builtin/clone.c:981 builtin/clone.c:1002 builtin/difftool.c:270
-#: builtin/worktree.c:246 builtin/worktree.c:276
+#: builtin/add.c:102
 #, c-format
-msgid "could not create leading directories of '%s'"
-msgstr "no se pudo crear directorios principales de '%s'"
+msgid "remove '%s'\n"
+msgstr "eliminar '%s'\n"
+
+#: builtin/add.c:177
+msgid "Unstaged changes after refreshing the index:"
+msgstr "Cambios fuera del área de stage tras refrescar el índice:"
 
-#: builtin/clone.c:986
+#: builtin/add.c:252 builtin/rev-parse.c:899
+msgid "Could not read the index"
+msgstr "No se pudo leer el índice"
+
+#: builtin/add.c:263
 #, c-format
-msgid "could not create work tree dir '%s'"
-msgstr "no se pudo crear un árbol de trabajo '%s'"
+msgid "Could not open '%s' for writing."
+msgstr "No se pudo abrir '%s' para escritura."
+
+#: builtin/add.c:267
+msgid "Could not write patch"
+msgstr "No se puede escribir el parche"
+
+#: builtin/add.c:270
+msgid "editing patch failed"
+msgstr "falló la edición del parche"
 
-#: builtin/clone.c:1006
+#: builtin/add.c:273
 #, c-format
-msgid "Cloning into bare repository '%s'...\n"
-msgstr "Clonando en un repositorio vacío '%s'...\n"
+msgid "Could not stat '%s'"
+msgstr "No se pudo definir '%s'"
 
-#: builtin/clone.c:1008
+#: builtin/add.c:275
+msgid "Empty patch. Aborted."
+msgstr "Parche vacío. Abortado."
+
+#: builtin/add.c:280
 #, c-format
-msgid "Cloning into '%s'...\n"
-msgstr "Clonando en '%s'...\n"
+msgid "Could not apply '%s'"
+msgstr "No se pudo aplicar '%s'"
 
-#: builtin/clone.c:1032
-msgid ""
-"clone --recursive is not compatible with both --reference and --reference-if-"
-"able"
+#: builtin/add.c:288
+msgid "The following paths are ignored by one of your .gitignore files:\n"
 msgstr ""
-"clone --recursive no es compatible con --reference y --reference-if-able al "
-"mismo tiempo"
-
-#: builtin/clone.c:1093
-msgid "--depth is ignored in local clones; use file:// instead."
-msgstr "--depth es ignorada en clonaciones locales; usa file:// más bien."
+"Las siguientes rutas son ignoradas por uno de tus archivos .gitignore:\n"
 
-#: builtin/clone.c:1095
-msgid "--shallow-since is ignored in local clones; use file:// instead."
-msgstr "--shallow-since es ignorado en el clon local; use file:// ."
+#: builtin/add.c:308 builtin/clean.c:910 builtin/fetch.c:163 builtin/mv.c:124
+#: builtin/prune-packed.c:56 builtin/pull.c:223 builtin/push.c:548
+#: builtin/remote.c:1344 builtin/rm.c:241 builtin/send-pack.c:165
+msgid "dry run"
+msgstr "dry run ( ejecución en seco)"
 
-#: builtin/clone.c:1097
-msgid "--shallow-exclude is ignored in local clones; use file:// instead."
-msgstr "--shallow-exclude es ignorado en clones locales; use file://."
+#: builtin/add.c:311
+msgid "interactive picking"
+msgstr "selección interactiva"
 
-#: builtin/clone.c:1099
-msgid "--filter is ignored in local clones; use file:// instead."
-msgstr "--filter es ignorado en clones locales; usa file:// en su lugar."
+#: builtin/add.c:312 builtin/checkout.c:1482 builtin/reset.c:307
+msgid "select hunks interactively"
+msgstr "elegir hunks de forma interactiva"
 
-#: builtin/clone.c:1102
-msgid "source repository is shallow, ignoring --local"
-msgstr "repositorio fuente es superficial, ignorando --local"
+#: builtin/add.c:313
+msgid "edit current diff and apply"
+msgstr "editar diff actual y aplicar"
 
-#: builtin/clone.c:1107
-msgid "--local is ignored"
-msgstr "--local es ignorado"
+#: builtin/add.c:314
+msgid "allow adding otherwise ignored files"
+msgstr "permitir agregar caso contrario ignorar archivos"
 
-#: builtin/clone.c:1169 builtin/clone.c:1177
-#, c-format
-msgid "Remote branch %s not found in upstream %s"
-msgstr "Rama remota %s no encontrada en upstream %s"
+#: builtin/add.c:315
+msgid "update tracked files"
+msgstr "actualizado las carpetas rastreadas"
 
-#: builtin/clone.c:1180
-msgid "You appear to have cloned an empty repository."
-msgstr "Pareces haber clonado un repositorio sin contenido."
-
-#: builtin/column.c:10
-msgid "git column [<options>]"
-msgstr "git column [<opciones>]"
-
-#: builtin/column.c:27
-msgid "lookup config vars"
-msgstr "revisa las variables de configuraciones"
-
-#: builtin/column.c:28 builtin/column.c:29
-msgid "layout to use"
-msgstr "capa a usar"
+#: builtin/add.c:316
+msgid "renormalize EOL of tracked files (implies -u)"
+msgstr "renormalizar EOL de los archivos rastreados (implica -u)"
 
-#: builtin/column.c:30
-msgid "Maximum width"
-msgstr "Ancho máximo"
+#: builtin/add.c:317
+msgid "record only the fact that the path will be added later"
+msgstr "grabar solo el hecho de que la ruta será agregada después"
 
-#: builtin/column.c:31
-msgid "Padding space on left border"
-msgstr "Realizando padding en el borde izquierdo"
+#: builtin/add.c:318
+msgid "add changes from all tracked and untracked files"
+msgstr "agregar los cambios de todas las carpetas con y sin seguimiento"
 
-#: builtin/column.c:32
-msgid "Padding space on right border"
-msgstr "Realizando padding en el borde derecho"
+#: builtin/add.c:321
+msgid "ignore paths removed in the working tree (same as --no-all)"
+msgstr ""
+"ignorar rutas eliminadas en el árbol de trabajo (lo mismo que --no-all)"
 
-#: builtin/column.c:33
-msgid "Padding space between columns"
-msgstr "Realizando padding entre columnas"
+#: builtin/add.c:323
+msgid "don't add, only refresh the index"
+msgstr "no agregar, solo actualizar el índice"
 
-#: builtin/column.c:51
-msgid "--command must be the first argument"
-msgstr "--command debe ser el primer argumento"
+#: builtin/add.c:324
+msgid "just skip files which cannot be added because of errors"
+msgstr "saltar las carpetas que no pueden ser agregadas a causa de errores"
 
-#: builtin/commit.c:37
-msgid "git commit [<options>] [--] <pathspec>..."
-msgstr "git commit [<opciones>] [--] <especificación-de-ruta>..."
+#: builtin/add.c:325
+msgid "check if - even missing - files are ignored in dry run"
+msgstr "comprobar si - incluso los archivos que faltan - se ignoran en dry run"
 
-#: builtin/commit.c:42
-msgid "git status [<options>] [--] <pathspec>..."
-msgstr "git status [<opciones>] [--] <especificación-de-ruta>..."
+#: builtin/add.c:327 builtin/update-index.c:1004
+msgid "override the executable bit of the listed files"
+msgstr "sobrescribir el bit ejecutable de los archivos listados"
 
-#: builtin/commit.c:47
-msgid ""
-"You asked to amend the most recent commit, but doing so would make\n"
-"it empty. You can repeat your command with --allow-empty, or you can\n"
-"remove the commit entirely with \"git reset HEAD^\".\n"
-msgstr ""
-"Has solicitado un amend en tu commit mas reciente, pero hacerlo lo \n"
-"vaciaría. Puedes repetir el comando con --alow-empty, o puedes remover \n"
-"el commit completamente con \"git reset HEAD^\".\n"
+#: builtin/add.c:329
+msgid "warn when adding an embedded repository"
+msgstr "avisar cuando se agrega un repositorio incrustado"
 
-#: builtin/commit.c:52
+#: builtin/add.c:347
+#, c-format
 msgid ""
-"The previous cherry-pick is now empty, possibly due to conflict resolution.\n"
-"If you wish to commit it anyway, use:\n"
+"You've added another git repository inside your current repository.\n"
+"Clones of the outer repository will not contain the contents of\n"
+"the embedded repository and will not know how to obtain it.\n"
+"If you meant to add a submodule, use:\n"
 "\n"
-"    git commit --allow-empty\n"
+"\tgit submodule add <url> %s\n"
 "\n"
-msgstr ""
-"El cherry-pick anterior ahora esta vacío, posiblemente por un conflicto de "
-"resolución.\n"
-"Si desea realizar un commit de todas maneras, use:\n"
+"If you added this path by mistake, you can remove it from the\n"
+"index with:\n"
 "\n"
-"    git commit --allow-empty\n"
+"\tgit rm --cached %s\n"
 "\n"
-
-#: builtin/commit.c:59
-msgid "Otherwise, please use 'git reset'\n"
-msgstr "Caso contrario, por favor usa 'git reset'\n"
-
-#: builtin/commit.c:62
-msgid ""
-"If you wish to skip this commit, use:\n"
+"See \"git help submodule\" for more information."
+msgstr ""
+"Se ha agregado otro repositorio de git dentro del repositorio actual.\n"
+"Clones del repositorio exterior no tendrán el contenido del \n"
+"repositorio embebido y no sabrán como obtenerla.\n"
+"Si querías agregar un submódulo, usa:\n"
 "\n"
-"    git reset\n"
+"\tgit submodule add <url> %s\n"
 "\n"
-"Then \"git cherry-pick --continue\" will resume cherry-picking\n"
-"the remaining commits.\n"
-msgstr ""
-"Si quiere saltar este commit, use:\n"
+"Si se agrego esta ruta por error, puedes eliminar desde el índice \n"
+"usando:\n"
 "\n"
-"    git reset\n"
+"\tgit rm --cached %s\n"
 "\n"
-"Luego \"git cherry-pick --continue\" continuara el cherry-picking\n"
-"para los commits restantes.\n"
-
-#: builtin/commit.c:293
-msgid "failed to unpack HEAD tree object"
-msgstr "falló al desempaquetar objeto del árbol HEAD"
-
-#: builtin/commit.c:334
-msgid "unable to create temporary index"
-msgstr "no es posible crear un índice temporal"
+"Vea \"git help submodule\" para más información."
 
-#: builtin/commit.c:340
-msgid "interactive add failed"
-msgstr "adición interactiva fallida"
+#: builtin/add.c:375
+#, c-format
+msgid "adding embedded git repository: %s"
+msgstr "agregando repositorio embebido: %s"
 
-#: builtin/commit.c:353
-msgid "unable to update temporary index"
-msgstr "no es posible actualizar el índice temporal"
+#: builtin/add.c:393
+#, c-format
+msgid "Use -f if you really want to add them.\n"
+msgstr "Usa -f si realmente quieres agregarlos.\n"
 
-#: builtin/commit.c:355
-msgid "Failed to update main cache tree"
-msgstr "Falló al actualizar el cache principal del árbol"
+#: builtin/add.c:400
+msgid "adding files failed"
+msgstr "falló al agregar archivos"
 
-#: builtin/commit.c:380 builtin/commit.c:403 builtin/commit.c:449
-msgid "unable to write new_index file"
-msgstr "no es posible escribir archivo new_index"
+#: builtin/add.c:428 builtin/commit.c:348
+msgid "--pathspec-from-file is incompatible with --interactive/--patch"
+msgstr "--pathspec-from-file es incompatible con --interactive/--patch"
+
+#: builtin/add.c:434
+msgid "--pathspec-from-file is incompatible with --edit"
+msgstr "--pathspec-from-file es incompatible con --edit"
 
-#: builtin/commit.c:432
-msgid "cannot do a partial commit during a merge."
-msgstr "no se puede realizar un commit parcial durante una fusión."
+#: builtin/add.c:446
+msgid "-A and -u are mutually incompatible"
+msgstr "-A y -u son mutuamente incompatibles"
 
-#: builtin/commit.c:434
-msgid "cannot do a partial commit during a cherry-pick."
-msgstr "no se puede realizar un commit parcial durante un cherry-pick."
+#: builtin/add.c:449
+msgid "Option --ignore-missing can only be used together with --dry-run"
+msgstr "Opción --ignore-missing solo puede ser usada junto a --dry-run"
 
-#: builtin/commit.c:442
-msgid "cannot read the index"
-msgstr "no se puede leer el índice"
+#: builtin/add.c:453
+#, c-format
+msgid "--chmod param '%s' must be either -x or +x"
+msgstr "El parámetro '%s' para --chmod debe ser -x ó +x"
 
-#: builtin/commit.c:461
-msgid "unable to write temporary index file"
-msgstr "no es posible escribir el índice temporal"
+#: builtin/add.c:471 builtin/checkout.c:1648 builtin/commit.c:354
+#: builtin/reset.c:327
+msgid "--pathspec-from-file is incompatible with pathspec arguments"
+msgstr "--pathspec-from-file es incompatible con argumentos de pathspec"
+
+#: builtin/add.c:478 builtin/checkout.c:1660 builtin/commit.c:360
+#: builtin/reset.c:333
+msgid "--pathspec-file-nul requires --pathspec-from-file"
+msgstr "--pathspec-file-nul requiere --pathspec-from-file"
 
-#: builtin/commit.c:558
+#: builtin/add.c:482
 #, c-format
-msgid "commit '%s' lacks author header"
-msgstr "commit '%s' requiere cabecera de autor"
+msgid "Nothing specified, nothing added.\n"
+msgstr "Nada especificado, nada agregado.\n"
 
-#: builtin/commit.c:560
+#: builtin/add.c:483
 #, c-format
-msgid "commit '%s' has malformed author line"
-msgstr "el commit '%s' tiene una línea de autor mal formada"
+msgid "Maybe you wanted to say 'git add .'?\n"
+msgstr "¿Tal vez quiso decir 'git add .'?\n"
 
-#: builtin/commit.c:579
-msgid "malformed --author parameter"
-msgstr "parámetro --author mal formado"
+#: builtin/am.c:347
+msgid "could not parse author script"
+msgstr "no se pudo analizar el script del autor"
 
-#: builtin/commit.c:631
-msgid ""
-"unable to select a comment character that is not used\n"
-"in the current commit message"
-msgstr ""
-"no es posible seleccionar un carácter de comentario que no es usado\n"
-"en el mensaje de commit actual"
+#: builtin/am.c:431
+#, c-format
+msgid "'%s' was deleted by the applypatch-msg hook"
+msgstr "'%s' fue borrado por el hook de applypatch-msg"
 
-#: builtin/commit.c:668 builtin/commit.c:701 builtin/commit.c:1029
+#: builtin/am.c:473
 #, c-format
-msgid "could not lookup commit %s"
-msgstr "no se pudo revisar el commit %s"
+msgid "Malformed input line: '%s'."
+msgstr "Línea mal formada: '%s'."
 
-#: builtin/commit.c:680 builtin/shortlog.c:316
+#: builtin/am.c:511
 #, c-format
-msgid "(reading log message from standard input)\n"
-msgstr "(leyendo mensajes de logs desde standard input)\n"
+msgid "Failed to copy notes from '%s' to '%s'"
+msgstr "Falló al copiar notas de '%s' a '%s'"
 
-#: builtin/commit.c:682
-msgid "could not read log from standard input"
-msgstr "no se pudo leer log desde standard input"
+#: builtin/am.c:537
+msgid "fseek failed"
+msgstr "fall de fseek"
 
-#: builtin/commit.c:686
+#: builtin/am.c:725
 #, c-format
-msgid "could not read log file '%s'"
-msgstr "no se pudo leer el log '%s'"
+msgid "could not parse patch '%s'"
+msgstr "no se pudo analizar el parche '%s'"
 
-#: builtin/commit.c:715 builtin/commit.c:723
-msgid "could not read SQUASH_MSG"
-msgstr "no se pudo leer SQUASH_MSG"
+#: builtin/am.c:790
+msgid "Only one StGIT patch series can be applied at once"
+msgstr "Solo un parche StGIT puede ser aplicado de una vez"
 
-#: builtin/commit.c:720
-msgid "could not read MERGE_MSG"
-msgstr "no se pudo leer MERGE_MSG"
+#: builtin/am.c:838
+msgid "invalid timestamp"
+msgstr "timestamp inválido"
 
-#: builtin/commit.c:774
-msgid "could not write commit template"
-msgstr "no se pudo escribir el template del commit"
+#: builtin/am.c:843 builtin/am.c:855
+msgid "invalid Date line"
+msgstr "línea Date inválida"
 
-#: builtin/commit.c:792
-#, c-format
-msgid ""
-"\n"
-"It looks like you may be committing a merge.\n"
-"If this is not correct, please remove the file\n"
-"\t%s\n"
-"and try again.\n"
-msgstr ""
-"\n"
-"Parece que estas haciendo un commit con una fusión dentro.\n"
-"Si esto no es correcto, por favor remueve el archivo\n"
-"\t%s\n"
-"y vuelve a intentar.\n"
+#: builtin/am.c:850
+msgid "invalid timezone offset"
+msgstr "offset de zona horaria inválido"
 
-#: builtin/commit.c:797
-#, c-format
-msgid ""
-"\n"
-"It looks like you may be committing a cherry-pick.\n"
-"If this is not correct, please remove the file\n"
-"\t%s\n"
-"and try again.\n"
-msgstr ""
-"\n"
-"Parece que puede estar haciendo un commit a un cherry-pick.\n"
-"Si esto no es correcto, por favor elimine el archivo\n"
-"\t%s\n"
-"y vuelva a intentar.\n"
+#: builtin/am.c:943
+msgid "Patch format detection failed."
+msgstr "Falló al detectar el formato del parche."
 
-#: builtin/commit.c:810
+#: builtin/am.c:948 builtin/clone.c:409
 #, c-format
-msgid ""
-"Please enter the commit message for your changes. Lines starting\n"
-"with '%c' will be ignored, and an empty message aborts the commit.\n"
-msgstr ""
-"Por favor ingrese el mensaje del commit para sus cambios. Las líneas que "
-"comiencen\n"
-"con '%c' serán ignoradas, y un mensaje vacío aborta el commit.\n"
+msgid "failed to create directory '%s'"
+msgstr "falló al crear el directorio '%s'"
 
-#: builtin/commit.c:818
-#, c-format
-msgid ""
-"Please enter the commit message for your changes. Lines starting\n"
-"with '%c' will be kept; you may remove them yourself if you want to.\n"
-"An empty message aborts the commit.\n"
-msgstr ""
-"Por favor ingrese el mensaje del commit para sus cambios. Las líneas que "
-"comiencen\n"
-"con '%c' serán guardadas; puede removerlas usted mismo si desea.\n"
-"Un mensaje vacío aborta el commit.\n"
+#: builtin/am.c:953
+msgid "Failed to split patches."
+msgstr "Falló al dividir parches."
 
-#: builtin/commit.c:835
+#: builtin/am.c:1084
 #, c-format
-msgid "%sAuthor:    %.*s <%.*s>"
-msgstr "%sAutor:     %.*s <%.*s>"
+msgid "When you have resolved this problem, run \"%s --continue\"."
+msgstr "Cuando hayas resuelto este problema, ejecuta \"%s --continue\"."
 
-#: builtin/commit.c:843
+#: builtin/am.c:1085
 #, c-format
-msgid "%sDate:      %s"
-msgstr "%sFecha:     %s"
+msgid "If you prefer to skip this patch, run \"%s --skip\" instead."
+msgstr "Si prefieres saltar este parche, ejecuta \"%s --skip\"."
 
-#: builtin/commit.c:850
+#: builtin/am.c:1086
 #, c-format
-msgid "%sCommitter: %.*s <%.*s>"
-msgstr "%sCommitter: %.*s <%.*s>"
+msgid "To restore the original branch and stop patching, run \"%s --abort\"."
+msgstr ""
+"Para restaurar la rama original y detener el parchado, ejecutar \"%s --abort"
+"\"."
 
-#: builtin/commit.c:867
-msgid "Cannot read index"
-msgstr "No se puede leer el índice"
+#: builtin/am.c:1169
+msgid "Patch sent with format=flowed; space at the end of lines might be lost."
+msgstr ""
+"Parche mandado con formato=flowed; espacios al final de las líneas tal vez "
+"desaparezcan."
 
-#: builtin/commit.c:933
-msgid "Error building trees"
-msgstr "Error al construir los árboles"
+#: builtin/am.c:1197
+msgid "Patch is empty."
+msgstr "El parche está vacío."
 
-#: builtin/commit.c:947 builtin/tag.c:257
+#: builtin/am.c:1262
 #, c-format
-msgid "Please supply the message using either -m or -F option.\n"
-msgstr "Por favor suministra el mensaje usando las opciones -m o -F.\n"
+msgid "missing author line in commit %s"
+msgstr "falta línea autor en commit %s"
 
-#: builtin/commit.c:991
+#: builtin/am.c:1265
 #, c-format
-msgid "--author '%s' is not 'Name <email>' and matches no existing author"
-msgstr ""
-"--author '%s' no está en el formato 'Name <email>' y no concuerda con ningún "
-"autor existente"
+msgid "invalid ident line: %.*s"
+msgstr "sangría no válida: %.*s"
 
-#: builtin/commit.c:1005
-#, c-format
-msgid "Invalid ignored mode '%s'"
-msgstr "Modo ignorado inválido '%s'"
+#: builtin/am.c:1484
+msgid "Repository lacks necessary blobs to fall back on 3-way merge."
+msgstr ""
+"Repositorio carece de los blobs necesarios para retroceder en una fusión de "
+"3-vías."
 
-#: builtin/commit.c:1019 builtin/commit.c:1269
-#, c-format
-msgid "Invalid untracked files mode '%s'"
-msgstr "Modo inválido de los archivos no rastreados '%s'"
+#: builtin/am.c:1486
+msgid "Using index info to reconstruct a base tree..."
+msgstr "Usando la información del índice para reconstruir un árbol base..."
 
-#: builtin/commit.c:1057
-msgid "--long and -z are incompatible"
-msgstr "--long y -z son incompatibles"
+#: builtin/am.c:1505
+msgid ""
+"Did you hand edit your patch?\n"
+"It does not apply to blobs recorded in its index."
+msgstr ""
+"¿Editaste el parche a mano?\n"
+"No aplica a blobs guardados en su índice."
 
-#: builtin/commit.c:1090
-msgid "Using both --reset-author and --author does not make sense"
-msgstr "Usar ambos --reset-author y --author no tiene sentido"
-
-#: builtin/commit.c:1099
-msgid "You have nothing to amend."
-msgstr "No tienes nada que enmendar."
-
-#: builtin/commit.c:1102
-msgid "You are in the middle of a merge -- cannot amend."
-msgstr "Estás en medio de una fusión -- no puedes enmendar."
-
-#: builtin/commit.c:1104
-msgid "You are in the middle of a cherry-pick -- cannot amend."
-msgstr "Está en medio de un cherry-pick -- no se puede enmendar."
-
-#: builtin/commit.c:1107
-msgid "Options --squash and --fixup cannot be used together"
-msgstr "Opciones --squash y --fixup no pueden ser usadas juntas"
-
-#: builtin/commit.c:1117
-msgid "Only one of -c/-C/-F/--fixup can be used."
-msgstr "Solo uno de -c/-C/-F/--fixup puede ser usado."
-
-#: builtin/commit.c:1119
-msgid "Option -m cannot be combined with -c/-C/-F."
-msgstr "La opción -m no puede ser combinada con -c/-C/-F."
-
-#: builtin/commit.c:1127
-msgid "--reset-author can be used only with -C, -c or --amend."
-msgstr "--reset-author sólo puede ser usada con -C, -c o --amend."
+#: builtin/am.c:1511
+msgid "Falling back to patching base and 3-way merge..."
+msgstr "Retrocediendo para parchar base y fusión de 3-vías..."
 
-#: builtin/commit.c:1144
-msgid "Only one of --include/--only/--all/--interactive/--patch can be used."
-msgstr ""
-"Solo uno de --include/--only/--all/--interactive/--patch puede ser usado."
+#: builtin/am.c:1537
+msgid "Failed to merge in the changes."
+msgstr "Falló al fusionar en los cambios."
 
-#: builtin/commit.c:1146
-msgid "No paths with --include/--only does not make sense."
-msgstr "No hay rutas con --include/--only no tiene sentido."
+#: builtin/am.c:1569
+msgid "applying to an empty history"
+msgstr "aplicando a un historial vacío"
 
-#: builtin/commit.c:1160 builtin/tag.c:543
+#: builtin/am.c:1616 builtin/am.c:1620
 #, c-format
-msgid "Invalid cleanup mode %s"
-msgstr "Modo cleanup invalido %s"
-
-#: builtin/commit.c:1165
-msgid "Paths with -a does not make sense."
-msgstr "Rutas con -a no tiene sentido."
-
-#: builtin/commit.c:1303 builtin/commit.c:1480
-msgid "show status concisely"
-msgstr "mostrar status de manera concisa"
-
-#: builtin/commit.c:1305 builtin/commit.c:1482
-msgid "show branch information"
-msgstr "mostrar información de la rama"
+msgid "cannot resume: %s does not exist."
+msgstr "no se puede continuar: %s no existe."
 
-#: builtin/commit.c:1307
-msgid "show stash information"
-msgstr "mostrar información del stash"
+#: builtin/am.c:1638
+msgid "Commit Body is:"
+msgstr "Cuerpo de commit es:"
 
-#: builtin/commit.c:1309 builtin/commit.c:1484
-msgid "compute full ahead/behind values"
-msgstr "calcular todos los valores delante/atrás"
+#. TRANSLATORS: Make sure to include [y], [n], [e], [v] and [a]
+#. in your translation. The program will only accept English
+#. input at this point.
+#.
+#: builtin/am.c:1648
+#, c-format
+msgid "Apply? [y]es/[n]o/[e]dit/[v]iew patch/[a]ccept all: "
+msgstr "¿Aplicar? [y]es/[n]o/[e]dit/[v]iew patch/[a]ccept all: "
 
-#: builtin/commit.c:1311
-msgid "version"
-msgstr "version"
+#: builtin/am.c:1695 builtin/commit.c:394
+msgid "unable to write index file"
+msgstr "no es posible escribir en el archivo índice"
 
-#: builtin/commit.c:1311 builtin/commit.c:1486 builtin/push.c:558
-#: builtin/worktree.c:581
-msgid "machine-readable output"
-msgstr "output formato-maquina"
+#: builtin/am.c:1699
+#, c-format
+msgid "Dirty index: cannot apply patches (dirty: %s)"
+msgstr "Índice sucio: no se puede aplicar parches (sucio: %s)"
 
-#: builtin/commit.c:1314 builtin/commit.c:1488
-msgid "show status in long format (default)"
-msgstr "mostrar status en formato largo (default)"
+#: builtin/am.c:1739 builtin/am.c:1807
+#, c-format
+msgid "Applying: %.*s"
+msgstr "Aplicando: %.*s"
 
-#: builtin/commit.c:1317 builtin/commit.c:1491
-msgid "terminate entries with NUL"
-msgstr "terminar entradas con NUL"
+#: builtin/am.c:1756
+msgid "No changes -- Patch already applied."
+msgstr "Sin cambios -- parche ya aplicado."
 
-#: builtin/commit.c:1319 builtin/commit.c:1323 builtin/commit.c:1494
-#: builtin/fast-export.c:1001 builtin/fast-export.c:1004 builtin/tag.c:397
-msgid "mode"
-msgstr "modo"
+#: builtin/am.c:1762
+#, c-format
+msgid "Patch failed at %s %.*s"
+msgstr "El parche falló en %s %.*s"
 
-#: builtin/commit.c:1320 builtin/commit.c:1494
-msgid "show untracked files, optional modes: all, normal, no. (Default: all)"
-msgstr ""
-"mostrar archivos sin seguimiento, modos opcionales: all, normal, no. "
-"(Predeterminado: all)"
+#: builtin/am.c:1766
+msgid "Use 'git am --show-current-patch' to see the failed patch"
+msgstr "Use 'git am --show-current-patch' para ver el parche fallido"
 
-#: builtin/commit.c:1324
+#: builtin/am.c:1810
 msgid ""
-"show ignored files, optional modes: traditional, matching, no. (Default: "
-"traditional)"
+"No changes - did you forget to use 'git add'?\n"
+"If there is nothing left to stage, chances are that something else\n"
+"already introduced the same changes; you might want to skip this patch."
 msgstr ""
-"mostrar archivos ignorados, modos opcionales: traditional, matching, no. "
-"(Predeterminado: traditional)"
-
-#: builtin/commit.c:1326 parse-options.h:167
-msgid "when"
-msgstr "cuando"
+"Sin cambios - ¿olvidaste usar 'git add'?\n"
+"Si no hay nada en el área de stage, las posibilidad es que algo mas\n"
+"ya haya introducido el mismo cambio; tal vez quieras omitir este parche."
 
-#: builtin/commit.c:1327
+#: builtin/am.c:1817
 msgid ""
-"ignore changes to submodules, optional when: all, dirty, untracked. "
-"(Default: all)"
+"You still have unmerged paths in your index.\n"
+"You should 'git add' each file with resolved conflicts to mark them as "
+"such.\n"
+"You might run `git rm` on a file to accept \"deleted by them\" for it."
 msgstr ""
-"ignorar cambios en submódulos, opcional cuando: all,dirty,untracked. "
-"(Default: all)"
-
-#: builtin/commit.c:1329
-msgid "list untracked files in columns"
-msgstr "listar en columnas los archivos sin seguimiento"
+"Todavía tienes rutas sin fusionar en tu índice.\n"
+"Debes realizar 'git add' cada archivo con conflictos resueltos y marcarlos "
+"como tal.\n"
+"Se puede ejecutar `git rm` en el archivo para aceptar \"borrado por ellos\" "
+"en él."
 
-#: builtin/commit.c:1330
-msgid "do not detect renames"
-msgstr "no detectar renombrados"
+#: builtin/am.c:1924 builtin/am.c:1928 builtin/am.c:1940 builtin/reset.c:346
+#: builtin/reset.c:354
+#, c-format
+msgid "Could not parse object '%s'."
+msgstr "No se pudo analizar el objeto '%s'."
 
-#: builtin/commit.c:1332
-msgid "detect renames, optionally set similarity index"
-msgstr "detectar renombres, opcionalmente configurar similaridad de índice"
+#: builtin/am.c:1976
+msgid "failed to clean index"
+msgstr "falló al limpiar el índice"
 
-#: builtin/commit.c:1352
-msgid "Unsupported combination of ignored and untracked-files arguments"
+#: builtin/am.c:2020
+msgid ""
+"You seem to have moved HEAD since the last 'am' failure.\n"
+"Not rewinding to ORIG_HEAD"
 msgstr ""
-"Combinación de argumentos de archivos ignorados y no rastreados no soportada"
+"Parece haber movido HEAD desde el último falló 'am'.\n"
+"No rebobinando a ORIG_HEAD"
 
-#: builtin/commit.c:1450
-msgid "suppress summary after successful commit"
-msgstr "suprime summary tras un commit exitoso"
+#: builtin/am.c:2117
+#, c-format
+msgid "Invalid value for --patch-format: %s"
+msgstr "Valor inválido para --patch-format: %s"
 
-#: builtin/commit.c:1451
-msgid "show diff in commit message template"
-msgstr "mostrar diff en el template del mensaje de commit"
+#: builtin/am.c:2153
+msgid "git am [<options>] [(<mbox> | <Maildir>)...]"
+msgstr "git am [<opciones>] [(<mbox> | <Directorio-de-correo>)...]"
 
-#: builtin/commit.c:1453
-msgid "Commit message options"
-msgstr "Opciones para el mensaje del commit"
+#: builtin/am.c:2154
+msgid "git am [<options>] (--continue | --skip | --abort)"
+msgstr "git am [<opciones>] (--continue | --skip | --abort)"
 
-#: builtin/commit.c:1454 builtin/tag.c:394
-msgid "read message from file"
-msgstr "leer mensaje desde un archivo"
+#: builtin/am.c:2160
+msgid "run interactively"
+msgstr "ejecutar de manera interactiva"
 
-#: builtin/commit.c:1455
-msgid "author"
-msgstr "autor"
+#: builtin/am.c:2162
+msgid "historical option -- no-op"
+msgstr "opción histórica -- no-op"
 
-#: builtin/commit.c:1455
-msgid "override author for commit"
-msgstr "sobrescribe el autor del commit"
+#: builtin/am.c:2164
+msgid "allow fall back on 3way merging if needed"
+msgstr "permitir retroceso en fusión de 3-vías si es necesario"
 
-#: builtin/commit.c:1456 builtin/gc.c:501
-msgid "date"
-msgstr "fecha"
+#: builtin/am.c:2165 builtin/init-db.c:494 builtin/prune-packed.c:58
+#: builtin/repack.c:304 builtin/stash.c:811
+msgid "be quiet"
+msgstr "ser silencioso"
 
-#: builtin/commit.c:1456
-msgid "override date for commit"
-msgstr "sobrescribe la fecha del commit"
+#: builtin/am.c:2167
+msgid "add a Signed-off-by line to the commit message"
+msgstr "agregar una línea \"Firmado-por\" al mensaje del commit"
 
-#: builtin/commit.c:1457 builtin/merge.c:228 builtin/notes.c:402
-#: builtin/notes.c:565 builtin/tag.c:392
-msgid "message"
-msgstr "mensaje"
+#: builtin/am.c:2170
+msgid "recode into utf8 (default)"
+msgstr "recodificar en utf8 (default)"
 
-#: builtin/commit.c:1457
-msgid "commit message"
-msgstr "mensaje del commit"
+#: builtin/am.c:2172
+msgid "pass -k flag to git-mailinfo"
+msgstr "pasar flag -k a git-mailinfo"
 
-#: builtin/commit.c:1458 builtin/commit.c:1459 builtin/commit.c:1460
-#: builtin/commit.c:1461 parse-options.h:270 ref-filter.h:92
-msgid "commit"
-msgstr "confirmar"
+#: builtin/am.c:2174
+msgid "pass -b flag to git-mailinfo"
+msgstr "pasar flag -b a git-mailinfo"
 
-#: builtin/commit.c:1458
-msgid "reuse and edit message from specified commit"
-msgstr "reusar y editar el mensaje de un commit especifico"
+#: builtin/am.c:2176
+msgid "pass -m flag to git-mailinfo"
+msgstr "pasar flag -m a git-mailinfo"
 
-#: builtin/commit.c:1459
-msgid "reuse message from specified commit"
-msgstr "reusar el mensaje de un commit especifico"
+#: builtin/am.c:2178
+msgid "pass --keep-cr flag to git-mailsplit for mbox format"
+msgstr "pasar flag --keep-cr a git-mailsplit para formato mbox"
 
-#: builtin/commit.c:1460
-msgid "use autosquash formatted message to fixup specified commit"
+#: builtin/am.c:2181
+msgid "do not pass --keep-cr flag to git-mailsplit independent of am.keepcr"
 msgstr ""
-"usar mensaje de formato autosquash para arreglar el commit especificado"
+"no pasar flag --keep-cr a git-mailsplit independientemente de am.keepcr"
 
-#: builtin/commit.c:1461
-msgid "use autosquash formatted message to squash specified commit"
-msgstr ""
-"usar el mensaje de formato autosquash para realizar squash  al commit "
-"especificado"
+#: builtin/am.c:2184
+msgid "strip everything before a scissors line"
+msgstr "descubrir todo antes de una línea de tijeras"
 
-#: builtin/commit.c:1462
-msgid "the commit is authored by me now (used with -C/-c/--amend)"
-msgstr "el autor del commit soy yo ahora (usado con -C/-c/--amend)"
+#: builtin/am.c:2186 builtin/am.c:2189 builtin/am.c:2192 builtin/am.c:2195
+#: builtin/am.c:2198 builtin/am.c:2201 builtin/am.c:2204 builtin/am.c:2207
+#: builtin/am.c:2213
+msgid "pass it through git-apply"
+msgstr "pasarlo a través de git-apply"
 
-#: builtin/commit.c:1463 builtin/log.c:1446 builtin/merge.c:242
-#: builtin/pull.c:154 builtin/revert.c:105
-msgid "add Signed-off-by:"
-msgstr "agregar Signed-off-by: (firmado por)"
+#: builtin/am.c:2203 builtin/commit.c:1386 builtin/fmt-merge-msg.c:673
+#: builtin/fmt-merge-msg.c:676 builtin/grep.c:883 builtin/merge.c:249
+#: builtin/pull.c:160 builtin/pull.c:219 builtin/rebase.c:1469
+#: builtin/repack.c:315 builtin/repack.c:319 builtin/repack.c:321
+#: builtin/show-branch.c:650 builtin/show-ref.c:172 builtin/tag.c:403
+#: parse-options.h:154 parse-options.h:175 parse-options.h:316
+msgid "n"
+msgstr "n"
 
-#: builtin/commit.c:1464
-msgid "use specified template file"
-msgstr "usar archivo de template especificado"
+#: builtin/am.c:2209 builtin/branch.c:661 builtin/for-each-ref.c:38
+#: builtin/replace.c:555 builtin/tag.c:437 builtin/verify-tag.c:38
+msgid "format"
+msgstr "formato"
 
-#: builtin/commit.c:1465
-msgid "force edit of commit"
-msgstr "forzar la edición del commit"
+#: builtin/am.c:2210
+msgid "format the patch(es) are in"
+msgstr "formatear el parche(s)"
 
-#: builtin/commit.c:1466
-msgid "default"
-msgstr "default"
+#: builtin/am.c:2216
+msgid "override error message when patch failure occurs"
+msgstr "sobrescribir mensajes de error cuando fallos de parchado ocurran"
 
-#: builtin/commit.c:1466 builtin/tag.c:398
-msgid "how to strip spaces and #comments from message"
-msgstr "cómo quitar espacios y #comentarios de mensajes"
+#: builtin/am.c:2218
+msgid "continue applying patches after resolving a conflict"
+msgstr "continuar aplicando los parches tras resolver conflictos"
 
-#: builtin/commit.c:1467
-msgid "include status in commit message template"
-msgstr "incluir status en el template del mensaje de commit"
+#: builtin/am.c:2221
+msgid "synonyms for --continue"
+msgstr "sinónimos para --continue"
 
-#: builtin/commit.c:1469 builtin/merge.c:240 builtin/pull.c:184
-#: builtin/revert.c:113
-msgid "GPG sign commit"
-msgstr "Firmar commit con GPG"
+#: builtin/am.c:2224
+msgid "skip the current patch"
+msgstr "saltar el parche actual"
 
-#: builtin/commit.c:1472
-msgid "Commit contents options"
-msgstr "Opciones para el contenido del commit"
+#: builtin/am.c:2227
+msgid "restore the original branch and abort the patching operation."
+msgstr "restaurar la rama original y abortar la operación de parchado."
 
-#: builtin/commit.c:1473
-msgid "commit all changed files"
-msgstr "confirmar todos los archivos cambiados"
+#: builtin/am.c:2230
+msgid "abort the patching operation but keep HEAD where it is."
+msgstr "abortar la operación de parchado pero mantener HEAD donde está."
 
-#: builtin/commit.c:1474
-msgid "add specified files to index for commit"
-msgstr "agregar archivos específicos al índice para confirmar"
+#: builtin/am.c:2233
+msgid "show the patch being applied."
+msgstr "muestra el parche siendo aplicado."
 
-#: builtin/commit.c:1475
-msgid "interactively add files"
-msgstr "agregar archivos interactivamente"
+#: builtin/am.c:2237
+msgid "lie about committer date"
+msgstr "mentir sobre la fecha del committer"
 
-#: builtin/commit.c:1476
-msgid "interactively add changes"
-msgstr "agregar cambios interactivamente"
+#: builtin/am.c:2239
+msgid "use current timestamp for author date"
+msgstr "usar el timestamp actual para la fecha del autor"
 
-#: builtin/commit.c:1477
-msgid "commit only specified files"
-msgstr "sólo confirmar archivos específicos"
+#: builtin/am.c:2241 builtin/commit-tree.c:120 builtin/commit.c:1507
+#: builtin/merge.c:286 builtin/pull.c:194 builtin/rebase.c:509
+#: builtin/rebase.c:1513 builtin/revert.c:117 builtin/tag.c:418
+msgid "key-id"
+msgstr "key-id"
 
-#: builtin/commit.c:1478
-msgid "bypass pre-commit and commit-msg hooks"
-msgstr "evitar los capturadores (hooks) de pre-commit y commit-msg"
+#: builtin/am.c:2242 builtin/rebase.c:510 builtin/rebase.c:1514
+msgid "GPG-sign commits"
+msgstr "Commits con firma GPG"
 
-#: builtin/commit.c:1479
-msgid "show what would be committed"
-msgstr "mostrar lo que sería incluido en el commit"
+#: builtin/am.c:2245
+msgid "(internal use for git-rebase)"
+msgstr "(uso interno para git-rebase)"
 
-#: builtin/commit.c:1492
-msgid "amend previous commit"
-msgstr "enmendar commit previo"
-
-#: builtin/commit.c:1493
-msgid "bypass post-rewrite hook"
-msgstr "gancho bypass post reescritura"
+#: builtin/am.c:2263
+msgid ""
+"The -b/--binary option has been a no-op for long time, and\n"
+"it will be removed. Please do not use it anymore."
+msgstr ""
+"La opción -b/--binary ha estado deshabilitada por mucho tiempo, y\n"
+"será eliminada. Por favor no la use más."
 
-#: builtin/commit.c:1498
-msgid "ok to record an empty change"
-msgstr "ok al grabar un cambio vacío"
+#: builtin/am.c:2270
+msgid "failed to read the index"
+msgstr "falló al leer el índice"
 
-#: builtin/commit.c:1500
-msgid "ok to record a change with an empty message"
-msgstr "ok al grabar un cambio con un mensaje vacío"
+#: builtin/am.c:2285
+#, c-format
+msgid "previous rebase directory %s still exists but mbox given."
+msgstr "directorio de rebase previo %s todavía existe en el mbox dado."
 
-#: builtin/commit.c:1573
+#: builtin/am.c:2309
 #, c-format
-msgid "Corrupt MERGE_HEAD file (%s)"
-msgstr "Archivo MERGE_HEAD (%s) corrupto"
+msgid ""
+"Stray %s directory found.\n"
+"Use \"git am --abort\" to remove it."
+msgstr ""
+"Directorio extraviado %s encontrado.\n"
+"Use \"git am --abort\" para borrarlo."
 
-#: builtin/commit.c:1580
-msgid "could not read MERGE_MODE"
-msgstr "no se pudo leer MERGE_MODE"
+#: builtin/am.c:2315
+msgid "Resolve operation not in progress, we are not resuming."
+msgstr "Operación de resolución no está en progreso, no vamos a continuar."
 
-#: builtin/commit.c:1599
-#, c-format
-msgid "could not read commit message: %s"
-msgstr "no se pudo leer el mensaje de commit: %s"
+#: builtin/am.c:2325
+msgid "interactive mode requires patches on the command line"
+msgstr "modo interactivo requiere parches en la línea de comando"
+
+#: builtin/apply.c:8
+msgid "git apply [<options>] [<patch>...]"
+msgstr "git apply [<opciones>] [<parche>...]"
 
-#: builtin/commit.c:1610
+#: builtin/archive.c:17
 #, c-format
-msgid "Aborting commit due to empty commit message.\n"
-msgstr "Abortando commit debido que el mensaje está en blanco.\n"
+msgid "could not create archive file '%s'"
+msgstr "no se pudo crear el archivo comprimido '%s'"
+
+#: builtin/archive.c:20
+msgid "could not redirect output"
+msgstr "no se pudo direccionar la salida"
+
+#: builtin/archive.c:37
+msgid "git archive: Remote with no URL"
+msgstr "git archive: Remote sin URL"
+
+#: builtin/archive.c:61
+msgid "git archive: expected ACK/NAK, got a flush packet"
+msgstr "git archive: se esperaba ACK/NAK, se obtuvo flush packet"
 
-#: builtin/commit.c:1615
+#: builtin/archive.c:64
 #, c-format
-msgid "Aborting commit; you did not edit the message.\n"
-msgstr "Abortando commit; no se ha editado el mensaje\n"
+msgid "git archive: NACK %s"
+msgstr "git archive: NACK %s"
+
+#: builtin/archive.c:65
+msgid "git archive: protocol error"
+msgstr "git archive: error de protocolo"
+
+#: builtin/archive.c:69
+msgid "git archive: expected a flush"
+msgstr "git archive: se esperaba un flush"
+
+#: builtin/bisect--helper.c:22
+msgid "git bisect--helper --next-all [--no-checkout]"
+msgstr "git bisect--helper --next-all [--no-checkout]"
 
-#: builtin/commit.c:1650
+#: builtin/bisect--helper.c:23
+msgid "git bisect--helper --write-terms <bad_term> <good_term>"
+msgstr "git bisect--helper --write-terms <mal_término> <buen_término>"
+
+#: builtin/bisect--helper.c:24
+msgid "git bisect--helper --bisect-clean-state"
+msgstr "git bisect--helper --bisect-clean-state"
+
+#: builtin/bisect--helper.c:25
+msgid "git bisect--helper --bisect-reset [<commit>]"
+msgstr "git bisect--helper --bisect-reset [<commit>]"
+
+#: builtin/bisect--helper.c:26
 msgid ""
-"Repository has been updated, but unable to write\n"
-"new_index file. Check that disk is not full and quota is\n"
-"not exceeded, and then \"git reset HEAD\" to recover."
+"git bisect--helper --bisect-write [--no-log] <state> <revision> <good_term> "
+"<bad_term>"
 msgstr ""
-"El repositorio ha sido actualizado, pero no se pudo escribir el archivo\n"
-"new_index. Verifique que el disco no este lleno y la quota no ha\n"
-"sido superada, y luego \"git reset HEAD\" para recuperar."
+"git bisect--helper --bisect-write [--no-log] <estado> <revision> <buen_term> "
+"<mal_term>"
 
-#: builtin/commit-graph.c:9
-msgid "git commit-graph [--object-dir <objdir>]"
-msgstr "git commit-graph [--object-dir <objdir>]"
+#: builtin/bisect--helper.c:27
+msgid ""
+"git bisect--helper --bisect-check-and-set-terms <command> <good_term> "
+"<bad_term>"
+msgstr ""
+"git bisect--helper --bisect-check-and-set-terms <comando> <buen_term> "
+"<mal_term>"
 
-#: builtin/commit-graph.c:10 builtin/commit-graph.c:16
-msgid "git commit-graph read [--object-dir <objdir>]"
-msgstr "git commit-graph read [--object-dir <objdir>]"
+#: builtin/bisect--helper.c:28
+msgid "git bisect--helper --bisect-next-check <good_term> <bad_term> [<term>]"
+msgstr "git bisect--helper --bisect-next-check <buen_term> <mal_term> [<term>]"
 
-#: builtin/commit-graph.c:11 builtin/commit-graph.c:21
+#: builtin/bisect--helper.c:29
 msgid ""
-"git commit-graph write [--object-dir <objdir>] [--append] [--stdin-packs|--"
-"stdin-commits]"
+"git bisect--helper --bisect-terms [--term-good | --term-old | --term-bad | --"
+"term-new]"
 msgstr ""
-"git commit-graph write [--object-dir <objdir>] [--append] [--stdin-packs|--"
-"stdin-commits]"
-
-#: builtin/commit-graph.c:39 builtin/commit-graph.c:92
-#: builtin/commit-graph.c:147 builtin/fetch.c:161 builtin/log.c:1466
-msgid "dir"
-msgstr "dir"
+"git bisect--helper --bisect-terms [--term-good | --term-old | --term-bad | --"
+"term-new]"
 
-#: builtin/commit-graph.c:40 builtin/commit-graph.c:93
-#: builtin/commit-graph.c:148
-msgid "The object directory to store the graph"
-msgstr "El directorio de objetos para guardar el gráfico"
+#: builtin/bisect--helper.c:30
+msgid ""
+"git bisect--helper --bisect-start [--term-{old,good}=<term> --term-{new,bad}"
+"=<term>][--no-checkout] [<bad> [<good>...]] [--] [<paths>...]"
+msgstr ""
+"git bisect--helper --bisect-start [--term-{old,good}=<término> --term-{new,"
+"bad}=<término>][--no-checkout] [<malo> [<bueno>...]] [--] [<rutas>...]"
 
-#: builtin/commit-graph.c:95
-msgid "scan pack-indexes listed by stdin for commits"
-msgstr "escanear paquete de índices por stdin por commits"
+#: builtin/bisect--helper.c:86
+#, c-format
+msgid "'%s' is not a valid term"
+msgstr "'%s' no es un término válido"
 
-#: builtin/commit-graph.c:97
-msgid "start walk at commits listed by stdin"
-msgstr "comenzar a caminar a los commits listados por stdin"
+#: builtin/bisect--helper.c:90
+#, c-format
+msgid "can't use the builtin command '%s' as a term"
+msgstr "no se puede usar el comando nativo '%s' como un término"
 
-#: builtin/commit-graph.c:99
-msgid "include all commits already in the commit-graph file"
-msgstr "inclye todos los commits que ya están en el archivo commit-graph"
+#: builtin/bisect--helper.c:100
+#, c-format
+msgid "can't change the meaning of the term '%s'"
+msgstr "no se puede cambiar el significado del término '%s'"
 
-#: builtin/commit-graph.c:108
-msgid "cannot use both --stdin-commits and --stdin-packs"
-msgstr "no se pueden usar ambos --stdin-commits y --stdin-packs"
+#: builtin/bisect--helper.c:111
+msgid "please use two different terms"
+msgstr "por favor use dos términos diferentes"
 
-#: builtin/config.c:10
-msgid "git config [<options>]"
-msgstr "git config [<opciones>]"
+#: builtin/bisect--helper.c:118
+msgid "could not open the file BISECT_TERMS"
+msgstr "no se pudo abrir el archivo BISECT_TERMS"
 
-#: builtin/config.c:101
+#: builtin/bisect--helper.c:155
 #, c-format
-msgid "unrecognized --type argument, %s"
-msgstr "argumento --type no reconocido, %s"
+msgid "We are not bisecting.\n"
+msgstr "No estamos bisecando.\n"
 
-#: builtin/config.c:123
-msgid "Config file location"
-msgstr "Ubicación del archivo configuración"
+#: builtin/bisect--helper.c:163
+#, c-format
+msgid "'%s' is not a valid commit"
+msgstr "'%s' no es un commit válido"
 
-#: builtin/config.c:124
-msgid "use global config file"
-msgstr "usar archivo de config global"
+#: builtin/bisect--helper.c:172
+#, c-format
+msgid ""
+"could not check out original HEAD '%s'. Try 'git bisect reset <commit>'."
+msgstr ""
+"no se pudo hacer check out al HEAD original '%s'. Intenta 'git bisect reset "
+"<commit>'."
 
-#: builtin/config.c:125
-msgid "use system config file"
-msgstr "usar archivo de config del sistema"
+#: builtin/bisect--helper.c:216
+#, c-format
+msgid "Bad bisect_write argument: %s"
+msgstr "Mal argumento bisect_write: %s"
 
-#: builtin/config.c:126
-msgid "use repository config file"
-msgstr "usar archivo de config del repositorio"
+#: builtin/bisect--helper.c:221
+#, c-format
+msgid "couldn't get the oid of the rev '%s'"
+msgstr "no se puede obtener el oid de la rev '%s'"
 
-#: builtin/config.c:127
-msgid "use given config file"
-msgstr "usar archivo config especificado"
+#: builtin/bisect--helper.c:233
+#, c-format
+msgid "couldn't open the file '%s'"
+msgstr "no se pudo abrir el archivo '%s'"
 
-#: builtin/config.c:128
-msgid "blob-id"
-msgstr "blob-id"
+#: builtin/bisect--helper.c:259
+#, c-format
+msgid "Invalid command: you're currently in a %s/%s bisect"
+msgstr "Comando inválido: actualmente se encuentra en un bisect %s/%s"
 
-#: builtin/config.c:128
-msgid "read config from given blob object"
-msgstr "leer config del objeto blob suministrado"
+#: builtin/bisect--helper.c:286
+#, c-format
+msgid ""
+"You need to give me at least one %s and %s revision.\n"
+"You can use \"git bisect %s\" and \"git bisect %s\" for that."
+msgstr ""
+"Tienes que dar al menos un %s y un %s revision.\n"
+"Se puede ver \"git bisect %s\" y \"git bisect %s\" para eso."
 
-#: builtin/config.c:129
-msgid "Action"
-msgstr "Acción"
+#: builtin/bisect--helper.c:290
+#, c-format
+msgid ""
+"You need to start by \"git bisect start\".\n"
+"You then need to give me at least one %s and %s revision.\n"
+"You can use \"git bisect %s\" and \"git bisect %s\" for that."
+msgstr ""
+"Tienes que comenzar por \"git bisect start\".\n"
+"Después tienes que entregar al menos un %s y una revision %s.\n"
+"Puedes usar \"git bisect %s\" y \"git bisect %s\" para eso."
 
-#: builtin/config.c:130
-msgid "get value: name [value-regex]"
-msgstr "obtener valor: nombre [valor-regex]"
+#: builtin/bisect--helper.c:322
+#, c-format
+msgid "bisecting only with a %s commit"
+msgstr "haciendo bisect solo con un commit %s"
 
-#: builtin/config.c:131
-msgid "get all values: key [value-regex]"
-msgstr "obtener todos los valores: llave [valores-regex]"
+#. TRANSLATORS: Make sure to include [Y] and [n] in your
+#. translation. The program will only accept English input
+#. at this point.
+#.
+#: builtin/bisect--helper.c:330
+msgid "Are you sure [Y/n]? "
+msgstr "¿Estás seguro [Y/n]? "
 
-#: builtin/config.c:132
-msgid "get values for regexp: name-regex [value-regex]"
-msgstr "obtener valores para una regexp: nombre-regex [valor-regex]"
+#: builtin/bisect--helper.c:377
+msgid "no terms defined"
+msgstr "no hay términos definidos"
 
-#: builtin/config.c:133
-msgid "get value specific for the URL: section[.var] URL"
-msgstr "obtener valor especifico para el URL: sección[.var] URL"
+#: builtin/bisect--helper.c:380
+#, c-format
+msgid ""
+"Your current terms are %s for the old state\n"
+"and %s for the new state.\n"
+msgstr ""
+"Tus términos actuales son %s para el estado viejo\n"
+"y %s para el estado nuevo.\n"
 
-#: builtin/config.c:134
-msgid "replace all matching variables: name value [value_regex]"
+#: builtin/bisect--helper.c:390
+#, c-format
+msgid ""
+"invalid argument %s for 'git bisect terms'.\n"
+"Supported options are: --term-good|--term-old and --term-bad|--term-new."
 msgstr ""
-"remplazar todas las variables que concuerden: nombre valor [valor_regex]"
+"argumento inválido %s para 'git bisect terms'.\n"
+"Las opciones soportadas son: --term-good|--term-old y --term-bad|--term-new."
 
-#: builtin/config.c:135
-msgid "add a new variable: name value"
-msgstr "agregar nueva variable: nombre valor"
+#: builtin/bisect--helper.c:476
+#, c-format
+msgid "unrecognized option: '%s'"
+msgstr "opción desconocida: '%s'"
 
-#: builtin/config.c:136
-msgid "remove a variable: name [value-regex]"
-msgstr "borrar una variable. nombre [valor-regex]"
+#: builtin/bisect--helper.c:480
+#, c-format
+msgid "'%s' does not appear to be a valid revision"
+msgstr "'%s' no parece ser una revisión válida"
 
-#: builtin/config.c:137
-msgid "remove all matches: name [value-regex]"
-msgstr "borrar todas las concurrencias: nombre [valor-regex]"
+#: builtin/bisect--helper.c:512
+msgid "bad HEAD - I need a HEAD"
+msgstr "mal HEAD - Necesito un HEAD"
 
-#: builtin/config.c:138
-msgid "rename section: old-name new-name"
-msgstr "renombrar sección: nombre-viejo nombre-nuevo"
+#: builtin/bisect--helper.c:527
+#, c-format
+msgid "checking out '%s' failed. Try 'git bisect start <valid-branch>'."
+msgstr ""
+"error al hacer checkout '%s'. Intente 'git bisect start <rama-válida>'."
 
-#: builtin/config.c:139
-msgid "remove a section: name"
-msgstr "borrar una sección: nombre"
+#: builtin/bisect--helper.c:548
+msgid "won't bisect on cg-seek'ed tree"
+msgstr "no se bisecará en un árbol con cg-seek"
 
-#: builtin/config.c:140
-msgid "list all"
-msgstr "listar todo"
+#: builtin/bisect--helper.c:551
+msgid "bad HEAD - strange symbolic ref"
+msgstr "mal HEAD - ref simbólico extraño"
 
-#: builtin/config.c:141
-msgid "open an editor"
-msgstr "abrir el editor"
+#: builtin/bisect--helper.c:575
+#, c-format
+msgid "invalid ref: '%s'"
+msgstr "ref inválido: '%s'"
 
-#: builtin/config.c:142
-msgid "find the color configured: slot [default]"
-msgstr "encontrar el color configurado: slot [default]"
+#: builtin/bisect--helper.c:631
+msgid "perform 'git bisect next'"
+msgstr "realiza 'git bisect next'"
 
-#: builtin/config.c:143
-msgid "find the color setting: slot [stdout-is-tty]"
-msgstr "encontrar las opciones del color: slot [stdout-es-tty]"
+#: builtin/bisect--helper.c:633
+msgid "write the terms to .git/BISECT_TERMS"
+msgstr "escribe los términos a .git/BISECT_TERMS"
 
-#: builtin/config.c:144
-msgid "Type"
-msgstr "Tipo"
+#: builtin/bisect--helper.c:635
+msgid "cleanup the bisection state"
+msgstr "limpiar el estado de bisección"
 
-#: builtin/config.c:145
-msgid "value is given this type"
-msgstr "al valor se ha dado este tipo"
+#: builtin/bisect--helper.c:637
+msgid "check for expected revs"
+msgstr "revisar por revs esperados"
 
-#: builtin/config.c:146
-msgid "value is \"true\" or \"false\""
-msgstr "valor es \"true\" o \"false\""
+#: builtin/bisect--helper.c:639
+msgid "reset the bisection state"
+msgstr "reiniciar el estado de bisect"
+
+#: builtin/bisect--helper.c:641
+msgid "write out the bisection state in BISECT_LOG"
+msgstr "escribir el estado de bisect en BISECT_LOG"
+
+#: builtin/bisect--helper.c:643
+msgid "check and set terms in a bisection state"
+msgstr "revisar y configurar los terms en el estado de bisect"
+
+#: builtin/bisect--helper.c:645
+msgid "check whether bad or good terms exist"
+msgstr "revisar si existen términos malos o buenos"
+
+#: builtin/bisect--helper.c:647
+msgid "print out the bisect terms"
+msgstr "imprimir los terms del bisect"
+
+#: builtin/bisect--helper.c:649
+msgid "start the bisect session"
+msgstr "comenzar la sesión de bisect"
 
-#: builtin/config.c:147
-msgid "value is decimal number"
-msgstr "valor es un numero decimal"
+#: builtin/bisect--helper.c:651
+msgid "update BISECT_HEAD instead of checking out the current commit"
+msgstr "actualiza BISECT_HEAD en lugar de revisar el commit actual"
 
-#: builtin/config.c:148
-msgid "value is --bool or --int"
-msgstr "valor es --bool o --int"
+#: builtin/bisect--helper.c:653
+msgid "no log for BISECT_WRITE"
+msgstr "no hay log para BISECT_WRITE"
 
-#: builtin/config.c:149
-msgid "value is a path (file or directory name)"
-msgstr "valor es una ruta (archivo o nombre de directorio)"
+#: builtin/bisect--helper.c:670
+msgid "--write-terms requires two arguments"
+msgstr "--write-terms requiere dos argumentos"
 
-#: builtin/config.c:150
-msgid "value is an expiry date"
-msgstr "valor es una fecha de expiración"
+#: builtin/bisect--helper.c:674
+msgid "--bisect-clean-state requires no arguments"
+msgstr "--bisect-clean-state no requiere argumentos"
 
-#: builtin/config.c:151
-msgid "Other"
-msgstr "Otro"
+#: builtin/bisect--helper.c:681
+msgid "--bisect-reset requires either no argument or a commit"
+msgstr "--bisect-reset requiere un commit o ningún argumento"
+
+#: builtin/bisect--helper.c:685
+msgid "--bisect-write requires either 4 or 5 arguments"
+msgstr "--bisect-write requiere entre 4 o 5 argumentos"
 
-#: builtin/config.c:152
-msgid "terminate values with NUL byte"
-msgstr "terminar valores con un byte NULL"
-
-#: builtin/config.c:153
-msgid "show variable names only"
-msgstr "mostrar solo nombres de variables"
-
-#: builtin/config.c:154
-msgid "respect include directives on lookup"
-msgstr "respetar directivas include en la búsqueda"
+#: builtin/bisect--helper.c:691
+msgid "--check-and-set-terms requires 3 arguments"
+msgstr "--bisect-clean-state no requiere argumentos"
 
-#: builtin/config.c:155
-msgid "show origin of config (file, standard input, blob, command line)"
-msgstr "mostrar el origen de configuración (archivo, stdin, blob, comando)"
+#: builtin/bisect--helper.c:697
+msgid "--bisect-next-check requires 2 or 3 arguments"
+msgstr "--bisect-next-check requiere 2 o 3 argumentos"
+
+#: builtin/bisect--helper.c:703
+msgid "--bisect-terms requires 0 or 1 argument"
+msgstr "--bisect-terms requiere 0 o 1 argumentos"
 
-#: builtin/config.c:156
-msgid "value"
-msgstr "valor"
+#: builtin/blame.c:31
+msgid "git blame [<options>] [<rev-opts>] [<rev>] [--] <file>"
+msgstr "git blame [<opciones>] [<opciones-rev>] [<revision>] [--] <archivo>"
 
-#: builtin/config.c:156
-msgid "with --get, use default value when missing entry"
-msgstr "con --get, usa el valor por defecto cuando falta una entrada"
+#: builtin/blame.c:36
+msgid "<rev-opts> are documented in git-rev-list(1)"
+msgstr "<rev-opts> están documentadas en git-rev-list(1)"
 
-#: builtin/config.c:332
+#: builtin/blame.c:409
 #, c-format
-msgid "failed to format default config value: %s"
-msgstr "falló al formatear el valor por defecto de configuración: %s"
+msgid "expecting a color: %s"
+msgstr "esperando un color: %s"
 
-#: builtin/config.c:431
-msgid "unable to parse default color value"
-msgstr "no es posible analizar el valor por defecto de color"
+#: builtin/blame.c:416
+msgid "must end with a color"
+msgstr "tiene que terminar con un color"
 
-#: builtin/config.c:575
+#: builtin/blame.c:729
 #, c-format
-msgid ""
-"# This is Git's per-user configuration file.\n"
-"[user]\n"
-"# Please adapt and uncomment the following lines:\n"
-"#\tname = %s\n"
-"#\temail = %s\n"
-msgstr ""
-"# Este es el archivo de configuración de Git por usuario.\n"
-"[user]\n"
-"# Por favor, adapta y descomenta las siguientes líneas:\n"
-"#\tname = %s\n"
-"#\temail = %s\n"
-
-#: builtin/config.c:603
-msgid "--local can only be used inside a git repository"
-msgstr "--local solo puedo ser usado dentro de un repositorio"
-
-#: builtin/config.c:606
-msgid "--blob can only be used inside a git repository"
-msgstr "--blob solo puede ser usado dentro de un repositorio"
+msgid "invalid color '%s' in color.blame.repeatedLines"
+msgstr "color inválido '%s' en color.blame.repeatedLines"
 
-#: builtin/config.c:735
-#, c-format
-msgid "cannot create configuration file %s"
-msgstr "no se puede crear el archivo de configuración %s"
+#: builtin/blame.c:747
+msgid "invalid value for blame.coloring"
+msgstr "valor inválido para blame.coloring"
 
-#: builtin/config.c:748
+#: builtin/blame.c:822
 #, c-format
-msgid ""
-"cannot overwrite multiple values with a single value\n"
-"       Use a regexp, --add or --replace-all to change %s."
-msgstr ""
-"no se puede sobrescribir múltiples valores con un único valor\n"
-"\tUse una regexp, --add o --replace-all para cambiar %s."
+msgid "cannot find revision %s to ignore"
+msgstr "no se pudo encontrar revision %s para ignorar"
 
-#: builtin/count-objects.c:90
-msgid "git count-objects [-v] [-H | --human-readable]"
-msgstr "git count-objects [-v] [-H | --human-readable]"
+#: builtin/blame.c:844
+msgid "Show blame entries as we find them, incrementally"
+msgstr "Mostrar las entradas blame como las encontramos, incrementalmente"
 
-#: builtin/count-objects.c:100
-msgid "print sizes in human readable format"
-msgstr "mostrar tamaños en formato legible para humano"
+#: builtin/blame.c:845
+msgid "Show blank SHA-1 for boundary commits (Default: off)"
+msgstr "Mostrar SHA-1 en blanco para commits extremos (Default: off)"
 
-#: builtin/describe.c:22
-msgid "git describe [<options>] [<commit-ish>...]"
-msgstr "git describe [<opciones>] [<commit-ish>...]"
+#: builtin/blame.c:846
+msgid "Do not treat root commits as boundaries (Default: off)"
+msgstr "No tratar commits raíces como extremos (Default: off)"
 
-#: builtin/describe.c:23
-msgid "git describe [<options>] --dirty"
-msgstr "git describe [<opciones>] --dirty"
+#: builtin/blame.c:847
+msgid "Show work cost statistics"
+msgstr "Mostrar estadísticas de costo de trabajo"
 
-#: builtin/describe.c:57
-msgid "head"
-msgstr "head"
+#: builtin/blame.c:848
+msgid "Force progress reporting"
+msgstr "Forzar el reporte de progreso"
 
-#: builtin/describe.c:57
-msgid "lightweight"
-msgstr "ligero"
+#: builtin/blame.c:849
+msgid "Show output score for blame entries"
+msgstr "Mostrar la puntuación de salida de las entradas de blame"
 
-#: builtin/describe.c:57
-msgid "annotated"
-msgstr "anotado"
+#: builtin/blame.c:850
+msgid "Show original filename (Default: auto)"
+msgstr "Mostrar nombre original del archivo (Default: auto)"
 
-#: builtin/describe.c:267
-#, c-format
-msgid "annotated tag %s not available"
-msgstr "tag anotado %s no disponible"
+#: builtin/blame.c:851
+msgid "Show original linenumber (Default: off)"
+msgstr "Mostrar número de línea original (Default: off)"
 
-#: builtin/describe.c:271
-#, c-format
-msgid "annotated tag %s has no embedded name"
-msgstr "tag anotado %s no tiene nombre embebido"
+#: builtin/blame.c:852
+msgid "Show in a format designed for machine consumption"
+msgstr "Mostrar en un formato diseñado para consumo de máquina"
 
-#: builtin/describe.c:273
-#, c-format
-msgid "tag '%s' is really '%s' here"
-msgstr "tag '%s' es realmente '%s' aquí"
+#: builtin/blame.c:853
+msgid "Show porcelain format with per-line commit information"
+msgstr "Mostrar en formato porcelana con información de commit por línea"
 
-#: builtin/describe.c:317
-#, c-format
-msgid "no tag exactly matches '%s'"
-msgstr "no hay tag que concuerde exactamente con '%s'"
+#: builtin/blame.c:854
+msgid "Use the same output mode as git-annotate (Default: off)"
+msgstr "Usar el mismo modo salida como git-annotate (Default: off)"
 
-#: builtin/describe.c:319
-#, c-format
-msgid "No exact match on refs or tags, searching to describe\n"
-msgstr "No hay coincidencia exacta en refs o tags, buscando en describe\n"
+#: builtin/blame.c:855
+msgid "Show raw timestamp (Default: off)"
+msgstr "Mostrar timestamp en formato raw (Default: off)"
 
-#: builtin/describe.c:366
-#, c-format
-msgid "finished search at %s\n"
-msgstr "búsqueda finalizada a las %s\n"
+#: builtin/blame.c:856
+msgid "Show long commit SHA1 (Default: off)"
+msgstr "Mostrar SHA1 del commit en formato largo (Default: off)"
 
-#: builtin/describe.c:392
-#, c-format
-msgid ""
-"No annotated tags can describe '%s'.\n"
-"However, there were unannotated tags: try --tags."
-msgstr ""
-"No hay tags anotados que puedan describir '%s'.\n"
-"Sin embargo, hubieron tags no anotados: intente --tags."
+#: builtin/blame.c:857
+msgid "Suppress author name and timestamp (Default: off)"
+msgstr "Suprimir nombre del autor y timestamp (Default: off)"
 
-#: builtin/describe.c:396
-#, c-format
-msgid ""
-"No tags can describe '%s'.\n"
-"Try --always, or create some tags."
-msgstr ""
-"Ningún tag puede describit '%s'.\n"
-"Intente --always, o cree algunos tags."
+#: builtin/blame.c:858
+msgid "Show author email instead of name (Default: off)"
+msgstr "Mostrar en cambio el email del autor (Default: off)"
 
-#: builtin/describe.c:426
-#, c-format
-msgid "traversed %lu commits\n"
-msgstr "%lu commits cruzados\n"
+#: builtin/blame.c:859
+msgid "Ignore whitespace differences"
+msgstr "Ignorar diferencias de espacios en blanco"
 
-#: builtin/describe.c:429
-#, c-format
-msgid ""
-"more than %i tags found; listed %i most recent\n"
-"gave up search at %s\n"
-msgstr ""
-"se encontró más de %i tags; se mostró %i más reciente\n"
-"fin de la búsqueda en %s\n"
+#: builtin/blame.c:860 builtin/log.c:1702
+msgid "rev"
+msgstr "rev"
+
+#: builtin/blame.c:860
+msgid "Ignore <rev> when blaming"
+msgstr "Ignorar <rev> durante el blame"
+
+#: builtin/blame.c:861
+msgid "Ignore revisions from <file>"
+msgstr "Ignorar revisiones de <archivo>"
 
-#: builtin/describe.c:497
-#, c-format
-msgid "describe %s\n"
-msgstr "describe %s\n"
+#: builtin/blame.c:862
+msgid "color redundant metadata from previous line differently"
+msgstr "colorear metadata redundante de líneas previas de manera diferente"
 
-#: builtin/describe.c:500 builtin/log.c:502
-#, c-format
-msgid "Not a valid object name %s"
-msgstr "Nombre de objeto %s no válido"
+#: builtin/blame.c:863
+msgid "color lines by age"
+msgstr "colorear líneas por edad"
 
-#: builtin/describe.c:508
-#, c-format
-msgid "%s is neither a commit nor blob"
-msgstr "%s no es un commit ni un blob"
+#: builtin/blame.c:864
+msgid "Spend extra cycles to find better match"
+msgstr "Ocupo más ciclos para encontrar mejoras resultados"
 
-#: builtin/describe.c:522
-msgid "find the tag that comes after the commit"
-msgstr "encontrar el tag que viene después del commit"
+#: builtin/blame.c:865
+msgid "Use revisions from <file> instead of calling git-rev-list"
+msgstr "Use revisiones desde <archivo> en lugar de llamar git-rev-list"
 
-#: builtin/describe.c:523
-msgid "debug search strategy on stderr"
-msgstr "hacer debug a la estrategia de búsqueda en stderr"
+#: builtin/blame.c:866
+msgid "Use <file>'s contents as the final image"
+msgstr "Usar contenido de <archivo> como imagen final"
 
-#: builtin/describe.c:524
-msgid "use any ref"
-msgstr "use cualquier ref"
+#: builtin/blame.c:867 builtin/blame.c:868
+msgid "score"
+msgstr "puntaje"
 
-#: builtin/describe.c:525
-msgid "use any tag, even unannotated"
-msgstr "use cualquier tag, incluso los no anotados"
+#: builtin/blame.c:867
+msgid "Find line copies within and across files"
+msgstr "Encontrar copias de líneas entre y a través de archivos"
 
-#: builtin/describe.c:526
-msgid "always use long format"
-msgstr "siempre usar formato largo"
+#: builtin/blame.c:868
+msgid "Find line movements within and across files"
+msgstr "Encontrar movimientos de líneas entre y a través de archivos"
 
-#: builtin/describe.c:527
-msgid "only follow first parent"
-msgstr "solo seguir el primer patrón"
+#: builtin/blame.c:869
+msgid "n,m"
+msgstr "n,m"
 
-#: builtin/describe.c:530
-msgid "only output exact matches"
-msgstr "solo mostrar concordancias exactas"
+#: builtin/blame.c:869
+msgid "Process only line range n,m, counting from 1"
+msgstr "Procesar solo el rango de líneas n,m, contando desde 1"
 
-#: builtin/describe.c:532
-msgid "consider <n> most recent tags (default: 10)"
-msgstr "considerar <n> tags más recientes (default:10)"
+#: builtin/blame.c:921
+msgid "--progress can't be used with --incremental or porcelain formats"
+msgstr "--progress no puede ser usado con --incremental o formatos porcelana"
 
-#: builtin/describe.c:534
-msgid "only consider tags matching <pattern>"
-msgstr "solo considerar tags que concuerden con <patrón>"
+#. TRANSLATORS: This string is used to tell us the
+#. maximum display width for a relative timestamp in
+#. "git blame" output.  For C locale, "4 years, 11
+#. months ago", which takes 22 places, is the longest
+#. among various forms of relative timestamps, but
+#. your language may need more or fewer display
+#. columns.
+#.
+#: builtin/blame.c:972
+msgid "4 years, 11 months ago"
+msgstr "hace 4 años, 11 meses"
 
-#: builtin/describe.c:536
-msgid "do not consider tags matching <pattern>"
-msgstr "no considerar tags que concuerden con <patrón>"
+#: builtin/blame.c:1079
+#, c-format
+msgid "file %s has only %lu line"
+msgid_plural "file %s has only %lu lines"
+msgstr[0] "archivo %s tiene solo %lu línea"
+msgstr[1] "archivo %s tiene solo %lu líneas"
 
-#: builtin/describe.c:538 builtin/name-rev.c:406
-msgid "show abbreviated commit object as fallback"
-msgstr "mostrar el objeto commit abreviado como fallback"
+#: builtin/blame.c:1125
+msgid "Blaming lines"
+msgstr "Blaming a líneas"
 
-#: builtin/describe.c:539 builtin/describe.c:542
-msgid "mark"
-msgstr "marca"
+#: builtin/branch.c:29
+msgid "git branch [<options>] [-r | -a] [--merged | --no-merged]"
+msgstr "git branch [<opciones>] [-r | -a] [--merged | --no-merged]"
 
-#: builtin/describe.c:540
-msgid "append <mark> on dirty working tree (default: \"-dirty\")"
-msgstr "adjuntar <marca> en el árbol de trabajo sucio (default: \"-dirty\")"
+#: builtin/branch.c:30
+msgid "git branch [<options>] [-l] [-f] <branch-name> [<start-point>]"
+msgstr "git branch [<opciones>] [-l] [-f] <nombre-de-rama> [<punto-inicial>]"
 
-#: builtin/describe.c:543
-msgid "append <mark> on broken working tree (default: \"-broken\")"
-msgstr "adjuntar <marca> en un árbol de trabajo roto (default: \"-broken\")"
+#: builtin/branch.c:31
+msgid "git branch [<options>] [-r] (-d | -D) <branch-name>..."
+msgstr "git branch [<opciones>] [-r] (-d | -D) <nombre-de-rama>..."
 
-#: builtin/describe.c:561
-msgid "--long is incompatible with --abbrev=0"
-msgstr "--long es incompatible con --abbrev=0"
+#: builtin/branch.c:32
+msgid "git branch [<options>] (-m | -M) [<old-branch>] <new-branch>"
+msgstr "git branch [<opciones>] (-m | -M) [<rama-vieja>] <rama-nueva>"
 
-#: builtin/describe.c:590
-msgid "No names found, cannot describe anything."
-msgstr "No se encontraron nombres, no se puede describir nada."
+#: builtin/branch.c:33
+msgid "git branch [<options>] (-c | -C) [<old-branch>] <new-branch>"
+msgstr "git branch [<opciones>] (-c | -C) [<rama-vieja>] <rama-nueva>"
 
-#: builtin/describe.c:640
-msgid "--dirty is incompatible with commit-ishes"
-msgstr "--dirty es incompatible con commit-ismos"
+#: builtin/branch.c:34
+msgid "git branch [<options>] [-r | -a] [--points-at]"
+msgstr "git branch [<opciones>] [-r | -a] [--points-at]"
 
-#: builtin/describe.c:642
-msgid "--broken is incompatible with commit-ishes"
-msgstr "--broken es incompatible con commit-ismos"
+#: builtin/branch.c:35
+msgid "git branch [<options>] [-r | -a] [--format]"
+msgstr "git branch [<opciones>] [-r | -a] [--formato]"
 
-#: builtin/diff.c:83
+#: builtin/branch.c:154
 #, c-format
-msgid "'%s': not a regular file or symlink"
-msgstr "'%s': no es un archivo regular o un enlace simbólico"
+msgid ""
+"deleting branch '%s' that has been merged to\n"
+"         '%s', but not yet merged to HEAD."
+msgstr ""
+"borrando la rama '%s' que ha sido fusionada en\n"
+"         '%s', pero aún no ha sido fusionada a HEAD."
 
-#: builtin/diff.c:234
+#: builtin/branch.c:158
 #, c-format
-msgid "invalid option: %s"
-msgstr "opción inválida: %s"
+msgid ""
+"not deleting branch '%s' that is not yet merged to\n"
+"         '%s', even though it is merged to HEAD."
+msgstr ""
+"no borrando rama '%s' que todavía no ha sido fusionada \n"
+"\ta '%s', aunque se fusione con HEAD."
 
-#: builtin/diff.c:356
-msgid "Not a git repository"
-msgstr "No es un repositorio git"
+#: builtin/branch.c:172
+#, c-format
+msgid "Couldn't look up commit object for '%s'"
+msgstr "No se pudo encontrar el objeto commit para '%s'"
 
-#: builtin/diff.c:399
+#: builtin/branch.c:176
 #, c-format
-msgid "invalid object '%s' given."
-msgstr "objeto '%s' entregado no es válido."
+msgid ""
+"The branch '%s' is not fully merged.\n"
+"If you are sure you want to delete it, run 'git branch -D %s'."
+msgstr ""
+"La rama '%s' no ha sido fusionada completamente.\n"
+"Si estás seguro de querer borrarla, ejecuta 'git branch -D %s'."
 
-#: builtin/diff.c:408
+#: builtin/branch.c:189
+msgid "Update of config-file failed"
+msgstr "Falló de actualización de config-file"
+
+#: builtin/branch.c:220
+msgid "cannot use -a with -d"
+msgstr "no se puede usar-a con -d"
+
+#: builtin/branch.c:226
+msgid "Couldn't look up commit object for HEAD"
+msgstr "No se pudo revisar el objeto commit para HEAD"
+
+#: builtin/branch.c:240
 #, c-format
-msgid "more than two blobs given: '%s'"
-msgstr "más de dos blobs entregados: '%s'"
+msgid "Cannot delete branch '%s' checked out at '%s'"
+msgstr "No se puede borrar rama '%s' que cuenta con checkout en '%s'"
 
-#: builtin/diff.c:413
+#: builtin/branch.c:255
 #, c-format
-msgid "unhandled object '%s' given."
-msgstr "objeto no manejado '%s' entregado."
+msgid "remote-tracking branch '%s' not found."
+msgstr "rama de rastreo remoto '%s' no encontrada."
 
-#: builtin/difftool.c:29
-msgid "git difftool [<options>] [<commit> [<commit>]] [--] [<path>...]"
-msgstr "git difftool [<opciones>] [<commit> [<commit>]] [--] [<ruta>...]"
+#: builtin/branch.c:256
+#, c-format
+msgid "branch '%s' not found."
+msgstr "rama '%s' no encontrada."
 
-#: builtin/difftool.c:259
+#: builtin/branch.c:271
 #, c-format
-msgid "failed: %d"
-msgstr "falló: %d"
+msgid "Error deleting remote-tracking branch '%s'"
+msgstr "Error al eliminar la rama de rastreo remota '%s'"
 
-#: builtin/difftool.c:301
+#: builtin/branch.c:272
 #, c-format
-msgid "could not read symlink %s"
-msgstr "no se pudo leer el symlink %s"
+msgid "Error deleting branch '%s'"
+msgstr "Error al eliminar la rama '%s'"
 
-#: builtin/difftool.c:303
+#: builtin/branch.c:279
 #, c-format
-msgid "could not read symlink file %s"
-msgstr "no se pudo leer el archivo symlink %s"
+msgid "Deleted remote-tracking branch %s (was %s).\n"
+msgstr "Eliminada la rama de rastreo remota %s (era %s).\n"
 
-#: builtin/difftool.c:311
+#: builtin/branch.c:280
 #, c-format
-msgid "could not read object %s for symlink %s"
-msgstr "no se pudo leer el objeto %s para el symlink %s"
+msgid "Deleted branch %s (was %s).\n"
+msgstr "Eliminada la rama %s (era %s)..\n"
 
-#: builtin/difftool.c:412
-msgid ""
-"combined diff formats('-c' and '--cc') are not supported in\n"
-"directory diff mode('-d' and '--dir-diff')."
-msgstr ""
-"formatos combinados de diff ('-c' y '--cc') no soportados en\n"
-"modo diff para directorio('-d' y '--dir-diff')."
+#: builtin/branch.c:429 builtin/tag.c:61
+msgid "unable to parse format string"
+msgstr "no es posible analizar el string de formato"
+
+#: builtin/branch.c:460
+msgid "could not resolve HEAD"
+msgstr "no se pudo resolver HEAD"
 
-#: builtin/difftool.c:632
+#: builtin/branch.c:466
 #, c-format
-msgid "both files modified: '%s' and '%s'."
-msgstr "ambos archivos modificados: '%s' y '%s'."
+msgid "HEAD (%s) points outside of refs/heads/"
+msgstr "HEAD (%s) apunta fuera de refs/heads/"
 
-#: builtin/difftool.c:634
-msgid "working tree file has been left."
-msgstr "archivo del árbol de trabajo ha sido dejado."
+#: builtin/branch.c:481
+#, c-format
+msgid "Branch %s is being rebased at %s"
+msgstr "Rama %s está siendo rebasada en %s"
 
-#: builtin/difftool.c:645
+#: builtin/branch.c:485
 #, c-format
-msgid "temporary files exist in '%s'."
-msgstr "archivo temporal existe en '%s'."
+msgid "Branch %s is being bisected at %s"
+msgstr "Rama %s está siendo bisecada en %s"
 
-#: builtin/difftool.c:646
-msgid "you may want to cleanup or recover these."
-msgstr "tal vez desee limpiar o recuperar estos."
+#: builtin/branch.c:502
+msgid "cannot copy the current branch while not on any."
+msgstr "no se puede copiar la rama actual mientras no se está en ninguna."
 
-#: builtin/difftool.c:695
-msgid "use `diff.guitool` instead of `diff.tool`"
-msgstr "use `diff.guitool` en lugar de `diff.tool`"
+#: builtin/branch.c:504
+msgid "cannot rename the current branch while not on any."
+msgstr "no se puede renombrar la rama actual mientras no se está en ninguna."
 
-#: builtin/difftool.c:697
-msgid "perform a full-directory diff"
-msgstr "realizar un diff de todo el directorio"
+#: builtin/branch.c:515
+#, c-format
+msgid "Invalid branch name: '%s'"
+msgstr "Nombre de rama inválido: '%s'"
 
-#: builtin/difftool.c:699
-msgid "do not prompt before launching a diff tool"
-msgstr "no mostrar antes de lanzar una herramienta de diff"
+#: builtin/branch.c:542
+msgid "Branch rename failed"
+msgstr "Cambio de nombre de rama fallido"
 
-#: builtin/difftool.c:704
-msgid "use symlinks in dir-diff mode"
-msgstr "usar enlaces simbólicos en modo dir-diff"
+#: builtin/branch.c:544
+msgid "Branch copy failed"
+msgstr "Copiado de rama fallido"
+
+#: builtin/branch.c:548
+#, c-format
+msgid "Created a copy of a misnamed branch '%s'"
+msgstr "Copia creada de la rama malnombrada '%s'"
 
-#: builtin/difftool.c:705
-msgid "<tool>"
-msgstr "<herramienta>"
+#: builtin/branch.c:551
+#, c-format
+msgid "Renamed a misnamed branch '%s' away"
+msgstr "Rama mal llamada '%s' renombrada"
 
-#: builtin/difftool.c:706
-msgid "use the specified diff tool"
-msgstr "usar la herramienta de diff especificada"
+#: builtin/branch.c:557
+#, c-format
+msgid "Branch renamed to %s, but HEAD is not updated!"
+msgstr "¡Rama renombrada a %s, pero HEAD no está actualizado!"
 
-#: builtin/difftool.c:708
-msgid "print a list of diff tools that may be used with `--tool`"
+#: builtin/branch.c:566
+msgid "Branch is renamed, but update of config-file failed"
 msgstr ""
-"mostrar una lista de herramientas de diff que pueden ser usadas con `--tool`"
+"La rama está renombrada, pero falló la actualización del archivo de "
+"configuración"
 
-#: builtin/difftool.c:711
+#: builtin/branch.c:568
+msgid "Branch is copied, but update of config-file failed"
+msgstr ""
+"La rama está copiada, pero falló la actualización del archivo de "
+"configuración"
+
+#: builtin/branch.c:584
+#, c-format
 msgid ""
-"make 'git-difftool' exit when an invoked diff tool returns a non - zero exit "
-"code"
+"Please edit the description for the branch\n"
+"  %s\n"
+"Lines starting with '%c' will be stripped.\n"
 msgstr ""
-"hacer que 'git-difftool' salga cuando una herramienta de diff retorne un "
-"código de salida distinto de cero"
+"Por favor, edita la descripción para la rama\n"
+"%s\n"
+"Las líneas que comiencen con '%c' serán eliminadas.\n"
 
-#: builtin/difftool.c:713
-msgid "<command>"
-msgstr "<comando>"
+#: builtin/branch.c:618
+msgid "Generic options"
+msgstr "Opciones genéricas"
 
-#: builtin/difftool.c:714
-msgid "specify a custom command for viewing diffs"
-msgstr "especificar un comando personalizado para ver diffs"
+#: builtin/branch.c:620
+msgid "show hash and subject, give twice for upstream branch"
+msgstr "mostrar hash y tema, dar dos veces para rama upstream"
 
-#: builtin/difftool.c:738
-msgid "no <tool> given for --tool=<tool>"
-msgstr "no se ha proporcionado <herramienta> para --tool=<herramienta>"
+#: builtin/branch.c:621
+msgid "suppress informational messages"
+msgstr "suprimir mensajes informativos"
 
-#: builtin/difftool.c:745
-msgid "no <cmd> given for --extcmd=<cmd>"
-msgstr "no se ha entregado <comando> para --extcmd=<comando>"
+#: builtin/branch.c:622
+msgid "set up tracking mode (see git-pull(1))"
+msgstr "configurando modo tracking (mirar git-pull(1))"
 
-#: builtin/fast-export.c:27
-msgid "git fast-export [rev-list-opts]"
-msgstr "git fast-export [rev-list-opts]"
+#: builtin/branch.c:624
+msgid "do not use"
+msgstr "no usar"
 
-#: builtin/fast-export.c:1000
-msgid "show progress after <n> objects"
-msgstr "mostrar progreso después de <n> objetos"
+#: builtin/branch.c:626 builtin/rebase.c:505
+msgid "upstream"
+msgstr "upstream"
 
-#: builtin/fast-export.c:1002
-msgid "select handling of signed tags"
-msgstr "seleccionar el manejo de tags firmados"
+#: builtin/branch.c:626
+msgid "change the upstream info"
+msgstr "cambiar info de upstream"
 
-#: builtin/fast-export.c:1005
-msgid "select handling of tags that tag filtered objects"
-msgstr "seleccionar el manejo de tags que son tags de objetos filtrados"
+#: builtin/branch.c:627
+msgid "unset the upstream info"
+msgstr "desconfigurando la info de upstream"
 
-#: builtin/fast-export.c:1008
-msgid "Dump marks to this file"
-msgstr "Volcar marcas a este archivo"
+#: builtin/branch.c:628
+msgid "use colored output"
+msgstr "usar salida con colores"
 
-#: builtin/fast-export.c:1010
-msgid "Import marks from this file"
-msgstr "Importar marcas de este archivo"
+#: builtin/branch.c:629
+msgid "act on remote-tracking branches"
+msgstr "actuar en ramas de traqueo remoto"
 
-#: builtin/fast-export.c:1012
-msgid "Fake a tagger when tags lack one"
-msgstr "Falsificar un tagger cuando les falta uno"
+#: builtin/branch.c:631 builtin/branch.c:633
+msgid "print only branches that contain the commit"
+msgstr "mostrar solo ramas que contienen el commit"
 
-#: builtin/fast-export.c:1014
-msgid "Output full tree for each commit"
-msgstr "Mostrar todo el árbol para cada commit"
+#: builtin/branch.c:632 builtin/branch.c:634
+msgid "print only branches that don't contain the commit"
+msgstr "mostrar solo ramas que no contienen el commit"
 
-#: builtin/fast-export.c:1016
-msgid "Use the done feature to terminate the stream"
-msgstr "Use el feature done para terminar el stream"
+#: builtin/branch.c:637
+msgid "Specific git-branch actions:"
+msgstr "Acciones específicas de git-branch:"
 
-#: builtin/fast-export.c:1017
-msgid "Skip output of blob data"
-msgstr "Saltar el output de data blob"
+#: builtin/branch.c:638
+msgid "list both remote-tracking and local branches"
+msgstr "listar ramas de remote-tracking y locales"
 
-#: builtin/fast-export.c:1018
-msgid "refspec"
-msgstr "refspec"
+#: builtin/branch.c:640
+msgid "delete fully merged branch"
+msgstr "borrar ramas totalmente fusionadas"
 
-#: builtin/fast-export.c:1019
-msgid "Apply refspec to exported refs"
-msgstr "Aplicar refspec para los refs exportados"
+#: builtin/branch.c:641
+msgid "delete branch (even if not merged)"
+msgstr "borrar rama (incluso si no está fusionada)"
 
-#: builtin/fast-export.c:1020
-msgid "anonymize output"
-msgstr "anonimizar la salida"
+#: builtin/branch.c:642
+msgid "move/rename a branch and its reflog"
+msgstr "mover/renombrar una rama y su reflog"
 
-#: builtin/fetch.c:26
-msgid "git fetch [<options>] [<repository> [<refspec>...]]"
-msgstr "git fetch [<opciones>] [<repositorio> [<refspec>...]]"
+#: builtin/branch.c:643
+msgid "move/rename a branch, even if target exists"
+msgstr "mover/renombrar una rama, incluso si el destino existe"
 
-#: builtin/fetch.c:27
-msgid "git fetch [<options>] <group>"
-msgstr "git fetch [<opciones>] <grupo>"
+#: builtin/branch.c:644
+msgid "copy a branch and its reflog"
+msgstr "copiar una rama y su reflog"
 
-#: builtin/fetch.c:28
-msgid "git fetch --multiple [<options>] [(<repository> | <group>)...]"
-msgstr "git fetch --multiple [<opciones>] [(<repositorio> | <grupo>)...]"
+#: builtin/branch.c:645
+msgid "copy a branch, even if target exists"
+msgstr "copiar una rama, incluso si el objetivo existe"
 
-#: builtin/fetch.c:29
-msgid "git fetch --all [<options>]"
-msgstr "git fetch --all [<opciones>]"
+#: builtin/branch.c:646
+msgid "list branch names"
+msgstr "listar nombres de ramas"
 
-#: builtin/fetch.c:123 builtin/pull.c:193
-msgid "fetch from all remotes"
-msgstr "extraer de todos los remotos"
+#: builtin/branch.c:647
+msgid "show current branch name"
+msgstr "muestra el nombre de branch actual"
 
-#: builtin/fetch.c:125 builtin/pull.c:196
-msgid "append to .git/FETCH_HEAD instead of overwriting"
-msgstr "adjuntar a .git/FETCH_HEAD en lugar de sobrescribir"
+#: builtin/branch.c:648
+msgid "create the branch's reflog"
+msgstr "crea el reflog de la rama"
 
-#: builtin/fetch.c:127 builtin/pull.c:199
-msgid "path to upload pack on remote end"
-msgstr "ruta para cargar el paquete al final del remoto"
+#: builtin/branch.c:650
+msgid "edit the description for the branch"
+msgstr "edita la descripción de la rama"
 
-#: builtin/fetch.c:128 builtin/pull.c:201
-msgid "force overwrite of local branch"
-msgstr "forzar sobrescritura de la rama local"
+#: builtin/branch.c:651
+msgid "force creation, move/rename, deletion"
+msgstr "fuerza la creación,movimiento/renombrado,borrado"
 
-#: builtin/fetch.c:130
-msgid "fetch from multiple remotes"
-msgstr "extraer de múltiples remotos"
+#: builtin/branch.c:652
+msgid "print only branches that are merged"
+msgstr "muestra solo ramas que han sido fusionadas"
 
-#: builtin/fetch.c:132 builtin/pull.c:203
-msgid "fetch all tags and associated objects"
-msgstr "extraer todos los tags y objetos asociados"
+#: builtin/branch.c:653
+msgid "print only branches that are not merged"
+msgstr "muestra solo ramas que no han sido fusionadas"
 
-#: builtin/fetch.c:134
-msgid "do not fetch all tags (--no-tags)"
-msgstr "no extraer todos los tags (--no-tags)"
+#: builtin/branch.c:654
+msgid "list branches in columns"
+msgstr "muestra las ramas en columnas"
 
-#: builtin/fetch.c:136
-msgid "number of submodules fetched in parallel"
-msgstr "número de submódulos extraídos en paralelo"
+#: builtin/branch.c:657 builtin/for-each-ref.c:42 builtin/notes.c:415
+#: builtin/notes.c:418 builtin/notes.c:581 builtin/notes.c:584
+#: builtin/tag.c:433
+msgid "object"
+msgstr "objeto"
 
-#: builtin/fetch.c:138 builtin/pull.c:206
-msgid "prune remote-tracking branches no longer on remote"
-msgstr "limpiar ramas remotas rastreadas que ya no están en el remoto"
+#: builtin/branch.c:658
+msgid "print only branches of the object"
+msgstr "imprimir sólo las ramas del objeto"
 
-#: builtin/fetch.c:140
-msgid "prune local tags no longer on remote and clobber changed tags"
-msgstr ""
-"limpiar tags locales que no se encuentran en el remoto y eliminar tags "
-"cambiados"
+#: builtin/branch.c:660 builtin/for-each-ref.c:48 builtin/tag.c:440
+msgid "sorting and filtering are case insensitive"
+msgstr "ordenamiento y filtrado son case-insensitive"
 
-#: builtin/fetch.c:141 builtin/fetch.c:164 builtin/pull.c:131
-msgid "on-demand"
-msgstr "en demanda"
+#: builtin/branch.c:661 builtin/for-each-ref.c:38 builtin/tag.c:438
+#: builtin/verify-tag.c:38
+msgid "format to use for the output"
+msgstr "formato para usar para el output"
 
-#: builtin/fetch.c:142
-msgid "control recursive fetching of submodules"
-msgstr "controlar extracción recursiva de submódulos"
+#: builtin/branch.c:684 builtin/clone.c:784
+msgid "HEAD not found below refs/heads!"
+msgstr "¡HEAD no encontrado abajo de refs/heads!"
 
-#: builtin/fetch.c:146 builtin/pull.c:214
-msgid "keep downloaded pack"
-msgstr "mantener el paquete descargado"
+#: builtin/branch.c:708
+msgid "--column and --verbose are incompatible"
+msgstr "--column y --verbose son incompatibles"
 
-#: builtin/fetch.c:148
-msgid "allow updating of HEAD ref"
-msgstr "permitir actualizar la ref HEAD"
+#: builtin/branch.c:723 builtin/branch.c:777 builtin/branch.c:786
+msgid "branch name required"
+msgstr "se necesita el nombre de la rama"
 
-#: builtin/fetch.c:151 builtin/fetch.c:157 builtin/pull.c:217
-msgid "deepen history of shallow clone"
-msgstr "historia profunda de un clon superficial"
+#: builtin/branch.c:753
+msgid "Cannot give description to detached HEAD"
+msgstr "No se puede dar descripción al HEAD desacoplado"
 
-#: builtin/fetch.c:153
-msgid "deepen history of shallow repository based on time"
-msgstr "historia profunda de un repositorio superficial basado en tiempo"
+#: builtin/branch.c:758
+msgid "cannot edit description of more than one branch"
+msgstr "no se puede editar la descripción de más de una rama"
 
-#: builtin/fetch.c:159 builtin/pull.c:220
-msgid "convert to a complete repository"
-msgstr "convertir a un repositorio completo"
+#: builtin/branch.c:765
+#, c-format
+msgid "No commit on branch '%s' yet."
+msgstr "Aún no hay commits en la rama '%s'."
 
-#: builtin/fetch.c:162
-msgid "prepend this to submodule path output"
-msgstr "anteponer esto a salida de la ruta del submódulo"
+#: builtin/branch.c:768
+#, c-format
+msgid "No branch named '%s'."
+msgstr "No hay ninguna rama llamada '%s'."
 
-#: builtin/fetch.c:165
-msgid ""
-"default for recursive fetching of submodules (lower priority than config "
-"files)"
-msgstr ""
-"default para extracción recursiva de submódulos (menor prioridad que "
-"archivos de configuración)"
+#: builtin/branch.c:783
+msgid "too many branches for a copy operation"
+msgstr "demasiadas ramas para una operación de copiado"
 
-#: builtin/fetch.c:169 builtin/pull.c:223
-msgid "accept refs that update .git/shallow"
-msgstr "aceptar refs que actualicen .git/shallow"
+#: builtin/branch.c:792
+msgid "too many arguments for a rename operation"
+msgstr "demasiados argumentos para una operación de renombrado"
 
-#: builtin/fetch.c:170 builtin/pull.c:225
-msgid "refmap"
-msgstr "refmap"
+#: builtin/branch.c:797
+msgid "too many arguments to set new upstream"
+msgstr "demasiados argumentos para configurar un nuevo upstream"
 
-#: builtin/fetch.c:171 builtin/pull.c:226
-msgid "specify fetch refmap"
-msgstr "especificar extracción de refmap"
+#: builtin/branch.c:801
+#, c-format
+msgid ""
+"could not set upstream of HEAD to %s when it does not point to any branch."
+msgstr ""
+"no se pudo configurar upstream de HEAD a %s cuando este no apunta a ninguna "
+"rama."
 
-#: builtin/fetch.c:172 builtin/ls-remote.c:77 builtin/push.c:582
-#: builtin/send-pack.c:172
-msgid "server-specific"
-msgstr "especifico-de-servidor"
+#: builtin/branch.c:804 builtin/branch.c:827
+#, c-format
+msgid "no such branch '%s'"
+msgstr "no hay tal rama '%s'"
 
-#: builtin/fetch.c:172 builtin/ls-remote.c:77 builtin/push.c:582
-#: builtin/send-pack.c:173
-msgid "option to transmit"
-msgstr "opción para trasmitir"
+#: builtin/branch.c:808
+#, c-format
+msgid "branch '%s' does not exist"
+msgstr "la rama '%s' no existe"
 
-#: builtin/fetch.c:442
-msgid "Couldn't find remote ref HEAD"
-msgstr "No se puedo encontrar ref remota HEAD"
+#: builtin/branch.c:821
+msgid "too many arguments to unset upstream"
+msgstr "demasiados argumentos para desconfigurar upstream"
 
-#: builtin/fetch.c:560
-#, c-format
-msgid "configuration fetch.output contains invalid value %s"
-msgstr "la configuración fetch.output contiene el valor inválido %s"
+#: builtin/branch.c:825
+msgid "could not unset upstream of HEAD when it does not point to any branch."
+msgstr ""
+"no se puede desconfigurar upstream de HEAD cuando este no apunta a ninguna "
+"rama."
 
-#: builtin/fetch.c:653
+#: builtin/branch.c:831
 #, c-format
-msgid "object %s not found"
-msgstr "objeto %s no encontrado"
-
-#: builtin/fetch.c:657
-msgid "[up to date]"
-msgstr "[actualizado]"
+msgid "Branch '%s' has no upstream information"
+msgstr "Rama '%s' no tiene información de upstream"
 
-#: builtin/fetch.c:670 builtin/fetch.c:750
-msgid "[rejected]"
-msgstr "[rechazado]"
+#: builtin/branch.c:841
+msgid ""
+"The -a, and -r, options to 'git branch' do not take a branch name.\n"
+"Did you mean to use: -a|-r --list <pattern>?"
+msgstr ""
+"Las opciones -a, y -r, de 'git branch' no toman un nombre de rama.\n"
+"¿Quisiste usar: -a|-r --list <patrón>?"
 
-#: builtin/fetch.c:671
-msgid "can't fetch in current branch"
-msgstr "no se puede traer en la rama actual"
+#: builtin/branch.c:845
+msgid ""
+"the '--set-upstream' option is no longer supported. Please use '--track' or "
+"'--set-upstream-to' instead."
+msgstr ""
+"la opción '--set-upstream' ya no es soportada. Considere usar '--track' o '--"
+"set-upstream-to' en cambio."
 
-#: builtin/fetch.c:680
-msgid "[tag update]"
-msgstr "[actualización de tag]"
+#: builtin/bundle.c:15 builtin/bundle.c:23
+msgid "git bundle create [<options>] <file> <git-rev-list args>"
+msgstr "git bundle create [<opciones>] <file> <git-rev-list args>"
+
+#: builtin/bundle.c:16 builtin/bundle.c:28
+msgid "git bundle verify [<options>] <file>"
+msgstr "git bundle verify [<opciones>] <archivo>"
+
+#: builtin/bundle.c:17 builtin/bundle.c:33
+msgid "git bundle list-heads <file> [<refname>...]"
+msgstr "git bundle list-heads <archivo> [<nombre-de-ref>...]"
+
+#: builtin/bundle.c:18 builtin/bundle.c:38
+msgid "git bundle unbundle <file> [<refname>...]"
+msgstr "git bundle unbundle <archivo> [<nombre-de-ref>...]"
 
-#: builtin/fetch.c:681 builtin/fetch.c:714 builtin/fetch.c:730
-#: builtin/fetch.c:745
-msgid "unable to update local ref"
-msgstr "no se posible actualizar el ref local"
+#: builtin/bundle.c:66 builtin/pack-objects.c:3228
+msgid "do not show progress meter"
+msgstr "no mostrar medidor de progreso"
 
-#: builtin/fetch.c:700
-msgid "[new tag]"
-msgstr "[nuevo tag]"
+#: builtin/bundle.c:68 builtin/pack-objects.c:3230
+msgid "show progress meter"
+msgstr "mostrar medidor de progreso"
 
-#: builtin/fetch.c:703
-msgid "[new branch]"
-msgstr "[nueva rama]"
+#: builtin/bundle.c:70 builtin/pack-objects.c:3232
+msgid "show progress meter during object writing phase"
+msgstr "mostrar medidor de progreso durante la fase de escritura de objeto"
 
-#: builtin/fetch.c:706
-msgid "[new ref]"
-msgstr "[nueva referencia]"
+#: builtin/bundle.c:73 builtin/pack-objects.c:3235
+msgid "similar to --all-progress when progress meter is shown"
+msgstr "similar a --all-progress cuando medidor de progreso es mostrado"
 
-#: builtin/fetch.c:745
-msgid "forced update"
-msgstr "actualización forzada"
+#: builtin/bundle.c:93
+msgid "Need a repository to create a bundle."
+msgstr "Se necesita un repositorio para agrupar."
 
-#: builtin/fetch.c:750
-msgid "non-fast-forward"
-msgstr "avance lento"
+#: builtin/bundle.c:104
+msgid "do not show bundle details"
+msgstr "no mostrar detalles del bundle"
 
-#: builtin/fetch.c:795
+#: builtin/bundle.c:119
 #, c-format
-msgid "%s did not send all necessary objects\n"
-msgstr "%s no envió todos los objetos necesarios\n"
+msgid "%s is okay\n"
+msgstr "%s está bien\n"
 
-#: builtin/fetch.c:815
-#, c-format
-msgid "reject %s because shallow roots are not allowed to be updated"
-msgstr "rechazado %s porque raíces superficiales no pueden ser actualizadas"
+#: builtin/bundle.c:160
+msgid "Need a repository to unbundle."
+msgstr "Se necesita un repositorio para desagrupar."
 
-#: builtin/fetch.c:903 builtin/fetch.c:999
-#, c-format
-msgid "From %.*s\n"
-msgstr "Desde %.*s\n"
+#: builtin/bundle.c:168 builtin/remote.c:1609
+msgid "be verbose; must be placed before a subcommand"
+msgstr "ser verboso; tiene que ser agregado antes de un subcomando"
 
-#: builtin/fetch.c:914
+#: builtin/bundle.c:190 builtin/remote.c:1640
 #, c-format
+msgid "Unknown subcommand: %s"
+msgstr "Sub-comando desconocido: %s"
+
+#: builtin/cat-file.c:595
 msgid ""
-"some local refs could not be updated; try running\n"
-" 'git remote prune %s' to remove any old, conflicting branches"
+"git cat-file (-t [--allow-unknown-type] | -s [--allow-unknown-type] | -e | -"
+"p | <type> | --textconv | --filters) [--path=<path>] <object>"
 msgstr ""
-"algunos refs locales no pudieron ser actualizados; intente ejecutar\n"
-" 'git remote prune %s' para remover cualquier rama vieja o conflictiva"
+"git cat-file (-t [--allow-unknown-type] | -s [--allow-unknown-type] | -e | -"
+"p | <tipo> | --textconv | --filters) [--path=<ruta>] <objeto>"
 
-#: builtin/fetch.c:969
-#, c-format
-msgid "   (%s will become dangling)"
-msgstr "   (%s se pondrá colgado)"
+#: builtin/cat-file.c:596
+msgid ""
+"git cat-file (--batch | --batch-check) [--follow-symlinks] [--textconv | --"
+"filters]"
+msgstr ""
+"git cat-file (--batch | --batch-check) [--follow-symlinks] [--textconv | --"
+"filters]"
 
-#: builtin/fetch.c:970
-#, c-format
-msgid "   (%s has become dangling)"
-msgstr "   (%s se ha colgado)"
+#: builtin/cat-file.c:617
+msgid "only one batch option may be specified"
+msgstr "solo se puede especificar una opción batch"
 
-#: builtin/fetch.c:1002
-msgid "[deleted]"
-msgstr "[eliminado]"
+#: builtin/cat-file.c:635
+msgid "<type> can be one of: blob, tree, commit, tag"
+msgstr "<tipo> puede ser: blob, tree, commit, tag"
 
-#: builtin/fetch.c:1003 builtin/remote.c:1033
-msgid "(none)"
-msgstr "(nada)"
+#: builtin/cat-file.c:636
+msgid "show object type"
+msgstr "mostrar el tipo del objeto"
 
-#: builtin/fetch.c:1026
-#, c-format
-msgid "Refusing to fetch into current branch %s of non-bare repository"
-msgstr "Rehusando extraer en la rama actual %s de un repositorio no vacío"
+#: builtin/cat-file.c:637
+msgid "show object size"
+msgstr "mostrar el tamaño del objeto"
 
-#: builtin/fetch.c:1045
-#, c-format
-msgid "Option \"%s\" value \"%s\" is not valid for %s"
-msgstr "Opción \"%s\" valor \"%s\" no es válido para %s"
+#: builtin/cat-file.c:639
+msgid "exit with zero when there's no error"
+msgstr "salir con cero cuando no haya error"
 
-#: builtin/fetch.c:1048
-#, c-format
-msgid "Option \"%s\" is ignored for %s\n"
-msgstr "Opción \"%s\" es ignorada por %s\n"
+#: builtin/cat-file.c:640
+msgid "pretty-print object's content"
+msgstr "realizar pretty-print del contenido del objeto"
 
-#: builtin/fetch.c:1287
-#, c-format
-msgid "Fetching %s\n"
-msgstr "Extrayendo %s\n"
+#: builtin/cat-file.c:642
+msgid "for blob objects, run textconv on object's content"
+msgstr "para objetos blob, ejecuta textconv en el contenido del objeto"
 
-#: builtin/fetch.c:1289 builtin/remote.c:98
-#, c-format
-msgid "Could not fetch %s"
-msgstr "No se pudo extraer %s"
+#: builtin/cat-file.c:644
+msgid "for blob objects, run filters on object's content"
+msgstr "para objetos blob, ejecuta filters en el contenido del objeto"
 
-#: builtin/fetch.c:1335 builtin/fetch.c:1503
-msgid ""
-"--filter can only be used with the remote configured in core.partialClone"
-msgstr ""
-"--filter solo puede ser usado con el remoto configurado en core.partialClone"
+#: builtin/cat-file.c:645 git-submodule.sh:992
+msgid "blob"
+msgstr "blob"
 
-#: builtin/fetch.c:1358
-msgid ""
-"No remote repository specified.  Please, specify either a URL or a\n"
-"remote name from which new revisions should be fetched."
-msgstr ""
-"No hay repositorio remoto especificado. Por favor, especifique un URL o un\n"
-"nombre remoto del cual las nuevas revisiones deben ser extraídas."
+#: builtin/cat-file.c:646
+msgid "use a specific path for --textconv/--filters"
+msgstr "use una ruta específica para --textconv/--filters"
 
-#: builtin/fetch.c:1395
-msgid "You need to specify a tag name."
-msgstr "Tiene que especificar un nombre de tag."
+#: builtin/cat-file.c:648
+msgid "allow -s and -t to work with broken/corrupt objects"
+msgstr "permita -s y -t para trabajar con objetos rotos o corruptos"
 
-#: builtin/fetch.c:1444
-msgid "Negative depth in --deepen is not supported"
-msgstr "Profundidad negativa en --deepen no soportada"
+#: builtin/cat-file.c:649
+msgid "buffer --batch output"
+msgstr "salida buffer --batch"
 
-#: builtin/fetch.c:1446
-msgid "--deepen and --depth are mutually exclusive"
-msgstr "--deepen y --depth son mutuamente exclusivas"
+#: builtin/cat-file.c:651
+msgid "show info and content of objects fed from the standard input"
+msgstr "mostrar info y content de los objetos alimentados por standard input"
 
-#: builtin/fetch.c:1451
-msgid "--depth and --unshallow cannot be used together"
-msgstr "--depth y --unshallow no pueden ser usadas juntas"
+#: builtin/cat-file.c:655
+msgid "show info about objects fed from the standard input"
+msgstr "mostrar info de los objetos alimentados por standard input"
 
-#: builtin/fetch.c:1453
-msgid "--unshallow on a complete repository does not make sense"
-msgstr "--unshallow no tiene sentido en un repositorio completo"
+#: builtin/cat-file.c:659
+msgid "follow in-tree symlinks (used with --batch or --batch-check)"
+msgstr ""
+"seguir los enlaces simbólicos en el árbol (usado con --batch o --batch-check)"
 
-#: builtin/fetch.c:1469
-msgid "fetch --all does not take a repository argument"
-msgstr "fetch --all no toma un argumento de repositorio"
+#: builtin/cat-file.c:661
+msgid "show all objects with --batch or --batch-check"
+msgstr "mostrar todos los objetos con --batch o --batch-check"
 
-#: builtin/fetch.c:1471
-msgid "fetch --all does not make sense with refspecs"
-msgstr "fetch --all no tiene sentido con refspecs"
+#: builtin/cat-file.c:663
+msgid "do not order --batch-all-objects output"
+msgstr "no ordenar el output de --batch-all-objects"
 
-#: builtin/fetch.c:1480
-#, c-format
-msgid "No such remote or remote group: %s"
-msgstr "No existe el remoto o grupo remoto: %s"
+#: builtin/check-attr.c:13
+msgid "git check-attr [-a | --all | <attr>...] [--] <pathname>..."
+msgstr "git check-attr [-a | --all | <attr>...] [--] <nombre-de-ruta>..."
 
-#: builtin/fetch.c:1487
-msgid "Fetching a group and specifying refspecs does not make sense"
-msgstr "Extraer un grupo y especificar un refspecs no tiene sentido"
+#: builtin/check-attr.c:14
+msgid "git check-attr --stdin [-z] [-a | --all | <attr>...]"
+msgstr "git check-attr --stdin [-z] [-a | --all | <attr>...]"
 
-#: builtin/fmt-merge-msg.c:15
-msgid ""
-"git fmt-merge-msg [-m <message>] [--log[=<n>] | --no-log] [--file <file>]"
-msgstr ""
-"git fmt-merge-msg [-m <mensaje>] [--log[=<n>] | --no-log] [--file <archivo>]"
-
-#: builtin/fmt-merge-msg.c:666
-msgid "populate log with at most <n> entries from shortlog"
-msgstr "poblar el log con máximo <n> entradas del shorlog"
-
-#: builtin/fmt-merge-msg.c:669
-msgid "alias for --log (deprecated)"
-msgstr "alias para --log (deprecado)"
+#: builtin/check-attr.c:21
+msgid "report all attributes set on file"
+msgstr "reportar todos los atributos configurados en el archivo"
 
-#: builtin/fmt-merge-msg.c:672
-msgid "text"
-msgstr "texto"
+#: builtin/check-attr.c:22
+msgid "use .gitattributes only from the index"
+msgstr "use .gitattributes solo desde el índice"
 
-#: builtin/fmt-merge-msg.c:673
-msgid "use <text> as start of message"
-msgstr "use <text> como comienzo de mensaje"
+#: builtin/check-attr.c:23 builtin/check-ignore.c:25 builtin/hash-object.c:102
+msgid "read file names from stdin"
+msgstr "leer nombres de archivos de stdin"
 
-#: builtin/fmt-merge-msg.c:674
-msgid "file to read from"
-msgstr "archivo del cual leer"
+#: builtin/check-attr.c:25 builtin/check-ignore.c:27
+msgid "terminate input and output records by a NUL character"
+msgstr "terminar registros de entrada y salida con un carácter NUL"
 
-#: builtin/for-each-ref.c:10
-msgid "git for-each-ref [<options>] [<pattern>]"
-msgstr "git for-each-ref [<opciones>] [<patrón>]"
+#: builtin/check-ignore.c:21 builtin/checkout.c:1435 builtin/gc.c:537
+#: builtin/worktree.c:506
+msgid "suppress progress reporting"
+msgstr "suprimir el reporte de progreso"
 
-#: builtin/for-each-ref.c:11
-msgid "git for-each-ref [--points-at <object>]"
-msgstr "git for-each-ref [--points-at <objeto>]"
+#: builtin/check-ignore.c:29
+msgid "show non-matching input paths"
+msgstr "mostrar rutas de entrada que no concuerdan"
 
-#: builtin/for-each-ref.c:12
-msgid "git for-each-ref [(--merged | --no-merged) [<commit>]]"
-msgstr "git for-each-ref [(--merged | --no-merged) [<commit>]]"
+#: builtin/check-ignore.c:31
+msgid "ignore index when checking"
+msgstr "ignorar el índice cuando se revise"
 
-#: builtin/for-each-ref.c:13
-msgid "git for-each-ref [--contains [<commit>]] [--no-contains [<commit>]]"
-msgstr "git for-each-ref [--contains [<commit>]] [--no-contains [<commit>]]"
+#: builtin/check-ignore.c:160
+msgid "cannot specify pathnames with --stdin"
+msgstr "no se puede especificar los nombres de rutas con --stdin"
 
-#: builtin/for-each-ref.c:28
-msgid "quote placeholders suitably for shells"
-msgstr "cite los marcadores de posición adecuadamente para los shells"
+#: builtin/check-ignore.c:163
+msgid "-z only makes sense with --stdin"
+msgstr "-z sólo tiene sentido con --stdin"
 
-#: builtin/for-each-ref.c:30
-msgid "quote placeholders suitably for perl"
-msgstr "cite los marcadores de posición adecuadamente para perl"
+#: builtin/check-ignore.c:165
+msgid "no path specified"
+msgstr "ruta no especificada"
 
-#: builtin/for-each-ref.c:32
-msgid "quote placeholders suitably for python"
-msgstr "cite los marcadores de posición adecuadamente para python"
+#: builtin/check-ignore.c:169
+msgid "--quiet is only valid with a single pathname"
+msgstr "--quiet solo es válido con un nombre de ruta único"
 
-#: builtin/for-each-ref.c:34
-msgid "quote placeholders suitably for Tcl"
-msgstr "cite los marcadores de posición adecuadamente para Tcl"
+#: builtin/check-ignore.c:171
+msgid "cannot have both --quiet and --verbose"
+msgstr "no se puede tener ambos --quiet y --verbose"
 
-#: builtin/for-each-ref.c:37
-msgid "show only <n> matched refs"
-msgstr "mostrar solo <n> refs encontradas"
+#: builtin/check-ignore.c:174
+msgid "--non-matching is only valid with --verbose"
+msgstr "--non-matching sólo es válida con --verbose"
 
-#: builtin/for-each-ref.c:39 builtin/tag.c:421
-msgid "respect format colors"
-msgstr "respetar el formato de colores"
+#: builtin/check-mailmap.c:9
+msgid "git check-mailmap [<options>] <contact>..."
+msgstr "git check-mailmap [<opciones>] <contacto>..."
 
-#: builtin/for-each-ref.c:43
-msgid "print only refs which points at the given object"
-msgstr "mostrar solo refs que apunten al objeto dado"
+#: builtin/check-mailmap.c:14
+msgid "also read contacts from stdin"
+msgstr "también leer contactos desde stdin"
 
-#: builtin/for-each-ref.c:45
-msgid "print only refs that are merged"
-msgstr "mostrar solo refs que son fusionadas"
+#: builtin/check-mailmap.c:25
+#, c-format
+msgid "unable to parse contact: %s"
+msgstr "no es posible analizar el contacto: %s"
 
-#: builtin/for-each-ref.c:46
-msgid "print only refs that are not merged"
-msgstr "mostrar solo refs que no son fusionadas"
+#: builtin/check-mailmap.c:48
+msgid "no contacts specified"
+msgstr "contactos no especificados"
 
-#: builtin/for-each-ref.c:47
-msgid "print only refs which contain the commit"
-msgstr "mostrar solo refs que contienen el commit"
+#: builtin/checkout-index.c:131
+msgid "git checkout-index [<options>] [--] [<file>...]"
+msgstr "git checkout-index [<opciones>] [--] [<archivo>...]"
 
-#: builtin/for-each-ref.c:48
-msgid "print only refs which don't contain the commit"
-msgstr "mostrar solo refs que no contienen el commit"
+#: builtin/checkout-index.c:148
+msgid "stage should be between 1 and 3 or all"
+msgstr "stage tiene que estar entre 1 y 3 o all"
 
-#: builtin/fsck.c:569
-msgid "Checking object directories"
-msgstr "Revisando objetos directorios"
+#: builtin/checkout-index.c:164
+msgid "check out all files in the index"
+msgstr "revisar todos los archivos en el índice"
 
-#: builtin/fsck.c:661
-msgid "git fsck [<options>] [<object>...]"
-msgstr "git fsck [<opciones>] [<objeto>...]"
+#: builtin/checkout-index.c:165
+msgid "force overwrite of existing files"
+msgstr "forzar sobreescritura de los archivos existentes"
 
-#: builtin/fsck.c:667
-msgid "show unreachable objects"
-msgstr "mostrar objetos ilegibles"
+#: builtin/checkout-index.c:167
+msgid "no warning for existing files and files not in index"
+msgstr ""
+"no hay advertencias para los archivos existentes y los archivos no están en "
+"el índice"
 
-#: builtin/fsck.c:668
-msgid "show dangling objects"
-msgstr "mostrar objetos colgados"
+#: builtin/checkout-index.c:169
+msgid "don't checkout new files"
+msgstr "no revisar archivos nuevos"
 
-#: builtin/fsck.c:669
-msgid "report tags"
-msgstr "reportar tags"
+#: builtin/checkout-index.c:171
+msgid "update stat information in the index file"
+msgstr "actualizar información de estado en el archivo índice"
 
-#: builtin/fsck.c:670
-msgid "report root nodes"
-msgstr "reportar nodos raíz"
+#: builtin/checkout-index.c:175
+msgid "read list of paths from the standard input"
+msgstr "leer lista de rutas desde standard input"
 
-#: builtin/fsck.c:671
-msgid "make index objects head nodes"
-msgstr "hacer objetos índices cabezas de nodos"
+#: builtin/checkout-index.c:177
+msgid "write the content to temporary files"
+msgstr "escribir el contenido en un archivo temporal"
 
-#: builtin/fsck.c:672
-msgid "make reflogs head nodes (default)"
-msgstr "hacer reflogs cabeza de nodos (default)"
+#: builtin/checkout-index.c:178 builtin/column.c:31
+#: builtin/submodule--helper.c:1385 builtin/submodule--helper.c:1388
+#: builtin/submodule--helper.c:1396 builtin/submodule--helper.c:1882
+#: builtin/worktree.c:679
+msgid "string"
+msgstr "string"
 
-#: builtin/fsck.c:673
-msgid "also consider packs and alternate objects"
-msgstr "también considerar paquetes y objetos alternos"
+#: builtin/checkout-index.c:179
+msgid "when creating files, prepend <string>"
+msgstr "cuando cree archivos, anteponer <string>"
 
-#: builtin/fsck.c:674
-msgid "check only connectivity"
-msgstr "revisar solo conectividad"
+#: builtin/checkout-index.c:181
+msgid "copy out the files from named stage"
+msgstr "copiar los archivos del stage nombrado"
 
-#: builtin/fsck.c:675
-msgid "enable more strict checking"
-msgstr "habilitar revisión más estricta"
+#: builtin/checkout.c:31
+msgid "git checkout [<options>] <branch>"
+msgstr "git checkout [<opciones>]  <rama>"
 
-#: builtin/fsck.c:677
-msgid "write dangling objects in .git/lost-found"
-msgstr "escribir objetos colgados en .git/lost-found"
+#: builtin/checkout.c:32
+msgid "git checkout [<options>] [<branch>] -- <file>..."
+msgstr "git checkout [<opciones>] [<rama>] -- <archivo>..."
 
-#: builtin/fsck.c:678 builtin/prune.c:109
-msgid "show progress"
-msgstr "mostrar progreso"
+#: builtin/checkout.c:37
+msgid "git switch [<options>] [<branch>]"
+msgstr "git switch [<opciones>] [<rama>]"
+
+#: builtin/checkout.c:42
+msgid "git restore [<options>] [--source=<branch>] <file>..."
+msgstr "git restore [<opciones>] [--source=<rama>] -- <archivo>..."
 
-#: builtin/fsck.c:679
-msgid "show verbose names for reachable objects"
-msgstr "mostrar nombres verboso para objetos alcanzables"
+#: builtin/checkout.c:175 builtin/checkout.c:214
+#, c-format
+msgid "path '%s' does not have our version"
+msgstr "ruta '%s' no tiene nuestra versión"
 
-#: builtin/fsck.c:745
-msgid "Checking objects"
-msgstr "Revisando objetos"
+#: builtin/checkout.c:177 builtin/checkout.c:216
+#, c-format
+msgid "path '%s' does not have their version"
+msgstr "ruta '%s' no tiene su versión"
 
-#: builtin/gc.c:33
-msgid "git gc [<options>]"
-msgstr "git gc [<opciones>]"
+#: builtin/checkout.c:193
+#, c-format
+msgid "path '%s' does not have all necessary versions"
+msgstr "ruta '%s' no tiene todas las versiones necesarias"
 
-#: builtin/gc.c:88
+#: builtin/checkout.c:243
 #, c-format
-msgid "Failed to fstat %s: %s"
-msgstr "Falló el fstat %s: %s"
+msgid "path '%s' does not have necessary versions"
+msgstr "ruta '%s' no tiene versiones necesarias"
 
-#: builtin/gc.c:452
+#: builtin/checkout.c:261
 #, c-format
-msgid "Can't stat %s"
-msgstr "No se puede definir %s"
+msgid "path '%s': cannot merge"
+msgstr "ruta '%s': no se puede fusionar"
 
-#: builtin/gc.c:461
+#: builtin/checkout.c:277
 #, c-format
-msgid ""
-"The last gc run reported the following. Please correct the root cause\n"
-"and remove %s.\n"
-"Automatic cleanup will not be performed until the file is removed.\n"
-"\n"
-"%s"
-msgstr ""
-"El último gc reportó lo siguiente. Por favor corrige la causa\n"
-"y remueva %s.\n"
-"Limpieza automática no se realizará hasta que el archivo sea removido.\n"
-"\n"
-"%s"
+msgid "Unable to add merge result for '%s'"
+msgstr "Incapaz de agregar resultados de fusión a '%s'"
 
-#: builtin/gc.c:502
-msgid "prune unreferenced objects"
-msgstr "limpiar objetos no referenciados"
+#: builtin/checkout.c:377
+#, c-format
+msgid "Recreated %d merge conflict"
+msgid_plural "Recreated %d merge conflicts"
+msgstr[0] "Recreado %d conflicto de merge"
+msgstr[1] "Recreados %d conflictos de merge"
 
-#: builtin/gc.c:504
-msgid "be more thorough (increased runtime)"
-msgstr "ser más exhaustivo (aumentar runtime)"
+#: builtin/checkout.c:382
+#, c-format
+msgid "Updated %d path from %s"
+msgid_plural "Updated %d paths from %s"
+msgstr[0] "Actualizada %d ruta para %s"
+msgstr[1] "Actualizadas %d rutas para %s"
 
-#: builtin/gc.c:505
-msgid "enable auto-gc mode"
-msgstr "habilitar modo auto-gc"
+#: builtin/checkout.c:389
+#, c-format
+msgid "Updated %d path from the index"
+msgid_plural "Updated %d paths from the index"
+msgstr[0] "Actualizada %d ruta desde el index"
+msgstr[1] "Actualizadas %d rutas desde el index"
 
-#: builtin/gc.c:508
-msgid "force running gc even if there may be another gc running"
-msgstr "forzar la ejecución de gc incluso si puede haber otro gc ejecutándose"
+#: builtin/checkout.c:412 builtin/checkout.c:415 builtin/checkout.c:418
+#: builtin/checkout.c:422
+#, c-format
+msgid "'%s' cannot be used with updating paths"
+msgstr "'%s' no puede ser usada con rutas actualizadas"
 
-#: builtin/gc.c:511
-msgid "repack all other packs except the largest pack"
-msgstr "reempaquetar todos los otros paquetes excepto el paquete más grande"
+#: builtin/checkout.c:425 builtin/checkout.c:428
+#, c-format
+msgid "'%s' cannot be used with %s"
+msgstr "'%s' no puede ser usado con %s"
 
-#: builtin/gc.c:528
+#: builtin/checkout.c:432
 #, c-format
-msgid "failed to parse gc.logexpiry value %s"
-msgstr "falló al analizar valor %s de gc.logexpirity"
+msgid "Cannot update paths and switch to branch '%s' at the same time."
+msgstr "No se puede actualizar rutas y cambiar a la rama '%s' al mismo tiempo."
 
-#: builtin/gc.c:539
+#: builtin/checkout.c:436
 #, c-format
-msgid "failed to parse prune expiry value %s"
-msgstr "falló al analizar valor %s de prune expiry"
+msgid "neither '%s' or '%s' is specified"
+msgstr "ni '%s' o '%s' están especificados"
 
-#: builtin/gc.c:559
+#: builtin/checkout.c:440
 #, c-format
-msgid "Auto packing the repository in background for optimum performance.\n"
-msgstr ""
-"Auto empaquetado del repositorio en segundo plano para un performance "
-"óptimo.\n"
+msgid "'%s' must be used when '%s' is not specified"
+msgstr "'%s' tiene que ser usado cuando '%s' no es especificado"
 
-#: builtin/gc.c:561
+#: builtin/checkout.c:445 builtin/checkout.c:450
 #, c-format
-msgid "Auto packing the repository for optimum performance.\n"
-msgstr "Auto empaquetado del repositorio para performance óptimo.\n"
+msgid "'%s' or '%s' cannot be used with %s"
+msgstr "'%s' o '%s' no puede ser usado con %s"
 
-#: builtin/gc.c:562
+#: builtin/checkout.c:509 builtin/checkout.c:516
 #, c-format
-msgid "See \"git help gc\" for manual housekeeping.\n"
-msgstr "Vea \"git help gc\" para limpieza manual.\n"
+msgid "path '%s' is unmerged"
+msgstr "ruta '%s' no esta fusionada"
 
-#: builtin/gc.c:598
+#: builtin/checkout.c:682 builtin/sparse-checkout.c:82
+msgid "you need to resolve your current index first"
+msgstr "necesitas resolver tu índice actual primero"
+
+#: builtin/checkout.c:732
 #, c-format
 msgid ""
-"gc is already running on machine '%s' pid %<PRIuMAX> (use --force if not)"
+"cannot continue with staged changes in the following files:\n"
+"%s"
 msgstr ""
-"gc ya está ejecutándose en la máquina '%s' pid %<PRIuMAX> (use --force so no "
-"es así)"
+"no se puede continuar con los cambios en stage en los siguientes archivos:\n"
+"%s"
 
-#: builtin/gc.c:645
-msgid ""
-"There are too many unreachable loose objects; run 'git prune' to remove them."
-msgstr ""
-"Hay muchos objetos sueltos inalcanzables; ejecute 'git prune' para "
-"removerlos."
+#: builtin/checkout.c:835
+#, c-format
+msgid "Can not do reflog for '%s': %s\n"
+msgstr "No se puede hacer reflog para '%s': %s\n"
 
-#: builtin/grep.c:28
-msgid "git grep [<options>] [-e] <pattern> [<rev>...] [[--] <path>...]"
-msgstr "git grep [<opciones>] [-e] <patrón> [<rev>...] [[--] <ruta>...]"
+#: builtin/checkout.c:877
+msgid "HEAD is now at"
+msgstr "HEAD está ahora en"
+
+#: builtin/checkout.c:881 builtin/clone.c:716
+msgid "unable to update HEAD"
+msgstr "no es posible actualizar  HEAD"
 
-#: builtin/grep.c:226
+#: builtin/checkout.c:885
 #, c-format
-msgid "grep: failed to create thread: %s"
-msgstr "grep: falló al crear el hilo: %s"
+msgid "Reset branch '%s'\n"
+msgstr "Reiniciar rama '%s'\n"
 
-#: builtin/grep.c:284
+#: builtin/checkout.c:888
 #, c-format
-msgid "invalid number of threads specified (%d) for %s"
-msgstr "número inválido de hilos especificado (%d) para %s"
+msgid "Already on '%s'\n"
+msgstr "Ya en '%s'\n"
 
-#. TRANSLATORS: %s is the configuration
-#. variable for tweaking threads, currently
-#. grep.threads
-#.
-#: builtin/grep.c:293 builtin/index-pack.c:1535 builtin/index-pack.c:1727
+#: builtin/checkout.c:892
 #, c-format
-msgid "no threads support, ignoring %s"
-msgstr "no hay soporte para hilos, ignorando %s"
+msgid "Switched to and reset branch '%s'\n"
+msgstr "Rama reiniciada y cambiada a '%s'\n"
 
-#: builtin/grep.c:461 builtin/grep.c:582 builtin/grep.c:623
+#: builtin/checkout.c:894 builtin/checkout.c:1291
 #, c-format
-msgid "unable to read tree (%s)"
-msgstr "no es posible leer el  árbol (%s)"
+msgid "Switched to a new branch '%s'\n"
+msgstr "Cambiado a nueva rama '%s'\n"
 
-#: builtin/grep.c:638
+#: builtin/checkout.c:896
 #, c-format
-msgid "unable to grep from object of type %s"
-msgstr "no es posible realizar grep del objeto de tipo %s"
+msgid "Switched to branch '%s'\n"
+msgstr "Cambiado a rama '%s'\n"
 
-#: builtin/grep.c:703
+#: builtin/checkout.c:947
 #, c-format
-msgid "switch `%c' expects a numerical value"
-msgstr "switch `%c' espera un valor numérico"
-
-#: builtin/grep.c:790
-msgid "search in index instead of in the work tree"
-msgstr "buscar en el índice en lugar del árbol de trabajo"
+msgid " ... and %d more.\n"
+msgstr " ... y %d más.\n"
 
-#: builtin/grep.c:792
-msgid "find in contents not managed by git"
-msgstr "encontrar en contenidos no manejados por git"
+#: builtin/checkout.c:953
+#, c-format
+msgid ""
+"Warning: you are leaving %d commit behind, not connected to\n"
+"any of your branches:\n"
+"\n"
+"%s\n"
+msgid_plural ""
+"Warning: you are leaving %d commits behind, not connected to\n"
+"any of your branches:\n"
+"\n"
+"%s\n"
+msgstr[0] ""
+"Peligro: estás saliendo %d commit atrás, no está conectado\n"
+"a ninguna rama:\n"
+"\n"
+"%s\n"
+msgstr[1] ""
+"Peligro: estás saliendo %d commits atrás, no está conectado\n"
+"a ninguna rama:\n"
+"\n"
+"%s\n"
 
-#: builtin/grep.c:794
-msgid "search in both tracked and untracked files"
-msgstr "buscar en archivos rastreados y no rastreados"
+#: builtin/checkout.c:972
+#, c-format
+msgid ""
+"If you want to keep it by creating a new branch, this may be a good time\n"
+"to do so with:\n"
+"\n"
+" git branch <new-branch-name> %s\n"
+"\n"
+msgid_plural ""
+"If you want to keep them by creating a new branch, this may be a good time\n"
+"to do so with:\n"
+"\n"
+" git branch <new-branch-name> %s\n"
+"\n"
+msgstr[0] ""
+"Si quieres conservarlo creando una nueva rama, este es un buen momento\n"
+"para hacerlo:\n"
+"\n"
+" git branch <nuevo-nombre-de-rama> %s\n"
+"\n"
+msgstr[1] ""
+"Si quieres conservarlos creando una nueva rama, este es un buen momento\n"
+"para hacerlo:\n"
+"\n"
+" git branch <nombre-de-rama> %s\n"
+"\n"
 
-#: builtin/grep.c:796
-msgid "ignore files specified via '.gitignore'"
-msgstr "ignorar archivos especificados via '.gitignore'"
+#: builtin/checkout.c:1007
+msgid "internal error in revision walk"
+msgstr "error interno en camino de revisión"
 
-#: builtin/grep.c:798
-msgid "recursively search in each submodule"
-msgstr "búsqueda recursiva en cada submódulo"
+#: builtin/checkout.c:1011
+msgid "Previous HEAD position was"
+msgstr "La posición previa de HEAD era"
 
-#: builtin/grep.c:801
-msgid "show non-matching lines"
-msgstr "mostrar líneas que no concuerdan"
+#: builtin/checkout.c:1051 builtin/checkout.c:1286
+msgid "You are on a branch yet to be born"
+msgstr "Estás en una rama por nacer"
 
-#: builtin/grep.c:803
-msgid "case insensitive matching"
-msgstr "búsqueda insensible a mayúsculas"
+#: builtin/checkout.c:1178
+msgid "only one reference expected"
+msgstr "solo una referencia esperada"
 
-#: builtin/grep.c:805
-msgid "match patterns only at word boundaries"
-msgstr "concordar patrón solo a los límites de las palabras"
+#: builtin/checkout.c:1195
+#, c-format
+msgid "only one reference expected, %d given."
+msgstr "solo una referencia esperada, %d entregadas."
 
-#: builtin/grep.c:807
-msgid "process binary files as text"
-msgstr "procesar archivos binarios como texto"
+#: builtin/checkout.c:1232
+#, c-format
+msgid ""
+"'%s' could be both a local file and a tracking branch.\n"
+"Please use -- (and optionally --no-guess) to disambiguate"
+msgstr ""
+"'%s' puede ser tanto un archivo local como una rama de rastreo.\n"
+"Por favor use -- (y opcionalmente --no-guess) para desambiguar"
 
-#: builtin/grep.c:809
-msgid "don't match patterns in binary files"
-msgstr "no concordar patrones en archivos binarios"
+#: builtin/checkout.c:1245 builtin/worktree.c:290 builtin/worktree.c:455
+#, c-format
+msgid "invalid reference: %s"
+msgstr "referencia inválida: %s"
 
-#: builtin/grep.c:812
-msgid "process binary files with textconv filters"
-msgstr "procesar archivos binarios con filtros textconv"
+#: builtin/checkout.c:1258 builtin/checkout.c:1622
+#, c-format
+msgid "reference is not a tree: %s"
+msgstr "la referencia no es n árbol: %s"
 
-#: builtin/grep.c:814
-msgid "descend at most <depth> levels"
-msgstr "descender como máximo <valor-de-profundiad>  niveles"
+#: builtin/checkout.c:1305
+#, c-format
+msgid "a branch is expected, got tag '%s'"
+msgstr "se esperaba un branch, se obtuvo tag '%s'"
 
-#: builtin/grep.c:818
-msgid "use extended POSIX regular expressions"
-msgstr "usar expresiones regulares POSIX extendidas"
+#: builtin/checkout.c:1307
+#, c-format
+msgid "a branch is expected, got remote branch '%s'"
+msgstr "se espera una rama, se obtuvo una rama remota '%s'"
 
-#: builtin/grep.c:821
-msgid "use basic POSIX regular expressions (default)"
-msgstr "usar expresiones regulares POSIX (default)"
+#: builtin/checkout.c:1308 builtin/checkout.c:1316
+#, c-format
+msgid "a branch is expected, got '%s'"
+msgstr "se esperaba branch, se obuto '%s'"
 
-#: builtin/grep.c:824
-msgid "interpret patterns as fixed strings"
-msgstr "interpretar patrones como strings arreglados"
+#: builtin/checkout.c:1311
+#, c-format
+msgid "a branch is expected, got commit '%s'"
+msgstr "se espera una rama, se obtuvo commit '%s'"
 
-#: builtin/grep.c:827
-msgid "use Perl-compatible regular expressions"
-msgstr "usar expresiones regulares compatibles con Perl"
+#: builtin/checkout.c:1327
+msgid ""
+"cannot switch branch while merging\n"
+"Consider \"git merge --quit\" or \"git worktree add\"."
+msgstr ""
+"no se puede cambiar de branch durante un merge\n"
+"Considera \"git merge --quit\" o \"git worktree add\"."
 
-#: builtin/grep.c:830
-msgid "show line numbers"
-msgstr "mostrar números de línea"
+#: builtin/checkout.c:1331
+msgid ""
+"cannot switch branch in the middle of an am session\n"
+"Consider \"git am --quit\" or \"git worktree add\"."
+msgstr ""
+"no se puede cambiar de branch en medio de una sesión de am\n"
+"Considera \"git am --quit\" o \"git worktree add\"."
 
-#: builtin/grep.c:831
-msgid "don't show filenames"
-msgstr "no mostrar nombres de archivo"
+#: builtin/checkout.c:1335
+msgid ""
+"cannot switch branch while rebasing\n"
+"Consider \"git rebase --quit\" or \"git worktree add\"."
+msgstr ""
+"no se puede cambiar de branch durante un rebase\n"
+"Considera \"git rebase --quit\" o \"git worktree add\"."
 
-#: builtin/grep.c:832
-msgid "show filenames"
-msgstr "mostrar nombres de archivo"
+#: builtin/checkout.c:1339
+msgid ""
+"cannot switch branch while cherry-picking\n"
+"Consider \"git cherry-pick --quit\" or \"git worktree add\"."
+msgstr ""
+"no se puede cambiar de branch durante un cherry-pick\n"
+"Considera \"git cherry-pick --quit\" o \"git worktree add\"."
 
-#: builtin/grep.c:834
-msgid "show filenames relative to top directory"
-msgstr "mostrar nombres de archivo relativos al directorio superior"
+#: builtin/checkout.c:1343
+msgid ""
+"cannot switch branch while reverting\n"
+"Consider \"git revert --quit\" or \"git worktree add\"."
+msgstr ""
+"no se puede cambiar de branch durante un revert\n"
+"Considera \"git revert --quit\" o \"git worktree add\"."
 
-#: builtin/grep.c:836
-msgid "show only filenames instead of matching lines"
-msgstr "mostrar solo nombres de archivos en lugar de líneas encontradas"
+#: builtin/checkout.c:1347
+msgid "you are switching branch while bisecting"
+msgstr "estás cambiando ramas durante un bisect"
 
-#: builtin/grep.c:838
-msgid "synonym for --files-with-matches"
-msgstr "sinónimo para --files-with-matches"
+#: builtin/checkout.c:1354
+msgid "paths cannot be used with switching branches"
+msgstr "rutas no pueden ser usadas con cambios de rama"
 
-#: builtin/grep.c:841
-msgid "show only the names of files without match"
-msgstr "mostrar solo los nombres de archivos sin coincidencias"
+#: builtin/checkout.c:1357 builtin/checkout.c:1361 builtin/checkout.c:1365
+#, c-format
+msgid "'%s' cannot be used with switching branches"
+msgstr "'%s' no puede ser usado con cambios de ramas"
 
-#: builtin/grep.c:843
-msgid "print NUL after filenames"
-msgstr "imprimir NUL después del nombre de archivo"
+#: builtin/checkout.c:1369 builtin/checkout.c:1372 builtin/checkout.c:1375
+#: builtin/checkout.c:1380 builtin/checkout.c:1385
+#, c-format
+msgid "'%s' cannot be used with '%s'"
+msgstr "'%s' no puede ser usado con '%s'"
 
-#: builtin/grep.c:846
-msgid "show the number of matches instead of matching lines"
-msgstr "mostrar el número de concordancias en lugar de las líneas concordantes"
+#: builtin/checkout.c:1382
+#, c-format
+msgid "'%s' cannot take <start-point>"
+msgstr "'%s' no puede tomar <punto de partida>"
 
-#: builtin/grep.c:847
-msgid "highlight matches"
-msgstr "resaltar concordancias"
+#: builtin/checkout.c:1390
+#, c-format
+msgid "Cannot switch branch to a non-commit '%s'"
+msgstr "No se puede cambiar rama a un '%s' sin commits"
 
-#: builtin/grep.c:849
-msgid "print empty line between matches from different files"
-msgstr "imprimir una línea vacía entre coincidencias de diferentes archivos"
+#: builtin/checkout.c:1397
+msgid "missing branch or commit argument"
+msgstr "falta branch o commit como argumento"
+
+#: builtin/checkout.c:1439 builtin/clone.c:91 builtin/commit-graph.c:52
+#: builtin/commit-graph.c:113 builtin/fetch.c:167 builtin/merge.c:285
+#: builtin/multi-pack-index.c:27 builtin/pull.c:138 builtin/push.c:563
+#: builtin/send-pack.c:174
+msgid "force progress reporting"
+msgstr "forzar el reporte de progreso"
 
-#: builtin/grep.c:851
-msgid "show filename only once above matches from same file"
-msgstr ""
-"mostrar el nombre de archivo solo una vez para concordancias en el mismo "
-"archivo"
+#: builtin/checkout.c:1440
+msgid "perform a 3-way merge with the new branch"
+msgstr "realizar una fusión de tres vías con la rama nueva"
 
-#: builtin/grep.c:854
-msgid "show <n> context lines before and after matches"
-msgstr "mostrar <n> líneas de contexto antes y después de la concordancia"
+#: builtin/checkout.c:1441 builtin/log.c:1690 parse-options.h:322
+msgid "style"
+msgstr "estilo"
 
-#: builtin/grep.c:857
-msgid "show <n> context lines before matches"
-msgstr "mostrar <n> líneas de contexto antes de las concordancias"
+#: builtin/checkout.c:1442
+msgid "conflict style (merge or diff3)"
+msgstr "conflicto de estilos (merge o diff3)"
 
-#: builtin/grep.c:859
-msgid "show <n> context lines after matches"
-msgstr "mostrar <n> líneas de context después de las concordancias"
+#: builtin/checkout.c:1454 builtin/worktree.c:503
+msgid "detach HEAD at named commit"
+msgstr "desacoplar HEAD en el commit nombrado"
 
-#: builtin/grep.c:861
-msgid "use <n> worker threads"
-msgstr "usar <n> hilos de trabajo"
+#: builtin/checkout.c:1455
+msgid "set upstream info for new branch"
+msgstr "configurar info de upstream para una rama nueva"
 
-#: builtin/grep.c:862
-msgid "shortcut for -C NUM"
-msgstr "atajo para -C NUM"
+#: builtin/checkout.c:1457
+msgid "force checkout (throw away local modifications)"
+msgstr "forzar el checkout (descartar modificaciones locales)"
 
-#: builtin/grep.c:865
-msgid "show a line with the function name before matches"
-msgstr ""
-"mostrar una línea con el nombre de la función antes de las concordancias"
+#: builtin/checkout.c:1459
+msgid "new-branch"
+msgstr "nueva-rama"
 
-#: builtin/grep.c:867
-msgid "show the surrounding function"
-msgstr "mostrar la función circundante"
+#: builtin/checkout.c:1459
+msgid "new unparented branch"
+msgstr "nueva rama no emparentada"
 
-#: builtin/grep.c:870
-msgid "read patterns from file"
-msgstr "leer patrones del archivo"
+#: builtin/checkout.c:1461 builtin/merge.c:288
+msgid "update ignored files (default)"
+msgstr "actualizar archivos ignorados (default)"
 
-#: builtin/grep.c:872
-msgid "match <pattern>"
-msgstr "concordar <patrón>"
+#: builtin/checkout.c:1464
+msgid "do not check if another worktree is holding the given ref"
+msgstr "no revise si otro árbol de trabajo contiene la ref entregada"
 
-#: builtin/grep.c:874
-msgid "combine patterns specified with -e"
-msgstr "combinar patrones especificados con -e"
+#: builtin/checkout.c:1477
+msgid "checkout our version for unmerged files"
+msgstr "hacer checkout a  nuestra versión para archivos sin fusionar"
 
-#: builtin/grep.c:886
-msgid "indicate hit with exit status without output"
-msgstr "indicar concordancia con exit status sin output"
+#: builtin/checkout.c:1480
+msgid "checkout their version for unmerged files"
+msgstr "hacer checkout a su versión para los archivos sin fusionar"
 
-#: builtin/grep.c:888
-msgid "show only matches from files that match all patterns"
-msgstr ""
-"mostrar solo concordancias con archivos que concuerdan todos los patrones"
+#: builtin/checkout.c:1484
+msgid "do not limit pathspecs to sparse entries only"
+msgstr "no limitar pathspecs a dispersar entradas solamente"
 
-#: builtin/grep.c:890
-msgid "show parse tree for grep expression"
-msgstr "mostrar árbol analizado para la expresión grep"
+#: builtin/checkout.c:1537
+msgid "-b, -B and --orphan are mutually exclusive"
+msgstr "-b, -B y --orphan son mutuamente exclusivas"
 
-#: builtin/grep.c:894
-msgid "pager"
-msgstr "paginador"
+#: builtin/checkout.c:1540
+msgid "-p and --overlay are mutually exclusive"
+msgstr "-p y --overlay son mutuamente exclusivas"
 
-#: builtin/grep.c:894
-msgid "show matching files in the pager"
-msgstr "mostrar archivos concordantes en el paginador"
+#: builtin/checkout.c:1577
+msgid "--track needs a branch name"
+msgstr "--track necesita el nombre de una rama"
 
-#: builtin/grep.c:898
-msgid "allow calling of grep(1) (ignored by this build)"
-msgstr "permitir el llamado de grep(1) (ignorado por esta build)"
+#: builtin/checkout.c:1582
+msgid "missing branch name; try -b"
+msgstr "falta nombre de rama; prueba -b"
 
-#: builtin/grep.c:962
-msgid "no pattern given."
-msgstr "no se ha entregado patrón."
+#: builtin/checkout.c:1615
+#, c-format
+msgid "could not resolve %s"
+msgstr "no se pudo resolver %s"
 
-#: builtin/grep.c:994
-msgid "--no-index or --untracked cannot be used with revs"
-msgstr "--no-index o --untracked no se puede usar con revs"
+#: builtin/checkout.c:1631
+msgid "invalid path specification"
+msgstr "especificación de ruta inválida"
 
-#: builtin/grep.c:1001
+#: builtin/checkout.c:1638
 #, c-format
-msgid "unable to resolve revision: %s"
-msgstr "no se posible resolver revisión: %s"
+msgid "'%s' is not a commit and a branch '%s' cannot be created from it"
+msgstr "'%s' no es un commit y una rama '%s' no puede ser creada desde este"
 
-#: builtin/grep.c:1036 builtin/index-pack.c:1531
+#: builtin/checkout.c:1642
 #, c-format
-msgid "invalid number of threads specified (%d)"
-msgstr "número inválido de hilos especificado (%d)"
+msgid "git checkout: --detach does not take a path argument '%s'"
+msgstr "git checkout: --detach no toma un argumento de ruta '%s'"
 
-#: builtin/grep.c:1041
-msgid "no threads support, ignoring --threads"
-msgstr "no se soportan hilos, ignorando --threads"
-
-#: builtin/grep.c:1065
-msgid "--open-files-in-pager only works on the worktree"
-msgstr "--open-files-in-pager solo funciona en el árbol de trabajo"
+#: builtin/checkout.c:1651
+msgid "--pathspec-from-file is incompatible with --detach"
+msgstr "--pathspec-from-file es incompatible con --detach"
+
+#: builtin/checkout.c:1654 builtin/reset.c:324
+msgid "--pathspec-from-file is incompatible with --patch"
+msgstr "--pathspec-from-file es incompatible con --patch"
 
-#: builtin/grep.c:1088
-msgid "option not supported with --recurse-submodules."
-msgstr "opción no soportada con --recurse-submodules."
-
-#: builtin/grep.c:1094
-msgid "--cached or --untracked cannot be used with --no-index."
-msgstr "--cached o --untracked no pueden ser usadas con --no-index."
-
-#: builtin/grep.c:1100
-msgid "--[no-]exclude-standard cannot be used for tracked contents."
-msgstr "--[no-]exclude-standard no puede ser usada para contenido rastreado."
-
-#: builtin/grep.c:1108
-msgid "both --cached and trees are given."
-msgstr "--cached y árboles han sido entregados."
-
-#: builtin/hash-object.c:83
+#: builtin/checkout.c:1665
 msgid ""
-"git hash-object [-t <type>] [-w] [--path=<file> | --no-filters] [--stdin] "
-"[--] <file>..."
+"git checkout: --ours/--theirs, --force and --merge are incompatible when\n"
+"checking out of the index."
 msgstr ""
-"git hash-object [-t <tipo>] [-w] [--path=<archivo> | --no-filters] [--stdin] "
-"[--] <archivo>..."
-
-#: builtin/hash-object.c:84
-msgid "git hash-object  --stdin-paths"
-msgstr "git hash-object  --stdin-paths"
-
-#: builtin/hash-object.c:96
-msgid "type"
-msgstr "tipo"
-
-#: builtin/hash-object.c:96
-msgid "object type"
-msgstr "tipo de objeto"
-
-#: builtin/hash-object.c:97
-msgid "write the object into the object database"
-msgstr "escribir el objeto en la base de datos de objetos"
-
-#: builtin/hash-object.c:99
-msgid "read the object from stdin"
-msgstr "leer el objeto de stdin"
+"git checkout: --ours/--theirs, --force y --merge son incompatibles cuando\n"
+"se revisa fuera del índice."
 
-#: builtin/hash-object.c:101
-msgid "store file as is without filters"
-msgstr "guardar el archivo como es sin filtros"
+#: builtin/checkout.c:1670
+msgid "you must specify path(s) to restore"
+msgstr "debes especificar path(s) para restaurar"
 
-#: builtin/hash-object.c:102
+#: builtin/checkout.c:1689
+#, c-format
 msgid ""
-"just hash any random garbage to create corrupt objects for debugging Git"
+"'%s' matched more than one remote tracking branch.\n"
+"We found %d remotes with a reference that matched. So we fell back\n"
+"on trying to resolve the argument as a path, but failed there too!\n"
+"\n"
+"If you meant to check out a remote tracking branch on, e.g. 'origin',\n"
+"you can do so by fully qualifying the name with the --track option:\n"
+"\n"
+"    git checkout --track origin/<name>\n"
+"\n"
+"If you'd like to always have checkouts of an ambiguous <name> prefer\n"
+"one remote, e.g. the 'origin' remote, consider setting\n"
+"checkout.defaultRemote=origin in your config."
 msgstr ""
-"solo realizar un hash a cualquier basura random para crear un objeto "
-"corrupto para hacer debugging de Gti"
-
-#: builtin/hash-object.c:103
-msgid "process file as it were from this path"
-msgstr "procesar el archivo como si fuera de esta ruta"
-
-#: builtin/help.c:45
-msgid "print all available commands"
-msgstr "mostrar todos los comandos disponibles"
+"'%s' acertó más de una rama remota rastreada.\n"
+"Encontramos %d remotos con una referencia que concuerda. Así que volvemos\n"
+"a intentar resolver el argumento como una ruta, ¡pero eso también falló!\n"
+"\n"
+"Si querías hacer un check out a una rama rastreada remota, como 'origin',\n"
+"puedes hacerlo proporcionando el nombre completo con la opción --track:\n"
+"\n"
+"    git checkout --track origin/<nombre>\n"
+"\n"
+"Si quisieras que siempre los checkouts de nombres ambiguos prefieran una "
+"rama\n"
+"de nombre <nombre> remota, como 'origin', considera configurar\n"
+"checkout.defaultRemote=origin en tu configuración."
 
-#: builtin/help.c:46
-msgid "exclude guides"
-msgstr "excluir las guias"
+#: builtin/checkout.c:1714 builtin/checkout.c:1716 builtin/checkout.c:1765
+#: builtin/checkout.c:1767 builtin/clone.c:121 builtin/remote.c:169
+#: builtin/remote.c:171 builtin/worktree.c:499 builtin/worktree.c:501
+msgid "branch"
+msgstr "rama"
 
-#: builtin/help.c:47
-msgid "print list of useful guides"
-msgstr "mostrar una lista de nociones utiles"
+#: builtin/checkout.c:1715
+msgid "create and checkout a new branch"
+msgstr "crear y hacer checkout a una nueva rama"
 
-#: builtin/help.c:48
-msgid "show man page"
-msgstr "mostrar la pagina del manual"
+#: builtin/checkout.c:1717
+msgid "create/reset and checkout a branch"
+msgstr "crear/reiniciar y hacer checkout a una rama"
 
-#: builtin/help.c:49
-msgid "show manual in web browser"
-msgstr "mostrar la pagina del manual en un navegador web"
+#: builtin/checkout.c:1718
+msgid "create reflog for new branch"
+msgstr "crear un reflog para una nueva rama"
 
-#: builtin/help.c:51
-msgid "show info page"
-msgstr "mostrar la pagina de info"
+#: builtin/checkout.c:1720
+msgid "second guess 'git checkout <no-such-branch>' (default)"
+msgstr "adivinar segunda opción 'git checkout <no-hay-tal-rama>' (default)"
+
+#: builtin/checkout.c:1721
+msgid "use overlay mode (default)"
+msgstr "usar modo overlay (default)"
+
+#: builtin/checkout.c:1766
+msgid "create and switch to a new branch"
+msgstr "crear y hacer switch a una nueva rama"
+
+#: builtin/checkout.c:1768
+msgid "create/reset and switch to a branch"
+msgstr "crear/reiniciar y hacer switch a una rama"
+
+#: builtin/checkout.c:1770
+msgid "second guess 'git switch <no-such-branch>'"
+msgstr "adivinar segunda opción 'git checkout <no-hay-tal-rama>'"
+
+#: builtin/checkout.c:1772
+msgid "throw away local modifications"
+msgstr "descartar modificaciones locales"
+
+#: builtin/checkout.c:1804
+msgid "which tree-ish to checkout from"
+msgstr "de qué árbol hacer el checkout"
+
+#: builtin/checkout.c:1806
+msgid "restore the index"
+msgstr "restaurar el index"
+
+#: builtin/checkout.c:1808
+msgid "restore the working tree (default)"
+msgstr "restaurar el árbol de trabajo (default)"
+
+#: builtin/checkout.c:1810
+msgid "ignore unmerged entries"
+msgstr "ignorar entradas no fusionadas"
+
+#: builtin/checkout.c:1811
+msgid "use overlay mode"
+msgstr "usar modo overlay"
 
-#: builtin/help.c:53
-msgid "print command description"
-msgstr "imprimir descripción del comando"
+#: builtin/clean.c:28
+msgid ""
+"git clean [-d] [-f] [-i] [-n] [-q] [-e <pattern>] [-x | -X] [--] <paths>..."
+msgstr ""
+"git clean [-d] [-f] [-i] [-n] [-q] [-e <patrón>] [-x | -X] [--] <rutas>..."
 
-#: builtin/help.c:58
-msgid "git help [--all] [--guides] [--man | --web | --info] [<command>]"
-msgstr "git help [--all] [--guides] [--man | --web | --info] [<comando>]"
+#: builtin/clean.c:32
+#, c-format
+msgid "Removing %s\n"
+msgstr "Borrando %s\n"
 
-#: builtin/help.c:70
+#: builtin/clean.c:33
 #, c-format
-msgid "unrecognized help format '%s'"
-msgstr "formato help no reconocido '%s'"
+msgid "Would remove %s\n"
+msgstr "Sera borrado %s\n"
 
-#: builtin/help.c:97
-msgid "Failed to start emacsclient."
-msgstr "Falló al iniciar emacsclient."
+#: builtin/clean.c:34
+#, c-format
+msgid "Skipping repository %s\n"
+msgstr "Saltando repositorio %s\n"
 
-#: builtin/help.c:110
-msgid "Failed to parse emacsclient version."
-msgstr "Falló al analizar la versión de emacsclient."
+#: builtin/clean.c:35
+#, c-format
+msgid "Would skip repository %s\n"
+msgstr "Se saltara repositorio %s\n"
 
-#: builtin/help.c:118
+#: builtin/clean.c:36
 #, c-format
-msgid "emacsclient version '%d' too old (< 22)."
-msgstr "la versión '%d' de emacsclient es muy antigua (<22)."
+msgid "failed to remove %s"
+msgstr "falló al borrar %s"
 
-#: builtin/help.c:136 builtin/help.c:158 builtin/help.c:168 builtin/help.c:176
+#: builtin/clean.c:37
 #, c-format
-msgid "failed to exec '%s'"
-msgstr "falló al ejecutar '%s'"
+msgid "could not lstat %s\n"
+msgstr "no se pudo lstat %s\n"
 
-#: builtin/help.c:214
+#: builtin/clean.c:301 git-add--interactive.perl:595
 #, c-format
 msgid ""
-"'%s': path for unsupported man viewer.\n"
-"Please consider using 'man.<tool>.cmd' instead."
+"Prompt help:\n"
+"1          - select a numbered item\n"
+"foo        - select item based on unique prefix\n"
+"           - (empty) select nothing\n"
 msgstr ""
-"'%s': ruta para el visualizador del manual no soportada.\n"
-"Por favor considere usar 'man.<herramienta.cmd'."
+"Ayuda rápida:\n"
+"1          - selecciona un objeto por numero\n"
+"foo        - selecciona un objeto basado en un prefijo único\n"
+"           - (vacío) no elegir nada\n"
 
-#: builtin/help.c:226
+#: builtin/clean.c:305 git-add--interactive.perl:604
 #, c-format
 msgid ""
-"'%s': cmd for supported man viewer.\n"
-"Please consider using 'man.<tool>.path' instead."
+"Prompt help:\n"
+"1          - select a single item\n"
+"3-5        - select a range of items\n"
+"2-3,6-9    - select multiple ranges\n"
+"foo        - select item based on unique prefix\n"
+"-...       - unselect specified items\n"
+"*          - choose all items\n"
+"           - (empty) finish selecting\n"
 msgstr ""
-"'%s': comando no soportado para man viewer.\n"
-"Por favor considere usar 'man.<herramienta>.path."
-
-#: builtin/help.c:343
-#, c-format
-msgid "'%s': unknown man viewer."
-msgstr "'%s': visualizador de man desconocido."
-
-#: builtin/help.c:360
-msgid "no man viewer handled the request"
-msgstr "ningún visualizador de manual proceso la petición"
+"Ayuda rápida:\n"
+"1          - selecciona un objeto único\n"
+"3-5        - selecciona un rango de objetos\n"
+"2-3,6-9    - selecciona múltiples rangos\n"
+"foo        - selecciona un objeto basado en un prefijo único\n"
+"-...       - de-seleccionar objetos especificados\n"
+"*          - escoger todos los objetos\n"
+"           - (vacío) terminar selección\n"
 
-#: builtin/help.c:368
-msgid "no info viewer handled the request"
-msgstr "ningún visor de info manejo la petición"
+#: builtin/clean.c:521 git-add--interactive.perl:570
+#: git-add--interactive.perl:575
+#, c-format, perl-format
+msgid "Huh (%s)?\n"
+msgstr "¿Ahh (%s)?\n"
 
-#: builtin/help.c:415
+#: builtin/clean.c:663
 #, c-format
-msgid "'%s' is aliased to '%s'"
-msgstr "'%s' tiene el alias '%s'"
+msgid "Input ignore patterns>> "
+msgstr "Input ignora los patrones >> "
 
-#: builtin/help.c:442 builtin/help.c:459
+#: builtin/clean.c:700
 #, c-format
-msgid "usage: %s%s"
-msgstr "uso: %s%s"
+msgid "WARNING: Cannot find items matched by: %s"
+msgstr "PELIGRO: No se puede encontrar objetos que concuerden con: %s"
 
-#: builtin/index-pack.c:158
-#, c-format
-msgid "unable to open %s"
-msgstr "no es posible abrir %s"
+#: builtin/clean.c:721
+msgid "Select items to delete"
+msgstr "Seleccionar objetos para borrar"
 
-#: builtin/index-pack.c:208
+#. TRANSLATORS: Make sure to keep [y/N] as is
+#: builtin/clean.c:762
 #, c-format
-msgid "object type mismatch at %s"
-msgstr "el tipo del objeto no concuerda en %s"
+msgid "Remove %s [y/N]? "
+msgstr "¿Borrar %s [y/N]? "
 
-#: builtin/index-pack.c:228
-#, c-format
-msgid "did not receive expected object %s"
-msgstr "no se recibió el objeto esperado %s"
+#: builtin/clean.c:795
+msgid ""
+"clean               - start cleaning\n"
+"filter by pattern   - exclude items from deletion\n"
+"select by numbers   - select items to be deleted by numbers\n"
+"ask each            - confirm each deletion (like \"rm -i\")\n"
+"quit                - stop cleaning\n"
+"help                - this screen\n"
+"?                   - help for prompt selection"
+msgstr ""
+"clean               - comenzar la limpieza\n"
+"filtrar por patrón   - excluye objetos del borrado \n"
+"elegir por números   - selecciona objetos a ser borrados por numero\n"
+"preguntar cada uno     - confirmar cada borrado (como \"rm -i\")\n"
+"quit                - parar limpieza\n"
+"help                - esta ventana\n"
+"?                   - ayuda para selección de opciones"
 
-#: builtin/index-pack.c:231
-#, c-format
-msgid "object %s: expected type %s, found %s"
-msgstr "objeto %s: tipo esperado %s, encontrado %s"
+#: builtin/clean.c:831
+msgid "Would remove the following item:"
+msgid_plural "Would remove the following items:"
+msgstr[0] "Se eliminará el siguiente objeto:"
+msgstr[1] "Se eliminarán los siguientes objetos:"
 
-#: builtin/index-pack.c:273
-#, c-format
-msgid "cannot fill %d byte"
-msgid_plural "cannot fill %d bytes"
-msgstr[0] "no se puede llenar %d byte"
-msgstr[1] "no se pueden llenar %d bytes"
+#: builtin/clean.c:847
+msgid "No more files to clean, exiting."
+msgstr "No hay más archivos para limpiar, saliendo."
 
-#: builtin/index-pack.c:283
-msgid "early EOF"
-msgstr "EOF temprano"
+#: builtin/clean.c:909
+msgid "do not print names of files removed"
+msgstr "no imprimir nombres de archivos borrados"
 
-#: builtin/index-pack.c:284
-msgid "read error on input"
-msgstr "leer error en input"
+#: builtin/clean.c:911
+msgid "force"
+msgstr "forzar"
 
-#: builtin/index-pack.c:296
-msgid "used more bytes than were available"
-msgstr "se usaron más bytes de los disponibles"
+#: builtin/clean.c:912
+msgid "interactive cleaning"
+msgstr "limpieza interactiva"
 
-#: builtin/index-pack.c:303
-msgid "pack too large for current definition of off_t"
-msgstr "paquete muy grande para la definición actual de off_t"
+#: builtin/clean.c:914
+msgid "remove whole directories"
+msgstr "borrar directorios completos"
 
-#: builtin/index-pack.c:306 builtin/unpack-objects.c:93
-msgid "pack exceeds maximum allowed size"
-msgstr "paquete excede el máximo tamaño permitido"
+#: builtin/clean.c:915 builtin/describe.c:548 builtin/describe.c:550
+#: builtin/grep.c:901 builtin/log.c:177 builtin/log.c:179
+#: builtin/ls-files.c:557 builtin/name-rev.c:464 builtin/name-rev.c:466
+#: builtin/show-ref.c:179
+msgid "pattern"
+msgstr "patrón"
 
-#: builtin/index-pack.c:321
-#, c-format
-msgid "unable to create '%s'"
-msgstr "no se puede crear '%s'"
+#: builtin/clean.c:916
+msgid "add <pattern> to ignore rules"
+msgstr "agregar <patrón> para ignorar reglas"
 
-#: builtin/index-pack.c:327
-#, c-format
-msgid "cannot open packfile '%s'"
-msgstr "no se puede abrir el archivo de paquete '%s'"
+#: builtin/clean.c:917
+msgid "remove ignored files, too"
+msgstr "borrar archivos ignorados, también"
 
-#: builtin/index-pack.c:341
-msgid "pack signature mismatch"
-msgstr "firma del paquete no concuerda"
+#: builtin/clean.c:919
+msgid "remove only ignored files"
+msgstr "borrar solo archivos ignorados"
 
-#: builtin/index-pack.c:343
-#, c-format
-msgid "pack version %<PRIu32> unsupported"
-msgstr "versión de paquete %<PRIu32> no soportada"
+#: builtin/clean.c:937
+msgid "-x and -X cannot be used together"
+msgstr "-x y -X no pueden ser usadas juntas"
 
-#: builtin/index-pack.c:361
-#, c-format
-msgid "pack has bad object at offset %<PRIuMAX>: %s"
-msgstr "paquete tiene un mal objeto en el offset %<PRIuMAX>: %s"
+#: builtin/clean.c:941
+msgid ""
+"clean.requireForce set to true and neither -i, -n, nor -f given; refusing to "
+"clean"
+msgstr ""
+"clean.requireForce configurado como true y ninguno -i, -n, ni -f entregados; "
+"rehusando el clean"
 
-#: builtin/index-pack.c:482
-#, c-format
-msgid "inflate returned %d"
-msgstr "inflate retornó %d"
+#: builtin/clean.c:944
+msgid ""
+"clean.requireForce defaults to true and neither -i, -n, nor -f given; "
+"refusing to clean"
+msgstr ""
+"clean.requireForce default en true y ninguno -i, -n, ni -f entregados; "
+"rehusando el clean"
 
-#: builtin/index-pack.c:531
-msgid "offset value overflow for delta base object"
-msgstr "valor de offset desbordado para el objeto base delta"
+#: builtin/clone.c:45
+msgid "git clone [<options>] [--] <repo> [<dir>]"
+msgstr "git clone [<opciones>] [--] <repo> [<directorio>]"
 
-#: builtin/index-pack.c:539
-msgid "delta base offset is out of bound"
-msgstr "offset de base delta está fuera de límites"
+#: builtin/clone.c:93
+msgid "don't create a checkout"
+msgstr "no crear checkout"
 
-#: builtin/index-pack.c:547
-#, c-format
-msgid "unknown object type %d"
-msgstr "tipo de objeto %d desconocido"
+#: builtin/clone.c:94 builtin/clone.c:96 builtin/init-db.c:489
+msgid "create a bare repository"
+msgstr "crear un repositorio vacío"
 
-#: builtin/index-pack.c:578
-msgid "cannot pread pack file"
-msgstr "no se puede propagar el paquete"
+#: builtin/clone.c:98
+msgid "create a mirror repository (implies bare)"
+msgstr "crear un repositorio espejo (implica vacío)"
 
-#: builtin/index-pack.c:580
-#, c-format
-msgid "premature end of pack file, %<PRIuMAX> byte missing"
-msgid_plural "premature end of pack file, %<PRIuMAX> bytes missing"
-msgstr[0] "final prematuro de archivo de paquete, %<PRIuMAX> byte faltante"
-msgstr[1] "final prematuro de archivo de paquete, %<PRIuMAX> bytes faltantes"
+#: builtin/clone.c:100
+msgid "to clone from a local repository"
+msgstr "clonar de un repositorio local"
 
-#: builtin/index-pack.c:606
-msgid "serious inflate inconsistency"
-msgstr "inconsistencia seria en inflate"
+#: builtin/clone.c:102
+msgid "don't use local hardlinks, always copy"
+msgstr "no usar hardlinks, siempre copiar"
 
-#: builtin/index-pack.c:751 builtin/index-pack.c:757 builtin/index-pack.c:780
-#: builtin/index-pack.c:819 builtin/index-pack.c:828
-#, c-format
-msgid "SHA1 COLLISION FOUND WITH %s !"
-msgstr "COLISIÓN DE TIPO SHA1 ENCONTRADA CON %s !"
+#: builtin/clone.c:104
+msgid "setup as shared repository"
+msgstr "configurar como repositorio compartido"
 
-#: builtin/index-pack.c:754 builtin/pack-objects.c:198
-#: builtin/pack-objects.c:292
-#, c-format
-msgid "unable to read %s"
-msgstr "no se posible leer %s"
+#: builtin/clone.c:107
+msgid "pathspec"
+msgstr "pathspec"
 
-#: builtin/index-pack.c:817
-#, c-format
-msgid "cannot read existing object info %s"
-msgstr "no se puede leer la información existente del objeto %s"
+#: builtin/clone.c:107
+msgid "initialize submodules in the clone"
+msgstr "inicializar submódulos en el clonado"
 
-#: builtin/index-pack.c:825
-#, c-format
-msgid "cannot read existing object %s"
-msgstr "no se puede leer el objeto existente %s"
+#: builtin/clone.c:110
+msgid "number of submodules cloned in parallel"
+msgstr "numero de submódulos clonados en paralelo"
 
-#: builtin/index-pack.c:839
-#, c-format
-msgid "invalid blob object %s"
-msgstr "objeto blob %s inválido"
+#: builtin/clone.c:111 builtin/init-db.c:486
+msgid "template-directory"
+msgstr "directorio-template"
 
-#: builtin/index-pack.c:842 builtin/index-pack.c:860
-msgid "fsck error in packed object"
-msgstr "error de fsck en el objeto empaquetado"
+#: builtin/clone.c:112 builtin/init-db.c:487
+msgid "directory from which templates will be used"
+msgstr "directorio del cual los templates serán usados"
 
-#: builtin/index-pack.c:857
-#, c-format
-msgid "invalid %s"
-msgstr "%s inválido"
+#: builtin/clone.c:114 builtin/clone.c:116 builtin/submodule--helper.c:1392
+#: builtin/submodule--helper.c:1885
+msgid "reference repository"
+msgstr "repositorio de referencia"
 
-#: builtin/index-pack.c:862
-#, c-format
-msgid "Not all child objects of %s are reachable"
-msgstr "No todos los objetos hijos de %s son alcanzables"
+#: builtin/clone.c:118 builtin/submodule--helper.c:1394
+#: builtin/submodule--helper.c:1887
+msgid "use --reference only while cloning"
+msgstr "usa--reference  solamente si estás clonado"
 
-#: builtin/index-pack.c:934 builtin/index-pack.c:965
-msgid "failed to apply delta"
-msgstr "falló al aplicar delta"
+#: builtin/clone.c:119 builtin/column.c:27 builtin/merge-file.c:46
+#: builtin/pack-objects.c:3294 builtin/repack.c:327
+msgid "name"
+msgstr "nombre"
 
-#: builtin/index-pack.c:1135
-msgid "Receiving objects"
-msgstr "Recibiendo objetos"
+#: builtin/clone.c:120
+msgid "use <name> instead of 'origin' to track upstream"
+msgstr "use <nombre> en lugar de 'origin' para rastrear upstream"
 
-#: builtin/index-pack.c:1135
-msgid "Indexing objects"
-msgstr "Indexando objetos"
+#: builtin/clone.c:122
+msgid "checkout <branch> instead of the remote's HEAD"
+msgstr "checkout <rama> en lugar de HEAD remota"
 
-#: builtin/index-pack.c:1169
-msgid "pack is corrupted (SHA1 mismatch)"
-msgstr "paquete está corrompido (SHA1 no concuerda)"
+#: builtin/clone.c:124
+msgid "path to git-upload-pack on the remote"
+msgstr "ruta para git-upload-pack en el remoto"
 
-#: builtin/index-pack.c:1174
-msgid "cannot fstat packfile"
-msgstr "no se puede fstat al archivo de paquete"
+#: builtin/clone.c:125 builtin/fetch.c:168 builtin/grep.c:840
+#: builtin/pull.c:227
+msgid "depth"
+msgstr "profundidad"
 
-#: builtin/index-pack.c:1177
-msgid "pack has junk at the end"
-msgstr "el paquete tiene basura al final"
+#: builtin/clone.c:126
+msgid "create a shallow clone of that depth"
+msgstr "crear un clon superficial para esa profundidad"
 
-#: builtin/index-pack.c:1189
-msgid "confusion beyond insanity in parse_pack_objects()"
-msgstr "confusión más allá de la locura en parse_pack_objects()"
+#: builtin/clone.c:127 builtin/fetch.c:170 builtin/pack-objects.c:3283
+msgid "time"
+msgstr "tiempo"
 
-#: builtin/index-pack.c:1212
-msgid "Resolving deltas"
-msgstr "Resolviendo deltas"
+#: builtin/clone.c:128
+msgid "create a shallow clone since a specific time"
+msgstr "crear un clon superficial desde el tiempo específico"
 
-#: builtin/index-pack.c:1223
-#, c-format
-msgid "unable to create thread: %s"
-msgstr "no es posible crear hilo: %s"
+#: builtin/clone.c:129 builtin/fetch.c:172 builtin/fetch.c:195
+#: builtin/rebase.c:1445
+msgid "revision"
+msgstr "revision"
 
-#: builtin/index-pack.c:1265
-msgid "confusion beyond insanity"
-msgstr "confusión más allá de la locura"
+#: builtin/clone.c:130 builtin/fetch.c:173
+msgid "deepen history of shallow clone, excluding rev"
+msgstr "ahondando historia de clon superficial, excluyendo rev"
 
-#: builtin/index-pack.c:1271
-#, c-format
-msgid "completed with %d local object"
-msgid_plural "completed with %d local objects"
-msgstr[0] "completado con %d objeto local"
-msgstr[1] "completado con %d objetos locales"
+#: builtin/clone.c:132
+msgid "clone only one branch, HEAD or --branch"
+msgstr "clonar solo una rama,HEAD o --branch"
 
-#: builtin/index-pack.c:1283
-#, c-format
-msgid "Unexpected tail checksum for %s (disk corruption?)"
-msgstr "Tail checksum para %s inesperada (corrupción de disco?)"
+#: builtin/clone.c:134
+msgid "don't clone any tags, and make later fetches not to follow them"
+msgstr "no clonar ningún tag, y hacer que los subsiguientes fetch no los sigan"
 
-#: builtin/index-pack.c:1287
-#, c-format
-msgid "pack has %d unresolved delta"
-msgid_plural "pack has %d unresolved deltas"
-msgstr[0] "paquete tiene %d delta sin resolver"
-msgstr[1] "paquete tiene %d deltas sin resolver"
+#: builtin/clone.c:136
+msgid "any cloned submodules will be shallow"
+msgstr "cualquier submódulo clonado será superficial"
 
-#: builtin/index-pack.c:1311
-#, c-format
-msgid "unable to deflate appended object (%d)"
-msgstr "no es posible desinflar el objeto adjunto (%d)"
+#: builtin/clone.c:137 builtin/init-db.c:495
+msgid "gitdir"
+msgstr "gitdir"
 
-#: builtin/index-pack.c:1388
-#, c-format
-msgid "local object %s is corrupt"
-msgstr "objeto local %s está corrompido"
+#: builtin/clone.c:138 builtin/init-db.c:496
+msgid "separate git dir from working tree"
+msgstr "separa git dir del árbol de trabajo"
 
-#: builtin/index-pack.c:1402
-#, c-format
-msgid "packfile name '%s' does not end with '.pack'"
-msgstr "nombre '%s' de archivo de paquete no termina con '.pack'"
+#: builtin/clone.c:139
+msgid "key=value"
+msgstr "llave=valor"
 
-#: builtin/index-pack.c:1427
-#, c-format
-msgid "cannot write %s file '%s'"
-msgstr "no se puede escribir %s en el archivo '%s'"
+#: builtin/clone.c:140
+msgid "set config inside the new repository"
+msgstr "configurar config dentro del nuevo repositorio"
 
-#: builtin/index-pack.c:1435
-#, c-format
-msgid "cannot close written %s file '%s'"
-msgstr "no se puede cerrar escrito %s en archivo '%s'"
+#: builtin/clone.c:142 builtin/fetch.c:190 builtin/ls-remote.c:76
+#: builtin/push.c:573 builtin/send-pack.c:172
+msgid "server-specific"
+msgstr "especifico-de-servidor"
 
-#: builtin/index-pack.c:1459
-msgid "error while closing pack file"
-msgstr "error mientras se cierra el archivo paquete"
+#: builtin/clone.c:142 builtin/fetch.c:190 builtin/ls-remote.c:76
+#: builtin/push.c:573 builtin/send-pack.c:173
+msgid "option to transmit"
+msgstr "opción para trasmitir"
 
-#: builtin/index-pack.c:1473
-msgid "cannot store pack file"
-msgstr "no se puede guardar el archivo paquete"
+#: builtin/clone.c:143 builtin/fetch.c:191 builtin/pull.c:240
+#: builtin/push.c:574
+msgid "use IPv4 addresses only"
+msgstr "solo usar direcciones IPv4"
 
-#: builtin/index-pack.c:1481
-msgid "cannot store index file"
-msgstr "no se puede guardar el archivo índice"
+#: builtin/clone.c:145 builtin/fetch.c:193 builtin/pull.c:243
+#: builtin/push.c:576
+msgid "use IPv6 addresses only"
+msgstr "solo usar direcciones IPv6"
 
-#: builtin/index-pack.c:1525
-#, c-format
-msgid "bad pack.indexversion=%<PRIu32>"
-msgstr "mal pack.indexversion=%<PRIu32>"
+#: builtin/clone.c:149
+msgid "any cloned submodules will use their remote-tracking branch"
+msgstr "cualquier submódulo clonado usará su branch de rastreo remoto"
 
-#: builtin/index-pack.c:1594
-#, c-format
-msgid "Cannot open existing pack file '%s'"
-msgstr "No se puede abrir el archivo paquete existente '%s'"
+#: builtin/clone.c:151
+msgid "initialize sparse-checkout file to include only files at root"
+msgstr ""
+"inicializar archivo sparse-checkout para incluir solo archivos en la raíz"
 
-#: builtin/index-pack.c:1596
-#, c-format
-msgid "Cannot open existing pack idx file for '%s'"
-msgstr "No se puede abrir el índice del archivo paquete para '%s'"
+#: builtin/clone.c:287
+msgid ""
+"No directory name could be guessed.\n"
+"Please specify a directory on the command line"
+msgstr ""
+"No se pudo adivinar ningún nombre de directorio.\n"
+"Por favor especifique un directorio en la línea de comando"
 
-#: builtin/index-pack.c:1644
+#: builtin/clone.c:340
 #, c-format
-msgid "non delta: %d object"
-msgid_plural "non delta: %d objects"
-msgstr[0] "no delta: %d objeto"
-msgstr[1] "no delta: %d objetos"
+msgid "info: Could not add alternate for '%s': %s\n"
+msgstr "info: No se pudo agregar un alterno para '%s': %s\n"
 
-#: builtin/index-pack.c:1651
+#: builtin/clone.c:413
 #, c-format
-msgid "chain length = %d: %lu object"
-msgid_plural "chain length = %d: %lu objects"
-msgstr[0] "largo de cadena = %d: %lu objeto"
-msgstr[1] "largo de cadena = %d: %lu objetos"
-
-#: builtin/index-pack.c:1688
-msgid "Cannot come back to cwd"
-msgstr "No se puede regresar a cwd"
+msgid "%s exists and is not a directory"
+msgstr "%s existe pero no es un directorio"
 
-#: builtin/index-pack.c:1739 builtin/index-pack.c:1742
-#: builtin/index-pack.c:1758 builtin/index-pack.c:1762
+#: builtin/clone.c:430
 #, c-format
-msgid "bad %s"
-msgstr "mal %s"
-
-#: builtin/index-pack.c:1778
-msgid "--fix-thin cannot be used without --stdin"
-msgstr "--fix-thin no puede ser usada sin --stdin"
-
-#: builtin/index-pack.c:1780
-msgid "--stdin requires a git repository"
-msgstr "--stdin requiere un repositorio git"
-
-#: builtin/index-pack.c:1786
-msgid "--verify with no packfile name given"
-msgstr "--verify no recibió ningún nombre de archivo de paquete"
-
-#: builtin/index-pack.c:1836 builtin/unpack-objects.c:578
-msgid "fsck error in pack objects"
-msgstr "error de fsck en objetos paquete"
+msgid "failed to start iterator over '%s'"
+msgstr "falló al iniciar el iterador sobre '%s'"
 
-#: builtin/init-db.c:55
+#: builtin/clone.c:460
 #, c-format
-msgid "cannot stat '%s'"
-msgstr "no se pudo definir '%s'"
+msgid "failed to create link '%s'"
+msgstr "falló al crear link '%s'"
 
-#: builtin/init-db.c:61
+#: builtin/clone.c:464
 #, c-format
-msgid "cannot stat template '%s'"
-msgstr "no se pudo definir template '%s'"
+msgid "failed to copy file to '%s'"
+msgstr "falló al copiar archivo a '%s'"
 
-#: builtin/init-db.c:66
+#: builtin/clone.c:469
 #, c-format
-msgid "cannot opendir '%s'"
-msgstr "no se puede abrir directorio '%s'"
+msgid "failed to iterate over '%s'"
+msgstr "falló al iterar sobre '%s'"
 
-#: builtin/init-db.c:77
+#: builtin/clone.c:494
 #, c-format
-msgid "cannot readlink '%s'"
-msgstr "no se puede leer link '%s'"
+msgid "done.\n"
+msgstr "hecho.\n"
 
-#: builtin/init-db.c:79
-#, c-format
-msgid "cannot symlink '%s' '%s'"
-msgstr "no se puede crear symlink '%s' '%s'"
+#: builtin/clone.c:508
+msgid ""
+"Clone succeeded, but checkout failed.\n"
+"You can inspect what was checked out with 'git status'\n"
+"and retry with 'git restore --source=HEAD :/'\n"
+msgstr ""
+"Clonado exitoso, pero falló el checkout.\n"
+"Puedes inspeccionar a qué se hizo checkout con 'git status'\n"
+"y volver a intentarlo con 'git restore --source=HEAD :/'\n"
 
-#: builtin/init-db.c:85
+#: builtin/clone.c:585
 #, c-format
-msgid "cannot copy '%s' to '%s'"
-msgstr "no se puede copiar '%s' a '%s'"
+msgid "Could not find remote branch %s to clone."
+msgstr "No se pudo encontrar la rama remota %s para clonar."
 
-#: builtin/init-db.c:89
+#: builtin/clone.c:704
 #, c-format
-msgid "ignoring template %s"
-msgstr "ignorando template %s"
+msgid "unable to update %s"
+msgstr "incapaz de actualizar %s"
 
-#: builtin/init-db.c:120
-#, c-format
-msgid "templates not found in %s"
-msgstr "template no encontrado en %s"
+#: builtin/clone.c:752
+msgid "failed to initialize sparse-checkout"
+msgstr "falló al inicializar sparse-checkout"
 
-#: builtin/init-db.c:135
-#, c-format
-msgid "not copying templates from '%s': %s"
-msgstr "no se copian templates de '%s': %s"
+#: builtin/clone.c:775
+msgid "remote HEAD refers to nonexistent ref, unable to checkout.\n"
+msgstr ""
+"remoto HEAD refiere a un ref inexistente, no se puede hacer checkout.\n"
 
-#: builtin/init-db.c:328
-#, c-format
-msgid "unable to handle file type %d"
-msgstr "no es posible manejar el tipo de archivo %d"
+#: builtin/clone.c:806
+msgid "unable to checkout working tree"
+msgstr "no es posible realizar checkout en el árbol de trabajo"
 
-#: builtin/init-db.c:331
-#, c-format
-msgid "unable to move %s to %s"
-msgstr "no se puede mover %s a %s"
+#: builtin/clone.c:856
+msgid "unable to write parameters to config file"
+msgstr "no es posible escribir parámetros al archivo config"
 
-#: builtin/init-db.c:348 builtin/init-db.c:351
-#, c-format
-msgid "%s already exists"
-msgstr "%s ya existe"
+#: builtin/clone.c:919
+msgid "cannot repack to clean up"
+msgstr "no se puede reempaquetar para limpiar"
 
-#: builtin/init-db.c:404
-#, c-format
-msgid "Reinitialized existing shared Git repository in %s%s\n"
-msgstr "Reinicializado el repositorio Git compartido existente en %s%s\n"
+#: builtin/clone.c:921
+msgid "cannot unlink temporary alternates file"
+msgstr "no se puede desvincular archivos alternos temporales"
+
+#: builtin/clone.c:959 builtin/receive-pack.c:1948
+msgid "Too many arguments."
+msgstr "Muchos argumentos."
+
+#: builtin/clone.c:963
+msgid "You must specify a repository to clone."
+msgstr "Tienes que especificar un repositorio para clonar."
 
-#: builtin/init-db.c:405
+#: builtin/clone.c:976
 #, c-format
-msgid "Reinitialized existing Git repository in %s%s\n"
-msgstr "Reinicializado el repositorio Git existente en %s%s\n"
+msgid "--bare and --origin %s options are incompatible."
+msgstr "Las opciones --bare y --origin %s son incompatibles."
+
+#: builtin/clone.c:979
+msgid "--bare and --separate-git-dir are incompatible."
+msgstr "--bare y --separate-git-dir son incompatibles."
 
-#: builtin/init-db.c:409
+#: builtin/clone.c:992
 #, c-format
-msgid "Initialized empty shared Git repository in %s%s\n"
-msgstr "Inicializado repositorio Git compartido vacío en %s%s\n"
+msgid "repository '%s' does not exist"
+msgstr "repositorio '%s' no existe"
 
-#: builtin/init-db.c:410
+#: builtin/clone.c:998 builtin/fetch.c:1787
 #, c-format
-msgid "Initialized empty Git repository in %s%s\n"
-msgstr "Inicializado repositorio Git vacío en %s%s\n"
+msgid "depth %s is not a positive number"
+msgstr "profundidad %s no es un numero positivo"
 
-#: builtin/init-db.c:458
-msgid ""
-"git init [-q | --quiet] [--bare] [--template=<template-directory>] [--"
-"shared[=<permissions>]] [<directory>]"
-msgstr ""
-"git init [-q | --quiet] [--bare] [--template=<directorio-template>] [--"
-"shared[=<permisos>]] [<directorio>]"
+#: builtin/clone.c:1008
+#, c-format
+msgid "destination path '%s' already exists and is not an empty directory."
+msgstr "la ruta de destino '%s' ya existe y no es un directorio vacío."
 
-#: builtin/init-db.c:481
-msgid "permissions"
-msgstr "permisos"
+#: builtin/clone.c:1018
+#, c-format
+msgid "working tree '%s' already exists."
+msgstr "directorio de trabajo '%s' ya existe."
 
-#: builtin/init-db.c:482
-msgid "specify that the git repository is to be shared amongst several users"
-msgstr ""
-"especifica que el repositorio de git será compartido entre varios usuarios"
+#: builtin/clone.c:1033 builtin/clone.c:1054 builtin/difftool.c:271
+#: builtin/log.c:1866 builtin/worktree.c:302 builtin/worktree.c:334
+#, c-format
+msgid "could not create leading directories of '%s'"
+msgstr "no se pudo crear directorios principales de '%s'"
 
-#: builtin/init-db.c:525
+#: builtin/clone.c:1038
 #, c-format
-msgid "cannot chdir to %s"
-msgstr "no se puede aplicar chdir a %s"
+msgid "could not create work tree dir '%s'"
+msgstr "no se pudo crear un árbol de trabajo '%s'"
 
-#: builtin/init-db.c:546
+#: builtin/clone.c:1058
 #, c-format
-msgid ""
-"%s (or --work-tree=<directory>) not allowed without specifying %s (or --git-"
-"dir=<directory>)"
-msgstr ""
-"%s (o --work-tree=<directorio>) no se permite sin especificar %s (o --git-"
-"dir=<directorio>)"
+msgid "Cloning into bare repository '%s'...\n"
+msgstr "Clonando en un repositorio vacío '%s'...\n"
 
-#: builtin/init-db.c:574
+#: builtin/clone.c:1060
 #, c-format
-msgid "Cannot access work tree '%s'"
-msgstr "No se puede acceder al árbol de trabajo '%s'"
+msgid "Cloning into '%s'...\n"
+msgstr "Clonando en '%s'...\n"
 
-#: builtin/interpret-trailers.c:15
+#: builtin/clone.c:1084
 msgid ""
-"git interpret-trailers [--in-place] [--trim-empty] [(--trailer "
-"<token>[(=|:)<value>])...] [<file>...]"
+"clone --recursive is not compatible with both --reference and --reference-if-"
+"able"
 msgstr ""
-"git interpret-trailers [--in-place] [--trim-empty] [(--trailer "
-"<token>[(=|:)<valor>])...] [<archivo>...]"
-
-#: builtin/interpret-trailers.c:92
-msgid "edit files in place"
-msgstr "editar archivos en el lugar"
-
-#: builtin/interpret-trailers.c:93
-msgid "trim empty trailers"
-msgstr "cortar trailers vacíos"
-
-#: builtin/interpret-trailers.c:96
-msgid "where to place the new trailer"
-msgstr "donde colocar el nuevo trailer"
-
-#: builtin/interpret-trailers.c:98
-msgid "action if trailer already exists"
-msgstr "acción if trailer ya existe"
-
-#: builtin/interpret-trailers.c:100
-msgid "action if trailer is missing"
-msgstr "acción si falta el trailer"
+"clone --recursive no es compatible con --reference y --reference-if-able al "
+"mismo tiempo"
 
-#: builtin/interpret-trailers.c:102
-msgid "output only the trailers"
-msgstr "mostrar solo los trailers"
+#: builtin/clone.c:1148
+msgid "--depth is ignored in local clones; use file:// instead."
+msgstr "--depth es ignorada en clonaciones locales; usa file:// más bien."
 
-#: builtin/interpret-trailers.c:103
-msgid "do not apply config rules"
-msgstr "no aplicar reglas de configuración"
+#: builtin/clone.c:1150
+msgid "--shallow-since is ignored in local clones; use file:// instead."
+msgstr "--shallow-since es ignorado en el clon local; use file:// ."
 
-#: builtin/interpret-trailers.c:104
-msgid "join whitespace-continued values"
-msgstr "juntar valores con espacios en blanco contiguos"
+#: builtin/clone.c:1152
+msgid "--shallow-exclude is ignored in local clones; use file:// instead."
+msgstr "--shallow-exclude es ignorado en clones locales; use file://."
 
-#: builtin/interpret-trailers.c:105
-msgid "set parsing options"
-msgstr "configurar opciones de análisis"
+#: builtin/clone.c:1154
+msgid "--filter is ignored in local clones; use file:// instead."
+msgstr "--filter es ignorado en clones locales; usa file:// en su lugar."
 
-#: builtin/interpret-trailers.c:107
-msgid "trailer"
-msgstr "trailer"
+#: builtin/clone.c:1157
+msgid "source repository is shallow, ignoring --local"
+msgstr "repositorio fuente es superficial, ignorando --local"
 
-#: builtin/interpret-trailers.c:108
-msgid "trailer(s) to add"
-msgstr "trailer(s) para agregar"
+#: builtin/clone.c:1162
+msgid "--local is ignored"
+msgstr "--local es ignorado"
 
-#: builtin/interpret-trailers.c:117
-msgid "--trailer with --only-input does not make sense"
-msgstr "--trailer con --only-input no tiene sentido"
+#: builtin/clone.c:1237 builtin/clone.c:1245
+#, c-format
+msgid "Remote branch %s not found in upstream %s"
+msgstr "Rama remota %s no encontrada en upstream %s"
 
-#: builtin/interpret-trailers.c:127
-msgid "no input file given for in-place editing"
-msgstr "no se entregó archivo de entrada para edición en lugar"
+#: builtin/clone.c:1248
+msgid "You appear to have cloned an empty repository."
+msgstr "Pareces haber clonado un repositorio sin contenido."
 
-#: builtin/log.c:48
-msgid "git log [<options>] [<revision-range>] [[--] <path>...]"
-msgstr "git log [<opciones>] [<rango-de-revisión>] [[--] <ruta>...]"
+#: builtin/column.c:10
+msgid "git column [<options>]"
+msgstr "git column [<opciones>]"
 
-#: builtin/log.c:49
-msgid "git show [<options>] <object>..."
-msgstr "git show [<opciones>] <objeto>..."
+#: builtin/column.c:27
+msgid "lookup config vars"
+msgstr "revisa las variables de configuraciones"
 
-#: builtin/log.c:93
-#, c-format
-msgid "invalid --decorate option: %s"
-msgstr "opción --decorate inválida: %s"
+#: builtin/column.c:28 builtin/column.c:29
+msgid "layout to use"
+msgstr "capa a usar"
 
-#: builtin/log.c:153
-msgid "suppress diff output"
-msgstr "suprimir salida de diff"
+#: builtin/column.c:30
+msgid "Maximum width"
+msgstr "Ancho máximo"
 
-#: builtin/log.c:154
-msgid "show source"
-msgstr "mostrar fuente"
+#: builtin/column.c:31
+msgid "Padding space on left border"
+msgstr "Realizando padding en el borde izquierdo"
 
-#: builtin/log.c:155
-msgid "Use mail map file"
-msgstr "Usar archivo de mapa de mail"
+#: builtin/column.c:32
+msgid "Padding space on right border"
+msgstr "Realizando padding en el borde derecho"
 
-#: builtin/log.c:157
-msgid "only decorate refs that match <pattern>"
-msgstr "solo decorar refs que concuerden con <patrón>"
+#: builtin/column.c:33
+msgid "Padding space between columns"
+msgstr "Realizando padding entre columnas"
 
-#: builtin/log.c:159
-msgid "do not decorate refs that match <pattern>"
-msgstr "no decorar refs que concuerden con <patrón>"
+#: builtin/column.c:51
+msgid "--command must be the first argument"
+msgstr "--command debe ser el primer argumento"
 
-#: builtin/log.c:160
-msgid "decorate options"
-msgstr "opciones de decorado"
+#: builtin/commit-tree.c:18
+msgid ""
+"git commit-tree [(-p <parent>)...] [-S[<keyid>]] [(-m <message>)...] [(-F "
+"<file>)...] <tree>"
+msgstr ""
+"git commit-tree [(-p <padre>)...] [-S[<keyid>]] [(-m <mensaje>)...] [(-F "
+"<archivo>)...] <árbol>"
 
-#: builtin/log.c:163
-msgid "Process line range n,m in file, counting from 1"
-msgstr "Procesar rango de líneas n,m en archivo, contando desde 1"
+#: builtin/commit-tree.c:31
+#, c-format
+msgid "duplicate parent %s ignored"
+msgstr "padre duplicado %s ignorado"
 
-#: builtin/log.c:259
+#: builtin/commit-tree.c:56 builtin/commit-tree.c:136 builtin/log.c:526
 #, c-format
-msgid "Final output: %d %s\n"
-msgstr "Salida final: %d %s\n"
+msgid "not a valid object name %s"
+msgstr "no es un nombre de objeto válido %s"
 
-#: builtin/log.c:510
+#: builtin/commit-tree.c:93
 #, c-format
-msgid "git show %s: bad file"
-msgstr "git show %s: mal archivo"
+msgid "git commit-tree: failed to open '%s'"
+msgstr "git commit-tree: falló al abrir '%s'"
 
-#: builtin/log.c:525 builtin/log.c:619
+#: builtin/commit-tree.c:96
 #, c-format
-msgid "Could not read object %s"
-msgstr "No se pudo leer objeto %s"
+msgid "git commit-tree: failed to read '%s'"
+msgstr "git commit-tree: falló al leer '%s'"
 
-#: builtin/log.c:643
+#: builtin/commit-tree.c:98
 #, c-format
-msgid "Unknown type: %d"
-msgstr "Tipo desconocido: %d"
+msgid "git commit-tree: failed to close '%s'"
+msgstr "git commit-tree: falló al cerrar '%s'"
 
-#: builtin/log.c:764
-msgid "format.headers without value"
-msgstr "formate.headers. sin valor"
+#: builtin/commit-tree.c:111
+msgid "parent"
+msgstr "padre"
 
-#: builtin/log.c:865
-msgid "name of output directory is too long"
-msgstr "nombre del directorio de salida es muy largo"
+#: builtin/commit-tree.c:112
+msgid "id of a parent commit object"
+msgstr "id del objeto commit padre"
 
-#: builtin/log.c:881
-#, c-format
-msgid "Cannot open patch file %s"
-msgstr "No se puede abrir archivo patch %s"
+#: builtin/commit-tree.c:114 builtin/commit.c:1496 builtin/merge.c:270
+#: builtin/notes.c:409 builtin/notes.c:575 builtin/stash.c:1469
+#: builtin/tag.c:412
+msgid "message"
+msgstr "mensaje"
 
-#: builtin/log.c:898
-msgid "Need exactly one range."
-msgstr "Exactamente un rango necesario."
+#: builtin/commit-tree.c:115 builtin/commit.c:1496
+msgid "commit message"
+msgstr "mensaje del commit"
 
-#: builtin/log.c:908
-msgid "Not a range."
-msgstr "No es un rango."
+#: builtin/commit-tree.c:118
+msgid "read commit log message from file"
+msgstr "leer mensaje de commit desde un archivo"
 
-#: builtin/log.c:1014
-msgid "Cover letter needs email format"
-msgstr "Letras de portada necesita formato email"
+#: builtin/commit-tree.c:121 builtin/commit.c:1508 builtin/merge.c:287
+#: builtin/pull.c:195 builtin/revert.c:118
+msgid "GPG sign commit"
+msgstr "Firmar commit con GPG"
 
-#: builtin/log.c:1095
-#, c-format
-msgid "insane in-reply-to: %s"
-msgstr "insano in-reply-to: %s"
+#: builtin/commit-tree.c:133
+msgid "must give exactly one tree"
+msgstr "tiene que dar exactamente un árbol"
+
+#: builtin/commit-tree.c:140
+msgid "git commit-tree: failed to read"
+msgstr "git commit-tree: falló al leer"
 
-#: builtin/log.c:1122
-msgid "git format-patch [<options>] [<since> | <revision-range>]"
-msgstr "git format-patch [<opciones>] [<desde> | <rango-de-revisiones>]"
+#: builtin/commit.c:41
+msgid "git commit [<options>] [--] <pathspec>..."
+msgstr "git commit [<opciones>] [--] <especificación-de-ruta>..."
 
-#: builtin/log.c:1172
-msgid "Two output directories?"
-msgstr "Dos directorios de salida?"
+#: builtin/commit.c:46
+msgid "git status [<options>] [--] <pathspec>..."
+msgstr "git status [<opciones>] [--] <especificación-de-ruta>..."
 
-#: builtin/log.c:1279 builtin/log.c:1932 builtin/log.c:1934 builtin/log.c:1946
-#, c-format
-msgid "Unknown commit %s"
-msgstr "Commit desconocido %s"
+#: builtin/commit.c:51
+msgid ""
+"You asked to amend the most recent commit, but doing so would make\n"
+"it empty. You can repeat your command with --allow-empty, or you can\n"
+"remove the commit entirely with \"git reset HEAD^\".\n"
+msgstr ""
+"Has solicitado un amend en tu commit más reciente, pero hacerlo lo \n"
+"vaciaría. Puedes repetir el comando con --alow-empty, o puedes eliminar\n"
+"el commit completamente con \"git reset HEAD^\".\n"
 
-#: builtin/log.c:1289 builtin/notes.c:887 builtin/tag.c:523
-#, c-format
-msgid "Failed to resolve '%s' as a valid ref."
-msgstr "Falló al resolver '%s' como una ref válida."
+#: builtin/commit.c:56
+msgid ""
+"The previous cherry-pick is now empty, possibly due to conflict resolution.\n"
+"If you wish to commit it anyway, use:\n"
+"\n"
+"    git commit --allow-empty\n"
+"\n"
+msgstr ""
+"El cherry-pick anterior ahora está vacío, posiblemente por un conflicto de "
+"resolución.\n"
+"Si deseas realizar un commit de todas maneras, usa:\n"
+"\n"
+"    git commit --allow-empty\n"
+"\n"
 
-#: builtin/log.c:1294
-msgid "Could not find exact merge base."
-msgstr "No se pudo encontrar una base de fusión."
+#: builtin/commit.c:63
+msgid "Otherwise, please use 'git cherry-pick --skip'\n"
+msgstr "Caso contrario, por favor usa 'git cherry-pick --skip'\n"
 
-#: builtin/log.c:1298
+#: builtin/commit.c:66
 msgid ""
-"Failed to get upstream, if you want to record base commit automatically,\n"
-"please use git branch --set-upstream-to to track a remote branch.\n"
-"Or you could specify base commit by --base=<base-commit-id> manually."
+"and then use:\n"
+"\n"
+"    git cherry-pick --continue\n"
+"\n"
+"to resume cherry-picking the remaining commits.\n"
+"If you wish to skip this commit, use:\n"
+"\n"
+"    git cherry-pick --skip\n"
+"\n"
 msgstr ""
-"Falló al conseguir upstream, si quiere grabar un commit base de manera "
-"automática,\n"
-"por favor use git branch --set-upstream-to para rastrear una rama remota.\n"
-"O puede especificar un commit base mediante --base=<id-commit-base> "
-"manualmente."
-
-#: builtin/log.c:1318
-msgid "Failed to find exact merge base"
-msgstr "Falló al encontrar una base de fusión exacta"
-
-#: builtin/log.c:1329
-msgid "base commit should be the ancestor of revision list"
-msgstr "el commit base debe ser el ancestro de la lista de revisión"
+"y luego usa:\n"
+"\n"
+"   git cherry-pick --continue\n"
+"\n"
+"para resumir el cherry-pick con los commits faltantes.\n"
+"Si deseas saltar el commit, usa:\n"
+"\n"
+"     git cherry-pick --skip\n"
+"\n"
 
-#: builtin/log.c:1333
-msgid "base commit shouldn't be in revision list"
-msgstr "el commit base no debe estar en la lista de revisión"
+#: builtin/commit.c:315
+msgid "failed to unpack HEAD tree object"
+msgstr "falló al desempaquetar objeto del árbol HEAD"
 
-#: builtin/log.c:1382
-msgid "cannot get patch id"
-msgstr "no se puede obtener id de patch"
+#: builtin/commit.c:351
+msgid "--pathspec-from-file with -a does not make sense"
+msgstr "--pathspec-from-file con -a no tiene sentido"
 
-#: builtin/log.c:1441
-msgid "use [PATCH n/m] even with a single patch"
-msgstr "use [PATCH n/m] incluso con un único parche"
+#: builtin/commit.c:364
+msgid "No paths with --include/--only does not make sense."
+msgstr "No hay rutas con --include/--only no tiene sentido."
 
-#: builtin/log.c:1444
-msgid "use [PATCH] even with multiple patches"
-msgstr "use [PATCH] incluso con múltiples parches"
+#: builtin/commit.c:376
+msgid "unable to create temporary index"
+msgstr "no es posible crear un índice temporal"
 
-#: builtin/log.c:1448
-msgid "print patches to standard out"
-msgstr "mostrar parches en standard out"
+#: builtin/commit.c:382
+msgid "interactive add failed"
+msgstr "adición interactiva fallida"
 
-#: builtin/log.c:1450
-msgid "generate a cover letter"
-msgstr "generar letra de cover"
+#: builtin/commit.c:396
+msgid "unable to update temporary index"
+msgstr "no es posible actualizar el índice temporal"
 
-#: builtin/log.c:1452
-msgid "use simple number sequence for output file names"
-msgstr ""
-"usar una secuencia simple de números para salida de nombres de archivos"
+#: builtin/commit.c:398
+msgid "Failed to update main cache tree"
+msgstr "Falló al actualizar el cache principal del árbol"
 
-#: builtin/log.c:1453
-msgid "sfx"
-msgstr "sfx"
+#: builtin/commit.c:423 builtin/commit.c:446 builtin/commit.c:492
+msgid "unable to write new_index file"
+msgstr "no es posible escribir archivo new_index"
 
-#: builtin/log.c:1454
-msgid "use <sfx> instead of '.patch'"
-msgstr "use <sfx> en lugar de '.patch'"
+#: builtin/commit.c:475
+msgid "cannot do a partial commit during a merge."
+msgstr "no se puede realizar un commit parcial durante una fusión."
 
-#: builtin/log.c:1456
-msgid "start numbering patches at <n> instead of 1"
-msgstr "comenzar a numerar los parches desde <n> en lugar de 1"
+#: builtin/commit.c:477
+msgid "cannot do a partial commit during a cherry-pick."
+msgstr "no se puede realizar un commit parcial durante un cherry-pick."
 
-#: builtin/log.c:1458
-msgid "mark the series as Nth re-roll"
-msgstr "marcar las series como Nth re-roll"
+#: builtin/commit.c:485
+msgid "cannot read the index"
+msgstr "no se puede leer el índice"
 
-#: builtin/log.c:1460
-msgid "Use [RFC PATCH] instead of [PATCH]"
-msgstr "Use [RFC PATCH] en lugar de [PATCH]"
+#: builtin/commit.c:504
+msgid "unable to write temporary index file"
+msgstr "no es posible escribir el índice temporal"
 
-#: builtin/log.c:1463
-msgid "Use [<prefix>] instead of [PATCH]"
-msgstr "Use [<prefijo>] en lugar de [PATCH]"
+#: builtin/commit.c:602
+#, c-format
+msgid "commit '%s' lacks author header"
+msgstr "commit '%s' requiere cabecera de autor"
 
-#: builtin/log.c:1466
-msgid "store resulting files in <dir>"
-msgstr "guardar archivos resultantes en <dir>"
+#: builtin/commit.c:604
+#, c-format
+msgid "commit '%s' has malformed author line"
+msgstr "el commit '%s' tiene una línea de autor mal formada"
 
-#: builtin/log.c:1469
-msgid "don't strip/add [PATCH]"
-msgstr "no cortar/agregar [PATCH]"
+#: builtin/commit.c:623
+msgid "malformed --author parameter"
+msgstr "parámetro --author mal formado"
 
-#: builtin/log.c:1472
-msgid "don't output binary diffs"
-msgstr "no mostrar diffs binarios"
+#: builtin/commit.c:676
+msgid ""
+"unable to select a comment character that is not used\n"
+"in the current commit message"
+msgstr ""
+"no es posible seleccionar un carácter de comentario que no es usado\n"
+"en el mensaje de commit actual"
 
-#: builtin/log.c:1474
-msgid "output all-zero hash in From header"
-msgstr "salida como hash de todos-ceros en la cabecera From"
+#: builtin/commit.c:714 builtin/commit.c:747 builtin/commit.c:1092
+#, c-format
+msgid "could not lookup commit %s"
+msgstr "no se pudo revisar el commit %s"
 
-#: builtin/log.c:1476
-msgid "don't include a patch matching a commit upstream"
-msgstr "no incluya un parche que coincida con un commit en upstream"
+#: builtin/commit.c:726 builtin/shortlog.c:319
+#, c-format
+msgid "(reading log message from standard input)\n"
+msgstr "(leyendo mensajes de logs desde standard input)\n"
 
-#: builtin/log.c:1478
-msgid "show patch format instead of default (patch + stat)"
-msgstr "mostrar formato de parche en lugar del default (parche + stat)"
+#: builtin/commit.c:728
+msgid "could not read log from standard input"
+msgstr "no se pudo leer log desde standard input"
 
-#: builtin/log.c:1480
-msgid "Messaging"
-msgstr "Mensajeando"
+#: builtin/commit.c:732
+#, c-format
+msgid "could not read log file '%s'"
+msgstr "no se pudo leer el log '%s'"
 
-#: builtin/log.c:1481
-msgid "header"
-msgstr "cabezal"
+#: builtin/commit.c:763 builtin/commit.c:779
+msgid "could not read SQUASH_MSG"
+msgstr "no se pudo leer SQUASH_MSG"
 
-#: builtin/log.c:1482
-msgid "add email header"
-msgstr "agregar cabecera email"
+#: builtin/commit.c:770
+msgid "could not read MERGE_MSG"
+msgstr "no se pudo leer MERGE_MSG"
 
-#: builtin/log.c:1483 builtin/log.c:1485
-msgid "email"
-msgstr "email"
+#: builtin/commit.c:830
+msgid "could not write commit template"
+msgstr "no se pudo escribir el template del commit"
 
-#: builtin/log.c:1483
-msgid "add To: header"
-msgstr "agregar cabecera To:"
+#: builtin/commit.c:849
+#, c-format
+msgid ""
+"\n"
+"It looks like you may be committing a merge.\n"
+"If this is not correct, please remove the file\n"
+"\t%s\n"
+"and try again.\n"
+msgstr ""
+"\n"
+"Parece que estás haciendo un commit con una fusión dentro.\n"
+"Si esto no es correcto, por favor elimina el archivo\n"
+"\t%s\n"
+"y vuelve a intentar.\n"
 
-#: builtin/log.c:1485
-msgid "add Cc: header"
-msgstr "agregar cabecera Cc:"
+#: builtin/commit.c:854
+#, c-format
+msgid ""
+"\n"
+"It looks like you may be committing a cherry-pick.\n"
+"If this is not correct, please remove the file\n"
+"\t%s\n"
+"and try again.\n"
+msgstr ""
+"\n"
+"Parece que puedes estar haciendo un commit a un cherry-pick.\n"
+"Si esto no es correcto, por favor elimina el archivo\n"
+"\t%s\n"
+"y vuelve a intentar.\n"
 
-#: builtin/log.c:1487
-msgid "ident"
-msgstr "ident"
+#: builtin/commit.c:867
+#, c-format
+msgid ""
+"Please enter the commit message for your changes. Lines starting\n"
+"with '%c' will be ignored, and an empty message aborts the commit.\n"
+msgstr ""
+"Por favor ingresa el mensaje del commit para tus cambios. Las\n"
+" líneas que comiencen con '%c' serán ignoradas, y un mensaje\n"
+" vacío aborta el commit.\n"
 
-#: builtin/log.c:1488
-msgid "set From address to <ident> (or committer ident if absent)"
+#: builtin/commit.c:875
+#, c-format
+msgid ""
+"Please enter the commit message for your changes. Lines starting\n"
+"with '%c' will be kept; you may remove them yourself if you want to.\n"
+"An empty message aborts the commit.\n"
 msgstr ""
-"configurar dirección From a <ident> ( o identidad de committer si está "
-"ausente)"
+"Por favor ingresa el mensaje del commit para tus cambios. Las\n"
+" líneas que comiencen con '%c' serán guardadas; puede eliminarlas\n"
+" usted mismo si lo desea.\n"
+"Un mensaje vacío aborta el commit.\n"
 
-#: builtin/log.c:1490
-msgid "message-id"
-msgstr "id de mensaje"
+#: builtin/commit.c:892
+#, c-format
+msgid "%sAuthor:    %.*s <%.*s>"
+msgstr "%sAutor:     %.*s <%.*s>"
 
-#: builtin/log.c:1491
-msgid "make first mail a reply to <message-id>"
-msgstr "hacer primer mail una respuesta a <id de mensaje>"
+#: builtin/commit.c:900
+#, c-format
+msgid "%sDate:      %s"
+msgstr "%sFecha:     %s"
 
-#: builtin/log.c:1492 builtin/log.c:1495
-msgid "boundary"
-msgstr "límite"
+#: builtin/commit.c:907
+#, c-format
+msgid "%sCommitter: %.*s <%.*s>"
+msgstr "%sCommitter: %.*s <%.*s>"
 
-#: builtin/log.c:1493
-msgid "attach the patch"
-msgstr "adjuntar el parche"
+#: builtin/commit.c:925
+msgid "Cannot read index"
+msgstr "No se puede leer el índice"
 
-#: builtin/log.c:1496
-msgid "inline the patch"
-msgstr "poner el parche en línea"
+#: builtin/commit.c:992
+msgid "Error building trees"
+msgstr "Error al construir los árboles"
 
-#: builtin/log.c:1500
-msgid "enable message threading, styles: shallow, deep"
-msgstr "habilitar hilos de mensajes, estilos: superficial, profundo"
+#: builtin/commit.c:1006 builtin/tag.c:275
+#, c-format
+msgid "Please supply the message using either -m or -F option.\n"
+msgstr "Por favor suministra el mensaje usando las opciones -m o -F.\n"
 
-#: builtin/log.c:1502
-msgid "signature"
-msgstr "firma"
+#: builtin/commit.c:1050
+#, c-format
+msgid "--author '%s' is not 'Name <email>' and matches no existing author"
+msgstr ""
+"--author '%s' no está en el formato 'Name <email>' y no concuerda con ningún "
+"autor existente"
 
-#: builtin/log.c:1503
-msgid "add a signature"
-msgstr "agregar una firma"
+#: builtin/commit.c:1064
+#, c-format
+msgid "Invalid ignored mode '%s'"
+msgstr "Modo ignorado inválido '%s'"
 
-#: builtin/log.c:1504
-msgid "base-commit"
-msgstr "commit-base"
+#: builtin/commit.c:1082 builtin/commit.c:1322
+#, c-format
+msgid "Invalid untracked files mode '%s'"
+msgstr "Modo inválido de los archivos no rastreados '%s'"
 
-#: builtin/log.c:1505
-msgid "add prerequisite tree info to the patch series"
-msgstr ""
-"agregar información de árbol de requisitos previos a la serie de parches"
+#: builtin/commit.c:1122
+msgid "--long and -z are incompatible"
+msgstr "--long y -z son incompatibles"
 
-#: builtin/log.c:1507
-msgid "add a signature from a file"
-msgstr "agregar una firma de un archivo"
+#: builtin/commit.c:1166
+msgid "Using both --reset-author and --author does not make sense"
+msgstr "Usar ambos --reset-author y --author no tiene sentido"
 
-#: builtin/log.c:1508
-msgid "don't print the patch filenames"
-msgstr "no mostrar los nombres de archivos de los parches"
+#: builtin/commit.c:1175
+msgid "You have nothing to amend."
+msgstr "No tienes nada que enmendar."
 
-#: builtin/log.c:1510
-msgid "show progress while generating patches"
-msgstr "mostrar medidor de progreso mientras se generan los parches"
+#: builtin/commit.c:1178
+msgid "You are in the middle of a merge -- cannot amend."
+msgstr "Estás en medio de una fusión -- no puedes enmendar."
 
-#: builtin/log.c:1585
-#, c-format
-msgid "invalid ident line: %s"
-msgstr "línea de identificación inválida: %s"
+#: builtin/commit.c:1180
+msgid "You are in the middle of a cherry-pick -- cannot amend."
+msgstr "Está en medio de un cherry-pick -- no se puede enmendar."
 
-#: builtin/log.c:1600
-msgid "-n and -k are mutually exclusive."
-msgstr "-n y -k son mutuamente exclusivas."
-
-#: builtin/log.c:1602
-msgid "--subject-prefix/--rfc and -k are mutually exclusive."
-msgstr "--subject-prefix/--rfc y -k son mutuamente exclusivos."
+#: builtin/commit.c:1183
+msgid "Options --squash and --fixup cannot be used together"
+msgstr "Opciones --squash y --fixup no pueden ser usadas juntas"
 
-#: builtin/log.c:1610
-msgid "--name-only does not make sense"
-msgstr "--name-only no tiene sentido"
+#: builtin/commit.c:1193
+msgid "Only one of -c/-C/-F/--fixup can be used."
+msgstr "Solo uno de -c/-C/-F/--fixup puede ser usado."
 
-#: builtin/log.c:1612
-msgid "--name-status does not make sense"
-msgstr "--name-status no tiene sentido"
+#: builtin/commit.c:1195
+msgid "Option -m cannot be combined with -c/-C/-F."
+msgstr "La opción -m no puede ser combinada con -c/-C/-F."
 
-#: builtin/log.c:1614
-msgid "--check does not make sense"
-msgstr "--check no tiene sentido"
+#: builtin/commit.c:1203
+msgid "--reset-author can be used only with -C, -c or --amend."
+msgstr "--reset-author sólo puede ser usada con -C, -c o --amend."
 
-#: builtin/log.c:1646
-msgid "standard output, or directory, which one?"
-msgstr "salida standard, o directorio, cual?"
+#: builtin/commit.c:1220
+msgid "Only one of --include/--only/--all/--interactive/--patch can be used."
+msgstr ""
+"Solo uno de --include/--only/--all/--interactive/--patch puede ser usado."
 
-#: builtin/log.c:1648
+#: builtin/commit.c:1226
 #, c-format
-msgid "Could not create directory '%s'"
-msgstr "No se pudo crear el directorio '%s'"
+msgid "paths '%s ...' with -a does not make sense"
+msgstr "paths '%s ...' con -a no tiene sentido"
 
-#: builtin/log.c:1741
-#, c-format
-msgid "unable to read signature file '%s'"
-msgstr "no se puede leer la firma del archivo '%s'"
+#: builtin/commit.c:1357 builtin/commit.c:1519
+msgid "show status concisely"
+msgstr "mostrar status de manera concisa"
 
-#: builtin/log.c:1773
-msgid "Generating patches"
-msgstr "Generando parches"
+#: builtin/commit.c:1359 builtin/commit.c:1521
+msgid "show branch information"
+msgstr "mostrar información de la rama"
 
-#: builtin/log.c:1817
-msgid "Failed to create output files"
-msgstr "Falló al crear los archivos de salida"
+#: builtin/commit.c:1361
+msgid "show stash information"
+msgstr "mostrar información del stash"
 
-#: builtin/log.c:1867
-msgid "git cherry [-v] [<upstream> [<head> [<limit>]]]"
-msgstr "git cherry [-v] [<upstream> [<head> [<límite>]]]"
+#: builtin/commit.c:1363 builtin/commit.c:1523
+msgid "compute full ahead/behind values"
+msgstr "calcular todos los valores delante/atrás"
 
-#: builtin/log.c:1921
-#, c-format
-msgid ""
-"Could not find a tracked remote branch, please specify <upstream> manually.\n"
-msgstr ""
-"No se pudo encontrar una rama remota rastreada, por favor especifique "
-"<upstream> manualmente.\n"
+#: builtin/commit.c:1365
+msgid "version"
+msgstr "version"
 
-#: builtin/ls-files.c:468
-msgid "git ls-files [<options>] [<file>...]"
-msgstr "git ls-files [<opciones>] [<archivo>...]"
+#: builtin/commit.c:1365 builtin/commit.c:1525 builtin/push.c:549
+#: builtin/worktree.c:650
+msgid "machine-readable output"
+msgstr "output formato-maquina"
 
-#: builtin/ls-files.c:517
-msgid "identify the file status with tags"
-msgstr "identifique el estado del archivo con tags"
-
-#: builtin/ls-files.c:519
-msgid "use lowercase letters for 'assume unchanged' files"
-msgstr "usar letras minúsculas para archivos 'asumidos sin cambios'"
-
-#: builtin/ls-files.c:521
-msgid "use lowercase letters for 'fsmonitor clean' files"
-msgstr "usar letras minúsculas para archivos de 'fsmonitor clean'"
+#: builtin/commit.c:1368 builtin/commit.c:1527
+msgid "show status in long format (default)"
+msgstr "mostrar status en formato largo (default)"
 
-#: builtin/ls-files.c:523
-msgid "show cached files in the output (default)"
-msgstr "mostrar archivos en caché en la salida (default)"
+#: builtin/commit.c:1371 builtin/commit.c:1530
+msgid "terminate entries with NUL"
+msgstr "terminar entradas con NUL"
 
-#: builtin/ls-files.c:525
-msgid "show deleted files in the output"
-msgstr "mostrar archivos borrados en la salida"
+#: builtin/commit.c:1373 builtin/commit.c:1377 builtin/commit.c:1533
+#: builtin/fast-export.c:1153 builtin/fast-export.c:1156
+#: builtin/fast-export.c:1159 builtin/rebase.c:1525 parse-options.h:336
+msgid "mode"
+msgstr "modo"
 
-#: builtin/ls-files.c:527
-msgid "show modified files in the output"
-msgstr "mostrar archivos modificados en la salida"
+#: builtin/commit.c:1374 builtin/commit.c:1533
+msgid "show untracked files, optional modes: all, normal, no. (Default: all)"
+msgstr ""
+"mostrar archivos sin seguimiento, modos opcionales: all, normal, no. "
+"(Predeterminado: all)"
 
-#: builtin/ls-files.c:529
-msgid "show other files in the output"
-msgstr "mostrar otros archivos en la salida"
+#: builtin/commit.c:1378
+msgid ""
+"show ignored files, optional modes: traditional, matching, no. (Default: "
+"traditional)"
+msgstr ""
+"mostrar archivos ignorados, modos opcionales: traditional, matching, no. "
+"(Predeterminado: traditional)"
 
-#: builtin/ls-files.c:531
-msgid "show ignored files in the output"
-msgstr "mostrar archivos ignorados en la salida"
+#: builtin/commit.c:1380 parse-options.h:192
+msgid "when"
+msgstr "cuando"
 
-#: builtin/ls-files.c:534
-msgid "show staged contents' object name in the output"
+#: builtin/commit.c:1381
+msgid ""
+"ignore changes to submodules, optional when: all, dirty, untracked. "
+"(Default: all)"
 msgstr ""
-"mostrar contenido de nombres de objetos en el área de stage en la salida"
-
-#: builtin/ls-files.c:536
-msgid "show files on the filesystem that need to be removed"
-msgstr "mostrar archivos en el filesystem que necesitan ser borrados"
+"ignorar cambios en submódulos, opcional cuando: all,dirty,untracked. "
+"(Default: all)"
 
-#: builtin/ls-files.c:538
-msgid "show 'other' directories' names only"
-msgstr "mostrar solo nombres de 'directorios otros'"
+#: builtin/commit.c:1383
+msgid "list untracked files in columns"
+msgstr "listar en columnas los archivos sin seguimiento"
 
-#: builtin/ls-files.c:540
-msgid "show line endings of files"
-msgstr "mostrar finales de línea de archivos"
+#: builtin/commit.c:1384
+msgid "do not detect renames"
+msgstr "no detectar renombrados"
 
-#: builtin/ls-files.c:542
-msgid "don't show empty directories"
-msgstr "no mostrar directorios vacíos"
+#: builtin/commit.c:1386
+msgid "detect renames, optionally set similarity index"
+msgstr "detectar renombres, opcionalmente configurar similaridad de índice"
 
-#: builtin/ls-files.c:545
-msgid "show unmerged files in the output"
-msgstr "mostrar archivos no fusionados en la salida"
+#: builtin/commit.c:1406
+msgid "Unsupported combination of ignored and untracked-files arguments"
+msgstr ""
+"Combinación de argumentos de archivos ignorados y no rastreados no soportada"
 
-#: builtin/ls-files.c:547
-msgid "show resolve-undo information"
-msgstr "mostrar información resolver-deshacer"
+#: builtin/commit.c:1489
+msgid "suppress summary after successful commit"
+msgstr "suprime summary tras un commit exitoso"
 
-#: builtin/ls-files.c:549
-msgid "skip files matching pattern"
-msgstr "saltar archivos que concuerden con el patrón"
+#: builtin/commit.c:1490
+msgid "show diff in commit message template"
+msgstr "mostrar diff en el template del mensaje de commit"
 
-#: builtin/ls-files.c:552
-msgid "exclude patterns are read from <file>"
-msgstr "excluir patrones leídos de <archivo>"
+#: builtin/commit.c:1492
+msgid "Commit message options"
+msgstr "Opciones para el mensaje del commit"
 
-#: builtin/ls-files.c:555
-msgid "read additional per-directory exclude patterns in <file>"
-msgstr ""
-"leer patrones de exclusión de manera adicional por directorio en <archivo>"
+#: builtin/commit.c:1493 builtin/merge.c:274 builtin/tag.c:414
+msgid "read message from file"
+msgstr "leer mensaje desde un archivo"
 
-#: builtin/ls-files.c:557
-msgid "add the standard git exclusions"
-msgstr "agregar las exclusiones standard de git"
+#: builtin/commit.c:1494
+msgid "author"
+msgstr "autor"
 
-#: builtin/ls-files.c:560
-msgid "make the output relative to the project top directory"
-msgstr "hacer la salida relativa al directorio principal del proyecto"
+#: builtin/commit.c:1494
+msgid "override author for commit"
+msgstr "sobrescribe el autor del commit"
 
-#: builtin/ls-files.c:563
-msgid "recurse through submodules"
-msgstr "recurrir a través de submódulos"
+#: builtin/commit.c:1495 builtin/gc.c:538
+msgid "date"
+msgstr "fecha"
 
-#: builtin/ls-files.c:565
-msgid "if any <file> is not in the index, treat this as an error"
-msgstr "si cualquier <archivo> no está en el índice, tratarlo como un error"
+#: builtin/commit.c:1495
+msgid "override date for commit"
+msgstr "sobrescribe la fecha del commit"
 
-#: builtin/ls-files.c:566
-msgid "tree-ish"
-msgstr "árbol-ismo"
+#: builtin/commit.c:1497 builtin/commit.c:1498 builtin/commit.c:1499
+#: builtin/commit.c:1500 parse-options.h:328 ref-filter.h:92
+msgid "commit"
+msgstr "confirmar"
 
-#: builtin/ls-files.c:567
-msgid "pretend that paths removed since <tree-ish> are still present"
-msgstr ""
-"fingir que las rutas han sido borradas ya que todavía hay <árbol-ismos> "
-"presentes"
+#: builtin/commit.c:1497
+msgid "reuse and edit message from specified commit"
+msgstr "reusar y editar el mensaje de un commit especifico"
 
-#: builtin/ls-files.c:569
-msgid "show debugging data"
-msgstr "mostrar data de debug"
+#: builtin/commit.c:1498
+msgid "reuse message from specified commit"
+msgstr "reusar el mensaje de un commit especifico"
 
-#: builtin/ls-remote.c:9
-msgid ""
-"git ls-remote [--heads] [--tags] [--refs] [--upload-pack=<exec>]\n"
-"                     [-q | --quiet] [--exit-code] [--get-url]\n"
-"                     [--symref] [<repository> [<refs>...]]"
+#: builtin/commit.c:1499
+msgid "use autosquash formatted message to fixup specified commit"
 msgstr ""
-"git ls-remote [--heads] [--tags] [--refs] [--upload-pack=<exec>]\n"
-"                     [-q | --quiet] [--exit-code] [--get-url]\n"
-"                     [--symref] [<repositorio> [<refs>...]]"
+"usar mensaje de formato autosquash para arreglar el commit especificado"
 
-#: builtin/ls-remote.c:59
-msgid "do not print remote URL"
-msgstr "no mostrar el URL remoto"
+#: builtin/commit.c:1500
+msgid "use autosquash formatted message to squash specified commit"
+msgstr ""
+"usar el mensaje de formato autosquash para realizar squash  al commit "
+"especificado"
 
-#: builtin/ls-remote.c:60 builtin/ls-remote.c:62
-msgid "exec"
-msgstr "ejecutar"
+#: builtin/commit.c:1501
+msgid "the commit is authored by me now (used with -C/-c/--amend)"
+msgstr "el autor del commit soy yo ahora (usado con -C/-c/--amend)"
 
-#: builtin/ls-remote.c:61 builtin/ls-remote.c:63
-msgid "path of git-upload-pack on the remote host"
-msgstr "ruta de git-upload-pack en el host remoto"
+#: builtin/commit.c:1502 builtin/log.c:1634 builtin/merge.c:289
+#: builtin/pull.c:164 builtin/revert.c:110
+msgid "add Signed-off-by:"
+msgstr "agregar Signed-off-by: (firmado por)"
 
-#: builtin/ls-remote.c:65
-msgid "limit to tags"
-msgstr "limitar a tags"
+#: builtin/commit.c:1503
+msgid "use specified template file"
+msgstr "usar archivo de template especificado"
 
-#: builtin/ls-remote.c:66
-msgid "limit to heads"
-msgstr "limitar a heads"
+#: builtin/commit.c:1504
+msgid "force edit of commit"
+msgstr "forzar la edición del commit"
 
-#: builtin/ls-remote.c:67
-msgid "do not show peeled tags"
-msgstr "no mostrar tags pelados"
+#: builtin/commit.c:1506
+msgid "include status in commit message template"
+msgstr "incluir status en el template del mensaje de commit"
 
-#: builtin/ls-remote.c:69
-msgid "take url.<base>.insteadOf into account"
-msgstr "tomar url.<base>.insteadOf en cuenta"
+#: builtin/commit.c:1511
+msgid "Commit contents options"
+msgstr "Opciones para el contenido del commit"
 
-#: builtin/ls-remote.c:73
-msgid "exit with exit code 2 if no matching refs are found"
-msgstr "salir con código de salida 2 si no se encuentran refs que concuerden"
+#: builtin/commit.c:1512
+msgid "commit all changed files"
+msgstr "confirmar todos los archivos cambiados"
 
-#: builtin/ls-remote.c:76
-msgid "show underlying ref in addition to the object pointed by it"
-msgstr "mostrar ref subyacente en adición al objeto apuntado por él"
+#: builtin/commit.c:1513
+msgid "add specified files to index for commit"
+msgstr "agregar archivos específicos al índice para confirmar"
 
-#: builtin/ls-tree.c:29
-msgid "git ls-tree [<options>] <tree-ish> [<path>...]"
-msgstr "git ls-tree [<opciones>] <árbol-ismo> [<ruta>...]"
+#: builtin/commit.c:1514
+msgid "interactively add files"
+msgstr "agregar archivos interactivamente"
 
-#: builtin/ls-tree.c:127
-msgid "only show trees"
-msgstr "solo mostrar árboles"
+#: builtin/commit.c:1515
+msgid "interactively add changes"
+msgstr "agregar cambios interactivamente"
 
-#: builtin/ls-tree.c:129
-msgid "recurse into subtrees"
-msgstr "recurrir en subárboles"
+#: builtin/commit.c:1516
+msgid "commit only specified files"
+msgstr "sólo confirmar archivos específicos"
 
-#: builtin/ls-tree.c:131
-msgid "show trees when recursing"
-msgstr "mostrar árboles cuando se recurre"
+#: builtin/commit.c:1517
+msgid "bypass pre-commit and commit-msg hooks"
+msgstr "evitar los capturadores (hooks) de pre-commit y commit-msg"
 
-#: builtin/ls-tree.c:134
-msgid "terminate entries with NUL byte"
-msgstr "terminar entradas con byte NUL"
+#: builtin/commit.c:1518
+msgid "show what would be committed"
+msgstr "mostrar lo que sería incluido en el commit"
 
-#: builtin/ls-tree.c:135
-msgid "include object size"
-msgstr "incluir tamaño de objeto"
+#: builtin/commit.c:1531
+msgid "amend previous commit"
+msgstr "enmendar commit previo"
 
-#: builtin/ls-tree.c:137 builtin/ls-tree.c:139
-msgid "list only filenames"
-msgstr "listar solo nombres de archivos"
+#: builtin/commit.c:1532
+msgid "bypass post-rewrite hook"
+msgstr "gancho bypass post reescritura"
 
-#: builtin/ls-tree.c:142
-msgid "use full path names"
-msgstr "usar rutas completas"
+#: builtin/commit.c:1539
+msgid "ok to record an empty change"
+msgstr "ok al grabar un cambio vacío"
 
-#: builtin/ls-tree.c:144
-msgid "list entire tree; not just current directory (implies --full-name)"
-msgstr ""
-"mostrar todo el árbol; no solo el directorio actual (implica --full-name)"
+#: builtin/commit.c:1541
+msgid "ok to record a change with an empty message"
+msgstr "ok al grabar un cambio con un mensaje vacío"
 
-#: builtin/mailsplit.c:241
+#: builtin/commit.c:1614
 #, c-format
-msgid "empty mbox: '%s'"
-msgstr "mbox vacío: '%s'"
-
-#: builtin/merge.c:51
-msgid "git merge [<options>] [<commit>...]"
-msgstr "git merge [<opciones>] [<commit>...]"
-
-#: builtin/merge.c:52
-msgid "git merge --abort"
-msgstr "git merge --abort"
-
-#: builtin/merge.c:53
-msgid "git merge --continue"
-msgstr "git merge --continue"
+msgid "Corrupt MERGE_HEAD file (%s)"
+msgstr "Archivo MERGE_HEAD (%s) corrupto"
 
-#: builtin/merge.c:110
-msgid "switch `m' requires a value"
-msgstr "cambiar `m' requiere un valor"
+#: builtin/commit.c:1621
+msgid "could not read MERGE_MODE"
+msgstr "no se pudo leer MERGE_MODE"
 
-#: builtin/merge.c:147
+#: builtin/commit.c:1640
 #, c-format
-msgid "Could not find merge strategy '%s'.\n"
-msgstr "No se pudo encontrar estrategia de fusión '%s'.\n"
+msgid "could not read commit message: %s"
+msgstr "no se pudo leer el mensaje de commit: %s"
 
-#: builtin/merge.c:148
+#: builtin/commit.c:1647
 #, c-format
-msgid "Available strategies are:"
-msgstr "Estrategias disponibles son:"
+msgid "Aborting commit due to empty commit message.\n"
+msgstr "Abortando commit debido que el mensaje está en blanco.\n"
 
-#: builtin/merge.c:153
+#: builtin/commit.c:1652
 #, c-format
-msgid "Available custom strategies are:"
-msgstr "Estrategias personalizadas disponibles son:"
+msgid "Aborting commit; you did not edit the message.\n"
+msgstr "Abortando commit; no se ha editado el mensaje\n"
 
-#: builtin/merge.c:203 builtin/pull.c:142
-msgid "do not show a diffstat at the end of the merge"
-msgstr "no mostrar un diffstat al final de la fusión"
+#: builtin/commit.c:1686
+msgid ""
+"repository has been updated, but unable to write\n"
+"new_index file. Check that disk is not full and quota is\n"
+"not exceeded, and then \"git restore --staged :/\" to recover."
+msgstr ""
+"el repositorio ha sido actualizado, pero no se pudo escribir el archivo\n"
+"new_index. Verifique que el disco no este lleno y la quota no ha\n"
+"sido superada, y luego \"git restore --sateged :/\" para recuperar."
 
-#: builtin/merge.c:206 builtin/pull.c:145
-msgid "show a diffstat at the end of the merge"
-msgstr "mostrar un diffstat al final de la fusión"
+#: builtin/commit-graph.c:11 builtin/commit-graph.c:17
+msgid ""
+"git commit-graph verify [--object-dir <objdir>] [--shallow] [--[no-]progress]"
+msgstr ""
+"git commit-graph verify [--object-dir <objdir>] [--shallow] [--[no-]progress]"
 
-#: builtin/merge.c:207 builtin/pull.c:148
-msgid "(synonym to --stat)"
-msgstr "(sinónimo para --stat)"
+#: builtin/commit-graph.c:12 builtin/commit-graph.c:22
+msgid ""
+"git commit-graph write [--object-dir <objdir>] [--append|--split] [--"
+"reachable|--stdin-packs|--stdin-commits] [--[no-]progress] <split options>"
+msgstr ""
+"git commit-graph write [--object-dir <dir objeto>] [--append|--split] [--"
+"reachable|--stdin-packs|--stdin-commits] [--[no-]progress] <opciones de "
+"split>"
 
-#: builtin/merge.c:209 builtin/pull.c:151
-msgid "add (at most <n>) entries from shortlog to merge commit message"
-msgstr ""
-"agregar (como máximo <n>) entradas del shortlog al mensaje del commit de "
-"fusión"
+#: builtin/commit-graph.c:48 builtin/commit-graph.c:103
+#: builtin/commit-graph.c:187 builtin/fetch.c:179 builtin/log.c:1657
+msgid "dir"
+msgstr "dir"
 
-#: builtin/merge.c:212 builtin/pull.c:157
-msgid "create a single commit instead of doing a merge"
-msgstr "crear un commit único en lugar de hacer una fusión"
+#: builtin/commit-graph.c:49 builtin/commit-graph.c:104
+#: builtin/commit-graph.c:188
+msgid "The object directory to store the graph"
+msgstr "El directorio de objetos para guardar el gráfico"
 
-#: builtin/merge.c:214 builtin/pull.c:160
-msgid "perform a commit if the merge succeeds (default)"
-msgstr "realizar un commit si la fusión es exitosa (default)"
+#: builtin/commit-graph.c:51
+msgid "if the commit-graph is split, only verify the tip file"
+msgstr "si el commit-graph está cortado, solo verifica la punta del archivo"
+
+#: builtin/commit-graph.c:73 t/helper/test-read-graph.c:23
+#, c-format
+msgid "Could not open commit-graph '%s'"
+msgstr "No se pudo abrir commit-graph '%s'"
+
+#: builtin/commit-graph.c:106
+msgid "start walk at all refs"
+msgstr "comenzar caminata en todas las refs"
 
-#: builtin/merge.c:216 builtin/pull.c:163
-msgid "edit message before committing"
-msgstr "editar mensaje antes de realizar commit"
+#: builtin/commit-graph.c:108
+msgid "scan pack-indexes listed by stdin for commits"
+msgstr "escanear paquete de índices por stdin por commits"
 
-#: builtin/merge.c:217
-msgid "allow fast-forward (default)"
-msgstr "permitir fast-forwars (default)"
+#: builtin/commit-graph.c:110
+msgid "start walk at commits listed by stdin"
+msgstr "comenzar a caminar a los commits listados por stdin"
 
-#: builtin/merge.c:219 builtin/pull.c:169
-msgid "abort if fast-forward is not possible"
-msgstr "abortar si fast-forward no es posible"
+#: builtin/commit-graph.c:112
+msgid "include all commits already in the commit-graph file"
+msgstr "inclye todos los commits que ya están en el archivo commit-graph"
 
-#: builtin/merge.c:223 builtin/pull.c:172
-msgid "verify that the named commit has a valid GPG signature"
-msgstr "verificar que el commit nombrado tiene una firma GPG válida"
+#: builtin/commit-graph.c:115
+msgid "allow writing an incremental commit-graph file"
+msgstr "permitir escribir un archivo commit-graph incremental"
+
+#: builtin/commit-graph.c:117 builtin/commit-graph.c:121
+msgid "maximum number of commits in a non-base split commit-graph"
+msgstr "máximo número de commits en un commit-graph sin base cortada"
+
+#: builtin/commit-graph.c:119
+msgid "maximum ratio between two levels of a split commit-graph"
+msgstr "radio máximo entre dos niveles de corte de commit-graph"
+
+#: builtin/commit-graph.c:137
+msgid "use at most one of --reachable, --stdin-commits, or --stdin-packs"
+msgstr "use como máximo uno de --reachable, --stdin-commits, o --stdin-packs"
 
-#: builtin/merge.c:224 builtin/notes.c:777 builtin/pull.c:176
-#: builtin/revert.c:109
-msgid "strategy"
-msgstr "estrategia"
+#: builtin/config.c:11
+msgid "git config [<options>]"
+msgstr "git config [<opciones>]"
 
-#: builtin/merge.c:225 builtin/pull.c:177
-msgid "merge strategy to use"
-msgstr "estrategia de fusión para usar"
+#: builtin/config.c:103 builtin/env--helper.c:23
+#, c-format
+msgid "unrecognized --type argument, %s"
+msgstr "argumento --type no reconocido, %s"
 
-#: builtin/merge.c:226 builtin/pull.c:180
-msgid "option=value"
-msgstr "opción=valor"
+#: builtin/config.c:115
+msgid "only one type at a time"
+msgstr "solo un tipo a la vez"
 
-#: builtin/merge.c:227 builtin/pull.c:181
-msgid "option for selected merge strategy"
-msgstr "opción para la estrategia de fusión seleccionada"
+#: builtin/config.c:124
+msgid "Config file location"
+msgstr "Ubicación del archivo configuración"
 
-#: builtin/merge.c:229
-msgid "merge commit message (for a non-fast-forward merge)"
-msgstr "fusionar mensaje de commit (para una fusión no fast-forward)"
+#: builtin/config.c:125
+msgid "use global config file"
+msgstr "usar archivo de config global"
 
-#: builtin/merge.c:233
-msgid "abort the current in-progress merge"
-msgstr "abortar la fusión en progreso actual"
+#: builtin/config.c:126
+msgid "use system config file"
+msgstr "usar archivo de config del sistema"
 
-#: builtin/merge.c:235
-msgid "continue the current in-progress merge"
-msgstr "continuar la fusión en progreso actual"
+#: builtin/config.c:127
+msgid "use repository config file"
+msgstr "usar archivo de config del repositorio"
 
-#: builtin/merge.c:237 builtin/pull.c:188
-msgid "allow merging unrelated histories"
-msgstr "permitir fusionar historias no relacionadas"
+#: builtin/config.c:128
+msgid "use per-worktree config file"
+msgstr "usar un archivo de config por árbol de trabajo"
 
-#: builtin/merge.c:243
-msgid "verify commit-msg hook"
-msgstr "verificar el hook commit-msg"
+#: builtin/config.c:129
+msgid "use given config file"
+msgstr "usar archivo config especificado"
 
-#: builtin/merge.c:268
-msgid "could not run stash."
-msgstr "no se pudo ejecutar stash."
+#: builtin/config.c:130
+msgid "blob-id"
+msgstr "blob-id"
 
-#: builtin/merge.c:273
-msgid "stash failed"
-msgstr "stash falló"
+#: builtin/config.c:130
+msgid "read config from given blob object"
+msgstr "leer config del objeto blob suministrado"
 
-#: builtin/merge.c:278
-#, c-format
-msgid "not a valid object: %s"
-msgstr "no es un objeto válido: %s"
+#: builtin/config.c:131
+msgid "Action"
+msgstr "Acción"
 
-#: builtin/merge.c:300 builtin/merge.c:317
-msgid "read-tree failed"
-msgstr "lectura de árbol falló"
+#: builtin/config.c:132
+msgid "get value: name [value-regex]"
+msgstr "obtener valor: nombre [valor-regex]"
 
-#: builtin/merge.c:347
-msgid " (nothing to squash)"
-msgstr " (nada para hacer squash)"
+#: builtin/config.c:133
+msgid "get all values: key [value-regex]"
+msgstr "obtener todos los valores: llave [valores-regex]"
 
-#: builtin/merge.c:358
-#, c-format
-msgid "Squash commit -- not updating HEAD\n"
-msgstr "Commit de squash -- no actualizando HEAD\n"
+#: builtin/config.c:134
+msgid "get values for regexp: name-regex [value-regex]"
+msgstr "obtener valores para una regexp: nombre-regex [valor-regex]"
 
-#: builtin/merge.c:408
-#, c-format
-msgid "No merge message -- not updating HEAD\n"
-msgstr "No hay mensaje de fusión -- no actualizando HEAD\n"
+#: builtin/config.c:135
+msgid "get value specific for the URL: section[.var] URL"
+msgstr "obtener valor especifico para el URL: sección[.var] URL"
 
-#: builtin/merge.c:458
-#, c-format
-msgid "'%s' does not point to a commit"
-msgstr "'%s' no apunta a ningún commit"
+#: builtin/config.c:136
+msgid "replace all matching variables: name value [value_regex]"
+msgstr ""
+"remplazar todas las variables que concuerden: nombre valor [valor_regex]"
 
-#: builtin/merge.c:548
-#, c-format
-msgid "Bad branch.%s.mergeoptions string: %s"
-msgstr "Mal string branch.%s.mergeoptions: %s"
+#: builtin/config.c:137
+msgid "add a new variable: name value"
+msgstr "agregar nueva variable: nombre valor"
 
-#: builtin/merge.c:669
-msgid "Not handling anything other than two heads merge."
-msgstr "No manejando nada más que fusión de dos heads."
+#: builtin/config.c:138
+msgid "remove a variable: name [value-regex]"
+msgstr "borrar una variable. nombre [valor-regex]"
 
-#: builtin/merge.c:683
-#, c-format
-msgid "Unknown option for merge-recursive: -X%s"
-msgstr "Opción desconocida para merge-recursive: -X%s"
+#: builtin/config.c:139
+msgid "remove all matches: name [value-regex]"
+msgstr "borrar todas las concurrencias: nombre [valor-regex]"
 
-#: builtin/merge.c:698
-#, c-format
-msgid "unable to write %s"
-msgstr "no es posible escribir %s"
+#: builtin/config.c:140
+msgid "rename section: old-name new-name"
+msgstr "renombrar sección: nombre-viejo nombre-nuevo"
 
-#: builtin/merge.c:749
-#, c-format
-msgid "Could not read from '%s'"
-msgstr "No se puedo leer de '%s'"
+#: builtin/config.c:141
+msgid "remove a section: name"
+msgstr "borrar una sección: nombre"
 
-#: builtin/merge.c:758
-#, c-format
-msgid "Not committing merge; use 'git commit' to complete the merge.\n"
-msgstr ""
-"No se realiza commit de la fusión; use 'git commit' para completar la "
-"fusión.\n"
+#: builtin/config.c:142
+msgid "list all"
+msgstr "listar todo"
 
-#: builtin/merge.c:764
-#, c-format
-msgid ""
-"Please enter a commit message to explain why this merge is necessary,\n"
-"especially if it merges an updated upstream into a topic branch.\n"
-"\n"
-"Lines starting with '%c' will be ignored, and an empty message aborts\n"
-"the commit.\n"
-msgstr ""
-"Por favor ingrese un mensaje de commit que explique por qué es necesaria "
-"esta fusión,\n"
-"especialmente si esto fusiona un upstream actualizado en una rama de "
-"tópico.\n"
-"\n"
-"Líneas comenzando con '%c' serán ignoradas, y un mensaje vacío aborta\n"
-"el commit.\n"
+#: builtin/config.c:143
+msgid "open an editor"
+msgstr "abrir el editor"
 
-#: builtin/merge.c:800
-msgid "Empty commit message."
-msgstr "Mensaje de commit vacío."
+#: builtin/config.c:144
+msgid "find the color configured: slot [default]"
+msgstr "encontrar el color configurado: slot [default]"
 
-#: builtin/merge.c:819
-#, c-format
-msgid "Wonderful.\n"
-msgstr "Maravilloso.\n"
+#: builtin/config.c:145
+msgid "find the color setting: slot [stdout-is-tty]"
+msgstr "encontrar las opciones del color: slot [stdout-es-tty]"
 
-#: builtin/merge.c:872
-#, c-format
-msgid "Automatic merge failed; fix conflicts and then commit the result.\n"
-msgstr ""
-"Fusión automática falló; arregle los conflictos y luego realice un commit "
-"con el resultado.\n"
+#: builtin/config.c:146
+msgid "Type"
+msgstr "Tipo"
 
-#: builtin/merge.c:911
-msgid "No current branch."
-msgstr "No rama actual."
+#: builtin/config.c:147 builtin/env--helper.c:38
+msgid "value is given this type"
+msgstr "al valor se ha dado este tipo"
 
-#: builtin/merge.c:913
-msgid "No remote for the current branch."
-msgstr "No hay remoto para la rama actual."
+#: builtin/config.c:148
+msgid "value is \"true\" or \"false\""
+msgstr "valor es \"true\" o \"false\""
 
-#: builtin/merge.c:915
-msgid "No default upstream defined for the current branch."
-msgstr "Por defecto, no hay un upstream  definido para la rama actual."
+#: builtin/config.c:149
+msgid "value is decimal number"
+msgstr "valor es un numero decimal"
 
-#: builtin/merge.c:920
-#, c-format
-msgid "No remote-tracking branch for %s from %s"
-msgstr "No hay rama de rastreo remoto para %s de %s"
+#: builtin/config.c:150
+msgid "value is --bool or --int"
+msgstr "valor es --bool o --int"
 
-#: builtin/merge.c:973
-#, c-format
-msgid "Bad value '%s' in environment '%s'"
-msgstr "Mal valor '%s' en el entorno '%s'"
+#: builtin/config.c:151
+msgid "value is a path (file or directory name)"
+msgstr "valor es una ruta (archivo o nombre de directorio)"
 
-#: builtin/merge.c:1075
-#, c-format
-msgid "not something we can merge in %s: %s"
-msgstr "nada que podamos fusionar en %s: %s"
+#: builtin/config.c:152
+msgid "value is an expiry date"
+msgstr "valor es una fecha de expiración"
 
-#: builtin/merge.c:1109
-msgid "not something we can merge"
-msgstr "nada que podamos fusionar"
+#: builtin/config.c:153
+msgid "Other"
+msgstr "Otro"
 
-#: builtin/merge.c:1211
-msgid "--abort expects no arguments"
-msgstr "--abort no espera argumentos"
+#: builtin/config.c:154
+msgid "terminate values with NUL byte"
+msgstr "terminar valores con un byte NULL"
 
-#: builtin/merge.c:1215
-msgid "There is no merge to abort (MERGE_HEAD missing)."
-msgstr "No hay una fusión para abortar (falta MERGE_HEAD)"
+#: builtin/config.c:155
+msgid "show variable names only"
+msgstr "mostrar solo nombres de variables"
 
-#: builtin/merge.c:1227
-msgid "--continue expects no arguments"
-msgstr "--continue no espera argumentos"
+#: builtin/config.c:156
+msgid "respect include directives on lookup"
+msgstr "respetar directivas include en la búsqueda"
 
-#: builtin/merge.c:1231
-msgid "There is no merge in progress (MERGE_HEAD missing)."
-msgstr "No hay fusión en progreso (falta MERGE_HEAD)."
+#: builtin/config.c:157
+msgid "show origin of config (file, standard input, blob, command line)"
+msgstr "mostrar el origen de configuración (archivo, stdin, blob, comando)"
 
-#: builtin/merge.c:1247
-msgid ""
-"You have not concluded your merge (MERGE_HEAD exists).\n"
-"Please, commit your changes before you merge."
-msgstr ""
-"No ha concluido la fusión (existe MERGE_HEAD).\n"
-"Por favor, realice un commit con los cambios antes de fusionar."
+#: builtin/config.c:158 builtin/env--helper.c:40
+msgid "value"
+msgstr "valor"
 
-#: builtin/merge.c:1254
-msgid ""
-"You have not concluded your cherry-pick (CHERRY_PICK_HEAD exists).\n"
-"Please, commit your changes before you merge."
-msgstr ""
-"No ha concluido el cherry-pick (existe CHERRY_PICK_HEAD).\n"
-"Por favor, realice un commit con los cambios antes de fusionar."
+#: builtin/config.c:158
+msgid "with --get, use default value when missing entry"
+msgstr "con --get, usa el valor por defecto cuando falta una entrada"
 
-#: builtin/merge.c:1257
-msgid "You have not concluded your cherry-pick (CHERRY_PICK_HEAD exists)."
-msgstr "No ha concluido el cherry-pick (existe CHERRY_PICK_HEAD)."
+#: builtin/config.c:172
+#, c-format
+msgid "wrong number of arguments, should be %d"
+msgstr "número de argumentos inválidos, deberían ser %d"
 
-#: builtin/merge.c:1266
-msgid "You cannot combine --squash with --no-ff."
-msgstr "No se puede combinar --squash con --no-ff."
+#: builtin/config.c:174
+#, c-format
+msgid "wrong number of arguments, should be from %d to %d"
+msgstr "número de argumentos inválidos, deberían ser de %d a %d"
 
-#: builtin/merge.c:1274
-msgid "No commit specified and merge.defaultToUpstream not set."
-msgstr ""
-"No hay commit especificado y merge.defaultToUpstream no está configurado."
-
-#: builtin/merge.c:1291
-msgid "Squash commit into empty head not supported yet"
-msgstr "Commit aplastado dentro de un head vacío no es soportado todavía"
-
-#: builtin/merge.c:1293
-msgid "Non-fast-forward commit does not make sense into an empty head"
-msgstr "Commit no fast-forward no tiene sentido dentro de un head vacío"
-
-#: builtin/merge.c:1298
-#, c-format
-msgid "%s - not something we can merge"
-msgstr "%s - nada que podamos fusionar"
-
-#: builtin/merge.c:1300
-msgid "Can merge only exactly one commit into empty head"
-msgstr "Solo se puede fusionar exactamente un commit en un head vacío"
-
-#: builtin/merge.c:1334
-#, c-format
-msgid "Commit %s has an untrusted GPG signature, allegedly by %s."
-msgstr "Commit %s tiene una firma GPG no confiable, pretendidamente por %s."
-
-#: builtin/merge.c:1337
-#, c-format
-msgid "Commit %s has a bad GPG signature allegedly by %s."
-msgstr "Commit %s tiene una mala firma GPG pretendidamente por %s."
-
-#: builtin/merge.c:1340
-#, c-format
-msgid "Commit %s does not have a GPG signature."
-msgstr "Commit %s no tiene una firma GPG."
-
-#: builtin/merge.c:1343
-#, c-format
-msgid "Commit %s has a good GPG signature by %s\n"
-msgstr "El Commit %s tiene una buena firma GPG por %s\n"
-
-#: builtin/merge.c:1402
-msgid "refusing to merge unrelated histories"
-msgstr "rehusando fusionar historias no relacionadas"
-
-#: builtin/merge.c:1411
-msgid "Already up to date."
-msgstr "Ya está actualizado."
-
-#: builtin/merge.c:1421
+#: builtin/config.c:308
 #, c-format
-msgid "Updating %s..%s\n"
-msgstr "Actualizando %s..%s\n"
+msgid "invalid key pattern: %s"
+msgstr "patrón de llave inválido: %s"
 
-#: builtin/merge.c:1462
+#: builtin/config.c:344
 #, c-format
-msgid "Trying really trivial in-index merge...\n"
-msgstr "Intentando fusión en índice realmente trivial...\n"
+msgid "failed to format default config value: %s"
+msgstr "falló al formatear el valor por defecto de configuración: %s"
 
-#: builtin/merge.c:1469
+#: builtin/config.c:401
 #, c-format
-msgid "Nope.\n"
-msgstr "Nop.\n"
+msgid "cannot parse color '%s'"
+msgstr "no se analizar color '%s'"
 
-#: builtin/merge.c:1494
-msgid "Already up to date. Yeeah!"
-msgstr "Ya está actualizado. ¡Oh, yeaahh!"
+#: builtin/config.c:443
+msgid "unable to parse default color value"
+msgstr "no es posible analizar el valor por defecto de color"
 
-#: builtin/merge.c:1500
-msgid "Not possible to fast-forward, aborting."
-msgstr "No es posible hacer fast-forward, abortando."
+#: builtin/config.c:496 builtin/config.c:742
+msgid "not in a git directory"
+msgstr "no en un directorio git"
+
+#: builtin/config.c:499
+msgid "writing to stdin is not supported"
+msgstr "escribir en stdin no está soportado"
+
+#: builtin/config.c:502
+msgid "writing config blobs is not supported"
+msgstr "escribir blobs de configuración no está soportado"
 
-#: builtin/merge.c:1523 builtin/merge.c:1602
+#: builtin/config.c:587
 #, c-format
-msgid "Rewinding the tree to pristine...\n"
-msgstr "Rebobinando el árbol a original...\n"
+msgid ""
+"# This is Git's per-user configuration file.\n"
+"[user]\n"
+"# Please adapt and uncomment the following lines:\n"
+"#\tname = %s\n"
+"#\temail = %s\n"
+msgstr ""
+"# Este es el archivo de configuración de Git por usuario.\n"
+"[user]\n"
+"# Por favor, adapta y descomenta las siguientes líneas:\n"
+"#\tname = %s\n"
+"#\temail = %s\n"
 
-#: builtin/merge.c:1527
-#, c-format
-msgid "Trying merge strategy %s...\n"
-msgstr "Intentando estrategia de fusión %s...\n"
+#: builtin/config.c:611
+msgid "only one config file at a time"
+msgstr "solo un archivo de configuración a la vez"
 
-#: builtin/merge.c:1593
-#, c-format
-msgid "No merge strategy handled the merge.\n"
-msgstr "Ninguna estrategia de fusión manejó la fusión.\n"
+#: builtin/config.c:616
+msgid "--local can only be used inside a git repository"
+msgstr "--local solo puedo ser usado dentro de un repositorio"
 
-#: builtin/merge.c:1595
-#, c-format
-msgid "Merge with strategy %s failed.\n"
-msgstr "Fusionar con estrategia %s falló.\n"
+#: builtin/config.c:619
+msgid "--blob can only be used inside a git repository"
+msgstr "--blob solo puede ser usado dentro de un repositorio"
 
-#: builtin/merge.c:1604
-#, c-format
-msgid "Using the %s to prepare resolving by hand.\n"
-msgstr "Usando el %s para preparar resolución a mano.\n"
+#: builtin/config.c:638
+msgid "$HOME not set"
+msgstr "$HOME no está configurado"
 
-#: builtin/merge.c:1616
-#, c-format
-msgid "Automatic merge went well; stopped before committing as requested\n"
+#: builtin/config.c:658
+msgid ""
+"--worktree cannot be used with multiple working trees unless the config\n"
+"extension worktreeConfig is enabled. Please read \"CONFIGURATION FILE\"\n"
+"section in \"git help worktree\" for details"
 msgstr ""
-"Fusión automática fue bien; detenida antes del commit como se solicitó\n"
+"--worktree no puede ser usado con multiples árboles de trabajo a menos que "
+"la\n"
+"extensión worktreeConfig esté habilitada. Por favor lea \"CONFIGURATION FILE"
+"\"\n"
+"en \"git help worktree\" para más detalles"
 
-#: builtin/merge-base.c:30
-msgid "git merge-base [-a | --all] <commit> <commit>..."
-msgstr "git merge-base [-a | --all] <commit> <commit>..."
+#: builtin/config.c:688
+msgid "--get-color and variable type are incoherent"
+msgstr "--get-color y tipo de variable incoherente"
 
-#: builtin/merge-base.c:31
-msgid "git merge-base [-a | --all] --octopus <commit>..."
-msgstr "git merge-base [-a | --all] --octopus <commit>..."
+#: builtin/config.c:693
+msgid "only one action at a time"
+msgstr "solo una acción a la vez"
 
-#: builtin/merge-base.c:32
-msgid "git merge-base --independent <commit>..."
-msgstr "git merge-base --independent <commit>..."
+#: builtin/config.c:706
+msgid "--name-only is only applicable to --list or --get-regexp"
+msgstr "--name-only solo es aplicable para --list o --get-regexp"
 
-#: builtin/merge-base.c:33
-msgid "git merge-base --is-ancestor <commit> <commit>"
-msgstr "git merge-base --is-ancestor <commit> <commit>"
+#: builtin/config.c:712
+msgid ""
+"--show-origin is only applicable to --get, --get-all, --get-regexp, and --"
+"list"
+msgstr ""
+"--show-origin solo es aplicable para --get, --get-all, --get-regexp, y --list"
 
-#: builtin/merge-base.c:34
-msgid "git merge-base --fork-point <ref> [<commit>]"
-msgstr "git merge-base --fork-point <ref> [<commit>]"
+#: builtin/config.c:718
+msgid "--default is only applicable to --get"
+msgstr "--default solo es aplicable para --get"
 
-#: builtin/merge-base.c:220
-msgid "output all common ancestors"
-msgstr "mostrar todos los ancestros comunes"
+#: builtin/config.c:731
+#, c-format
+msgid "unable to read config file '%s'"
+msgstr "no se puede leer el archivo de configuración '%s'"
 
-#: builtin/merge-base.c:222
-msgid "find ancestors for a single n-way merge"
-msgstr "encontrar ancestros para una única fusión de n-vías"
+#: builtin/config.c:734
+msgid "error processing config file(s)"
+msgstr "error al procesar archivo(s) de configuración"
 
-#: builtin/merge-base.c:224
-msgid "list revs not reachable from others"
-msgstr "listar revs no alcanzables desde otros"
+#: builtin/config.c:744
+msgid "editing stdin is not supported"
+msgstr "editar stdin no está soportado"
 
-#: builtin/merge-base.c:226
-msgid "is the first one ancestor of the other?"
-msgstr "es el primer ancestro del otro?"
+#: builtin/config.c:746
+msgid "editing blobs is not supported"
+msgstr "editar blobs no está soportado"
 
-#: builtin/merge-base.c:228
-msgid "find where <commit> forked from reflog of <ref>"
-msgstr "encontrar donde <commit> forjó del reflog de <ref>"
+#: builtin/config.c:760
+#, c-format
+msgid "cannot create configuration file %s"
+msgstr "no se puede crear el archivo de configuración %s"
 
-#: builtin/merge-file.c:9
+#: builtin/config.c:773
+#, c-format
 msgid ""
-"git merge-file [<options>] [-L <name1> [-L <orig> [-L <name2>]]] <file1> "
-"<orig-file> <file2>"
+"cannot overwrite multiple values with a single value\n"
+"       Use a regexp, --add or --replace-all to change %s."
 msgstr ""
-"git merge-file [<opciones>] [-L <nombre1> [-L <origen> [-L <nombre2>]]] "
-"<archivo1> <archivo-origen> <archivo2>"
+"no se puede sobrescribir múltiples valores con un único valor\n"
+"\tUse una regexp, --add o --replace-all para cambiar %s."
 
-#: builtin/merge-file.c:33
-msgid "send results to standard output"
-msgstr "mandar resultados a standard output"
+#: builtin/config.c:847 builtin/config.c:858
+#, c-format
+msgid "no such section: %s"
+msgstr "no existe la sección: %s"
 
-#: builtin/merge-file.c:34
-msgid "use a diff3 based merge"
-msgstr "usar un fusión basada en diff3"
+#: builtin/count-objects.c:90
+msgid "git count-objects [-v] [-H | --human-readable]"
+msgstr "git count-objects [-v] [-H | --human-readable]"
 
-#: builtin/merge-file.c:35
-msgid "for conflicts, use our version"
-msgstr "por conflictos, usar nuestra versión"
+#: builtin/count-objects.c:100
+msgid "print sizes in human readable format"
+msgstr "mostrar tamaños en formato legible para humano"
 
-#: builtin/merge-file.c:37
-msgid "for conflicts, use their version"
-msgstr "por conflictos, usar la versión de ellos"
+#: builtin/describe.c:26
+msgid "git describe [<options>] [<commit-ish>...]"
+msgstr "git describe [<opciones>] [<commit-ish>...]"
 
-#: builtin/merge-file.c:39
-msgid "for conflicts, use a union version"
-msgstr "por conflictos, usar una versión de unión"
+#: builtin/describe.c:27
+msgid "git describe [<options>] --dirty"
+msgstr "git describe [<opciones>] --dirty"
 
-#: builtin/merge-file.c:42
-msgid "for conflicts, use this marker size"
-msgstr "por conflictos, usar el tamaño de este marcador"
+#: builtin/describe.c:62
+msgid "head"
+msgstr "head"
 
-#: builtin/merge-file.c:43
-msgid "do not warn about conflicts"
-msgstr "no advertir sobre conflictos"
+#: builtin/describe.c:62
+msgid "lightweight"
+msgstr "ligero"
 
-#: builtin/merge-file.c:45
-msgid "set labels for file1/orig-file/file2"
-msgstr "configurar labels para archivo1/orig-archivo/archivo2"
+#: builtin/describe.c:62
+msgid "annotated"
+msgstr "anotado"
 
-#: builtin/merge-recursive.c:45
+#: builtin/describe.c:275
 #, c-format
-msgid "unknown option %s"
-msgstr "opción %s desconocida"
+msgid "annotated tag %s not available"
+msgstr "tag anotado %s no disponible"
 
-#: builtin/merge-recursive.c:51
+#: builtin/describe.c:279
 #, c-format
-msgid "could not parse object '%s'"
-msgstr "no se pudo analizar el objeto '%s'"
+msgid "annotated tag %s has no embedded name"
+msgstr "tag anotado %s no tiene nombre embebido"
 
-#: builtin/merge-recursive.c:55
+#: builtin/describe.c:281
 #, c-format
-msgid "cannot handle more than %d base. Ignoring %s."
-msgid_plural "cannot handle more than %d bases. Ignoring %s."
-msgstr[0] "no se puede manejar más de %d base. Ignorando %s."
-msgstr[1] "no se puede manejar más de %d bases. Ignorando %s."
-
-#: builtin/merge-recursive.c:63
-msgid "not handling anything other than two heads merge."
-msgstr "no manejando nada distinto a fusiones de dos heads."
+msgid "tag '%s' is really '%s' here"
+msgstr "tag '%s' es realmente '%s' aquí"
 
-#: builtin/merge-recursive.c:69 builtin/merge-recursive.c:71
+#: builtin/describe.c:325
 #, c-format
-msgid "could not resolve ref '%s'"
-msgstr "no se pudo resolver ref '%s'"
+msgid "no tag exactly matches '%s'"
+msgstr "no hay tag que concuerde exactamente con '%s'"
 
-#: builtin/merge-recursive.c:77
+#: builtin/describe.c:327
 #, c-format
-msgid "Merging %s with %s\n"
-msgstr "Fusionando %s con %s\n"
-
-#: builtin/mktree.c:65
-msgid "git mktree [-z] [--missing] [--batch]"
-msgstr "git mktree [-z] [--missing] [--batch]"
-
-#: builtin/mktree.c:153
-msgid "input is NUL terminated"
-msgstr "input es terminada con NUL"
-
-#: builtin/mktree.c:154 builtin/write-tree.c:25
-msgid "allow missing objects"
-msgstr "permitir objetos faltantes"
-
-#: builtin/mktree.c:155
-msgid "allow creation of more than one tree"
-msgstr "permitir la creación de más de un árbol"
+msgid "No exact match on refs or tags, searching to describe\n"
+msgstr "No hay coincidencia exacta en refs o tags, buscando en describe\n"
 
-#: builtin/mv.c:17
-msgid "git mv [<options>] <source>... <destination>"
-msgstr "git mv [<opciones>] <fuente>... <destino>"
+#: builtin/describe.c:381
+#, c-format
+msgid "finished search at %s\n"
+msgstr "búsqueda finalizada a las %s\n"
 
-#: builtin/mv.c:82
+#: builtin/describe.c:407
 #, c-format
-msgid "Directory %s is in index and no submodule?"
-msgstr "Directorio %s está en el índice y no hay submódulo?"
+msgid ""
+"No annotated tags can describe '%s'.\n"
+"However, there were unannotated tags: try --tags."
+msgstr ""
+"No hay tags anotados que puedan describir '%s'.\n"
+"Sin embargo, hubieron tags no anotados: intente --tags."
 
-#: builtin/mv.c:84 builtin/rm.c:288
-msgid "Please stage your changes to .gitmodules or stash them to proceed"
+#: builtin/describe.c:411
+#, c-format
+msgid ""
+"No tags can describe '%s'.\n"
+"Try --always, or create some tags."
 msgstr ""
-"Por favor agrega el stage de tus cambios a .gitmodules o realiza un stash "
-"para proceder"
+"Ningún tag puede describit '%s'.\n"
+"Intente --always, o cree algunos tags."
 
-#: builtin/mv.c:102
+#: builtin/describe.c:441
 #, c-format
-msgid "%.*s is in index"
-msgstr "%.*s está en el índice"
+msgid "traversed %lu commits\n"
+msgstr "%lu commits cruzados\n"
 
-#: builtin/mv.c:124
-msgid "force move/rename even if target exists"
-msgstr "forzar mover/renombrar incluso si el objetivo existe"
+#: builtin/describe.c:444
+#, c-format
+msgid ""
+"more than %i tags found; listed %i most recent\n"
+"gave up search at %s\n"
+msgstr ""
+"se encontró más de %i tags; se mostró %i más reciente\n"
+"fin de la búsqueda en %s\n"
 
-#: builtin/mv.c:126
-msgid "skip move/rename errors"
-msgstr "saltar errores de mover/renombrar"
+#: builtin/describe.c:512
+#, c-format
+msgid "describe %s\n"
+msgstr "describe %s\n"
 
-#: builtin/mv.c:168
+#: builtin/describe.c:515
 #, c-format
-msgid "destination '%s' is not a directory"
-msgstr "destino '%s' no es un directorio"
+msgid "Not a valid object name %s"
+msgstr "Nombre de objeto %s no válido"
 
-#: builtin/mv.c:179
+#: builtin/describe.c:523
 #, c-format
-msgid "Checking rename of '%s' to '%s'\n"
-msgstr "Revisando cambio de nombre de '%s' a '%s'\n"
+msgid "%s is neither a commit nor blob"
+msgstr "%s no es un commit ni un blob"
 
-#: builtin/mv.c:183
-msgid "bad source"
-msgstr "mala fuente"
+#: builtin/describe.c:537
+msgid "find the tag that comes after the commit"
+msgstr "encontrar el tag que viene después del commit"
 
-#: builtin/mv.c:186
-msgid "can not move directory into itself"
-msgstr "no se pude mover un directorio en sí mismo"
+#: builtin/describe.c:538
+msgid "debug search strategy on stderr"
+msgstr "hacer debug a la estrategia de búsqueda en stderr"
 
-#: builtin/mv.c:189
-msgid "cannot move directory over file"
-msgstr "no se puede mover un directorio dentro de un archivo"
-
-#: builtin/mv.c:198
-msgid "source directory is empty"
-msgstr "directorio de fuente está vacío"
+#: builtin/describe.c:539
+msgid "use any ref"
+msgstr "use cualquier ref"
 
-#: builtin/mv.c:223
-msgid "not under version control"
-msgstr "no se encuentra bajo control de versión"
+#: builtin/describe.c:540
+msgid "use any tag, even unannotated"
+msgstr "use cualquier tag, incluso los no anotados"
 
-#: builtin/mv.c:226
-msgid "destination exists"
-msgstr "destino existe"
+#: builtin/describe.c:541
+msgid "always use long format"
+msgstr "siempre usar formato largo"
 
-#: builtin/mv.c:234
-#, c-format
-msgid "overwriting '%s'"
-msgstr "sobrescribiendo '%s'"
+#: builtin/describe.c:542
+msgid "only follow first parent"
+msgstr "solo seguir el primer patrón"
 
-#: builtin/mv.c:237
-msgid "Cannot overwrite"
-msgstr "No se puede sobrescribir"
+#: builtin/describe.c:545
+msgid "only output exact matches"
+msgstr "solo mostrar concordancias exactas"
 
-#: builtin/mv.c:240
-msgid "multiple sources for the same target"
-msgstr "múltiples fuentes para el mismo objetivo"
+#: builtin/describe.c:547
+msgid "consider <n> most recent tags (default: 10)"
+msgstr "considerar <n> tags más recientes (default:10)"
 
-#: builtin/mv.c:242
-msgid "destination directory does not exist"
-msgstr "el directorio de destino no existe"
+#: builtin/describe.c:549
+msgid "only consider tags matching <pattern>"
+msgstr "solo considerar tags que concuerden con <patrón>"
 
-#: builtin/mv.c:249
-#, c-format
-msgid "%s, source=%s, destination=%s"
-msgstr "%s, fuente=%s, destino=%s"
+#: builtin/describe.c:551
+msgid "do not consider tags matching <pattern>"
+msgstr "no considerar tags que concuerden con <patrón>"
 
-#: builtin/mv.c:270
-#, c-format
-msgid "Renaming %s to %s\n"
-msgstr "Renombrando %s a %s\n"
+#: builtin/describe.c:553 builtin/name-rev.c:473
+msgid "show abbreviated commit object as fallback"
+msgstr "mostrar el objeto commit abreviado como fallback"
 
-#: builtin/mv.c:276 builtin/remote.c:715 builtin/repack.c:409
-#, c-format
-msgid "renaming '%s' failed"
-msgstr "renombrando '%s' falló"
+#: builtin/describe.c:554 builtin/describe.c:557
+msgid "mark"
+msgstr "marca"
 
-#: builtin/name-rev.c:338
-msgid "git name-rev [<options>] <commit>..."
-msgstr "git name-rev [<opciones>] <commit>..."
+#: builtin/describe.c:555
+msgid "append <mark> on dirty working tree (default: \"-dirty\")"
+msgstr "adjuntar <marca> en el árbol de trabajo sucio (default: \"-dirty\")"
 
-#: builtin/name-rev.c:339
-msgid "git name-rev [<options>] --all"
-msgstr "git name-rev [<opciones>] --all"
+#: builtin/describe.c:558
+msgid "append <mark> on broken working tree (default: \"-broken\")"
+msgstr "adjuntar <marca> en un árbol de trabajo roto (default: \"-broken\")"
 
-#: builtin/name-rev.c:340
-msgid "git name-rev [<options>] --stdin"
-msgstr "git name-rev [<opciones>] --stdin"
+#: builtin/describe.c:576
+msgid "--long is incompatible with --abbrev=0"
+msgstr "--long es incompatible con --abbrev=0"
 
-#: builtin/name-rev.c:395
-msgid "print only names (no SHA-1)"
-msgstr "imprimir sólo nombres (sin SHA-1)"
+#: builtin/describe.c:605
+msgid "No names found, cannot describe anything."
+msgstr "No se encontraron nombres, no se puede describir nada."
 
-#: builtin/name-rev.c:396
-msgid "only use tags to name the commits"
-msgstr "sólo usar tags para nombrar commits"
+#: builtin/describe.c:656
+msgid "--dirty is incompatible with commit-ishes"
+msgstr "--dirty es incompatible con commit-ismos"
 
-#: builtin/name-rev.c:398
-msgid "only use refs matching <pattern>"
-msgstr "solo usar refs que concuerden con <patrón>"
+#: builtin/describe.c:658
+msgid "--broken is incompatible with commit-ishes"
+msgstr "--broken es incompatible con commit-ismos"
 
-#: builtin/name-rev.c:400
-msgid "ignore refs matching <pattern>"
-msgstr "ignorar refs que concuerden con <patrón>"
+#: builtin/diff.c:84
+#, c-format
+msgid "'%s': not a regular file or symlink"
+msgstr "'%s': no es un archivo regular o un enlace simbólico"
 
-#: builtin/name-rev.c:402
-msgid "list all commits reachable from all refs"
-msgstr "listar todos los commits alcanzables desde todas las referencias"
+#: builtin/diff.c:235
+#, c-format
+msgid "invalid option: %s"
+msgstr "opción inválida: %s"
 
-#: builtin/name-rev.c:403
-msgid "read from stdin"
-msgstr "leer desde stdin"
+#: builtin/diff.c:350
+msgid "Not a git repository"
+msgstr "No es un repositorio git"
 
-#: builtin/name-rev.c:404
-msgid "allow to print `undefined` names (default)"
-msgstr "permitir imprimir nombres `undefined` (predeterminado)"
+#: builtin/diff.c:394
+#, c-format
+msgid "invalid object '%s' given."
+msgstr "objeto '%s' entregado no es válido."
 
-#: builtin/name-rev.c:410
-msgid "dereference tags in the input (internal use)"
-msgstr "desreferenciar tags en la entrada (uso interno)"
+#: builtin/diff.c:403
+#, c-format
+msgid "more than two blobs given: '%s'"
+msgstr "más de dos blobs entregados: '%s'"
 
-#: builtin/notes.c:26
-msgid "git notes [--ref <notes-ref>] [list [<object>]]"
-msgstr "git notes [--ref <referencia-de-notas>] [list [<objeto>]]"
+#: builtin/diff.c:408
+#, c-format
+msgid "unhandled object '%s' given."
+msgstr "objeto no manejado '%s' entregado."
 
-#: builtin/notes.c:27
-msgid ""
-"git notes [--ref <notes-ref>] add [-f] [--allow-empty] [-m <msg> | -F <file> "
-"| (-c | -C) <object>] [<object>]"
-msgstr ""
-"git notes [--ref <referencia-de-notas>] add [-f] [--allow-empty] [-m "
-"<mensaje> | -F <archivo> | (-c | -C) <objeto>] [<objeto>]"
+#: builtin/difftool.c:30
+msgid "git difftool [<options>] [<commit> [<commit>]] [--] [<path>...]"
+msgstr "git difftool [<opciones>] [<commit> [<commit>]] [--] [<ruta>...]"
 
-#: builtin/notes.c:28
-msgid "git notes [--ref <notes-ref>] copy [-f] <from-object> <to-object>"
-msgstr ""
-"git notes [--ref <referencia-de-notas>] copy [-f] <objeto-origen> <objeto-"
-"destino>"
+#: builtin/difftool.c:260
+#, c-format
+msgid "failed: %d"
+msgstr "falló: %d"
 
-#: builtin/notes.c:29
-msgid ""
-"git notes [--ref <notes-ref>] append [--allow-empty] [-m <msg> | -F <file> | "
-"(-c | -C) <object>] [<object>]"
-msgstr ""
-"git notes [--ref <referencia-de-notas>] append [--allow-empty] [-m <mensaje> "
-"| -F <archivo> | (-c | -C) <objeto>] [<objeto>]"
+#: builtin/difftool.c:302
+#, c-format
+msgid "could not read symlink %s"
+msgstr "no se pudo leer el symlink %s"
 
-#: builtin/notes.c:30
-msgid "git notes [--ref <notes-ref>] edit [--allow-empty] [<object>]"
-msgstr ""
-"git notes [--ref <referencia-de-notas>] edit [--allow-empty] [<objeto>]"
+#: builtin/difftool.c:304
+#, c-format
+msgid "could not read symlink file %s"
+msgstr "no se pudo leer el archivo symlink %s"
 
-#: builtin/notes.c:31
-msgid "git notes [--ref <notes-ref>] show [<object>]"
-msgstr "git notes [--ref <referencia-de-notas>] show [<objeto>]"
+#: builtin/difftool.c:312
+#, c-format
+msgid "could not read object %s for symlink %s"
+msgstr "no se pudo leer el objeto %s para el symlink %s"
 
-#: builtin/notes.c:32
+#: builtin/difftool.c:413
 msgid ""
-"git notes [--ref <notes-ref>] merge [-v | -q] [-s <strategy>] <notes-ref>"
+"combined diff formats('-c' and '--cc') are not supported in\n"
+"directory diff mode('-d' and '--dir-diff')."
 msgstr ""
-"git notes [--ref <referencia-de notas>] merge [-v | -q] [-s <estrategia>] "
-"<referencia-de-notas>"
+"formatos combinados de diff ('-c' y '--cc') no soportados en\n"
+"modo diff para directorio('-d' y '--dir-diff')."
 
-#: builtin/notes.c:33
-msgid "git notes merge --commit [-v | -q]"
-msgstr "git notes merge --commit [-v | -q]"
+#: builtin/difftool.c:634
+#, c-format
+msgid "both files modified: '%s' and '%s'."
+msgstr "ambos archivos modificados: '%s' y '%s'."
 
-#: builtin/notes.c:34
-msgid "git notes merge --abort [-v | -q]"
-msgstr "git notes merge --abort [-v | -q]"
+#: builtin/difftool.c:636
+msgid "working tree file has been left."
+msgstr "archivo del árbol de trabajo ha sido dejado."
 
-#: builtin/notes.c:35
-msgid "git notes [--ref <notes-ref>] remove [<object>...]"
-msgstr "git notes [--ref <referencia-de-notas>] remove [<objeto>...]"
+#: builtin/difftool.c:647
+#, c-format
+msgid "temporary files exist in '%s'."
+msgstr "archivo temporal existe en '%s'."
 
-#: builtin/notes.c:36
-msgid "git notes [--ref <notes-ref>] prune [-n] [-v]"
-msgstr "git notes [--ref <referencia-de-notas>] prune [-n] [-v]"
+#: builtin/difftool.c:648
+msgid "you may want to cleanup or recover these."
+msgstr "tal vez desees limpiar o recuperar estos."
 
-#: builtin/notes.c:37
-msgid "git notes [--ref <notes-ref>] get-ref"
-msgstr "git notes [--ref <referencia-de-notas>] get-ref"
+#: builtin/difftool.c:697
+msgid "use `diff.guitool` instead of `diff.tool`"
+msgstr "use `diff.guitool` en lugar de `diff.tool`"
 
-#: builtin/notes.c:42
-msgid "git notes [list [<object>]]"
-msgstr "git notes [list [<objeto>]]"
+#: builtin/difftool.c:699
+msgid "perform a full-directory diff"
+msgstr "realizar un diff de todo el directorio"
 
-#: builtin/notes.c:47
-msgid "git notes add [<options>] [<object>]"
-msgstr "git notes add [<opciones>] [<objeto>]"
+#: builtin/difftool.c:701
+msgid "do not prompt before launching a diff tool"
+msgstr "no mostrar antes de lanzar una herramienta de diff"
 
-#: builtin/notes.c:52
-msgid "git notes copy [<options>] <from-object> <to-object>"
-msgstr "git notes copy [<opciones>] <objeto-origen> <objeto-destino>"
+#: builtin/difftool.c:706
+msgid "use symlinks in dir-diff mode"
+msgstr "usar enlaces simbólicos en modo dir-diff"
 
-#: builtin/notes.c:53
-msgid "git notes copy --stdin [<from-object> <to-object>]..."
-msgstr "git notes copy --stdin [<objeto-origen> <objeto-destino>]..."
+#: builtin/difftool.c:707
+msgid "tool"
+msgstr "herramienta"
 
-#: builtin/notes.c:58
-msgid "git notes append [<options>] [<object>]"
-msgstr "git notes append [<opciones>] [<objeto>]"
+#: builtin/difftool.c:708
+msgid "use the specified diff tool"
+msgstr "usar la herramienta de diff especificada"
 
-#: builtin/notes.c:63
-msgid "git notes edit [<object>]"
-msgstr "git notes edit [<objeto>]"
+#: builtin/difftool.c:710
+msgid "print a list of diff tools that may be used with `--tool`"
+msgstr ""
+"mostrar una lista de herramientas de diff que pueden ser usadas con `--tool`"
 
-#: builtin/notes.c:68
-msgid "git notes show [<object>]"
-msgstr "git notes show [<objeto>]"
+#: builtin/difftool.c:713
+msgid ""
+"make 'git-difftool' exit when an invoked diff tool returns a non - zero exit "
+"code"
+msgstr ""
+"hacer que 'git-difftool' salga cuando una herramienta de diff retorne un "
+"código de salida distinto de cero"
 
-#: builtin/notes.c:73
-msgid "git notes merge [<options>] <notes-ref>"
-msgstr "git notes merge [<opciones>] <referencia-de-notas>"
+#: builtin/difftool.c:716
+msgid "specify a custom command for viewing diffs"
+msgstr "especificar un comando personalizado para ver diffs"
 
-#: builtin/notes.c:74
-msgid "git notes merge --commit [<options>]"
-msgstr "git notes merge --commit [<opciones>]"
+#: builtin/difftool.c:717
+msgid "passed to `diff`"
+msgstr "pasado a `diff`"
+
+#: builtin/difftool.c:732
+msgid "difftool requires worktree or --no-index"
+msgstr "difftool requiere un árbol de trabajo o --no-index"
+
+#: builtin/difftool.c:739
+msgid "--dir-diff is incompatible with --no-index"
+msgstr "--dirty-diff es incompatible con --no-index"
+
+#: builtin/difftool.c:742
+msgid "--gui, --tool and --extcmd are mutually exclusive"
+msgstr "--gui, --tool y --extcmd son mutuamente exclusivas"
 
-#: builtin/notes.c:75
-msgid "git notes merge --abort [<options>]"
-msgstr "git notes merge --abort [<opciones>]"
+#: builtin/difftool.c:750
+msgid "no <tool> given for --tool=<tool>"
+msgstr "no se ha proporcionado <herramienta> para --tool=<herramienta>"
 
-#: builtin/notes.c:80
-msgid "git notes remove [<object>]"
-msgstr "git notes remove [<objeto>]"
+#: builtin/difftool.c:757
+msgid "no <cmd> given for --extcmd=<cmd>"
+msgstr "no se ha entregado <comando> para --extcmd=<comando>"
 
-#: builtin/notes.c:85
-msgid "git notes prune [<options>]"
-msgstr "git notes prune [<opciones>]"
+#: builtin/env--helper.c:6
+msgid "git env--helper --type=[bool|ulong] <options> <env-var>"
+msgstr "git env--helper --type=[bool|ulong] <opciones> <env-var>"
 
-#: builtin/notes.c:90
-msgid "git notes get-ref"
-msgstr "git notes get-ref"
+#: builtin/env--helper.c:37 builtin/hash-object.c:98
+msgid "type"
+msgstr "tipo"
 
-#: builtin/notes.c:95
-msgid "Write/edit the notes for the following object:"
-msgstr "Escribe/edita las notas para los siguientes objetos:"
+#: builtin/env--helper.c:41
+msgid "default for git_env_*(...) to fall back on"
+msgstr "default para git_env_*(...) es hacer fallback en"
 
-#: builtin/notes.c:148
-#, c-format
-msgid "unable to start 'show' for object '%s'"
-msgstr "incapaz de iniciar 'show' para el objeto '%s'"
+#: builtin/env--helper.c:43
+msgid "be quiet only use git_env_*() value as exit code"
+msgstr "ser silencioso solo usar valor git_env_*() como código de salida"
 
-#: builtin/notes.c:152
-msgid "could not read 'show' output"
-msgstr "no se pudo leer salida de 'show'"
+#: builtin/env--helper.c:62
+#, c-format
+msgid "option `--default' expects a boolean value with `--type=bool`, not `%s`"
+msgstr "opción `--default' espera un valor boolean con `--type=bool`, no `%s`"
 
-#: builtin/notes.c:160
+#: builtin/env--helper.c:77
 #, c-format
-msgid "failed to finish 'show' for object '%s'"
-msgstr "falló la finalización de 'show' para el objeto '%s'"
+msgid ""
+"option `--default' expects an unsigned long value with `--type=ulong`, not `"
+"%s`"
+msgstr ""
+"opción `--default' espera un valor unsigned long con `--type=ulong`, no `%s`"
 
-#: builtin/notes.c:195
-msgid "please supply the note contents using either -m or -F option"
-msgstr "por favor suministrar los contenidos de nota usando la opción -m o -F"
+#: builtin/fast-export.c:29
+msgid "git fast-export [rev-list-opts]"
+msgstr "git fast-export [rev-list-opts]"
 
-#: builtin/notes.c:204
-msgid "unable to write note object"
-msgstr "incapaz de escribir el objeto de nota"
+#: builtin/fast-export.c:852
+msgid "Error: Cannot export nested tags unless --mark-tags is specified."
+msgstr ""
+"Error: No se puede exportar los tags anidados a menos que --mark-tags sea "
+"especificado."
 
-#: builtin/notes.c:206
-#, c-format
-msgid "the note contents have been left in %s"
-msgstr "los contenidos de nota han sido dejados en %s"
+#: builtin/fast-export.c:1152
+msgid "show progress after <n> objects"
+msgstr "mostrar progreso después de <n> objetos"
 
-#: builtin/notes.c:234 builtin/tag.c:507
-#, c-format
-msgid "cannot read '%s'"
-msgstr "no se puede leer '%s'"
+#: builtin/fast-export.c:1154
+msgid "select handling of signed tags"
+msgstr "seleccionar el manejo de tags firmados"
 
-#: builtin/notes.c:236 builtin/tag.c:510
-#, c-format
-msgid "could not open or read '%s'"
-msgstr "no se pudo abrir o leer '%s'"
+#: builtin/fast-export.c:1157
+msgid "select handling of tags that tag filtered objects"
+msgstr "seleccionar el manejo de tags que son tags de objetos filtrados"
 
-#: builtin/notes.c:255 builtin/notes.c:306 builtin/notes.c:308
-#: builtin/notes.c:376 builtin/notes.c:431 builtin/notes.c:517
-#: builtin/notes.c:522 builtin/notes.c:600 builtin/notes.c:662
-#, c-format
-msgid "failed to resolve '%s' as a valid ref."
-msgstr "falló al resolver '%s' como ref válida."
+#: builtin/fast-export.c:1160
+msgid "select handling of commit messages in an alternate encoding"
+msgstr "seleccionar el manejo de mensajes de commit en un encoding diferente"
 
-#: builtin/notes.c:258
-#, c-format
-msgid "failed to read object '%s'."
-msgstr "falló al leer objeto '%s'."
+#: builtin/fast-export.c:1163
+msgid "Dump marks to this file"
+msgstr "Volcar marcas a este archivo"
 
-#: builtin/notes.c:262
-#, c-format
-msgid "cannot read note data from non-blob object '%s'."
-msgstr "no se puede leer la data de la nota de un objeto no-blob '%s'."
+#: builtin/fast-export.c:1165
+msgid "Import marks from this file"
+msgstr "Importar marcas de este archivo"
 
-#: builtin/notes.c:302
-#, c-format
-msgid "malformed input line: '%s'."
-msgstr "línea de entrada mal formada: '%s'."
+#: builtin/fast-export.c:1169
+msgid "Import marks from this file if it exists"
+msgstr "Importar marcas de este archivo si existe"
 
-#: builtin/notes.c:317
-#, c-format
-msgid "failed to copy notes from '%s' to '%s'"
-msgstr "falló al copiar notas de '%s' a '%s'"
+#: builtin/fast-export.c:1171
+msgid "Fake a tagger when tags lack one"
+msgstr "Falsificar un tagger cuando les falta uno"
 
-#. TRANSLATORS: the first %s will be replaced by a git
-#. notes command: 'add', 'merge', 'remove', etc.
-#.
-#: builtin/notes.c:349
-#, c-format
-msgid "refusing to %s notes in %s (outside of refs/notes/)"
-msgstr "rechazando %s notas en %s (fuera de refs/notes/)"
+#: builtin/fast-export.c:1173
+msgid "Output full tree for each commit"
+msgstr "Mostrar todo el árbol para cada commit"
 
-#: builtin/notes.c:369 builtin/notes.c:424 builtin/notes.c:500
-#: builtin/notes.c:512 builtin/notes.c:588 builtin/notes.c:655
-#: builtin/notes.c:805 builtin/notes.c:952 builtin/notes.c:973
-msgid "too many parameters"
-msgstr "demasiados parámetros"
+#: builtin/fast-export.c:1175
+msgid "Use the done feature to terminate the stream"
+msgstr "Use el feature done para terminar el stream"
 
-#: builtin/notes.c:382 builtin/notes.c:668
-#, c-format
-msgid "no note found for object %s."
-msgstr "no se encontraron notas para objeto %s."
+#: builtin/fast-export.c:1176
+msgid "Skip output of blob data"
+msgstr "Saltar el output de data blob"
 
-#: builtin/notes.c:403 builtin/notes.c:566
-msgid "note contents as a string"
-msgstr "contenidos de la nota como cadena"
+#: builtin/fast-export.c:1177 builtin/log.c:1705
+msgid "refspec"
+msgstr "refspec"
 
-#: builtin/notes.c:406 builtin/notes.c:569
-msgid "note contents in a file"
-msgstr "contenidos de la nota en un archivo"
+#: builtin/fast-export.c:1178
+msgid "Apply refspec to exported refs"
+msgstr "Aplicar refspec para los refs exportados"
 
-#: builtin/notes.c:409 builtin/notes.c:572
-msgid "reuse and edit specified note object"
-msgstr "reutilizar y editar el objeto de nota especificada"
+#: builtin/fast-export.c:1179
+msgid "anonymize output"
+msgstr "anonimizar la salida"
 
-#: builtin/notes.c:412 builtin/notes.c:575
-msgid "reuse specified note object"
-msgstr "reutilizar el objeto de nota especificado"
+#: builtin/fast-export.c:1181
+msgid "Reference parents which are not in fast-export stream by object id"
+msgstr ""
+"Padres de la referencia que no estan en fast-export stream por id de objeto"
 
-#: builtin/notes.c:415 builtin/notes.c:578
-msgid "allow storing empty note"
-msgstr "permitir almacenar nota vacía"
+#: builtin/fast-export.c:1183
+msgid "Show original object ids of blobs/commits"
+msgstr "Mostrar ids de objetos originales para blobs/commits"
 
-#: builtin/notes.c:416 builtin/notes.c:487
-msgid "replace existing notes"
-msgstr "reemplazar notas existentes"
+#: builtin/fast-export.c:1185
+msgid "Label tags with mark ids"
+msgstr "Marcar tags con ids de mark"
 
-#: builtin/notes.c:441
-#, c-format
-msgid ""
-"Cannot add notes. Found existing notes for object %s. Use '-f' to overwrite "
-"existing notes"
-msgstr ""
-"No se puede agregar notas. Se encontró notas existentes para objeto %s. Use "
-"'-f' para sobrescribir las notas existentes"
+#: builtin/fast-export.c:1220
+msgid "Cannot pass both --import-marks and --import-marks-if-exists"
+msgstr "No se puede pasar ambos --import-marks y --import-marks-if-exists"
 
-#: builtin/notes.c:456 builtin/notes.c:535
-#, c-format
-msgid "Overwriting existing notes for object %s\n"
-msgstr "Sobrescribiendo notas existentes para objeto %s\n"
+#: builtin/fetch.c:34
+msgid "git fetch [<options>] [<repository> [<refspec>...]]"
+msgstr "git fetch [<opciones>] [<repositorio> [<refspec>...]]"
 
-#: builtin/notes.c:467 builtin/notes.c:627 builtin/notes.c:892
-#, c-format
-msgid "Removing note for object %s\n"
-msgstr "Removiendo nota para objeto %s\n"
+#: builtin/fetch.c:35
+msgid "git fetch [<options>] <group>"
+msgstr "git fetch [<opciones>] <grupo>"
 
-#: builtin/notes.c:488
-msgid "read objects from stdin"
-msgstr "leer objetos desde stdin"
+#: builtin/fetch.c:36
+msgid "git fetch --multiple [<options>] [(<repository> | <group>)...]"
+msgstr "git fetch --multiple [<opciones>] [(<repositorio> | <grupo>)...]"
 
-#: builtin/notes.c:490
-msgid "load rewriting config for <command> (implies --stdin)"
-msgstr "cargar configuración de reescritura para <comando> (implica --stdin)"
+#: builtin/fetch.c:37
+msgid "git fetch --all [<options>]"
+msgstr "git fetch --all [<opciones>]"
 
-#: builtin/notes.c:508
-msgid "too few parameters"
-msgstr "muy pocos parámetros"
+#: builtin/fetch.c:116
+msgid "fetch.parallel cannot be negative"
+msgstr "fetch.parallel no puede ser negativo"
 
-#: builtin/notes.c:529
-#, c-format
-msgid ""
-"Cannot copy notes. Found existing notes for object %s. Use '-f' to overwrite "
-"existing notes"
-msgstr ""
-"No se puede copiar notas. Se encontró notas existentes para el objeto %s. "
-"Use '-f' para sobrescribir las notes existentes"
+#: builtin/fetch.c:139 builtin/pull.c:204
+msgid "fetch from all remotes"
+msgstr "extraer de todos los remotos"
 
-#: builtin/notes.c:541
-#, c-format
-msgid "missing notes on source object %s. Cannot copy."
-msgstr "faltan notas en la fuente del objeto %s. No se puede copiar."
+#: builtin/fetch.c:141 builtin/pull.c:248
+msgid "set upstream for git pull/fetch"
+msgstr "configurar upstream para git pulll/fetch"
 
-#: builtin/notes.c:593
-#, c-format
-msgid ""
-"The -m/-F/-c/-C options have been deprecated for the 'edit' subcommand.\n"
-"Please use 'git notes add -f -m/-F/-c/-C' instead.\n"
-msgstr ""
-"Las opciones -m/-F/-c/-C han sido deprecadas por el subcomando 'edit'.\n"
-"Por favor use 'git notes add -f -m/-F/-c/-C' en cambio.\n"
+#: builtin/fetch.c:143 builtin/pull.c:207
+msgid "append to .git/FETCH_HEAD instead of overwriting"
+msgstr "adjuntar a .git/FETCH_HEAD en lugar de sobrescribir"
 
-#: builtin/notes.c:688
-msgid "failed to delete ref NOTES_MERGE_PARTIAL"
-msgstr "falló al borrar ref NOTES_MERGE_PARTIAL"
+#: builtin/fetch.c:145 builtin/pull.c:210
+msgid "path to upload pack on remote end"
+msgstr "ruta para cargar el paquete al final del remoto"
 
-#: builtin/notes.c:690
-msgid "failed to delete ref NOTES_MERGE_REF"
-msgstr "falló al borrar ref NOTES_MERGE_REF"
+#: builtin/fetch.c:146
+msgid "force overwrite of local reference"
+msgstr "forzar sobrescritura de referencia local"
 
-#: builtin/notes.c:692
-msgid "failed to remove 'git notes merge' worktree"
-msgstr "no se pudo eliminar el árbol de trabajo 'git notes merge'"
+#: builtin/fetch.c:148
+msgid "fetch from multiple remotes"
+msgstr "extraer de múltiples remotos"
 
-#: builtin/notes.c:712
-msgid "failed to read ref NOTES_MERGE_PARTIAL"
-msgstr "falló al leer ref NOTES_MERGE_PARTIAL"
+#: builtin/fetch.c:150 builtin/pull.c:214
+msgid "fetch all tags and associated objects"
+msgstr "extraer todos los tags y objetos asociados"
 
-#: builtin/notes.c:714
-msgid "could not find commit from NOTES_MERGE_PARTIAL."
-msgstr "no se pudo encontrar commit de NOTES_MERGE_PARTIAL."
+#: builtin/fetch.c:152
+msgid "do not fetch all tags (--no-tags)"
+msgstr "no extraer todos los tags (--no-tags)"
 
-#: builtin/notes.c:716
-msgid "could not parse commit from NOTES_MERGE_PARTIAL."
-msgstr "no se pudo analizar commit de NOTES_MERGE_PARTIAL."
+#: builtin/fetch.c:154
+msgid "number of submodules fetched in parallel"
+msgstr "número de submódulos extraídos en paralelo"
 
-#: builtin/notes.c:729
-msgid "failed to resolve NOTES_MERGE_REF"
-msgstr "falló al resolver NOTES_MERGE_REF"
+#: builtin/fetch.c:156 builtin/pull.c:217
+msgid "prune remote-tracking branches no longer on remote"
+msgstr "limpiar ramas remotas rastreadas que ya no están en el remoto"
 
-#: builtin/notes.c:732
-msgid "failed to finalize notes merge"
-msgstr "falló al finalizar las notas de fusión"
+#: builtin/fetch.c:158
+msgid "prune local tags no longer on remote and clobber changed tags"
+msgstr ""
+"limpiar tags locales que no se encuentran en el remoto y eliminar tags "
+"cambiados"
 
-#: builtin/notes.c:758
-#, c-format
-msgid "unknown notes merge strategy %s"
-msgstr "estrategia de fusión de notas %s desconocida"
+#: builtin/fetch.c:159 builtin/fetch.c:182 builtin/pull.c:141
+msgid "on-demand"
+msgstr "en demanda"
 
-#: builtin/notes.c:774
-msgid "General options"
-msgstr "Opciones generales"
+#: builtin/fetch.c:160
+msgid "control recursive fetching of submodules"
+msgstr "controlar extracción recursiva de submódulos"
 
-#: builtin/notes.c:776
-msgid "Merge options"
-msgstr "Opciones de fusión"
+#: builtin/fetch.c:164 builtin/pull.c:225
+msgid "keep downloaded pack"
+msgstr "mantener el paquete descargado"
 
-#: builtin/notes.c:778
-msgid ""
-"resolve notes conflicts using the given strategy (manual/ours/theirs/union/"
-"cat_sort_uniq)"
-msgstr ""
-"resolver conflictos de notas usando la estrategia entregadas (manual/ours/"
-"theirs/union/cat_sort_uniq)"
+#: builtin/fetch.c:166
+msgid "allow updating of HEAD ref"
+msgstr "permitir actualizar la ref HEAD"
 
-#: builtin/notes.c:780
-msgid "Committing unmerged notes"
-msgstr "Realizando commit a las notas no fusionadas"
+#: builtin/fetch.c:169 builtin/fetch.c:175 builtin/pull.c:228
+msgid "deepen history of shallow clone"
+msgstr "historia profunda de un clon superficial"
 
-#: builtin/notes.c:782
-msgid "finalize notes merge by committing unmerged notes"
-msgstr ""
-"finalizar fusión de notas realizando un commit de las notas no fusionadas"
+#: builtin/fetch.c:171
+msgid "deepen history of shallow repository based on time"
+msgstr "historia profunda de un repositorio superficial basado en tiempo"
 
-#: builtin/notes.c:784
-msgid "Aborting notes merge resolution"
-msgstr "Abortando notas de resolución de fusión"
+#: builtin/fetch.c:177 builtin/pull.c:231
+msgid "convert to a complete repository"
+msgstr "convertir a un repositorio completo"
 
-#: builtin/notes.c:786
-msgid "abort notes merge"
-msgstr "abortar notas de fusión"
+#: builtin/fetch.c:180
+msgid "prepend this to submodule path output"
+msgstr "anteponer esto a salida de la ruta del submódulo"
 
-#: builtin/notes.c:797
-msgid "cannot mix --commit, --abort or -s/--strategy"
-msgstr "no se pueden mezclar --commit, --abort ó -s/--strategy"
+#: builtin/fetch.c:183
+msgid ""
+"default for recursive fetching of submodules (lower priority than config "
+"files)"
+msgstr ""
+"default para extracción recursiva de submódulos (menor prioridad que "
+"archivos de configuración)"
 
-#: builtin/notes.c:802
-msgid "must specify a notes ref to merge"
-msgstr "debe especificar una ref de notas a fusionar"
+#: builtin/fetch.c:187 builtin/pull.c:234
+msgid "accept refs that update .git/shallow"
+msgstr "aceptar refs que actualicen .git/shallow"
 
-#: builtin/notes.c:826
-#, c-format
-msgid "unknown -s/--strategy: %s"
-msgstr "--strategy/-s desconocida: %s"
+#: builtin/fetch.c:188 builtin/pull.c:236
+msgid "refmap"
+msgstr "refmap"
 
-#: builtin/notes.c:863
-#, c-format
-msgid "a notes merge into %s is already in-progress at %s"
-msgstr "una fusión de notas en %s ya está en progreso en %s"
+#: builtin/fetch.c:189 builtin/pull.c:237
+msgid "specify fetch refmap"
+msgstr "especificar extracción de refmap"
 
-#: builtin/notes.c:866
-#, c-format
-msgid "failed to store link to current notes ref (%s)"
-msgstr "falló al guardar un link para el ref de notas actual (%s)"
+#: builtin/fetch.c:196
+msgid "report that we have only objects reachable from this object"
+msgstr "reporta que solo tenemos objetos alcanzables de este objeto"
+
+#: builtin/fetch.c:199
+msgid "run 'gc --auto' after fetching"
+msgstr "ejecutar 'gc --auto' tras el fetch"
+
+#: builtin/fetch.c:201 builtin/pull.c:246
+msgid "check for forced-updates on all updated branches"
+msgstr "verificar updates forzados en todos los branch actualizados"
+
+#: builtin/fetch.c:203
+msgid "write the commit-graph after fetching"
+msgstr "escribir commit-graph luego del fetch"
+
+#: builtin/fetch.c:513
+msgid "Couldn't find remote ref HEAD"
+msgstr "No se puedo encontrar ref remota HEAD"
 
-#: builtin/notes.c:868
+#: builtin/fetch.c:653
 #, c-format
-msgid ""
-"Automatic notes merge failed. Fix conflicts in %s and commit the result with "
-"'git notes merge --commit', or abort the merge with 'git notes merge --"
-"abort'.\n"
-msgstr ""
-"Fusión automática de notas falló. Arregle conflictos en %s y realice un "
-"commit con el resultado 'git notes merge --commit', o aborte la fusión con "
-"'git notes merge --abort'.\n"
+msgid "configuration fetch.output contains invalid value %s"
+msgstr "la configuración fetch.output contiene el valor inválido %s"
 
-#: builtin/notes.c:890
+#: builtin/fetch.c:751
 #, c-format
-msgid "Object %s has no note\n"
-msgstr "El objeto %s no tiene notas\n"
+msgid "object %s not found"
+msgstr "objeto %s no encontrado"
 
-#: builtin/notes.c:902
-msgid "attempt to remove non-existent note is not an error"
-msgstr "intentar remover una nota no existente no es un error"
+#: builtin/fetch.c:755
+msgid "[up to date]"
+msgstr "[actualizado]"
 
-#: builtin/notes.c:905
-msgid "read object names from the standard input"
-msgstr "leer nombres de objetos de standard input"
+#: builtin/fetch.c:768 builtin/fetch.c:784 builtin/fetch.c:856
+msgid "[rejected]"
+msgstr "[rechazado]"
 
-#: builtin/notes.c:943 builtin/prune.c:107 builtin/worktree.c:151
-msgid "do not remove, show only"
-msgstr "no remover, solo mostrar"
+#: builtin/fetch.c:769
+msgid "can't fetch in current branch"
+msgstr "no se puede traer en la rama actual"
 
-#: builtin/notes.c:944
-msgid "report pruned notes"
-msgstr "reportar notas recortadas"
+#: builtin/fetch.c:779
+msgid "[tag update]"
+msgstr "[actualización de tag]"
 
-#: builtin/notes.c:986
-msgid "notes-ref"
-msgstr "referencia-de-notas"
+#: builtin/fetch.c:780 builtin/fetch.c:817 builtin/fetch.c:839
+#: builtin/fetch.c:851
+msgid "unable to update local ref"
+msgstr "no se posible actualizar el ref local"
 
-#: builtin/notes.c:987
-msgid "use notes from <notes-ref>"
-msgstr "usar notas desde <referencia-de-notas>"
+#: builtin/fetch.c:784
+msgid "would clobber existing tag"
+msgstr "podría golpear tag existente"
 
-#: builtin/notes.c:1022
-#, c-format
-msgid "unknown subcommand: %s"
-msgstr "subcomando desconocido: %s"
+#: builtin/fetch.c:806
+msgid "[new tag]"
+msgstr "[nuevo tag]"
+
+#: builtin/fetch.c:809
+msgid "[new branch]"
+msgstr "[nueva rama]"
+
+#: builtin/fetch.c:812
+msgid "[new ref]"
+msgstr "[nueva referencia]"
 
-#: builtin/pack-objects.c:48
+#: builtin/fetch.c:851
+msgid "forced update"
+msgstr "actualización forzada"
+
+#: builtin/fetch.c:856
+msgid "non-fast-forward"
+msgstr "avance lento"
+
+#: builtin/fetch.c:877
 msgid ""
-"git pack-objects --stdout [<options>...] [< <ref-list> | < <object-list>]"
+"Fetch normally indicates which branches had a forced update,\n"
+"but that check has been disabled. To re-enable, use '--show-forced-updates'\n"
+"flag or run 'git config fetch.showForcedUpdates true'."
 msgstr ""
-"git pack-objects --stdout [<opciones>...] [< <lista-de-ref> | < <lista-de-"
-"objetos>]"
+"Fetch normalmente incida qué branches han tenido un update forzado,\n"
+"pero esa validación ha sido deshabilitada. Para activarla de nuevo use '--"
+"show-forced-updates'\n"
+"o ejecute 'git config fetch.showForcedUpdates true'."
 
-#: builtin/pack-objects.c:49
+#: builtin/fetch.c:881
+#, c-format
 msgid ""
-"git pack-objects [<options>...] <base-name> [< <ref-list> | < <object-list>]"
+"It took %.2f seconds to check forced updates. You can use\n"
+"'--no-show-forced-updates' or run 'git config fetch.showForcedUpdates "
+"false'\n"
+" to avoid this check.\n"
 msgstr ""
-"git pack-objects [<opciones>...] <nombre-base> [< <lista-de-refs> | < <lista-"
-"de-objetos>]"
+"Tomó %.2f segundos validar los updates forzados. Puedes usar\n"
+"'--no-show-forced-updates' o ejecutar 'git config fetch.showForcedUpdates "
+"false'\n"
+"para evitar esta validación.\n"
 
-#: builtin/pack-objects.c:211 builtin/pack-objects.c:214
+#: builtin/fetch.c:911
 #, c-format
-msgid "deflate error (%d)"
-msgstr "error al desinflar (%d)"
+msgid "%s did not send all necessary objects\n"
+msgstr "%s no envió todos los objetos necesarios\n"
 
-#: builtin/pack-objects.c:810
-msgid "disabling bitmap writing, packs are split due to pack.packSizeLimit"
-msgstr ""
-"deshabilitando escritura bitmap, paquetes son divididos debido a pack."
-"packSizeLimit"
+#: builtin/fetch.c:932
+#, c-format
+msgid "reject %s because shallow roots are not allowed to be updated"
+msgstr "rechazado %s porque raíces superficiales no pueden ser actualizadas"
 
-#: builtin/pack-objects.c:823
-msgid "Writing objects"
-msgstr "Escribiendo objetos"
+#: builtin/fetch.c:1017 builtin/fetch.c:1155
+#, c-format
+msgid "From %.*s\n"
+msgstr "Desde %.*s\n"
 
-#: builtin/pack-objects.c:1106
-msgid "disabling bitmap writing, as some objects are not being packed"
+#: builtin/fetch.c:1028
+#, c-format
+msgid ""
+"some local refs could not be updated; try running\n"
+" 'git remote prune %s' to remove any old, conflicting branches"
 msgstr ""
-"deshabilitando escritura bitmap, ya que algunos objetos no están siendo "
-"empaquetados"
+"algunos refs locales no pudieron ser actualizados; intente ejecutar\n"
+" 'git remote prune %s' para eliminar cualquier rama vieja o conflictiva"
 
-#: builtin/pack-objects.c:1765
-msgid "Counting objects"
-msgstr "Contando objetos"
+#: builtin/fetch.c:1125
+#, c-format
+msgid "   (%s will become dangling)"
+msgstr "   (%s se pondrá colgado)"
 
-#: builtin/pack-objects.c:1895
+#: builtin/fetch.c:1126
 #, c-format
-msgid "unable to get size of %s"
-msgstr "no se pudo obtener el tamaño de %s"
+msgid "   (%s has become dangling)"
+msgstr "   (%s se ha colgado)"
+
+#: builtin/fetch.c:1158
+msgid "[deleted]"
+msgstr "[eliminado]"
+
+#: builtin/fetch.c:1159 builtin/remote.c:1035
+msgid "(none)"
+msgstr "(nada)"
 
-#: builtin/pack-objects.c:1910
+#: builtin/fetch.c:1182
 #, c-format
-msgid "unable to parse object header of %s"
-msgstr "incapaz de analizar header del objeto %s"
+msgid "Refusing to fetch into current branch %s of non-bare repository"
+msgstr "Rehusando extraer en la rama actual %s de un repositorio no vacío"
 
-#: builtin/pack-objects.c:2564
-msgid "Compressing objects"
-msgstr "Comprimiendo objetos"
+#: builtin/fetch.c:1201
+#, c-format
+msgid "Option \"%s\" value \"%s\" is not valid for %s"
+msgstr "Opción \"%s\" valor \"%s\" no es válido para %s"
 
-#: builtin/pack-objects.c:2735
-msgid "invalid value for --missing"
-msgstr "valor inválido para --missing"
+#: builtin/fetch.c:1204
+#, c-format
+msgid "Option \"%s\" is ignored for %s\n"
+msgstr "Opción \"%s\" es ignorada por %s\n"
+
+#: builtin/fetch.c:1412
+msgid "multiple branches detected, incompatible with --set-upstream"
+msgstr "múltiples ramas detectadas, incompatible con --set-upstream"
+
+#: builtin/fetch.c:1427
+msgid "not setting upstream for a remote remote-tracking branch"
+msgstr "no configurar upstream para una rama de rastreo remoto"
+
+#: builtin/fetch.c:1429
+msgid "not setting upstream for a remote tag"
+msgstr "no configurar upstream para un tag remoto"
+
+#: builtin/fetch.c:1431
+msgid "unknown branch type"
+msgstr "tipo de branch desconocido"
+
+#: builtin/fetch.c:1433
+msgid ""
+"no source branch found.\n"
+"you need to specify exactly one branch with the --set-upstream option."
+msgstr ""
+"no se encontró rama fuente.\n"
+"tienes que especificar exactamente una rama con la opción --set-upstream."
 
-#: builtin/pack-objects.c:3067
+#: builtin/fetch.c:1559 builtin/fetch.c:1622
 #, c-format
-msgid "unsupported index version %s"
-msgstr "versión de índice no soportada %s"
+msgid "Fetching %s\n"
+msgstr "Extrayendo %s\n"
 
-#: builtin/pack-objects.c:3071
+#: builtin/fetch.c:1569 builtin/fetch.c:1624 builtin/remote.c:100
 #, c-format
-msgid "bad index version '%s'"
-msgstr "mala versión del índice '%s'"
+msgid "Could not fetch %s"
+msgstr "No se pudo extraer %s"
 
-#: builtin/pack-objects.c:3102
-msgid "do not show progress meter"
-msgstr "no mostrar medidor de progreso"
+#: builtin/fetch.c:1581
+#, c-format
+msgid "could not fetch '%s' (exit code: %d)\n"
+msgstr "no se pudo hacer fetch a '%s' (código de salida: %d)\n"
 
-#: builtin/pack-objects.c:3104
-msgid "show progress meter"
-msgstr "mostrar medidor de progreso"
+#: builtin/fetch.c:1684
+msgid ""
+"No remote repository specified.  Please, specify either a URL or a\n"
+"remote name from which new revisions should be fetched."
+msgstr ""
+"No hay repositorio remoto especificado. Por favor, especifique un URL o un\n"
+"nombre remoto del cual las nuevas revisiones deben ser extraídas."
 
-#: builtin/pack-objects.c:3106
-msgid "show progress meter during object writing phase"
-msgstr "mostrar medidor de progreso durante la fase de escritura de objeto"
+#: builtin/fetch.c:1721
+msgid "You need to specify a tag name."
+msgstr "Tienes que especificar un nombre de tag."
 
-#: builtin/pack-objects.c:3109
-msgid "similar to --all-progress when progress meter is shown"
-msgstr "similar a --all-progress cuando medidor de progreso es mostrado"
+#: builtin/fetch.c:1771
+msgid "Negative depth in --deepen is not supported"
+msgstr "Profundidad negativa en --deepen no soportada"
 
-#: builtin/pack-objects.c:3110
-msgid "version[,offset]"
-msgstr "versión[,offset]"
+#: builtin/fetch.c:1773
+msgid "--deepen and --depth are mutually exclusive"
+msgstr "--deepen y --depth son mutuamente exclusivas"
 
-#: builtin/pack-objects.c:3111
-msgid "write the pack index file in the specified idx format version"
+#: builtin/fetch.c:1778
+msgid "--depth and --unshallow cannot be used together"
+msgstr "--depth y --unshallow no pueden ser usadas juntas"
+
+#: builtin/fetch.c:1780
+msgid "--unshallow on a complete repository does not make sense"
+msgstr "--unshallow no tiene sentido en un repositorio completo"
+
+#: builtin/fetch.c:1796
+msgid "fetch --all does not take a repository argument"
+msgstr "fetch --all no toma un argumento de repositorio"
+
+#: builtin/fetch.c:1798
+msgid "fetch --all does not make sense with refspecs"
+msgstr "fetch --all no tiene sentido con refspecs"
+
+#: builtin/fetch.c:1807
+#, c-format
+msgid "No such remote or remote group: %s"
+msgstr "No existe el remoto o grupo remoto: %s"
+
+#: builtin/fetch.c:1814
+msgid "Fetching a group and specifying refspecs does not make sense"
+msgstr "Extraer un grupo y especificar un refspecs no tiene sentido"
+
+#: builtin/fetch.c:1832
+msgid ""
+"--filter can only be used with the remote configured in extensions."
+"partialclone"
 msgstr ""
-"escribir el índice de paquete en la versión de formato idx especificado"
+"--filter solo puede ser usado con el remoto configurado en extensions."
+"partialClone"
 
-#: builtin/pack-objects.c:3114
-msgid "maximum size of each output pack file"
-msgstr "tamaño máximo de cada paquete resultante"
+#: builtin/fmt-merge-msg.c:18
+msgid ""
+"git fmt-merge-msg [-m <message>] [--log[=<n>] | --no-log] [--file <file>]"
+msgstr ""
+"git fmt-merge-msg [-m <mensaje>] [--log[=<n>] | --no-log] [--file <archivo>]"
 
-#: builtin/pack-objects.c:3116
-msgid "ignore borrowed objects from alternate object store"
-msgstr "ignorar objetos prestados de otros almacenes de objetos"
+#: builtin/fmt-merge-msg.c:674
+msgid "populate log with at most <n> entries from shortlog"
+msgstr "poblar el log con máximo <n> entradas del shorlog"
 
-#: builtin/pack-objects.c:3118
-msgid "ignore packed objects"
-msgstr "ignorar objetos paquete"
+#: builtin/fmt-merge-msg.c:677
+msgid "alias for --log (deprecated)"
+msgstr "alias para --log (deprecado)"
 
-#: builtin/pack-objects.c:3120
-msgid "limit pack window by objects"
-msgstr "limitar ventana de paquete por objetos"
+#: builtin/fmt-merge-msg.c:680
+msgid "text"
+msgstr "texto"
 
-#: builtin/pack-objects.c:3122
-msgid "limit pack window by memory in addition to object limit"
-msgstr "limitar ventana de paquete por memoria en adición a límite de objetos"
+#: builtin/fmt-merge-msg.c:681
+msgid "use <text> as start of message"
+msgstr "use <text> como comienzo de mensaje"
 
-#: builtin/pack-objects.c:3124
-msgid "maximum length of delta chain allowed in the resulting pack"
-msgstr "longitud máxima de cadena delta permitida en el paquete resultante"
+#: builtin/fmt-merge-msg.c:682
+msgid "file to read from"
+msgstr "archivo del cual leer"
 
-#: builtin/pack-objects.c:3126
-msgid "reuse existing deltas"
-msgstr "reusar deltas existentes"
+#: builtin/for-each-ref.c:10
+msgid "git for-each-ref [<options>] [<pattern>]"
+msgstr "git for-each-ref [<opciones>] [<patrón>]"
 
-#: builtin/pack-objects.c:3128
-msgid "reuse existing objects"
-msgstr "reutilizar objetos existentes"
+#: builtin/for-each-ref.c:11
+msgid "git for-each-ref [--points-at <object>]"
+msgstr "git for-each-ref [--points-at <objeto>]"
 
-#: builtin/pack-objects.c:3130
-msgid "use OFS_DELTA objects"
-msgstr "usar objetos OFS_DELTA"
+#: builtin/for-each-ref.c:12
+msgid "git for-each-ref [(--merged | --no-merged) [<commit>]]"
+msgstr "git for-each-ref [(--merged | --no-merged) [<commit>]]"
 
-#: builtin/pack-objects.c:3132
-msgid "use threads when searching for best delta matches"
-msgstr "usar hilos cuando se busque para mejores concordancias de delta"
+#: builtin/for-each-ref.c:13
+msgid "git for-each-ref [--contains [<commit>]] [--no-contains [<commit>]]"
+msgstr "git for-each-ref [--contains [<commit>]] [--no-contains [<commit>]]"
 
-#: builtin/pack-objects.c:3134
-msgid "do not create an empty pack output"
-msgstr "no crear un paquete resultante vacío"
+#: builtin/for-each-ref.c:28
+msgid "quote placeholders suitably for shells"
+msgstr "cite los marcadores de posición adecuadamente para los shells"
 
-#: builtin/pack-objects.c:3136
-msgid "read revision arguments from standard input"
-msgstr "leer argumentos de revisión de standard input"
+#: builtin/for-each-ref.c:30
+msgid "quote placeholders suitably for perl"
+msgstr "cite los marcadores de posición adecuadamente para perl"
 
-#: builtin/pack-objects.c:3138
-msgid "limit the objects to those that are not yet packed"
-msgstr "limitar los objetos a aquellos que no han sido empaquetados todavía"
+#: builtin/for-each-ref.c:32
+msgid "quote placeholders suitably for python"
+msgstr "cite los marcadores de posición adecuadamente para python"
 
-#: builtin/pack-objects.c:3141
-msgid "include objects reachable from any reference"
-msgstr "incluir objetos alcanzables por cualquier referencia"
+#: builtin/for-each-ref.c:34
+msgid "quote placeholders suitably for Tcl"
+msgstr "cite los marcadores de posición adecuadamente para Tcl"
 
-#: builtin/pack-objects.c:3144
-msgid "include objects referred by reflog entries"
-msgstr "incluir objetos referidos por entradas de reflog"
+#: builtin/for-each-ref.c:37
+msgid "show only <n> matched refs"
+msgstr "mostrar solo <n> refs encontradas"
 
-#: builtin/pack-objects.c:3147
-msgid "include objects referred to by the index"
-msgstr "incluir objetos referidos por el índice"
+#: builtin/for-each-ref.c:39 builtin/tag.c:439
+msgid "respect format colors"
+msgstr "respetar el formato de colores"
 
-#: builtin/pack-objects.c:3150
-msgid "output pack to stdout"
-msgstr "mostrar paquete en stdout"
+#: builtin/for-each-ref.c:42
+msgid "print only refs which points at the given object"
+msgstr "mostrar solo refs que apunten al objeto dado"
 
-#: builtin/pack-objects.c:3152
-msgid "include tag objects that refer to objects to be packed"
-msgstr "incluir objetos tag que refieren a objetos a ser empaquetados"
+#: builtin/for-each-ref.c:44
+msgid "print only refs that are merged"
+msgstr "mostrar solo refs que son fusionadas"
 
-#: builtin/pack-objects.c:3154
-msgid "keep unreachable objects"
-msgstr "mantener objetos inalcanzables"
+#: builtin/for-each-ref.c:45
+msgid "print only refs that are not merged"
+msgstr "mostrar solo refs que no son fusionadas"
 
-#: builtin/pack-objects.c:3156
-msgid "pack loose unreachable objects"
-msgstr "empaquetar objetos sueltos inalcanzables"
+#: builtin/for-each-ref.c:46
+msgid "print only refs which contain the commit"
+msgstr "mostrar solo refs que contienen el commit"
 
-#: builtin/pack-objects.c:3158
-msgid "unpack unreachable objects newer than <time>"
-msgstr "desempaquetar objetos inalcanzables más nuevos que <tiempo>"
+#: builtin/for-each-ref.c:47
+msgid "print only refs which don't contain the commit"
+msgstr "mostrar solo refs que no contienen el commit"
+
+#: builtin/fsck.c:68 builtin/fsck.c:147 builtin/fsck.c:148
+msgid "unknown"
+msgstr "desconocido"
+
+#. TRANSLATORS: e.g. error in tree 01bfda: <more explanation>
+#: builtin/fsck.c:100 builtin/fsck.c:120
+#, c-format
+msgid "error in %s %s: %s"
+msgstr "error en %s %s: %s"
+
+#. TRANSLATORS: e.g. warning in tree 01bfda: <more explanation>
+#: builtin/fsck.c:114
+#, c-format
+msgid "warning in %s %s: %s"
+msgstr "peligro en %s %s: %s"
+
+#: builtin/fsck.c:143 builtin/fsck.c:146
+#, c-format
+msgid "broken link from %7s %s"
+msgstr "link roto de %7s %s"
+
+#: builtin/fsck.c:155
+msgid "wrong object type in link"
+msgstr "tipo de objeto equivocado en link"
+
+#: builtin/fsck.c:171
+#, c-format
+msgid ""
+"broken link from %7s %s\n"
+"              to %7s %s"
+msgstr ""
+"link roto de %7s %s\n"
+"              a %7s %s"
+
+#: builtin/fsck.c:282
+#, c-format
+msgid "missing %s %s"
+msgstr "faltan %s %s"
+
+#: builtin/fsck.c:309
+#, c-format
+msgid "unreachable %s %s"
+msgstr "inalcanzable %s %s"
+
+#: builtin/fsck.c:329
+#, c-format
+msgid "dangling %s %s"
+msgstr "actualizando %s %s"
+
+#: builtin/fsck.c:339
+msgid "could not create lost-found"
+msgstr "no se pudo crear lost-found"
+
+#: builtin/fsck.c:350
+#, c-format
+msgid "could not finish '%s'"
+msgstr "no se pudo finalizar '%s'"
+
+#: builtin/fsck.c:367
+#, c-format
+msgid "Checking %s"
+msgstr "Revisando %s"
+
+#: builtin/fsck.c:405
+#, c-format
+msgid "Checking connectivity (%d objects)"
+msgstr "Verificando conectividad (%d objetos)"
+
+#: builtin/fsck.c:424
+#, c-format
+msgid "Checking %s %s"
+msgstr "Revisando %s %s"
+
+#: builtin/fsck.c:429
+msgid "broken links"
+msgstr "links rotos"
+
+#: builtin/fsck.c:438
+#, c-format
+msgid "root %s"
+msgstr "raíz %s"
+
+#: builtin/fsck.c:446
+#, c-format
+msgid "tagged %s %s (%s) in %s"
+msgstr "tag %s %s (%s) en %s"
+
+#: builtin/fsck.c:475
+#, c-format
+msgid "%s: object corrupt or missing"
+msgstr "%s: objecto corrupto o faltante"
+
+#: builtin/fsck.c:500
+#, c-format
+msgid "%s: invalid reflog entry %s"
+msgstr "%s: referencia inválida %s"
+
+#: builtin/fsck.c:514
+#, c-format
+msgid "Checking reflog %s->%s"
+msgstr "Revisando reflog %s->%s"
+
+#: builtin/fsck.c:548
+#, c-format
+msgid "%s: invalid sha1 pointer %s"
+msgstr "%s: puntero sha1 inválido %s"
+
+#: builtin/fsck.c:555
+#, c-format
+msgid "%s: not a commit"
+msgstr "%s: no es un commit"
+
+#: builtin/fsck.c:609
+msgid "notice: No default references"
+msgstr "aviso: No hay referencias por defecto"
+
+#: builtin/fsck.c:624
+#, c-format
+msgid "%s: object corrupt or missing: %s"
+msgstr "%s: objeto corrupto o no encontrado: %s"
+
+#: builtin/fsck.c:637
+#, c-format
+msgid "%s: object could not be parsed: %s"
+msgstr "%s: no se puede analizar objeto: %s"
+
+#: builtin/fsck.c:657
+#, c-format
+msgid "bad sha1 file: %s"
+msgstr "mal sha1 de archivo: %s"
+
+#: builtin/fsck.c:672
+msgid "Checking object directory"
+msgstr "Revisando directorio de objetos"
+
+#: builtin/fsck.c:675
+msgid "Checking object directories"
+msgstr "Revisando objetos directorios"
+
+#: builtin/fsck.c:690
+#, c-format
+msgid "Checking %s link"
+msgstr "Revisando link %s"
+
+#: builtin/fsck.c:695 builtin/index-pack.c:842
+#, c-format
+msgid "invalid %s"
+msgstr "%s inválido"
+
+#: builtin/fsck.c:702
+#, c-format
+msgid "%s points to something strange (%s)"
+msgstr "%s apunta a algo extraño (%s)"
+
+#: builtin/fsck.c:708
+#, c-format
+msgid "%s: detached HEAD points at nothing"
+msgstr "%s: HEAD desacoplado apunta a nada"
+
+#: builtin/fsck.c:712
+#, c-format
+msgid "notice: %s points to an unborn branch (%s)"
+msgstr "aviso: %s apunta a un branch no nacido (%s)"
+
+#: builtin/fsck.c:724
+msgid "Checking cache tree"
+msgstr "Revisando el cache tree"
+
+#: builtin/fsck.c:729
+#, c-format
+msgid "%s: invalid sha1 pointer in cache-tree"
+msgstr "%s: puntero inválido sha1 en cache-tree"
+
+#: builtin/fsck.c:738
+msgid "non-tree in cache-tree"
+msgstr "non-tree en cache-tree"
+
+#: builtin/fsck.c:769
+msgid "git fsck [<options>] [<object>...]"
+msgstr "git fsck [<opciones>] [<objeto>...]"
+
+#: builtin/fsck.c:775
+msgid "show unreachable objects"
+msgstr "mostrar objetos ilegibles"
+
+#: builtin/fsck.c:776
+msgid "show dangling objects"
+msgstr "mostrar objetos colgados"
+
+#: builtin/fsck.c:777
+msgid "report tags"
+msgstr "reportar tags"
+
+#: builtin/fsck.c:778
+msgid "report root nodes"
+msgstr "reportar nodos raíz"
+
+#: builtin/fsck.c:779
+msgid "make index objects head nodes"
+msgstr "hacer objetos índices cabezas de nodos"
+
+#: builtin/fsck.c:780
+msgid "make reflogs head nodes (default)"
+msgstr "hacer reflogs cabeza de nodos (default)"
+
+#: builtin/fsck.c:781
+msgid "also consider packs and alternate objects"
+msgstr "también considerar paquetes y objetos alternos"
+
+#: builtin/fsck.c:782
+msgid "check only connectivity"
+msgstr "revisar solo conectividad"
+
+#: builtin/fsck.c:783
+msgid "enable more strict checking"
+msgstr "habilitar revisión más estricta"
+
+#: builtin/fsck.c:785
+msgid "write dangling objects in .git/lost-found"
+msgstr "escribir objetos colgados en .git/lost-found"
+
+#: builtin/fsck.c:786 builtin/prune.c:132
+msgid "show progress"
+msgstr "mostrar progreso"
+
+#: builtin/fsck.c:787
+msgid "show verbose names for reachable objects"
+msgstr "mostrar nombres verboso para objetos alcanzables"
+
+#: builtin/fsck.c:846 builtin/index-pack.c:225
+msgid "Checking objects"
+msgstr "Revisando objetos"
+
+#: builtin/fsck.c:874
+#, c-format
+msgid "%s: object missing"
+msgstr "%s: objeto faltante"
+
+#: builtin/fsck.c:885
+#, c-format
+msgid "invalid parameter: expected sha1, got '%s'"
+msgstr "parámetro inválido: sha1 esperado, se obtuvo '%s'"
+
+#: builtin/gc.c:35
+msgid "git gc [<options>]"
+msgstr "git gc [<opciones>]"
+
+#: builtin/gc.c:90
+#, c-format
+msgid "Failed to fstat %s: %s"
+msgstr "Falló el fstat %s: %s"
+
+#: builtin/gc.c:126
+#, c-format
+msgid "failed to parse '%s' value '%s'"
+msgstr "falló al analizar '%s' valor '%s'"
+
+#: builtin/gc.c:475 builtin/init-db.c:55
+#, c-format
+msgid "cannot stat '%s'"
+msgstr "no se pudo definir '%s'"
+
+#: builtin/gc.c:484 builtin/notes.c:240 builtin/tag.c:529
+#, c-format
+msgid "cannot read '%s'"
+msgstr "no se puede leer '%s'"
+
+#: builtin/gc.c:491
+#, c-format
+msgid ""
+"The last gc run reported the following. Please correct the root cause\n"
+"and remove %s.\n"
+"Automatic cleanup will not be performed until the file is removed.\n"
+"\n"
+"%s"
+msgstr ""
+"El último gc reportó lo siguiente. Por favor corrige la causa\n"
+"y elimine %s.\n"
+"Limpieza automática no se realizará hasta que el archivo sea eliminado.\n"
+"\n"
+"%s"
+
+#: builtin/gc.c:539
+msgid "prune unreferenced objects"
+msgstr "limpiar objetos no referenciados"
+
+#: builtin/gc.c:541
+msgid "be more thorough (increased runtime)"
+msgstr "ser más exhaustivo (aumentar runtime)"
+
+#: builtin/gc.c:542
+msgid "enable auto-gc mode"
+msgstr "habilitar modo auto-gc"
+
+#: builtin/gc.c:545
+msgid "force running gc even if there may be another gc running"
+msgstr "forzar la ejecución de gc incluso si puede haber otro gc ejecutándose"
+
+#: builtin/gc.c:548
+msgid "repack all other packs except the largest pack"
+msgstr "reempaquetar todos los otros paquetes excepto el paquete más grande"
+
+#: builtin/gc.c:565
+#, c-format
+msgid "failed to parse gc.logexpiry value %s"
+msgstr "falló al analizar valor %s de gc.logexpirity"
+
+#: builtin/gc.c:576
+#, c-format
+msgid "failed to parse prune expiry value %s"
+msgstr "falló al analizar valor %s de prune expiry"
+
+#: builtin/gc.c:596
+#, c-format
+msgid "Auto packing the repository in background for optimum performance.\n"
+msgstr ""
+"Auto empaquetado del repositorio en segundo plano para un performance "
+"óptimo.\n"
+
+#: builtin/gc.c:598
+#, c-format
+msgid "Auto packing the repository for optimum performance.\n"
+msgstr "Auto empaquetado del repositorio para performance óptimo.\n"
+
+#: builtin/gc.c:599
+#, c-format
+msgid "See \"git help gc\" for manual housekeeping.\n"
+msgstr "Vea \"git help gc\" para limpieza manual.\n"
+
+#: builtin/gc.c:639
+#, c-format
+msgid ""
+"gc is already running on machine '%s' pid %<PRIuMAX> (use --force if not)"
+msgstr ""
+"gc ya está ejecutándose en la máquina '%s' pid %<PRIuMAX> (use --force so no "
+"es así)"
+
+#: builtin/gc.c:694
+msgid ""
+"There are too many unreachable loose objects; run 'git prune' to remove them."
+msgstr ""
+"Hay muchos objetos sueltos inalcanzables; ejecute 'git prune' para "
+"eliminarlos."
+
+#: builtin/grep.c:29
+msgid "git grep [<options>] [-e] <pattern> [<rev>...] [[--] <path>...]"
+msgstr "git grep [<opciones>] [-e] <patrón> [<rev>...] [[--] <ruta>...]"
+
+#: builtin/grep.c:225
+#, c-format
+msgid "grep: failed to create thread: %s"
+msgstr "grep: falló al crear el hilo: %s"
+
+#: builtin/grep.c:279
+#, c-format
+msgid "invalid number of threads specified (%d) for %s"
+msgstr "número inválido de hilos especificado (%d) para %s"
+
+#. TRANSLATORS: %s is the configuration
+#. variable for tweaking threads, currently
+#. grep.threads
+#.
+#: builtin/grep.c:287 builtin/index-pack.c:1534 builtin/index-pack.c:1727
+#: builtin/pack-objects.c:2708
+#, c-format
+msgid "no threads support, ignoring %s"
+msgstr "no hay soporte para hilos, ignorando %s"
+
+#: builtin/grep.c:467 builtin/grep.c:592 builtin/grep.c:635
+#, c-format
+msgid "unable to read tree (%s)"
+msgstr "no es posible leer el  árbol (%s)"
+
+#: builtin/grep.c:650
+#, c-format
+msgid "unable to grep from object of type %s"
+msgstr "no es posible realizar grep del objeto de tipo %s"
+
+#: builtin/grep.c:716
+#, c-format
+msgid "switch `%c' expects a numerical value"
+msgstr "switch `%c' espera un valor numérico"
+
+#: builtin/grep.c:815
+msgid "search in index instead of in the work tree"
+msgstr "buscar en el índice en lugar del árbol de trabajo"
+
+#: builtin/grep.c:817
+msgid "find in contents not managed by git"
+msgstr "encontrar en contenidos no manejados por git"
+
+#: builtin/grep.c:819
+msgid "search in both tracked and untracked files"
+msgstr "buscar en archivos rastreados y no rastreados"
+
+#: builtin/grep.c:821
+msgid "ignore files specified via '.gitignore'"
+msgstr "ignorar archivos especificados via '.gitignore'"
+
+#: builtin/grep.c:823
+msgid "recursively search in each submodule"
+msgstr "búsqueda recursiva en cada submódulo"
+
+#: builtin/grep.c:826
+msgid "show non-matching lines"
+msgstr "mostrar líneas que no concuerdan"
+
+#: builtin/grep.c:828
+msgid "case insensitive matching"
+msgstr "búsqueda insensible a mayúsculas"
+
+#: builtin/grep.c:830
+msgid "match patterns only at word boundaries"
+msgstr "concordar patrón solo a los límites de las palabras"
+
+#: builtin/grep.c:832
+msgid "process binary files as text"
+msgstr "procesar archivos binarios como texto"
+
+#: builtin/grep.c:834
+msgid "don't match patterns in binary files"
+msgstr "no concordar patrones en archivos binarios"
+
+#: builtin/grep.c:837
+msgid "process binary files with textconv filters"
+msgstr "procesar archivos binarios con filtros textconv"
+
+#: builtin/grep.c:839
+msgid "search in subdirectories (default)"
+msgstr "buscar en subdirectorios (default)"
+
+#: builtin/grep.c:841
+msgid "descend at most <depth> levels"
+msgstr "descender como máximo <valor-de-profundiad>  niveles"
+
+#: builtin/grep.c:845
+msgid "use extended POSIX regular expressions"
+msgstr "usar expresiones regulares POSIX extendidas"
+
+#: builtin/grep.c:848
+msgid "use basic POSIX regular expressions (default)"
+msgstr "usar expresiones regulares POSIX (default)"
+
+#: builtin/grep.c:851
+msgid "interpret patterns as fixed strings"
+msgstr "interpretar patrones como strings arreglados"
+
+#: builtin/grep.c:854
+msgid "use Perl-compatible regular expressions"
+msgstr "usar expresiones regulares compatibles con Perl"
+
+#: builtin/grep.c:857
+msgid "show line numbers"
+msgstr "mostrar números de línea"
+
+#: builtin/grep.c:858
+msgid "show column number of first match"
+msgstr "mostrar el número de columna de la primer coincidencia"
+
+#: builtin/grep.c:859
+msgid "don't show filenames"
+msgstr "no mostrar nombres de archivo"
+
+#: builtin/grep.c:860
+msgid "show filenames"
+msgstr "mostrar nombres de archivo"
+
+#: builtin/grep.c:862
+msgid "show filenames relative to top directory"
+msgstr "mostrar nombres de archivo relativos al directorio superior"
+
+#: builtin/grep.c:864
+msgid "show only filenames instead of matching lines"
+msgstr "mostrar solo nombres de archivos en lugar de líneas encontradas"
+
+#: builtin/grep.c:866
+msgid "synonym for --files-with-matches"
+msgstr "sinónimo para --files-with-matches"
+
+#: builtin/grep.c:869
+msgid "show only the names of files without match"
+msgstr "mostrar solo los nombres de archivos sin coincidencias"
+
+#: builtin/grep.c:871
+msgid "print NUL after filenames"
+msgstr "imprimir NUL después del nombre de archivo"
+
+#: builtin/grep.c:874
+msgid "show only matching parts of a line"
+msgstr "mostrar solo partes que concuerdan de una línea"
+
+#: builtin/grep.c:876
+msgid "show the number of matches instead of matching lines"
+msgstr "mostrar el número de concordancias en lugar de las líneas concordantes"
+
+#: builtin/grep.c:877
+msgid "highlight matches"
+msgstr "resaltar concordancias"
+
+#: builtin/grep.c:879
+msgid "print empty line between matches from different files"
+msgstr "imprimir una línea vacía entre coincidencias de diferentes archivos"
+
+#: builtin/grep.c:881
+msgid "show filename only once above matches from same file"
+msgstr ""
+"mostrar el nombre de archivo solo una vez para concordancias en el mismo "
+"archivo"
+
+#: builtin/grep.c:884
+msgid "show <n> context lines before and after matches"
+msgstr "mostrar <n> líneas de contexto antes y después de la concordancia"
+
+#: builtin/grep.c:887
+msgid "show <n> context lines before matches"
+msgstr "mostrar <n> líneas de contexto antes de las concordancias"
+
+#: builtin/grep.c:889
+msgid "show <n> context lines after matches"
+msgstr "mostrar <n> líneas de context después de las concordancias"
+
+#: builtin/grep.c:891
+msgid "use <n> worker threads"
+msgstr "usar <n> hilos de trabajo"
+
+#: builtin/grep.c:892
+msgid "shortcut for -C NUM"
+msgstr "atajo para -C NUM"
+
+#: builtin/grep.c:895
+msgid "show a line with the function name before matches"
+msgstr ""
+"mostrar una línea con el nombre de la función antes de las concordancias"
+
+#: builtin/grep.c:897
+msgid "show the surrounding function"
+msgstr "mostrar la función circundante"
+
+#: builtin/grep.c:900
+msgid "read patterns from file"
+msgstr "leer patrones del archivo"
+
+#: builtin/grep.c:902
+msgid "match <pattern>"
+msgstr "concordar <patrón>"
+
+#: builtin/grep.c:904
+msgid "combine patterns specified with -e"
+msgstr "combinar patrones especificados con -e"
+
+#: builtin/grep.c:916
+msgid "indicate hit with exit status without output"
+msgstr "indicar concordancia con exit status sin output"
+
+#: builtin/grep.c:918
+msgid "show only matches from files that match all patterns"
+msgstr ""
+"mostrar solo concordancias con archivos que concuerdan todos los patrones"
+
+#: builtin/grep.c:920
+msgid "show parse tree for grep expression"
+msgstr "mostrar árbol analizado para la expresión grep"
+
+#: builtin/grep.c:924
+msgid "pager"
+msgstr "paginador"
+
+#: builtin/grep.c:924
+msgid "show matching files in the pager"
+msgstr "mostrar archivos concordantes en el paginador"
+
+#: builtin/grep.c:928
+msgid "allow calling of grep(1) (ignored by this build)"
+msgstr "permitir el llamado de grep(1) (ignorado por esta build)"
+
+#: builtin/grep.c:992
+msgid "no pattern given"
+msgstr "no se ha entregado patrón"
+
+#: builtin/grep.c:1028
+msgid "--no-index or --untracked cannot be used with revs"
+msgstr "--no-index o --untracked no se puede usar con revs"
+
+#: builtin/grep.c:1036
+#, c-format
+msgid "unable to resolve revision: %s"
+msgstr "no se posible resolver revisión: %s"
+
+#: builtin/grep.c:1067
+msgid "invalid option combination, ignoring --threads"
+msgstr "combinación de opciones inválida, ignorando --threads"
+
+#: builtin/grep.c:1070 builtin/pack-objects.c:3400
+msgid "no threads support, ignoring --threads"
+msgstr "no se soportan hilos, ignorando --threads"
+
+#: builtin/grep.c:1073 builtin/index-pack.c:1531 builtin/pack-objects.c:2705
+#, c-format
+msgid "invalid number of threads specified (%d)"
+msgstr "número inválido de hilos especificado (%d)"
+
+#: builtin/grep.c:1096
+msgid "--open-files-in-pager only works on the worktree"
+msgstr "--open-files-in-pager solo funciona en el árbol de trabajo"
+
+#: builtin/grep.c:1119
+msgid "option not supported with --recurse-submodules"
+msgstr "opción no soportada con --recurse-submodules"
+
+#: builtin/grep.c:1125
+msgid "--cached or --untracked cannot be used with --no-index"
+msgstr "--cached o --untracked no pueden ser usadas con --no-index"
+
+#: builtin/grep.c:1131
+msgid "--[no-]exclude-standard cannot be used for tracked contents"
+msgstr "--[no-]exclude-standard no puede ser usada para contenido rastreado"
+
+#: builtin/grep.c:1139
+msgid "both --cached and trees are given"
+msgstr "--cached y árboles han sido entregados"
+
+#: builtin/hash-object.c:85
+msgid ""
+"git hash-object [-t <type>] [-w] [--path=<file> | --no-filters] [--stdin] "
+"[--] <file>..."
+msgstr ""
+"git hash-object [-t <tipo>] [-w] [--path=<archivo> | --no-filters] [--stdin] "
+"[--] <archivo>..."
+
+#: builtin/hash-object.c:86
+msgid "git hash-object  --stdin-paths"
+msgstr "git hash-object  --stdin-paths"
+
+#: builtin/hash-object.c:98
+msgid "object type"
+msgstr "tipo de objeto"
+
+#: builtin/hash-object.c:99
+msgid "write the object into the object database"
+msgstr "escribir el objeto en la base de datos de objetos"
+
+#: builtin/hash-object.c:101
+msgid "read the object from stdin"
+msgstr "leer el objeto de stdin"
+
+#: builtin/hash-object.c:103
+msgid "store file as is without filters"
+msgstr "guardar el archivo como es sin filtros"
+
+#: builtin/hash-object.c:104
+msgid ""
+"just hash any random garbage to create corrupt objects for debugging Git"
+msgstr ""
+"solo realizar un hash a cualquier basura random para crear un objeto "
+"corrupto para hacer debugging de Gti"
+
+#: builtin/hash-object.c:105
+msgid "process file as it were from this path"
+msgstr "procesar el archivo como si fuera de esta ruta"
+
+#: builtin/help.c:46
+msgid "print all available commands"
+msgstr "mostrar todos los comandos disponibles"
+
+#: builtin/help.c:47
+msgid "exclude guides"
+msgstr "excluir las guias"
+
+#: builtin/help.c:48
+msgid "print list of useful guides"
+msgstr "mostrar una lista de nociones utiles"
+
+#: builtin/help.c:49
+msgid "print all configuration variable names"
+msgstr "imprimir todos los nombres de variables de configuración"
+
+#: builtin/help.c:51
+msgid "show man page"
+msgstr "mostrar la pagina del manual"
+
+#: builtin/help.c:52
+msgid "show manual in web browser"
+msgstr "mostrar la pagina del manual en un navegador web"
+
+#: builtin/help.c:54
+msgid "show info page"
+msgstr "mostrar la pagina de info"
+
+#: builtin/help.c:56
+msgid "print command description"
+msgstr "imprimir descripción del comando"
+
+#: builtin/help.c:61
+msgid "git help [--all] [--guides] [--man | --web | --info] [<command>]"
+msgstr "git help [--all] [--guides] [--man | --web | --info] [<comando>]"
+
+#: builtin/help.c:77
+#, c-format
+msgid "unrecognized help format '%s'"
+msgstr "formato help no reconocido '%s'"
+
+#: builtin/help.c:104
+msgid "Failed to start emacsclient."
+msgstr "Falló al iniciar emacsclient."
+
+#: builtin/help.c:117
+msgid "Failed to parse emacsclient version."
+msgstr "Falló al analizar la versión de emacsclient."
+
+#: builtin/help.c:125
+#, c-format
+msgid "emacsclient version '%d' too old (< 22)."
+msgstr "la versión '%d' de emacsclient es muy antigua (<22)."
+
+#: builtin/help.c:143 builtin/help.c:165 builtin/help.c:175 builtin/help.c:183
+#, c-format
+msgid "failed to exec '%s'"
+msgstr "falló al ejecutar '%s'"
+
+#: builtin/help.c:221
+#, c-format
+msgid ""
+"'%s': path for unsupported man viewer.\n"
+"Please consider using 'man.<tool>.cmd' instead."
+msgstr ""
+"'%s': ruta para el visualizador del manual no soportada.\n"
+"Por favor considere usar 'man.<herramienta.cmd'."
+
+#: builtin/help.c:233
+#, c-format
+msgid ""
+"'%s': cmd for supported man viewer.\n"
+"Please consider using 'man.<tool>.path' instead."
+msgstr ""
+"'%s': comando no soportado para man viewer.\n"
+"Por favor considere usar 'man.<herramienta>.path."
+
+#: builtin/help.c:350
+#, c-format
+msgid "'%s': unknown man viewer."
+msgstr "'%s': visualizador de man desconocido."
+
+#: builtin/help.c:367
+msgid "no man viewer handled the request"
+msgstr "ningún visualizador de manual proceso la petición"
+
+#: builtin/help.c:375
+msgid "no info viewer handled the request"
+msgstr "ningún visor de info manejo la petición"
+
+#: builtin/help.c:434 builtin/help.c:445 git.c:336
+#, c-format
+msgid "'%s' is aliased to '%s'"
+msgstr "'%s' tiene el alias '%s'"
+
+#: builtin/help.c:448 git.c:365
+#, c-format
+msgid "bad alias.%s string: %s"
+msgstr "mal alias.%s string: %s"
+
+#: builtin/help.c:477 builtin/help.c:507
+#, c-format
+msgid "usage: %s%s"
+msgstr "uso: %s%s"
+
+#: builtin/help.c:491
+msgid "'git help config' for more information"
+msgstr "'git help config' para más información"
+
+#: builtin/index-pack.c:185
+#, c-format
+msgid "object type mismatch at %s"
+msgstr "el tipo del objeto no concuerda en %s"
+
+#: builtin/index-pack.c:205
+#, c-format
+msgid "did not receive expected object %s"
+msgstr "no se recibió el objeto esperado %s"
+
+#: builtin/index-pack.c:208
+#, c-format
+msgid "object %s: expected type %s, found %s"
+msgstr "objeto %s: tipo esperado %s, encontrado %s"
+
+#: builtin/index-pack.c:258
+#, c-format
+msgid "cannot fill %d byte"
+msgid_plural "cannot fill %d bytes"
+msgstr[0] "no se puede llenar %d byte"
+msgstr[1] "no se pueden llenar %d bytes"
+
+#: builtin/index-pack.c:268
+msgid "early EOF"
+msgstr "EOF temprano"
+
+#: builtin/index-pack.c:269
+msgid "read error on input"
+msgstr "leer error en input"
+
+#: builtin/index-pack.c:281
+msgid "used more bytes than were available"
+msgstr "se usaron más bytes de los disponibles"
+
+#: builtin/index-pack.c:288 builtin/pack-objects.c:604
+msgid "pack too large for current definition of off_t"
+msgstr "paquete muy grande para la definición actual de off_t"
+
+#: builtin/index-pack.c:291 builtin/unpack-objects.c:95
+msgid "pack exceeds maximum allowed size"
+msgstr "paquete excede el máximo tamaño permitido"
+
+#: builtin/index-pack.c:312
+#, c-format
+msgid "cannot open packfile '%s'"
+msgstr "no se puede abrir el archivo de paquete '%s'"
+
+#: builtin/index-pack.c:326
+msgid "pack signature mismatch"
+msgstr "firma del paquete no concuerda"
+
+#: builtin/index-pack.c:328
+#, c-format
+msgid "pack version %<PRIu32> unsupported"
+msgstr "versión de paquete %<PRIu32> no soportada"
+
+#: builtin/index-pack.c:346
+#, c-format
+msgid "pack has bad object at offset %<PRIuMAX>: %s"
+msgstr "paquete tiene un mal objeto en el offset %<PRIuMAX>: %s"
+
+#: builtin/index-pack.c:466
+#, c-format
+msgid "inflate returned %d"
+msgstr "inflate devolvió %d"
+
+#: builtin/index-pack.c:515
+msgid "offset value overflow for delta base object"
+msgstr "valor de offset desbordado para el objeto base delta"
+
+#: builtin/index-pack.c:523
+msgid "delta base offset is out of bound"
+msgstr "offset de base delta está fuera de límites"
+
+#: builtin/index-pack.c:531
+#, c-format
+msgid "unknown object type %d"
+msgstr "tipo de objeto %d desconocido"
+
+#: builtin/index-pack.c:562
+msgid "cannot pread pack file"
+msgstr "no se puede propagar el paquete"
+
+#: builtin/index-pack.c:564
+#, c-format
+msgid "premature end of pack file, %<PRIuMAX> byte missing"
+msgid_plural "premature end of pack file, %<PRIuMAX> bytes missing"
+msgstr[0] "final prematuro de archivo de paquete, %<PRIuMAX> byte faltante"
+msgstr[1] "final prematuro de archivo de paquete, %<PRIuMAX> bytes faltantes"
+
+#: builtin/index-pack.c:590
+msgid "serious inflate inconsistency"
+msgstr "inconsistencia seria en inflate"
+
+#: builtin/index-pack.c:735 builtin/index-pack.c:741 builtin/index-pack.c:764
+#: builtin/index-pack.c:803 builtin/index-pack.c:812
+#, c-format
+msgid "SHA1 COLLISION FOUND WITH %s !"
+msgstr "¡COLISIÓN DE TIPO SHA1 ENCONTRADA CON %s !"
+
+#: builtin/index-pack.c:738 builtin/pack-objects.c:157
+#: builtin/pack-objects.c:217 builtin/pack-objects.c:311
+#, c-format
+msgid "unable to read %s"
+msgstr "no se posible leer %s"
+
+#: builtin/index-pack.c:801
+#, c-format
+msgid "cannot read existing object info %s"
+msgstr "no se puede leer la información existente del objeto %s"
+
+#: builtin/index-pack.c:809
+#, c-format
+msgid "cannot read existing object %s"
+msgstr "no se puede leer el objeto existente %s"
+
+#: builtin/index-pack.c:823
+#, c-format
+msgid "invalid blob object %s"
+msgstr "objeto blob %s inválido"
+
+#: builtin/index-pack.c:826 builtin/index-pack.c:845
+msgid "fsck error in packed object"
+msgstr "error de fsck en el objeto empaquetado"
+
+#: builtin/index-pack.c:847
+#, c-format
+msgid "Not all child objects of %s are reachable"
+msgstr "No todos los objetos hijos de %s son alcanzables"
+
+#: builtin/index-pack.c:919 builtin/index-pack.c:950
+msgid "failed to apply delta"
+msgstr "falló al aplicar delta"
+
+#: builtin/index-pack.c:1118
+msgid "Receiving objects"
+msgstr "Recibiendo objetos"
+
+#: builtin/index-pack.c:1118
+msgid "Indexing objects"
+msgstr "Indexando objetos"
+
+#: builtin/index-pack.c:1152
+msgid "pack is corrupted (SHA1 mismatch)"
+msgstr "paquete está corrompido (SHA1 no concuerda)"
+
+#: builtin/index-pack.c:1157
+msgid "cannot fstat packfile"
+msgstr "no se puede fstat al archivo de paquete"
+
+#: builtin/index-pack.c:1160
+msgid "pack has junk at the end"
+msgstr "el paquete tiene basura al final"
+
+#: builtin/index-pack.c:1172
+msgid "confusion beyond insanity in parse_pack_objects()"
+msgstr "confusión más allá de la locura en parse_pack_objects()"
+
+#: builtin/index-pack.c:1195
+msgid "Resolving deltas"
+msgstr "Resolviendo deltas"
+
+#: builtin/index-pack.c:1205 builtin/pack-objects.c:2481
+#, c-format
+msgid "unable to create thread: %s"
+msgstr "no es posible crear hilo: %s"
+
+#: builtin/index-pack.c:1246
+msgid "confusion beyond insanity"
+msgstr "confusión más allá de la locura"
+
+#: builtin/index-pack.c:1252
+#, c-format
+msgid "completed with %d local object"
+msgid_plural "completed with %d local objects"
+msgstr[0] "completado con %d objeto local"
+msgstr[1] "completado con %d objetos locales"
+
+#: builtin/index-pack.c:1264
+#, c-format
+msgid "Unexpected tail checksum for %s (disk corruption?)"
+msgstr "Tail checksum para %s inesperada (¿corrupción de disco?)"
+
+#: builtin/index-pack.c:1268
+#, c-format
+msgid "pack has %d unresolved delta"
+msgid_plural "pack has %d unresolved deltas"
+msgstr[0] "paquete tiene %d delta sin resolver"
+msgstr[1] "paquete tiene %d deltas sin resolver"
+
+#: builtin/index-pack.c:1292
+#, c-format
+msgid "unable to deflate appended object (%d)"
+msgstr "no es posible desinflar el objeto adjunto (%d)"
+
+#: builtin/index-pack.c:1388
+#, c-format
+msgid "local object %s is corrupt"
+msgstr "objeto local %s está corrompido"
+
+#: builtin/index-pack.c:1402
+#, c-format
+msgid "packfile name '%s' does not end with '.pack'"
+msgstr "nombre '%s' de archivo de paquete no termina con '.pack'"
+
+#: builtin/index-pack.c:1427
+#, c-format
+msgid "cannot write %s file '%s'"
+msgstr "no se puede escribir %s en el archivo '%s'"
+
+#: builtin/index-pack.c:1435
+#, c-format
+msgid "cannot close written %s file '%s'"
+msgstr "no se puede cerrar escrito %s en archivo '%s'"
+
+#: builtin/index-pack.c:1459
+msgid "error while closing pack file"
+msgstr "error mientras se cierra el archivo paquete"
+
+#: builtin/index-pack.c:1473
+msgid "cannot store pack file"
+msgstr "no se puede guardar el archivo paquete"
+
+#: builtin/index-pack.c:1481
+msgid "cannot store index file"
+msgstr "no se puede guardar el archivo índice"
+
+#: builtin/index-pack.c:1525 builtin/pack-objects.c:2716
+#, c-format
+msgid "bad pack.indexversion=%<PRIu32>"
+msgstr "mal pack.indexversion=%<PRIu32>"
+
+#: builtin/index-pack.c:1593
+#, c-format
+msgid "Cannot open existing pack file '%s'"
+msgstr "No se puede abrir el archivo paquete existente '%s'"
+
+#: builtin/index-pack.c:1595
+#, c-format
+msgid "Cannot open existing pack idx file for '%s'"
+msgstr "No se puede abrir el índice del archivo paquete para '%s'"
+
+#: builtin/index-pack.c:1643
+#, c-format
+msgid "non delta: %d object"
+msgid_plural "non delta: %d objects"
+msgstr[0] "no delta: %d objeto"
+msgstr[1] "no delta: %d objetos"
+
+#: builtin/index-pack.c:1650
+#, c-format
+msgid "chain length = %d: %lu object"
+msgid_plural "chain length = %d: %lu objects"
+msgstr[0] "largo de cadena = %d: %lu objeto"
+msgstr[1] "largo de cadena = %d: %lu objetos"
+
+#: builtin/index-pack.c:1689
+msgid "Cannot come back to cwd"
+msgstr "No se puede regresar a cwd"
+
+#: builtin/index-pack.c:1738 builtin/index-pack.c:1741
+#: builtin/index-pack.c:1757 builtin/index-pack.c:1761
+#, c-format
+msgid "bad %s"
+msgstr "mal %s"
+
+#: builtin/index-pack.c:1777
+msgid "--fix-thin cannot be used without --stdin"
+msgstr "--fix-thin no puede ser usada sin --stdin"
+
+#: builtin/index-pack.c:1779
+msgid "--stdin requires a git repository"
+msgstr "--stdin requiere un repositorio git"
+
+#: builtin/index-pack.c:1785
+msgid "--verify with no packfile name given"
+msgstr "--verify no recibió ningún nombre de archivo de paquete"
+
+#: builtin/index-pack.c:1833 builtin/unpack-objects.c:581
+msgid "fsck error in pack objects"
+msgstr "error de fsck en objetos paquete"
+
+#: builtin/init-db.c:61
+#, c-format
+msgid "cannot stat template '%s'"
+msgstr "no se pudo definir template '%s'"
+
+#: builtin/init-db.c:66
+#, c-format
+msgid "cannot opendir '%s'"
+msgstr "no se puede abrir directorio '%s'"
+
+#: builtin/init-db.c:78
+#, c-format
+msgid "cannot readlink '%s'"
+msgstr "no se puede leer link '%s'"
+
+#: builtin/init-db.c:80
+#, c-format
+msgid "cannot symlink '%s' '%s'"
+msgstr "no se puede crear symlink '%s' '%s'"
+
+#: builtin/init-db.c:86
+#, c-format
+msgid "cannot copy '%s' to '%s'"
+msgstr "no se puede copiar '%s' a '%s'"
+
+#: builtin/init-db.c:90
+#, c-format
+msgid "ignoring template %s"
+msgstr "ignorando template %s"
+
+#: builtin/init-db.c:121
+#, c-format
+msgid "templates not found in %s"
+msgstr "template no encontrado en %s"
+
+#: builtin/init-db.c:136
+#, c-format
+msgid "not copying templates from '%s': %s"
+msgstr "no se copian templates de '%s': %s"
+
+#: builtin/init-db.c:334
+#, c-format
+msgid "unable to handle file type %d"
+msgstr "no es posible manejar el tipo de archivo %d"
+
+#: builtin/init-db.c:337
+#, c-format
+msgid "unable to move %s to %s"
+msgstr "no se puede mover %s a %s"
+
+#: builtin/init-db.c:354 builtin/init-db.c:357
+#, c-format
+msgid "%s already exists"
+msgstr "%s ya existe"
+
+#: builtin/init-db.c:413
+#, c-format
+msgid "Reinitialized existing shared Git repository in %s%s\n"
+msgstr "Reinicializado el repositorio Git compartido existente en %s%s\n"
+
+#: builtin/init-db.c:414
+#, c-format
+msgid "Reinitialized existing Git repository in %s%s\n"
+msgstr "Reinicializado el repositorio Git existente en %s%s\n"
+
+#: builtin/init-db.c:418
+#, c-format
+msgid "Initialized empty shared Git repository in %s%s\n"
+msgstr "Inicializado repositorio Git compartido vacío en %s%s\n"
+
+#: builtin/init-db.c:419
+#, c-format
+msgid "Initialized empty Git repository in %s%s\n"
+msgstr "Inicializado repositorio Git vacío en %s%s\n"
+
+#: builtin/init-db.c:468
+msgid ""
+"git init [-q | --quiet] [--bare] [--template=<template-directory>] [--"
+"shared[=<permissions>]] [<directory>]"
+msgstr ""
+"git init [-q | --quiet] [--bare] [--template=<directorio-template>] [--"
+"shared[=<permisos>]] [<directorio>]"
+
+#: builtin/init-db.c:491
+msgid "permissions"
+msgstr "permisos"
+
+#: builtin/init-db.c:492
+msgid "specify that the git repository is to be shared amongst several users"
+msgstr ""
+"especifica que el repositorio de git será compartido entre varios usuarios"
+
+#: builtin/init-db.c:529 builtin/init-db.c:534
+#, c-format
+msgid "cannot mkdir %s"
+msgstr "no se pude crear directorio %s"
+
+#: builtin/init-db.c:538
+#, c-format
+msgid "cannot chdir to %s"
+msgstr "no se puede aplicar chdir a %s"
+
+#: builtin/init-db.c:559
+#, c-format
+msgid ""
+"%s (or --work-tree=<directory>) not allowed without specifying %s (or --git-"
+"dir=<directory>)"
+msgstr ""
+"%s (o --work-tree=<directorio>) no se permite sin especificar %s (o --git-"
+"dir=<directorio>)"
+
+#: builtin/init-db.c:587
+#, c-format
+msgid "Cannot access work tree '%s'"
+msgstr "No se puede acceder al árbol de trabajo '%s'"
+
+#: builtin/interpret-trailers.c:16
+msgid ""
+"git interpret-trailers [--in-place] [--trim-empty] [(--trailer "
+"<token>[(=|:)<value>])...] [<file>...]"
+msgstr ""
+"git interpret-trailers [--in-place] [--trim-empty] [(--trailer "
+"<token>[(=|:)<valor>])...] [<archivo>...]"
+
+#: builtin/interpret-trailers.c:95
+msgid "edit files in place"
+msgstr "editar archivos en el lugar"
+
+#: builtin/interpret-trailers.c:96
+msgid "trim empty trailers"
+msgstr "cortar trailers vacíos"
+
+#: builtin/interpret-trailers.c:99
+msgid "where to place the new trailer"
+msgstr "donde colocar el nuevo trailer"
+
+#: builtin/interpret-trailers.c:101
+msgid "action if trailer already exists"
+msgstr "acción if trailer ya existe"
+
+#: builtin/interpret-trailers.c:103
+msgid "action if trailer is missing"
+msgstr "acción si falta el trailer"
+
+#: builtin/interpret-trailers.c:105
+msgid "output only the trailers"
+msgstr "mostrar solo los trailers"
+
+#: builtin/interpret-trailers.c:106
+msgid "do not apply config rules"
+msgstr "no aplicar reglas de configuración"
+
+#: builtin/interpret-trailers.c:107
+msgid "join whitespace-continued values"
+msgstr "juntar valores con espacios en blanco contiguos"
+
+#: builtin/interpret-trailers.c:108
+msgid "set parsing options"
+msgstr "configurar opciones de análisis"
+
+#: builtin/interpret-trailers.c:110
+msgid "do not treat --- specially"
+msgstr "no tratar --- especialmente"
+
+#: builtin/interpret-trailers.c:111
+msgid "trailer"
+msgstr "trailer"
+
+#: builtin/interpret-trailers.c:112
+msgid "trailer(s) to add"
+msgstr "trailer(s) para agregar"
+
+#: builtin/interpret-trailers.c:123
+msgid "--trailer with --only-input does not make sense"
+msgstr "--trailer con --only-input no tiene sentido"
+
+#: builtin/interpret-trailers.c:133
+msgid "no input file given for in-place editing"
+msgstr "no se entregó archivo de entrada para edición en lugar"
+
+#: builtin/log.c:56
+msgid "git log [<options>] [<revision-range>] [[--] <path>...]"
+msgstr "git log [<opciones>] [<rango-de-revisión>] [[--] <ruta>...]"
+
+#: builtin/log.c:57
+msgid "git show [<options>] <object>..."
+msgstr "git show [<opciones>] <objeto>..."
+
+#: builtin/log.c:110
+#, c-format
+msgid "invalid --decorate option: %s"
+msgstr "opción --decorate inválida: %s"
+
+#: builtin/log.c:174
+msgid "show source"
+msgstr "mostrar fuente"
+
+#: builtin/log.c:175
+msgid "Use mail map file"
+msgstr "Usar archivo de mapa de mail"
+
+#: builtin/log.c:177
+msgid "only decorate refs that match <pattern>"
+msgstr "solo decorar refs que concuerden con <patrón>"
+
+#: builtin/log.c:179
+msgid "do not decorate refs that match <pattern>"
+msgstr "no decorar refs que concuerden con <patrón>"
+
+#: builtin/log.c:180
+msgid "decorate options"
+msgstr "opciones de decorado"
+
+#: builtin/log.c:183
+msgid "Process line range n,m in file, counting from 1"
+msgstr "Procesar rango de líneas n,m en archivo, contando desde 1"
+
+#: builtin/log.c:281
+#, c-format
+msgid "Final output: %d %s\n"
+msgstr "Salida final: %d %s\n"
+
+#: builtin/log.c:535
+#, c-format
+msgid "git show %s: bad file"
+msgstr "git show %s: mal archivo"
+
+#: builtin/log.c:550 builtin/log.c:645
+#, c-format
+msgid "could not read object %s"
+msgstr "no se pudo leer objeto %s"
+
+#: builtin/log.c:670
+#, c-format
+msgid "unknown type: %d"
+msgstr "tipo desconocido: %d"
+
+#: builtin/log.c:814
+#, c-format
+msgid "%s: invalid cover from description mode"
+msgstr "%s: modo cover from description inválido"
+
+#: builtin/log.c:821
+msgid "format.headers without value"
+msgstr "formate.headers. sin valor"
+
+#: builtin/log.c:936
+msgid "name of output directory is too long"
+msgstr "nombre del directorio de salida es muy largo"
+
+#: builtin/log.c:952
+#, c-format
+msgid "cannot open patch file %s"
+msgstr "no se puede abrir archivo patch %s"
+
+#: builtin/log.c:969
+msgid "need exactly one range"
+msgstr "necesita exactamente un rango"
+
+#: builtin/log.c:979
+msgid "not a range"
+msgstr "no es un rango"
+
+#: builtin/log.c:1143
+msgid "cover letter needs email format"
+msgstr "letras de portada necesita formato email"
+
+#: builtin/log.c:1149
+msgid "failed to create cover-letter file"
+msgstr "falló al crear los archivos cover-letter"
+
+#: builtin/log.c:1228
+#, c-format
+msgid "insane in-reply-to: %s"
+msgstr "insano in-reply-to: %s"
+
+#: builtin/log.c:1255
+msgid "git format-patch [<options>] [<since> | <revision-range>]"
+msgstr "git format-patch [<opciones>] [<desde> | <rango-de-revisiones>]"
+
+#: builtin/log.c:1313
+msgid "two output directories?"
+msgstr "¿dos directorios de salida?"
+
+#: builtin/log.c:1424 builtin/log.c:2197 builtin/log.c:2199 builtin/log.c:2211
+#, c-format
+msgid "unknown commit %s"
+msgstr "commit desconocido %s"
+
+#: builtin/log.c:1434 builtin/replace.c:58 builtin/replace.c:207
+#: builtin/replace.c:210
+#, c-format
+msgid "failed to resolve '%s' as a valid ref"
+msgstr "falló al resolver '%s' como ref válida"
+
+#: builtin/log.c:1439
+msgid "could not find exact merge base"
+msgstr "no se pudo encontrar una base de fusión exacta"
+
+#: builtin/log.c:1443
+msgid ""
+"failed to get upstream, if you want to record base commit automatically,\n"
+"please use git branch --set-upstream-to to track a remote branch.\n"
+"Or you could specify base commit by --base=<base-commit-id> manually"
+msgstr ""
+"falló al conseguir upstream, si quieres grabar un commit base de manera "
+"automática,\n"
+"por favor usa git branch --set-upstream-to para rastrear una rama remota.\n"
+"O puedes especificar un commit base mediante --base=<id-commit-base> "
+"manualmente"
+
+#: builtin/log.c:1463
+msgid "failed to find exact merge base"
+msgstr "falló al encontrar una base de fusión exacta"
+
+#: builtin/log.c:1474
+msgid "base commit should be the ancestor of revision list"
+msgstr "el commit base debe ser el ancestro de la lista de revisión"
+
+#: builtin/log.c:1478
+msgid "base commit shouldn't be in revision list"
+msgstr "el commit base no debe estar en la lista de revisión"
+
+#: builtin/log.c:1531
+msgid "cannot get patch id"
+msgstr "no se puede obtener id de patch"
+
+#: builtin/log.c:1583
+msgid "failed to infer range-diff ranges"
+msgstr "falló al inferir rangos range-diff"
+
+#: builtin/log.c:1629
+msgid "use [PATCH n/m] even with a single patch"
+msgstr "use [PATCH n/m] incluso con un único parche"
+
+#: builtin/log.c:1632
+msgid "use [PATCH] even with multiple patches"
+msgstr "use [PATCH] incluso con múltiples parches"
+
+#: builtin/log.c:1636
+msgid "print patches to standard out"
+msgstr "mostrar parches en standard out"
+
+#: builtin/log.c:1638
+msgid "generate a cover letter"
+msgstr "generar letra de cover"
+
+#: builtin/log.c:1640
+msgid "use simple number sequence for output file names"
+msgstr ""
+"usar una secuencia simple de números para salida de nombres de archivos"
+
+#: builtin/log.c:1641
+msgid "sfx"
+msgstr "sfx"
+
+#: builtin/log.c:1642
+msgid "use <sfx> instead of '.patch'"
+msgstr "use <sfx> en lugar de '.patch'"
+
+#: builtin/log.c:1644
+msgid "start numbering patches at <n> instead of 1"
+msgstr "comenzar a numerar los parches desde <n> en lugar de 1"
+
+#: builtin/log.c:1646
+msgid "mark the series as Nth re-roll"
+msgstr "marcar las series como Nth re-roll"
+
+#: builtin/log.c:1648
+msgid "Use [RFC PATCH] instead of [PATCH]"
+msgstr "Use [RFC PATCH] en lugar de [PATCH]"
+
+#: builtin/log.c:1651
+msgid "cover-from-description-mode"
+msgstr "modo-cover-from-description"
+
+#: builtin/log.c:1652
+msgid "generate parts of a cover letter based on a branch's description"
+msgstr ""
+"genera partes de una carta de presentación basado en la descripción de la "
+"rama"
+
+#: builtin/log.c:1654
+msgid "Use [<prefix>] instead of [PATCH]"
+msgstr "Use [<prefijo>] en lugar de [PATCH]"
+
+#: builtin/log.c:1657
+msgid "store resulting files in <dir>"
+msgstr "guardar archivos resultantes en <dir>"
+
+#: builtin/log.c:1660
+msgid "don't strip/add [PATCH]"
+msgstr "no cortar/agregar [PATCH]"
+
+#: builtin/log.c:1663
+msgid "don't output binary diffs"
+msgstr "no mostrar diffs binarios"
+
+#: builtin/log.c:1665
+msgid "output all-zero hash in From header"
+msgstr "salida como hash de todos-ceros en la cabecera From"
+
+#: builtin/log.c:1667
+msgid "don't include a patch matching a commit upstream"
+msgstr "no incluya un parche que coincida con un commit en upstream"
+
+#: builtin/log.c:1669
+msgid "show patch format instead of default (patch + stat)"
+msgstr "mostrar formato de parche en lugar del default (parche + stat)"
+
+#: builtin/log.c:1671
+msgid "Messaging"
+msgstr "Mensajeando"
+
+#: builtin/log.c:1672
+msgid "header"
+msgstr "cabezal"
+
+#: builtin/log.c:1673
+msgid "add email header"
+msgstr "agregar cabecera email"
+
+#: builtin/log.c:1674 builtin/log.c:1676
+msgid "email"
+msgstr "email"
+
+#: builtin/log.c:1674
+msgid "add To: header"
+msgstr "agregar cabecera To:"
+
+#: builtin/log.c:1676
+msgid "add Cc: header"
+msgstr "agregar cabecera Cc:"
+
+#: builtin/log.c:1678
+msgid "ident"
+msgstr "ident"
+
+#: builtin/log.c:1679
+msgid "set From address to <ident> (or committer ident if absent)"
+msgstr ""
+"configurar dirección From a <ident> ( o identidad de committer si está "
+"ausente)"
+
+#: builtin/log.c:1681
+msgid "message-id"
+msgstr "id de mensaje"
+
+#: builtin/log.c:1682
+msgid "make first mail a reply to <message-id>"
+msgstr "hacer primer mail una respuesta a <id de mensaje>"
+
+#: builtin/log.c:1683 builtin/log.c:1686
+msgid "boundary"
+msgstr "límite"
+
+#: builtin/log.c:1684
+msgid "attach the patch"
+msgstr "adjuntar el parche"
+
+#: builtin/log.c:1687
+msgid "inline the patch"
+msgstr "poner el parche en línea"
+
+#: builtin/log.c:1691
+msgid "enable message threading, styles: shallow, deep"
+msgstr "habilitar hilos de mensajes, estilos: superficial, profundo"
+
+#: builtin/log.c:1693
+msgid "signature"
+msgstr "firma"
+
+#: builtin/log.c:1694
+msgid "add a signature"
+msgstr "agregar una firma"
+
+#: builtin/log.c:1695
+msgid "base-commit"
+msgstr "commit-base"
+
+#: builtin/log.c:1696
+msgid "add prerequisite tree info to the patch series"
+msgstr ""
+"agregar información de árbol de requisitos previos a la serie de parches"
+
+#: builtin/log.c:1698
+msgid "add a signature from a file"
+msgstr "agregar una firma de un archivo"
+
+#: builtin/log.c:1699
+msgid "don't print the patch filenames"
+msgstr "no mostrar los nombres de archivos de los parches"
+
+#: builtin/log.c:1701
+msgid "show progress while generating patches"
+msgstr "mostrar medidor de progreso mientras se generan los parches"
+
+#: builtin/log.c:1703
+msgid "show changes against <rev> in cover letter or single patch"
+msgstr "muestra cambios contra <rev> en cover letter o en un solo parche"
+
+#: builtin/log.c:1706
+msgid "show changes against <refspec> in cover letter or single patch"
+msgstr "muestra cambios contra <refspec> en cover letter o en un solo parche"
+
+#: builtin/log.c:1708
+msgid "percentage by which creation is weighted"
+msgstr "porcentaje por el cual la creación es pesada"
+
+#: builtin/log.c:1792
+#, c-format
+msgid "invalid ident line: %s"
+msgstr "línea de identificación inválida: %s"
+
+#: builtin/log.c:1807
+msgid "-n and -k are mutually exclusive"
+msgstr "-n y -k son mutuamente exclusivas"
+
+#: builtin/log.c:1809
+msgid "--subject-prefix/--rfc and -k are mutually exclusive"
+msgstr "--subject-prefix/--rfc y -k son mutuamente exclusivos"
+
+#: builtin/log.c:1817
+msgid "--name-only does not make sense"
+msgstr "--name-only no tiene sentido"
+
+#: builtin/log.c:1819
+msgid "--name-status does not make sense"
+msgstr "--name-status no tiene sentido"
+
+#: builtin/log.c:1821
+msgid "--check does not make sense"
+msgstr "--check no tiene sentido"
+
+#: builtin/log.c:1854
+msgid "standard output, or directory, which one?"
+msgstr "¿salida standard, o directorio, cual?"
+
+#: builtin/log.c:1958
+msgid "--interdiff requires --cover-letter or single patch"
+msgstr "--interdiff requiere --cover-letter o un parche único"
+
+#: builtin/log.c:1962
+msgid "Interdiff:"
+msgstr "Interdiff:"
+
+#: builtin/log.c:1963
+#, c-format
+msgid "Interdiff against v%d:"
+msgstr "Interdiff contra v%d:"
+
+#: builtin/log.c:1969
+msgid "--creation-factor requires --range-diff"
+msgstr "--creation-factor requiere --range-diff"
+
+#: builtin/log.c:1973
+msgid "--range-diff requires --cover-letter or single patch"
+msgstr "--range-diff requiere --cover-letter o parche único"
+
+#: builtin/log.c:1981
+msgid "Range-diff:"
+msgstr "Range-diff:"
+
+#: builtin/log.c:1982
+#, c-format
+msgid "Range-diff against v%d:"
+msgstr "Range-diff contra v%d:"
+
+#: builtin/log.c:1993
+#, c-format
+msgid "unable to read signature file '%s'"
+msgstr "no se puede leer la firma del archivo '%s'"
+
+#: builtin/log.c:2029
+msgid "Generating patches"
+msgstr "Generando parches"
+
+#: builtin/log.c:2073
+msgid "failed to create output files"
+msgstr "falló al crear los archivos de salida"
+
+#: builtin/log.c:2132
+msgid "git cherry [-v] [<upstream> [<head> [<limit>]]]"
+msgstr "git cherry [-v] [<upstream> [<head> [<límite>]]]"
+
+#: builtin/log.c:2186
+#, c-format
+msgid ""
+"Could not find a tracked remote branch, please specify <upstream> manually.\n"
+msgstr ""
+"No se pudo encontrar una rama remota rastreada, por favor especifique "
+"<upstream> manualmente.\n"
+
+#: builtin/ls-files.c:470
+msgid "git ls-files [<options>] [<file>...]"
+msgstr "git ls-files [<opciones>] [<archivo>...]"
+
+#: builtin/ls-files.c:526
+msgid "identify the file status with tags"
+msgstr "identifique el estado del archivo con tags"
+
+#: builtin/ls-files.c:528
+msgid "use lowercase letters for 'assume unchanged' files"
+msgstr "usar letras minúsculas para archivos 'asumidos sin cambios'"
+
+#: builtin/ls-files.c:530
+msgid "use lowercase letters for 'fsmonitor clean' files"
+msgstr "usar letras minúsculas para archivos de 'fsmonitor clean'"
+
+#: builtin/ls-files.c:532
+msgid "show cached files in the output (default)"
+msgstr "mostrar archivos en caché en la salida (default)"
+
+#: builtin/ls-files.c:534
+msgid "show deleted files in the output"
+msgstr "mostrar archivos borrados en la salida"
+
+#: builtin/ls-files.c:536
+msgid "show modified files in the output"
+msgstr "mostrar archivos modificados en la salida"
+
+#: builtin/ls-files.c:538
+msgid "show other files in the output"
+msgstr "mostrar otros archivos en la salida"
+
+#: builtin/ls-files.c:540
+msgid "show ignored files in the output"
+msgstr "mostrar archivos ignorados en la salida"
+
+#: builtin/ls-files.c:543
+msgid "show staged contents' object name in the output"
+msgstr ""
+"mostrar contenido de nombres de objetos en el área de stage en la salida"
+
+#: builtin/ls-files.c:545
+msgid "show files on the filesystem that need to be removed"
+msgstr "mostrar archivos en el filesystem que necesitan ser borrados"
+
+#: builtin/ls-files.c:547
+msgid "show 'other' directories' names only"
+msgstr "mostrar solo nombres de 'directorios otros'"
+
+#: builtin/ls-files.c:549
+msgid "show line endings of files"
+msgstr "mostrar finales de línea de archivos"
+
+#: builtin/ls-files.c:551
+msgid "don't show empty directories"
+msgstr "no mostrar directorios vacíos"
+
+#: builtin/ls-files.c:554
+msgid "show unmerged files in the output"
+msgstr "mostrar archivos no fusionados en la salida"
+
+#: builtin/ls-files.c:556
+msgid "show resolve-undo information"
+msgstr "mostrar información resolver-deshacer"
+
+#: builtin/ls-files.c:558
+msgid "skip files matching pattern"
+msgstr "saltar archivos que concuerden con el patrón"
+
+#: builtin/ls-files.c:561
+msgid "exclude patterns are read from <file>"
+msgstr "excluir patrones leídos de <archivo>"
+
+#: builtin/ls-files.c:564
+msgid "read additional per-directory exclude patterns in <file>"
+msgstr ""
+"leer patrones de exclusión de manera adicional por directorio en <archivo>"
+
+#: builtin/ls-files.c:566
+msgid "add the standard git exclusions"
+msgstr "agregar las exclusiones standard de git"
+
+#: builtin/ls-files.c:570
+msgid "make the output relative to the project top directory"
+msgstr "hacer la salida relativa al directorio principal del proyecto"
+
+#: builtin/ls-files.c:573
+msgid "recurse through submodules"
+msgstr "recurrir a través de submódulos"
+
+#: builtin/ls-files.c:575
+msgid "if any <file> is not in the index, treat this as an error"
+msgstr "si cualquier <archivo> no está en el índice, tratarlo como un error"
+
+#: builtin/ls-files.c:576
+msgid "tree-ish"
+msgstr "árbol-ismo"
+
+#: builtin/ls-files.c:577
+msgid "pretend that paths removed since <tree-ish> are still present"
+msgstr ""
+"fingir que las rutas han sido borradas ya que todavía hay <árbol-ismos> "
+"presentes"
+
+#: builtin/ls-files.c:579
+msgid "show debugging data"
+msgstr "mostrar data de debug"
+
+#: builtin/ls-remote.c:9
+msgid ""
+"git ls-remote [--heads] [--tags] [--refs] [--upload-pack=<exec>]\n"
+"                     [-q | --quiet] [--exit-code] [--get-url]\n"
+"                     [--symref] [<repository> [<refs>...]]"
+msgstr ""
+"git ls-remote [--heads] [--tags] [--refs] [--upload-pack=<exec>]\n"
+"                     [-q | --quiet] [--exit-code] [--get-url]\n"
+"                     [--symref] [<repositorio> [<refs>...]]"
+
+#: builtin/ls-remote.c:59
+msgid "do not print remote URL"
+msgstr "no mostrar el URL remoto"
+
+#: builtin/ls-remote.c:60 builtin/ls-remote.c:62 builtin/rebase.c:1518
+msgid "exec"
+msgstr "ejecutar"
+
+#: builtin/ls-remote.c:61 builtin/ls-remote.c:63
+msgid "path of git-upload-pack on the remote host"
+msgstr "ruta de git-upload-pack en el host remoto"
+
+#: builtin/ls-remote.c:65
+msgid "limit to tags"
+msgstr "limitar a tags"
+
+#: builtin/ls-remote.c:66
+msgid "limit to heads"
+msgstr "limitar a heads"
+
+#: builtin/ls-remote.c:67
+msgid "do not show peeled tags"
+msgstr "no mostrar tags pelados"
+
+#: builtin/ls-remote.c:69
+msgid "take url.<base>.insteadOf into account"
+msgstr "tomar url.<base>.insteadOf en cuenta"
+
+#: builtin/ls-remote.c:72
+msgid "exit with exit code 2 if no matching refs are found"
+msgstr "salir con código de salida 2 si no se encuentran refs que concuerden"
+
+#: builtin/ls-remote.c:75
+msgid "show underlying ref in addition to the object pointed by it"
+msgstr "mostrar ref subyacente en adición al objeto apuntado por él"
+
+#: builtin/ls-tree.c:30
+msgid "git ls-tree [<options>] <tree-ish> [<path>...]"
+msgstr "git ls-tree [<opciones>] <árbol-ismo> [<ruta>...]"
+
+#: builtin/ls-tree.c:128
+msgid "only show trees"
+msgstr "solo mostrar árboles"
+
+#: builtin/ls-tree.c:130
+msgid "recurse into subtrees"
+msgstr "recurrir en subárboles"
+
+#: builtin/ls-tree.c:132
+msgid "show trees when recursing"
+msgstr "mostrar árboles cuando se recurre"
+
+#: builtin/ls-tree.c:135
+msgid "terminate entries with NUL byte"
+msgstr "terminar entradas con byte NUL"
+
+#: builtin/ls-tree.c:136
+msgid "include object size"
+msgstr "incluir tamaño de objeto"
+
+#: builtin/ls-tree.c:138 builtin/ls-tree.c:140
+msgid "list only filenames"
+msgstr "listar solo nombres de archivos"
+
+#: builtin/ls-tree.c:143
+msgid "use full path names"
+msgstr "usar rutas completas"
+
+#: builtin/ls-tree.c:145
+msgid "list entire tree; not just current directory (implies --full-name)"
+msgstr ""
+"mostrar todo el árbol; no solo el directorio actual (implica --full-name)"
+
+#: builtin/mailsplit.c:241
+#, c-format
+msgid "empty mbox: '%s'"
+msgstr "mbox vacío: '%s'"
+
+#: builtin/merge.c:55
+msgid "git merge [<options>] [<commit>...]"
+msgstr "git merge [<opciones>] [<commit>...]"
+
+#: builtin/merge.c:56
+msgid "git merge --abort"
+msgstr "git merge --abort"
+
+#: builtin/merge.c:57
+msgid "git merge --continue"
+msgstr "git merge --continue"
+
+#: builtin/merge.c:118
+msgid "switch `m' requires a value"
+msgstr "cambiar `m' requiere un valor"
+
+#: builtin/merge.c:141
+#, c-format
+msgid "option `%s' requires a value"
+msgstr "opción `%s' requiere un valor"
+
+#: builtin/merge.c:187
+#, c-format
+msgid "Could not find merge strategy '%s'.\n"
+msgstr "No se pudo encontrar estrategia de fusión '%s'.\n"
+
+#: builtin/merge.c:188
+#, c-format
+msgid "Available strategies are:"
+msgstr "Estrategias disponibles son:"
+
+#: builtin/merge.c:193
+#, c-format
+msgid "Available custom strategies are:"
+msgstr "Estrategias personalizadas disponibles son:"
+
+#: builtin/merge.c:244 builtin/pull.c:152
+msgid "do not show a diffstat at the end of the merge"
+msgstr "no mostrar un diffstat al final de la fusión"
+
+#: builtin/merge.c:247 builtin/pull.c:155
+msgid "show a diffstat at the end of the merge"
+msgstr "mostrar un diffstat al final de la fusión"
+
+#: builtin/merge.c:248 builtin/pull.c:158
+msgid "(synonym to --stat)"
+msgstr "(sinónimo para --stat)"
+
+#: builtin/merge.c:250 builtin/pull.c:161
+msgid "add (at most <n>) entries from shortlog to merge commit message"
+msgstr ""
+"agregar (como máximo <n>) entradas del shortlog al mensaje del commit de "
+"fusión"
+
+#: builtin/merge.c:253 builtin/pull.c:167
+msgid "create a single commit instead of doing a merge"
+msgstr "crear un commit único en lugar de hacer una fusión"
+
+#: builtin/merge.c:255 builtin/pull.c:170
+msgid "perform a commit if the merge succeeds (default)"
+msgstr "realizar un commit si la fusión es exitosa (default)"
+
+#: builtin/merge.c:257 builtin/pull.c:173
+msgid "edit message before committing"
+msgstr "editar mensaje antes de realizar commit"
+
+#: builtin/merge.c:259
+msgid "allow fast-forward (default)"
+msgstr "permitir fast-forwars (default)"
+
+#: builtin/merge.c:261 builtin/pull.c:180
+msgid "abort if fast-forward is not possible"
+msgstr "abortar si fast-forward no es posible"
+
+#: builtin/merge.c:265 builtin/pull.c:183
+msgid "verify that the named commit has a valid GPG signature"
+msgstr "verificar que el commit nombrado tiene una firma GPG válida"
+
+#: builtin/merge.c:266 builtin/notes.c:787 builtin/pull.c:187
+#: builtin/rebase.c:512 builtin/rebase.c:1531 builtin/revert.c:114
+msgid "strategy"
+msgstr "estrategia"
+
+#: builtin/merge.c:267 builtin/pull.c:188
+msgid "merge strategy to use"
+msgstr "estrategia de fusión para usar"
+
+#: builtin/merge.c:268 builtin/pull.c:191
+msgid "option=value"
+msgstr "opción=valor"
+
+#: builtin/merge.c:269 builtin/pull.c:192
+msgid "option for selected merge strategy"
+msgstr "opción para la estrategia de fusión seleccionada"
+
+#: builtin/merge.c:271
+msgid "merge commit message (for a non-fast-forward merge)"
+msgstr "fusionar mensaje de commit (para una fusión no fast-forward)"
+
+#: builtin/merge.c:278
+msgid "abort the current in-progress merge"
+msgstr "abortar la fusión en progreso actual"
+
+#: builtin/merge.c:280
+msgid "--abort but leave index and working tree alone"
+msgstr "--abort pero deja el índice y el árbol de trabajo solos"
+
+#: builtin/merge.c:282
+msgid "continue the current in-progress merge"
+msgstr "continuar la fusión en progreso actual"
+
+#: builtin/merge.c:284 builtin/pull.c:199
+msgid "allow merging unrelated histories"
+msgstr "permitir fusionar historias no relacionadas"
+
+#: builtin/merge.c:290
+msgid "bypass pre-merge-commit and commit-msg hooks"
+msgstr "hacer un bypass a hooks pre-merge-commit y commit-msg"
+
+#: builtin/merge.c:307
+msgid "could not run stash."
+msgstr "no se pudo ejecutar stash."
+
+#: builtin/merge.c:312
+msgid "stash failed"
+msgstr "stash falló"
+
+#: builtin/merge.c:317
+#, c-format
+msgid "not a valid object: %s"
+msgstr "no es un objeto válido: %s"
+
+#: builtin/merge.c:339 builtin/merge.c:356
+msgid "read-tree failed"
+msgstr "lectura de árbol falló"
+
+#: builtin/merge.c:386
+msgid " (nothing to squash)"
+msgstr " (nada para hacer squash)"
+
+#: builtin/merge.c:397
+#, c-format
+msgid "Squash commit -- not updating HEAD\n"
+msgstr "Commit de squash -- no actualizando HEAD\n"
+
+#: builtin/merge.c:447
+#, c-format
+msgid "No merge message -- not updating HEAD\n"
+msgstr "No hay mensaje de fusión -- no actualizando HEAD\n"
+
+#: builtin/merge.c:498
+#, c-format
+msgid "'%s' does not point to a commit"
+msgstr "'%s' no apunta a ningún commit"
+
+#: builtin/merge.c:585
+#, c-format
+msgid "Bad branch.%s.mergeoptions string: %s"
+msgstr "Mal string branch.%s.mergeoptions: %s"
+
+#: builtin/merge.c:705
+msgid "Not handling anything other than two heads merge."
+msgstr "No manejando nada más que fusión de dos heads."
+
+#: builtin/merge.c:719
+#, c-format
+msgid "Unknown option for merge-recursive: -X%s"
+msgstr "Opción desconocida para merge-recursive: -X%s"
+
+#: builtin/merge.c:734
+#, c-format
+msgid "unable to write %s"
+msgstr "no es posible escribir %s"
+
+#: builtin/merge.c:786
+#, c-format
+msgid "Could not read from '%s'"
+msgstr "No se puedo leer de '%s'"
+
+#: builtin/merge.c:795
+#, c-format
+msgid "Not committing merge; use 'git commit' to complete the merge.\n"
+msgstr ""
+"No se realiza commit de la fusión; use 'git commit' para completar la "
+"fusión.\n"
+
+#: builtin/merge.c:801
+msgid ""
+"Please enter a commit message to explain why this merge is necessary,\n"
+"especially if it merges an updated upstream into a topic branch.\n"
+"\n"
+msgstr ""
+"Por favor ingrese un mensaje de commit que explique por qué es necesaria "
+"esta fusión,\n"
+"especialmente si esto fusiona un upstream actualizado en una rama de "
+"tópico.\n"
+"\n"
+
+#: builtin/merge.c:806
+msgid "An empty message aborts the commit.\n"
+msgstr "Un mensaje vacío aborta el commit.\n"
+
+#: builtin/merge.c:809
+#, c-format
+msgid ""
+"Lines starting with '%c' will be ignored, and an empty message aborts\n"
+"the commit.\n"
+msgstr ""
+"Líneas comenzando con '%c' serán ignoradas, y un mensaje vacío aborta\n"
+" el commit.\n"
+
+#: builtin/merge.c:862
+msgid "Empty commit message."
+msgstr "Mensaje de commit vacío."
+
+#: builtin/merge.c:877
+#, c-format
+msgid "Wonderful.\n"
+msgstr "Maravilloso.\n"
+
+#: builtin/merge.c:938
+#, c-format
+msgid "Automatic merge failed; fix conflicts and then commit the result.\n"
+msgstr ""
+"Fusión automática falló; arregle los conflictos y luego realice un commit "
+"con el resultado.\n"
+
+#: builtin/merge.c:977
+msgid "No current branch."
+msgstr "No rama actual."
+
+#: builtin/merge.c:979
+msgid "No remote for the current branch."
+msgstr "No hay remoto para la rama actual."
+
+#: builtin/merge.c:981
+msgid "No default upstream defined for the current branch."
+msgstr "Por defecto, no hay un upstream  definido para la rama actual."
+
+#: builtin/merge.c:986
+#, c-format
+msgid "No remote-tracking branch for %s from %s"
+msgstr "No hay rama de rastreo remoto para %s de %s"
+
+#: builtin/merge.c:1043
+#, c-format
+msgid "Bad value '%s' in environment '%s'"
+msgstr "Valor erróneo '%s' en el entorno '%s'"
+
+#: builtin/merge.c:1146
+#, c-format
+msgid "not something we can merge in %s: %s"
+msgstr "nada que podamos fusionar en %s: %s"
+
+#: builtin/merge.c:1180
+msgid "not something we can merge"
+msgstr "nada que podamos fusionar"
+
+#: builtin/merge.c:1283
+msgid "--abort expects no arguments"
+msgstr "--abort no espera argumentos"
+
+#: builtin/merge.c:1287
+msgid "There is no merge to abort (MERGE_HEAD missing)."
+msgstr "No hay una fusión para abortar (falta MERGE_HEAD)"
+
+#: builtin/merge.c:1296
+msgid "--quit expects no arguments"
+msgstr "--quit no espera argumentos"
+
+#: builtin/merge.c:1309
+msgid "--continue expects no arguments"
+msgstr "--continue no espera argumentos"
+
+#: builtin/merge.c:1313
+msgid "There is no merge in progress (MERGE_HEAD missing)."
+msgstr "No hay fusión en progreso (falta MERGE_HEAD)."
+
+#: builtin/merge.c:1329
+msgid ""
+"You have not concluded your merge (MERGE_HEAD exists).\n"
+"Please, commit your changes before you merge."
+msgstr ""
+"No has concluido la fusión (existe MERGE_HEAD).\n"
+"Por favor, realiza un commit con los cambios antes de fusionar."
+
+#: builtin/merge.c:1336
+msgid ""
+"You have not concluded your cherry-pick (CHERRY_PICK_HEAD exists).\n"
+"Please, commit your changes before you merge."
+msgstr ""
+"No has concluido el cherry-pick (existe CHERRY_PICK_HEAD).\n"
+"Por favor, realiza un commit con los cambios antes de fusionar."
+
+#: builtin/merge.c:1339
+msgid "You have not concluded your cherry-pick (CHERRY_PICK_HEAD exists)."
+msgstr "No has concluido el cherry-pick (existe CHERRY_PICK_HEAD)."
+
+#: builtin/merge.c:1353
+msgid "You cannot combine --squash with --no-ff."
+msgstr "No se puede combinar --squash con --no-ff."
+
+#: builtin/merge.c:1355
+msgid "You cannot combine --squash with --commit."
+msgstr "No se puede combinar --squash con --commit."
+
+#: builtin/merge.c:1371
+msgid "No commit specified and merge.defaultToUpstream not set."
+msgstr ""
+"No hay commit especificado y merge.defaultToUpstream no está configurado."
+
+#: builtin/merge.c:1388
+msgid "Squash commit into empty head not supported yet"
+msgstr "Commit aplastado dentro de un head vacío no es soportado todavía"
+
+#: builtin/merge.c:1390
+msgid "Non-fast-forward commit does not make sense into an empty head"
+msgstr "Commit no fast-forward no tiene sentido dentro de un head vacío"
+
+#: builtin/merge.c:1395
+#, c-format
+msgid "%s - not something we can merge"
+msgstr "%s - nada que podamos fusionar"
+
+#: builtin/merge.c:1397
+msgid "Can merge only exactly one commit into empty head"
+msgstr "Solo se puede fusionar exactamente un commit en un head vacío"
+
+#: builtin/merge.c:1476
+msgid "refusing to merge unrelated histories"
+msgstr "rehusando fusionar historias no relacionadas"
+
+#: builtin/merge.c:1485
+msgid "Already up to date."
+msgstr "Ya está actualizado."
+
+#: builtin/merge.c:1495
+#, c-format
+msgid "Updating %s..%s\n"
+msgstr "Actualizando %s..%s\n"
+
+#: builtin/merge.c:1537
+#, c-format
+msgid "Trying really trivial in-index merge...\n"
+msgstr "Intentando fusión en índice realmente trivial...\n"
+
+#: builtin/merge.c:1544
+#, c-format
+msgid "Nope.\n"
+msgstr "Nop.\n"
+
+#: builtin/merge.c:1569
+msgid "Already up to date. Yeeah!"
+msgstr "Ya está actualizado. ¡Oh, yeaahh!"
+
+#: builtin/merge.c:1575
+msgid "Not possible to fast-forward, aborting."
+msgstr "No es posible hacer fast-forward, abortando."
+
+#: builtin/merge.c:1598 builtin/merge.c:1663
+#, c-format
+msgid "Rewinding the tree to pristine...\n"
+msgstr "Rebobinando el árbol a original...\n"
+
+#: builtin/merge.c:1602
+#, c-format
+msgid "Trying merge strategy %s...\n"
+msgstr "Intentando estrategia de fusión %s...\n"
+
+#: builtin/merge.c:1654
+#, c-format
+msgid "No merge strategy handled the merge.\n"
+msgstr "Ninguna estrategia de fusión manejó la fusión.\n"
+
+#: builtin/merge.c:1656
+#, c-format
+msgid "Merge with strategy %s failed.\n"
+msgstr "Fusionar con estrategia %s falló.\n"
+
+#: builtin/merge.c:1665
+#, c-format
+msgid "Using the %s to prepare resolving by hand.\n"
+msgstr "Usando el %s para preparar resolución a mano.\n"
+
+#: builtin/merge.c:1677
+#, c-format
+msgid "Automatic merge went well; stopped before committing as requested\n"
+msgstr ""
+"Fusión automática fue bien; detenida antes del commit como se solicitó\n"
+
+#: builtin/merge-base.c:32
+msgid "git merge-base [-a | --all] <commit> <commit>..."
+msgstr "git merge-base [-a | --all] <commit> <commit>..."
+
+#: builtin/merge-base.c:33
+msgid "git merge-base [-a | --all] --octopus <commit>..."
+msgstr "git merge-base [-a | --all] --octopus <commit>..."
+
+#: builtin/merge-base.c:34
+msgid "git merge-base --independent <commit>..."
+msgstr "git merge-base --independent <commit>..."
+
+#: builtin/merge-base.c:35
+msgid "git merge-base --is-ancestor <commit> <commit>"
+msgstr "git merge-base --is-ancestor <commit> <commit>"
+
+#: builtin/merge-base.c:36
+msgid "git merge-base --fork-point <ref> [<commit>]"
+msgstr "git merge-base --fork-point <ref> [<commit>]"
+
+#: builtin/merge-base.c:153
+msgid "output all common ancestors"
+msgstr "mostrar todos los ancestros comunes"
+
+#: builtin/merge-base.c:155
+msgid "find ancestors for a single n-way merge"
+msgstr "encontrar ancestros para una única fusión de n-vías"
+
+#: builtin/merge-base.c:157
+msgid "list revs not reachable from others"
+msgstr "listar revs no alcanzables desde otros"
+
+#: builtin/merge-base.c:159
+msgid "is the first one ancestor of the other?"
+msgstr "¿es el primer ancestro del otro?"
+
+#: builtin/merge-base.c:161
+msgid "find where <commit> forked from reflog of <ref>"
+msgstr "encontrar donde <commit> forjó del reflog de <ref>"
+
+#: builtin/merge-file.c:9
+msgid ""
+"git merge-file [<options>] [-L <name1> [-L <orig> [-L <name2>]]] <file1> "
+"<orig-file> <file2>"
+msgstr ""
+"git merge-file [<opciones>] [-L <nombre1> [-L <origen> [-L <nombre2>]]] "
+"<archivo1> <archivo-origen> <archivo2>"
+
+#: builtin/merge-file.c:35
+msgid "send results to standard output"
+msgstr "mandar resultados a standard output"
+
+#: builtin/merge-file.c:36
+msgid "use a diff3 based merge"
+msgstr "usar un fusión basada en diff3"
+
+#: builtin/merge-file.c:37
+msgid "for conflicts, use our version"
+msgstr "por conflictos, usar nuestra versión"
+
+#: builtin/merge-file.c:39
+msgid "for conflicts, use their version"
+msgstr "por conflictos, usar la versión de ellos"
+
+#: builtin/merge-file.c:41
+msgid "for conflicts, use a union version"
+msgstr "por conflictos, usar una versión de unión"
+
+#: builtin/merge-file.c:44
+msgid "for conflicts, use this marker size"
+msgstr "por conflictos, usar el tamaño de este marcador"
+
+#: builtin/merge-file.c:45
+msgid "do not warn about conflicts"
+msgstr "no advertir sobre conflictos"
+
+#: builtin/merge-file.c:47
+msgid "set labels for file1/orig-file/file2"
+msgstr "configurar labels para archivo1/orig-archivo/archivo2"
+
+#: builtin/merge-recursive.c:47
+#, c-format
+msgid "unknown option %s"
+msgstr "opción %s desconocida"
+
+#: builtin/merge-recursive.c:53
+#, c-format
+msgid "could not parse object '%s'"
+msgstr "no se pudo analizar el objeto '%s'"
+
+#: builtin/merge-recursive.c:57
+#, c-format
+msgid "cannot handle more than %d base. Ignoring %s."
+msgid_plural "cannot handle more than %d bases. Ignoring %s."
+msgstr[0] "no se puede manejar más de %d base. Ignorando %s."
+msgstr[1] "no se puede manejar más de %d bases. Ignorando %s."
+
+#: builtin/merge-recursive.c:65
+msgid "not handling anything other than two heads merge."
+msgstr "no manejando nada distinto a fusiones de dos heads."
+
+#: builtin/merge-recursive.c:74 builtin/merge-recursive.c:76
+#, c-format
+msgid "could not resolve ref '%s'"
+msgstr "no se pudo resolver ref '%s'"
+
+#: builtin/merge-recursive.c:82
+#, c-format
+msgid "Merging %s with %s\n"
+msgstr "Fusionando %s con %s\n"
+
+#: builtin/mktree.c:66
+msgid "git mktree [-z] [--missing] [--batch]"
+msgstr "git mktree [-z] [--missing] [--batch]"
+
+#: builtin/mktree.c:154
+msgid "input is NUL terminated"
+msgstr "input es terminada con NUL"
+
+#: builtin/mktree.c:155 builtin/write-tree.c:26
+msgid "allow missing objects"
+msgstr "permitir objetos faltantes"
+
+#: builtin/mktree.c:156
+msgid "allow creation of more than one tree"
+msgstr "permitir la creación de más de un árbol"
+
+#: builtin/multi-pack-index.c:9
+msgid ""
+"git multi-pack-index [<options>] (write|verify|expire|repack --batch-"
+"size=<size>)"
+msgstr ""
+"git multi-pack-index [<options>] (write|verify|expire|repack --batch-"
+"size=<tamaño>)"
+
+#: builtin/multi-pack-index.c:26
+msgid "object directory containing set of packfile and pack-index pairs"
+msgstr "objeto directorio conteniendo conjuntos de pares packfile y pack-index"
+
+#: builtin/multi-pack-index.c:29
+msgid ""
+"during repack, collect pack-files of smaller size into a batch that is "
+"larger than this size"
+msgstr ""
+"durante el repack, recolectar los pack-files de tamaño menor en un batch que "
+"es más grande que este tamaño"
+
+#: builtin/multi-pack-index.c:50 builtin/prune-packed.c:67
+msgid "too many arguments"
+msgstr "muchos argumentos"
+
+#: builtin/multi-pack-index.c:60
+msgid "--batch-size option is only for 'repack' subcommand"
+msgstr "opción --batch-size es solo para el subcomando 'repack'"
+
+#: builtin/multi-pack-index.c:69
+#, c-format
+msgid "unrecognized subcommand: %s"
+msgstr "subcomando desconocido: %s"
+
+#: builtin/mv.c:18
+msgid "git mv [<options>] <source>... <destination>"
+msgstr "git mv [<opciones>] <fuente>... <destino>"
+
+#: builtin/mv.c:83
+#, c-format
+msgid "Directory %s is in index and no submodule?"
+msgstr "¿Directorio %s está en el índice y no hay submódulo?"
+
+#: builtin/mv.c:85
+msgid "Please stage your changes to .gitmodules or stash them to proceed"
+msgstr ""
+"Por favor agrega el stage de tus cambios a .gitmodules o realiza un stash "
+"para proceder"
+
+#: builtin/mv.c:103
+#, c-format
+msgid "%.*s is in index"
+msgstr "%.*s está en el índice"
+
+#: builtin/mv.c:125
+msgid "force move/rename even if target exists"
+msgstr "forzar mover/renombrar incluso si el objetivo existe"
+
+#: builtin/mv.c:127
+msgid "skip move/rename errors"
+msgstr "saltar errores de mover/renombrar"
+
+#: builtin/mv.c:169
+#, c-format
+msgid "destination '%s' is not a directory"
+msgstr "destino '%s' no es un directorio"
+
+#: builtin/mv.c:180
+#, c-format
+msgid "Checking rename of '%s' to '%s'\n"
+msgstr "Revisando cambio de nombre de '%s' a '%s'\n"
+
+#: builtin/mv.c:184
+msgid "bad source"
+msgstr "mala fuente"
+
+#: builtin/mv.c:187
+msgid "can not move directory into itself"
+msgstr "no se pude mover un directorio en sí mismo"
+
+#: builtin/mv.c:190
+msgid "cannot move directory over file"
+msgstr "no se puede mover un directorio dentro de un archivo"
+
+#: builtin/mv.c:199
+msgid "source directory is empty"
+msgstr "directorio de fuente está vacío"
+
+#: builtin/mv.c:224
+msgid "not under version control"
+msgstr "no se encuentra bajo control de versión"
+
+#: builtin/mv.c:227
+msgid "destination exists"
+msgstr "destino existe"
+
+#: builtin/mv.c:235
+#, c-format
+msgid "overwriting '%s'"
+msgstr "sobrescribiendo '%s'"
+
+#: builtin/mv.c:238
+msgid "Cannot overwrite"
+msgstr "No se puede sobrescribir"
+
+#: builtin/mv.c:241
+msgid "multiple sources for the same target"
+msgstr "múltiples fuentes para el mismo objetivo"
+
+#: builtin/mv.c:243
+msgid "destination directory does not exist"
+msgstr "el directorio de destino no existe"
+
+#: builtin/mv.c:250
+#, c-format
+msgid "%s, source=%s, destination=%s"
+msgstr "%s, fuente=%s, destino=%s"
+
+#: builtin/mv.c:271
+#, c-format
+msgid "Renaming %s to %s\n"
+msgstr "Renombrando %s a %s\n"
+
+#: builtin/mv.c:277 builtin/remote.c:716 builtin/repack.c:518
+#, c-format
+msgid "renaming '%s' failed"
+msgstr "renombrando '%s' falló"
+
+#: builtin/name-rev.c:403
+msgid "git name-rev [<options>] <commit>..."
+msgstr "git name-rev [<opciones>] <commit>..."
+
+#: builtin/name-rev.c:404
+msgid "git name-rev [<options>] --all"
+msgstr "git name-rev [<opciones>] --all"
+
+#: builtin/name-rev.c:405
+msgid "git name-rev [<options>] --stdin"
+msgstr "git name-rev [<opciones>] --stdin"
+
+#: builtin/name-rev.c:462
+msgid "print only names (no SHA-1)"
+msgstr "imprimir sólo nombres (sin SHA-1)"
+
+#: builtin/name-rev.c:463
+msgid "only use tags to name the commits"
+msgstr "sólo usar tags para nombrar commits"
+
+#: builtin/name-rev.c:465
+msgid "only use refs matching <pattern>"
+msgstr "solo usar refs que concuerden con <patrón>"
+
+#: builtin/name-rev.c:467
+msgid "ignore refs matching <pattern>"
+msgstr "ignorar refs que concuerden con <patrón>"
+
+#: builtin/name-rev.c:469
+msgid "list all commits reachable from all refs"
+msgstr "listar todos los commits alcanzables desde todas las referencias"
+
+#: builtin/name-rev.c:470
+msgid "read from stdin"
+msgstr "leer desde stdin"
+
+#: builtin/name-rev.c:471
+msgid "allow to print `undefined` names (default)"
+msgstr "permitir imprimir nombres `undefined` (predeterminado)"
+
+#: builtin/name-rev.c:477
+msgid "dereference tags in the input (internal use)"
+msgstr "desreferenciar tags en la entrada (uso interno)"
+
+#: builtin/notes.c:28
+msgid "git notes [--ref <notes-ref>] [list [<object>]]"
+msgstr "git notes [--ref <referencia-de-notas>] [list [<objeto>]]"
+
+#: builtin/notes.c:29
+msgid ""
+"git notes [--ref <notes-ref>] add [-f] [--allow-empty] [-m <msg> | -F <file> "
+"| (-c | -C) <object>] [<object>]"
+msgstr ""
+"git notes [--ref <referencia-de-notas>] add [-f] [--allow-empty] [-m "
+"<mensaje> | -F <archivo> | (-c | -C) <objeto>] [<objeto>]"
+
+#: builtin/notes.c:30
+msgid "git notes [--ref <notes-ref>] copy [-f] <from-object> <to-object>"
+msgstr ""
+"git notes [--ref <referencia-de-notas>] copy [-f] <objeto-origen> <objeto-"
+"destino>"
+
+#: builtin/notes.c:31
+msgid ""
+"git notes [--ref <notes-ref>] append [--allow-empty] [-m <msg> | -F <file> | "
+"(-c | -C) <object>] [<object>]"
+msgstr ""
+"git notes [--ref <referencia-de-notas>] append [--allow-empty] [-m <mensaje> "
+"| -F <archivo> | (-c | -C) <objeto>] [<objeto>]"
+
+#: builtin/notes.c:32
+msgid "git notes [--ref <notes-ref>] edit [--allow-empty] [<object>]"
+msgstr ""
+"git notes [--ref <referencia-de-notas>] edit [--allow-empty] [<objeto>]"
+
+#: builtin/notes.c:33
+msgid "git notes [--ref <notes-ref>] show [<object>]"
+msgstr "git notes [--ref <referencia-de-notas>] show [<objeto>]"
+
+#: builtin/notes.c:34
+msgid ""
+"git notes [--ref <notes-ref>] merge [-v | -q] [-s <strategy>] <notes-ref>"
+msgstr ""
+"git notes [--ref <referencia-de notas>] merge [-v | -q] [-s <estrategia>] "
+"<referencia-de-notas>"
+
+#: builtin/notes.c:35
+msgid "git notes merge --commit [-v | -q]"
+msgstr "git notes merge --commit [-v | -q]"
+
+#: builtin/notes.c:36
+msgid "git notes merge --abort [-v | -q]"
+msgstr "git notes merge --abort [-v | -q]"
+
+#: builtin/notes.c:37
+msgid "git notes [--ref <notes-ref>] remove [<object>...]"
+msgstr "git notes [--ref <referencia-de-notas>] remove [<objeto>...]"
+
+#: builtin/notes.c:38
+msgid "git notes [--ref <notes-ref>] prune [-n] [-v]"
+msgstr "git notes [--ref <referencia-de-notas>] prune [-n] [-v]"
+
+#: builtin/notes.c:39
+msgid "git notes [--ref <notes-ref>] get-ref"
+msgstr "git notes [--ref <referencia-de-notas>] get-ref"
+
+#: builtin/notes.c:44
+msgid "git notes [list [<object>]]"
+msgstr "git notes [list [<objeto>]]"
+
+#: builtin/notes.c:49
+msgid "git notes add [<options>] [<object>]"
+msgstr "git notes add [<opciones>] [<objeto>]"
+
+#: builtin/notes.c:54
+msgid "git notes copy [<options>] <from-object> <to-object>"
+msgstr "git notes copy [<opciones>] <objeto-origen> <objeto-destino>"
+
+#: builtin/notes.c:55
+msgid "git notes copy --stdin [<from-object> <to-object>]..."
+msgstr "git notes copy --stdin [<objeto-origen> <objeto-destino>]..."
+
+#: builtin/notes.c:60
+msgid "git notes append [<options>] [<object>]"
+msgstr "git notes append [<opciones>] [<objeto>]"
+
+#: builtin/notes.c:65
+msgid "git notes edit [<object>]"
+msgstr "git notes edit [<objeto>]"
+
+#: builtin/notes.c:70
+msgid "git notes show [<object>]"
+msgstr "git notes show [<objeto>]"
+
+#: builtin/notes.c:75
+msgid "git notes merge [<options>] <notes-ref>"
+msgstr "git notes merge [<opciones>] <referencia-de-notas>"
+
+#: builtin/notes.c:76
+msgid "git notes merge --commit [<options>]"
+msgstr "git notes merge --commit [<opciones>]"
+
+#: builtin/notes.c:77
+msgid "git notes merge --abort [<options>]"
+msgstr "git notes merge --abort [<opciones>]"
+
+#: builtin/notes.c:82
+msgid "git notes remove [<object>]"
+msgstr "git notes remove [<objeto>]"
+
+#: builtin/notes.c:87
+msgid "git notes prune [<options>]"
+msgstr "git notes prune [<opciones>]"
+
+#: builtin/notes.c:92
+msgid "git notes get-ref"
+msgstr "git notes get-ref"
+
+#: builtin/notes.c:97
+msgid "Write/edit the notes for the following object:"
+msgstr "Escribe/edita las notas para los siguientes objetos:"
+
+#: builtin/notes.c:150
+#, c-format
+msgid "unable to start 'show' for object '%s'"
+msgstr "incapaz de iniciar 'show' para el objeto '%s'"
+
+#: builtin/notes.c:154
+msgid "could not read 'show' output"
+msgstr "no se pudo leer salida de 'show'"
+
+#: builtin/notes.c:162
+#, c-format
+msgid "failed to finish 'show' for object '%s'"
+msgstr "falló la finalización de 'show' para el objeto '%s'"
+
+#: builtin/notes.c:197
+msgid "please supply the note contents using either -m or -F option"
+msgstr "por favor suministrar los contenidos de nota usando la opción -m o -F"
+
+#: builtin/notes.c:206
+msgid "unable to write note object"
+msgstr "incapaz de escribir el objeto de nota"
+
+#: builtin/notes.c:208
+#, c-format
+msgid "the note contents have been left in %s"
+msgstr "los contenidos de nota han sido dejados en %s"
+
+#: builtin/notes.c:242 builtin/tag.c:532
+#, c-format
+msgid "could not open or read '%s'"
+msgstr "no se pudo abrir o leer '%s'"
+
+#: builtin/notes.c:263 builtin/notes.c:313 builtin/notes.c:315
+#: builtin/notes.c:383 builtin/notes.c:438 builtin/notes.c:526
+#: builtin/notes.c:531 builtin/notes.c:610 builtin/notes.c:672
+#, c-format
+msgid "failed to resolve '%s' as a valid ref."
+msgstr "falló al resolver '%s' como ref válida."
+
+#: builtin/notes.c:265
+#, c-format
+msgid "failed to read object '%s'."
+msgstr "falló al leer objeto '%s'."
+
+#: builtin/notes.c:268
+#, c-format
+msgid "cannot read note data from non-blob object '%s'."
+msgstr "no se puede leer la data de la nota de un objeto no-blob '%s'."
+
+#: builtin/notes.c:309
+#, c-format
+msgid "malformed input line: '%s'."
+msgstr "línea de entrada mal formada: '%s'."
+
+#: builtin/notes.c:324
+#, c-format
+msgid "failed to copy notes from '%s' to '%s'"
+msgstr "falló al copiar notas de '%s' a '%s'"
+
+#. TRANSLATORS: the first %s will be replaced by a git
+#. notes command: 'add', 'merge', 'remove', etc.
+#.
+#: builtin/notes.c:356
+#, c-format
+msgid "refusing to %s notes in %s (outside of refs/notes/)"
+msgstr "rechazando %s notas en %s (fuera de refs/notes/)"
+
+#: builtin/notes.c:376 builtin/notes.c:431 builtin/notes.c:509
+#: builtin/notes.c:521 builtin/notes.c:598 builtin/notes.c:665
+#: builtin/notes.c:815 builtin/notes.c:963 builtin/notes.c:985
+msgid "too many parameters"
+msgstr "demasiados parámetros"
+
+#: builtin/notes.c:389 builtin/notes.c:678
+#, c-format
+msgid "no note found for object %s."
+msgstr "no se encontraron notas para objeto %s."
+
+#: builtin/notes.c:410 builtin/notes.c:576
+msgid "note contents as a string"
+msgstr "contenidos de la nota como cadena"
+
+#: builtin/notes.c:413 builtin/notes.c:579
+msgid "note contents in a file"
+msgstr "contenidos de la nota en un archivo"
+
+#: builtin/notes.c:416 builtin/notes.c:582
+msgid "reuse and edit specified note object"
+msgstr "reutilizar y editar el objeto de nota especificada"
+
+#: builtin/notes.c:419 builtin/notes.c:585
+msgid "reuse specified note object"
+msgstr "reutilizar el objeto de nota especificado"
+
+#: builtin/notes.c:422 builtin/notes.c:588
+msgid "allow storing empty note"
+msgstr "permitir almacenar nota vacía"
+
+#: builtin/notes.c:423 builtin/notes.c:496
+msgid "replace existing notes"
+msgstr "reemplazar notas existentes"
+
+#: builtin/notes.c:448
+#, c-format
+msgid ""
+"Cannot add notes. Found existing notes for object %s. Use '-f' to overwrite "
+"existing notes"
+msgstr ""
+"No se puede agregar notas. Se encontró notas existentes para objeto %s. Use "
+"'-f' para sobrescribir las notas existentes"
+
+#: builtin/notes.c:463 builtin/notes.c:544
+#, c-format
+msgid "Overwriting existing notes for object %s\n"
+msgstr "Sobrescribiendo notas existentes para objeto %s\n"
+
+#: builtin/notes.c:475 builtin/notes.c:637 builtin/notes.c:902
+#, c-format
+msgid "Removing note for object %s\n"
+msgstr "Removiendo nota para objeto %s\n"
+
+#: builtin/notes.c:497
+msgid "read objects from stdin"
+msgstr "leer objetos desde stdin"
+
+#: builtin/notes.c:499
+msgid "load rewriting config for <command> (implies --stdin)"
+msgstr "cargar configuración de reescritura para <comando> (implica --stdin)"
+
+#: builtin/notes.c:517
+msgid "too few parameters"
+msgstr "muy pocos parámetros"
+
+#: builtin/notes.c:538
+#, c-format
+msgid ""
+"Cannot copy notes. Found existing notes for object %s. Use '-f' to overwrite "
+"existing notes"
+msgstr ""
+"No se puede copiar notas. Se encontró notas existentes para el objeto %s. "
+"Use '-f' para sobrescribir las notes existentes"
+
+#: builtin/notes.c:550
+#, c-format
+msgid "missing notes on source object %s. Cannot copy."
+msgstr "faltan notas en la fuente del objeto %s. No se puede copiar."
+
+#: builtin/notes.c:603
+#, c-format
+msgid ""
+"The -m/-F/-c/-C options have been deprecated for the 'edit' subcommand.\n"
+"Please use 'git notes add -f -m/-F/-c/-C' instead.\n"
+msgstr ""
+"Las opciones -m/-F/-c/-C han sido deprecadas por el subcomando 'edit'.\n"
+"Por favor use 'git notes add -f -m/-F/-c/-C' en cambio.\n"
+
+#: builtin/notes.c:698
+msgid "failed to delete ref NOTES_MERGE_PARTIAL"
+msgstr "falló al borrar ref NOTES_MERGE_PARTIAL"
+
+#: builtin/notes.c:700
+msgid "failed to delete ref NOTES_MERGE_REF"
+msgstr "falló al borrar ref NOTES_MERGE_REF"
+
+#: builtin/notes.c:702
+msgid "failed to remove 'git notes merge' worktree"
+msgstr "no se pudo eliminar el árbol de trabajo 'git notes merge'"
+
+#: builtin/notes.c:722
+msgid "failed to read ref NOTES_MERGE_PARTIAL"
+msgstr "falló al leer ref NOTES_MERGE_PARTIAL"
+
+#: builtin/notes.c:724
+msgid "could not find commit from NOTES_MERGE_PARTIAL."
+msgstr "no se pudo encontrar commit de NOTES_MERGE_PARTIAL."
+
+#: builtin/notes.c:726
+msgid "could not parse commit from NOTES_MERGE_PARTIAL."
+msgstr "no se pudo analizar commit de NOTES_MERGE_PARTIAL."
+
+#: builtin/notes.c:739
+msgid "failed to resolve NOTES_MERGE_REF"
+msgstr "falló al resolver NOTES_MERGE_REF"
+
+#: builtin/notes.c:742
+msgid "failed to finalize notes merge"
+msgstr "falló al finalizar las notas de fusión"
+
+#: builtin/notes.c:768
+#, c-format
+msgid "unknown notes merge strategy %s"
+msgstr "estrategia de fusión de notas %s desconocida"
+
+#: builtin/notes.c:784
+msgid "General options"
+msgstr "Opciones generales"
+
+#: builtin/notes.c:786
+msgid "Merge options"
+msgstr "Opciones de fusión"
+
+#: builtin/notes.c:788
+msgid ""
+"resolve notes conflicts using the given strategy (manual/ours/theirs/union/"
+"cat_sort_uniq)"
+msgstr ""
+"resolver conflictos de notas usando la estrategia entregadas (manual/ours/"
+"theirs/union/cat_sort_uniq)"
+
+#: builtin/notes.c:790
+msgid "Committing unmerged notes"
+msgstr "Realizando commit a las notas no fusionadas"
+
+#: builtin/notes.c:792
+msgid "finalize notes merge by committing unmerged notes"
+msgstr ""
+"finalizar fusión de notas realizando un commit de las notas no fusionadas"
+
+#: builtin/notes.c:794
+msgid "Aborting notes merge resolution"
+msgstr "Abortando notas de resolución de fusión"
+
+#: builtin/notes.c:796
+msgid "abort notes merge"
+msgstr "abortar notas de fusión"
+
+#: builtin/notes.c:807
+msgid "cannot mix --commit, --abort or -s/--strategy"
+msgstr "no se pueden mezclar --commit, --abort ó -s/--strategy"
+
+#: builtin/notes.c:812
+msgid "must specify a notes ref to merge"
+msgstr "debe especificar una ref de notas a fusionar"
+
+#: builtin/notes.c:836
+#, c-format
+msgid "unknown -s/--strategy: %s"
+msgstr "--strategy/-s desconocida: %s"
+
+#: builtin/notes.c:873
+#, c-format
+msgid "a notes merge into %s is already in-progress at %s"
+msgstr "una fusión de notas en %s ya está en progreso en %s"
+
+#: builtin/notes.c:876
+#, c-format
+msgid "failed to store link to current notes ref (%s)"
+msgstr "falló al guardar un link para el ref de notas actual (%s)"
+
+#: builtin/notes.c:878
+#, c-format
+msgid ""
+"Automatic notes merge failed. Fix conflicts in %s and commit the result with "
+"'git notes merge --commit', or abort the merge with 'git notes merge --"
+"abort'.\n"
+msgstr ""
+"Fusión automática de notas falló. Arregle conflictos en %s y realice un "
+"commit con el resultado 'git notes merge --commit', o aborte la fusión con "
+"'git notes merge --abort'.\n"
+
+#: builtin/notes.c:897 builtin/tag.c:545
+#, c-format
+msgid "Failed to resolve '%s' as a valid ref."
+msgstr "Falló al resolver '%s' como una ref válida."
+
+#: builtin/notes.c:900
+#, c-format
+msgid "Object %s has no note\n"
+msgstr "El objeto %s no tiene notas\n"
+
+#: builtin/notes.c:912
+msgid "attempt to remove non-existent note is not an error"
+msgstr "intentar eliminar una nota no existente no es un error"
+
+#: builtin/notes.c:915
+msgid "read object names from the standard input"
+msgstr "leer nombres de objetos de standard input"
+
+#: builtin/notes.c:954 builtin/prune.c:130 builtin/worktree.c:164
+msgid "do not remove, show only"
+msgstr "no eliminar, solo mostrar"
+
+#: builtin/notes.c:955
+msgid "report pruned notes"
+msgstr "reportar notas recortadas"
+
+#: builtin/notes.c:998
+msgid "notes-ref"
+msgstr "referencia-de-notas"
+
+#: builtin/notes.c:999
+msgid "use notes from <notes-ref>"
+msgstr "usar notas desde <referencia-de-notas>"
+
+#: builtin/notes.c:1034 builtin/stash.c:1607
+#, c-format
+msgid "unknown subcommand: %s"
+msgstr "subcomando desconocido: %s"
+
+#: builtin/pack-objects.c:52
+msgid ""
+"git pack-objects --stdout [<options>...] [< <ref-list> | < <object-list>]"
+msgstr ""
+"git pack-objects --stdout [<opciones>...] [< <lista-de-ref> | < <lista-de-"
+"objetos>]"
+
+#: builtin/pack-objects.c:53
+msgid ""
+"git pack-objects [<options>...] <base-name> [< <ref-list> | < <object-list>]"
+msgstr ""
+"git pack-objects [<opciones>...] <nombre-base> [< <lista-de-refs> | < <lista-"
+"de-objetos>]"
+
+#: builtin/pack-objects.c:428
+#, c-format
+msgid "bad packed object CRC for %s"
+msgstr "mal paquete de objeto CRC para %s"
+
+#: builtin/pack-objects.c:439
+#, c-format
+msgid "corrupt packed object for %s"
+msgstr "objeto empaquetado corrupto para %s"
+
+#: builtin/pack-objects.c:570
+#, c-format
+msgid "recursive delta detected for object %s"
+msgstr "delta recursivo encontrado para objeto %s"
+
+#: builtin/pack-objects.c:781
+#, c-format
+msgid "ordered %u objects, expected %<PRIu32>"
+msgstr "%u objetos ordenados, esperados %<PRIu32>"
+
+#: builtin/pack-objects.c:794
+#, c-format
+msgid "packfile is invalid: %s"
+msgstr "packfile es inválido: %s"
+
+#: builtin/pack-objects.c:798
+#, c-format
+msgid "unable to open packfile for reuse: %s"
+msgstr "no es posible abrir packfile para reusar: %s"
+
+#: builtin/pack-objects.c:802
+msgid "unable to seek in reused packfile"
+msgstr "no es posible buscar en los packfile reusados"
+
+#: builtin/pack-objects.c:813
+msgid "unable to read from reused packfile"
+msgstr "no es posible leer de packfile reusado"
+
+#: builtin/pack-objects.c:841
+msgid "disabling bitmap writing, packs are split due to pack.packSizeLimit"
+msgstr ""
+"deshabilitando escritura bitmap, paquetes son divididos debido a pack."
+"packSizeLimit"
+
+#: builtin/pack-objects.c:854
+msgid "Writing objects"
+msgstr "Escribiendo objetos"
+
+#: builtin/pack-objects.c:917 builtin/update-index.c:90
+#, c-format
+msgid "failed to stat %s"
+msgstr "falló al iniciar %s"
+
+#: builtin/pack-objects.c:970
+#, c-format
+msgid "wrote %<PRIu32> objects while expecting %<PRIu32>"
+msgstr "%<PRIu32> objetos escritos mientras se esperaban %<PRIu32>"
+
+#: builtin/pack-objects.c:1164
+msgid "disabling bitmap writing, as some objects are not being packed"
+msgstr ""
+"deshabilitando escritura bitmap, ya que algunos objetos no están siendo "
+"empaquetados"
+
+#: builtin/pack-objects.c:1592
+#, c-format
+msgid "delta base offset overflow in pack for %s"
+msgstr "overflow de offset en la base de delta en paquete para %s"
+
+#: builtin/pack-objects.c:1601
+#, c-format
+msgid "delta base offset out of bound for %s"
+msgstr "outbound de offset en la base de delta para %s"
+
+#: builtin/pack-objects.c:1870
+msgid "Counting objects"
+msgstr "Contando objetos"
+
+#: builtin/pack-objects.c:2000
+#, c-format
+msgid "unable to get size of %s"
+msgstr "no se pudo obtener el tamaño de %s"
+
+#: builtin/pack-objects.c:2015
+#, c-format
+msgid "unable to parse object header of %s"
+msgstr "incapaz de analizar header del objeto %s"
+
+#: builtin/pack-objects.c:2085 builtin/pack-objects.c:2101
+#: builtin/pack-objects.c:2111
+#, c-format
+msgid "object %s cannot be read"
+msgstr "objeto %s no puede ser leído"
+
+#: builtin/pack-objects.c:2088 builtin/pack-objects.c:2115
+#, c-format
+msgid "object %s inconsistent object length (%<PRIuMAX> vs %<PRIuMAX>)"
+msgstr ""
+"objeto %s inconsistente con el largo del objeto (%<PRIuMAX> vs %<PRIuMAX>)"
+
+#: builtin/pack-objects.c:2125
+msgid "suboptimal pack - out of memory"
+msgstr "suboptimal pack - fuera de memoria"
+
+#: builtin/pack-objects.c:2440
+#, c-format
+msgid "Delta compression using up to %d threads"
+msgstr "Compresión delta usando hasta %d hilos"
+
+#: builtin/pack-objects.c:2572
+#, c-format
+msgid "unable to pack objects reachable from tag %s"
+msgstr "no es posible empaquetar objetos alcanzables desde tag %s"
+
+#: builtin/pack-objects.c:2659
+msgid "Compressing objects"
+msgstr "Comprimiendo objetos"
+
+#: builtin/pack-objects.c:2665
+msgid "inconsistency with delta count"
+msgstr "inconsistencia con la cuenta de delta"
+
+#: builtin/pack-objects.c:2742
+#, c-format
+msgid ""
+"expected edge object ID, got garbage:\n"
+" %s"
+msgstr ""
+"se espseraba ID de objeto al borde, se obtuvo basura:\n"
+"%s"
+
+#: builtin/pack-objects.c:2748
+#, c-format
+msgid ""
+"expected object ID, got garbage:\n"
+" %s"
+msgstr ""
+"se esperaba ID de objeto, se obtuvo basuta:\n"
+"%s"
+
+#: builtin/pack-objects.c:2846
+msgid "invalid value for --missing"
+msgstr "valor inválido para --missing"
+
+#: builtin/pack-objects.c:2905 builtin/pack-objects.c:3013
+msgid "cannot open pack index"
+msgstr "no se puede abrir índice de paquetes"
+
+#: builtin/pack-objects.c:2936
+#, c-format
+msgid "loose object at %s could not be examined"
+msgstr "objeto perdido en %s no pudo ser examinado"
+
+#: builtin/pack-objects.c:3021
+msgid "unable to force loose object"
+msgstr "incapaz de forzar un objeto perdido"
+
+#: builtin/pack-objects.c:3113
+#, c-format
+msgid "not a rev '%s'"
+msgstr "no es una rev '%s'"
+
+#: builtin/pack-objects.c:3116
+#, c-format
+msgid "bad revision '%s'"
+msgstr "mala revisión '%s'"
+
+#: builtin/pack-objects.c:3141
+msgid "unable to add recent objects"
+msgstr "incapaz de añadir objetos recientes"
+
+#: builtin/pack-objects.c:3194
+#, c-format
+msgid "unsupported index version %s"
+msgstr "versión de índice no soportada %s"
+
+#: builtin/pack-objects.c:3198
+#, c-format
+msgid "bad index version '%s'"
+msgstr "mala versión del índice '%s'"
+
+#: builtin/pack-objects.c:3236
+msgid "<version>[,<offset>]"
+msgstr "<versión>[,<offset>]"
+
+#: builtin/pack-objects.c:3237
+msgid "write the pack index file in the specified idx format version"
+msgstr ""
+"escribir el índice de paquete en la versión de formato idx especificado"
+
+#: builtin/pack-objects.c:3240
+msgid "maximum size of each output pack file"
+msgstr "tamaño máximo de cada paquete resultante"
+
+#: builtin/pack-objects.c:3242
+msgid "ignore borrowed objects from alternate object store"
+msgstr "ignorar objetos prestados de otros almacenes de objetos"
+
+#: builtin/pack-objects.c:3244
+msgid "ignore packed objects"
+msgstr "ignorar objetos paquete"
+
+#: builtin/pack-objects.c:3246
+msgid "limit pack window by objects"
+msgstr "limitar ventana de paquete por objetos"
+
+#: builtin/pack-objects.c:3248
+msgid "limit pack window by memory in addition to object limit"
+msgstr "limitar ventana de paquete por memoria en adición a límite de objetos"
+
+#: builtin/pack-objects.c:3250
+msgid "maximum length of delta chain allowed in the resulting pack"
+msgstr "longitud máxima de cadena delta permitida en el paquete resultante"
+
+#: builtin/pack-objects.c:3252
+msgid "reuse existing deltas"
+msgstr "reusar deltas existentes"
+
+#: builtin/pack-objects.c:3254
+msgid "reuse existing objects"
+msgstr "reutilizar objetos existentes"
+
+#: builtin/pack-objects.c:3256
+msgid "use OFS_DELTA objects"
+msgstr "usar objetos OFS_DELTA"
+
+#: builtin/pack-objects.c:3258
+msgid "use threads when searching for best delta matches"
+msgstr "usar hilos cuando se busque para mejores concordancias de delta"
+
+#: builtin/pack-objects.c:3260
+msgid "do not create an empty pack output"
+msgstr "no crear un paquete resultante vacío"
+
+#: builtin/pack-objects.c:3262
+msgid "read revision arguments from standard input"
+msgstr "leer argumentos de revisión de standard input"
+
+#: builtin/pack-objects.c:3264
+msgid "limit the objects to those that are not yet packed"
+msgstr "limitar los objetos a aquellos que no han sido empaquetados todavía"
+
+#: builtin/pack-objects.c:3267
+msgid "include objects reachable from any reference"
+msgstr "incluir objetos alcanzables por cualquier referencia"
+
+#: builtin/pack-objects.c:3270
+msgid "include objects referred by reflog entries"
+msgstr "incluir objetos referidos por entradas de reflog"
+
+#: builtin/pack-objects.c:3273
+msgid "include objects referred to by the index"
+msgstr "incluir objetos referidos por el índice"
+
+#: builtin/pack-objects.c:3276
+msgid "output pack to stdout"
+msgstr "mostrar paquete en stdout"
+
+#: builtin/pack-objects.c:3278
+msgid "include tag objects that refer to objects to be packed"
+msgstr "incluir objetos tag que refieren a objetos a ser empaquetados"
+
+#: builtin/pack-objects.c:3280
+msgid "keep unreachable objects"
+msgstr "mantener objetos inalcanzables"
+
+#: builtin/pack-objects.c:3282
+msgid "pack loose unreachable objects"
+msgstr "empaquetar objetos sueltos inalcanzables"
+
+#: builtin/pack-objects.c:3284
+msgid "unpack unreachable objects newer than <time>"
+msgstr "desempaquetar objetos inalcanzables más nuevos que <tiempo>"
+
+#: builtin/pack-objects.c:3287
+msgid "use the sparse reachability algorithm"
+msgstr "usar el algoritmo sparse reachability"
+
+#: builtin/pack-objects.c:3289
+msgid "create thin packs"
+msgstr "crear paquetes delgados"
+
+#: builtin/pack-objects.c:3291
+msgid "create packs suitable for shallow fetches"
+msgstr "crear paquetes adecuados para fetches superficiales"
+
+#: builtin/pack-objects.c:3293
+msgid "ignore packs that have companion .keep file"
+msgstr "ignorar paquetes que tienen un archivo .keep acompañante"
+
+#: builtin/pack-objects.c:3295
+msgid "ignore this pack"
+msgstr "ignorar este paquete"
+
+#: builtin/pack-objects.c:3297
+msgid "pack compression level"
+msgstr "nivel de compresión del paquete"
+
+#: builtin/pack-objects.c:3299
+msgid "do not hide commits by grafts"
+msgstr "no ocultar commits por injertos"
+
+#: builtin/pack-objects.c:3301
+msgid "use a bitmap index if available to speed up counting objects"
+msgstr ""
+"usar un índice bitmap si está disponible para acelerar la cuenta de objetos"
+
+#: builtin/pack-objects.c:3303
+msgid "write a bitmap index together with the pack index"
+msgstr "escribir un índice de bitmap junto al índice de paquete"
+
+#: builtin/pack-objects.c:3307
+msgid "write a bitmap index if possible"
+msgstr "escribir un índice de bitmap si es posible"
+
+#: builtin/pack-objects.c:3311
+msgid "handling for missing objects"
+msgstr "manejo de objetos perdidos"
+
+#: builtin/pack-objects.c:3314
+msgid "do not pack objects in promisor packfiles"
+msgstr "no se puede empaquetar objetos en packfiles promisores"
+
+#: builtin/pack-objects.c:3316
+msgid "respect islands during delta compression"
+msgstr "respetar islas durante la compresión delta"
+
+#: builtin/pack-objects.c:3345
+#, c-format
+msgid "delta chain depth %d is too deep, forcing %d"
+msgstr "profundidad de cadena de delta %d es muy profunda, forzando %d"
+
+#: builtin/pack-objects.c:3350
+#, c-format
+msgid "pack.deltaCacheLimit is too high, forcing %d"
+msgstr "pack.deltaCacheLimit es muy grande, forzando %d"
+
+#: builtin/pack-objects.c:3404
+msgid "--max-pack-size cannot be used to build a pack for transfer"
+msgstr ""
+"--max-pack-size no puede ser usado para construir un paquete para "
+"transferencia"
+
+#: builtin/pack-objects.c:3406
+msgid "minimum pack size limit is 1 MiB"
+msgstr "tamaño mínimo del paquete es 1 MiB"
+
+#: builtin/pack-objects.c:3411
+msgid "--thin cannot be used to build an indexable pack"
+msgstr "--thin no puede ser usado para construir un paquete indexable"
+
+#: builtin/pack-objects.c:3414
+msgid "--keep-unreachable and --unpack-unreachable are incompatible"
+msgstr "--keep-unreachable y --unpack-unreachable son incompatibles"
+
+#: builtin/pack-objects.c:3420
+msgid "cannot use --filter without --stdout"
+msgstr "no se puede usar--filter sin --stdout"
+
+#: builtin/pack-objects.c:3481
+msgid "Enumerating objects"
+msgstr "Enumerando objetos"
+
+#: builtin/pack-objects.c:3511
+#, c-format
+msgid "Total %<PRIu32> (delta %<PRIu32>), reused %<PRIu32> (delta %<PRIu32>)"
+msgstr "Total %<PRIu32> (delta %<PRIu32>), reusado %<PRIu32> (delta %<PRIu32>)"
+
+#: builtin/pack-refs.c:8
+msgid "git pack-refs [<options>]"
+msgstr "git pack-refs [<opciones>]"
+
+#: builtin/pack-refs.c:16
+msgid "pack everything"
+msgstr "empaquetar todo"
+
+#: builtin/pack-refs.c:17
+msgid "prune loose refs (default)"
+msgstr "recortar refs perdidos (default)"
+
+#: builtin/prune-packed.c:9
+msgid "git prune-packed [-n | --dry-run] [-q | --quiet]"
+msgstr "git prune-packed [-n | --dry-run] [-q | --quiet]"
+
+#: builtin/prune-packed.c:42
+msgid "Removing duplicate objects"
+msgstr "Removiendo objetos duplicados"
+
+#: builtin/prune.c:12
+msgid "git prune [-n] [-v] [--progress] [--expire <time>] [--] [<head>...]"
+msgstr "git prune [-n] [-v] [--progress] [--expire <tiempo>] [--] [<head>...]"
+
+#: builtin/prune.c:131
+msgid "report pruned objects"
+msgstr "reportar objetos recortados"
+
+#: builtin/prune.c:134
+msgid "expire objects older than <time>"
+msgstr "expirar objetos más viejos a <tiempo>"
+
+#: builtin/prune.c:136
+msgid "limit traversal to objects outside promisor packfiles"
+msgstr "limitar el recorrido a objetos fuera de los paquetes del promisor"
+
+#: builtin/prune.c:150
+msgid "cannot prune in a precious-objects repo"
+msgstr "no se puede recortar en un repositorio de objetos-preciosos"
+
+#: builtin/pull.c:66 builtin/pull.c:68
+#, c-format
+msgid "Invalid value for %s: %s"
+msgstr "Valor inválido para %s: %s"
+
+#: builtin/pull.c:88
+msgid "git pull [<options>] [<repository> [<refspec>...]]"
+msgstr ""
+"git pull [<opciones>] [<repositorio> [<especificación-de-referencia>...]]"
+
+#: builtin/pull.c:142
+msgid "control for recursive fetching of submodules"
+msgstr "control de fetch recursivo en submódulos"
+
+#: builtin/pull.c:146
+msgid "Options related to merging"
+msgstr "Opciones relacionadas a fusión"
+
+#: builtin/pull.c:149
+msgid "incorporate changes by rebasing rather than merging"
+msgstr "incorporar cambios por rebase en lugar de fusión"
+
+#: builtin/pull.c:177 builtin/rebase.c:467 builtin/revert.c:126
+msgid "allow fast-forward"
+msgstr "permitir fast-forward"
+
+#: builtin/pull.c:186
+msgid "automatically stash/stash pop before and after rebase"
+msgstr "ejecutar automáticamente stash/stash pop antes y después de rebase"
+
+#: builtin/pull.c:202
+msgid "Options related to fetching"
+msgstr "Opciones relacionadas a fetch"
+
+#: builtin/pull.c:212
+msgid "force overwrite of local branch"
+msgstr "forzar sobrescritura de la rama local"
+
+#: builtin/pull.c:220
+msgid "number of submodules pulled in parallel"
+msgstr "número de submódulos que realizan pull en paralelo"
+
+#: builtin/pull.c:320
+#, c-format
+msgid "Invalid value for pull.ff: %s"
+msgstr "Valor inválido para pull.ff: %s"
+
+#: builtin/pull.c:437
+msgid ""
+"There is no candidate for rebasing against among the refs that you just "
+"fetched."
+msgstr "No hay candidato para rebasar entre las refs que has bajado con fetch."
+
+#: builtin/pull.c:439
+msgid ""
+"There are no candidates for merging among the refs that you just fetched."
+msgstr ""
+"No hay candidatos para fusionar entre las refs que has bajado con fetch."
+
+#: builtin/pull.c:440
+msgid ""
+"Generally this means that you provided a wildcard refspec which had no\n"
+"matches on the remote end."
+msgstr ""
+"Generalmente esto significa que has proveído un wildcard de refspec que no "
+"tiene\n"
+"concordancia en el final remoto."
+
+#: builtin/pull.c:443
+#, c-format
+msgid ""
+"You asked to pull from the remote '%s', but did not specify\n"
+"a branch. Because this is not the default configured remote\n"
+"for your current branch, you must specify a branch on the command line."
+msgstr ""
+"Se ha solicitado un pull del remoto '%s', pero no se ha especificado\n"
+"una rama. Porque este no es el remoto configurado por default\n"
+"para tu rama actual, tienes que especificar una rama en la línea de comando."
+
+#: builtin/pull.c:448 builtin/rebase.c:1375 git-parse-remote.sh:73
+msgid "You are not currently on a branch."
+msgstr "No te encuentras actualmente en la rama."
+
+#: builtin/pull.c:450 builtin/pull.c:465 git-parse-remote.sh:79
+msgid "Please specify which branch you want to rebase against."
+msgstr "Por favor especifica a qué rama quieres rebasar."
+
+#: builtin/pull.c:452 builtin/pull.c:467 git-parse-remote.sh:82
+msgid "Please specify which branch you want to merge with."
+msgstr "Por favor especifica a qué rama quieres fusionar."
+
+#: builtin/pull.c:453 builtin/pull.c:468
+msgid "See git-pull(1) for details."
+msgstr "Ver git-pull(1) para detalles."
+
+#: builtin/pull.c:455 builtin/pull.c:461 builtin/pull.c:470
+#: builtin/rebase.c:1381 git-parse-remote.sh:64
+msgid "<remote>"
+msgstr "<remoto>"
+
+#: builtin/pull.c:455 builtin/pull.c:470 builtin/pull.c:475
+#: git-parse-remote.sh:65
+msgid "<branch>"
+msgstr "<rama>"
+
+#: builtin/pull.c:463 builtin/rebase.c:1373 git-parse-remote.sh:75
+msgid "There is no tracking information for the current branch."
+msgstr "No hay información de rastreo para la rama actual."
+
+#: builtin/pull.c:472 git-parse-remote.sh:95
+msgid ""
+"If you wish to set tracking information for this branch you can do so with:"
+msgstr ""
+"Si deseas configurar el rastreo de información para esta rama, puedes "
+"hacerlo con:"
+
+#: builtin/pull.c:477
+#, c-format
+msgid ""
+"Your configuration specifies to merge with the ref '%s'\n"
+"from the remote, but no such ref was fetched."
+msgstr ""
+"Tu configuración especifica fusionar con la ref '%s'\n"
+"de tu remoto, pero no se pudo hacer fetch a esa ref."
+
+#: builtin/pull.c:587
+#, c-format
+msgid "unable to access commit %s"
+msgstr "no es posible acceder al commit %s"
+
+#: builtin/pull.c:867
+msgid "ignoring --verify-signatures for rebase"
+msgstr "ignorando --verify-signatures para rebase"
+
+#: builtin/pull.c:922
+msgid "--[no-]autostash option is only valid with --rebase."
+msgstr "La opción --[no-]autostash sólo es válida con --rebase."
+
+#: builtin/pull.c:930
+msgid "Updating an unborn branch with changes added to the index."
+msgstr "Actualizando una rama no nata con cambios agregados al índice."
+
+#: builtin/pull.c:934
+msgid "pull with rebase"
+msgstr "pull con rebase"
+
+#: builtin/pull.c:935
+msgid "please commit or stash them."
+msgstr "por favor realiza un commit o un stash con ellos."
+
+#: builtin/pull.c:960
+#, c-format
+msgid ""
+"fetch updated the current branch head.\n"
+"fast-forwarding your working tree from\n"
+"commit %s."
+msgstr ""
+"fetch actualizó el head de la rama actual.\n"
+"realizando fast-forward al árbol de trabajo\n"
+"desde commit %s."
+
+#: builtin/pull.c:966
+#, c-format
+msgid ""
+"Cannot fast-forward your working tree.\n"
+"After making sure that you saved anything precious from\n"
+"$ git diff %s\n"
+"output, run\n"
+"$ git reset --hard\n"
+"to recover."
+msgstr ""
+"No se puede realizar fast-forward en tu árbol de trabajo.\n"
+"Tras asegurarse que ha guardado todo lo preciado de la salida de\n"
+"$ git diff %s\n"
+",ejecute\n"
+"$ git reset --hard\n"
+"para recuperar."
+
+#: builtin/pull.c:981
+msgid "Cannot merge multiple branches into empty head."
+msgstr "No se puede fusionar múltiples ramas en un head vacío."
+
+#: builtin/pull.c:985
+msgid "Cannot rebase onto multiple branches."
+msgstr "No se puede rebasar en múltiples ramas."
+
+#: builtin/pull.c:992
+msgid "cannot rebase with locally recorded submodule modifications"
+msgstr ""
+"no se puede rebasar con modificaciones de submódulos grabadas localmente"
+
+#: builtin/push.c:19
+msgid "git push [<options>] [<repository> [<refspec>...]]"
+msgstr ""
+"git push [<opciones>] [<repositorio> [<especificaciones-de-referencia>...]]"
+
+#: builtin/push.c:112
+msgid "tag shorthand without <tag>"
+msgstr "taquigrafía de tag sin <tag>"
+
+#: builtin/push.c:122
+msgid "--delete only accepts plain target ref names"
+msgstr "--delete solo acepta como objetivos nombres de ref planos"
+
+#: builtin/push.c:168
+msgid ""
+"\n"
+"To choose either option permanently, see push.default in 'git help config'."
+msgstr ""
+"\n"
+"Para elegir si la opción es permanente, mira push.default en 'git help "
+"config'."
+
+#: builtin/push.c:171
+#, c-format
+msgid ""
+"The upstream branch of your current branch does not match\n"
+"the name of your current branch.  To push to the upstream branch\n"
+"on the remote, use\n"
+"\n"
+"    git push %s HEAD:%s\n"
+"\n"
+"To push to the branch of the same name on the remote, use\n"
+"\n"
+"    git push %s HEAD\n"
+"%s"
+msgstr ""
+"La rama upstream de tu rama actual no concuerda\n"
+"con el nombre de tu rama actual. Para hacer un push a la rama upstream\n"
+"en el remoto, ejecuta\n"
+"\n"
+"    git push %s HEAD:%s\n"
+"\n"
+"Para hacer un push a la rama del mismo nombre en el remoto, ejecuta\n"
+"\n"
+"    git push %s HEAD\n"
+"%s"
+
+#: builtin/push.c:186
+#, c-format
+msgid ""
+"You are not currently on a branch.\n"
+"To push the history leading to the current (detached HEAD)\n"
+"state now, use\n"
+"\n"
+"    git push %s HEAD:<name-of-remote-branch>\n"
+msgstr ""
+"Actualmente no estás en una rama.\n"
+"Para hacer un push a la historia que lleva al estado actual\n"
+"(HEAD desacoplado), use\n"
+"\n"
+"\tgit push %s HEAD:<nombre-de-rama-remota>\n"
+
+#: builtin/push.c:200
+#, c-format
+msgid ""
+"The current branch %s has no upstream branch.\n"
+"To push the current branch and set the remote as upstream, use\n"
+"\n"
+"    git push --set-upstream %s %s\n"
+msgstr ""
+"La rama actual %s no tiene una rama upstream.\n"
+"Para realizar un push de la rama actual y configurar el remoto como "
+"upstream, use\n"
+"\n"
+"\tgit push --set-upstream %s %s\n"
+
+#: builtin/push.c:208
+#, c-format
+msgid "The current branch %s has multiple upstream branches, refusing to push."
+msgstr "La rama actual %s tiene múltiples ramas upstream, rechazando el push."
+
+#: builtin/push.c:211
+#, c-format
+msgid ""
+"You are pushing to remote '%s', which is not the upstream of\n"
+"your current branch '%s', without telling me what to push\n"
+"to update which remote branch."
+msgstr ""
+"Estás haciendo un push al remoto '%s', el cual no es el upstream de\n"
+"la rama actual '%s', sin decirme qué poner en el push\n"
+"para actualizar en qué rama de remoto."
+
+#: builtin/push.c:270
+msgid ""
+"You didn't specify any refspecs to push, and push.default is \"nothing\"."
+msgstr ""
+"No se especificó ningún refspecs para hacer push, y push.default es \"nada\"."
+
+#: builtin/push.c:277
+msgid ""
+"Updates were rejected because the tip of your current branch is behind\n"
+"its remote counterpart. Integrate the remote changes (e.g.\n"
+"'git pull ...') before pushing again.\n"
+"See the 'Note about fast-forwards' in 'git push --help' for details."
+msgstr ""
+"Actualizaciones fueron rechazadas porque la punta de tu rama actual está\n"
+"detrás de su contraparte remota. Integra los cambios remotos (es decir\n"
+"'git pull ...') antes de hacer push de nuevo.\n"
+"Mira 'Note about fast-forwards' en 'git push --help' para más detalles."
+
+#: builtin/push.c:283
+msgid ""
+"Updates were rejected because a pushed branch tip is behind its remote\n"
+"counterpart. Check out this branch and integrate the remote changes\n"
+"(e.g. 'git pull ...') before pushing again.\n"
+"See the 'Note about fast-forwards' in 'git push --help' for details."
+msgstr ""
+"Actualizaciones fueron rechazadas porque una punta de rama en el push está \n"
+"detrás de su contraparte remota. Verifique esta rama e integre los cambios "
+"remotos\n"
+"(ejem. 'git pull ...') antes de volver a hacer push.\n"
+"Vea las 'Notes about fast-forwards' en 'git push --help' para más detalles."
+
+#: builtin/push.c:289
+msgid ""
+"Updates were rejected because the remote contains work that you do\n"
+"not have locally. This is usually caused by another repository pushing\n"
+"to the same ref. You may want to first integrate the remote changes\n"
+"(e.g., 'git pull ...') before pushing again.\n"
+"See the 'Note about fast-forwards' in 'git push --help' for details."
+msgstr ""
+"Actualizaciones fueron rechazadas porque el remoto contiene trabajo que\n"
+"no existe localmente. Esto es causado usualmente por otro repositorio \n"
+"realizando push a la misma ref. Quizás quiera integrar primero los cambios\n"
+"remotos (ej. 'git pull ...') antes de volver a hacer push.\n"
+"Vea 'Notes about fast-forwards0 en 'git push --help' para detalles."
+
+#: builtin/push.c:296
+msgid "Updates were rejected because the tag already exists in the remote."
+msgstr ""
+"Actualizaciones fueron rechazadas porque el tag ya existe en el remoto."
+
+#: builtin/push.c:299
+msgid ""
+"You cannot update a remote ref that points at a non-commit object,\n"
+"or update a remote ref to make it point at a non-commit object,\n"
+"without using the '--force' option.\n"
+msgstr ""
+"No se puede actualizar un ref remoto que apunta a un objeto no-commit,\n"
+"o actualizar un ref remoto para hacer que  apunte a un objeto no-commit,\n"
+"sin usar la opción '--force'.\n"
+
+#: builtin/push.c:360
+#, c-format
+msgid "Pushing to %s\n"
+msgstr "Haciendo push a %s\n"
+
+#: builtin/push.c:367
+#, c-format
+msgid "failed to push some refs to '%s'"
+msgstr "falló el push de algunas referencias a '%s'"
+
+#: builtin/push.c:542
+msgid "repository"
+msgstr "repositorio"
+
+#: builtin/push.c:543 builtin/send-pack.c:164
+msgid "push all refs"
+msgstr "realizar push a todas las refs"
+
+#: builtin/push.c:544 builtin/send-pack.c:166
+msgid "mirror all refs"
+msgstr "realizar mirror a todas las refs"
+
+#: builtin/push.c:546
+msgid "delete refs"
+msgstr "borrar refs"
+
+#: builtin/push.c:547
+msgid "push tags (can't be used with --all or --mirror)"
+msgstr "realizar push a tags (no puede ser usado con --all o --mirror)"
+
+#: builtin/push.c:550 builtin/send-pack.c:167
+msgid "force updates"
+msgstr "forzar actualizaciones"
+
+#: builtin/push.c:552 builtin/send-pack.c:181
+msgid "<refname>:<expect>"
+msgstr "<refname>:<expect>"
+
+#: builtin/push.c:553 builtin/send-pack.c:182
+msgid "require old value of ref to be at this value"
+msgstr "requiere haber valor viejo de ref en este valor"
+
+#: builtin/push.c:556
+msgid "control recursive pushing of submodules"
+msgstr "controlar push recursivo de submódulos"
+
+#: builtin/push.c:558 builtin/send-pack.c:175
+msgid "use thin pack"
+msgstr "usar empaquetado delgado"
+
+#: builtin/push.c:559 builtin/push.c:560 builtin/send-pack.c:161
+#: builtin/send-pack.c:162
+msgid "receive pack program"
+msgstr "recibir programa de paquete"
+
+#: builtin/push.c:561
+msgid "set upstream for git pull/status"
+msgstr "configurar upstream para git pulll/status"
+
+#: builtin/push.c:564
+msgid "prune locally removed refs"
+msgstr "recortando refs eliminadas localmente"
+
+#: builtin/push.c:566
+msgid "bypass pre-push hook"
+msgstr "hacer un bypass al hook pre-push"
+
+#: builtin/push.c:567
+msgid "push missing but relevant tags"
+msgstr "realizar push de tags faltantes pero relevantes"
+
+#: builtin/push.c:570 builtin/send-pack.c:169
+msgid "GPG sign the push"
+msgstr "Firmar con GPG el push"
+
+#: builtin/push.c:572 builtin/send-pack.c:176
+msgid "request atomic transaction on remote side"
+msgstr "solicitar transacción atómica en el lado remoto"
+
+#: builtin/push.c:590
+msgid "--delete is incompatible with --all, --mirror and --tags"
+msgstr "--delete es incompatible con --all, --mirror y --tags"
+
+#: builtin/push.c:592
+msgid "--delete doesn't make sense without any refs"
+msgstr "--delete no tiene sentido sin ninguna referencia"
+
+#: builtin/push.c:612
+#, c-format
+msgid "bad repository '%s'"
+msgstr "mal repositorio '%s'"
+
+#: builtin/push.c:613
+msgid ""
+"No configured push destination.\n"
+"Either specify the URL from the command-line or configure a remote "
+"repository using\n"
+"\n"
+"    git remote add <name> <url>\n"
+"\n"
+"and then push using the remote name\n"
+"\n"
+"    git push <name>\n"
+msgstr ""
+"No se ha configurado un destino para el push.\n"
+"Puedes o especificar una URL desde la línea de comandos o configurar un "
+"repositorio remoto usando\n"
+"\n"
+"    git remote add <nombre> <url>\n"
+"\n"
+"y luego haciendo push al nombre del remoto\n"
+"\n"
+"    git push <nombre>\n"
 
-#: builtin/pack-objects.c:3161
-msgid "create thin packs"
-msgstr "crear paquetes delgados"
+#: builtin/push.c:628
+msgid "--all and --tags are incompatible"
+msgstr "--all y --tags son incompatibles"
 
-#: builtin/pack-objects.c:3163
-msgid "create packs suitable for shallow fetches"
-msgstr "crear paquetes adecuados para fetches superficiales"
+#: builtin/push.c:630
+msgid "--all can't be combined with refspecs"
+msgstr "--all no puede ser combinada con refspecs"
 
-#: builtin/pack-objects.c:3165
-msgid "ignore packs that have companion .keep file"
-msgstr "ignorar paquetes que tienen un archivo .keep acompañante"
+#: builtin/push.c:634
+msgid "--mirror and --tags are incompatible"
+msgstr "--mirror y --tags son incompatibles"
 
-#: builtin/pack-objects.c:3167
-msgid "ignore this pack"
-msgstr "ignorar este paquete"
+#: builtin/push.c:636
+msgid "--mirror can't be combined with refspecs"
+msgstr "--mirror no puede ser combinado con refspecs"
 
-#: builtin/pack-objects.c:3169
-msgid "pack compression level"
-msgstr "nivel de compresión del paquete"
+#: builtin/push.c:639
+msgid "--all and --mirror are incompatible"
+msgstr "--all y --mirror son incompatibles"
 
-#: builtin/pack-objects.c:3171
-msgid "do not hide commits by grafts"
-msgstr "no ocultar commits por injertos"
+#: builtin/push.c:643
+msgid "push options must not have new line characters"
+msgstr "opciones de push no pueden tener caracteres de línea nueva"
 
-#: builtin/pack-objects.c:3173
-msgid "use a bitmap index if available to speed up counting objects"
+#: builtin/range-diff.c:8
+msgid "git range-diff [<options>] <old-base>..<old-tip> <new-base>..<new-tip>"
 msgstr ""
-"usar un índice bitmap si está disponible para acelerar la cuenta de objetos"
+"git range-diff [<opciones>] <base-vieja>..<punta-vieja> <base-nueva>..<punta-"
+"nueva>"
 
-#: builtin/pack-objects.c:3175
-msgid "write a bitmap index together with the pack index"
-msgstr "escribir un índice de bitmap junto al índice de paquete"
+#: builtin/range-diff.c:9
+msgid "git range-diff [<options>] <old-tip>...<new-tip>"
+msgstr "git range-diff [<opciones>] <punta-vieja>...<punta-nueva>"
 
-#: builtin/pack-objects.c:3178
-msgid "handling for missing objects"
-msgstr "manejo de objetos perdidos"
+#: builtin/range-diff.c:10
+msgid "git range-diff [<options>] <base> <old-tip> <new-tip>"
+msgstr "git range-diff [<opciones>] <base> <punta-vieja> <punta-nueva>"
 
-#: builtin/pack-objects.c:3181
-msgid "do not pack objects in promisor packfiles"
-msgstr "no se puede empaquetar objetos en packfiles promisores"
+#: builtin/range-diff.c:22
+msgid "Percentage by which creation is weighted"
+msgstr "Porcentaje por el cual la creación es pesada"
 
-#: builtin/pack-objects.c:3205
-#, c-format
-msgid "delta chain depth %d is too deep, forcing %d"
-msgstr "profundidad de cadena de delta %d es muy profunda, forzando %d"
+#: builtin/range-diff.c:24
+msgid "use simple diff colors"
+msgstr "usar colores simples de diff"
 
-#: builtin/pack-objects.c:3210
-#, c-format
-msgid "pack.deltaCacheLimit is too high, forcing %d"
-msgstr "pack.deltaCacheLimit es muy grande, forzando %d"
+#: builtin/range-diff.c:26
+msgid "notes"
+msgstr "notas"
 
-#: builtin/pack-objects.c:3338
-msgid "Enumerating objects"
-msgstr "Enumerando objetos"
+#: builtin/range-diff.c:26
+msgid "passed to 'git log'"
+msgstr "pasado a 'git log'"
 
-#: builtin/pack-refs.c:7
-msgid "git pack-refs [<options>]"
-msgstr "git pack-refs [<opciones>]"
+#: builtin/range-diff.c:50 builtin/range-diff.c:54
+#, c-format
+msgid "no .. in range: '%s'"
+msgstr "no .. en rango: '%s'"
 
-#: builtin/pack-refs.c:15
-msgid "pack everything"
-msgstr "empaquetar todo"
+#: builtin/range-diff.c:64
+msgid "single arg format must be symmetric range"
+msgstr "argumento único de formato debe ser un rango simétrico"
 
-#: builtin/pack-refs.c:16
-msgid "prune loose refs (default)"
-msgstr "recortar refs perdidos (default)"
+#: builtin/range-diff.c:79
+msgid "need two commit ranges"
+msgstr "se necesitan dos rangos de commits"
 
-#: builtin/prune-packed.c:8
-msgid "git prune-packed [-n | --dry-run] [-q | --quiet]"
-msgstr "git prune-packed [-n | --dry-run] [-q | --quiet]"
+#: builtin/read-tree.c:41
+msgid ""
+"git read-tree [(-m [--trivial] [--aggressive] | --reset | --prefix=<prefix>) "
+"[-u [--exclude-per-directory=<gitignore>] | -i]] [--no-sparse-checkout] [--"
+"index-output=<file>] (--empty | <tree-ish1> [<tree-ish2> [<tree-ish3>]])"
+msgstr ""
+"git read-tree [(-m [--trivial] [--aggressive] | --reset | --"
+"prefix=<prefijo>) [-u [--exclude-per-directory=<gitignore>] | -i]] [--no-"
+"sparse-checkout] [--index-output=<archivo>] (--empty | <árbol-ismo1> [<árbol-"
+"ismo2> [<árbol-ismo3>]])"
 
-#: builtin/prune-packed.c:41
-msgid "Removing duplicate objects"
-msgstr "Removiendo objetos duplicados"
+#: builtin/read-tree.c:124
+msgid "write resulting index to <file>"
+msgstr "escribir índice resultante en <archivo>"
 
-#: builtin/prune.c:11
-msgid "git prune [-n] [-v] [--progress] [--expire <time>] [--] [<head>...]"
-msgstr "git prune [-n] [-v] [--progress] [--expire <tiempo>] [--] [<head>...]"
+#: builtin/read-tree.c:127
+msgid "only empty the index"
+msgstr "solo vaciar el índice"
 
-#: builtin/prune.c:108
-msgid "report pruned objects"
-msgstr "reportar objetos recortados"
+#: builtin/read-tree.c:129
+msgid "Merging"
+msgstr "Fusionando"
 
-#: builtin/prune.c:111
-msgid "expire objects older than <time>"
-msgstr "expirar objetos más viejos a <tiempo>"
+#: builtin/read-tree.c:131
+msgid "perform a merge in addition to a read"
+msgstr "realizar un merge en adición a una lectura"
 
-#: builtin/prune.c:113
-msgid "limit traversal to objects outside promisor packfiles"
-msgstr "limitar el recorrido a objetos fuera de los paquetes del promisor"
+#: builtin/read-tree.c:133
+msgid "3-way merge if no file level merging required"
+msgstr "fusión de 3-vías si no se requiere ninguna fusión a nivel de archivo"
 
-#: builtin/prune.c:127
-msgid "cannot prune in a precious-objects repo"
-msgstr "no se puede recortar en un repositorio de objetos-preciosos"
+#: builtin/read-tree.c:135
+msgid "3-way merge in presence of adds and removes"
+msgstr "fusión en 3-vías en presencia de adiciones y remociones"
 
-#: builtin/pull.c:59 builtin/pull.c:61
-#, c-format
-msgid "Invalid value for %s: %s"
-msgstr "Valor inválido para %s: %s"
+#: builtin/read-tree.c:137
+msgid "same as -m, but discard unmerged entries"
+msgstr "igual que -m, pero descarta entradas sin fusionar"
 
-#: builtin/pull.c:81
-msgid "git pull [<options>] [<repository> [<refspec>...]]"
-msgstr ""
-"git pull [<opciones>] [<repositorio> [<especificación-de-referencia>...]]"
+#: builtin/read-tree.c:138
+msgid "<subdirectory>/"
+msgstr "<subdirectorio>/"
 
-#: builtin/pull.c:132
-msgid "control for recursive fetching of submodules"
-msgstr "control de fetch recursivo en submódulos"
+#: builtin/read-tree.c:139
+msgid "read the tree into the index under <subdirectory>/"
+msgstr "lea el árbol en el índice bajo <subdirectorio>/"
 
-#: builtin/pull.c:136
-msgid "Options related to merging"
-msgstr "Opciones relacionadas a fusión"
+#: builtin/read-tree.c:142
+msgid "update working tree with merge result"
+msgstr "actualiza el árbol de trabajo con el resultado de la fusión"
 
-#: builtin/pull.c:139
-msgid "incorporate changes by rebasing rather than merging"
-msgstr "incorporar cambios por rebase en lugar de fusión"
+#: builtin/read-tree.c:144
+msgid "gitignore"
+msgstr "gitignore"
 
-#: builtin/pull.c:166 builtin/rebase--helper.c:23 builtin/revert.c:121
-msgid "allow fast-forward"
-msgstr "permitir fast-forward"
+#: builtin/read-tree.c:145
+msgid "allow explicitly ignored files to be overwritten"
+msgstr "permitir sobrescritura de archivos explícitamente ignorados"
 
-#: builtin/pull.c:175
-msgid "automatically stash/stash pop before and after rebase"
-msgstr "ejecutar automáticamente stash/stash pop antes y después de rebase"
+#: builtin/read-tree.c:148
+msgid "don't check the working tree after merging"
+msgstr "no revisar el árbol de trabajo tras fusionar"
 
-#: builtin/pull.c:191
-msgid "Options related to fetching"
-msgstr "Opciones relacionadas a fetch"
+#: builtin/read-tree.c:149
+msgid "don't update the index or the work tree"
+msgstr "no actualizar el índice o el árbol de trabajo"
 
-#: builtin/pull.c:209
-msgid "number of submodules pulled in parallel"
-msgstr "número de submódulos que realizan pull en paralelo"
+#: builtin/read-tree.c:151
+msgid "skip applying sparse checkout filter"
+msgstr "saltar aplicado de filtro de sparse checkout"
 
-#: builtin/pull.c:304
-#, c-format
-msgid "Invalid value for pull.ff: %s"
-msgstr "Valor inválido para pull.ff: %s"
+#: builtin/read-tree.c:153
+msgid "debug unpack-trees"
+msgstr "debug de árboles-desempacados"
 
-#: builtin/pull.c:420
-msgid ""
-"There is no candidate for rebasing against among the refs that you just "
-"fetched."
-msgstr "No hay candidato para rebasar entre las refs que has bajado con fetch."
+#: builtin/read-tree.c:157
+msgid "suppress feedback messages"
+msgstr "suprimir mensajes de feedback"
 
-#: builtin/pull.c:422
+#: builtin/read-tree.c:188
+msgid "You need to resolve your current index first"
+msgstr "Necesitas resolver tu índice actual primero"
+
+#: builtin/rebase.c:32
 msgid ""
-"There are no candidates for merging among the refs that you just fetched."
+"git rebase [-i] [options] [--exec <cmd>] [--onto <newbase> | --keep-base] "
+"[<upstream> [<branch>]]"
 msgstr ""
-"No hay candidatos para fusionar entre las refs que has bajado con fetch."
+"git rebase [-i] [opciones] [--exec <cmd>] [--onto <newbase> | --keep-base] "
+"[<upstream> [<branch>]]"
 
-#: builtin/pull.c:423
+#: builtin/rebase.c:34
 msgid ""
-"Generally this means that you provided a wildcard refspec which had no\n"
-"matches on the remote end."
+"git rebase [-i] [options] [--exec <cmd>] [--onto <newbase>] --root [<branch>]"
 msgstr ""
-"Generalmente esto significa que has proveído un wildcard de refspec que no "
-"tiene\n"
-"concordancia en el final remoto."
+"git rebase [-i] [opciones] [--exec <cmd>] [--onto <newbase>] --root[<rama>]"
 
-#: builtin/pull.c:426
+#: builtin/rebase.c:36
+msgid "git rebase --continue | --abort | --skip | --edit-todo"
+msgstr "git rebase --continue | --abort | --skip | --edit-todo"
+
+#: builtin/rebase.c:177 builtin/rebase.c:201 builtin/rebase.c:228
 #, c-format
-msgid ""
-"You asked to pull from the remote '%s', but did not specify\n"
-"a branch. Because this is not the default configured remote\n"
-"for your current branch, you must specify a branch on the command line."
-msgstr ""
-"Se ha solicitado un pull del remoto '%s', pero no se ha especificado\n"
-"una rama. Porque este no es el remoto configurado por default\n"
-"para tu rama actual, tienes que especificar una rama en la línea de comando."
+msgid "unusable todo list: '%s'"
+msgstr "lista de pendientes inutilizable: '%s'"
 
-#: builtin/pull.c:431 git-parse-remote.sh:73
-msgid "You are not currently on a branch."
-msgstr "No te encuentras actualmente en la rama."
+#: builtin/rebase.c:186 builtin/rebase.c:212 builtin/rebase.c:236
+#, c-format
+msgid "could not write '%s'."
+msgstr "no se pudo escribir '%s'."
 
-#: builtin/pull.c:433 builtin/pull.c:448 git-parse-remote.sh:79
-msgid "Please specify which branch you want to rebase against."
-msgstr "Por favor especifica a qué rama quieres rebasar."
+#: builtin/rebase.c:271
+msgid "no HEAD?"
+msgstr "¿Sin HEAD?"
 
-#: builtin/pull.c:435 builtin/pull.c:450 git-parse-remote.sh:82
-msgid "Please specify which branch you want to merge with."
-msgstr "Por favor especifica a qué rama quieres fusionar."
+#: builtin/rebase.c:298
+#, c-format
+msgid "could not create temporary %s"
+msgstr "no se pudo crear archivo temporal %s"
 
-#: builtin/pull.c:436 builtin/pull.c:451
-msgid "See git-pull(1) for details."
-msgstr "Ver git-pull(1) para detalles."
+#: builtin/rebase.c:304
+msgid "could not mark as interactive"
+msgstr "no se pudo marcar como interactivo"
 
-#: builtin/pull.c:438 builtin/pull.c:444 builtin/pull.c:453
-#: git-parse-remote.sh:64
-msgid "<remote>"
-msgstr "<remoto>"
+#: builtin/rebase.c:362
+msgid "could not generate todo list"
+msgstr "no se pudo generar lista de pendientes"
 
-#: builtin/pull.c:438 builtin/pull.c:453 builtin/pull.c:458 git-rebase.sh:523
-#: git-parse-remote.sh:65
-msgid "<branch>"
-msgstr "<rama>"
+#: builtin/rebase.c:402
+msgid "a base commit must be provided with --upstream or --onto"
+msgstr "un commit base tiene que ser provisto con --upstream o --onto"
 
-#: builtin/pull.c:446 git-parse-remote.sh:75
-msgid "There is no tracking information for the current branch."
-msgstr "No hay información de rastreo para la rama actual."
+#: builtin/rebase.c:457
+msgid "git rebase--interactive [<options>]"
+msgstr "git rebase--interactive [<opciones>]"
 
-#: builtin/pull.c:455 git-parse-remote.sh:95
-msgid ""
-"If you wish to set tracking information for this branch you can do so with:"
-msgstr ""
-"Si deseas configurar el rastreo de información para esta rama, puedes "
-"hacerlo con:"
+#: builtin/rebase.c:469
+msgid "keep empty commits"
+msgstr "mantener commits vacíos"
 
-#: builtin/pull.c:460
-#, c-format
-msgid ""
-"Your configuration specifies to merge with the ref '%s'\n"
-"from the remote, but no such ref was fetched."
-msgstr ""
-"Tu configuración especifica fusionar con la ref '%s'\n"
-"de tu remoto, pero no se pudo hacer fetch a esa ref."
+#: builtin/rebase.c:471 builtin/revert.c:128
+msgid "allow commits with empty messages"
+msgstr "permitir commits con mensajes vacíos"
 
-#: builtin/pull.c:826
-msgid "ignoring --verify-signatures for rebase"
-msgstr "ignorando --verify-signatures para rebase"
+#: builtin/rebase.c:472
+msgid "rebase merge commits"
+msgstr "rebasando commits de fusión"
 
-#: builtin/pull.c:874
-msgid "--[no-]autostash option is only valid with --rebase."
-msgstr "La opción --[no-]autostash sólo es válida con --rebase."
+#: builtin/rebase.c:474
+msgid "keep original branch points of cousins"
+msgstr "mantener puntos originales de la rama de sus primos"
 
-#: builtin/pull.c:882
-msgid "Updating an unborn branch with changes added to the index."
-msgstr "Actualizando una rama no nata con cambios agregados al índice."
+#: builtin/rebase.c:476
+msgid "move commits that begin with squash!/fixup!"
+msgstr "mover commits que comienzan con squash!/fixup!"
+
+#: builtin/rebase.c:477
+msgid "sign commits"
+msgstr "firmar commits"
+
+#: builtin/rebase.c:479 builtin/rebase.c:1455
+msgid "display a diffstat of what changed upstream"
+msgstr "mostrar un diffstat de lo que cambió en upstream"
 
-#: builtin/pull.c:885
-msgid "pull with rebase"
-msgstr "pull con rebase"
+#: builtin/rebase.c:481
+msgid "continue rebase"
+msgstr "continuar rebase"
 
-#: builtin/pull.c:886
-msgid "please commit or stash them."
-msgstr "por favor realiza un commit o un stash con ellos."
+#: builtin/rebase.c:483
+msgid "skip commit"
+msgstr "saltar commit"
+
+#: builtin/rebase.c:484
+msgid "edit the todo list"
+msgstr "editar la lista de pendientes"
+
+#: builtin/rebase.c:486
+msgid "show the current patch"
+msgstr "mostrar el parche actual"
 
-#: builtin/pull.c:911
-#, c-format
-msgid ""
-"fetch updated the current branch head.\n"
-"fast-forwarding your working tree from\n"
-"commit %s."
-msgstr ""
-"fetch actualizó el head de la rama actual.\n"
-"realizando fast-forward al árbol de trabajo\n"
-"desde commit %s."
+#: builtin/rebase.c:489
+msgid "shorten commit ids in the todo list"
+msgstr "ids de commits cortos en la lista de pendientes"
+
+#: builtin/rebase.c:491
+msgid "expand commit ids in the todo list"
+msgstr "expandir ids de commits en la lista de pendientes"
+
+#: builtin/rebase.c:493
+msgid "check the todo list"
+msgstr "revisar la lista de pendientes"
+
+#: builtin/rebase.c:495
+msgid "rearrange fixup/squash lines"
+msgstr "reorganizar líneas fixup/squash"
+
+#: builtin/rebase.c:497
+msgid "insert exec commands in todo list"
+msgstr "insertar comando exec en la lista de pendientes"
 
-#: builtin/pull.c:916
+#: builtin/rebase.c:498
+msgid "onto"
+msgstr "hacia"
+
+#: builtin/rebase.c:501
+msgid "restrict-revision"
+msgstr "restrict-revision"
+
+#: builtin/rebase.c:501
+msgid "restrict revision"
+msgstr "restringir revision"
+
+#: builtin/rebase.c:503
+msgid "squash-onto"
+msgstr "squash-onto"
+
+#: builtin/rebase.c:504
+msgid "squash onto"
+msgstr "squash hacia"
+
+#: builtin/rebase.c:506
+msgid "the upstream commit"
+msgstr "el commit de upstream"
+
+#: builtin/rebase.c:508
+msgid "head-name"
+msgstr "head-name"
+
+#: builtin/rebase.c:508
+msgid "head name"
+msgstr "nombre de head"
+
+#: builtin/rebase.c:513
+msgid "rebase strategy"
+msgstr "estrategia de rebase"
+
+#: builtin/rebase.c:514
+msgid "strategy-opts"
+msgstr "strategy-opts"
+
+#: builtin/rebase.c:515
+msgid "strategy options"
+msgstr "opciones de estrategia"
+
+#: builtin/rebase.c:516
+msgid "switch-to"
+msgstr "cambiar a"
+
+#: builtin/rebase.c:517
+msgid "the branch or commit to checkout"
+msgstr "la rama o commit para hacer checkout"
+
+#: builtin/rebase.c:518
+msgid "onto-name"
+msgstr "hacia-nombre"
+
+#: builtin/rebase.c:518
+msgid "onto name"
+msgstr "hacia nombre"
+
+#: builtin/rebase.c:519
+msgid "cmd"
+msgstr "cmd"
+
+#: builtin/rebase.c:519
+msgid "the command to run"
+msgstr "el comando para ejecutar"
+
+#: builtin/rebase.c:522 builtin/rebase.c:1540
+msgid "automatically re-schedule any `exec` that fails"
+msgstr "reprogramar automaticamente cualquier `exec` que falle"
+
+#: builtin/rebase.c:540
+msgid "--[no-]rebase-cousins has no effect without --rebase-merges"
+msgstr "--[no-]rebase-cousins no tiene efecto sin --rebase-merges"
+
+#: builtin/rebase.c:556
 #, c-format
-msgid ""
-"Cannot fast-forward your working tree.\n"
-"After making sure that you saved anything precious from\n"
-"$ git diff %s\n"
-"output, run\n"
-"$ git reset --hard\n"
-"to recover."
-msgstr ""
-"No se puede realizar fast-forward en tu árbol de trabajo.\n"
-"Tras asegurarse que ha guardado todo lo preciado de la salida de\n"
-"$ git diff %s\n"
-",ejecute\n"
-"$ git reset --hard\n"
-"para recuperar."
+msgid "%s requires an interactive rebase"
+msgstr "%s requiere un rebase interactivo"
 
-#: builtin/pull.c:931
-msgid "Cannot merge multiple branches into empty head."
-msgstr "No se puede fusionar múltiples ramas en un head vacío."
+#: builtin/rebase.c:608
+#, c-format
+msgid "could not get 'onto': '%s'"
+msgstr "no se pudo conseguir 'onto': '%s'"
 
-#: builtin/pull.c:935
-msgid "Cannot rebase onto multiple branches."
-msgstr "No se puede rebasar en múltiples ramas."
+#: builtin/rebase.c:623
+#, c-format
+msgid "invalid orig-head: '%s'"
+msgstr "orig-head inválido: '%s'"
 
-#: builtin/pull.c:942
-msgid "cannot rebase with locally recorded submodule modifications"
-msgstr ""
-"no se puede rebasar con modificaciones de submódulos grabadas localmente"
+#: builtin/rebase.c:648
+#, c-format
+msgid "ignoring invalid allow_rerere_autoupdate: '%s'"
+msgstr "ignorando inválido allow_rerere_autoupdate: '%s'"
 
-#: builtin/push.c:19
-msgid "git push [<options>] [<repository> [<refspec>...]]"
-msgstr ""
-"git push [<opciones>] [<repositorio> [<especificaciones-de-referencia>...]]"
+#: builtin/rebase.c:724
+#, c-format
+msgid "Could not read '%s'"
+msgstr "No se pudo leer '%s'"
 
-#: builtin/push.c:111
-msgid "tag shorthand without <tag>"
-msgstr "taquigrafía de tag sin <tag>"
+#: builtin/rebase.c:742
+#, c-format
+msgid "Cannot store %s"
+msgstr "No se puede guardar %s"
 
-#: builtin/push.c:121
-msgid "--delete only accepts plain target ref names"
-msgstr "--delete solo acepta como objetivos nombres de ref planos"
+#: builtin/rebase.c:849
+msgid "could not determine HEAD revision"
+msgstr "no se pudo determinar revisión HEAD"
 
-#: builtin/push.c:165
+#: builtin/rebase.c:972 git-rebase--preserve-merges.sh:81
 msgid ""
-"\n"
-"To choose either option permanently, see push.default in 'git help config'."
+"Resolve all conflicts manually, mark them as resolved with\n"
+"\"git add/rm <conflicted_files>\", then run \"git rebase --continue\".\n"
+"You can instead skip this commit: run \"git rebase --skip\".\n"
+"To abort and get back to the state before \"git rebase\", run \"git rebase --"
+"abort\"."
 msgstr ""
-"\n"
-"Para elegir si la opción es permanente, mira push.default en 'git help "
-"config'."
+"Resuelva todos los conflictos manualmente ya sea con \n"
+"\"git add/rm <archivo_conflictivo>\", luego ejecute \"git rebase --continue"
+"\".\n"
+"Si prefieres saltar este parche, ejecuta \"git rebase --skip\" .\n"
+"Para abortar y regresar al estado previo al \"git rebase\", ejecuta \"git "
+"rebase --abort\"."
 
-#: builtin/push.c:168
+#: builtin/rebase.c:1060
 #, c-format
 msgid ""
-"The upstream branch of your current branch does not match\n"
-"the name of your current branch.  To push to the upstream branch\n"
-"on the remote, use\n"
 "\n"
-"    git push %s HEAD:%s\n"
+"git encountered an error while preparing the patches to replay\n"
+"these revisions:\n"
 "\n"
-"To push to the branch of the same name on the remote, use\n"
+"    %s\n"
 "\n"
-"    git push %s %s\n"
-"%s"
+"As a result, git cannot rebase them."
 msgstr ""
-"La rama upstream de tu rama actual no concuerda\n"
-"con el nombre de tu rama actual. Para hacer un push a la rama upstream\n"
-"en el remoto, ejecuta\n"
 "\n"
-"\tgit push %s HEAD:%s\n"
+"git encontró un error mientras preparaba los parches para replicar\n"
+"esas revisiones:\n"
 "\n"
-"Para hacer un push a la rama del mismo nombre en el remoto, ejecuta\n"
+"    %s\n"
 "\n"
-"\tgit push %s %s\n"
-"%s"
+"Como resultado, git no puede hacer rebase con ellos."
 
-#: builtin/push.c:183
+#: builtin/rebase.c:1367
 #, c-format
 msgid ""
-"You are not currently on a branch.\n"
-"To push the history leading to the current (detached HEAD)\n"
-"state now, use\n"
+"%s\n"
+"Please specify which branch you want to rebase against.\n"
+"See git-rebase(1) for details.\n"
+"\n"
+"    git rebase '<branch>'\n"
 "\n"
-"    git push %s HEAD:<name-of-remote-branch>\n"
 msgstr ""
-"Actualmente no estás en una rama.\n"
-"Para hacer un push a la historia que lleva al estado actual\n"
-"(HEAD desacoplado), use\n"
+"%s\n"
+"Por favor especifica contra qué rama deseas hacer el rebase.\n"
+"Ver git-rebase(1) para detalles.\n"
+"\n"
+"    git rebase '<rama>'\n"
 "\n"
-"\tgit push %s HEAD:<nombre-de-rama-remota>\n"
 
-#: builtin/push.c:197
+#: builtin/rebase.c:1383
 #, c-format
 msgid ""
-"The current branch %s has no upstream branch.\n"
-"To push the current branch and set the remote as upstream, use\n"
+"If you wish to set tracking information for this branch you can do so with:\n"
+"\n"
+"    git branch --set-upstream-to=%s/<branch> %s\n"
 "\n"
-"    git push --set-upstream %s %s\n"
 msgstr ""
-"La rama actual %s no tiene una rama upstream.\n"
-"Para realizar un push de la rama actual y configurar el remoto como "
-"upstream, use\n"
+"Si quieres configurar información de rastreo puedes hacerlo con:\n"
+"\n"
+"    git branch --set-upstream-to=%s/<rama> %s\n"
 "\n"
-"\tgit push --set-upstream %s %s\n"
 
-#: builtin/push.c:205
-#, c-format
-msgid "The current branch %s has multiple upstream branches, refusing to push."
-msgstr "La rama actual %s tiene múltiples ramas upstream, rechazando el push."
+#: builtin/rebase.c:1413
+msgid "exec commands cannot contain newlines"
+msgstr "comandos exec no pueden contener newlines"
 
-#: builtin/push.c:208
-#, c-format
-msgid ""
-"You are pushing to remote '%s', which is not the upstream of\n"
-"your current branch '%s', without telling me what to push\n"
-"to update which remote branch."
-msgstr ""
-"Está haciendo un push al remoto '%s', el cual no es el upstream de\n"
-"su rama actual '%s', sin decirme qué poner en el push\n"
-"para actualizar en qué rama de remoto."
+#: builtin/rebase.c:1417
+msgid "empty exec command"
+msgstr "comando exec vacío"
 
-#: builtin/push.c:267
-msgid ""
-"You didn't specify any refspecs to push, and push.default is \"nothing\"."
-msgstr ""
-"No se especificó ningún refspecs para hacer push, y push.default es \"nada\"."
+#: builtin/rebase.c:1446
+msgid "rebase onto given branch instead of upstream"
+msgstr "haciendo rebase hacia rama dada en lugar de upstream"
 
-#: builtin/push.c:274
-msgid ""
-"Updates were rejected because the tip of your current branch is behind\n"
-"its remote counterpart. Integrate the remote changes (e.g.\n"
-"'git pull ...') before pushing again.\n"
-"See the 'Note about fast-forwards' in 'git push --help' for details."
-msgstr ""
-"Actualizaciones fueron rechazadas porque la punta de tu rama actual esta\n"
-"detrás de su contraparte remota. Integra los cambios remotos (es decir\n"
-"'git pull ...') antes de hacer push de nuevo.\n"
-"Mira 'Note about fast-forwards' en 'git push --help' para mas detalles."
+#: builtin/rebase.c:1448
+msgid "use the merge-base of upstream and branch as the current base"
+msgstr "usar la base de fusión de upstream y la rama como base actual"
 
-#: builtin/push.c:280
-msgid ""
-"Updates were rejected because a pushed branch tip is behind its remote\n"
-"counterpart. Check out this branch and integrate the remote changes\n"
-"(e.g. 'git pull ...') before pushing again.\n"
-"See the 'Note about fast-forwards' in 'git push --help' for details."
-msgstr ""
-"Actualizaciones fueron rechazadas porque una punta de rama en el push está \n"
-"detrás de su contraparte remota. Verifique esta rama e integre los cambios "
-"remotos\n"
-"(ejem. 'git pull ...') antes de volver a hacer push.\n"
-"Vea las 'Notes about fast-forwards' en 'git push --help' para más detalles."
+#: builtin/rebase.c:1450
+msgid "allow pre-rebase hook to run"
+msgstr "permitir ejecutar hook pre-rebase"
 
-#: builtin/push.c:286
-msgid ""
-"Updates were rejected because the remote contains work that you do\n"
-"not have locally. This is usually caused by another repository pushing\n"
-"to the same ref. You may want to first integrate the remote changes\n"
-"(e.g., 'git pull ...') before pushing again.\n"
-"See the 'Note about fast-forwards' in 'git push --help' for details."
-msgstr ""
-"Actualizaciones fueron rechazadas porque el remoto contiene trabajo que\n"
-"no existe localmente. Esto es causado usualmente por otro repositorio \n"
-"realizando push a la misma ref. Quizás quiera integrar primero los cambios\n"
-"remotos (ej. 'git pull ...') antes de volver a hacer push.\n"
-"Vea 'Notes about fast-forwards0 en 'git push --help' para detalles."
+#: builtin/rebase.c:1452
+msgid "be quiet. implies --no-stat"
+msgstr "ser silencioso implica --no-stat"
 
-#: builtin/push.c:293
-msgid "Updates were rejected because the tag already exists in the remote."
-msgstr ""
-"Actualizaciones fueron rechazadas porque el tag ya existe en el remoto."
+#: builtin/rebase.c:1458
+msgid "do not show diffstat of what changed upstream"
+msgstr "no mostrar un diffstat de lo que cambió en upstream"
 
-#: builtin/push.c:296
-msgid ""
-"You cannot update a remote ref that points at a non-commit object,\n"
-"or update a remote ref to make it point at a non-commit object,\n"
-"without using the '--force' option.\n"
-msgstr ""
-"No puede actualizar un ref remoto que apunta a un objeto no-commit,\n"
-"o actualizar un ref remoto para hacer que  apunte a un objeto no-commit,\n"
-"sin usar la opción '--force'.\n"
+#: builtin/rebase.c:1461
+msgid "add a Signed-off-by: line to each commit"
+msgstr "agregar una línea \"Firmado-por\" al mensaje de cada commit"
 
-#: builtin/push.c:357
-#, c-format
-msgid "Pushing to %s\n"
-msgstr "Haciendo push a %s\n"
+#: builtin/rebase.c:1464
+msgid "make committer date match author date"
+msgstr "hacer que la fecha del commit concuerde con la fecha de autoría"
 
-#: builtin/push.c:361
-#, c-format
-msgid "failed to push some refs to '%s'"
-msgstr "falló el push de algunas referencias a '%s'"
+#: builtin/rebase.c:1466
+msgid "ignore author date and use current date"
+msgstr "ignorar la fecha del autor y usar la fecha actual"
 
-#: builtin/push.c:395
-#, c-format
-msgid "bad repository '%s'"
-msgstr "mal repositorio '%s'"
+#: builtin/rebase.c:1468
+msgid "synonym of --reset-author-date"
+msgstr "sinónimo para --reset-author-date"
 
-#: builtin/push.c:396
-msgid ""
-"No configured push destination.\n"
-"Either specify the URL from the command-line or configure a remote "
-"repository using\n"
-"\n"
-"    git remote add <name> <url>\n"
-"\n"
-"and then push using the remote name\n"
-"\n"
-"    git push <name>\n"
-msgstr ""
-"No se ha configurado un destino para el push.\n"
-"Puedes o especificar una URL desde la línea de comandos o configurar un "
-"repositorio remoto usando\n"
-"\n"
-"    git remote add <nombre> <url>\n"
-"\n"
-"y luego haciendo push al nombre del remoto\n"
-"\n"
-"    git push <nombre>\n"
+#: builtin/rebase.c:1470 builtin/rebase.c:1474
+msgid "passed to 'git apply'"
+msgstr "pasado a 'git-apply'"
 
-#: builtin/push.c:551
-msgid "repository"
-msgstr "repositorio"
+#: builtin/rebase.c:1472
+msgid "ignore changes in whitespace"
+msgstr "ignorar cambios en espacios en blanco"
 
-#: builtin/push.c:552 builtin/send-pack.c:164
-msgid "push all refs"
-msgstr "realizar push a todas las refs"
+#: builtin/rebase.c:1476 builtin/rebase.c:1479
+msgid "cherry-pick all commits, even if unchanged"
+msgstr "cherry-pick todos los commits, incluso si no han cambiado"
 
-#: builtin/push.c:553 builtin/send-pack.c:166
-msgid "mirror all refs"
-msgstr "realizar mirror a todas las refs"
+#: builtin/rebase.c:1481
+msgid "continue"
+msgstr "continuar"
 
-#: builtin/push.c:555
-msgid "delete refs"
-msgstr "borrar refs"
+#: builtin/rebase.c:1484
+msgid "skip current patch and continue"
+msgstr "saltar el parche y continuar"
 
-#: builtin/push.c:556
-msgid "push tags (can't be used with --all or --mirror)"
-msgstr "realizar push a tags (no puede ser usado con --all o --mirror)"
+#: builtin/rebase.c:1486
+msgid "abort and check out the original branch"
+msgstr "aborta y revisa la rama original"
 
-#: builtin/push.c:559 builtin/send-pack.c:167
-msgid "force updates"
-msgstr "forzar actualizaciones"
+#: builtin/rebase.c:1489
+msgid "abort but keep HEAD where it is"
+msgstr "aborta pero mantiene HEAD donde está"
 
-#: builtin/push.c:561 builtin/send-pack.c:181
-msgid "refname>:<expect"
-msgstr "refname>:<expect"
+#: builtin/rebase.c:1490
+msgid "edit the todo list during an interactive rebase"
+msgstr "editar la lista de pendientes durante el rebase interactivo"
 
-#: builtin/push.c:562 builtin/send-pack.c:182
-msgid "require old value of ref to be at this value"
-msgstr "requiere haber valor viejo de ref en este valor"
+#: builtin/rebase.c:1493
+msgid "show the patch file being applied or merged"
+msgstr "muestra el archivo parche siendo aplicado o fusionado"
 
-#: builtin/push.c:565
-msgid "control recursive pushing of submodules"
-msgstr "controlar push recursivo de submódulos"
+#: builtin/rebase.c:1496
+msgid "use merging strategies to rebase"
+msgstr "usar estrategias de fusión para el rebase"
 
-#: builtin/push.c:567 builtin/send-pack.c:175
-msgid "use thin pack"
-msgstr "usar empaquetado delgado"
+#: builtin/rebase.c:1500
+msgid "let the user edit the list of commits to rebase"
+msgstr "permitir al usuario editar la lista de commits para rebasar"
 
-#: builtin/push.c:568 builtin/push.c:569 builtin/send-pack.c:161
-#: builtin/send-pack.c:162
-msgid "receive pack program"
-msgstr "recibir programa de paquete"
+#: builtin/rebase.c:1504
+msgid "(DEPRECATED) try to recreate merges instead of ignoring them"
+msgstr "(DEPRECADO) intentar recrear merges en lugar de ignorarlos"
 
-#: builtin/push.c:570
-msgid "set upstream for git pull/status"
-msgstr "configurar upstream para git pulll/status"
+#: builtin/rebase.c:1509
+msgid "preserve empty commits during rebase"
+msgstr "preservar commits vacíos durante el rebase"
 
-#: builtin/push.c:573
-msgid "prune locally removed refs"
-msgstr "recortando refs removidas localmente"
+#: builtin/rebase.c:1511
+msgid "move commits that begin with squash!/fixup! under -i"
+msgstr "mover commits que comienzan con squash!/fixup! bajo -i"
 
-#: builtin/push.c:575
-msgid "bypass pre-push hook"
-msgstr "hacer un bypass al hook pre-push"
+#: builtin/rebase.c:1517
+msgid "automatically stash/stash pop before and after"
+msgstr "ejecutar automáticamente stash/stash pop antes y después"
 
-#: builtin/push.c:576
-msgid "push missing but relevant tags"
-msgstr "realizar push de tags faltantes pero relevantes"
+#: builtin/rebase.c:1519
+msgid "add exec lines after each commit of the editable list"
+msgstr "agregar líneas exec tras cada acommit de la lista editable"
 
-#: builtin/push.c:579 builtin/send-pack.c:169
-msgid "GPG sign the push"
-msgstr "Firmar con GPG el push"
+#: builtin/rebase.c:1523
+msgid "allow rebasing commits with empty messages"
+msgstr "permitir rebase commits con mensajes vacíos"
 
-#: builtin/push.c:581 builtin/send-pack.c:176
-msgid "request atomic transaction on remote side"
-msgstr "solicitar transacción atómica en el lado remoto"
+#: builtin/rebase.c:1526
+msgid "try to rebase merges instead of skipping them"
+msgstr "intentar fusiones por rebase en lugar de saltarlas"
 
-#: builtin/push.c:599
-msgid "--delete is incompatible with --all, --mirror and --tags"
-msgstr "--delete es incompatible con --all, --mirror y --tags"
+#: builtin/rebase.c:1529
+msgid "use 'merge-base --fork-point' to refine upstream"
+msgstr "use 'merge-base --fork-point' para refinar upstream"
 
-#: builtin/push.c:601
-msgid "--delete doesn't make sense without any refs"
-msgstr "--delete no tiene sentido sin ninguna referencia"
+#: builtin/rebase.c:1531
+msgid "use the given merge strategy"
+msgstr "usar la estrategia de merge dada"
 
-#: builtin/push.c:604
-msgid "--all and --tags are incompatible"
-msgstr "--all y --tags son incompatibles"
+#: builtin/rebase.c:1533 builtin/revert.c:115
+msgid "option"
+msgstr "opción"
 
-#: builtin/push.c:606
-msgid "--all can't be combined with refspecs"
-msgstr "--all no puede ser combinada con refspecs"
+#: builtin/rebase.c:1534
+msgid "pass the argument through to the merge strategy"
+msgstr "pasar el argumento para la estrategia de fusión"
 
-#: builtin/push.c:610
-msgid "--mirror and --tags are incompatible"
-msgstr "--mirror y --tags son incompatibles"
+#: builtin/rebase.c:1537
+msgid "rebase all reachable commits up to the root(s)"
+msgstr "hacer rebase a todos los commits alcanzables hasta la raíz(raíces)"
 
-#: builtin/push.c:612
-msgid "--mirror can't be combined with refspecs"
-msgstr "--mirror no puede ser combinado con refspecs"
+#: builtin/rebase.c:1554
+msgid ""
+"the rebase.useBuiltin support has been removed!\n"
+"See its entry in 'git help config' for details."
+msgstr ""
+"el soporte para rebase.useBuiltin ha sido eliminado!\n"
+"Vea su entrada en 'git help config' para detalles."
 
-#: builtin/push.c:615
-msgid "--all and --mirror are incompatible"
-msgstr "--all y --mirror son incompatibles"
+#: builtin/rebase.c:1560
+msgid "It looks like 'git am' is in progress. Cannot rebase."
+msgstr "Parece que 'git am' está en progreso. No se puede rebasar."
 
-#: builtin/push.c:634
-msgid "push options must not have new line characters"
-msgstr "opciones de push no pueden tener caracteres de línea nueva"
+#: builtin/rebase.c:1601
+msgid ""
+"git rebase --preserve-merges is deprecated. Use --rebase-merges instead."
+msgstr ""
+"git rebase --preserve-merges está deprecado. Use --rebase-merges en su lugar."
 
-#: builtin/read-tree.c:40
+#: builtin/rebase.c:1606
+msgid "cannot combine '--keep-base' with '--onto'"
+msgstr "no se puede combinar '--keep-base' con '--onto'"
+
+#: builtin/rebase.c:1608
+msgid "cannot combine '--keep-base' with '--root'"
+msgstr "no se puede combinar '--keep-base' con '--root'"
+
+#: builtin/rebase.c:1612
+msgid "No rebase in progress?"
+msgstr "¿No hay rebase en progreso?"
+
+#: builtin/rebase.c:1616
+msgid "The --edit-todo action can only be used during interactive rebase."
+msgstr ""
+"La acción --edit-todo sólo puede ser usada al rebasar interactivamente."
+
+#: builtin/rebase.c:1639
+msgid "Cannot read HEAD"
+msgstr "No se puede leer el HEAD"
+
+#: builtin/rebase.c:1651
 msgid ""
-"git read-tree [(-m [--trivial] [--aggressive] | --reset | --prefix=<prefix>) "
-"[-u [--exclude-per-directory=<gitignore>] | -i]] [--no-sparse-checkout] [--"
-"index-output=<file>] (--empty | <tree-ish1> [<tree-ish2> [<tree-ish3>]])"
+"You must edit all merge conflicts and then\n"
+"mark them as resolved using git add"
 msgstr ""
-"git read-tree [(-m [--trivial] [--aggressive] | --reset | --"
-"prefix=<prefijo>) [-u [--exclude-per-directory=<gitignore>] | -i]] [--no-"
-"sparse-checkout] [--index-output=<archivo>] (--empty | <árbol-ismo1> [<árbol-"
-"ismo2> [<árbol-ismo3>]])"
+"Tienes que editar todos los conflictos de fusión y luego\n"
+"marcarlos como resueltos usando git add"
 
-#: builtin/read-tree.c:120
-msgid "write resulting index to <file>"
-msgstr "escribir índice resultante en <archivo>"
+#: builtin/rebase.c:1670
+msgid "could not discard worktree changes"
+msgstr "no se pudo descartar los cambios del árbol de trabajo"
 
-#: builtin/read-tree.c:123
-msgid "only empty the index"
-msgstr "solo vaciar el índice"
+#: builtin/rebase.c:1689
+#, c-format
+msgid "could not move back to %s"
+msgstr "no se puede regresar a %s"
 
-#: builtin/read-tree.c:125
-msgid "Merging"
-msgstr "Fusionando"
+#: builtin/rebase.c:1734
+#, c-format
+msgid ""
+"It seems that there is already a %s directory, and\n"
+"I wonder if you are in the middle of another rebase.  If that is the\n"
+"case, please try\n"
+"\t%s\n"
+"If that is not the case, please\n"
+"\t%s\n"
+"and run me again.  I am stopping in case you still have something\n"
+"valuable there.\n"
+msgstr ""
+"Parece que ya hay un directorio %s, y\n"
+"me pregunto si estás en medio de otro rebase. Si ese es el \n"
+"caso, por favor intenta\n"
+"\t%s\n"
+"Si no es el caso, por favor\n"
+"\t%s\n"
+"y ejecútame nuevamente. Me estoy deteniendo en caso de que tengas\n"
+"algo de valor ahí.\n"
+
+#: builtin/rebase.c:1757
+msgid "switch `C' expects a numerical value"
+msgstr "switch `C' espera un valor numérico"
+
+#: builtin/rebase.c:1798
+#, c-format
+msgid "Unknown mode: %s"
+msgstr "Modo desconocido: %s"
+
+#: builtin/rebase.c:1820
+msgid "--strategy requires --merge or --interactive"
+msgstr "--strategy requiere --merge o --interactive"
+
+#: builtin/rebase.c:1860
+msgid "--reschedule-failed-exec requires --exec or --interactive"
+msgstr "--reschedule-failed-exec requiere --exec o --interactive"
+
+#: builtin/rebase.c:1872
+msgid "cannot combine am options with either interactive or merge options"
+msgstr ""
+"no se pueden combinar opciones de am con opciones interactivas o de merge"
 
-#: builtin/read-tree.c:127
-msgid "perform a merge in addition to a read"
-msgstr "realizar un merge en adición a una lectura"
+#: builtin/rebase.c:1891
+msgid "cannot combine '--preserve-merges' with '--rebase-merges'"
+msgstr "no se puede combinar '--preserve-merges' con '--rebase-merges'"
 
-#: builtin/read-tree.c:129
-msgid "3-way merge if no file level merging required"
-msgstr "fusión de 3-vías si no se requiere ninguna fusión a nivel de archivo"
+#: builtin/rebase.c:1895
+msgid ""
+"error: cannot combine '--preserve-merges' with '--reschedule-failed-exec'"
+msgstr ""
+"error: no se puede combinar '--preserve-merges' con '--reschedule-failed-"
+"exec'"
 
-#: builtin/read-tree.c:131
-msgid "3-way merge in presence of adds and removes"
-msgstr "fusión en 3-vías en presencia de adiciones y remociones"
+#: builtin/rebase.c:1919
+#, c-format
+msgid "invalid upstream '%s'"
+msgstr "upstream inválido '%s'"
 
-#: builtin/read-tree.c:133
-msgid "same as -m, but discard unmerged entries"
-msgstr "igual que -m, pero descarta entradas sin fusionar"
+#: builtin/rebase.c:1925
+msgid "Could not create new root commit"
+msgstr "No se pudo crear commit raíz nuevo"
 
-#: builtin/read-tree.c:134
-msgid "<subdirectory>/"
-msgstr "<subdirectorio>/"
+#: builtin/rebase.c:1951
+#, c-format
+msgid "'%s': need exactly one merge base with branch"
+msgstr "'%s': necesita exactamente una base de fusión con rama"
 
-#: builtin/read-tree.c:135
-msgid "read the tree into the index under <subdirectory>/"
-msgstr "lea el árbol en el índice bajo <subdirectorio>/"
+#: builtin/rebase.c:1954
+#, c-format
+msgid "'%s': need exactly one merge base"
+msgstr "'%s': necesita exactamente una base de fusión"
 
-#: builtin/read-tree.c:138
-msgid "update working tree with merge result"
-msgstr "actualiza el árbol de trabajo con el resultado de la fusión"
+#: builtin/rebase.c:1962
+#, c-format
+msgid "Does not point to a valid commit '%s'"
+msgstr "No apunta a un commit válido '%s'"
 
-#: builtin/read-tree.c:140
-msgid "gitignore"
-msgstr "gitignore"
+#: builtin/rebase.c:1987
+#, c-format
+msgid "fatal: no such branch/commit '%s'"
+msgstr "fatal: no existe la rama/commit: '%s'"
 
-#: builtin/read-tree.c:141
-msgid "allow explicitly ignored files to be overwritten"
-msgstr "permitir sobrescritura de archivos explícitamente ignorados"
+#: builtin/rebase.c:1995 builtin/submodule--helper.c:40
+#: builtin/submodule--helper.c:1961
+#, c-format
+msgid "No such ref: %s"
+msgstr "No existe ref: %s"
 
-#: builtin/read-tree.c:144
-msgid "don't check the working tree after merging"
-msgstr "no revisar el árbol de trabajo tras fusionar"
+#: builtin/rebase.c:2006
+msgid "Could not resolve HEAD to a revision"
+msgstr "No se pudo resolver HEAD a una revisión"
 
-#: builtin/read-tree.c:145
-msgid "don't update the index or the work tree"
-msgstr "no actualizar el índice o el árbol de trabajo"
+#: builtin/rebase.c:2044
+msgid "Cannot autostash"
+msgstr "No se puede ejecutar autostash"
 
-#: builtin/read-tree.c:147
-msgid "skip applying sparse checkout filter"
-msgstr "saltar aplicado de filtro de sparse checkout"
+#: builtin/rebase.c:2047
+#, c-format
+msgid "Unexpected stash response: '%s'"
+msgstr "Respuesta de stash inesperada: '%s'"
 
-#: builtin/read-tree.c:149
-msgid "debug unpack-trees"
-msgstr "debug de árboles-desempacados"
+#: builtin/rebase.c:2053
+#, c-format
+msgid "Could not create directory for '%s'"
+msgstr "No se pudo crear el directorio para '%s'"
 
-#: builtin/rebase--helper.c:8
-msgid "git rebase--helper [<options>]"
-msgstr "git rebase--helper [<opciones>]"
+#: builtin/rebase.c:2056
+#, c-format
+msgid "Created autostash: %s\n"
+msgstr "Autostash creado: %s\n"
 
-#: builtin/rebase--helper.c:24
-msgid "keep empty commits"
-msgstr "mantener commits vacíos"
+#: builtin/rebase.c:2059
+msgid "could not reset --hard"
+msgstr "no se pudo reset --hard"
 
-#: builtin/rebase--helper.c:26 builtin/revert.c:123
-msgid "allow commits with empty messages"
-msgstr "permitir commits con mensajes vacíos"
+#: builtin/rebase.c:2068
+msgid "Please commit or stash them."
+msgstr "Por favor, confírmalos o guárdalos."
 
-#: builtin/rebase--helper.c:27
-msgid "rebase merge commits"
-msgstr "rebasando commits de fusión"
+#: builtin/rebase.c:2095
+#, c-format
+msgid "could not parse '%s'"
+msgstr "no se puede analizar '%s'"
 
-#: builtin/rebase--helper.c:29
-msgid "keep original branch points of cousins"
-msgstr "mantener puntos originales de la rama de sus primos"
+#: builtin/rebase.c:2108
+#, c-format
+msgid "could not switch to %s"
+msgstr "no se pudo cambiar a %s"
 
-#: builtin/rebase--helper.c:30
-msgid "continue rebase"
-msgstr "continuar rebase"
+#: builtin/rebase.c:2119
+msgid "HEAD is up to date."
+msgstr "HEAD está actualizado."
 
-#: builtin/rebase--helper.c:32
-msgid "abort rebase"
-msgstr "abortar rebase"
-
-#: builtin/rebase--helper.c:35
-msgid "make rebase script"
-msgstr "generar script de rebase"
+#: builtin/rebase.c:2121
+#, c-format
+msgid "Current branch %s is up to date.\n"
+msgstr "La rama actual %s está actualizada.\n"
 
-#: builtin/rebase--helper.c:37
-msgid "shorten commit ids in the todo list"
-msgstr "ids de commits cortos en la lista de pendientes"
+#: builtin/rebase.c:2129
+msgid "HEAD is up to date, rebase forced."
+msgstr "HEAD está actualizado, rebase forzado."
 
-#: builtin/rebase--helper.c:39
-msgid "expand commit ids in the todo list"
-msgstr "expandir ids de commits en la lista de pendientes"
+#: builtin/rebase.c:2131
+#, c-format
+msgid "Current branch %s is up to date, rebase forced.\n"
+msgstr "Rama actual %s está actualizada, rebase forzado.\n"
 
-#: builtin/rebase--helper.c:41
-msgid "check the todo list"
-msgstr "revisar la lista de pendientes"
+#: builtin/rebase.c:2139
+msgid "The pre-rebase hook refused to rebase."
+msgstr "El hook pre-rebase rechazó el rebase."
 
-#: builtin/rebase--helper.c:43
-msgid "skip unnecessary picks"
-msgstr "saltar los picks innecesarios"
+#: builtin/rebase.c:2146
+#, c-format
+msgid "Changes to %s:\n"
+msgstr "Cambios a %s:\n"
 
-#: builtin/rebase--helper.c:45
-msgid "rearrange fixup/squash lines"
-msgstr "reorganizar líneas fixup/squash"
+#: builtin/rebase.c:2149
+#, c-format
+msgid "Changes from %s to %s:\n"
+msgstr "Cambios desde %s a %s:\n"
 
-#: builtin/rebase--helper.c:47
-msgid "insert exec commands in todo list"
-msgstr "insertar comando exec en la lista de pendientes"
+#: builtin/rebase.c:2174
+#, c-format
+msgid "First, rewinding head to replay your work on top of it...\n"
+msgstr ""
+"En primer lugar, rebobinando HEAD para después reproducir tus cambios encima "
+"de ésta...\n"
 
-#: builtin/rebase--helper.c:68
-msgid "--[no-]rebase-cousins has no effect without --rebase-merges"
-msgstr "--[no-]rebase-cousins no tiene efecto sin --rebase-merges"
+#: builtin/rebase.c:2183
+msgid "Could not detach HEAD"
+msgstr "No se puede desacoplar HEAD"
+
+#: builtin/rebase.c:2192
+#, c-format
+msgid "Fast-forwarded %s to %s.\n"
+msgstr "Avance rápido de %s a %s.\n"
 
-#: builtin/receive-pack.c:31
+#: builtin/receive-pack.c:32
 msgid "git receive-pack <git-dir>"
 msgstr "git receive-pack <git-dir>"
 
-#: builtin/receive-pack.c:842
+#: builtin/receive-pack.c:830
 msgid ""
 "By default, updating the current branch in a non-bare repository\n"
 "is denied, because it will make the index and work tree inconsistent\n"
@@ -12815,17 +18378,17 @@ msgstr ""
 "arreglar\n"
 "el árbol de trabajo con HEAD.\n"
 "\n"
-"Puede configurar la variable de configuración 'receive.denyCurrentBranch'\n"
+"Puedes configurar la variable de configuración 'receive.denyCurrentBranch'\n"
 "\"ignore\" o \"warn\" en el repositorio remoto para permitir\n"
-"su rama actual; Sin embargo, esto no se recomienda a menos que usted\n"
-"se haya organizado para actualizar su árbol de trabajo para que coincida con "
-"lo que\n"
-"enviará con el push de otra manera.\n"
+"su rama actual; Sin embargo, esto no se recomienda a menos que tú\n"
+"te hayas organizado para actualizar su árbol de trabajo para que coincida "
+"con lo que\n"
+"enviarás con el push de otra manera.\n"
 "\n"
 "Para suprimir este mensaje y mantener el comportamiento predeterminado,\n"
-"configure 'receive.denyCurrentBranch' a 'refuse'."
+"configura 'receive.denyCurrentBranch' a 'refuse'."
 
-#: builtin/receive-pack.c:862
+#: builtin/receive-pack.c:850
 msgid ""
 "By default, deleting the current branch is denied, because the next\n"
 "'git clone' won't result in any file checked out, causing confusion.\n"
@@ -12844,26 +18407,81 @@ msgstr ""
 "en el repositorio remoto para permitir borrar la rama actual.\n"
 "con o sin mensaje de advertencia.\n"
 "\n"
-"Para suprimir este mensaje, puede configurarlo en 'refuse'."
+"Para suprimir este mensaje, puedes configurarlo en 'refuse'."
 
-#: builtin/receive-pack.c:1935
+#: builtin/receive-pack.c:1936
 msgid "quiet"
 msgstr "tranquilo"
 
-#: builtin/receive-pack.c:1949
+#: builtin/receive-pack.c:1950
 msgid "You must specify a directory."
 msgstr "Se tiene que especificar un directorio."
 
-#: builtin/reflog.c:532 builtin/reflog.c:537
+#: builtin/reflog.c:17
+msgid ""
+"git reflog expire [--expire=<time>] [--expire-unreachable=<time>] [--"
+"rewrite] [--updateref] [--stale-fix] [--dry-run | -n] [--verbose] [--all] "
+"<refs>..."
+msgstr ""
+"git reflog expire [--expire=<tiempo>] [--expire-unreachable=<tiempo>] [--"
+"rewrite] [--updateref] [--stale-fix] [--dry-run | -n] [--verbose] [--all] "
+"<refs>..."
+
+#: builtin/reflog.c:22
+msgid ""
+"git reflog delete [--rewrite] [--updateref] [--dry-run | -n] [--verbose] "
+"<refs>..."
+msgstr ""
+"git reflog delete [--rewrite] [--updateref] [--dry-run | -n] [--verbose] "
+"<refs>..."
+
+#: builtin/reflog.c:25
+msgid "git reflog exists <ref>"
+msgstr "git reflog existe <ref>"
+
+#: builtin/reflog.c:567 builtin/reflog.c:572
 #, c-format
 msgid "'%s' is not a valid timestamp"
 msgstr "'%s' no es una marca de tiempo válida"
 
-#: builtin/remote.c:14
+#: builtin/reflog.c:605
+#, c-format
+msgid "Marking reachable objects..."
+msgstr "Marcando objectos alcanzables..."
+
+#: builtin/reflog.c:643
+#, c-format
+msgid "%s points nowhere!"
+msgstr "¡%s apunta a ningún lado!"
+
+#: builtin/reflog.c:695
+msgid "no reflog specified to delete"
+msgstr "no reflog especificado para borrar"
+
+#: builtin/reflog.c:704
+#, c-format
+msgid "not a reflog: %s"
+msgstr "no es una reflog: %s"
+
+#: builtin/reflog.c:709
+#, c-format
+msgid "no reflog for '%s'"
+msgstr "no reflog para '%s'"
+
+#: builtin/reflog.c:755
+#, c-format
+msgid "invalid ref format: %s"
+msgstr "formato inválido: %s"
+
+#: builtin/reflog.c:764
+msgid "git reflog [ show | expire | delete | exists ]"
+msgstr "git reflog [ show | expire | delete | exists ]"
+
+#: builtin/remote.c:16
 msgid "git remote [-v | --verbose]"
 msgstr "git remote [-v | --verbose]"
 
-#: builtin/remote.c:15
+#: builtin/remote.c:17
 msgid ""
 "git remote add [-t <branch>] [-m <master>] [-f] [--tags | --no-tags] [--"
 "mirror=<fetch|push>] <name> <url>"
@@ -12871,82 +18489,82 @@ msgstr ""
 "git remote add [-t <rama>] [-m <master>] [-f] [--tags | --no-tags] [--"
 "mirror=<fetch|push>] <nombre> <url>"
 
-#: builtin/remote.c:16 builtin/remote.c:36
+#: builtin/remote.c:18 builtin/remote.c:38
 msgid "git remote rename <old> <new>"
 msgstr "git remote rename <viejo> <nuevo>"
 
-#: builtin/remote.c:17 builtin/remote.c:41
+#: builtin/remote.c:19 builtin/remote.c:43
 msgid "git remote remove <name>"
 msgstr "git remote remove <nombre>"
 
-#: builtin/remote.c:18 builtin/remote.c:46
+#: builtin/remote.c:20 builtin/remote.c:48
 msgid "git remote set-head <name> (-a | --auto | -d | --delete | <branch>)"
 msgstr "git remote set-head <nombre> (-a | --auto | -d | --delete | <rama>)"
 
-#: builtin/remote.c:19
+#: builtin/remote.c:21
 msgid "git remote [-v | --verbose] show [-n] <name>"
 msgstr "git remote [-v | --verbose] show [-n] <nombre>"
 
-#: builtin/remote.c:20
+#: builtin/remote.c:22
 msgid "git remote prune [-n | --dry-run] <name>"
 msgstr "git remote prune [-n | --dry-run] <nombre>"
 
-#: builtin/remote.c:21
+#: builtin/remote.c:23
 msgid ""
 "git remote [-v | --verbose] update [-p | --prune] [(<group> | <remote>)...]"
 msgstr ""
 "git remote [-v | --verbose] update [-p | --prune] [(<grupo> | <remoto>)...]"
 
-#: builtin/remote.c:22
+#: builtin/remote.c:24
 msgid "git remote set-branches [--add] <name> <branch>..."
 msgstr "git remote set-branches [--add] <nombre> <rama>..."
 
-#: builtin/remote.c:23 builtin/remote.c:72
+#: builtin/remote.c:25 builtin/remote.c:74
 msgid "git remote get-url [--push] [--all] <name>"
 msgstr "git remote get-url [--push] [--all] <nombre>"
 
-#: builtin/remote.c:24 builtin/remote.c:77
+#: builtin/remote.c:26 builtin/remote.c:79
 msgid "git remote set-url [--push] <name> <newurl> [<oldurl>]"
 msgstr "git remote set-url [--push] <nombre> <nuevo-url> [<viejo-url>]"
 
-#: builtin/remote.c:25 builtin/remote.c:78
+#: builtin/remote.c:27 builtin/remote.c:80
 msgid "git remote set-url --add <name> <newurl>"
 msgstr "git remote set-url --add <nombre> <nuevo-url>"
 
-#: builtin/remote.c:26 builtin/remote.c:79
+#: builtin/remote.c:28 builtin/remote.c:81
 msgid "git remote set-url --delete <name> <url>"
 msgstr "git remote set-url --delete <nombre> <url>"
 
-#: builtin/remote.c:31
+#: builtin/remote.c:33
 msgid "git remote add [<options>] <name> <url>"
 msgstr "git remote add [<opciones>] <nombre> <url>"
 
-#: builtin/remote.c:51
+#: builtin/remote.c:53
 msgid "git remote set-branches <name> <branch>..."
 msgstr "git remote set-branches <nombre> <rama>..."
 
-#: builtin/remote.c:52
+#: builtin/remote.c:54
 msgid "git remote set-branches --add <name> <branch>..."
 msgstr "git remote set-branches --add <nombre> <rama>..."
 
-#: builtin/remote.c:57
+#: builtin/remote.c:59
 msgid "git remote show [<options>] <name>"
 msgstr "git remote show [<opciones>] <nombre>"
 
-#: builtin/remote.c:62
+#: builtin/remote.c:64
 msgid "git remote prune [<options>] <name>"
 msgstr "git remote prune [<opciones>] <nombre>"
 
-#: builtin/remote.c:67
+#: builtin/remote.c:69
 msgid "git remote update [<options>] [<group> | <remote>]..."
 msgstr "git remote update [<opciones>] [<grupo> | <remoto>]..."
 
-#: builtin/remote.c:96
+#: builtin/remote.c:98
 #, c-format
 msgid "Updating %s"
 msgstr "Actualizando %s"
 
-#: builtin/remote.c:128
+#: builtin/remote.c:130
 msgid ""
 "--mirror is dangerous and deprecated; please\n"
 "\t use --mirror=fetch or --mirror=push instead"
@@ -12954,88 +18572,84 @@ msgstr ""
 "Usar --mirror es peligroso y está desaprobado;\n"
 "\t usa más bien --mirror=fetch o --mirror=push"
 
-#: builtin/remote.c:145
+#: builtin/remote.c:147
 #, c-format
 msgid "unknown mirror argument: %s"
 msgstr "argumento mirror desconocido: %s"
 
-#: builtin/remote.c:161
+#: builtin/remote.c:163
 msgid "fetch the remote branches"
 msgstr "realizar fetch a las ramas remotas"
 
-#: builtin/remote.c:163
+#: builtin/remote.c:165
 msgid "import all tags and associated objects when fetching"
 msgstr "importar todos los tags y objetos asociados cuando realiza el fetch"
 
-#: builtin/remote.c:166
+#: builtin/remote.c:168
 msgid "or do not fetch any tag at all (--no-tags)"
 msgstr "o no realziar fetch a ningún tag (--no-tags)"
 
-#: builtin/remote.c:168
+#: builtin/remote.c:170
 msgid "branch(es) to track"
 msgstr "rama(s) para rastrear"
 
-#: builtin/remote.c:169
+#: builtin/remote.c:171
 msgid "master branch"
 msgstr "rama master"
 
-#: builtin/remote.c:170
-msgid "push|fetch"
-msgstr "push|fetch"
-
-#: builtin/remote.c:171
+#: builtin/remote.c:173
 msgid "set up remote as a mirror to push to or fetch from"
 msgstr ""
 "configurar remote como mirror para realizar push o desde el cual realizar "
 "fetch"
 
-#: builtin/remote.c:183
+#: builtin/remote.c:185
 msgid "specifying a master branch makes no sense with --mirror"
 msgstr "especificar una rama master no tiene sentido con --mirror"
 
-#: builtin/remote.c:185
+#: builtin/remote.c:187
 msgid "specifying branches to track makes sense only with fetch mirrors"
 msgstr "especificar ramas para rastrear solo tiene sentido con fetch mirrors"
 
-#: builtin/remote.c:192 builtin/remote.c:634
+#: builtin/remote.c:194 builtin/remote.c:636
 #, c-format
 msgid "remote %s already exists."
 msgstr "remoto %s ya existe."
 
-#: builtin/remote.c:196 builtin/remote.c:638
+#: builtin/remote.c:198 builtin/remote.c:640
 #, c-format
 msgid "'%s' is not a valid remote name"
 msgstr "'%s' no es un nombre remoto válido"
 
-#: builtin/remote.c:236
+#: builtin/remote.c:238
 #, c-format
 msgid "Could not setup master '%s'"
 msgstr "No se pudo configurar master '%s'"
 
-#: builtin/remote.c:342
+#: builtin/remote.c:344
 #, c-format
 msgid "Could not get fetch map for refspec %s"
 msgstr "No se pudo realizar el fetch al mapa para refspec %s"
 
-#: builtin/remote.c:441 builtin/remote.c:449
+#: builtin/remote.c:443 builtin/remote.c:451
 msgid "(matching)"
 msgstr "(concordando)"
 
-#: builtin/remote.c:453
+#: builtin/remote.c:455
 msgid "(delete)"
 msgstr "(eliminar)"
 
-#: builtin/remote.c:627 builtin/remote.c:762 builtin/remote.c:861
+#: builtin/remote.c:629 builtin/remote.c:764 builtin/remote.c:863
 #, c-format
-msgid "No such remote: %s"
-msgstr "No existe el remoto: %s"
+msgid "No such remote: '%s'"
+msgstr "No existe el remoto '%s'"
 
-#: builtin/remote.c:644
+#: builtin/remote.c:646
 #, c-format
 msgid "Could not rename config section '%s' to '%s'"
 msgstr "No se pudo renombrar la sección de configuración '%s' a '%s'"
 
-#: builtin/remote.c:664
+#: builtin/remote.c:666
 #, c-format
 msgid ""
 "Not updating non-default fetch refspec\n"
@@ -13046,17 +18660,17 @@ msgstr ""
 "\t%s\n"
 "\tPor favor actualice la configuración manualmente si es necesario."
 
-#: builtin/remote.c:700
+#: builtin/remote.c:701
 #, c-format
 msgid "deleting '%s' failed"
 msgstr "borrando '%s' falló"
 
-#: builtin/remote.c:734
+#: builtin/remote.c:735
 #, c-format
 msgid "creating '%s' failed"
 msgstr "creando '%s' falló"
 
-#: builtin/remote.c:799
+#: builtin/remote.c:801
 msgid ""
 "Note: A branch outside the refs/remotes/ hierarchy was not removed;\n"
 "to delete it, use:"
@@ -13064,125 +18678,125 @@ msgid_plural ""
 "Note: Some branches outside the refs/remotes/ hierarchy were not removed;\n"
 "to delete them, use:"
 msgstr[0] ""
-"Nota: Una rama fuera de la jerarquía refs/remotes/ no fue removida;\n"
+"Nota: Una rama fuera de la jerarquía refs/remotes/ no fue eliminada;\n"
 "para borrarla, use:"
 msgstr[1] ""
 "Nota: Algunas ramas fuera de la jerarquía refs/remotes/ no fueron "
-"removidas;\n"
+"eliminadas;\n"
 "para borrarlas, use:"
 
-#: builtin/remote.c:813
+#: builtin/remote.c:815
 #, c-format
 msgid "Could not remove config section '%s'"
 msgstr "No se pudo borrar la sección de configuración '%s'"
 
-#: builtin/remote.c:914
+#: builtin/remote.c:916
 #, c-format
 msgid " new (next fetch will store in remotes/%s)"
 msgstr " nuevo (siguiente fetch se guardará en remotes/%s)"
 
-#: builtin/remote.c:917
+#: builtin/remote.c:919
 msgid " tracked"
 msgstr " rastreada"
 
-#: builtin/remote.c:919
+#: builtin/remote.c:921
 msgid " stale (use 'git remote prune' to remove)"
-msgstr " viejo ( use 'git remote prune' para remover)"
+msgstr " viejo ( use 'git remote prune' para eliminar)"
 
-#: builtin/remote.c:921
+#: builtin/remote.c:923
 msgid " ???"
 msgstr " ???"
 
-#: builtin/remote.c:962
+#: builtin/remote.c:964
 #, c-format
 msgid "invalid branch.%s.merge; cannot rebase onto > 1 branch"
-msgstr "invalido branch.%s.merge; no se puede rebasar en > 1 rama"
+msgstr "inválido branch.%s.merge; no se puede rebasar en > 1 rama"
 
-#: builtin/remote.c:971
+#: builtin/remote.c:973
 #, c-format
 msgid "rebases interactively onto remote %s"
 msgstr "rebasa interactivamente en remoto %s"
 
-#: builtin/remote.c:973
+#: builtin/remote.c:975
 #, c-format
 msgid "rebases interactively (with merges) onto remote %s"
 msgstr "rebasa interactivamente (con fusiones) en remoto %s"
 
-#: builtin/remote.c:976
+#: builtin/remote.c:978
 #, c-format
 msgid "rebases onto remote %s"
 msgstr "rebasa sobre el remoto %s"
 
-#: builtin/remote.c:980
+#: builtin/remote.c:982
 #, c-format
 msgid " merges with remote %s"
 msgstr " se fusiona con remoto %s"
 
-#: builtin/remote.c:983
+#: builtin/remote.c:985
 #, c-format
 msgid "merges with remote %s"
 msgstr "fusiona con remoto %s"
 
-#: builtin/remote.c:986
+#: builtin/remote.c:988
 #, c-format
 msgid "%-*s    and with remote %s\n"
 msgstr "%-*s y con el remoto %s\n"
 
-#: builtin/remote.c:1029
+#: builtin/remote.c:1031
 msgid "create"
 msgstr "crear"
 
-#: builtin/remote.c:1032
+#: builtin/remote.c:1034
 msgid "delete"
 msgstr "borrar"
 
-#: builtin/remote.c:1036
+#: builtin/remote.c:1038
 msgid "up to date"
 msgstr "actualizado"
 
-#: builtin/remote.c:1039
+#: builtin/remote.c:1041
 msgid "fast-forwardable"
 msgstr "puede realizar fast-forward"
 
-#: builtin/remote.c:1042
+#: builtin/remote.c:1044
 msgid "local out of date"
 msgstr "desactualizado local"
 
-#: builtin/remote.c:1049
+#: builtin/remote.c:1051
 #, c-format
 msgid "    %-*s forces to %-*s (%s)"
 msgstr "    %-*s fuerza a %-*s (%s)"
 
-#: builtin/remote.c:1052
+#: builtin/remote.c:1054
 #, c-format
 msgid "    %-*s pushes to %-*s (%s)"
 msgstr "    %-*s publica a %-*s (%s)"
 
-#: builtin/remote.c:1056
+#: builtin/remote.c:1058
 #, c-format
 msgid "    %-*s forces to %s"
 msgstr "    %-*s fuerza a %s"
 
-#: builtin/remote.c:1059
+#: builtin/remote.c:1061
 #, c-format
 msgid "    %-*s pushes to %s"
 msgstr "    %-*s publica a %s"
 
-#: builtin/remote.c:1127
+#: builtin/remote.c:1129
 msgid "do not query remotes"
 msgstr "no consultar remotos"
 
-#: builtin/remote.c:1154
+#: builtin/remote.c:1156
 #, c-format
 msgid "* remote %s"
 msgstr "* remoto %s"
 
-#: builtin/remote.c:1155
+#: builtin/remote.c:1157
 #, c-format
 msgid "  Fetch URL: %s"
 msgstr "  URL  para obtener: %s"
 
-#: builtin/remote.c:1156 builtin/remote.c:1172 builtin/remote.c:1311
+#: builtin/remote.c:1158 builtin/remote.c:1174 builtin/remote.c:1313
 msgid "(no URL)"
 msgstr "(sin URL)"
 
@@ -13190,194 +18804,185 @@ msgstr "(sin URL)"
 #. with the one in " Fetch URL: %s"
 #. translation.
 #.
-#: builtin/remote.c:1170 builtin/remote.c:1172
+#: builtin/remote.c:1172 builtin/remote.c:1174
 #, c-format
 msgid "  Push  URL: %s"
 msgstr "  URL para publicar: %s"
 
-#: builtin/remote.c:1174 builtin/remote.c:1176 builtin/remote.c:1178
+#: builtin/remote.c:1176 builtin/remote.c:1178 builtin/remote.c:1180
 #, c-format
 msgid "  HEAD branch: %s"
 msgstr "  Rama HEAD: %s"
 
-#: builtin/remote.c:1174
+#: builtin/remote.c:1176
 msgid "(not queried)"
 msgstr "(no consultado)"
 
-#: builtin/remote.c:1176
+#: builtin/remote.c:1178
 msgid "(unknown)"
 msgstr "(desconocido)"
 
-#: builtin/remote.c:1180
+#: builtin/remote.c:1182
 #, c-format
 msgid ""
 "  HEAD branch (remote HEAD is ambiguous, may be one of the following):\n"
 msgstr ""
 "  HEAD en rama ( HEAD remoto es ambiguo, puede ser uno de los siguientes):\n"
 
-#: builtin/remote.c:1192
+#: builtin/remote.c:1194
 #, c-format
 msgid "  Remote branch:%s"
 msgid_plural "  Remote branches:%s"
 msgstr[0] "  Rama remota:%s"
 msgstr[1] "  Ramas remotas:%s"
 
-#: builtin/remote.c:1195 builtin/remote.c:1221
+#: builtin/remote.c:1197 builtin/remote.c:1223
 msgid " (status not queried)"
 msgstr " (estado no consultado)"
 
-#: builtin/remote.c:1204
+#: builtin/remote.c:1206
 msgid "  Local branch configured for 'git pull':"
 msgid_plural "  Local branches configured for 'git pull':"
 msgstr[0] "  Rama local configurada para 'git pull':"
 msgstr[1] "  Ramas locales configuradas para 'git pull':"
 
-#: builtin/remote.c:1212
+#: builtin/remote.c:1214
 msgid "  Local refs will be mirrored by 'git push'"
 msgstr "  Las referencias locales serán reflejadas por 'git push'"
 
-#: builtin/remote.c:1218
+#: builtin/remote.c:1220
 #, c-format
 msgid "  Local ref configured for 'git push'%s:"
 msgid_plural "  Local refs configured for 'git push'%s:"
 msgstr[0] "  Referencia local configurada para 'git push'%s:"
 msgstr[1] "  Referencias locales configuradas para 'git push'%s:"
 
-#: builtin/remote.c:1239
+#: builtin/remote.c:1241
 msgid "set refs/remotes/<name>/HEAD according to remote"
 msgstr "configurar refs/remotes/<nombre>/HEAD de acuerdo al remoto"
 
-#: builtin/remote.c:1241
+#: builtin/remote.c:1243
 msgid "delete refs/remotes/<name>/HEAD"
 msgstr "borrar refs/remotos/<nombre>/HEAD"
 
-#: builtin/remote.c:1256
+#: builtin/remote.c:1258
 msgid "Cannot determine remote HEAD"
 msgstr "No se puede determinar el HEAD remoto"
 
-#: builtin/remote.c:1258
+#: builtin/remote.c:1260
 msgid "Multiple remote HEAD branches. Please choose one explicitly with:"
 msgstr "Múltiples ramas HEAD remotas. Por favor escoja una explícitamente con:"
 
-#: builtin/remote.c:1268
+#: builtin/remote.c:1270
 #, c-format
 msgid "Could not delete %s"
 msgstr "No se pudo borrar %s"
 
-#: builtin/remote.c:1276
+#: builtin/remote.c:1278
 #, c-format
 msgid "Not a valid ref: %s"
 msgstr "No es un ref válido: %s"
 
-#: builtin/remote.c:1278
+#: builtin/remote.c:1280
 #, c-format
 msgid "Could not setup %s"
 msgstr "No se pudo configurar %s"
 
-#: builtin/remote.c:1296
+#: builtin/remote.c:1298
 #, c-format
 msgid " %s will become dangling!"
-msgstr " %s será colgado!"
+msgstr " ¡%s será colgado!"
 
-#: builtin/remote.c:1297
+#: builtin/remote.c:1299
 #, c-format
 msgid " %s has become dangling!"
-msgstr " %s ha sido colgado!"
+msgstr " ¡%s ha sido colgado!"
 
-#: builtin/remote.c:1307
+#: builtin/remote.c:1309
 #, c-format
 msgid "Pruning %s"
 msgstr "Recortando %s"
 
-#: builtin/remote.c:1308
+#: builtin/remote.c:1310
 #, c-format
 msgid "URL: %s"
 msgstr "URL: %s"
 
-#: builtin/remote.c:1324
+#: builtin/remote.c:1326
 #, c-format
 msgid " * [would prune] %s"
 msgstr " * [ejecutará prune] %s"
 
-#: builtin/remote.c:1327
+#: builtin/remote.c:1329
 #, c-format
 msgid " * [pruned] %s"
 msgstr " * [prune realizado] %s"
 
-#: builtin/remote.c:1372
+#: builtin/remote.c:1374
 msgid "prune remotes after fetching"
 msgstr "recortar remotos tras realizar fetch"
 
-#: builtin/remote.c:1435 builtin/remote.c:1489 builtin/remote.c:1557
+#: builtin/remote.c:1437 builtin/remote.c:1491 builtin/remote.c:1559
 #, c-format
 msgid "No such remote '%s'"
 msgstr "No existe el remoto '%s'"
 
-#: builtin/remote.c:1451
+#: builtin/remote.c:1453
 msgid "add branch"
 msgstr "agregar rama"
 
-#: builtin/remote.c:1458
+#: builtin/remote.c:1460
 msgid "no remote specified"
 msgstr "no hay remotos especificados"
 
-#: builtin/remote.c:1475
+#: builtin/remote.c:1477
 msgid "query push URLs rather than fetch URLs"
 msgstr "consultar URLs de push en lugar de URLs de fetch"
 
-#: builtin/remote.c:1477
+#: builtin/remote.c:1479
 msgid "return all URLs"
 msgstr "retornar todos los URLs"
 
-#: builtin/remote.c:1505
+#: builtin/remote.c:1507
 #, c-format
 msgid "no URLs configured for remote '%s'"
 msgstr "no hay URLs configurados para remoto '%s'"
 
-#: builtin/remote.c:1531
+#: builtin/remote.c:1533
 msgid "manipulate push URLs"
 msgstr "manipular URLs de push"
 
-#: builtin/remote.c:1533
+#: builtin/remote.c:1535
 msgid "add URL"
 msgstr "agregar URL"
 
-#: builtin/remote.c:1535
+#: builtin/remote.c:1537
 msgid "delete URLs"
 msgstr "borrar URLs"
 
-#: builtin/remote.c:1542
+#: builtin/remote.c:1544
 msgid "--add --delete doesn't make sense"
 msgstr "--add --delete no tiene sentido"
 
-#: builtin/remote.c:1581
+#: builtin/remote.c:1583
 #, c-format
 msgid "Invalid old URL pattern: %s"
 msgstr "Patrón de URL viejo inválido: %s"
 
-#: builtin/remote.c:1589
+#: builtin/remote.c:1591
 #, c-format
 msgid "No such URL found: %s"
 msgstr "No se encontró URL: %s"
 
-#: builtin/remote.c:1591
+#: builtin/remote.c:1593
 msgid "Will not delete all non-push URLs"
 msgstr "No borrará todos los URLs de no-push"
 
-#: builtin/remote.c:1607
-msgid "be verbose; must be placed before a subcommand"
-msgstr "ser verboso; tiene que ser agregado antes de un subcomando"
-
-#: builtin/remote.c:1638
-#, c-format
-msgid "Unknown subcommand: %s"
-msgstr "Sub-comando desconocido: %s"
-
-#: builtin/repack.c:18
+#: builtin/repack.c:23
 msgid "git repack [<options>]"
 msgstr "git repack [<opciones>]"
 
-#: builtin/repack.c:23
+#: builtin/repack.c:28
 msgid ""
 "Incremental repacks are incompatible with bitmap indexes.  Use\n"
 "--no-write-bitmap-index or disable the pack.writebitmaps configuration."
@@ -13385,96 +18990,137 @@ msgstr ""
 "Re empaquetados incrementales son incompatibles con índices bitmap. Use \n"
 "--no-write-bitmap-index o deshabilite la configuración pack.writebitmaps."
 
-#: builtin/repack.c:180
+#: builtin/repack.c:191
+msgid "could not start pack-objects to repack promisor objects"
+msgstr "no se puede iniciar pack-objects para reempaquetar objetos promisores"
+
+#: builtin/repack.c:230 builtin/repack.c:416
+msgid "repack: Expecting full hex object ID lines only from pack-objects."
+msgstr ""
+"repack: Esperando líneas de ID de objeto en full hex solo desde pack-objects."
+
+#: builtin/repack.c:254
+msgid "could not finish pack-objects to repack promisor objects"
+msgstr ""
+"no se puede finalizar pack-objects para reempaquetar objetos promisores"
+
+#: builtin/repack.c:292
 msgid "pack everything in a single pack"
 msgstr "empaquetar todo en un único paquete"
 
-#: builtin/repack.c:182
+#: builtin/repack.c:294
 msgid "same as -a, and turn unreachable objects loose"
 msgstr "lo mismo que -a, y pierde objetos inaccesibles"
 
-#: builtin/repack.c:185
+#: builtin/repack.c:297
 msgid "remove redundant packs, and run git-prune-packed"
-msgstr "remover paquetes redundantes, y ejecutar git-prune-packed"
+msgstr "eliminar paquetes redundantes, y ejecutar git-prune-packed"
 
-#: builtin/repack.c:187
+#: builtin/repack.c:299
 msgid "pass --no-reuse-delta to git-pack-objects"
 msgstr "pasar --no-reuse-delta a git-pack-objects"
 
-#: builtin/repack.c:189
+#: builtin/repack.c:301
 msgid "pass --no-reuse-object to git-pack-objects"
 msgstr "pasar --no-reuse-object a git-pack-objects"
 
-#: builtin/repack.c:191
+#: builtin/repack.c:303
 msgid "do not run git-update-server-info"
 msgstr "no ejecutar git-update-server-info"
 
-#: builtin/repack.c:194
+#: builtin/repack.c:306
 msgid "pass --local to git-pack-objects"
 msgstr "pasar --local a git-pack-objects"
 
-#: builtin/repack.c:196
+#: builtin/repack.c:308
 msgid "write bitmap index"
 msgstr "escribir un índice de bitmap"
 
-#: builtin/repack.c:197
+#: builtin/repack.c:310
+msgid "pass --delta-islands to git-pack-objects"
+msgstr "pasar --delta-islands a git-pack-objects"
+
+#: builtin/repack.c:311
 msgid "approxidate"
 msgstr "aproxime"
 
-#: builtin/repack.c:198
+#: builtin/repack.c:312
 msgid "with -A, do not loosen objects older than this"
 msgstr "con -A, no perder objetos más antiguos que este"
 
-#: builtin/repack.c:200
+#: builtin/repack.c:314
 msgid "with -a, repack unreachable objects"
 msgstr "con -a, re empaquetar objetos inalcanzables"
 
-#: builtin/repack.c:202
+#: builtin/repack.c:316
 msgid "size of the window used for delta compression"
 msgstr "tamaño de la ventana usado para la compresión delta"
 
-#: builtin/repack.c:203 builtin/repack.c:209
+#: builtin/repack.c:317 builtin/repack.c:323
 msgid "bytes"
 msgstr "bytes"
 
-#: builtin/repack.c:204
+#: builtin/repack.c:318
 msgid "same as the above, but limit memory size instead of entries count"
 msgstr ""
 "lo mismo que arriba, pero limita el tamaño de memoria en lugar de contar "
 "entradas"
 
-#: builtin/repack.c:206
+#: builtin/repack.c:320
 msgid "limits the maximum delta depth"
 msgstr "limita la profundidad máxima del delta"
 
-#: builtin/repack.c:208
+#: builtin/repack.c:322
 msgid "limits the maximum number of threads"
 msgstr "limita el número máximo de hilos"
 
-#: builtin/repack.c:210
+#: builtin/repack.c:324
 msgid "maximum size of each packfile"
 msgstr "tamaño máximo de cada paquete"
 
-#: builtin/repack.c:212
+#: builtin/repack.c:326
 msgid "repack objects in packs marked with .keep"
 msgstr "re-empaquetar objetos en paquetes marcados con .keep"
 
-#: builtin/repack.c:214
+#: builtin/repack.c:328
 msgid "do not repack this pack"
 msgstr "no reempaquetar este paquete"
 
-#: builtin/repack.c:224
+#: builtin/repack.c:338
 msgid "cannot delete packs in a precious-objects repo"
 msgstr "no se pueden borrar paquetes en un repositorio de objetos-preciosos"
 
-#: builtin/repack.c:228
+#: builtin/repack.c:342
 msgid "--keep-unreachable and -A are incompatible"
 msgstr "--keep-unreachable y -A son incompatibles"
 
-#: builtin/repack.c:425 builtin/worktree.c:139
+#: builtin/repack.c:425
+msgid "Nothing new to pack."
+msgstr "Nada nuevo para empaquetar."
+
+#: builtin/repack.c:486
+#, c-format
+msgid ""
+"WARNING: Some packs in use have been renamed by\n"
+"WARNING: prefixing old- to their name, in order to\n"
+"WARNING: replace them with the new version of the\n"
+"WARNING: file.  But the operation failed, and the\n"
+"WARNING: attempt to rename them back to their\n"
+"WARNING: original names also failed.\n"
+"WARNING: Please rename them in %s manually:\n"
+msgstr ""
+"WARNING: Algunos packs en uso han sido renombrados\n"
+"WARNING: agregando el prefijo old- a sus nombres,para\n"
+"WARNING: reemplazarlos con la nueva versión del\n"
+"WARNING: archivo. Pero la operación falló, y el intento\n"
+"WARNING: de renombrarlos a sus nombres originales\n"
+"WARNING: también falló.\n"
+"WARNING: Por favor renombralos en %s manualmente:\n"
+
+#: builtin/repack.c:534
 #, c-format
 msgid "failed to remove '%s'"
-msgstr "falló al remover '%s'"
+msgstr "falló al eliminar'%s'"
 
 #: builtin/replace.c:22
 msgid "git replace [-f] <object> <replacement>"
@@ -13500,22 +19146,121 @@ msgstr "git replace -d <objeto>..."
 msgid "git replace [--format=<format>] [-l [<pattern>]]"
 msgstr "git replace [--format=<formato>] [-l [<patrón>]]"
 
-#: builtin/replace.c:371 builtin/replace.c:415 builtin/replace.c:445
+#: builtin/replace.c:90
+#, c-format
+msgid ""
+"invalid replace format '%s'\n"
+"valid formats are 'short', 'medium' and 'long'"
+msgstr ""
+"formato de reemplazo inválido '%s'\n"
+"formatos válidos son 'short', 'medium' y 'long'"
+
+#: builtin/replace.c:125
+#, c-format
+msgid "replace ref '%s' not found"
+msgstr "rama de reemplazo '%s' no encontrada"
+
+#: builtin/replace.c:141
+#, c-format
+msgid "Deleted replace ref '%s'"
+msgstr "Borradas replace refs '%s'"
+
+#: builtin/replace.c:153
+#, c-format
+msgid "'%s' is not a valid ref name"
+msgstr "'%s' no es un nombre de ref válido"
+
+#: builtin/replace.c:158
+#, c-format
+msgid "replace ref '%s' already exists"
+msgstr "ref de reemplazo '%s' ya existe"
+
+#: builtin/replace.c:178
+#, c-format
+msgid ""
+"Objects must be of the same type.\n"
+"'%s' points to a replaced object of type '%s'\n"
+"while '%s' points to a replacement object of type '%s'."
+msgstr ""
+"Objeto debe ser del mismo tipo.\n"
+"'%s' puntos para un objeto reemplazado de tipo '%s'\n"
+"mientras '%s' puntos para un reemplazo de tipo de objeto '%s'."
+
+#: builtin/replace.c:229
+#, c-format
+msgid "unable to open %s for writing"
+msgstr "no se pudo abrir %s para escritura"
+
+#: builtin/replace.c:242
+msgid "cat-file reported failure"
+msgstr "cat-file reportó un fallo"
+
+#: builtin/replace.c:258
+#, c-format
+msgid "unable to open %s for reading"
+msgstr "no se pudo abrir %s para lectura"
+
+#: builtin/replace.c:272
+msgid "unable to spawn mktree"
+msgstr "no es posible generar mktree"
+
+#: builtin/replace.c:276
+msgid "unable to read from mktree"
+msgstr "no es posible leer de mktree"
+
+#: builtin/replace.c:285
+msgid "mktree reported failure"
+msgstr "mktree reportó un error"
+
+#: builtin/replace.c:289
+msgid "mktree did not return an object name"
+msgstr "mktree no devolvió un nombre de objeto"
+
+#: builtin/replace.c:298
+#, c-format
+msgid "unable to fstat %s"
+msgstr "incapaz de correr fstat %s"
+
+#: builtin/replace.c:303
+msgid "unable to write object to database"
+msgstr "incapaz de escribir el objeto en la base de datos"
+
+#: builtin/replace.c:322 builtin/replace.c:378 builtin/replace.c:423
+#: builtin/replace.c:453
+#, c-format
+msgid "not a valid object name: '%s'"
+msgstr "nombre de objeto no válido: '%s'"
+
+#: builtin/replace.c:326
+#, c-format
+msgid "unable to get object type for %s"
+msgstr "no es obtener tipo de objeto para %s"
+
+#: builtin/replace.c:342
+msgid "editing object file failed"
+msgstr "edición de archivo de objeto falló"
+
+#: builtin/replace.c:351
+#, c-format
+msgid "new object is the same as the old one: '%s'"
+msgstr "nuevo objeto es igual al antiguo: '%s'"
+
+#: builtin/replace.c:384
 #, c-format
-msgid "Not a valid object name: '%s'"
-msgstr "Nombre de objeto no válido: '%s'"
+msgid "could not parse %s as a commit"
+msgstr "no se pudo analizar %s como un commit"
 
-#: builtin/replace.c:407
+#: builtin/replace.c:415
 #, c-format
 msgid "bad mergetag in commit '%s'"
 msgstr "mal mergetag en commit '%s'"
 
-#: builtin/replace.c:409
+#: builtin/replace.c:417
 #, c-format
 msgid "malformed mergetag in commit '%s'"
 msgstr "mergetag mal formado en commit '%s'"
 
-#: builtin/replace.c:421
+#: builtin/replace.c:429
 #, c-format
 msgid ""
 "original commit '%s' contains mergetag '%s' that is discarded; use --edit "
@@ -13524,21 +19269,31 @@ msgstr ""
 "commit original '%s' contiene un mergetag '%s' que es descartado; use --edit "
 "en lugar de --graft"
 
-#: builtin/replace.c:460
+#: builtin/replace.c:468
 #, c-format
-msgid "the original commit '%s' has a gpg signature."
-msgstr "el commit original '%s' tiene una firma gpg."
+msgid "the original commit '%s' has a gpg signature"
+msgstr "el commit original '%s' tiene una firma gpg"
 
-#: builtin/replace.c:461
+#: builtin/replace.c:469
 msgid "the signature will be removed in the replacement commit!"
-msgstr "la firma será removida en el commit de reemplazo!"
+msgstr "la firma será eliminada en el commit de reemplazo!"
 
-#: builtin/replace.c:471
+#: builtin/replace.c:479
 #, c-format
 msgid "could not write replacement commit for: '%s'"
 msgstr "no se pudo escribir el commit de reemplazo: '%s'"
 
-#: builtin/replace.c:514
+#: builtin/replace.c:487
+#, c-format
+msgid "graft for '%s' unnecessary"
+msgstr "graft para '%s' innecesario"
+
+#: builtin/replace.c:491
+#, c-format
+msgid "new commit is the same as the old one: '%s'"
+msgstr "nuevo commit es le mismo que el antiguo: '%s'"
+
+#: builtin/replace.c:526
 #, c-format
 msgid ""
 "could not convert the following graft(s):\n"
@@ -13547,212 +19302,273 @@ msgstr ""
 "no se pudo convertir el siguiente graft(s):\n"
 "%s"
 
-#: builtin/replace.c:535
+#: builtin/replace.c:547
 msgid "list replace refs"
 msgstr "listar replace refs"
 
-#: builtin/replace.c:536
+#: builtin/replace.c:548
 msgid "delete replace refs"
 msgstr "borrar replace refs"
 
-#: builtin/replace.c:537
+#: builtin/replace.c:549
 msgid "edit existing object"
 msgstr "editar objeto existente"
 
-#: builtin/replace.c:538
+#: builtin/replace.c:550
 msgid "change a commit's parents"
 msgstr "cambiar un padre de commit"
 
-#: builtin/replace.c:539
+#: builtin/replace.c:551
 msgid "convert existing graft file"
 msgstr "convertir archivo graft existente"
 
-#: builtin/replace.c:540
+#: builtin/replace.c:552
 msgid "replace the ref if it exists"
 msgstr "reemplazar el ref si este existe"
 
-#: builtin/replace.c:542
+#: builtin/replace.c:554
 msgid "do not pretty-print contents for --edit"
 msgstr "no se puede imprimir contenidos para --edit"
 
-#: builtin/replace.c:543
+#: builtin/replace.c:555
 msgid "use this format"
 msgstr "usar este formato"
 
+#: builtin/replace.c:568
+msgid "--format cannot be used when not listing"
+msgstr "--format no puede ser usado cuando no se hace listing"
+
+#: builtin/replace.c:576
+msgid "-f only makes sense when writing a replacement"
+msgstr "-f solo tiene sentido cuando se escribe un reemplazo"
+
+#: builtin/replace.c:580
+msgid "--raw only makes sense with --edit"
+msgstr "--raw solo tiene sentido con --edit"
+
+#: builtin/replace.c:586
+msgid "-d needs at least one argument"
+msgstr "-d necesita al menos un argumento"
+
+#: builtin/replace.c:592
+msgid "bad number of arguments"
+msgstr "mal número de argumentos"
+
+#: builtin/replace.c:598
+msgid "-e needs exactly one argument"
+msgstr "-e necesita exactamente un argumento"
+
+#: builtin/replace.c:604
+msgid "-g needs at least one argument"
+msgstr "-g necesita al menos un argumento"
+
+#: builtin/replace.c:610
+msgid "--convert-graft-file takes no argument"
+msgstr "--convert-graft-file no toma argumentos"
+
+#: builtin/replace.c:616
+msgid "only one pattern can be given with -l"
+msgstr "solo se puede dar un patrón con -l"
+
 #: builtin/rerere.c:13
 msgid "git rerere [clear | forget <path>... | status | remaining | diff | gc]"
 msgstr "git rerere [clear | forget <ruta>... | status | remaining | diff | gc]"
 
-#: builtin/rerere.c:59
+#: builtin/rerere.c:60
 msgid "register clean resolutions in index"
 msgstr "registrar resoluciones limpias en el índice"
 
-#: builtin/reset.c:29
+#: builtin/rerere.c:79
+msgid "'git rerere forget' without paths is deprecated"
+msgstr "'git rerere forget' sin rutas está deprecado"
+
+#: builtin/rerere.c:113
+#, c-format
+msgid "unable to generate diff for '%s'"
+msgstr "no es posible generar diff para '%s'"
+
+#: builtin/reset.c:32
 msgid ""
 "git reset [--mixed | --soft | --hard | --merge | --keep] [-q] [<commit>]"
 msgstr ""
 "git reset [--mixed | --soft | --hard | --merge | --keep] [-q] [<commit>]"
 
-#: builtin/reset.c:30
-msgid "git reset [-q] [<tree-ish>] [--] <paths>..."
-msgstr "git reset [-q] [<árbol-ismo>] [--] <rutas>..."
-
-#: builtin/reset.c:31
-msgid "git reset --patch [<tree-ish>] [--] [<paths>...]"
-msgstr "git reset --patch [<árbol-ismo>] [--] [<rutas>...]"
+#: builtin/reset.c:33
+msgid "git reset [-q] [<tree-ish>] [--] <pathspec>..."
+msgstr "git reset [-q] [<árbol-ismo>] [--] <pathspec>..."
+
+#: builtin/reset.c:34
+msgid ""
+"git reset [-q] [--pathspec-from-file [--pathspec-file-nul]] [<tree-ish>]"
+msgstr ""
+"git reset [-q] [--pathspec-from-file [--pathspec-file-nul]] [<árbol-ismo>]"
 
-#: builtin/reset.c:37
+#: builtin/reset.c:35
+msgid "git reset --patch [<tree-ish>] [--] [<pathspec>...]"
+msgstr "git reset --patch [<árbol-ismo>] [--] [<pathspec>...]"
+
+#: builtin/reset.c:41
 msgid "mixed"
 msgstr "mezclado"
 
-#: builtin/reset.c:37
+#: builtin/reset.c:41
 msgid "soft"
 msgstr "suave"
 
-#: builtin/reset.c:37
+#: builtin/reset.c:41
 msgid "hard"
 msgstr "duro"
 
-#: builtin/reset.c:37
+#: builtin/reset.c:41
 msgid "merge"
 msgstr "fusionar"
 
-#: builtin/reset.c:37
+#: builtin/reset.c:41
 msgid "keep"
 msgstr "mantener"
 
-#: builtin/reset.c:78
+#: builtin/reset.c:82
 msgid "You do not have a valid HEAD."
 msgstr "No hay un HEAD válido."
 
-#: builtin/reset.c:80
+#: builtin/reset.c:84
 msgid "Failed to find tree of HEAD."
 msgstr "Falló al encontrar el HEAD del árbol."
 
-#: builtin/reset.c:86
+#: builtin/reset.c:90
 #, c-format
 msgid "Failed to find tree of %s."
 msgstr "Falló al encontrar árbol de %s."
 
-#: builtin/reset.c:111
+#: builtin/reset.c:115
 #, c-format
 msgid "HEAD is now at %s"
 msgstr "HEAD está ahora en %s"
 
-#: builtin/reset.c:189
+#: builtin/reset.c:194
 #, c-format
 msgid "Cannot do a %s reset in the middle of a merge."
 msgstr "No se puede realziar un reset %s  en medio de una fusión."
 
-#: builtin/reset.c:289
+#: builtin/reset.c:294 builtin/stash.c:519 builtin/stash.c:594
+#: builtin/stash.c:618
 msgid "be quiet, only report errors"
 msgstr "ser silencioso, solo reportar errores"
 
-#: builtin/reset.c:291
+#: builtin/reset.c:296
 msgid "reset HEAD and index"
 msgstr "reiniciar HEAD e index"
 
-#: builtin/reset.c:292
+#: builtin/reset.c:297
 msgid "reset only HEAD"
 msgstr "reiniciar solo HEAD"
 
-#: builtin/reset.c:294 builtin/reset.c:296
+#: builtin/reset.c:299 builtin/reset.c:301
 msgid "reset HEAD, index and working tree"
 msgstr "reiniciar HEAD, índice y árbol de trabajo"
 
-#: builtin/reset.c:298
+#: builtin/reset.c:303
 msgid "reset HEAD but keep local changes"
 msgstr "reiniciar HEAD pero mantener cambios locales"
 
-#: builtin/reset.c:304
+#: builtin/reset.c:309
 msgid "record only the fact that removed paths will be added later"
 msgstr ""
-"grabar solo el hecho de que las rutas removidas serán agregadas después"
+"grabar solo el hecho de que las rutas eliminadas serán agregadas después"
 
-#: builtin/reset.c:321
+#: builtin/reset.c:343
 #, c-format
 msgid "Failed to resolve '%s' as a valid revision."
 msgstr "Falló al resolver '%s' como una revisión válida."
 
-#: builtin/reset.c:329
+#: builtin/reset.c:351
 #, c-format
 msgid "Failed to resolve '%s' as a valid tree."
 msgstr "Falló al resolver '%s' como un árbol válido."
 
-#: builtin/reset.c:338
+#: builtin/reset.c:360
 msgid "--patch is incompatible with --{hard,mixed,soft}"
 msgstr "--patch es incompatible con --{hard,mixed,soft}"
 
-#: builtin/reset.c:347
+#: builtin/reset.c:370
 msgid "--mixed with paths is deprecated; use 'git reset -- <paths>' instead."
 msgstr ""
 "--mixed con rutas ha sido deprecado; use 'git reset -- <rutas>' en cambio."
 
-#: builtin/reset.c:349
+#: builtin/reset.c:372
 #, c-format
 msgid "Cannot do %s reset with paths."
 msgstr "No se puede hacer un reset %s con rutas."
 
-#: builtin/reset.c:359
+#: builtin/reset.c:387
 #, c-format
 msgid "%s reset is not allowed in a bare repository"
 msgstr "%s reset no está permitido en un repositorio vacío"
 
-#: builtin/reset.c:363
+#: builtin/reset.c:391
 msgid "-N can only be used with --mixed"
 msgstr "-N sólo puede ser usada con --mixed"
 
-#: builtin/reset.c:380
+#: builtin/reset.c:412
 msgid "Unstaged changes after reset:"
 msgstr "Cambios fuera del área de stage tras el reset:"
 
-#: builtin/reset.c:386
+#: builtin/reset.c:415
+#, c-format
+msgid ""
+"\n"
+"It took %.2f seconds to enumerate unstaged changes after reset.  You can\n"
+"use '--quiet' to avoid this.  Set the config setting reset.quiet to true\n"
+"to make this the default.\n"
+msgstr ""
+"\n"
+"Tomó %.2f segundos en enumerar cambios fuera de stage tras el reinicio.  "
+"Puedes\n"
+"usar '--quiet' para evitar esto.  Configura la opción reset.quiet a true\n"
+"para volverlo en el default.\n"
+
+#: builtin/reset.c:425
 #, c-format
 msgid "Could not reset index file to revision '%s'."
 msgstr "No se puede reiniciar el índice a la revisión '%s'."
 
-#: builtin/reset.c:390
+#: builtin/reset.c:429
 msgid "Could not write new index file."
 msgstr "No se puede escribir un nuevo archivo índice."
 
-#: builtin/rev-list.c:397
+#: builtin/rev-list.c:411
 msgid "cannot combine --exclude-promisor-objects and --missing"
 msgstr "no se puede combinar --exclude-promisor-objects y --missing"
 
-#: builtin/rev-list.c:455
+#: builtin/rev-list.c:472
 msgid "object filtering requires --objects"
 msgstr "filtrado de objetos requiere --objects"
 
-#: builtin/rev-list.c:458
-#, c-format
-msgid "invalid sparse value '%s'"
-msgstr "valor disperso inválido: '%s'"
-
-#: builtin/rev-list.c:499
+#: builtin/rev-list.c:522
 msgid "rev-list does not support display of notes"
 msgstr "rev-list no soporta mostrar notas"
 
-#: builtin/rev-list.c:502
+#: builtin/rev-list.c:525
 msgid "cannot combine --use-bitmap-index with object filtering"
 msgstr "no se puede combinar --use-bitmap-index con objetos de filtrado"
 
-#: builtin/rev-parse.c:406
+#: builtin/rev-parse.c:408
 msgid "git rev-parse --parseopt [<options>] -- [<args>...]"
 msgstr "git rev-parse --parseopt [<opciones>] -- [<args>...]"
 
-#: builtin/rev-parse.c:411
+#: builtin/rev-parse.c:413
 msgid "keep the `--` passed as an arg"
 msgstr "mantener el `--` pasado como un arg"
 
-#: builtin/rev-parse.c:413
+#: builtin/rev-parse.c:415
 msgid "stop parsing after the first non-option argument"
 msgstr "detener análisis tras el primer argumento que no es opción"
 
-#: builtin/rev-parse.c:416
+#: builtin/rev-parse.c:418
 msgid "output in stuck long form"
 msgstr "salida en formulario largo de atasco"
 
-#: builtin/rev-parse.c:549
+#: builtin/rev-parse.c:551
 msgid ""
 "git rev-parse --parseopt [<options>] -- [<args>...]\n"
 "   or: git rev-parse --sq-quote [<arg>...]\n"
@@ -13767,92 +19583,97 @@ msgstr ""
 "Ejecute \"git rev-parse --parseopt -h\" para más información sobre el primer "
 "uso."
 
-#: builtin/revert.c:23
+#: builtin/revert.c:24
 msgid "git revert [<options>] <commit-ish>..."
 msgstr "git revert [<opciones>] <commit-ish>..."
 
-#: builtin/revert.c:24
+#: builtin/revert.c:25
 msgid "git revert <subcommand>"
 msgstr "git revert <subcomando>"
 
-#: builtin/revert.c:29
+#: builtin/revert.c:30
 msgid "git cherry-pick [<options>] <commit-ish>..."
 msgstr "git cherry-pick [<opciones>] <commit-ish>..."
 
-#: builtin/revert.c:30
+#: builtin/revert.c:31
 msgid "git cherry-pick <subcommand>"
 msgstr "git cherry-pick <subcomando>"
 
-#: builtin/revert.c:90
+#: builtin/revert.c:72
+#, c-format
+msgid "option `%s' expects a number greater than zero"
+msgstr "opción `%s' espera un valor numérico mayor a cero"
+
+#: builtin/revert.c:92
 #, c-format
 msgid "%s: %s cannot be used with %s"
 msgstr "%s: %s no puede ser usado con %s"
 
-#: builtin/revert.c:99
+#: builtin/revert.c:102
 msgid "end revert or cherry-pick sequence"
 msgstr "finalizar secuencia revert o cherry-pick"
 
-#: builtin/revert.c:100
+#: builtin/revert.c:103
 msgid "resume revert or cherry-pick sequence"
 msgstr "resumir secuencia revert o cherry-pick"
 
-#: builtin/revert.c:101
+#: builtin/revert.c:104
 msgid "cancel revert or cherry-pick sequence"
 msgstr "cancelar secuencia revert o cherry-pick"
 
-#: builtin/revert.c:102
+#: builtin/revert.c:105
+msgid "skip current commit and continue"
+msgstr "saltar el commit actual y continuar"
+
+#: builtin/revert.c:107
 msgid "don't automatically commit"
 msgstr "no realizar commit de forma automática"
 
-#: builtin/revert.c:103
+#: builtin/revert.c:108
 msgid "edit the commit message"
 msgstr "editar el mensaje de commit"
 
-#: builtin/revert.c:106
+#: builtin/revert.c:111
 msgid "parent-number"
 msgstr "número-de-padre"
 
-#: builtin/revert.c:107
+#: builtin/revert.c:112
 msgid "select mainline parent"
 msgstr "seleccionar el padre principal"
 
-#: builtin/revert.c:109
+#: builtin/revert.c:114
 msgid "merge strategy"
 msgstr "estrategia de fusión"
 
-#: builtin/revert.c:110
-msgid "option"
-msgstr "opción"
-
-#: builtin/revert.c:111
+#: builtin/revert.c:116
 msgid "option for merge strategy"
 msgstr "opción para estrategia de fusión"
 
-#: builtin/revert.c:120
+#: builtin/revert.c:125
 msgid "append commit name"
 msgstr "adjuntar el nombre del commit"
 
-#: builtin/revert.c:122
+#: builtin/revert.c:127
 msgid "preserve initially empty commits"
 msgstr "preservar commits iniciales vacíos"
 
-#: builtin/revert.c:124
+#: builtin/revert.c:129
 msgid "keep redundant, empty commits"
 msgstr "mantener commits redundantes, vacíos"
 
-#: builtin/revert.c:214
+#: builtin/revert.c:232
 msgid "revert failed"
 msgstr "falló al revertir"
 
-#: builtin/revert.c:227
+#: builtin/revert.c:245
 msgid "cherry-pick failed"
 msgstr "cherry-pick falló"
 
-#: builtin/rm.c:18
+#: builtin/rm.c:19
 msgid "git rm [<options>] [--] <file>..."
 msgstr "git rm [<opciones>] [--] <archivo>..."
 
-#: builtin/rm.c:206
+#: builtin/rm.c:207
 msgid ""
 "the following file has staged content different from both the\n"
 "file and the HEAD:"
@@ -13866,7 +19687,7 @@ msgstr[1] ""
 "los siguientes archivos tienen contenido diferente a los mismos\n"
 "y a HEAD:"
 
-#: builtin/rm.c:211
+#: builtin/rm.c:212
 msgid ""
 "\n"
 "(use -f to force removal)"
@@ -13874,13 +19695,13 @@ msgstr ""
 "\n"
 "(usa -f para forzar su eliminación)"
 
-#: builtin/rm.c:215
+#: builtin/rm.c:216
 msgid "the following file has changes staged in the index:"
 msgid_plural "the following files have changes staged in the index:"
 msgstr[0] "el siguiente archivo tiene cambios en stage en el índice:"
 msgstr[1] "los siguientes archivos tienen cambios en stage en el índice:"
 
-#: builtin/rm.c:219 builtin/rm.c:228
+#: builtin/rm.c:220 builtin/rm.c:229
 msgid ""
 "\n"
 "(use --cached to keep the file, or -f to force removal)"
@@ -13888,46 +19709,47 @@ msgstr ""
 "\n"
 "(usa --cached para conservar el archivo, o -f para forzar su eliminación)"
 
-#: builtin/rm.c:225
+#: builtin/rm.c:226
 msgid "the following file has local modifications:"
 msgid_plural "the following files have local modifications:"
 msgstr[0] "el siguiente archivo tiene modificaciones locales:"
 msgstr[1] "los siguientes archivos tienen modificaciones locales:"
 
-#: builtin/rm.c:241
+#: builtin/rm.c:242
 msgid "do not list removed files"
-msgstr "no listar archivos removidos"
+msgstr "no listar archivos eliminado"
 
-#: builtin/rm.c:242
+#: builtin/rm.c:243
 msgid "only remove from the index"
-msgstr "solo remover del índice"
+msgstr "solo eliminar del índice"
 
-#: builtin/rm.c:243
+#: builtin/rm.c:244
 msgid "override the up-to-date check"
 msgstr "sobrescribir el check de actualizado"
 
-#: builtin/rm.c:244
+#: builtin/rm.c:245
 msgid "allow recursive removal"
-msgstr "permitir remover de forma recursiva"
+msgstr "permitir eliminar de forma recursiva"
 
-#: builtin/rm.c:246
+#: builtin/rm.c:247
 msgid "exit with a zero status even if nothing matched"
 msgstr "salir con estado cero incluso si nada coincide"
 
-#: builtin/rm.c:306
-#, c-format
-msgid "not removing '%s' recursively without -r"
-msgstr "no removiendo '%s' de manera recursiva sin -r"
+#: builtin/rm.c:289
+msgid "please stage your changes to .gitmodules or stash them to proceed"
+msgstr ""
+"por favor agrega el stage de tus cambios a .gitmodules o realiza un stash "
+"para proceder"
 
-#: builtin/rm.c:345
+#: builtin/rm.c:307
 #, c-format
-msgid "git rm: unable to remove %s"
-msgstr "git rm: no es posible remover %s"
+msgid "not removing '%s' recursively without -r"
+msgstr "no eliminando '%s' de manera recursiva sin -r"
 
-#: builtin/rm.c:368
+#: builtin/rm.c:346
 #, c-format
-msgid "could not remove '%s'"
-msgstr "no se pudo remover '%s'"
+msgid "git rm: unable to remove %s"
+msgstr "git rm: no es posible eliminar %s"
 
 #: builtin/send-pack.c:20
 msgid ""
@@ -13957,18 +19779,6 @@ msgstr "leer refs de stdin"
 msgid "print status from remote helper"
 msgstr "mostrar status del remote helper"
 
-#: builtin/serve.c:7
-msgid "git serve [<options>]"
-msgstr "git serve [<opciones>]"
-
-#: builtin/serve.c:17 builtin/upload-pack.c:23
-msgid "quit after a single request/response exchange"
-msgstr "sale después de un intercambio petición/respuesta único"
-
-#: builtin/serve.c:19
-msgid "exit immediately after advertising capabilities"
-msgstr "salir inmediatamente tras anunciar capacidades"
-
 #: builtin/shortlog.c:14
 msgid "git shortlog [<options>] [<revision-range>] [[--] <path>...]"
 msgstr "git shortlog [<opciones>] [<rango-de-revisión>] [[--] <ruta>...]"
@@ -13994,18 +19804,18 @@ msgid "Show the email address of each au
 msgstr "Mostrar la dirección de correo de cada autor"
 
 #: builtin/shortlog.c:271
-msgid "w[,i1[,i2]]"
-msgstr "w[,i1[,i2]]"
+msgid "<w>[,<i1>[,<i2>]]"
+msgstr "<w>[,<i1>[,<i2>]]"
 
 #: builtin/shortlog.c:272
 msgid "Linewrap output"
 msgstr "Salida de línea"
 
-#: builtin/shortlog.c:298
+#: builtin/shortlog.c:301
 msgid "too many arguments given outside repository"
 msgstr "demasiados argumentos dados fuera del repositorio"
 
-#: builtin/show-branch.c:12
+#: builtin/show-branch.c:13
 msgid ""
 "git show-branch [-a | --all] [-r | --remotes] [--topo-order | --date-order]\n"
 "\t\t[--current] [--color[=<when>] | --no-color] [--sparse]\n"
@@ -14017,130 +19827,130 @@ msgstr ""
 "\t\t[--more=<n> | --list | --independent | --merge-base]\n"
 "\t\t[--no-name | --sha1-name] [--topics] [(<rev> | <glob>)...]"
 
-#: builtin/show-branch.c:16
+#: builtin/show-branch.c:17
 msgid "git show-branch (-g | --reflog)[=<n>[,<base>]] [--list] [<ref>]"
 msgstr "git show-branch (-g | --reflog)[=<n>[,<base>]] [--list] [<ref>]"
 
-#: builtin/show-branch.c:376
+#: builtin/show-branch.c:395
 #, c-format
 msgid "ignoring %s; cannot handle more than %d ref"
 msgid_plural "ignoring %s; cannot handle more than %d refs"
 msgstr[0] "ignorando %s; no se puede manejar más de %d ref"
 msgstr[1] "ignorando %s; no se puede manejar más de %d refs"
 
-#: builtin/show-branch.c:530
+#: builtin/show-branch.c:548
 #, c-format
 msgid "no matching refs with %s"
 msgstr "no hay refs que concuerden con %s"
 
-#: builtin/show-branch.c:626
+#: builtin/show-branch.c:645
 msgid "show remote-tracking and local branches"
 msgstr "mostrar ramas locales y de rastreo remoto"
 
-#: builtin/show-branch.c:628
+#: builtin/show-branch.c:647
 msgid "show remote-tracking branches"
 msgstr "mostrar ramas de rastreo remoto"
 
-#: builtin/show-branch.c:630
+#: builtin/show-branch.c:649
 msgid "color '*!+-' corresponding to the branch"
 msgstr "color '*!+-' correspondiendo a la rama"
 
-#: builtin/show-branch.c:632
+#: builtin/show-branch.c:651
 msgid "show <n> more commits after the common ancestor"
 msgstr "mostrar <n> commits más tras encontrar el ancestro común"
 
-#: builtin/show-branch.c:634
+#: builtin/show-branch.c:653
 msgid "synonym to more=-1"
 msgstr "sinónimo de más=-1"
 
-#: builtin/show-branch.c:635
+#: builtin/show-branch.c:654
 msgid "suppress naming strings"
 msgstr "suprimir strings de nombre"
 
-#: builtin/show-branch.c:637
+#: builtin/show-branch.c:656
 msgid "include the current branch"
 msgstr "incluir la rama actual"
 
-#: builtin/show-branch.c:639
+#: builtin/show-branch.c:658
 msgid "name commits with their object names"
 msgstr "nombrar commits con sus nombres de objeto"
 
-#: builtin/show-branch.c:641
+#: builtin/show-branch.c:660
 msgid "show possible merge bases"
 msgstr "mostrar bases de fusión posibles"
 
-#: builtin/show-branch.c:643
+#: builtin/show-branch.c:662
 msgid "show refs unreachable from any other ref"
 msgstr "mostrar refs inalcanzables por ningún otro ref"
 
-#: builtin/show-branch.c:645
+#: builtin/show-branch.c:664
 msgid "show commits in topological order"
 msgstr "mostrar commits en orden topológico"
 
-#: builtin/show-branch.c:648
+#: builtin/show-branch.c:667
 msgid "show only commits not on the first branch"
 msgstr "mostrar solo commits que no están en la primera rama"
 
-#: builtin/show-branch.c:650
+#: builtin/show-branch.c:669
 msgid "show merges reachable from only one tip"
 msgstr "mostrar fusiones alcanzables solo por una punta"
 
-#: builtin/show-branch.c:652
+#: builtin/show-branch.c:671
 msgid "topologically sort, maintaining date order where possible"
 msgstr "orden topológico, manteniendo el orden de fechas donde sea posible"
 
-#: builtin/show-branch.c:655
+#: builtin/show-branch.c:674
 msgid "<n>[,<base>]"
 msgstr "<n>[,<base>]"
 
-#: builtin/show-branch.c:656
+#: builtin/show-branch.c:675
 msgid "show <n> most recent ref-log entries starting at base"
 msgstr "mostrar <n> entradas más recientes de ref-log comenzando desde la base"
 
-#: builtin/show-branch.c:690
+#: builtin/show-branch.c:711
 msgid ""
 "--reflog is incompatible with --all, --remotes, --independent or --merge-base"
 msgstr ""
 "--reflog no es compatible con --all, --remotes, --independent o --merge-base"
 
-#: builtin/show-branch.c:714
+#: builtin/show-branch.c:735
 msgid "no branches given, and HEAD is not valid"
 msgstr "no se dieron ramas, y el HEAD no es válido"
 
-#: builtin/show-branch.c:717
+#: builtin/show-branch.c:738
 msgid "--reflog option needs one branch name"
 msgstr "opción --reflog necesita un nombre de rama"
 
-#: builtin/show-branch.c:720
+#: builtin/show-branch.c:741
 #, c-format
 msgid "only %d entry can be shown at one time."
 msgid_plural "only %d entries can be shown at one time."
 msgstr[0] "solo %d entrada puede ser mostrada a la vez."
 msgstr[1] "solo %d entradas pueden ser mostradas a la vez."
 
-#: builtin/show-branch.c:724
+#: builtin/show-branch.c:745
 #, c-format
 msgid "no such ref %s"
 msgstr "no existe el ref %s"
 
-#: builtin/show-branch.c:808
+#: builtin/show-branch.c:831
 #, c-format
 msgid "cannot handle more than %d rev."
 msgid_plural "cannot handle more than %d revs."
 msgstr[0] "no se puede manejar más de %d rev."
 msgstr[1] "no se puede manejar más de %d revs."
 
-#: builtin/show-branch.c:812
+#: builtin/show-branch.c:835
 #, c-format
 msgid "'%s' is not a valid ref."
 msgstr "'%s' no es una ref válida."
 
-#: builtin/show-branch.c:815
+#: builtin/show-branch.c:838
 #, c-format
 msgid "cannot find commit %s (%s)"
 msgstr "no se puede encontrar el commit %s (%s)"
 
-#: builtin/show-ref.c:10
+#: builtin/show-ref.c:12
 msgid ""
 "git show-ref [-q | --quiet] [--verify] [--head] [-d | --dereference] [-s | --"
 "hash[=<n>]] [--abbrev[=<n>]] [--tags] [--heads] [--] [<pattern>...]"
@@ -14148,42 +19958,319 @@ msgstr ""
 "git show-ref [-q | --quiet] [--verify] [--head] [-d | --dereference] [-s | --"
 "hash[=<n>]] [--abbrev[=<n>]] [--tags] [--heads] [--] [<patrón>...]"
 
-#: builtin/show-ref.c:11
+#: builtin/show-ref.c:13
 msgid "git show-ref --exclude-existing[=<pattern>]"
 msgstr "git show-ref --exclude-existing[=<patrón>]"
 
-#: builtin/show-ref.c:159
+#: builtin/show-ref.c:162
 msgid "only show tags (can be combined with heads)"
 msgstr "solo mostrar tags (puede ser combinado con heads)"
 
-#: builtin/show-ref.c:160
+#: builtin/show-ref.c:163
 msgid "only show heads (can be combined with tags)"
 msgstr "solo mostrar heads (puede ser combinado con tags)"
 
-#: builtin/show-ref.c:161
+#: builtin/show-ref.c:164
 msgid "stricter reference checking, requires exact ref path"
 msgstr "revisar referencias más estrictamente, requiere ruta de ref exacta"
 
-#: builtin/show-ref.c:164 builtin/show-ref.c:166
+#: builtin/show-ref.c:167 builtin/show-ref.c:169
 msgid "show the HEAD reference, even if it would be filtered out"
 msgstr "mostrar la referencia de HEAD, incluso si se filtrara"
 
-#: builtin/show-ref.c:168
+#: builtin/show-ref.c:171
 msgid "dereference tags into object IDs"
 msgstr "tags de deferencia en IDs de objeto"
 
-#: builtin/show-ref.c:170
+#: builtin/show-ref.c:173
 msgid "only show SHA1 hash using <n> digits"
 msgstr "solo mostrar hash SHA1 usando <n> dígitos"
 
-#: builtin/show-ref.c:174
+#: builtin/show-ref.c:177
 msgid "do not print results to stdout (useful with --verify)"
 msgstr "no mostrar resultados en stdout (útil con --verify)"
 
-#: builtin/show-ref.c:176
+#: builtin/show-ref.c:179
 msgid "show refs from stdin that aren't in local repository"
 msgstr "mostrar refs de stdin que no están en el repositorio local"
 
+#: builtin/sparse-checkout.c:20
+msgid "git sparse-checkout (init|list|set|disable) <options>"
+msgstr "git sparse-checkout (init|list|set|disable) <opciones>"
+
+#: builtin/sparse-checkout.c:61
+msgid "this worktree is not sparse (sparse-checkout file may not exist)"
+msgstr ""
+"este árbol de trabajo no tiene sparse (archivo sparese-checkout tal vez no "
+"existe)"
+
+#: builtin/sparse-checkout.c:220
+msgid "failed to set extensions.worktreeConfig setting"
+msgstr "falló al configurar opción extensions.worktreeConfig"
+
+#: builtin/sparse-checkout.c:237
+msgid "git sparse-checkout init [--cone]"
+msgstr "git sparse-checkout init [--cone]"
+
+#: builtin/sparse-checkout.c:256
+msgid "initialize the sparse-checkout in cone mode"
+msgstr "inicializa el sparse-checkout en modo cono"
+
+#: builtin/sparse-checkout.c:262
+msgid "initialize sparse-checkout"
+msgstr "inicializar sparse-checkout"
+
+#: builtin/sparse-checkout.c:295
+#, c-format
+msgid "failed to open '%s'"
+msgstr "falló al abrir '%s'"
+
+#: builtin/sparse-checkout.c:361
+msgid "git sparse-checkout set (--stdin | <patterns>)"
+msgstr "git sparse-checkout set (--stdin | <patrones>)"
+
+#: builtin/sparse-checkout.c:378
+msgid "read patterns from standard in"
+msgstr "leer patrones de standard in"
+
+#: builtin/sparse-checkout.c:384
+msgid "set sparse-checkout patterns"
+msgstr "configurar patrones de sparse-checkout"
+
+#: builtin/sparse-checkout.c:447
+msgid "disable sparse-checkout"
+msgstr "deshabilitar sparse-checkout"
+
+#: builtin/sparse-checkout.c:459
+msgid "error while refreshing working directory"
+msgstr "error al refrescar directorio de trabajo"
+
+#: builtin/stash.c:22 builtin/stash.c:37
+msgid "git stash list [<options>]"
+msgstr "git stash list [<opciones>]"
+
+#: builtin/stash.c:23 builtin/stash.c:42
+msgid "git stash show [<options>] [<stash>]"
+msgstr "git stash show [<opciones>] [<stash>]"
+
+#: builtin/stash.c:24 builtin/stash.c:47
+msgid "git stash drop [-q|--quiet] [<stash>]"
+msgstr "git stash drop [-q|--quiet] [<stash>]"
+
+#: builtin/stash.c:25
+msgid "git stash ( pop | apply ) [--index] [-q|--quiet] [<stash>]"
+msgstr "git stash ( pop | apply ) [--index] [-q|--quiet] [<stash>]"
+
+#: builtin/stash.c:26 builtin/stash.c:62
+msgid "git stash branch <branchname> [<stash>]"
+msgstr "git stash branch <nombre-rama> [<stash>]"
+
+#: builtin/stash.c:27 builtin/stash.c:67
+msgid "git stash clear"
+msgstr "git stash clear"
+
+#: builtin/stash.c:28 builtin/stash.c:77
+msgid ""
+"git stash [push [-p|--patch] [-k|--[no-]keep-index] [-q|--quiet]\n"
+"          [-u|--include-untracked] [-a|--all] [-m|--message <message>]\n"
+"          [--] [<pathspec>...]]"
+msgstr ""
+"git stash [push [-p|--patch] [-k|--[no-]keep-index] [-q|--quiet]\n"
+"          [-u|--include-untracked] [-a|--all] [-m|--message <mensaje>]\n"
+"          [--] [<pathspec>...]]"
+
+#: builtin/stash.c:31 builtin/stash.c:84
+msgid ""
+"git stash save [-p|--patch] [-k|--[no-]keep-index] [-q|--quiet]\n"
+"          [-u|--include-untracked] [-a|--all] [<message>]"
+msgstr ""
+"git stash save [-p|--patch] [-k|--[no-]keep-index] [-q|--quiet]\n"
+"          [-u|--include-untracked] [-a|--all] [<mensaje>]"
+
+#: builtin/stash.c:52
+msgid "git stash pop [--index] [-q|--quiet] [<stash>]"
+msgstr "git stash pop [--index] [-q|--quiet] [<stash>]"
+
+#: builtin/stash.c:57
+msgid "git stash apply [--index] [-q|--quiet] [<stash>]"
+msgstr "git stash apply [--index] [-q|--quiet] [<stash>]"
+
+#: builtin/stash.c:72
+msgid "git stash store [-m|--message <message>] [-q|--quiet] <commit>"
+msgstr "git stash store [-m|--message <mensaje>] [-q|--quiet] <commit>"
+
+#: builtin/stash.c:127
+#, c-format
+msgid "'%s' is not a stash-like commit"
+msgstr "'%s' no es un commit estilo stash"
+
+#: builtin/stash.c:147
+#, c-format
+msgid "Too many revisions specified:%s"
+msgstr "Se especificaron demasiadas revisiones: %s"
+
+#: builtin/stash.c:161 git-legacy-stash.sh:549
+msgid "No stash entries found."
+msgstr "No se encontraron entradas de stash."
+
+#: builtin/stash.c:175
+#, c-format
+msgid "%s is not a valid reference"
+msgstr "%s no es una referencia válida"
+
+#: builtin/stash.c:224 git-legacy-stash.sh:75
+msgid "git stash clear with parameters is unimplemented"
+msgstr "git stash clear con parámetros no está implementado"
+
+#: builtin/stash.c:403
+msgid "cannot apply a stash in the middle of a merge"
+msgstr "no se puede aplicar un stash en medio de un merge"
+
+#: builtin/stash.c:414
+#, c-format
+msgid "could not generate diff %s^!."
+msgstr "no se pudo generar diff %s^!."
+
+#: builtin/stash.c:421
+msgid "conflicts in index.Try without --index."
+msgstr "conflictos en índice. Intente sin --index."
+
+#: builtin/stash.c:427
+msgid "could not save index tree"
+msgstr "no se puede guardar el índice del árbol"
+
+#: builtin/stash.c:436
+msgid "could not restore untracked files from stash"
+msgstr "no se pueden restaurar archivos no rastreados de la entrada stash"
+
+#: builtin/stash.c:450
+#, c-format
+msgid "Merging %s with %s"
+msgstr "Fusionando %s con %s"
+
+#: builtin/stash.c:460 git-legacy-stash.sh:681
+msgid "Index was not unstashed."
+msgstr "El índice no fue sacado de stash."
+
+#: builtin/stash.c:521 builtin/stash.c:620
+msgid "attempt to recreate the index"
+msgstr "intento de recrear el index"
+
+#: builtin/stash.c:554
+#, c-format
+msgid "Dropped %s (%s)"
+msgstr "Botado %s (%s)"
+
+#: builtin/stash.c:557
+#, c-format
+msgid "%s: Could not drop stash entry"
+msgstr "%s: No se pudo borrar entrada stash"
+
+#: builtin/stash.c:582
+#, c-format
+msgid "'%s' is not a stash reference"
+msgstr "'%s' no es una referencia stash"
+
+#: builtin/stash.c:632 git-legacy-stash.sh:695
+msgid "The stash entry is kept in case you need it again."
+msgstr "La entrada de stash se guardó en caso de ser necesario nuevamente."
+
+#: builtin/stash.c:655 git-legacy-stash.sh:713
+msgid "No branch name specified"
+msgstr "No se especificó el nombre de la rama"
+
+#: builtin/stash.c:795 builtin/stash.c:832
+#, c-format
+msgid "Cannot update %s with %s"
+msgstr "No se puede actualizar %s con %s"
+
+#: builtin/stash.c:813 builtin/stash.c:1470 builtin/stash.c:1506
+msgid "stash message"
+msgstr "mensaje de stash"
+
+#: builtin/stash.c:823
+msgid "\"git stash store\" requires one <commit> argument"
+msgstr "\"git stash store\" requiere un argumento <commit>"
+
+#: builtin/stash.c:1045 git-legacy-stash.sh:218
+msgid "No changes selected"
+msgstr "Sin cambios seleccionados"
+
+#: builtin/stash.c:1145 git-legacy-stash.sh:150
+msgid "You do not have the initial commit yet"
+msgstr "Aún no tienes un commit inicial"
+
+#: builtin/stash.c:1172 git-legacy-stash.sh:165
+msgid "Cannot save the current index state"
+msgstr "No se puede guardar el estado actual del índice"
+
+#: builtin/stash.c:1181 git-legacy-stash.sh:180
+msgid "Cannot save the untracked files"
+msgstr "No se pueden guardar los archivos no rastreados"
+
+#: builtin/stash.c:1192 builtin/stash.c:1201 git-legacy-stash.sh:201
+#: git-legacy-stash.sh:214
+msgid "Cannot save the current worktree state"
+msgstr "No se puede guardar el estado actual del árbol de trabajo"
+
+#: builtin/stash.c:1229 git-legacy-stash.sh:234
+msgid "Cannot record working tree state"
+msgstr "No se puede grabar el estado del árbol de trabajo"
+
+#: builtin/stash.c:1278 git-legacy-stash.sh:338
+msgid "Can't use --patch and --include-untracked or --all at the same time"
+msgstr "No se puede usar --patch y --include-untracked o --all al mismo tiempo"
+
+#: builtin/stash.c:1294
+msgid "Did you forget to 'git add'?"
+msgstr "¿Olvidaste 'git add'?"
+
+#: builtin/stash.c:1309 git-legacy-stash.sh:346
+msgid "No local changes to save"
+msgstr "No hay cambios locales para guardar"
+
+#: builtin/stash.c:1316 git-legacy-stash.sh:351
+msgid "Cannot initialize stash"
+msgstr "No se puede inicializar stash"
+
+#: builtin/stash.c:1331 git-legacy-stash.sh:355
+msgid "Cannot save the current status"
+msgstr "No se puede guardar el estado actual"
+
+#: builtin/stash.c:1336
+#, c-format
+msgid "Saved working directory and index state %s"
+msgstr "Directorio de trabajo guardado y estado de índice %s"
+
+#: builtin/stash.c:1426 git-legacy-stash.sh:385
+msgid "Cannot remove worktree changes"
+msgstr "No se pueden eliminar cambios del árbol de trabajo"
+
+#: builtin/stash.c:1461 builtin/stash.c:1497
+msgid "keep index"
+msgstr "mantener index"
+
+#: builtin/stash.c:1463 builtin/stash.c:1499
+msgid "stash in patch mode"
+msgstr "stash en modo patch"
+
+#: builtin/stash.c:1464 builtin/stash.c:1500
+msgid "quiet mode"
+msgstr "modo tranquilo"
+
+#: builtin/stash.c:1466 builtin/stash.c:1502
+msgid "include untracked files in stash"
+msgstr "incluir archivos sin seguimiento en stash"
+
+#: builtin/stash.c:1468 builtin/stash.c:1504
+msgid "include ignore files"
+msgstr "incluir archivos ignorados"
+
+#: builtin/stash.c:1564
+#, c-format
+msgid "could not exec %s"
+msgstr "no se pudo ejecutar %s"
+
 #: builtin/stripspace.c:18
 msgid "git stripspace [-s | --strip-comments]"
 msgstr "git stripspace [-s | --strip-comments]"
@@ -14192,107 +20279,140 @@ msgstr "git stripspace [-s | --strip-com
 msgid "git stripspace [-c | --comment-lines]"
 msgstr "git stripspace [-c | --comment-lines]"
 
-#: builtin/stripspace.c:36
+#: builtin/stripspace.c:37
 msgid "skip and remove all lines starting with comment character"
 msgstr ""
 "saltar y borrar todas las líneas que comienzan con un carácter de comentario"
 
-#: builtin/stripspace.c:39
+#: builtin/stripspace.c:40
 msgid "prepend comment character and space to each line"
 msgstr "anteponer carácter de comentario y espacio a cada línea"
 
-#: builtin/submodule--helper.c:37 builtin/submodule--helper.c:1688
-#, c-format
-msgid "No such ref: %s"
-msgstr "No existe ref: %s"
-
-#: builtin/submodule--helper.c:44 builtin/submodule--helper.c:1697
+#: builtin/submodule--helper.c:47 builtin/submodule--helper.c:1970
 #, c-format
 msgid "Expecting a full ref name, got %s"
 msgstr "Se esperaba un nombre de ref completo, se obtuvo %s"
 
-#: builtin/submodule--helper.c:61
+#: builtin/submodule--helper.c:64
 msgid "submodule--helper print-default-remote takes no arguments"
 msgstr "subomdule--helper print-default-remote no toma argumentos"
 
-#: builtin/submodule--helper.c:98
+#: builtin/submodule--helper.c:102
 #, c-format
 msgid "cannot strip one component off url '%s'"
 msgstr "no se puede quitar un componente del url '%s'"
 
-#: builtin/submodule--helper.c:406 builtin/submodule--helper.c:1211
+#: builtin/submodule--helper.c:410 builtin/submodule--helper.c:1380
 msgid "alternative anchor for relative paths"
 msgstr "ancho alternativo para rutas relativas"
 
-#: builtin/submodule--helper.c:411
+#: builtin/submodule--helper.c:415
 msgid "git submodule--helper list [--prefix=<path>] [<path>...]"
 msgstr "git submodule--helper list [--prefix=<ruta>] [<ruta>...]"
 
-#: builtin/submodule--helper.c:462 builtin/submodule--helper.c:485
+#: builtin/submodule--helper.c:472 builtin/submodule--helper.c:630
+#: builtin/submodule--helper.c:653
 #, c-format
 msgid "No url found for submodule path '%s' in .gitmodules"
 msgstr "No se encontró url para la ruta del submódulo '%s' en .gitmodules"
 
-#: builtin/submodule--helper.c:500
+#: builtin/submodule--helper.c:524
+#, c-format
+msgid "Entering '%s'\n"
+msgstr "Entrando '%s'\n"
+
+#: builtin/submodule--helper.c:527
+#, c-format
+msgid ""
+"run_command returned non-zero status for %s\n"
+"."
+msgstr ""
+"run_command devolvió estado no-cero para %s\n"
+"."
+
+#: builtin/submodule--helper.c:549
+#, c-format
+msgid ""
+"run_command returned non-zero status while recursing in the nested "
+"submodules of %s\n"
+"."
+msgstr ""
+"run_command devolvió estado no-cero mientras cursaba en los submódulos "
+"anidados de %s\n"
+"."
+
+#: builtin/submodule--helper.c:565
+msgid "Suppress output of entering each submodule command"
+msgstr "Suprime la salida al inicializar cada comando de submódulo"
+
+#: builtin/submodule--helper.c:567 builtin/submodule--helper.c:1053
+msgid "Recurse into nested submodules"
+msgstr "Recursar en submódulos anidados"
+
+#: builtin/submodule--helper.c:572
+msgid "git submodule--helper foreach [--quiet] [--recursive] [--] <command>"
+msgstr "git submodule--helper foreach [--quiet] [--recursive] [--] <comando>"
+
+#: builtin/submodule--helper.c:599
 #, c-format
 msgid ""
-"could not lookup configuration '%s'. Assuming this repository is its own "
+"could not look up configuration '%s'. Assuming this repository is its own "
 "authoritative upstream."
 msgstr ""
 "no se pudo encontrar configuración '%s'. Asumiendo que este repositorio es "
 "su propio upstream autoritativo."
 
-#: builtin/submodule--helper.c:511
+#: builtin/submodule--helper.c:667
 #, c-format
 msgid "Failed to register url for submodule path '%s'"
 msgstr "Falló al registrar el url para la ruta del submódulo '%s'"
 
-#: builtin/submodule--helper.c:515
+#: builtin/submodule--helper.c:671
 #, c-format
 msgid "Submodule '%s' (%s) registered for path '%s'\n"
 msgstr "Submódulo '%s' (%s) registrado para ruta '%s'\n"
 
-#: builtin/submodule--helper.c:525
+#: builtin/submodule--helper.c:681
 #, c-format
 msgid "warning: command update mode suggested for submodule '%s'\n"
 msgstr ""
 "peligro: modo de actualización de comandos sugerido para el submódulo '%s'\n"
 
-#: builtin/submodule--helper.c:532
+#: builtin/submodule--helper.c:688
 #, c-format
 msgid "Failed to register update mode for submodule path '%s'"
 msgstr ""
 "Error al registrar el modo de actualización para la ruta del submódulo '%s'"
 
-#: builtin/submodule--helper.c:554
+#: builtin/submodule--helper.c:710
 msgid "Suppress output for initializing a submodule"
 msgstr "Suprime la salida para inicializar un submódulo"
 
-#: builtin/submodule--helper.c:559
-msgid "git submodule--helper init [<path>]"
-msgstr "git submodule--helper init [<ruta>]"
+#: builtin/submodule--helper.c:715
+msgid "git submodule--helper init [<options>] [<path>]"
+msgstr "git submodule--helper init [<opciones>] [<path>]"
 
-#: builtin/submodule--helper.c:631 builtin/submodule--helper.c:757
+#: builtin/submodule--helper.c:787 builtin/submodule--helper.c:914
 #, c-format
 msgid "no submodule mapping found in .gitmodules for path '%s'"
 msgstr ""
 "no se ha encontrado mapeo de submódulos en .gitmodules para la ruta '%s'"
 
-#: builtin/submodule--helper.c:670
+#: builtin/submodule--helper.c:827
 #, c-format
 msgid "could not resolve HEAD ref inside the submodule '%s'"
 msgstr "no pudo resolver ref de HEAD dentro del submódulo '%s'"
 
-#: builtin/submodule--helper.c:697 builtin/submodule--helper.c:866
+#: builtin/submodule--helper.c:854 builtin/submodule--helper.c:1023
 #, c-format
 msgid "failed to recurse into submodule '%s'"
 msgstr "falló al recursar en el submódulo '%s'"
 
-#: builtin/submodule--helper.c:721 builtin/submodule--helper.c:1031
+#: builtin/submodule--helper.c:878 builtin/submodule--helper.c:1189
 msgid "Suppress submodule status output"
 msgstr "Suprimir output del estado del submódulo"
 
-#: builtin/submodule--helper.c:722
+#: builtin/submodule--helper.c:879
 msgid ""
 "Use commit stored in the index instead of the one stored in the submodule "
 "HEAD"
@@ -14300,60 +20420,56 @@ msgstr ""
 "Usar el commit guardado en el índice en lugar del guardado en el submódulo "
 "HEAD"
 
-#: builtin/submodule--helper.c:723
+#: builtin/submodule--helper.c:880
 msgid "recurse into nested submodules"
 msgstr "recursar en submódulos anidados"
 
-#: builtin/submodule--helper.c:728
+#: builtin/submodule--helper.c:885
 msgid "git submodule status [--quiet] [--cached] [--recursive] [<path>...]"
 msgstr "git submodule status [--quiet] [--cached] [--recursive] [<ruta>...]"
 
-#: builtin/submodule--helper.c:752
+#: builtin/submodule--helper.c:909
 msgid "git submodule--helper name <path>"
 msgstr "git submodule--helper name <ruta>"
 
-#: builtin/submodule--helper.c:816
+#: builtin/submodule--helper.c:973
 #, c-format
 msgid "Synchronizing submodule url for '%s'\n"
 msgstr "Sincronizando url del submódulo para '%s'\n"
 
-#: builtin/submodule--helper.c:822
+#: builtin/submodule--helper.c:979
 #, c-format
 msgid "failed to register url for submodule path '%s'"
 msgstr "falló al registrar el url para la ruta del submódulo '%s'"
 
-#: builtin/submodule--helper.c:836
+#: builtin/submodule--helper.c:993
 #, c-format
 msgid "failed to get the default remote for submodule '%s'"
 msgstr "error al conseguir el remoto por defecto para el submódulo '%s'"
 
-#: builtin/submodule--helper.c:847
+#: builtin/submodule--helper.c:1004
 #, c-format
 msgid "failed to update remote for submodule '%s'"
 msgstr "error al actualizar el remoto para el submódulo '%s'"
 
-#: builtin/submodule--helper.c:895
+#: builtin/submodule--helper.c:1051
 msgid "Suppress output of synchronizing submodule url"
 msgstr "Suprime la salida del url del submódulo que se sincroniza"
 
-#: builtin/submodule--helper.c:897
-msgid "Recurse into nested submodules"
-msgstr "Recursar en submódulos anidados"
-
-#: builtin/submodule--helper.c:902
+#: builtin/submodule--helper.c:1058
 msgid "git submodule--helper sync [--quiet] [--recursive] [<path>]"
 msgstr "git submodule--helper sync [--quiet] [--recursive] [<ruta>]"
 
-#: builtin/submodule--helper.c:956
+#: builtin/submodule--helper.c:1112
 #, c-format
 msgid ""
 "Submodule work tree '%s' contains a .git directory (use 'rm -rf' if you "
 "really want to remove it including all of its history)"
 msgstr ""
 "El árbol de trabajo del submódulo '%s' contiene un directorio .git (use 'rm -"
-"rf' si realmente quiere removerlo incluyendo todo en su historia)"
+"rf' si realmente quieres eliminarlo incluyendo todo en su historia)"
 
-#: builtin/submodule--helper.c:968
+#: builtin/submodule--helper.c:1124
 #, c-format
 msgid ""
 "Submodule work tree '%s' contains local modifications; use '-f' to discard "
@@ -14362,81 +20478,99 @@ msgstr ""
 "El árbol de trabajo del submódulo '%s' contiene modificaciones locales; usa "
 "'-f' para descartarlas"
 
-#: builtin/submodule--helper.c:976
+#: builtin/submodule--helper.c:1132
 #, c-format
 msgid "Cleared directory '%s'\n"
 msgstr "Directorio '%s' limpiado\n"
 
-#: builtin/submodule--helper.c:978
+#: builtin/submodule--helper.c:1134
 #, c-format
 msgid "Could not remove submodule work tree '%s'\n"
 msgstr "No se pudo eliminar el árbol de trabajo del submódulo '%s'\n"
 
-#: builtin/submodule--helper.c:987
+#: builtin/submodule--helper.c:1145
 #, c-format
 msgid "could not create empty submodule directory %s"
 msgstr "no se pudo crear directorio vacío de submódulo %s"
 
-#: builtin/submodule--helper.c:1003
+#: builtin/submodule--helper.c:1161
 #, c-format
 msgid "Submodule '%s' (%s) unregistered for path '%s'\n"
 msgstr "Submódulo '%s' (%s) no registrado para ruta '%s'\n"
 
-#: builtin/submodule--helper.c:1032
+#: builtin/submodule--helper.c:1190
 msgid "Remove submodule working trees even if they contain local changes"
 msgstr ""
-"Remover arboles de trabajo de submódulos incluso si contienen cambios locales"
+"Remover árboles de trabajo de submódulos incluso si contienen cambios locales"
 
-#: builtin/submodule--helper.c:1033
+#: builtin/submodule--helper.c:1191
 msgid "Unregister all submodules"
 msgstr "Quitar todos los submódulos"
 
-#: builtin/submodule--helper.c:1038
+#: builtin/submodule--helper.c:1196
 msgid ""
 "git submodule deinit [--quiet] [-f | --force] [--all | [--] [<path>...]]"
 msgstr ""
 "git submodule deinit [--quiet] [-f | --force] [--all | [--] [<ruta>...]]"
 
-#: builtin/submodule--helper.c:1052
+#: builtin/submodule--helper.c:1210
 msgid "Use '--all' if you really want to deinitialize all submodules"
 msgstr "Usa '--all' si realmente quieres des-inicializar todos los submódulos"
 
-#: builtin/submodule--helper.c:1145 builtin/submodule--helper.c:1148
+#: builtin/submodule--helper.c:1275
+msgid ""
+"An alternate computed from a superproject's alternate is invalid.\n"
+"To allow Git to clone without an alternate in such a case, set\n"
+"submodule.alternateErrorStrategy to 'info' or, equivalently, clone with\n"
+"'--reference-if-able' instead of '--reference'."
+msgstr ""
+"Una alternativa calculada a partir de la alternativa de un superproyecto no "
+"es válida.\n"
+"Para permitir que Git clone sin una alternativa en ese caso, establezca\n"
+"submodule.alternateErrorStrategy a 'info' o, de manera equivalente, clonar "
+"con\n"
+"'--reference-if-able' en lugar de '--reference'."
+
+#: builtin/submodule--helper.c:1314 builtin/submodule--helper.c:1317
 #, c-format
 msgid "submodule '%s' cannot add alternate: %s"
 msgstr "submódulo '%s' no puede agregar alterno: %s"
 
-#: builtin/submodule--helper.c:1184
+#: builtin/submodule--helper.c:1353
 #, c-format
 msgid "Value '%s' for submodule.alternateErrorStrategy is not recognized"
 msgstr "Valor '%s' para submodule.alternateErrorStrategy no es reconocido"
 
-#: builtin/submodule--helper.c:1191
+#: builtin/submodule--helper.c:1360
 #, c-format
 msgid "Value '%s' for submodule.alternateLocation is not recognized"
 msgstr "Valor '%s' para submodule.alternateLocation no es reconocido"
 
-#: builtin/submodule--helper.c:1214
+#: builtin/submodule--helper.c:1383
 msgid "where the new submodule will be cloned to"
 msgstr "a donde el nuevo submódulo será clonado"
 
-#: builtin/submodule--helper.c:1217
+#: builtin/submodule--helper.c:1386
 msgid "name of the new submodule"
 msgstr "nombre del nuevo submódulo"
 
-#: builtin/submodule--helper.c:1220
+#: builtin/submodule--helper.c:1389
 msgid "url where to clone the submodule from"
 msgstr "url de dónde clonar el submódulo"
 
-#: builtin/submodule--helper.c:1228
+#: builtin/submodule--helper.c:1397
 msgid "depth for shallow clones"
 msgstr "profundidad para clones superficiales"
 
-#: builtin/submodule--helper.c:1231 builtin/submodule--helper.c:1606
+#: builtin/submodule--helper.c:1400 builtin/submodule--helper.c:1897
 msgid "force cloning progress"
 msgstr "forzar el proceso de clonado"
 
-#: builtin/submodule--helper.c:1236
+#: builtin/submodule--helper.c:1402 builtin/submodule--helper.c:1899
+msgid "disallow cloning into non-empty directory"
+msgstr "no permitir clonar en directorios no vacíos"
+
+#: builtin/submodule--helper.c:1407
 msgid ""
 "git submodule--helper clone [--prefix=<path>] [--quiet] [--reference "
 "<repository>] [--name <name>] [--depth <depth>] --url <url> --path <path>"
@@ -14445,108 +20579,160 @@ msgstr ""
 "<repositorio>] [--name <nombre>] [--depth <profundidad>] --url <url> --path "
 "<ruta>"
 
-#: builtin/submodule--helper.c:1267
+#: builtin/submodule--helper.c:1431
+#, c-format
+msgid "refusing to create/use '%s' in another submodule's git dir"
+msgstr "rechazando crear/usar '%s' en el directorio de git de otro submódulo"
+
+#: builtin/submodule--helper.c:1442
 #, c-format
 msgid "clone of '%s' into submodule path '%s' failed"
 msgstr "clon de '%s' en la ruta de submódulo '%s' falló"
 
-#: builtin/submodule--helper.c:1281
+#: builtin/submodule--helper.c:1446
+#, c-format
+msgid "directory not empty: '%s'"
+msgstr "directorio no está vacío: '%s'"
+
+#: builtin/submodule--helper.c:1458
 #, c-format
 msgid "could not get submodule directory for '%s'"
 msgstr "no se pudo obtener el directorio de submódulo para '%s'"
 
-#: builtin/submodule--helper.c:1347
+#: builtin/submodule--helper.c:1494
+#, c-format
+msgid "Invalid update mode '%s' for submodule path '%s'"
+msgstr "Modo de actualización inválido '%s' para ruta de submódulo '%s'"
+
+#: builtin/submodule--helper.c:1498
+#, c-format
+msgid "Invalid update mode '%s' configured for submodule path '%s'"
+msgstr ""
+"Modo de actualización inválido '%s' configurado para ruta de submódulo '%s'"
+
+#: builtin/submodule--helper.c:1594
 #, c-format
 msgid "Submodule path '%s' not initialized"
 msgstr "Ruta de submódulo '%s' no inicializada"
 
-#: builtin/submodule--helper.c:1351
+#: builtin/submodule--helper.c:1598
 msgid "Maybe you want to use 'update --init'?"
-msgstr "Tal vez quiere usar 'update --init'?"
+msgstr "¿Tal vez quieres usar 'update --init'?"
 
-#: builtin/submodule--helper.c:1380
+#: builtin/submodule--helper.c:1628
 #, c-format
 msgid "Skipping unmerged submodule %s"
 msgstr "Saltando submódulo %s no fusionado"
 
-#: builtin/submodule--helper.c:1409
+#: builtin/submodule--helper.c:1657
 #, c-format
 msgid "Skipping submodule '%s'"
 msgstr "Saltando submódulo '%s'"
 
-#: builtin/submodule--helper.c:1544
+#: builtin/submodule--helper.c:1803
 #, c-format
 msgid "Failed to clone '%s'. Retry scheduled"
 msgstr "Falló al clonar '%s'. Reintento programado"
 
-#: builtin/submodule--helper.c:1555
+#: builtin/submodule--helper.c:1814
 #, c-format
 msgid "Failed to clone '%s' a second time, aborting"
 msgstr "Falló al clonar '%s' una segunda vez, abortando"
 
-#: builtin/submodule--helper.c:1585 builtin/submodule--helper.c:1808
+#: builtin/submodule--helper.c:1876 builtin/submodule--helper.c:2120
 msgid "path into the working tree"
 msgstr "ruta hacia el árbol de trabajo"
 
-#: builtin/submodule--helper.c:1588
+#: builtin/submodule--helper.c:1879
 msgid "path into the working tree, across nested submodule boundaries"
 msgstr ""
 "ruta hacia el árbol de trabajo, a través de extremos de submódulos anidados"
 
-#: builtin/submodule--helper.c:1592
+#: builtin/submodule--helper.c:1883
 msgid "rebase, merge, checkout or none"
 msgstr "rebase, merge, checkout o none"
 
-#: builtin/submodule--helper.c:1598
+#: builtin/submodule--helper.c:1889
 msgid "Create a shallow clone truncated to the specified number of revisions"
 msgstr "Crea un clon superficial truncado al número especificado de revisión"
 
-#: builtin/submodule--helper.c:1601
+#: builtin/submodule--helper.c:1892
 msgid "parallel jobs"
 msgstr "trabajos paralelos"
 
-#: builtin/submodule--helper.c:1603
+#: builtin/submodule--helper.c:1894
 msgid "whether the initial clone should follow the shallow recommendation"
 msgstr "si el clon inicial debe seguir la recomendación superficial"
 
-#: builtin/submodule--helper.c:1604
+#: builtin/submodule--helper.c:1895
 msgid "don't print cloning progress"
 msgstr "no mostrar el progreso de clonado"
 
-#: builtin/submodule--helper.c:1611
-msgid "git submodule--helper update_clone [--prefix=<path>] [<path>...]"
-msgstr "git submodule--helper update_clone [--prefix=<ruta>] [<ruta>...]"
+#: builtin/submodule--helper.c:1904
+msgid "git submodule--helper update-clone [--prefix=<path>] [<path>...]"
+msgstr "git submodule--helper update-clone [--prefix=<ruta>] [<ruta>...]"
 
-#: builtin/submodule--helper.c:1624
+#: builtin/submodule--helper.c:1917
 msgid "bad value for update parameter"
 msgstr "mal valor para parámetro update"
 
-#: builtin/submodule--helper.c:1692
+#: builtin/submodule--helper.c:1965
 #, c-format
 msgid ""
 "Submodule (%s) branch configured to inherit branch from superproject, but "
 "the superproject is not on any branch"
 msgstr ""
-"Rama de submódulo (%s)  configurada para heredar rama del superproyecto, "
-"pero el superproyecto no está en ninguna rama"
+"Rama de submódulo (%s) configurada para heredar rama del superproyecto, pero "
+"el superproyecto no está en ninguna rama"
 
-#: builtin/submodule--helper.c:1809
+#: builtin/submodule--helper.c:2088
+#, c-format
+msgid "could not get a repository handle for submodule '%s'"
+msgstr "no se pudo conseguir un handle para el submódulo '%s'"
+
+#: builtin/submodule--helper.c:2121
 msgid "recurse into submodules"
 msgstr "recurrir a submódulos"
 
-#: builtin/submodule--helper.c:1815
-msgid "git submodule--helper embed-git-dir [<path>...]"
-msgstr "git submodule--helper embed-git-dir [<ruta>...]"
+#: builtin/submodule--helper.c:2127
+msgid "git submodule--helper absorb-git-dirs [<options>] [<path>...]"
+msgstr "git submodule--helper absorb-git-dirs [<opciones>] [<path>...]"
+
+#: builtin/submodule--helper.c:2183
+msgid "check if it is safe to write to the .gitmodules file"
+msgstr "revisar is es seguro escribir el archivo .gitmodules"
+
+#: builtin/submodule--helper.c:2186
+msgid "unset the config in the .gitmodules file"
+msgstr "desconfigura la opción en elarchivo .gitmodules"
 
-#: builtin/submodule--helper.c:1901
+#: builtin/submodule--helper.c:2191
+msgid "git submodule--helper config <name> [<value>]"
+msgstr "git submodule--helper config <nombre> [<valor>]"
+
+#: builtin/submodule--helper.c:2192
+msgid "git submodule--helper config --unset <name>"
+msgstr "git submodule--helper config --unset <nombre>"
+
+#: builtin/submodule--helper.c:2193
+msgid "git submodule--helper config --check-writeable"
+msgstr "git submodule--helper config --check-writeable"
+
+#: builtin/submodule--helper.c:2212 git-submodule.sh:173
+#, sh-format
+msgid "please make sure that the .gitmodules file is in the working tree"
+msgstr ""
+"por favor asegúrate que el archivo .gitmodules está en el árbol de trabajo"
+
+#: builtin/submodule--helper.c:2262 git.c:433 git.c:684
 #, c-format
 msgid "%s doesn't support --super-prefix"
 msgstr "%s no soporta --super-prefix"
 
-#: builtin/submodule--helper.c:1907
+#: builtin/submodule--helper.c:2268
 #, c-format
 msgid "'%s' is not a valid submodule--helper subcommand"
-msgstr "'%s' no es un comando submodule--helper valido"
+msgstr "'%s' no es un comando submodule--helper válido"
 
 #: builtin/symbolic-ref.c:8
 msgid "git symbolic-ref [<options>] <name> [<ref>]"
@@ -14568,27 +20754,27 @@ msgstr "eliminar referencia simbólica"
 msgid "shorten ref output"
 msgstr "salida de referencia más corta"
 
-#: builtin/symbolic-ref.c:43 builtin/update-ref.c:362
+#: builtin/symbolic-ref.c:43 builtin/update-ref.c:363
 msgid "reason"
 msgstr "razón"
 
-#: builtin/symbolic-ref.c:43 builtin/update-ref.c:362
+#: builtin/symbolic-ref.c:43 builtin/update-ref.c:363
 msgid "reason of the update"
 msgstr "razón de la actualización"
 
-#: builtin/tag.c:24
+#: builtin/tag.c:25
 msgid ""
-"git tag [-a | -s | -u <key-id>] [-f] [-m <msg> | -F <file>] <tagname> "
-"[<head>]"
+"git tag [-a | -s | -u <key-id>] [-f] [-m <msg> | -F <file>]\n"
+"\t\t<tagname> [<head>]"
 msgstr ""
-"git tag [-a | -s | -u <id-de-clave>] [-f] [-m <mensaje> | -F <archivo>] "
-"<nombre-de-tag> [<head>]"
+"git tag [-a | -s | -u <key-id>] [-f] [-m <msg> | -F <archivo>]\n"
+"\t\t<nombre-tag> [<head>]"
 
-#: builtin/tag.c:25
+#: builtin/tag.c:27
 msgid "git tag -d <tagname>..."
 msgstr "git tag -d <nombre-de-tag>..."
 
-#: builtin/tag.c:26
+#: builtin/tag.c:28
 msgid ""
 "git tag -l [-n[<num>]] [--contains <commit>] [--no-contains <commit>] [--"
 "points-at <object>]\n"
@@ -14598,21 +20784,21 @@ msgstr ""
 "points-at <objeto>]\n"
 "\t\t[--format=<formato>] [--[no-]merged [<commit>]] [<patrón>...]"
 
-#: builtin/tag.c:28
+#: builtin/tag.c:30
 msgid "git tag -v [--format=<format>] <tagname>..."
 msgstr "git tag -v [--format=<formato>] <nombre-de-tag>..."
 
-#: builtin/tag.c:86
+#: builtin/tag.c:89
 #, c-format
 msgid "tag '%s' not found."
 msgstr "tag '%s' no encontrado."
 
-#: builtin/tag.c:102
+#: builtin/tag.c:105
 #, c-format
 msgid "Deleted tag '%s' (was %s)\n"
 msgstr "Etiqueta '%s' eliminada (era %s)\n"
 
-#: builtin/tag.c:132
+#: builtin/tag.c:135
 #, c-format
 msgid ""
 "\n"
@@ -14625,7 +20811,7 @@ msgstr ""
 "  %s\n"
 "Las líneas que comienzan con '%c' serán ignoradas.\n"
 
-#: builtin/tag.c:136
+#: builtin/tag.c:139
 #, c-format
 msgid ""
 "\n"
@@ -14640,356 +20826,368 @@ msgstr ""
 "Las líneas que comienzan con '%c' serán conservadas; puedes eliminarlas por "
 "ti mismo si quieres hacerlo.\n"
 
-#: builtin/tag.c:190
+#: builtin/tag.c:198
 msgid "unable to sign the tag"
 msgstr "incapaz de firmar tag"
 
-#: builtin/tag.c:192
+#: builtin/tag.c:200
 msgid "unable to write tag file"
 msgstr "incapaz de escribir el archivo de tag"
 
-#: builtin/tag.c:217
+#: builtin/tag.c:216
+#, c-format
+msgid ""
+"You have created a nested tag. The object referred to by your new tag is\n"
+"already a tag. If you meant to tag the object that it points to, use:\n"
+"\n"
+"\tgit tag -f %s %s^{}"
+msgstr ""
+"Has creado un tag anidado. El objeto referido por el nuevo tag ya\n"
+"es un tag. Si quisiste hacer el tag al objeto que apunta, usa:\n"
+"\n"
+"\tgit tag -f %s %s^{}"
+
+#: builtin/tag.c:232
 msgid "bad object type."
 msgstr "tipo de objeto erróneo."
 
-#: builtin/tag.c:266
+#: builtin/tag.c:284
 msgid "no tag message?"
 msgstr "¿Sin mensaje de tag?"
 
-#: builtin/tag.c:273
+#: builtin/tag.c:291
 #, c-format
 msgid "The tag message has been left in %s\n"
 msgstr "El mensaje del tag ha sido dejado en %s\n"
 
-#: builtin/tag.c:382
+#: builtin/tag.c:402
 msgid "list tag names"
 msgstr "listar nombres de tags"
 
-#: builtin/tag.c:384
+#: builtin/tag.c:404
 msgid "print <n> lines of each tag message"
 msgstr "imprimir <n> líneas de cada mensaje de tag"
 
-#: builtin/tag.c:386
+#: builtin/tag.c:406
 msgid "delete tags"
 msgstr "eliminar tags"
 
-#: builtin/tag.c:387
+#: builtin/tag.c:407
 msgid "verify tags"
 msgstr "verificar tags"
 
-#: builtin/tag.c:389
+#: builtin/tag.c:409
 msgid "Tag creation options"
 msgstr "Opciones de creación de tags"
 
-#: builtin/tag.c:391
+#: builtin/tag.c:411
 msgid "annotated tag, needs a message"
 msgstr "tags anotadas necesitan un mensaje"
 
-#: builtin/tag.c:393
+#: builtin/tag.c:413
 msgid "tag message"
 msgstr "mensaje de tag"
 
-#: builtin/tag.c:395
+#: builtin/tag.c:415
 msgid "force edit of tag message"
 msgstr "forzar la edición del mensaje de tag"
 
-#: builtin/tag.c:396
+#: builtin/tag.c:416
 msgid "annotated and GPG-signed tag"
 msgstr "tag anotado y firmado con GPG"
 
-#: builtin/tag.c:400
+#: builtin/tag.c:419
 msgid "use another key to sign the tag"
 msgstr "usar otra clave para firmar el tag"
 
-#: builtin/tag.c:401
+#: builtin/tag.c:420
 msgid "replace the tag if exists"
 msgstr "remplazar tag si existe"
 
-#: builtin/tag.c:402 builtin/update-ref.c:368
+#: builtin/tag.c:421 builtin/update-ref.c:369
 msgid "create a reflog"
 msgstr "crear un reflog"
 
-#: builtin/tag.c:404
+#: builtin/tag.c:423
 msgid "Tag listing options"
 msgstr "Opciones de listado de tag"
 
-#: builtin/tag.c:405
+#: builtin/tag.c:424
 msgid "show tag list in columns"
 msgstr "mostrar lista de tags en columnas"
 
-#: builtin/tag.c:406 builtin/tag.c:408
+#: builtin/tag.c:425 builtin/tag.c:427
 msgid "print only tags that contain the commit"
 msgstr "mostrar solo tags que contienen el commit"
 
-#: builtin/tag.c:407 builtin/tag.c:409
+#: builtin/tag.c:426 builtin/tag.c:428
 msgid "print only tags that don't contain the commit"
 msgstr "mostrar solo tags que no contienen el commit"
 
-#: builtin/tag.c:410
+#: builtin/tag.c:429
 msgid "print only tags that are merged"
 msgstr "sólo imprimir las tags que están fusionadas"
 
-#: builtin/tag.c:411
+#: builtin/tag.c:430
 msgid "print only tags that are not merged"
 msgstr "sólo imprimir las tags que no están fusionadas"
 
-#: builtin/tag.c:416
+#: builtin/tag.c:434
 msgid "print only tags of the object"
 msgstr "sólo imprimir tags de el objeto"
 
-#: builtin/tag.c:460
+#: builtin/tag.c:482
 msgid "--column and -n are incompatible"
 msgstr "--column y -n son incompatibles"
 
-#: builtin/tag.c:482
+#: builtin/tag.c:504
 msgid "-n option is only allowed in list mode"
 msgstr "opción -n solo es permitida en modo lista"
 
-#: builtin/tag.c:484
+#: builtin/tag.c:506
 msgid "--contains option is only allowed in list mode"
 msgstr "opción --contains solo es permitido en modo lista"
 
-#: builtin/tag.c:486
+#: builtin/tag.c:508
 msgid "--no-contains option is only allowed in list mode"
 msgstr "opción --no-contains solo es permitida en modo lista"
 
-#: builtin/tag.c:488
+#: builtin/tag.c:510
 msgid "--points-at option is only allowed in list mode"
 msgstr "opción --points-at solo es permitida en modo lista"
 
-#: builtin/tag.c:490
+#: builtin/tag.c:512
 msgid "--merged and --no-merged options are only allowed in list mode"
 msgstr "opciones --merged y --no-merged  solo están permitidas en modo lista"
 
-#: builtin/tag.c:501
+#: builtin/tag.c:523
 msgid "only one -F or -m option is allowed."
 msgstr "sólo se permite una de las opciones, -m ó -F."
 
-#: builtin/tag.c:520
+#: builtin/tag.c:542
 msgid "too many params"
 msgstr "demasiados parámetros"
 
-#: builtin/tag.c:526
+#: builtin/tag.c:548
 #, c-format
 msgid "'%s' is not a valid tag name."
 msgstr "'%s' no es un nombre de tag válido."
 
-#: builtin/tag.c:531
+#: builtin/tag.c:553
 #, c-format
 msgid "tag '%s' already exists"
 msgstr "el tag '%s' ya existe"
 
-#: builtin/tag.c:562
+#: builtin/tag.c:584
 #, c-format
 msgid "Updated tag '%s' (was %s)\n"
 msgstr "Etiqueta '%s' actualizada (era %s)\n"
 
-#: builtin/unpack-objects.c:498
+#: builtin/unpack-objects.c:501
 msgid "Unpacking objects"
 msgstr "Desempaquetando objetos"
 
-#: builtin/update-index.c:82
+#: builtin/update-index.c:84
 #, c-format
 msgid "failed to create directory %s"
 msgstr "falló al crear directorio %s"
 
-#: builtin/update-index.c:88
-#, c-format
-msgid "failed to stat %s"
-msgstr "falló al iniciar %s"
-
-#: builtin/update-index.c:98
+#: builtin/update-index.c:100
 #, c-format
 msgid "failed to create file %s"
 msgstr "falló al crear el archivo %s"
 
-#: builtin/update-index.c:106
+#: builtin/update-index.c:108
 #, c-format
 msgid "failed to delete file %s"
 msgstr "falló al eliminar el archivo %s"
 
-#: builtin/update-index.c:113 builtin/update-index.c:219
+#: builtin/update-index.c:115 builtin/update-index.c:221
 #, c-format
 msgid "failed to delete directory %s"
 msgstr "falló al eliminar directorio %s"
 
-#: builtin/update-index.c:138
+#: builtin/update-index.c:140
 #, c-format
 msgid "Testing mtime in '%s' "
 msgstr "Probando mtime en '%s' "
 
-#: builtin/update-index.c:152
+#: builtin/update-index.c:154
 msgid "directory stat info does not change after adding a new file"
 msgstr "info de estado del directorio no cambia tras agregar un nuevo archivo"
 
-#: builtin/update-index.c:165
+#: builtin/update-index.c:167
 msgid "directory stat info does not change after adding a new directory"
 msgstr ""
 "info de estado del directorio no cambia tras agregar un nuevo directorio"
 
-#: builtin/update-index.c:178
+#: builtin/update-index.c:180
 msgid "directory stat info changes after updating a file"
 msgstr "info de estado del directorio cambia tras actualizar un archivo"
 
-#: builtin/update-index.c:189
+#: builtin/update-index.c:191
 msgid "directory stat info changes after adding a file inside subdirectory"
 msgstr ""
 "info de estado del directorio cambia tras agregar un archivo dentro del "
 "subdirectorio"
 
-#: builtin/update-index.c:200
+#: builtin/update-index.c:202
 msgid "directory stat info does not change after deleting a file"
 msgstr "info de estado del directorio no cambia tras borrar un archivo"
 
-#: builtin/update-index.c:213
+#: builtin/update-index.c:215
 msgid "directory stat info does not change after deleting a directory"
 msgstr "info de estado del directorio no cambia tras borrar un directorio"
 
-#: builtin/update-index.c:220
+#: builtin/update-index.c:222
 msgid " OK"
 msgstr " OK"
 
-#: builtin/update-index.c:589
+#: builtin/update-index.c:591
 msgid "git update-index [<options>] [--] [<file>...]"
 msgstr "git update-index [<opciones>] [--] [<archivo>...]"
 
-#: builtin/update-index.c:946
+#: builtin/update-index.c:974
 msgid "continue refresh even when index needs update"
 msgstr ""
 "continuar refresh (Actualización) incluso cuando el índice necesita "
 "actualización"
 
-#: builtin/update-index.c:949
+#: builtin/update-index.c:977
 msgid "refresh: ignore submodules"
 msgstr "refresh: ignora submódulos"
 
-#: builtin/update-index.c:952
+#: builtin/update-index.c:980
 msgid "do not ignore new files"
 msgstr "no ignorar archivos nuevos"
 
-#: builtin/update-index.c:954
+#: builtin/update-index.c:982
 msgid "let files replace directories and vice-versa"
 msgstr "permitir que archivos remplacen directorios y vice-versa"
 
-#: builtin/update-index.c:956
+#: builtin/update-index.c:984
 msgid "notice files missing from worktree"
 msgstr "avisar de archivos faltando en el árbol de trabajo"
 
-#: builtin/update-index.c:958
+#: builtin/update-index.c:986
 msgid "refresh even if index contains unmerged entries"
 msgstr "ejecutar refresh incluso si el índice contiene entradas sin cambios"
 
-#: builtin/update-index.c:961
+#: builtin/update-index.c:989
 msgid "refresh stat information"
 msgstr "refresh información de estado"
 
-#: builtin/update-index.c:965
+#: builtin/update-index.c:993
 msgid "like --refresh, but ignore assume-unchanged setting"
 msgstr "como --refresh, pero ignora configuración assume-unchanged"
 
-#: builtin/update-index.c:969
+#: builtin/update-index.c:997
 msgid "<mode>,<object>,<path>"
 msgstr "<modo>,<objeto>,<ruta>"
 
-#: builtin/update-index.c:970
+#: builtin/update-index.c:998
 msgid "add the specified entry to the index"
 msgstr "agregar la entrada especificada al índice"
 
-#: builtin/update-index.c:979
+#: builtin/update-index.c:1008
 msgid "mark files as \"not changing\""
 msgstr "marcar archivos como \"not changing\""
 
-#: builtin/update-index.c:982
+#: builtin/update-index.c:1011
 msgid "clear assumed-unchanged bit"
 msgstr "limpiar bit assumed-unchanged"
 
-#: builtin/update-index.c:985
+#: builtin/update-index.c:1014
 msgid "mark files as \"index-only\""
 msgstr "marcar archivos como \"index-only\""
 
-#: builtin/update-index.c:988
+#: builtin/update-index.c:1017
 msgid "clear skip-worktree bit"
 msgstr "limpiar bit skip-worktree"
 
-#: builtin/update-index.c:991
+#: builtin/update-index.c:1020
+msgid "do not touch index-only entries"
+msgstr "no tocar entradas index-only"
+
+#: builtin/update-index.c:1022
 msgid "add to index only; do not add content to object database"
 msgstr ""
 "agregar solo al índice; no agregar contenido a la base de datos de objetos"
 
-#: builtin/update-index.c:993
+#: builtin/update-index.c:1024
 msgid "remove named paths even if present in worktree"
 msgstr ""
-"remover rutas nombradas incluso si están presentes en el árbol de trabajo"
+"eliminar rutas nombradas incluso si están presentes en el árbol de trabajo"
 
-#: builtin/update-index.c:995
+#: builtin/update-index.c:1026
 msgid "with --stdin: input lines are terminated by null bytes"
-msgstr "con --stdin: las lineas de entrada son terminadas con bytes nulos"
+msgstr "con --stdin: las líneas de entrada son terminadas con bytes nulos"
 
-#: builtin/update-index.c:997
+#: builtin/update-index.c:1028
 msgid "read list of paths to be updated from standard input"
 msgstr "leer la lista de rutas para ser actualizada desde standard input"
 
-#: builtin/update-index.c:1001
+#: builtin/update-index.c:1032
 msgid "add entries from standard input to the index"
 msgstr "agregar entradas de standard input al índice"
 
-#: builtin/update-index.c:1005
+#: builtin/update-index.c:1036
 msgid "repopulate stages #2 and #3 for the listed paths"
 msgstr "repoblar stages #2 y #3 para las rutas listadas"
 
-#: builtin/update-index.c:1009
+#: builtin/update-index.c:1040
 msgid "only update entries that differ from HEAD"
 msgstr "solo actualizar entradas que difieren de HEAD"
 
-#: builtin/update-index.c:1013
+#: builtin/update-index.c:1044
 msgid "ignore files missing from worktree"
 msgstr "ignorar archivos faltantes en el árbol de trabajo"
 
-#: builtin/update-index.c:1016
+#: builtin/update-index.c:1047
 msgid "report actions to standard output"
 msgstr "reportar acciones por standard output"
 
-#: builtin/update-index.c:1018
+#: builtin/update-index.c:1049
 msgid "(for porcelains) forget saved unresolved conflicts"
 msgstr "(para porcelanas) olvidar conflictos sin resolver guardados"
 
-#: builtin/update-index.c:1022
+#: builtin/update-index.c:1053
 msgid "write index in this format"
 msgstr "escribir índice en este formato"
 
-#: builtin/update-index.c:1024
+#: builtin/update-index.c:1055
 msgid "enable or disable split index"
 msgstr "activar o desactivar índice dividido"
 
-#: builtin/update-index.c:1026
+#: builtin/update-index.c:1057
 msgid "enable/disable untracked cache"
 msgstr "habilitar o deshabilitar caché no rastreado"
 
-#: builtin/update-index.c:1028
+#: builtin/update-index.c:1059
 msgid "test if the filesystem supports untracked cache"
 msgstr "probar si el filesystem soporta caché no rastreado"
 
-#: builtin/update-index.c:1030
+#: builtin/update-index.c:1061
 msgid "enable untracked cache without testing the filesystem"
 msgstr "habilitar caché no rastreado sin probar el filesystem"
 
-#: builtin/update-index.c:1032
+#: builtin/update-index.c:1063
 msgid "write out the index even if is not flagged as changed"
 msgstr "escribir el índice incluso si no está marcado como cambiado"
 
-#: builtin/update-index.c:1034
+#: builtin/update-index.c:1065
 msgid "enable or disable file system monitor"
 msgstr "activar o desactivar monitor de sistema de archivos"
 
-#: builtin/update-index.c:1036
+#: builtin/update-index.c:1067
 msgid "mark files as fsmonitor valid"
 msgstr "marcar archivos como válidos para fsmonitor"
 
-#: builtin/update-index.c:1039
+#: builtin/update-index.c:1070
 msgid "clear fsmonitor valid bit"
 msgstr "limpia el bit de validación fsmonitor"
 
-#: builtin/update-index.c:1138
+#: builtin/update-index.c:1173
 msgid ""
 "core.splitIndex is set to false; remove or change it, if you really want to "
 "enable split index"
@@ -14997,7 +21195,7 @@ msgstr ""
 "core.splitIndex está configurado en false; remuévelo o cámbialo, si "
 "realmente quieres habilitar el índice partido"
 
-#: builtin/update-index.c:1147
+#: builtin/update-index.c:1182
 msgid ""
 "core.splitIndex is set to true; remove or change it, if you really want to "
 "disable split index"
@@ -15005,7 +21203,7 @@ msgstr ""
 "core.splitIndex está configurado en true; remuévelo o cámbialo, si realmente "
 "quieres deshabilitar el índice partido"
 
-#: builtin/update-index.c:1158
+#: builtin/update-index.c:1194
 msgid ""
 "core.untrackedCache is set to true; remove or change it, if you really want "
 "to disable the untracked cache"
@@ -15013,11 +21211,11 @@ msgstr ""
 "core.untrackedCache está configurado en true; remuévelo o cámbialo, si "
 "realmente quieres deshabilitar el chaché no rastreado"
 
-#: builtin/update-index.c:1162
+#: builtin/update-index.c:1198
 msgid "Untracked cache disabled"
 msgstr "Caché no rastreado deshabilitado"
 
-#: builtin/update-index.c:1170
+#: builtin/update-index.c:1206
 msgid ""
 "core.untrackedCache is set to false; remove or change it, if you really want "
 "to enable the untracked cache"
@@ -15025,29 +21223,29 @@ msgstr ""
 "core.untrackedCache está configurado en false; remuévelo o cámbialo, si "
 "realmente quieres habilitar el caché no rastreado"
 
-#: builtin/update-index.c:1174
+#: builtin/update-index.c:1210
 #, c-format
 msgid "Untracked cache enabled for '%s'"
 msgstr "Caché no rastreado habilitado para '%s'"
 
-#: builtin/update-index.c:1182
+#: builtin/update-index.c:1218
 msgid "core.fsmonitor is unset; set it if you really want to enable fsmonitor"
 msgstr ""
 "core.fsmonitor no está configurado; actívalo si realmente quieres habilitar "
 "fsmonitor"
 
-#: builtin/update-index.c:1186
+#: builtin/update-index.c:1222
 msgid "fsmonitor enabled"
 msgstr "fsmonitor activado"
 
-#: builtin/update-index.c:1189
+#: builtin/update-index.c:1225
 msgid ""
 "core.fsmonitor is set; remove it if you really want to disable fsmonitor"
 msgstr ""
 "core.fsmonitor está configurado; remuévelo si realmente quieres deshabilitar "
 "el fsmonitor"
 
-#: builtin/update-index.c:1193
+#: builtin/update-index.c:1229
 msgid "fsmonitor disabled"
 msgstr "fsmonitor desactivado"
 
@@ -15065,19 +21263,19 @@ msgstr ""
 msgid "git update-ref [<options>] --stdin [-z]"
 msgstr "git update-ref [<opciones>] --stdin [-z]"
 
-#: builtin/update-ref.c:363
+#: builtin/update-ref.c:364
 msgid "delete the reference"
 msgstr "eliminar la referencia"
 
-#: builtin/update-ref.c:365
+#: builtin/update-ref.c:366
 msgid "update <refname> not the one it points to"
 msgstr "actualiza <refname> no a lo que apunta"
 
-#: builtin/update-ref.c:366
+#: builtin/update-ref.c:367
 msgid "stdin has NUL-terminated arguments"
 msgstr "stdin tiene argumentos terminados en NUL"
 
-#: builtin/update-ref.c:367
+#: builtin/update-ref.c:368
 msgid "read updates from stdin"
 msgstr "lee actualizaciones de stdin"
 
@@ -15093,6 +21291,10 @@ msgstr "actualiza los archivos info desd
 msgid "git upload-pack [<options>] <dir>"
 msgstr "git upload-pack [<opciones>] <directorio>"
 
+#: builtin/upload-pack.c:23 t/helper/test-serve-v2.c:17
+msgid "quit after a single request/response exchange"
+msgstr "sale después de un intercambio petición/respuesta único"
+
 #: builtin/upload-pack.c:25
 msgid "exit immediately after initial ref advertisement"
 msgstr "salir inmediatamente tras el anuncio inicial de ref"
@@ -15105,15 +21307,15 @@ msgstr "no intente <directorio>/.git/ si
 msgid "interrupt transfer after <n> seconds of inactivity"
 msgstr "interrumpir transferencia tras <n> segundos de inactividad"
 
-#: builtin/verify-commit.c:18
+#: builtin/verify-commit.c:19
 msgid "git verify-commit [-v | --verbose] <commit>..."
 msgstr "git verify-commit [-v | --verbose] <commit>..."
 
-#: builtin/verify-commit.c:73
+#: builtin/verify-commit.c:68
 msgid "print commit contents"
 msgstr "imprimir contenido del commit"
 
-#: builtin/verify-commit.c:74 builtin/verify-tag.c:38
+#: builtin/verify-commit.c:69 builtin/verify-tag.c:37
 msgid "print raw gpg status output"
 msgstr "muestra la salida de status gpg en formato raw"
 
@@ -15129,11 +21331,11 @@ msgstr "verboso"
 msgid "show statistics only"
 msgstr "solo mostrar estadísticas"
 
-#: builtin/verify-tag.c:19
+#: builtin/verify-tag.c:18
 msgid "git verify-tag [-v | --verbose] [--format=<format>] <tag>..."
 msgstr "git verify-tag [-v | --verbose] [--format=<formato>] <tag>..."
 
-#: builtin/verify-tag.c:37
+#: builtin/verify-tag.c:36
 msgid "print tag contents"
 msgstr "imprimir contenido del tag"
 
@@ -15165,22 +21367,27 @@ msgstr "git worktree remove [<opciones>]
 msgid "git worktree unlock <path>"
 msgstr "git worktree unlock <ruta>"
 
-#: builtin/worktree.c:58
+#: builtin/worktree.c:60 builtin/worktree.c:898
+#, c-format
+msgid "failed to delete '%s'"
+msgstr "falló al borrar '%s'"
+
+#: builtin/worktree.c:79
 #, c-format
 msgid "Removing worktrees/%s: not a valid directory"
 msgstr "Removiendo el worktrees/%s: no es un directorio válido"
 
-#: builtin/worktree.c:64
+#: builtin/worktree.c:85
 #, c-format
 msgid "Removing worktrees/%s: gitdir file does not exist"
 msgstr "Removiendo worktrees/%s: archivo gitdir no existe"
 
-#: builtin/worktree.c:69 builtin/worktree.c:78
+#: builtin/worktree.c:90 builtin/worktree.c:99
 #, c-format
 msgid "Removing worktrees/%s: unable to read gitdir file (%s)"
 msgstr "Removiendo worktrees/%s: no es posible leer el archivo gitdir (%s)"
 
-#: builtin/worktree.c:88
+#: builtin/worktree.c:109
 #, c-format
 msgid ""
 "Removing worktrees/%s: short read (expected %<PRIuMAX> bytes, read "
@@ -15189,211 +21396,249 @@ msgstr ""
 "Removiendo árboles de trabajo/%s: lectura corta (se esperan %<PRIuMAX> "
 "bytes, %<PRIuMAX> leídos)"
 
-#: builtin/worktree.c:96
+#: builtin/worktree.c:117
 #, c-format
 msgid "Removing worktrees/%s: invalid gitdir file"
 msgstr "Removiendo worktrees/%s: archivo gitdir inválido"
 
-#: builtin/worktree.c:105
+#: builtin/worktree.c:126
 #, c-format
 msgid "Removing worktrees/%s: gitdir file points to non-existent location"
 msgstr ""
 "Removiendo worktrees/%s: archivo gitdir apunta a una ubicación no existente"
 
-#: builtin/worktree.c:152
+#: builtin/worktree.c:165
 msgid "report pruned working trees"
 msgstr "reporta árboles de trabajo recortados"
 
-#: builtin/worktree.c:154
+#: builtin/worktree.c:167
 msgid "expire working trees older than <time>"
 msgstr "expirar árboles de trabajo más viejos a <tiempo>"
 
-#: builtin/worktree.c:229
+#: builtin/worktree.c:234
 #, c-format
 msgid "'%s' already exists"
 msgstr "'%s' ya existe"
 
-#: builtin/worktree.c:260
+#: builtin/worktree.c:251
+#, c-format
+msgid "unable to re-add worktree '%s'"
+msgstr "no es posible volver a agregar el árbol '%s'"
+
+#: builtin/worktree.c:256
+#, c-format
+msgid ""
+"'%s' is a missing but locked worktree;\n"
+"use 'add -f -f' to override, or 'unlock' and 'prune' or 'remove' to clear"
+msgstr ""
+"'%s' es un árbol de trabajo faltante pero bloqueado;\n"
+"usa 'add -f -f' para sobreescribir, o 'unlock' y 'prune' o 'remove' para "
+"limpiar"
+
+#: builtin/worktree.c:258
+#, c-format
+msgid ""
+"'%s' is a missing but already registered worktree;\n"
+"use 'add -f' to override, or 'prune' or 'remove' to clear"
+msgstr ""
+"'%s' es un árbol de trabajo faltante pero ya registrado;\n"
+"usa 'add -f' para sobreescribir, o 'prune' o 'remove' para limpiar"
+
+#: builtin/worktree.c:308
 #, c-format
 msgid "could not create directory of '%s'"
 msgstr "no se pudo crear directorio de '%s'"
 
-#: builtin/worktree.c:373 builtin/worktree.c:379
+#: builtin/worktree.c:439 builtin/worktree.c:445
 #, c-format
 msgid "Preparing worktree (new branch '%s')"
 msgstr "Preparando árbol de trabajo (nueva rama '%s')"
 
-#: builtin/worktree.c:375
+#: builtin/worktree.c:441
 #, c-format
 msgid "Preparing worktree (resetting branch '%s'; was at %s)"
 msgstr "Preparando árbol de trabajo (reiniciando rama '%s'; estaba en %s)"
 
-#: builtin/worktree.c:384
+#: builtin/worktree.c:450
 #, c-format
 msgid "Preparing worktree (checking out '%s')"
 msgstr "Preparando árbol de trabajo (haciendo checkout a '%s')"
 
-#: builtin/worktree.c:390
+#: builtin/worktree.c:456
 #, c-format
 msgid "Preparing worktree (detached HEAD %s)"
 msgstr "Preparando árbol de trabajo (HEAD desacoplado %s)"
 
-#: builtin/worktree.c:431
+#: builtin/worktree.c:497
 msgid "checkout <branch> even if already checked out in other worktree"
 msgstr ""
 "hacer checkout a <rama> incluso si ya ha hecho checkout en otro árbol de "
 "trabajo"
 
-#: builtin/worktree.c:434
+#: builtin/worktree.c:500
 msgid "create a new branch"
 msgstr "crear una nueva rama"
 
-#: builtin/worktree.c:436
+#: builtin/worktree.c:502
 msgid "create or reset a branch"
 msgstr "crear o restablecer una rama"
 
-#: builtin/worktree.c:438
+#: builtin/worktree.c:504
 msgid "populate the new working tree"
 msgstr "popular el nuevo árbol de trabajo"
 
-#: builtin/worktree.c:439
+#: builtin/worktree.c:505
 msgid "keep the new working tree locked"
 msgstr "mantener el nuevo árbol de trabajo bloqueado"
 
-#: builtin/worktree.c:441
+#: builtin/worktree.c:508
 msgid "set up tracking mode (see git-branch(1))"
 msgstr "configurando modo tracking (mirar git-branch(1))"
 
-#: builtin/worktree.c:444
+#: builtin/worktree.c:511
 msgid "try to match the new branch name with a remote-tracking branch"
 msgstr ""
 "intentar emparejar el nuevo nombre de rama con una rama de rastreo remoto"
 
-#: builtin/worktree.c:452
+#: builtin/worktree.c:519
 msgid "-b, -B, and --detach are mutually exclusive"
 msgstr "-b, -B, y --detach son mutuamente exclusivas"
 
-#: builtin/worktree.c:511
+#: builtin/worktree.c:580
 msgid "--[no-]track can only be used if a new branch is created"
 msgstr "--[no-]track solo puede ser usado si una nueva rama es creada"
 
-#: builtin/worktree.c:611
+#: builtin/worktree.c:680
 msgid "reason for locking"
 msgstr "razón para bloquear"
 
-#: builtin/worktree.c:623 builtin/worktree.c:656 builtin/worktree.c:710
-#: builtin/worktree.c:850
+#: builtin/worktree.c:692 builtin/worktree.c:725 builtin/worktree.c:799
+#: builtin/worktree.c:926
 #, c-format
 msgid "'%s' is not a working tree"
 msgstr "'%s' no es un árbol de trabajo"
 
-#: builtin/worktree.c:625 builtin/worktree.c:658
+#: builtin/worktree.c:694 builtin/worktree.c:727
 msgid "The main working tree cannot be locked or unlocked"
 msgstr "El árbol de trabajo principal no puede ser bloqueado ni desbloqueado"
 
-#: builtin/worktree.c:630
+#: builtin/worktree.c:699
 #, c-format
 msgid "'%s' is already locked, reason: %s"
 msgstr "'%s' ya está bloqueado; razón: %s"
 
-#: builtin/worktree.c:632
+#: builtin/worktree.c:701
 #, c-format
 msgid "'%s' is already locked"
 msgstr "'%s' ya está bloqueado"
 
-#: builtin/worktree.c:660
+#: builtin/worktree.c:729
 #, c-format
 msgid "'%s' is not locked"
 msgstr "'%s' no está bloqueado"
 
-#: builtin/worktree.c:685
+#: builtin/worktree.c:770
 msgid "working trees containing submodules cannot be moved or removed"
 msgstr ""
-"árboles de trabajo conteniendo submódulos no puede ser movidos o removidos"
+"árboles de trabajo conteniendo submódulos no puede ser movidos o eliminado"
 
-#: builtin/worktree.c:712 builtin/worktree.c:852
+#: builtin/worktree.c:778
+msgid "force move even if worktree is dirty or locked"
+msgstr "forzar move incluso si el árbol de trabajo está sucio o bloqueado"
+
+#: builtin/worktree.c:801 builtin/worktree.c:928
 #, c-format
 msgid "'%s' is a main working tree"
 msgstr "'%s' es un árbol de trabajo principal"
 
-#: builtin/worktree.c:717
+#: builtin/worktree.c:806
 #, c-format
 msgid "could not figure out destination name from '%s'"
 msgstr "no se pudo descubrir el nombre de destino de '%s'"
 
-#: builtin/worktree.c:723
+#: builtin/worktree.c:812
 #, c-format
 msgid "target '%s' already exists"
 msgstr "el objetivo '%s' ya existe"
 
-#: builtin/worktree.c:730
+#: builtin/worktree.c:820
 #, c-format
-msgid "cannot move a locked working tree, lock reason: %s"
+msgid ""
+"cannot move a locked working tree, lock reason: %s\n"
+"use 'move -f -f' to override or unlock first"
 msgstr ""
-"no se puede mover un árbol de trabajo encerrado, motivo del encierro: %s"
+"no se puede mover un árbol de trabajo bloqueado, motivo del bloqueo: %s\n"
+"use 'move -f -f' para sobreescribir o desbloquear primero"
 
-#: builtin/worktree.c:732
-msgid "cannot move a locked working tree"
-msgstr "no se puede mover un árbol de trabajo encerrado"
+#: builtin/worktree.c:822
+msgid ""
+"cannot move a locked working tree;\n"
+"use 'move -f -f' to override or unlock first"
+msgstr ""
+"no se puede mover un árbol de trabajo bloqueado;\n"
+"use 'move -f -f' para sobreescribir o desbloquear primero"
 
-#: builtin/worktree.c:735
+#: builtin/worktree.c:825
 #, c-format
 msgid "validation failed, cannot move working tree: %s"
 msgstr "falló validación, no se puede mover el árbol de trabajo: %s"
 
-#: builtin/worktree.c:740
+#: builtin/worktree.c:830
 #, c-format
 msgid "failed to move '%s' to '%s'"
 msgstr "falló al mover '%s' a '%s'"
 
-#: builtin/worktree.c:788
+#: builtin/worktree.c:878
 #, c-format
 msgid "failed to run 'git status' on '%s'"
 msgstr "falló al ejecutar 'git status' en '%s'"
 
-#: builtin/worktree.c:792
+#: builtin/worktree.c:882
 #, c-format
-msgid "'%s' is dirty, use --force to delete it"
-msgstr "'%s' está sucio, use --force para borrarlo"
-
-#: builtin/worktree.c:797
-#, c-format
-msgid "failed to run 'git status' on '%s', code %d"
-msgstr "no se pudo ejecutar 'git status' en '%s', código %d"
+msgid "'%s' contains modified or untracked files, use --force to delete it"
+msgstr ""
+"'%s' contiene archivos no rastreados o modificados, use --force para borrarlo"
 
-#: builtin/worktree.c:808 builtin/worktree.c:822
-#, c-format
-msgid "failed to delete '%s'"
-msgstr "falló al borrar '%s'"
+#: builtin/worktree.c:887
+#, c-format
+msgid "failed to run 'git status' on '%s', code %d"
+msgstr "no se pudo ejecutar 'git status' en '%s', código %d"
 
-#: builtin/worktree.c:834
-msgid "force removing even if the worktree is dirty"
-msgstr "forzar remoción incluso si el árbol de trabajo está sucio"
+#: builtin/worktree.c:910
+msgid "force removal even if worktree is dirty or locked"
+msgstr "forzar remoción incluso si el árbol de trabajo está sucio o bloqueado"
 
-#: builtin/worktree.c:856
+#: builtin/worktree.c:933
 #, c-format
-msgid "cannot remove a locked working tree, lock reason: %s"
+msgid ""
+"cannot remove a locked working tree, lock reason: %s\n"
+"use 'remove -f -f' to override or unlock first"
 msgstr ""
-"no se pueden remover árbol de trabajo encerrado, razón del encierro: %s"
+"no se pueden eliminar árbol de trabajo bloqueado, razón del bloqueo: %s\n"
+"use 'remove -f -f' para sobreescribir o desbloquear primero"
 
-#: builtin/worktree.c:858
-msgid "cannot remove a locked working tree"
-msgstr "no se puede remover árbol de trabajo encerrado"
+#: builtin/worktree.c:935
+msgid ""
+"cannot remove a locked working tree;\n"
+"use 'remove -f -f' to override or unlock first"
+msgstr ""
+"no se pueden eliminar árbol de trabajo bloqueado;\n"
+"use 'remove -f -f' para sobreescribir o desbloquear primero"
 
-#: builtin/worktree.c:861
+#: builtin/worktree.c:938
 #, c-format
 msgid "validation failed, cannot remove working tree: %s"
-msgstr "falló validación, no se puede remover árbol de trabajo: %s"
+msgstr "falló validación, no se puede eliminar árbol de trabajo: %s"
 
-#: builtin/write-tree.c:14
+#: builtin/write-tree.c:15
 msgid "git write-tree [--missing-ok] [--prefix=<prefix>/]"
 msgstr "git write-tree [--missing-ok] [--prefix=<prefijo>/]"
 
-#: builtin/write-tree.c:27
+#: builtin/write-tree.c:28
 msgid "<prefix>/"
 msgstr "<prefijo>/"
 
-#: builtin/write-tree.c:28
+#: builtin/write-tree.c:29
 msgid "write tree object for a subdirectory <prefix>"
 msgstr "escribir objeto de  árbol para un subdirectorio <prefijo>"
 
@@ -15401,7 +21646,22 @@ msgstr "escribir objeto de  árbol para
 msgid "only useful for debugging"
 msgstr "sólo útil para depurar"
 
-#: credential-cache--daemon.c:222
+#: fast-import.c:3125
+#, c-format
+msgid "Expected 'mark' command, got %s"
+msgstr "Se esperaba comando 'mark', se obtuvo %s"
+
+#: fast-import.c:3130
+#, c-format
+msgid "Expected 'to' command, got %s"
+msgstr "Se esperaba comando 'to', se obtuvo %s"
+
+#: fast-import.c:3254
+#, c-format
+msgid "feature '%s' forbidden in input without --allow-unsafe-features"
+msgstr "característica '%s' prohibida en input sin --allow-unsafe-features"
+
+#: credential-cache--daemon.c:223
 #, c-format
 msgid ""
 "The permissions on your socket directory are too loose; other\n"
@@ -15409,16 +21669,33 @@ msgid ""
 "\n"
 "\tchmod 0700 %s"
 msgstr ""
-"Los permisos en su directorio de socket son demasiado flojos; otros\n"
-"usuarios pueden leer sus credenciales almacenadas en caché. Considere "
+"Los permisos en tu directorio de socket son demasiado flojos; otros\n"
+"usuarios pueden leer sus credenciales almacenadas en caché. Considera "
 "ejecutar:\n"
 "\n"
 "\tchmod 0700 %s"
 
-#: credential-cache--daemon.c:271
+#: credential-cache--daemon.c:272
 msgid "print debugging messages to stderr"
 msgstr "mostrar mensajes de debug en stderr"
 
+#: t/helper/test-reach.c:152
+#, c-format
+msgid "commit %s is not marked reachable"
+msgstr "commit %s no está marcado como alcanzable"
+
+#: t/helper/test-reach.c:162
+msgid "too many commits marked reachable"
+msgstr "demasiados commits marcados como alcanzables"
+
+#: t/helper/test-serve-v2.c:7
+msgid "test-tool serve-v2 [<options>]"
+msgstr "test-tool serve-v2 [<opciones>]"
+
+#: t/helper/test-serve-v2.c:19
+msgid "exit immediately after advertising capabilities"
+msgstr "salir inmediatamente tras anunciar capacidades"
+
 #: git.c:27
 msgid ""
 "git [--version] [--help] [-C <path>] [-c <name>=<value>]\n"
@@ -15439,71 +21716,155 @@ msgstr ""
 msgid ""
 "'git help -a' and 'git help -g' list available subcommands and some\n"
 "concept guides. See 'git help <command>' or 'git help <concept>'\n"
-"to read about a specific subcommand or concept."
+"to read about a specific subcommand or concept.\n"
+"See 'git help git' for an overview of the system."
 msgstr ""
 "'git help -a' y 'git help -g' listan los subcomandos disponibles y algunas\n"
 "guías de concepto. Consulte 'git help <command>' o 'git help <concepto>'\n"
-"para leer sobre un subcomando o concepto específico."
+"para leer sobre un subcomando o concepto específico.\n"
+"Mira 'git help git' para una vista general del sistema."
 
-#: git.c:173
+#: git.c:186
 #, c-format
 msgid "no directory given for --git-dir\n"
 msgstr "no se entregó directorio para --git-dir\n"
 
-#: git.c:187
+#: git.c:200
 #, c-format
 msgid "no namespace given for --namespace\n"
 msgstr "no se entregó namespace para --namespace\n"
 
-#: git.c:201
+#: git.c:214
 #, c-format
 msgid "no directory given for --work-tree\n"
 msgstr "no se entregó directorio para --work-tree\n"
 
-#: git.c:215
+#: git.c:228
 #, c-format
 msgid "no prefix given for --super-prefix\n"
 msgstr "no se entregó prefijo para --super-prefix\n"
 
-#: git.c:237
+#: git.c:250
 #, c-format
 msgid "-c expects a configuration string\n"
 msgstr "-c espera un string de configuración\n"
 
-#: git.c:275
+#: git.c:288
 #, c-format
 msgid "no directory given for -C\n"
 msgstr "no se entregó directorio para -C\n"
 
-#: git.c:300
+#: git.c:314
 #, c-format
 msgid "unknown option: %s\n"
 msgstr "opción %s desconocida\n"
 
-#: git.c:765
+#: git.c:360
+#, c-format
+msgid "while expanding alias '%s': '%s'"
+msgstr "al expandir el alias '%s':'%s'"
+
+#: git.c:369
+#, c-format
+msgid ""
+"alias '%s' changes environment variables.\n"
+"You can use '!git' in the alias to do this"
+msgstr ""
+"alias '%s' cambia las variables de entorno.\n"
+"Puedes usar '!git' en el alias para hacer esto"
+
+#: git.c:376
+#, c-format
+msgid "empty alias for %s"
+msgstr "alias vacío para %s"
+
+#: git.c:379
+#, c-format
+msgid "recursive alias: %s"
+msgstr "alias recursivo: %s"
+
+#: git.c:459
+msgid "write failure on standard output"
+msgstr "error de escritura en standard output"
+
+#: git.c:461
+msgid "unknown write failure on standard output"
+msgstr "error desconocido de escritura en standard output"
+
+#: git.c:463
+msgid "close failed on standard output"
+msgstr "cierre falló en standard output"
+
+#: git.c:793
+#, c-format
+msgid "alias loop detected: expansion of '%s' does not terminate:%s"
+msgstr "bucle de alias detectado: expansión de '%s' no termina: %s"
+
+#: git.c:843
+#, c-format
+msgid "cannot handle %s as a builtin"
+msgstr "no se puede manejar %s como un builtin"
+
+#: git.c:856
+#, c-format
+msgid ""
+"usage: %s\n"
+"\n"
+msgstr ""
+"uso: %s\n"
+"\n"
+"\n"
+"\n"
+
+#: git.c:876
 #, c-format
 msgid "expansion of alias '%s' failed; '%s' is not a git command\n"
 msgstr "expansión del alias '%s' falló; '%s' no es un comando de git\n"
 
-#: git.c:777
+#: git.c:888
 #, c-format
 msgid "failed to run command '%s': %s\n"
 msgstr "falló al ejecutar comando '%s': %s\n"
 
-#: http.c:348
+#: http.c:378
 #, c-format
 msgid "negative value for http.postbuffer; defaulting to %d"
 msgstr "valor negativo para http.postbuffer; poniendo el default a %d"
 
-#: http.c:369
+#: http.c:399
 msgid "Delegation control is not supported with cURL < 7.22.0"
 msgstr "Delegación de control no es soportada con cURL < 7.22.0"
 
-#: http.c:378
+#: http.c:408
 msgid "Public key pinning not supported with cURL < 7.44.0"
 msgstr "Fijación de llave pública no es soportada con cURL < 7.44.0"
 
-#: http.c:1854
+#: http.c:876
+msgid "CURLSSLOPT_NO_REVOKE not supported with cURL < 7.44.0"
+msgstr "CURLSSLOPT_NO_REVOKE no soportado con cURL < 7.44.0"
+
+#: http.c:949
+msgid "Protocol restrictions not supported with cURL < 7.19.4"
+msgstr "Restricción de protocolo no soportada con cURL < 7.19.4"
+
+#: http.c:1086
+#, c-format
+msgid "Unsupported SSL backend '%s'. Supported SSL backends:"
+msgstr "Backend SSL no soportado '%s'. Backends SSL soportados:"
+
+#: http.c:1093
+#, c-format
+msgid "Could not set SSL backend to '%s': cURL was built without SSL backends"
+msgstr ""
+"No se pudo configurar backend SSL a '%s': cURL fue construido sin backends "
+"SSL"
+
+#: http.c:1097
+#, c-format
+msgid "Could not set SSL backend to '%s': already set"
+msgstr "No se pudo configurar backend SSL para '%s': ya configurado"
+
+#: http.c:1966
 #, c-format
 msgid ""
 "unable to update url base from redirection:\n"
@@ -15514,39 +21875,183 @@ msgstr ""
 "  preguntaba por: %s\n"
 "   redireccionamiento: %s"
 
-#: remote-curl.c:401
+#: remote-curl.c:166
+#, c-format
+msgid "invalid quoting in push-option value: '%s'"
+msgstr "quoting inválido en valor de push-option: '%s'"
+
+#: remote-curl.c:263
+#, c-format
+msgid "%sinfo/refs not valid: is this a git repository?"
+msgstr "%sinfo/refs no es válido: ¿es este un repositorio git?"
+
+#: remote-curl.c:364
+msgid "invalid server response; expected service, got flush packet"
+msgstr ""
+"respuesta de servidor inválida; se esperaba servicio, se obtuvo un flush "
+"packet"
+
+#: remote-curl.c:395
+#, c-format
+msgid "invalid server response; got '%s'"
+msgstr "respuesta de servidor inválida; se obtuvo '%s'"
+
+#: remote-curl.c:455
+#, c-format
+msgid "repository '%s' not found"
+msgstr "repositorio '%s' no encontrado"
+
+#: remote-curl.c:459
+#, c-format
+msgid "Authentication failed for '%s'"
+msgstr "Autenticación falló para '%s'"
+
+#: remote-curl.c:463
+#, c-format
+msgid "unable to access '%s': %s"
+msgstr "no es posible acceder '%s':%s"
+
+#: remote-curl.c:469
 #, c-format
 msgid "redirecting to %s"
 msgstr "redirigiendo a %s"
 
-#: list-objects-filter-options.h:59
+#: remote-curl.c:593
+msgid "shouldn't have EOF when not gentle on EOF"
+msgstr "no debería tener EOF cuando no es gentil en EOF"
+
+#: remote-curl.c:673
+msgid "unable to rewind rpc post data - try increasing http.postBuffer"
+msgstr ""
+"no es posible rebobinar rpc post data - intenta incrementando http.postBuffer"
+
+#: remote-curl.c:733
+#, c-format
+msgid "RPC failed; %s"
+msgstr "RPC falló; %s"
+
+#: remote-curl.c:773
+msgid "cannot handle pushes this big"
+msgstr "no se puede manejar pushes tan grandes"
+
+#: remote-curl.c:888
+#, c-format
+msgid "cannot deflate request; zlib deflate error %d"
+msgstr "no se puede desinflar el request; zlib deflate error %d"
+
+#: remote-curl.c:892
+#, c-format
+msgid "cannot deflate request; zlib end error %d"
+msgstr "no se puede desinflar el request; zlib end error %d"
+
+#: remote-curl.c:1023
+msgid "dumb http transport does not support shallow capabilities"
+msgstr "dump http transport no soporta capacidades superficiales"
+
+#: remote-curl.c:1037
+msgid "fetch failed."
+msgstr "fetch falló."
+
+#: remote-curl.c:1085
+msgid "cannot fetch by sha1 over smart http"
+msgstr "no se puede hacer fetch por sha1 sobre smart http"
+
+#: remote-curl.c:1129 remote-curl.c:1135
+#, c-format
+msgid "protocol error: expected sha/ref, got '%s'"
+msgstr "error de protocolo: se esperaba sha/ref, se obtuvo '%s'"
+
+#: remote-curl.c:1147 remote-curl.c:1261
+#, c-format
+msgid "http transport does not support %s"
+msgstr "http transport no soporta %s"
+
+#: remote-curl.c:1183
+msgid "git-http-push failed"
+msgstr "git-http-push falló"
+
+#: remote-curl.c:1367
+msgid "remote-curl: usage: git remote-curl <remote> [<url>]"
+msgstr "remote-curl: uso: git remote-curl <remote> [<url>]"
+
+#: remote-curl.c:1399
+msgid "remote-curl: error reading command stream from git"
+msgstr "remote-curl: error leyendo command stream de git"
+
+#: remote-curl.c:1406
+msgid "remote-curl: fetch attempted without a local repo"
+msgstr "remote-curl: fetch intentado sin un repositorio local"
+
+#: remote-curl.c:1446
+#, c-format
+msgid "remote-curl: unknown command '%s' from git"
+msgstr "remote-curl: comando '%s' desconocido de git"
+
+#: list-objects-filter-options.h:85
 msgid "args"
 msgstr "args"
 
-#: list-objects-filter-options.h:60
+#: list-objects-filter-options.h:86
 msgid "object filtering"
 msgstr "filtrado de objeto"
 
-#: parse-options.h:157
+#: parse-options.h:183
 msgid "expiry-date"
 msgstr "fecha de expiración"
 
-#: parse-options.h:172
+#: parse-options.h:197
 msgid "no-op (backward compatibility)"
 msgstr "no-op (compatibilidad con versiones anteriores)"
 
-#: parse-options.h:251
+#: parse-options.h:309
 msgid "be more verbose"
-msgstr "ser mas verboso"
+msgstr "ser más verboso"
 
-#: parse-options.h:253
+#: parse-options.h:311
 msgid "be more quiet"
-msgstr "ser mas discreto"
+msgstr "ser más discreto"
 
-#: parse-options.h:259
+#: parse-options.h:317
 msgid "use <n> digits to display SHA-1s"
 msgstr "usa <n> dígitos para mostrar SHA-1s"
 
+#: parse-options.h:336
+msgid "how to strip spaces and #comments from message"
+msgstr "cómo quitar espacios y #comentarios de mensajes"
+
+#: parse-options.h:337
+msgid "read pathspec from file"
+msgstr "leer pathspec de archivo"
+
+#: parse-options.h:338
+msgid ""
+"with --pathspec-from-file, pathspec elements are separated with NUL character"
+msgstr ""
+"con --pathspec-from-file, elementos de pathspec son separados con caracter "
+"NUL"
+
+#: ref-filter.h:101
+msgid "key"
+msgstr "clave"
+
+#: ref-filter.h:101
+msgid "field name to sort on"
+msgstr "nombre del campo por el cuál ordenar"
+
+#: rerere.h:44
+msgid "update the index with reused conflict resolution if possible"
+msgstr ""
+"actualizar el índice con la resolución de conflictos reutilizada si es "
+"posible"
+
+#: wt-status.h:67
+msgid "HEAD detached at "
+msgstr "HEAD desacoplada en "
+
+#: wt-status.h:68
+msgid "HEAD detached from "
+msgstr "HEAD desacoplada de "
+
 #: command-list.h:50
 msgid "Add file contents to the index"
 msgstr "Agrega contenido de carpetas al índice"
@@ -15564,8 +22069,8 @@ msgid "Apply a patch to files and/or to
 msgstr "Aplicar un parche a archivos y/o  el índice"
 
 #: command-list.h:54
-msgid "Import an Arch repository into Git"
-msgstr "Importar un repositorio Arch en Git"
+msgid "Import a GNU Arch repository into Git"
+msgstr "Importar un repositorio GNU Arch en Git"
 
 #: command-list.h:55
 msgid "Create an archive of files from a named tree"
@@ -15646,8 +22151,8 @@ msgid "Record changes to the repository"
 msgstr "Graba los cambios en tu repositorio"
 
 #: command-list.h:74
-msgid "Write and verify Git commit graph files"
-msgstr "Escribe y verifica los archivos de Git commit graph"
+msgid "Write and verify Git commit-graph files"
+msgstr "Escribe y verifica los archivos de Git commit-graph"
 
 #: command-list.h:75
 msgid "Create a new commit object"
@@ -15807,8 +22312,8 @@ msgid "Instantly browse your working rep
 msgstr "Buscar instantáneamente tu repositorio de trabajo en gitweb"
 
 #: command-list.h:113
-msgid "add or parse structured information in commit messages"
-msgstr "agregar o analizar información estructurada en mensajes de commit"
+msgid "Add or parse structured information in commit messages"
+msgstr "Agregar o analizar información estructurada en mensajes de commit"
 
 #: command-list.h:114
 msgid "The Git repository browser"
@@ -15840,7 +22345,7 @@ msgstr "Programa divisor de mbox simple
 
 #: command-list.h:121
 msgid "Join two or more development histories together"
-msgstr "Junta dos o mas historiales de desarrollo juntos"
+msgstr "Junta dos o más historiales de desarrollo juntos"
 
 #: command-list.h:122
 msgid "Find as good common ancestors as possible for a merge"
@@ -15869,334 +22374,352 @@ msgid "Show three-way merge without touc
 msgstr "Mostrar fusión de tres vías sin tocar el índice"
 
 #: command-list.h:128
+msgid "Write and verify multi-pack-indexes"
+msgstr "Escribe y verifica archivos multi-pack-index"
+
+#: command-list.h:129
 msgid "Creates a tag object"
 msgstr "Crea un objeto tag"
 
-#: command-list.h:129
+#: command-list.h:130
 msgid "Build a tree-object from ls-tree formatted text"
 msgstr "Construir un objeto árbol de un texto en formato ls-tree"
 
-#: command-list.h:130
+#: command-list.h:131
 msgid "Move or rename a file, a directory, or a symlink"
 msgstr "Mueve o cambia el nombre a archivos, directorios o enlaces simbólicos"
 
-#: command-list.h:131
+#: command-list.h:132
 msgid "Find symbolic names for given revs"
 msgstr "Encontrar nombres simbólicos para revs dados"
 
-#: command-list.h:132
+#: command-list.h:133
 msgid "Add or inspect object notes"
 msgstr "Agrega o inspecciona objetos nota"
 
-#: command-list.h:133
+#: command-list.h:134
 msgid "Import from and submit to Perforce repositories"
 msgstr "Importar desde y enviar a repositorios Perforce"
 
-#: command-list.h:134
+#: command-list.h:135
 msgid "Create a packed archive of objects"
 msgstr "Crea un archivo de objetos empaquetados"
 
-#: command-list.h:135
+#: command-list.h:136
 msgid "Find redundant pack files"
 msgstr "Encuentra archivos empaquetados de manera redundante"
 
-#: command-list.h:136
+#: command-list.h:137
 msgid "Pack heads and tags for efficient repository access"
 msgstr "Empaqueta heads y tags para un acceso eficiente al repositorio"
 
-#: command-list.h:137
+#: command-list.h:138
 msgid "Routines to help parsing remote repository access parameters"
 msgstr ""
 "Rutinas para ayudar a analizar los parámetros de acceso del repositorio "
 "remoto"
 
-#: command-list.h:138
+#: command-list.h:139
 msgid "Compute unique ID for a patch"
 msgstr "Calcular ID único para un parche"
 
-#: command-list.h:139
+#: command-list.h:140
 msgid "Prune all unreachable objects from the object database"
 msgstr "Limpia todos los objetos no alcanzables de la base de datos de objetos"
 
-#: command-list.h:140
+#: command-list.h:141
 msgid "Remove extra objects that are already in pack files"
 msgstr "Remover objetos extra que ya están en archivos empaquetados"
 
-#: command-list.h:141
+#: command-list.h:142
 msgid "Fetch from and integrate with another repository or a local branch"
 msgstr "Realiza un fetch e integra con otro repositorio o rama local"
 
-#: command-list.h:142
+#: command-list.h:143
 msgid "Update remote refs along with associated objects"
 msgstr "Actualiza referencias remotas junto con sus objetos asociados"
 
-#: command-list.h:143
+#: command-list.h:144
 msgid "Applies a quilt patchset onto the current branch"
 msgstr "Aplica un parche quilt en la rama actual"
 
-#: command-list.h:144
+#: command-list.h:145
+msgid "Compare two commit ranges (e.g. two versions of a branch)"
+msgstr "Compara dos rangos de commits (por ejemplo dos versions de un branch)"
+
+#: command-list.h:146
 msgid "Reads tree information into the index"
 msgstr "Lee información del ábol en el índice"
 
-#: command-list.h:145
+#: command-list.h:147
 msgid "Reapply commits on top of another base tip"
 msgstr "Vuelve a aplicar commits en la punta de otra rama"
 
-#: command-list.h:146
+#: command-list.h:148
 msgid "Receive what is pushed into the repository"
 msgstr "Recibir lo que es empujado en el respositorio"
 
-#: command-list.h:147
+#: command-list.h:149
 msgid "Manage reflog information"
 msgstr "Gestionar información de reflog"
 
-#: command-list.h:148
+#: command-list.h:150
 msgid "Manage set of tracked repositories"
 msgstr "Gestiona un conjunto de repositorios rastreados"
 
-#: command-list.h:149
+#: command-list.h:151
 msgid "Pack unpacked objects in a repository"
-msgstr "empaquetar objetos no empaquetados en un repositorio"
+msgstr "Empaquetar objetos no empaquetados en un repositorio"
 
-#: command-list.h:150
+#: command-list.h:152
 msgid "Create, list, delete refs to replace objects"
 msgstr "Crea, lista, borra referencias para reemplazar objetos"
 
-#: command-list.h:151
+#: command-list.h:153
 msgid "Generates a summary of pending changes"
 msgstr "Genera un resumen de cambios pendientes"
 
-#: command-list.h:152
+#: command-list.h:154
 msgid "Reuse recorded resolution of conflicted merges"
 msgstr "Reutilizar la resolución registrada de fusiones conflictivas"
 
-#: command-list.h:153
+#: command-list.h:155
 msgid "Reset current HEAD to the specified state"
 msgstr "Reinicia el HEAD actual a un estado especifico"
 
-#: command-list.h:154
+#: command-list.h:156
+msgid "Restore working tree files"
+msgstr "Restaurar archivos de árboles de trabajo"
+
+#: command-list.h:157
 msgid "Revert some existing commits"
 msgstr "Revierte algunos commits existentes"
 
-#: command-list.h:155
+#: command-list.h:158
 msgid "Lists commit objects in reverse chronological order"
 msgstr "Lista objetos commit en orden cronológico inverso"
 
-#: command-list.h:156
+#: command-list.h:159
 msgid "Pick out and massage parameters"
 msgstr "Seleccionar y masajear los parámetros"
 
-#: command-list.h:157
+#: command-list.h:160
 msgid "Remove files from the working tree and from the index"
 msgstr "Borra archivos del árbol de trabajo y del índice"
 
-#: command-list.h:158
+#: command-list.h:161
 msgid "Send a collection of patches as emails"
 msgstr "Envía una colección de parches como e-mails"
 
-#: command-list.h:159
+#: command-list.h:162
 msgid "Push objects over Git protocol to another repository"
 msgstr "Empujar objetos por protocolo Git a otro repositorio"
 
-#: command-list.h:160
+#: command-list.h:163
 msgid "Restricted login shell for Git-only SSH access"
 msgstr "Shell de inicio de sesión restringido para acceso SSH exclusivo de Git"
 
-#: command-list.h:161
+#: command-list.h:164
 msgid "Summarize 'git log' output"
 msgstr "Resumir la salida 'git log'"
 
-#: command-list.h:162
+#: command-list.h:165
 msgid "Show various types of objects"
 msgstr "Muestra varios tipos de objetos"
 
-#: command-list.h:163
+#: command-list.h:166
 msgid "Show branches and their commits"
 msgstr "Mostrar ramas y sus commits"
 
-#: command-list.h:164
+#: command-list.h:167
 msgid "Show packed archive index"
 msgstr "Mostrar el índice de archivo empaquetado"
 
-#: command-list.h:165
+#: command-list.h:168
 msgid "List references in a local repository"
 msgstr "Listar referencias en el repositorio local"
 
-#: command-list.h:166
+#: command-list.h:169
 msgid "Git's i18n setup code for shell scripts"
 msgstr "El código de configuración i18n de Git para scripts de shell"
 
-#: command-list.h:167
+#: command-list.h:170
 msgid "Common Git shell script setup code"
 msgstr "Código de configuración de script de shell común de Git"
 
-#: command-list.h:168
+#: command-list.h:171
+msgid "Initialize and modify the sparse-checkout"
+msgstr "Inicializa y modifica el sparse-checkout"
+
+#: command-list.h:172
 msgid "Stash the changes in a dirty working directory away"
 msgstr ""
 "Poner en un stash los cambios en un directorio de trabajo sucio de todas "
 "maneras"
 
-#: command-list.h:169
+#: command-list.h:173
 msgid "Add file contents to the staging area"
 msgstr "Agrega contenidos de un archivo al área de staging"
 
-#: command-list.h:170
+#: command-list.h:174
 msgid "Show the working tree status"
 msgstr "Muestra el estado del árbol de trabajo"
 
-#: command-list.h:171
+#: command-list.h:175
 msgid "Remove unnecessary whitespace"
 msgstr "Eliminar el espacio en blanco innecesario"
 
-#: command-list.h:172
+#: command-list.h:176
 msgid "Initialize, update or inspect submodules"
 msgstr "Inicializa, actualiza o inspecciona submódulos"
 
-#: command-list.h:173
+#: command-list.h:177
 msgid "Bidirectional operation between a Subversion repository and Git"
 msgstr "Operación bidireccional entre un repositorio Subversion y Git"
 
-#: command-list.h:174
+#: command-list.h:178
+msgid "Switch branches"
+msgstr "Cambiar branches"
+
+#: command-list.h:179
 msgid "Read, modify and delete symbolic refs"
 msgstr "Lee, modifica y borra referencias simbólicas"
 
-#: command-list.h:175
+#: command-list.h:180
 msgid "Create, list, delete or verify a tag object signed with GPG"
 msgstr "Crea, lista, borra o verifica un tag de objeto firmado con GPG"
 
-#: command-list.h:176
+#: command-list.h:181
 msgid "Creates a temporary file with a blob's contents"
 msgstr "Crea un archivo temporal con contenidos de un blob"
 
-#: command-list.h:177
+#: command-list.h:182
 msgid "Unpack objects from a packed archive"
 msgstr "Desempaqueta objetos de un archivo empaquetado"
 
-#: command-list.h:178
+#: command-list.h:183
 msgid "Register file contents in the working tree to the index"
 msgstr "Registra contenidos de archivos en el árbol de trabajo al índice"
 
-#: command-list.h:179
+#: command-list.h:184
 msgid "Update the object name stored in a ref safely"
 msgstr ""
 "Actualiza el nombre del objeto almacenado en una referencia de forma segura"
 
-#: command-list.h:180
+#: command-list.h:185
 msgid "Update auxiliary info file to help dumb servers"
 msgstr ""
 "Actualiza el archivo de información auxiliar para ayudar a los servidores "
 "dumb"
 
-#: command-list.h:181
+#: command-list.h:186
 msgid "Send archive back to git-archive"
 msgstr "Enviar archivo a git-archive"
 
-#: command-list.h:182
+#: command-list.h:187
 msgid "Send objects packed back to git-fetch-pack"
 msgstr "Enviar objetos empaquetados a git-fetch-pack"
 
-#: command-list.h:183
+#: command-list.h:188
 msgid "Show a Git logical variable"
 msgstr "Mostrar una variable lógica de Git"
 
-#: command-list.h:184
+#: command-list.h:189
 msgid "Check the GPG signature of commits"
 msgstr "Verificar firma GPG de commits"
 
-#: command-list.h:185
+#: command-list.h:190
 msgid "Validate packed Git archive files"
 msgstr "Valida archivos Git empaquetados"
 
-#: command-list.h:186
+#: command-list.h:191
 msgid "Check the GPG signature of tags"
 msgstr "Verifica la firma GPG de etiquetas"
 
-#: command-list.h:187
+#: command-list.h:192
 msgid "Git web interface (web frontend to Git repositories)"
 msgstr "Interfaz web Git (interfaz web para repositorios Git)"
 
-#: command-list.h:188
+#: command-list.h:193
 msgid "Show logs with difference each commit introduces"
 msgstr "Muestra logs con las diferencias que cada commit introduce"
 
-#: command-list.h:189
+#: command-list.h:194
 msgid "Manage multiple working trees"
 msgstr "Gestiona múltiples árboles de trabajo"
 
-#: command-list.h:190
+#: command-list.h:195
 msgid "Create a tree object from the current index"
 msgstr "Crea un objeto árbol del índice actual"
 
-#: command-list.h:191
+#: command-list.h:196
 msgid "Defining attributes per path"
 msgstr "Definiendo atributos por ruta"
 
-#: command-list.h:192
+#: command-list.h:197
 msgid "Git command-line interface and conventions"
 msgstr "Interfaz y convenciones de línea de comandos de Git"
 
-#: command-list.h:193
+#: command-list.h:198
 msgid "A Git core tutorial for developers"
 msgstr "Un tutorial básico de Git para desarrolladores"
 
-#: command-list.h:194
+#: command-list.h:199
 msgid "Git for CVS users"
 msgstr "Git para usuarios CVS"
 
-#: command-list.h:195
+#: command-list.h:200
 msgid "Tweaking diff output"
 msgstr "Afinar la salida de diff"
 
-#: command-list.h:196
+#: command-list.h:201
 msgid "A useful minimum set of commands for Everyday Git"
 msgstr "Un conjunto mínimo útil de comandos diarios de Git"
 
-#: command-list.h:197
+#: command-list.h:202
 msgid "A Git Glossary"
 msgstr "Un Glosario de Git"
 
-#: command-list.h:198
+#: command-list.h:203
 msgid "Hooks used by Git"
 msgstr "Hooks utilizados por Git"
 
-#: command-list.h:199
+#: command-list.h:204
 msgid "Specifies intentionally untracked files to ignore"
 msgstr "Especifica de forma intencional archivos sin seguimiento a ignorar"
 
-#: command-list.h:200
+#: command-list.h:205
 msgid "Defining submodule properties"
 msgstr "Definiendo las propiedades del submódulo"
 
-#: command-list.h:201
+#: command-list.h:206
 msgid "Git namespaces"
-msgstr "namespaces de Git"
+msgstr "Namespaces de Git"
 
-#: command-list.h:202
+#: command-list.h:207
 msgid "Git Repository Layout"
 msgstr "Disposición del repositorio Git"
 
-#: command-list.h:203
+#: command-list.h:208
 msgid "Specifying revisions and ranges for Git"
 msgstr "Especificando revisiones y rangos para Git"
 
-#: command-list.h:204
+#: command-list.h:209
+msgid "Mounting one repository inside another"
+msgstr "Montando un repositorio dentro de otro"
+
+#: command-list.h:210
 msgid "A tutorial introduction to Git: part two"
 msgstr "Un tutorial de introducción a Git: parte dos"
 
-#: command-list.h:205
+#: command-list.h:211
 msgid "A tutorial introduction to Git"
 msgstr "Un tutorial de introducción para Git"
 
-#: command-list.h:206
+#: command-list.h:212
 msgid "An overview of recommended workflows with Git"
 msgstr "Una visión general de flujos de trabajo recomendados con Git"
 
-#: rerere.h:40
-msgid "update the index with reused conflict resolution if possible"
-msgstr ""
-"actualizar el índice con la resolución de conflictos reutilizada si es "
-"posible"
-
 #: git-bisect.sh:54
 msgid "You need to start by \"git bisect start\""
 msgstr "Debes iniciar con \"git bisect start\""
@@ -16208,133 +22731,49 @@ msgstr "Debes iniciar con \"git bisect s
 msgid "Do you want me to do it for you [Y/n]? "
 msgstr "¿Quieres que lo haga por ti [Y/n]? "
 
-#: git-bisect.sh:121
-#, sh-format
-msgid "unrecognised option: '$arg'"
-msgstr "opción no reconocida: '$arg'"
-
-#: git-bisect.sh:125
-#, sh-format
-msgid "'$arg' does not appear to be a valid revision"
-msgstr "'$arg' no parece ser una revisión válida"
-
-#: git-bisect.sh:154
-msgid "Bad HEAD - I need a HEAD"
-msgstr "Mal HEAD - Necesito un HEAD"
-
-#: git-bisect.sh:167
-#, sh-format
-msgid ""
-"Checking out '$start_head' failed. Try 'git bisect reset <valid-branch>'."
-msgstr ""
-"Error al comprobar '$start_head'. Intente 'git bisect reset <rama-válida>'."
-
-#: git-bisect.sh:177
-msgid "won't bisect on cg-seek'ed tree"
-msgstr "no se bisecará en un árbol con cg-seek"
-
-#: git-bisect.sh:181
-msgid "Bad HEAD - strange symbolic ref"
-msgstr "Mal HEAD - ref simbólico extraño"
-
-#: git-bisect.sh:233
-#, sh-format
-msgid "Bad bisect_write argument: $state"
-msgstr "Mal argumento bisect_write: $state"
-
-#: git-bisect.sh:246
+#: git-bisect.sh:101
 #, sh-format
 msgid "Bad rev input: $arg"
 msgstr "Mala entrada rev: $arg"
 
-#: git-bisect.sh:265
+#: git-bisect.sh:121
 #, sh-format
 msgid "Bad rev input: $bisected_head"
 msgstr "Mala entrada rev: $bisected_head"
 
-#: git-bisect.sh:274
+#: git-bisect.sh:130
 #, sh-format
 msgid "Bad rev input: $rev"
 msgstr "Mala entrada rev: $rev"
 
-#: git-bisect.sh:283
+#: git-bisect.sh:139
 #, sh-format
 msgid "'git bisect $TERM_BAD' can take only one argument."
 msgstr "'git bisect $TERM_BAD' solo puede tomar un argumento."
 
-#: git-bisect.sh:306
-#, sh-format
-msgid "Warning: bisecting only with a $TERM_BAD commit."
-msgstr "Peligro: bisecando solo con un $TERM_BAD commit."
-
-#. TRANSLATORS: Make sure to include [Y] and [n] in your
-#. translation. The program will only accept English input
-#. at this point.
-#: git-bisect.sh:312
-msgid "Are you sure [Y/n]? "
-msgstr "¿Estás seguro [Y/n]? "
-
-#: git-bisect.sh:324
-#, sh-format
-msgid ""
-"You need to give me at least one $bad_syn and one $good_syn revision.\n"
-"(You can use \"git bisect $bad_syn\" and \"git bisect $good_syn\" for that.)"
-msgstr ""
-"Tiene que dar al menos un $bad_syn y un $good_syn revision.\n"
-"(Puede ver \"git bisect $bad_syn\" y \"git bisect $good_syn\" para eso.)"
-
-#: git-bisect.sh:327
-#, sh-format
-msgid ""
-"You need to start by \"git bisect start\".\n"
-"You then need to give me at least one $good_syn and one $bad_syn revision.\n"
-"(You can use \"git bisect $bad_syn\" and \"git bisect $good_syn\" for that.)"
-msgstr ""
-"Tiene que comenzar por \"git bisect start\".\n"
-"Después tiene que entregar al menos un $good_syn y un $bad_syn revision.\n"
-"(Puede usar \"git bisect $bad_syn\" y \"git bisect $good_syn\" para eso.)"
-
-#: git-bisect.sh:398 git-bisect.sh:512
-msgid "We are not bisecting."
-msgstr "No estamos bisecando."
-
-#: git-bisect.sh:405
-#, sh-format
-msgid "'$invalid' is not a valid commit"
-msgstr "'$invalid' no es un commit válido"
-
-#: git-bisect.sh:414
-#, sh-format
-msgid ""
-"Could not check out original HEAD '$branch'.\n"
-"Try 'git bisect reset <commit>'."
-msgstr ""
-"No se pudo revisar el HEAD original '$branch'.\n"
-"Intente 'git bisect reset <commit>'."
-
-#: git-bisect.sh:422
+#: git-bisect.sh:209
 msgid "No logfile given"
 msgstr "Ningún logfile proporcionado"
 
-#: git-bisect.sh:423
+#: git-bisect.sh:210
 #, sh-format
 msgid "cannot read $file for replaying"
 msgstr "no se puede leer $file para reproducir"
 
-#: git-bisect.sh:444
+#: git-bisect.sh:232
 msgid "?? what are you talking about?"
 msgstr "?? ¿De qué estás hablando?"
 
-#: git-bisect.sh:453
+#: git-bisect.sh:241
 msgid "bisect run failed: no command provided."
 msgstr "bisect falló: no se proveyó comando."
 
-#: git-bisect.sh:458
+#: git-bisect.sh:246
 #, sh-format
 msgid "running $command"
 msgstr "ejecutando $command"
 
-#: git-bisect.sh:465
+#: git-bisect.sh:253
 #, sh-format
 msgid ""
 "bisect run failed:\n"
@@ -16343,11 +22782,11 @@ msgstr ""
 "bisect falló:\n"
 "código de salida $res de '$command' es <0 o >=128"
 
-#: git-bisect.sh:491
+#: git-bisect.sh:279
 msgid "bisect run cannot continue any more"
 msgstr "bisect no puede seguir continuando"
 
-#: git-bisect.sh:497
+#: git-bisect.sh:285
 #, sh-format
 msgid ""
 "bisect run failed:\n"
@@ -16356,36 +22795,20 @@ msgstr ""
 "bisect falló:\n"
 "'bisect_state $state' salió con código de error $res"
 
-#: git-bisect.sh:504
+#: git-bisect.sh:292
 msgid "bisect run success"
 msgstr "bisect exitoso"
 
-#: git-bisect.sh:533
-#, sh-format
-msgid "Invalid command: you're currently in a $TERM_BAD/$TERM_GOOD bisect."
-msgstr ""
-"Comando inválido: actualmente se encuentra en un bisect $TERM_BAD/$TERM_GOOD."
-
-#: git-bisect.sh:567
-msgid "no terms defined"
-msgstr "no hay términos definidos"
-
-#: git-bisect.sh:584
-#, sh-format
-msgid ""
-"invalid argument $arg for 'git bisect terms'.\n"
-"Supported options are: --term-good|--term-old and --term-bad|--term-new."
-msgstr ""
-"argumento inválido $arg para 'git bisect terms'.\n"
-"Las opciones soportadas son: --term-good|--term-old and --term-bad|--term-"
-"new."
+#: git-bisect.sh:300
+msgid "We are not bisecting."
+msgstr "No estamos bisecando."
 
 #: git-merge-octopus.sh:46
 msgid ""
 "Error: Your local changes to the following files would be overwritten by "
 "merge"
 msgstr ""
-"Error: Sus cambios locales de los siguientes archivos serán sobrescritos por "
+"Error: Tus cambios locales de los siguientes archivos serán sobrescritos por "
 "la fusión"
 
 #: git-merge-octopus.sh:61
@@ -16420,331 +22843,115 @@ msgstr "Intentando fusión simple con $p
 msgid "Simple merge did not work, trying automatic merge."
 msgstr "Fusión simple no funcionó, intentando fusión automática."
 
-#: git-rebase.sh:61
-msgid ""
-"Resolve all conflicts manually, mark them as resolved with\n"
-"\"git add/rm <conflicted_files>\", then run \"git rebase --continue\".\n"
-"You can instead skip this commit: run \"git rebase --skip\".\n"
-"To abort and get back to the state before \"git rebase\", run \"git rebase --"
-"abort\"."
-msgstr ""
-"Resuelva todos los conflictos manualmente ya sea con \n"
-"\"git add/rm <archivo_conflictivo>\", luego ejecute \"git rebase --continue"
-"\".\n"
-"Si prefiere saltar este parche, ejecute \"git rebase --skip\" .\n"
-"Para abortar y regresar al estado previo al \"git rebase\", ejecute \"git "
-"rebase --abort\"."
-
-#: git-rebase.sh:173 git-rebase.sh:442
-#, sh-format
-msgid "Could not move back to $head_name"
-msgstr "No se puede regresar a $head_name"
-
-#: git-rebase.sh:184
-msgid "Applied autostash."
-msgstr "Autostash aplicado."
-
-#: git-rebase.sh:187
-#, sh-format
-msgid "Cannot store $stash_sha1"
-msgstr "No se puede almacenar $stash_sha1"
-
-#: git-rebase.sh:229
-msgid "The pre-rebase hook refused to rebase."
-msgstr "El hook pre-rebase rechazó el rebase."
-
-#: git-rebase.sh:234
-msgid "It looks like 'git am' is in progress. Cannot rebase."
-msgstr "Parece que 'git am' está en progreso. No se puede rebasar."
-
-#: git-rebase.sh:403
-msgid "No rebase in progress?"
-msgstr "No hay rebase en progreso?"
-
-#: git-rebase.sh:414
-msgid "The --edit-todo action can only be used during interactive rebase."
-msgstr ""
-"La acción --edit-todo sólo puede ser usada al rebasar interactivamente."
-
-#: git-rebase.sh:421
-msgid "Cannot read HEAD"
-msgstr "No se puede leer el HEAD"
-
-#: git-rebase.sh:424
-msgid ""
-"You must edit all merge conflicts and then\n"
-"mark them as resolved using git add"
-msgstr ""
-"Tienes que editar todos los conflictos de fusión y luego\n"
-"marcarlos como resueltos usando git add"
-
-#: git-rebase.sh:468
-#, sh-format
-msgid ""
-"It seems that there is already a $state_dir_base directory, and\n"
-"I wonder if you are in the middle of another rebase.  If that is the\n"
-"case, please try\n"
-"\t$cmd_live_rebase\n"
-"If that is not the case, please\n"
-"\t$cmd_clear_stale_rebase\n"
-"and run me again.  I am stopping in case you still have something\n"
-"valuable there."
-msgstr ""
-"Parece que ya hay un directorio $state_dir_base, y\n"
-"me pregunto si está en medio de otro rebase. Si ese es el \n"
-"caso, por favor intente\n"
-"\t$cmd_live_rebase\n"
-"Si no es el caso, por favor\n"
-"\t$cmd_clear_stale_rebase\n"
-"y ejecúteme nuevamente.  Me estoy deteniendo en caso de que tenga\n"
-"algo de valor ahí."
-
-#: git-rebase.sh:509
-msgid "error: cannot combine '--signoff' with '--preserve-merges'"
-msgstr "error: no se puede combinar '--signoff' con '--preserve-merges'"
-
-#: git-rebase.sh:537
-#, sh-format
-msgid "invalid upstream '$upstream_name'"
-msgstr "upstream inválido '$upstream_name'"
-
-#: git-rebase.sh:561
-#, sh-format
-msgid "$onto_name: there are more than one merge bases"
-msgstr "$onto_name: hay más de una base de fusión"
-
-#: git-rebase.sh:564 git-rebase.sh:568
-#, sh-format
-msgid "$onto_name: there is no merge base"
-msgstr "$onto_name: no hay base de fusión"
-
-#: git-rebase.sh:573
-#, sh-format
-msgid "Does not point to a valid commit: $onto_name"
-msgstr "No apunta a un commit válido: $onto_name"
-
-#: git-rebase.sh:599
-#, sh-format
-msgid "fatal: no such branch/commit '$branch_name'"
-msgstr "fatal: no existe la rama/commit: '$branch_name'"
-
-#: git-rebase.sh:632
-msgid "Cannot autostash"
-msgstr "No se puede ejecutar autostash"
-
-#: git-rebase.sh:637
-#, sh-format
-msgid "Created autostash: $stash_abbrev"
-msgstr "Autostash creado: $stash_abbrev"
-
-#: git-rebase.sh:641
-msgid "Please commit or stash them."
-msgstr "Por favor, confírmalos o guárdalos."
-
-#: git-rebase.sh:664
-#, sh-format
-msgid "HEAD is up to date."
-msgstr "HEAD está actualizado."
-
-#: git-rebase.sh:666
-#, sh-format
-msgid "Current branch $branch_name is up to date."
-msgstr "La rama actual $branch_name está actualizada."
-
-#: git-rebase.sh:674
-#, sh-format
-msgid "HEAD is up to date, rebase forced."
-msgstr "HEAD está actualizado, rebase forzado."
-
-#: git-rebase.sh:676
-#, sh-format
-msgid "Current branch $branch_name is up to date, rebase forced."
-msgstr "Rama actual $branch_name está actualizada, rebase forzado."
-
-#: git-rebase.sh:688
-#, sh-format
-msgid "Changes from $mb to $onto:"
-msgstr "Cambios desde $mb a $onto:"
-
-#: git-rebase.sh:697
-msgid "First, rewinding head to replay your work on top of it..."
-msgstr ""
-"En primer lugar, rebobinando HEAD para después reproducir tus cambios encima "
-"de ésta..."
-
-#: git-rebase.sh:707
-#, sh-format
-msgid "Fast-forwarded $branch_name to $onto_name."
-msgstr "Avance rápido de $branch_name a $onto_name."
-
-#: git-stash.sh:61
-msgid "git stash clear with parameters is unimplemented"
-msgstr "git stash clear con parámetros no está implementado"
-
-#: git-stash.sh:108
-msgid "You do not have the initial commit yet"
-msgstr "Aún no tienes un commit inicial"
-
-#: git-stash.sh:123
-msgid "Cannot save the current index state"
-msgstr "No se puede guardar el estado actual del índice"
-
-#: git-stash.sh:138
-msgid "Cannot save the untracked files"
-msgstr "No se pueden guardar los archivos no rastreados"
-
-#: git-stash.sh:158 git-stash.sh:171
-msgid "Cannot save the current worktree state"
-msgstr "No se puede guardar el estado actual del árbol de trabajo"
-
-#: git-stash.sh:175
-msgid "No changes selected"
-msgstr "Sin cambios seleccionados"
-
-#: git-stash.sh:178
+#: git-legacy-stash.sh:221
 msgid "Cannot remove temporary index (can't happen)"
-msgstr "No se puede remover el índice temporal (no puede suceder)"
-
-#: git-stash.sh:191
-msgid "Cannot record working tree state"
-msgstr "No se puede grabar el estado del árbol de trabajo"
+msgstr "No se puede eliminar el índice temporal (no puede suceder)"
 
-#: git-stash.sh:229
+#: git-legacy-stash.sh:272
 #, sh-format
 msgid "Cannot update $ref_stash with $w_commit"
 msgstr "No se puede actualizar $ref_stash con $w_commit"
 
-#: git-stash.sh:281
+#: git-legacy-stash.sh:324
 #, sh-format
 msgid "error: unknown option for 'stash push': $option"
 msgstr "error: opción desconocida para 'stash pus': $option"
 
-#: git-stash.sh:295
-msgid "Can't use --patch and --include-untracked or --all at the same time"
-msgstr "No se puede usar --patch y --include-untracked o --all al mismo tiempo"
-
-#: git-stash.sh:303
-msgid "No local changes to save"
-msgstr "No hay cambios locales para guardar"
-
-#: git-stash.sh:308
-msgid "Cannot initialize stash"
-msgstr "No se puede inicializar stash"
-
-#: git-stash.sh:312
-msgid "Cannot save the current status"
-msgstr "No se puede guardar el estado actual"
-
-#: git-stash.sh:313
+#: git-legacy-stash.sh:356
 #, sh-format
 msgid "Saved working directory and index state $stash_msg"
 msgstr "Directorio de trabajo guardado y estado de índice $stash_msg"
 
-#: git-stash.sh:342
-msgid "Cannot remove worktree changes"
-msgstr "No se pueden remover cambios del árbol de trabajo"
-
-#: git-stash.sh:490
+#: git-legacy-stash.sh:536
 #, sh-format
 msgid "unknown option: $opt"
 msgstr "opción desconocida: $opt"
 
-#: git-stash.sh:503
-msgid "No stash entries found."
-msgstr "No se encontraron entradas de stash."
-
-#: git-stash.sh:510
+#: git-legacy-stash.sh:556
 #, sh-format
 msgid "Too many revisions specified: $REV"
 msgstr "Se especificaron demasiadas revisiones: $REV"
 
-#: git-stash.sh:525
+#: git-legacy-stash.sh:571
 #, sh-format
 msgid "$reference is not a valid reference"
 msgstr "$reference no es una referencia válida"
 
-#: git-stash.sh:553
+#: git-legacy-stash.sh:599
 #, sh-format
 msgid "'$args' is not a stash-like commit"
 msgstr "'$args' no es un commit estilo stash"
 
-#: git-stash.sh:564
+#: git-legacy-stash.sh:610
 #, sh-format
 msgid "'$args' is not a stash reference"
 msgstr "'$args' no es una referencia stash"
 
-#: git-stash.sh:572
+#: git-legacy-stash.sh:618
 msgid "unable to refresh index"
 msgstr "incapaz de refrescar el índice"
 
-#: git-stash.sh:576
+#: git-legacy-stash.sh:622
 msgid "Cannot apply a stash in the middle of a merge"
 msgstr "No se puede aplicar un stash en medio de una fusión"
 
-#: git-stash.sh:584
+#: git-legacy-stash.sh:630
 msgid "Conflicts in index. Try without --index."
 msgstr "Conflictos en índice. Intente sin --index."
 
-#: git-stash.sh:586
+#: git-legacy-stash.sh:632
 msgid "Could not save index tree"
 msgstr "No se puede guardar el índice del árbol"
 
-#: git-stash.sh:595
+#: git-legacy-stash.sh:641
 msgid "Could not restore untracked files from stash entry"
 msgstr "No se pueden restaurar archivos no rastreados de la entrada stash"
 
-#: git-stash.sh:620
+#: git-legacy-stash.sh:666
 msgid "Cannot unstage modified files"
 msgstr "No se puede sacar de stage archivos modificados"
 
-#: git-stash.sh:635
-msgid "Index was not unstashed."
-msgstr "El índice no fue sacado de stash."
-
-#: git-stash.sh:649
-msgid "The stash entry is kept in case you need it again."
-msgstr "La entrada de stash se guardó en caso de ser necesario nuevamente."
-
-#: git-stash.sh:658
+#: git-legacy-stash.sh:704
 #, sh-format
 msgid "Dropped ${REV} ($s)"
 msgstr "Botado ${REV} ($s)"
 
-#: git-stash.sh:659
+#: git-legacy-stash.sh:705
 #, sh-format
 msgid "${REV}: Could not drop stash entry"
 msgstr "${REV}: No se pudo borrar entrada stash"
 
-#: git-stash.sh:667
-msgid "No branch name specified"
-msgstr "No se especificó el nombre de la rama"
-
-#: git-stash.sh:746
+#: git-legacy-stash.sh:792
 msgid "(To restore them type \"git stash apply\")"
 msgstr "(Para restaurarlos, escribe \"git stash apply\")"
 
-#: git-submodule.sh:188
+#: git-submodule.sh:202
 msgid "Relative path can only be used from the toplevel of the working tree"
 msgstr ""
 "La ruta relativa sólo se puede usar desde el nivel superior del árbol de "
 "trabajo"
 
-#: git-submodule.sh:198
+#: git-submodule.sh:212
 #, sh-format
 msgid "repo URL: '$repo' must be absolute or begin with ./|../"
 msgstr "repo URL: '$repo' debe ser absoluta o iniciar con ./|../"
 
-#: git-submodule.sh:217
+#: git-submodule.sh:231
 #, sh-format
 msgid "'$sm_path' already exists in the index"
 msgstr "'$sm_path' ya existe en el índice"
 
-#: git-submodule.sh:220
+#: git-submodule.sh:234
 #, sh-format
 msgid "'$sm_path' already exists in the index and is not a submodule"
 msgstr "'$sm_path' ya existe en el índice y no es un submódulo"
 
-#: git-submodule.sh:226
+#: git-submodule.sh:241
+#, sh-format
+msgid "'$sm_path' does not have a commit checked out"
+msgstr "'$sm_path' no tiene un commit checked out"
+
+#: git-submodule.sh:247
 #, sh-format
 msgid ""
 "The following path is ignored by one of your .gitignore files:\n"
@@ -16755,24 +22962,24 @@ msgstr ""
 "$sm_path\n"
 "Usa -f si en verdad quieres agregarlo."
 
-#: git-submodule.sh:249
+#: git-submodule.sh:270
 #, sh-format
 msgid "Adding existing repo at '$sm_path' to the index"
 msgstr "Agregando el repositorio existente en '$sm_path' al índice"
 
-#: git-submodule.sh:251
+#: git-submodule.sh:272
 #, sh-format
 msgid "'$sm_path' already exists and is not a valid git repo"
 msgstr "'$sm_path' ya existe y no es un repositorio git válido"
 
-#: git-submodule.sh:259
+#: git-submodule.sh:280
 #, sh-format
 msgid "A git directory for '$sm_name' is found locally with remote(s):"
 msgstr ""
 "Se encontró localmente un directorio git para '$sm_name' con el(los) "
 "remoto(s):"
 
-#: git-submodule.sh:261
+#: git-submodule.sh:282
 #, sh-format
 msgid ""
 "If you want to reuse this local git directory instead of cloning again from\n"
@@ -16784,55 +22991,44 @@ msgid ""
 msgstr ""
 "Si quiere reusar este directorio git local en lugar de clonar nuevamente de\n"
 "  $realrepo\n"
-"use la opción '--force'. Si el directorio git local no es el repositorio "
+"usa la opción '--force'. Si el directorio git local no es el repositorio "
 "correcto\n"
-"o no está seguro de lo que esto significa, escoja otro nombre con la opción "
+"o no estás seguro de lo que esto significa, escoge otro nombre con la opción "
 "'--name'."
 
-#: git-submodule.sh:267
+#: git-submodule.sh:288
 #, sh-format
 msgid "Reactivating local git directory for submodule '$sm_name'."
 msgstr "Reactivar directorio git local para el submódulo '$sm_name'."
 
-#: git-submodule.sh:279
+#: git-submodule.sh:300
 #, sh-format
 msgid "Unable to checkout submodule '$sm_path'"
 msgstr "No es posible hacer checkout al submódulo '$sm_path'"
 
-#: git-submodule.sh:284
+#: git-submodule.sh:305
 #, sh-format
 msgid "Failed to add submodule '$sm_path'"
 msgstr "Falló al agregar el submódulo '$sm_path'"
 
-#: git-submodule.sh:293
+#: git-submodule.sh:314
 #, sh-format
 msgid "Failed to register submodule '$sm_path'"
 msgstr "Falló al registrar el submódulo '$sm_path'"
 
-#: git-submodule.sh:354
-#, sh-format
-msgid "Entering '$displaypath'"
-msgstr "Entrando a '$displaypath'"
-
-#: git-submodule.sh:374
-#, sh-format
-msgid "Stopping at '$displaypath'; script returned non-zero status."
-msgstr ""
-"Deteniendo en '$displaypath'; script retornó un status distinto de cero."
-
-#: git-submodule.sh:600
+#: git-submodule.sh:580
 #, sh-format
 msgid "Unable to find current revision in submodule path '$displaypath'"
 msgstr ""
 "No se pudo encontrar la revisión actual en la ruta de submódulo "
 "'$displaypath'"
 
-#: git-submodule.sh:610
+#: git-submodule.sh:590
 #, sh-format
 msgid "Unable to fetch in submodule path '$sm_path'"
 msgstr "No es posible realizar fetch en la ruta de submódulo '$sm_path'"
 
-#: git-submodule.sh:615
+#: git-submodule.sh:595
 #, sh-format
 msgid ""
 "Unable to find current ${remote_name}/${branch} revision in submodule path "
@@ -16841,12 +23037,16 @@ msgstr ""
 "No es posible encontrar revisión actual ${remote_name}/${branch} en la ruta "
 "de submódulo  '$sm_path'"
 
-#: git-submodule.sh:633
+#: git-submodule.sh:613
 #, sh-format
-msgid "Unable to fetch in submodule path '$displaypath'"
-msgstr "No es posible realizar fetch en la ruta de submódulo '$displaypath'"
+msgid ""
+"Unable to fetch in submodule path '$displaypath'; trying to directly fetch "
+"$sha1:"
+msgstr ""
+"No es posible realizar fetch en la ruta de submódulo '$displaypath'; "
+"intentando hacer un fetch directo $sha1:"
 
-#: git-submodule.sh:639
+#: git-submodule.sh:619
 #, sh-format
 msgid ""
 "Fetched in submodule path '$displaypath', but it did not contain $sha1. "
@@ -16855,75 +23055,75 @@ msgstr ""
 "Fetch realizado en ruta de submódulo '$displaypath', pero no contenía $sha1. "
 "Fetch directo del commit falló."
 
-#: git-submodule.sh:646
+#: git-submodule.sh:626
 #, sh-format
 msgid "Unable to checkout '$sha1' in submodule path '$displaypath'"
 msgstr "No es posible revisar '$sha1' en la ruta de submódulo '$displaypath'"
 
-#: git-submodule.sh:647
+#: git-submodule.sh:627
 #, sh-format
 msgid "Submodule path '$displaypath': checked out '$sha1'"
 msgstr "Ruta de submódulo '$displaypath': check out realizado a '$sha1'"
 
-#: git-submodule.sh:651
+#: git-submodule.sh:631
 #, sh-format
 msgid "Unable to rebase '$sha1' in submodule path '$displaypath'"
 msgstr ""
 "No se posible ejecutar rebase a '$sha1' en la ruta de submódulo "
 "'$displaypath'"
 
-#: git-submodule.sh:652
+#: git-submodule.sh:632
 #, sh-format
 msgid "Submodule path '$displaypath': rebased into '$sha1'"
 msgstr "Ruta de submódulo '$displaypath': rebasada en '$sha1'"
 
-#: git-submodule.sh:657
+#: git-submodule.sh:637
 #, sh-format
 msgid "Unable to merge '$sha1' in submodule path '$displaypath'"
 msgstr "Incapaz de fusionar '$sha1' en la ruta del submódulo '$displaypath'"
 
-#: git-submodule.sh:658
+#: git-submodule.sh:638
 #, sh-format
 msgid "Submodule path '$displaypath': merged in '$sha1'"
 msgstr "Ruta de submódulo '$displaypath': fusionada en '$sha1'"
 
-#: git-submodule.sh:663
+#: git-submodule.sh:643
 #, sh-format
 msgid "Execution of '$command $sha1' failed in submodule path '$displaypath'"
 msgstr ""
 "Falló la ejecución  de  '$command $sha1' en la ruta de submódulo "
 "'$displaypath'"
 
-#: git-submodule.sh:664
+#: git-submodule.sh:644
 #, sh-format
 msgid "Submodule path '$displaypath': '$command $sha1'"
 msgstr "Ruta de submódulo '$displaypath': '$command $sha1'"
 
-#: git-submodule.sh:695
+#: git-submodule.sh:675
 #, sh-format
 msgid "Failed to recurse into submodule path '$displaypath'"
 msgstr "Falló al recurrir en la ruta de submódulo '$displaypath'"
 
-#: git-submodule.sh:791
+#: git-submodule.sh:886
 msgid "The --cached option cannot be used with the --files option"
 msgstr "La opción --cached no puede ser usada con la opción --files"
 
-#: git-submodule.sh:843
+#: git-submodule.sh:938
 #, sh-format
 msgid "unexpected mode $mod_dst"
 msgstr "modo $mod_dst inesperado"
 
-#: git-submodule.sh:863
+#: git-submodule.sh:958
 #, sh-format
 msgid "  Warn: $display_name doesn't contain commit $sha1_src"
 msgstr "  Advertencia: $display_name no contiene el commit $sha1_src"
 
-#: git-submodule.sh:866
+#: git-submodule.sh:961
 #, sh-format
 msgid "  Warn: $display_name doesn't contain commit $sha1_dst"
 msgstr "  Advertencia: $display_name no contiene el commit $sha1_dst"
 
-#: git-submodule.sh:869
+#: git-submodule.sh:964
 #, sh-format
 msgid "  Warn: $display_name doesn't contain commits $sha1_src and $sha1_dst"
 msgstr ""
@@ -16934,12 +23134,21 @@ msgstr ""
 msgid "See git-${cmd}(1) for details."
 msgstr "Véase git-${cmd}(1) para más detalles."
 
-#: git-rebase--interactive.sh:142
+#: git-rebase--preserve-merges.sh:109
+msgid "Applied autostash."
+msgstr "Autostash aplicado."
+
+#: git-rebase--preserve-merges.sh:112
+#, sh-format
+msgid "Cannot store $stash_sha1"
+msgstr "No se puede almacenar $stash_sha1"
+
+#: git-rebase--preserve-merges.sh:191
 #, sh-format
 msgid "Rebasing ($new_count/$total)"
 msgstr "Rebasando ($new_count/$total)"
 
-#: git-rebase--interactive.sh:158
+#: git-rebase--preserve-merges.sh:207
 msgid ""
 "\n"
 "Commands:\n"
@@ -16948,7 +23157,7 @@ msgid ""
 "e, edit <commit> = use commit, but stop for amending\n"
 "s, squash <commit> = use commit, but meld into previous commit\n"
 "f, fixup <commit> = like \"squash\", but discard this commit's log message\n"
-"x, exec <command> = run command (the rest of the line) using shell\n"
+"x, exec <commit> = run command (the rest of the line) using shell\n"
 "d, drop <commit> = remove commit\n"
 "l, label <label> = label current HEAD with a name\n"
 "t, reset <label> = reset HEAD to a label\n"
@@ -16968,7 +23177,7 @@ msgstr ""
 "f, fixup <commit> = como \"squash\", pero descarta el mensaje del log de "
 "este commit\n"
 "x, exec <commit> = ejecuta comando ( el resto de la línea) usando un shell\n"
-"d, drop <commit> = remover commit\n"
+"d, drop <commit> = eliminar commit\n"
 "l, label <label> = poner label al HEAD actual con un nombre\n"
 "t, reset <label> = reiniciar HEAD a el label\n"
 "m, merge [-C <commit> | -c <commit>] <label> [# <oneline>]\n"
@@ -16979,23 +23188,7 @@ msgstr ""
 "Estas líneas pueden ser reordenadas; son ejecutadas desde arriba hacia "
 "abajo.\n"
 
-#: git-rebase--interactive.sh:179
-msgid ""
-"\n"
-"Do not remove any line. Use 'drop' explicitly to remove a commit.\n"
-msgstr ""
-"\n"
-"No eliminar ninguna línea. Usa 'drop' explícitamente para borrar un commit \n"
-
-#: git-rebase--interactive.sh:183
-msgid ""
-"\n"
-"If you remove a line here THAT COMMIT WILL BE LOST.\n"
-msgstr ""
-"\n"
-"Si remueves una línea aquí EL COMMIT SE PERDERÁ.\n"
-
-#: git-rebase--interactive.sh:221
+#: git-rebase--preserve-merges.sh:270
 #, sh-format
 msgid ""
 "You can amend the commit now, with\n"
@@ -17006,91 +23199,91 @@ msgid ""
 "\n"
 "\tgit rebase --continue"
 msgstr ""
-"Puede enmendar el commit ahora, con\n"
+"Puedes enmendar el commit ahora, con\n"
 "\n"
 "\tgit commit --amend $gpg_sign_opt_quoted\n"
 "\n"
-"Una vez que esté satisfecho con los cambios, ejecute\n"
+"Una vez que estés satisfecho con los cambios, ejecuta\n"
 "\n"
 "\tgit rebase --continue"
 
-#: git-rebase--interactive.sh:246
+#: git-rebase--preserve-merges.sh:295
 #, sh-format
 msgid "$sha1: not a commit that can be picked"
 msgstr "$sha1: no es un commit que pueda ser cogido"
 
-#: git-rebase--interactive.sh:285
+#: git-rebase--preserve-merges.sh:334
 #, sh-format
 msgid "Invalid commit name: $sha1"
 msgstr "Nombre de commit inválido: $sha1"
 
-#: git-rebase--interactive.sh:325
+#: git-rebase--preserve-merges.sh:364
 msgid "Cannot write current commit's replacement sha1"
 msgstr "No se puede escribir el remplazo sha1 del commit actual"
 
-#: git-rebase--interactive.sh:376
+#: git-rebase--preserve-merges.sh:415
 #, sh-format
 msgid "Fast-forward to $sha1"
 msgstr "Avance rápido a $sha1"
 
-#: git-rebase--interactive.sh:378
+#: git-rebase--preserve-merges.sh:417
 #, sh-format
 msgid "Cannot fast-forward to $sha1"
 msgstr "No se puede realizar avance rápido a $sha1"
 
-#: git-rebase--interactive.sh:387
+#: git-rebase--preserve-merges.sh:426
 #, sh-format
 msgid "Cannot move HEAD to $first_parent"
 msgstr "No se puede mover HEAD a $first_parent"
 
-#: git-rebase--interactive.sh:392
+#: git-rebase--preserve-merges.sh:431
 #, sh-format
 msgid "Refusing to squash a merge: $sha1"
 msgstr "Rehusando a ejecutar squash en fusión: $sha1"
 
-#: git-rebase--interactive.sh:410
+#: git-rebase--preserve-merges.sh:449
 #, sh-format
 msgid "Error redoing merge $sha1"
 msgstr "Error rehaciendo fusión $sha1"
 
-#: git-rebase--interactive.sh:419
+#: git-rebase--preserve-merges.sh:458
 #, sh-format
 msgid "Could not pick $sha1"
 msgstr "No se pudo coger $sha1"
 
-#: git-rebase--interactive.sh:428
+#: git-rebase--preserve-merges.sh:467
 #, sh-format
 msgid "This is the commit message #${n}:"
 msgstr "Este es el mensaje del commit #${n}:"
 
-#: git-rebase--interactive.sh:433
+#: git-rebase--preserve-merges.sh:472
 #, sh-format
 msgid "The commit message #${n} will be skipped:"
 msgstr "El mensaje del commit  #${n} será ignorado:"
 
-#: git-rebase--interactive.sh:444
+#: git-rebase--preserve-merges.sh:483
 #, sh-format
 msgid "This is a combination of $count commit."
 msgid_plural "This is a combination of $count commits."
 msgstr[0] "Esta es una combinación de $count commit."
 msgstr[1] "Esta es la combinación de $count commits."
 
-#: git-rebase--interactive.sh:453
+#: git-rebase--preserve-merges.sh:492
 #, sh-format
 msgid "Cannot write $fixup_msg"
 msgstr "No se puede escribir $fixup_msg"
 
-#: git-rebase--interactive.sh:456
+#: git-rebase--preserve-merges.sh:495
 msgid "This is a combination of 2 commits."
 msgstr "Esto es una combinación de 2 commits."
 
-#: git-rebase--interactive.sh:497 git-rebase--interactive.sh:540
-#: git-rebase--interactive.sh:543
+#: git-rebase--preserve-merges.sh:536 git-rebase--preserve-merges.sh:579
+#: git-rebase--preserve-merges.sh:582
 #, sh-format
 msgid "Could not apply $sha1... $rest"
 msgstr "No se puede aplicar $sha1... $rest"
 
-#: git-rebase--interactive.sh:572
+#: git-rebase--preserve-merges.sh:611
 #, sh-format
 msgid ""
 "Could not amend commit after successfully picking $sha1... $rest\n"
@@ -17103,35 +23296,35 @@ msgstr ""
 "$rest\n"
 "Esto es probablemente debido a un mensaje de commit vacío, o el hook pre-"
 "commit\n"
-"ha fallado. Si el hook pre-commit falló, es posible que deba resolver el "
+"ha fallado. Si el hook pre-commit falló, es posible que debas resolver el "
 "problema antes\n"
 "de que sea capaz de reformular el commit."
 
-#: git-rebase--interactive.sh:587
+#: git-rebase--preserve-merges.sh:626
 #, sh-format
 msgid "Stopped at $sha1_abbrev... $rest"
 msgstr "Detenido en $sha1_abbrev... $rest"
 
-#: git-rebase--interactive.sh:602
+#: git-rebase--preserve-merges.sh:641
 #, sh-format
 msgid "Cannot '$squash_style' without a previous commit"
 msgstr "No se puede '$squash_style' sin un commit previo"
 
-#: git-rebase--interactive.sh:644
+#: git-rebase--preserve-merges.sh:683
 #, sh-format
 msgid "Executing: $rest"
 msgstr "Ejecutando: $rest"
 
-#: git-rebase--interactive.sh:652
+#: git-rebase--preserve-merges.sh:691
 #, sh-format
 msgid "Execution failed: $rest"
 msgstr "Ejecución fallida: $rest"
 
-#: git-rebase--interactive.sh:654
+#: git-rebase--preserve-merges.sh:693
 msgid "and made changes to the index and/or the working tree"
 msgstr "y hizo cambios al índice y/o al árbol de trabajo"
 
-#: git-rebase--interactive.sh:656
+#: git-rebase--preserve-merges.sh:695
 msgid ""
 "You can fix the problem, and then run\n"
 "\n"
@@ -17142,7 +23335,7 @@ msgstr ""
 "\tgit rebase --continue"
 
 #. TRANSLATORS: after these lines is a command to be issued by the user
-#: git-rebase--interactive.sh:669
+#: git-rebase--preserve-merges.sh:708
 #, sh-format
 msgid ""
 "Execution succeeded: $rest\n"
@@ -17153,33 +23346,29 @@ msgid ""
 msgstr ""
 "La ejecución tuvo éxito: $rest\n"
 "Pero dejó cambios en el índice y/o en el árbol de trabajo\n"
-"Realice un commit o stash con los cambios y, a continuación, ejecute\n"
+"Realiza un commit o stash con los cambios y, a continuación, ejecuta\n"
 "\n"
 "\tgit rebase --continue"
 
-#: git-rebase--interactive.sh:680
+#: git-rebase--preserve-merges.sh:719
 #, sh-format
 msgid "Unknown command: $command $sha1 $rest"
 msgstr "Comando desconocido: $command $sha1 $rest"
 
-#: git-rebase--interactive.sh:681
+#: git-rebase--preserve-merges.sh:720
 msgid "Please fix this using 'git rebase --edit-todo'."
 msgstr "Por favor, corrige esto usando 'git rebase --edit-todo'."
 
-#: git-rebase--interactive.sh:716
+#: git-rebase--preserve-merges.sh:755
 #, sh-format
 msgid "Successfully rebased and updated $head_name."
 msgstr "$head_name rebasado y actualizado satisfactoriamente."
 
-#: git-rebase--interactive.sh:740
-msgid "could not detach HEAD"
-msgstr "no se puede desacoplar HEAD"
-
-#: git-rebase--interactive.sh:778
+#: git-rebase--preserve-merges.sh:812
 msgid "Could not remove CHERRY_PICK_HEAD"
-msgstr "No se pudo remover CHERRY_PICK_HEAD"
+msgstr "No se pudo eliminar CHERRY_PICK_HEAD"
 
-#: git-rebase--interactive.sh:783
+#: git-rebase--preserve-merges.sh:817
 #, sh-format
 msgid ""
 "You have staged changes in your working tree.\n"
@@ -17196,26 +23385,26 @@ msgid ""
 "\n"
 "  git rebase --continue\n"
 msgstr ""
-"Tiene cambios en el área de stage de su árbol de trabajo.\n"
+"Tienes cambios en el área de stage de tu árbol de trabajo.\n"
 "Si estos cambios están destinados a \n"
-"ser aplastados en el commit previo, ejecute:\n"
+"ser aplastados en el commit previo, ejecuta:\n"
 "\n"
 "  git commit --amend $gpg_sign_opt_quoted\n"
 "\n"
-"Si estos están destinados a ir en un nuevo commit, ejecute:\n"
+"Si estos están destinados a ir en un nuevo commit, ejecuta:\n"
 "\n"
 "  git commit $gpg_sign_opt_quoted\n"
 "\n"
-"En ambos casos, cuando termine, continue con:\n"
+"En ambos casos, cuando termines, continue con:\n"
 "\n"
 "  git rebase --continue\n"
 
-#: git-rebase--interactive.sh:800
+#: git-rebase--preserve-merges.sh:834
 msgid "Error trying to find the author identity to amend commit"
 msgstr ""
 "Error tratando de encontrar la identidad del autor para remediar el commit"
 
-#: git-rebase--interactive.sh:805
+#: git-rebase--preserve-merges.sh:839
 msgid ""
 "You have uncommitted changes in your working tree. Please commit them\n"
 "first and then run 'git rebase --continue' again."
@@ -17223,74 +23412,40 @@ msgstr ""
 "Tienes cambios sin confirmar en tu árbol de trabajo. Por favor, confírmalos\n"
 "primero y entonces ejecuta 'git rebase --continue' de nuevo."
 
-#: git-rebase--interactive.sh:810 git-rebase--interactive.sh:814
+#: git-rebase--preserve-merges.sh:844 git-rebase--preserve-merges.sh:848
 msgid "Could not commit staged changes."
 msgstr "No se pudo realizar el commit con los cambios en el área de stage."
 
-#: git-rebase--interactive.sh:843
-msgid ""
-"\n"
-"You are editing the todo file of an ongoing interactive rebase.\n"
-"To continue rebase after editing, run:\n"
-"    git rebase --continue\n"
-"\n"
-msgstr ""
-"\n"
-"Esta editando el archivo TODO de un rebase interactivo.\n"
-"Para continuar el rebase después de editar, ejecute:\n"
-"    git rebase --continue\n"
-"\n"
-
-#: git-rebase--interactive.sh:851 git-rebase--interactive.sh:937
+#: git-rebase--preserve-merges.sh:879 git-rebase--preserve-merges.sh:965
 msgid "Could not execute editor"
 msgstr "No se pudo ejecutar el editor"
 
-#: git-rebase--interactive.sh:872
+#: git-rebase--preserve-merges.sh:900
 #, sh-format
 msgid "Could not checkout $switch_to"
 msgstr "No se pudo actualizar el árbol de trabajo a $switch_to"
 
-#: git-rebase--interactive.sh:879
+#: git-rebase--preserve-merges.sh:907
 msgid "No HEAD?"
 msgstr "¿Sin HEAD?"
 
-#: git-rebase--interactive.sh:880
+#: git-rebase--preserve-merges.sh:908
 #, sh-format
 msgid "Could not create temporary $state_dir"
 msgstr "No se pudo crear $state_dir temporalmente"
 
-#: git-rebase--interactive.sh:883
+#: git-rebase--preserve-merges.sh:911
 msgid "Could not mark as interactive"
 msgstr "No se pudo marcar como interactivo"
 
-#: git-rebase--interactive.sh:915
+#: git-rebase--preserve-merges.sh:943
 #, sh-format
 msgid "Rebase $shortrevisions onto $shortonto ($todocount command)"
 msgid_plural "Rebase $shortrevisions onto $shortonto ($todocount commands)"
 msgstr[0] "Rebase $shortrevisions en $shortonto ($todocount comando)"
 msgstr[1] "Rebase $shortrevisions en $shortonto ($todocount comandos)"
 
-#: git-rebase--interactive.sh:920
-msgid ""
-"\n"
-"\tHowever, if you remove everything, the rebase will be aborted.\n"
-"\n"
-"\t"
-msgstr ""
-"\n"
-"\tComo sea, si quieres borrar todo, el rebase será abortado.\n"
-"\n"
-"\t"
-
-#: git-rebase--interactive.sh:927
-msgid "Note that empty commits are commented out"
-msgstr "Tenga en cuenta que los commits vacíos están comentados"
-
-#: git-rebase--interactive.sh:980
-msgid "Could not generate todo list"
-msgstr "No se pudo generar lista de pendientes"
-
-#: git-rebase--interactive.sh:1001 git-rebase--interactive.sh:1006
+#: git-rebase--preserve-merges.sh:997 git-rebase--preserve-merges.sh:1002
 msgid "Could not init rewritten commits"
 msgstr "No se puede inicializar los commits reescritos"
 
@@ -17299,146 +23454,84 @@ msgstr "No se puede inicializar los comm
 msgid "usage: $dashless $USAGE"
 msgstr "uso: $dashless $USAGE"
 
-#: git-sh-setup.sh:190
+#: git-sh-setup.sh:191
 #, sh-format
 msgid "Cannot chdir to $cdup, the toplevel of the working tree"
 msgstr ""
 "No se puede aplicar chdir a $cdup, el nivel máximo del árbol de trabajo"
 
-#: git-sh-setup.sh:199 git-sh-setup.sh:206
+#: git-sh-setup.sh:200 git-sh-setup.sh:207
 #, sh-format
 msgid "fatal: $program_name cannot be used without a working tree."
 msgstr "fatal: $program_name no puede ser usado sin un árbol de trabajo."
 
-#: git-sh-setup.sh:220
+#: git-sh-setup.sh:221
 msgid "Cannot rebase: You have unstaged changes."
 msgstr ""
 "No se puede aplicar rebase: Tienes cambios que no están en el área de stage."
 
-#: git-sh-setup.sh:223
+#: git-sh-setup.sh:224
 msgid "Cannot rewrite branches: You have unstaged changes."
 msgstr ""
 "No se puede reescribir las ramas: Tienes cambios que no están en el área de "
 "stage."
 
-#: git-sh-setup.sh:226
+#: git-sh-setup.sh:227
 msgid "Cannot pull with rebase: You have unstaged changes."
 msgstr ""
 "No se puede aplicar pull con rebase: Tienes cambios que no están en el área "
 "de stage."
 
-#: git-sh-setup.sh:229
+#: git-sh-setup.sh:230
 #, sh-format
 msgid "Cannot $action: You have unstaged changes."
 msgstr "No se puede $action: Tienes cambios que no están en el área de stage."
 
-#: git-sh-setup.sh:242
+#: git-sh-setup.sh:243
 msgid "Cannot rebase: Your index contains uncommitted changes."
 msgstr ""
 "No se puede hacer rebase: Tu índice contiene cambios que no están en un "
 "commit."
 
-#: git-sh-setup.sh:245
+#: git-sh-setup.sh:246
 msgid "Cannot pull with rebase: Your index contains uncommitted changes."
 msgstr ""
 "No se puede hacer pull con rebase: Tu índice contiene cambios que no están "
 "en un commit."
 
-#: git-sh-setup.sh:248
+#: git-sh-setup.sh:249
 #, sh-format
 msgid "Cannot $action: Your index contains uncommitted changes."
 msgstr "No se puede $action: El índice contiene cambios sin confirmar."
 
-#: git-sh-setup.sh:252
+#: git-sh-setup.sh:253
 msgid "Additionally, your index contains uncommitted changes."
 msgstr "Adicionalmente, tu índice contiene cambios que no están en un commit."
 
-#: git-sh-setup.sh:372
+#: git-sh-setup.sh:373
 msgid "You need to run this command from the toplevel of the working tree."
 msgstr ""
 "Necesitas ejecutar este comando desde el nivel superior de tu árbol de "
 "trabajo."
 
-#: git-sh-setup.sh:377
+#: git-sh-setup.sh:378
 msgid "Unable to determine absolute path of git directory"
 msgstr "Incapaz de determinar la ruta absoluta del directorio git"
 
 #. TRANSLATORS: you can adjust this to align "git add -i" status menu
-#: git-add--interactive.perl:196
+#: git-add--interactive.perl:212
 #, perl-format
 msgid "%12s %12s %s"
 msgstr "%12s %12s %s"
 
-#: git-add--interactive.perl:197
-msgid "staged"
-msgstr "rastreado"
-
-#: git-add--interactive.perl:197
-msgid "unstaged"
-msgstr "no rastreado"
-
-#: git-add--interactive.perl:253 git-add--interactive.perl:278
-msgid "binary"
-msgstr "binario"
-
-#: git-add--interactive.perl:262 git-add--interactive.perl:316
-msgid "nothing"
-msgstr "nada"
-
-#: git-add--interactive.perl:298 git-add--interactive.perl:313
-msgid "unchanged"
-msgstr "sin cambios"
-
-#: git-add--interactive.perl:609
-#, perl-format
-msgid "added %d path\n"
-msgid_plural "added %d paths\n"
-msgstr[0] "agregada %d ruta\n"
-msgstr[1] "agregadas %d rutas\n"
-
-#: git-add--interactive.perl:612
-#, perl-format
-msgid "updated %d path\n"
-msgid_plural "updated %d paths\n"
-msgstr[0] "actualizada %d ruta\n"
-msgstr[1] "actualizadas %d rutas\n"
-
-#: git-add--interactive.perl:615
-#, perl-format
-msgid "reverted %d path\n"
-msgid_plural "reverted %d paths\n"
-msgstr[0] "revertida %d ruta\n"
-msgstr[1] "revertidas %d rutas\n"
-
-#: git-add--interactive.perl:618
+#: git-add--interactive.perl:634
 #, perl-format
 msgid "touched %d path\n"
 msgid_plural "touched %d paths\n"
 msgstr[0] "touch hecho a %d ruta\n"
 msgstr[1] "touch hecho a %d rutas\n"
 
-#: git-add--interactive.perl:627
-msgid "Update"
-msgstr "Actualizar"
-
-#: git-add--interactive.perl:639
-msgid "Revert"
-msgstr "Revertir"
-
-#: git-add--interactive.perl:662
-#, perl-format
-msgid "note: %s is untracked now.\n"
-msgstr "nota: %s no es rastreado ahora.\n"
-
-#: git-add--interactive.perl:673
-msgid "Add untracked"
-msgstr "Agregar no rastreados"
-
-#: git-add--interactive.perl:679
-msgid "No untracked files.\n"
-msgstr "No hay archivos sin rastrear.\n"
-
-#: git-add--interactive.perl:1033
+#: git-add--interactive.perl:1053
 msgid ""
 "If the patch applies cleanly, the edited hunk will immediately be\n"
 "marked for staging."
@@ -17446,7 +23539,7 @@ msgstr ""
 "Si el parche aplica limpiamente, el hunk editado sera marcado\n"
 "inmediatamente para el área de stage."
 
-#: git-add--interactive.perl:1036
+#: git-add--interactive.perl:1056
 msgid ""
 "If the patch applies cleanly, the edited hunk will immediately be\n"
 "marked for stashing."
@@ -17454,7 +23547,7 @@ msgstr ""
 "Si el parche aplica limpiamente, el hunk editado sera marcado\n"
 "inmediatamente para aplicar stash."
 
-#: git-add--interactive.perl:1039
+#: git-add--interactive.perl:1059
 msgid ""
 "If the patch applies cleanly, the edited hunk will immediately be\n"
 "marked for unstaging."
@@ -17462,7 +23555,8 @@ msgstr ""
 "Si el parche aplica limpiamente, el hunk editado sera marcado\n"
 "inmediatamente para sacar del área de stage."
 
-#: git-add--interactive.perl:1042 git-add--interactive.perl:1051
+#: git-add--interactive.perl:1062 git-add--interactive.perl:1071
+#: git-add--interactive.perl:1077
 msgid ""
 "If the patch applies cleanly, the edited hunk will immediately be\n"
 "marked for applying."
@@ -17470,7 +23564,8 @@ msgstr ""
 "Si el parche aplica de forma limpia, el hunk editado sera marcado \n"
 "inmediatamente para aplicar."
 
-#: git-add--interactive.perl:1045 git-add--interactive.perl:1048
+#: git-add--interactive.perl:1065 git-add--interactive.perl:1068
+#: git-add--interactive.perl:1074
 msgid ""
 "If the patch applies cleanly, the edited hunk will immediately be\n"
 "marked for discarding."
@@ -17478,16 +23573,12 @@ msgstr ""
 "Si el parche aplica de forma limpia, el hunk editado sera marcado\n"
 "inmediatamente para descarte."
 
-#: git-add--interactive.perl:1085
+#: git-add--interactive.perl:1111
 #, perl-format
 msgid "failed to open hunk edit file for writing: %s"
 msgstr "falló al abrir el archivo de adición del hunk para escritura: %s"
 
-#: git-add--interactive.perl:1086
-msgid "Manual hunk edit mode -- see bottom for a quick guide.\n"
-msgstr "Modo de edición manual de hunk -- vea abajo para una guía rápida.\n"
-
-#: git-add--interactive.perl:1092
+#: git-add--interactive.perl:1118
 #, perl-format
 msgid ""
 "---\n"
@@ -17496,39 +23587,16 @@ msgid ""
 "Lines starting with %s will be removed.\n"
 msgstr ""
 "---\n"
-"Para remover '%s' líneas, haga de ellas líneas  ' '  (contexto).\n"
-"Para remover '%s' líneas, bórrelas.\n"
-"Lineas comenzando con  %s serán removidas.\n"
-
-#. TRANSLATORS: 'it' refers to the patch mentioned in the previous messages.
-#: git-add--interactive.perl:1100
-msgid ""
-"If it does not apply cleanly, you will be given an opportunity to\n"
-"edit again.  If all lines of the hunk are removed, then the edit is\n"
-"aborted and the hunk is left unchanged.\n"
-msgstr ""
-"Si esto no aplica de manera limpia, se le da la oportunidad de \n"
-"editar nuevamente. Si todas las líneas del hunk son removidas, entonces \n"
-"la edición es abortada y el hunk queda sin cambios.\n"
+"Para eliminar '%s' líneas, haga de ellas líneas  ' '  (contexto).\n"
+"Para eliminar '%s' líneas, bórrelas.\n"
+"Lineas comenzando con  %s serán eliminadas.\n"
 
-#: git-add--interactive.perl:1114
+#: git-add--interactive.perl:1140
 #, perl-format
 msgid "failed to open hunk edit file for reading: %s"
 msgstr "falló al abrir el archivo de edición del hunk para lectura: %s"
 
-#. TRANSLATORS: do not translate [y/n]
-#. The program will only accept that input
-#. at this point.
-#. Consider translating (saying "no" discards!) as
-#. (saying "n" for "no" discards!) if the translation
-#. of the word "no" does not start with n.
-#: git-add--interactive.perl:1213
-msgid ""
-"Your edited hunk does not apply. Edit again (saying \"no\" discards!) [y/n]? "
-msgstr ""
-"Tu hunk editado no aplica. Editar nuevamente (decir \"no\" descarta!) [y/n]? "
-
-#: git-add--interactive.perl:1222
+#: git-add--interactive.perl:1248
 msgid ""
 "y - stage this hunk\n"
 "n - do not stage this hunk\n"
@@ -17543,7 +23611,7 @@ msgstr ""
 "d - no aplicar stage a este hunk o a ninguno de los posteriores en este "
 "archivo"
 
-#: git-add--interactive.perl:1228
+#: git-add--interactive.perl:1254
 msgid ""
 "y - stash this hunk\n"
 "n - do not stash this hunk\n"
@@ -17557,7 +23625,7 @@ msgstr ""
 "a - aplicar stash a este hunk y a todos los posteriores en el archivo\n"
 "d - no aplicar stash a este hunk o ninguno de los posteriores en el archivo"
 
-#: git-add--interactive.perl:1234
+#: git-add--interactive.perl:1260
 msgid ""
 "y - unstage this hunk\n"
 "n - do not unstage this hunk\n"
@@ -17572,7 +23640,7 @@ msgstr ""
 "d - no sacar del area de stage este hunk o ninguno de los posteriores en el "
 "archivo"
 
-#: git-add--interactive.perl:1240
+#: git-add--interactive.perl:1266
 msgid ""
 "y - apply this hunk to index\n"
 "n - do not apply this hunk to index\n"
@@ -17586,7 +23654,7 @@ msgstr ""
 "a - aplicar este hunk y todos los posteriores en el archivo\n"
 "d - no aplicar este hunko ninguno de los posteriores en el archivo"
 
-#: git-add--interactive.perl:1246
+#: git-add--interactive.perl:1272 git-add--interactive.perl:1290
 msgid ""
 "y - discard this hunk from worktree\n"
 "n - do not discard this hunk from worktree\n"
@@ -17600,7 +23668,7 @@ msgstr ""
 "a - descartar este hunk y todos los posteriores en este archivo\n"
 "d - no descartar este hunk o ninguno de los posteriores en el archivo"
 
-#: git-add--interactive.perl:1252
+#: git-add--interactive.perl:1278
 msgid ""
 "y - discard this hunk from index and worktree\n"
 "n - do not discard this hunk from index and worktree\n"
@@ -17614,7 +23682,7 @@ msgstr ""
 "a - descartar este hunk y todos los posteriores en este archivo\n"
 "d - no descartar este hunk o ninguno posterior en el archivo"
 
-#: git-add--interactive.perl:1258
+#: git-add--interactive.perl:1284
 msgid ""
 "y - apply this hunk to index and worktree\n"
 "n - do not apply this hunk to index and worktree\n"
@@ -17628,7 +23696,21 @@ msgstr ""
 "a - aplicar este hunk y todos los posteriores en el archivo\n"
 "d - no aplicar este hunk o ninguno de los siguientes en este archivo"
 
-#: git-add--interactive.perl:1273
+#: git-add--interactive.perl:1296
+msgid ""
+"y - apply this hunk to worktree\n"
+"n - do not apply this hunk to worktree\n"
+"q - quit; do not apply this hunk or any of the remaining ones\n"
+"a - apply this hunk and all later hunks in the file\n"
+"d - do not apply this hunk or any of the later hunks in the file"
+msgstr ""
+"y - aplicar este hunk al índice y al árbol de trabajo\n"
+"n - no aplicar este hunk al índice y al árbol de trabajo\n"
+"q - quit;  no aplicar este hunk o ninguno de los restantes\n"
+"a - aplicar este hunk y todos los posteriores en el archivo\n"
+"d - no aplicar este hunk o ninguno de los siguientes en este archivo"
+
+#: git-add--interactive.perl:1311
 msgid ""
 "g - select a hunk to go to\n"
 "/ - search for a hunk matching the given regex\n"
@@ -17646,217 +23728,206 @@ msgstr ""
 "J - dejar este hunk por definir, ver siguiente hunk\n"
 "k - dejar este hunk por definir, ver hunk previo por definir\n"
 "K - dejar este hunk por definir, ver hunk previo\n"
-"s - dividir el  hunk actual en hunks mas pequeños\n"
+"s - dividir el  hunk actual en hunks más pequeños\n"
 "e - editar manualmente el hunk actual\n"
 "? - imprimir ayuda\n"
 
-#: git-add--interactive.perl:1304
+#: git-add--interactive.perl:1342
 msgid "The selected hunks do not apply to the index!\n"
-msgstr "Los hunks seleccionados no aplican al índice!\n"
+msgstr "¡Los hunks seleccionados no aplican al índice!\n"
 
-#: git-add--interactive.perl:1305
+#: git-add--interactive.perl:1343
 msgid "Apply them to the worktree anyway? "
-msgstr "Aplicarlos al árbol de trabajo de todas maneras? "
+msgstr "¿Aplicarlos al árbol de trabajo de todas maneras? "
 
-#: git-add--interactive.perl:1308
+#: git-add--interactive.perl:1346
 msgid "Nothing was applied.\n"
 msgstr "Nada fue aplicado.\n"
 
-#: git-add--interactive.perl:1319
+#: git-add--interactive.perl:1357
 #, perl-format
 msgid "ignoring unmerged: %s\n"
 msgstr "ignorando lo no fusionado: %s\n"
 
-#: git-add--interactive.perl:1328
-msgid "Only binary files changed.\n"
-msgstr "Solo cambiaron archivos binarios.\n"
-
-#: git-add--interactive.perl:1330
-msgid "No changes.\n"
-msgstr "Sin cambios.\n"
-
-#: git-add--interactive.perl:1338
-msgid "Patch update"
-msgstr "Actualización del parche"
-
-#: git-add--interactive.perl:1390
+#: git-add--interactive.perl:1428
 #, perl-format
 msgid "Stage mode change [y,n,q,a,d%s,?]? "
-msgstr "Cambio de modo de stage [y,n,q,a,d%s,?]? "
+msgstr "¿Cambio de modo de stage [y,n,q,a,d%s,?]? "
 
-#: git-add--interactive.perl:1391
+#: git-add--interactive.perl:1429
 #, perl-format
 msgid "Stage deletion [y,n,q,a,d%s,?]? "
-msgstr "Aplicar stage al borrado [y,n,q,a,d%s,?]? "
+msgstr "¿Aplicar stage al borrado [y,n,q,a,d%s,?]? "
 
-#: git-add--interactive.perl:1392
+#: git-add--interactive.perl:1430
 #, perl-format
 msgid "Stage this hunk [y,n,q,a,d%s,?]? "
-msgstr "Aplicar stage a este hunk [y,n,q,a,d%s,?]? "
+msgstr "¿Aplicar stage a este hunk [y,n,q,a,d%s,?]? "
 
-#: git-add--interactive.perl:1395
+#: git-add--interactive.perl:1433
 #, perl-format
 msgid "Stash mode change [y,n,q,a,d%s,?]? "
-msgstr "Aplicar stash al cambio de modo [y,n,q,a,d%s,?]? "
+msgstr "¿Aplicar stash al cambio de modo [y,n,q,a,d%s,?]? "
 
-#: git-add--interactive.perl:1396
+#: git-add--interactive.perl:1434
 #, perl-format
 msgid "Stash deletion [y,n,q,a,d%s,?]? "
-msgstr "Aplicar stash al borrado [y,n,q,a,d%s,?]? "
+msgstr "¿Aplicar stash al borrado [y,n,q,a,d%s,?]? "
 
-#: git-add--interactive.perl:1397
+#: git-add--interactive.perl:1435
 #, perl-format
 msgid "Stash this hunk [y,n,q,a,d%s,?]? "
-msgstr "Aplicar stash a este hunk [y,n,q,a,d%s,?]? "
+msgstr "¿Aplicar stash a este hunk [y,n,q,a,d%s,?]? "
 
-#: git-add--interactive.perl:1400
+#: git-add--interactive.perl:1438
 #, perl-format
 msgid "Unstage mode change [y,n,q,a,d%s,?]? "
-msgstr "Sacar cambio de modo del stage [y,n,q,a,d%s,?]? "
+msgstr "¿Sacar cambio de modo del stage [y,n,q,a,d%s,?]? "
 
-#: git-add--interactive.perl:1401
+#: git-add--interactive.perl:1439
 #, perl-format
 msgid "Unstage deletion [y,n,q,a,d%s,?]? "
-msgstr "Sacar borrado del stage [y,n,q,a,d%s,?]? "
+msgstr "¿Sacar borrado del stage [y,n,q,a,d%s,?]? "
 
-#: git-add--interactive.perl:1402
+#: git-add--interactive.perl:1440
 #, perl-format
 msgid "Unstage this hunk [y,n,q,a,d%s,?]? "
-msgstr "Sacar este hunk del stage [y,n,q,a,d%s,?]? "
+msgstr "¿Sacar este hunk del stage [y,n,q,a,d%s,?]? "
 
-#: git-add--interactive.perl:1405
+#: git-add--interactive.perl:1443
 #, perl-format
 msgid "Apply mode change to index [y,n,q,a,d%s,?]? "
-msgstr "Aplicar cambio de modo al índice [y,n,q,a,d%s,?]? "
+msgstr "¿Aplicar cambio de modo al índice [y,n,q,a,d%s,?]? "
 
-#: git-add--interactive.perl:1406
+#: git-add--interactive.perl:1444
 #, perl-format
 msgid "Apply deletion to index [y,n,q,a,d%s,?]? "
-msgstr "Aplicar borrado al índice [y,n,q,a,d%s,?]? "
+msgstr "¿Aplicar borrado al índice [y,n,q,a,d%s,?]? "
 
-#: git-add--interactive.perl:1407
+#: git-add--interactive.perl:1445
 #, perl-format
 msgid "Apply this hunk to index [y,n,q,a,d%s,?]? "
-msgstr "Aplicar este hunk al índice [y,n,q,a,d%s,?]? "
+msgstr "¿Aplicar este hunk al índice [y,n,q,a,d%s,?]? "
 
-#: git-add--interactive.perl:1410
+#: git-add--interactive.perl:1448 git-add--interactive.perl:1463
 #, perl-format
 msgid "Discard mode change from worktree [y,n,q,a,d%s,?]? "
-msgstr "Descartar cambio de modo del árbol de trabajo [y,n,q,a,d%s,?]? "
+msgstr "¿Descartar cambio de modo del árbol de trabajo [y,n,q,a,d%s,?]? "
 
-#: git-add--interactive.perl:1411
+#: git-add--interactive.perl:1449 git-add--interactive.perl:1464
 #, perl-format
 msgid "Discard deletion from worktree [y,n,q,a,d%s,?]? "
-msgstr "Descartar borrado del árbol de trabajo [y,n,q,a,d%s,?]? "
+msgstr "¿Descartar borrado del árbol de trabajo [y,n,q,a,d%s,?]? "
 
-#: git-add--interactive.perl:1412
+#: git-add--interactive.perl:1450 git-add--interactive.perl:1465
 #, perl-format
 msgid "Discard this hunk from worktree [y,n,q,a,d%s,?]? "
-msgstr "Descartar este hunk del árbol de trabajo [y,n,q,a,d%s,?]? "
+msgstr "¿Descartar este hunk del árbol de trabajo [y,n,q,a,d%s,?]? "
 
-#: git-add--interactive.perl:1415
+#: git-add--interactive.perl:1453
 #, perl-format
 msgid "Discard mode change from index and worktree [y,n,q,a,d%s,?]? "
 msgstr ""
-"Descartar cambio de modo del índice y el árbol de trabajo [y,n,q,a,d%s,?]? "
+"¿Descartar cambio de modo del índice y el árbol de trabajo [y,n,q,a,d%s,?]? "
 
-#: git-add--interactive.perl:1416
+#: git-add--interactive.perl:1454
 #, perl-format
 msgid "Discard deletion from index and worktree [y,n,q,a,d%s,?]? "
-msgstr "Descartar borrado del índice y el árbol de trabajo [y,n,q,a,d%s,?]? "
+msgstr "¿Descartar borrado del índice y el árbol de trabajo [y,n,q,a,d%s,?]? "
 
-#: git-add--interactive.perl:1417
+#: git-add--interactive.perl:1455
 #, perl-format
 msgid "Discard this hunk from index and worktree [y,n,q,a,d%s,?]? "
-msgstr "Descartar este hunk del índice y el árbol de trabajo [y,n,q,a,d%s,?]? "
+msgstr ""
+"¿Descartar este hunk del índice y el árbol de trabajo [y,n,q,a,d%s,?]? "
 
-#: git-add--interactive.perl:1420
+#: git-add--interactive.perl:1458
 #, perl-format
 msgid "Apply mode change to index and worktree [y,n,q,a,d%s,?]? "
 msgstr ""
-"Aplicar cambio de modo para el índice y el árbol de trabajo [y,n,q,a,d%s,?]? "
+"¿Aplicar cambio de modo para el índice y el árbol de trabajo [y,n,q,a,d"
+"%s,?]? "
 
-#: git-add--interactive.perl:1421
+#: git-add--interactive.perl:1459
 #, perl-format
 msgid "Apply deletion to index and worktree [y,n,q,a,d%s,?]? "
-msgstr "Aplicar borrado al índice y al árbol de trabajo [y,n,q,a,d%s,?]? "
+msgstr "¿Aplicar borrado al índice y al árbol de trabajo [y,n,q,a,d%s,?]? "
 
-#: git-add--interactive.perl:1422
+#: git-add--interactive.perl:1460
 #, perl-format
 msgid "Apply this hunk to index and worktree [y,n,q,a,d%s,?]? "
-msgstr "Aplicar este hunk al índice y árbol de trabajo [y,n,q,a,d,/%s,?]? "
+msgstr "¿Aplicar este hunk al índice y árbol de trabajo [y,n,q,a,d,/%s,?]? "
 
-#: git-add--interactive.perl:1522
-msgid "No other hunks to goto\n"
-msgstr "No hay más pedazos para el ir\n"
+#: git-add--interactive.perl:1468
+#, perl-format
+msgid "Apply mode change to worktree [y,n,q,a,d%s,?]? "
+msgstr "¿Aplicar cambio de modo para el árbol de trabajo [y,n,q,a,d%s,?]? "
 
-#: git-add--interactive.perl:1529
-msgid "go to which hunk (<ret> to see more)? "
-msgstr "a que hunk ir (<enter> para ver mas)? "
+#: git-add--interactive.perl:1469
+#, perl-format
+msgid "Apply deletion to worktree [y,n,q,a,d%s,?]? "
+msgstr "¿Aplicar borrado al árbol de trabajo [y,n,q,a,d%s,?]? "
 
-#: git-add--interactive.perl:1531
-msgid "go to which hunk? "
-msgstr "a que hunk ir? "
+#: git-add--interactive.perl:1470
+#, perl-format
+msgid "Apply this hunk to worktree [y,n,q,a,d%s,?]? "
+msgstr "¿Aplicar este hunk al árbol de trabajo [y,n,q,a,d,/%s,?]? "
 
-#: git-add--interactive.perl:1540
+#: git-add--interactive.perl:1570
+msgid "No other hunks to goto\n"
+msgstr "No hay más pedazos para el ir\n"
+
+#: git-add--interactive.perl:1588
 #, perl-format
 msgid "Invalid number: '%s'\n"
-msgstr "Numero invalido: '%s'\n"
+msgstr "Numero inválido: '%s'\n"
 
-#: git-add--interactive.perl:1545
+#: git-add--interactive.perl:1593
 #, perl-format
 msgid "Sorry, only %d hunk available.\n"
 msgid_plural "Sorry, only %d hunks available.\n"
 msgstr[0] "Lo siento, solo %d hunk disponible.\n"
 msgstr[1] "Lo siento, solo %d hunks disponibles.\n"
 
-#: git-add--interactive.perl:1571
+#: git-add--interactive.perl:1619
 msgid "No other hunks to search\n"
 msgstr "No hay más pedazos para buscar\n"
 
-#: git-add--interactive.perl:1575
-msgid "search for regex? "
-msgstr "buscar para regexp? "
-
-#: git-add--interactive.perl:1588
+#: git-add--interactive.perl:1636
 #, perl-format
 msgid "Malformed search regexp %s: %s\n"
 msgstr "Regexp para la búsqueda mal formado %s: %s\n"
 
-#: git-add--interactive.perl:1598
+#: git-add--interactive.perl:1646
 msgid "No hunk matches the given pattern\n"
 msgstr "No hay hunks que concuerden con el patrón entregado.\n"
 
-#: git-add--interactive.perl:1610 git-add--interactive.perl:1632
+#: git-add--interactive.perl:1658 git-add--interactive.perl:1680
 msgid "No previous hunk\n"
 msgstr "No el anterior hunk\n"
 
-#: git-add--interactive.perl:1619 git-add--interactive.perl:1638
+#: git-add--interactive.perl:1667 git-add--interactive.perl:1686
 msgid "No next hunk\n"
 msgstr "No el siguiente hunk\n"
 
-#: git-add--interactive.perl:1644
+#: git-add--interactive.perl:1692
 msgid "Sorry, cannot split this hunk\n"
 msgstr "Perdón, no se puede dividir este pedazo\n"
 
-#: git-add--interactive.perl:1650
+#: git-add--interactive.perl:1698
 #, perl-format
 msgid "Split into %d hunk.\n"
 msgid_plural "Split into %d hunks.\n"
 msgstr[0] "Cortar en %d hunk.\n"
 msgstr[1] "Cortar en  %d hunks.\n"
 
-#: git-add--interactive.perl:1660
+#: git-add--interactive.perl:1708
 msgid "Sorry, cannot edit this hunk\n"
 msgstr "Perdón, no se puede editar este pedazo\n"
 
-#: git-add--interactive.perl:1706
-msgid "Review diff"
-msgstr "Revisión de  diff"
-
 #. TRANSLATORS: please do not translate the command names
 #. 'status', 'update', 'revert', etc.
-#: git-add--interactive.perl:1725
+#: git-add--interactive.perl:1773
 msgid ""
 "status        - show paths with changes\n"
 "update        - add working tree state to the staged set of changes\n"
@@ -17876,55 +23947,56 @@ msgstr ""
 "add untracked - agrega contenidos de archivos no rastreados al grupo de "
 "cambios del area de stage\n"
 
-#: git-add--interactive.perl:1742 git-add--interactive.perl:1747
-#: git-add--interactive.perl:1750 git-add--interactive.perl:1757
-#: git-add--interactive.perl:1761 git-add--interactive.perl:1767
+#: git-add--interactive.perl:1790 git-add--interactive.perl:1795
+#: git-add--interactive.perl:1798 git-add--interactive.perl:1805
+#: git-add--interactive.perl:1808 git-add--interactive.perl:1815
+#: git-add--interactive.perl:1819 git-add--interactive.perl:1825
 msgid "missing --"
 msgstr "falta --"
 
-#: git-add--interactive.perl:1763
+#: git-add--interactive.perl:1821
 #, perl-format
 msgid "unknown --patch mode: %s"
 msgstr "modo --patch desconocido: %s"
 
-#: git-add--interactive.perl:1769 git-add--interactive.perl:1775
+#: git-add--interactive.perl:1827 git-add--interactive.perl:1833
 #, perl-format
 msgid "invalid argument %s, expecting --"
-msgstr "argumento invalido %s, se esperaba --"
+msgstr "argumento inválido %s, se esperaba --"
 
-#: git-send-email.perl:130
+#: git-send-email.perl:138
 msgid "local zone differs from GMT by a non-minute interval\n"
 msgstr "la zona local difiere de GMT por un intervalo de cero minutos\n"
 
-#: git-send-email.perl:137 git-send-email.perl:143
+#: git-send-email.perl:145 git-send-email.perl:151
 msgid "local time offset greater than or equal to 24 hours\n"
 msgstr "el offset del tiempo local es mayor o igual a 24 horas\n"
 
-#: git-send-email.perl:211 git-send-email.perl:217
+#: git-send-email.perl:223 git-send-email.perl:229
 msgid "the editor exited uncleanly, aborting everything"
 msgstr "el editor se cerro inapropiadamente, abortando todo"
 
-#: git-send-email.perl:294
+#: git-send-email.perl:310
 #, perl-format
 msgid ""
 "'%s' contains an intermediate version of the email you were composing.\n"
 msgstr ""
 "'%s' contiene una versión intermedia del correo que se estaba generando.\n"
 
-#: git-send-email.perl:299
+#: git-send-email.perl:315
 #, perl-format
 msgid "'%s.final' contains the composed email.\n"
 msgstr "'%s.final' contiene el email generado.\n"
 
-#: git-send-email.perl:317
+#: git-send-email.perl:408
 msgid "--dump-aliases incompatible with other options\n"
 msgstr "--dump-aliases no es compatible con otras opciones.\n"
 
-#: git-send-email.perl:383 git-send-email.perl:638
+#: git-send-email.perl:481 git-send-email.perl:683
 msgid "Cannot run git format-patch from outside a repository\n"
 msgstr "No se puede ejecutar git format-patch desde fuera del repositorio.\n"
 
-#: git-send-email.perl:386
+#: git-send-email.perl:484
 msgid ""
 "`batch-size` and `relogin` must be specified together (via command-line or "
 "configuration option)\n"
@@ -17932,37 +24004,37 @@ msgstr ""
 "`batch-size` y `relogin` deben ser especificados juntos (via la línea de "
 "comando o por opción de configuración)\n"
 
-#: git-send-email.perl:456
+#: git-send-email.perl:497
 #, perl-format
 msgid "Unknown --suppress-cc field: '%s'\n"
 msgstr "Campo --suppress-cc desconocido: '%s'\n"
 
-#: git-send-email.perl:485
+#: git-send-email.perl:528
 #, perl-format
 msgid "Unknown --confirm setting: '%s'\n"
 msgstr "Configuración --confirm desconocida: '%s'\n"
 
-#: git-send-email.perl:513
+#: git-send-email.perl:556
 #, perl-format
 msgid "warning: sendmail alias with quotes is not supported: %s\n"
 msgstr "peligro: alias de sendmail  con comillas no es soportado: %s\n"
 
-#: git-send-email.perl:515
+#: git-send-email.perl:558
 #, perl-format
 msgid "warning: `:include:` not supported: %s\n"
 msgstr "peligro: `:include:` no soportado: %s\n"
 
-#: git-send-email.perl:517
+#: git-send-email.perl:560
 #, perl-format
 msgid "warning: `/file` or `|pipe` redirection not supported: %s\n"
 msgstr "advertencia: redirección `/file` o `|pipe` no soportada : %s\n"
 
-#: git-send-email.perl:522
+#: git-send-email.perl:565
 #, perl-format
 msgid "warning: sendmail line is not recognized: %s\n"
 msgstr "advertencia: línea sendmail no reconocida: %s\n"
 
-#: git-send-email.perl:604
+#: git-send-email.perl:649
 #, perl-format
 msgid ""
 "File '%s' exists but it could also be the range of commits\n"
@@ -17977,12 +24049,12 @@ msgstr ""
 "    * Diciendo \"./%s\" si se quiere decir un archivo; o\n"
 "    * Agregando la opción --format-patch si se quiere decir un rango.\n"
 
-#: git-send-email.perl:625
+#: git-send-email.perl:670
 #, perl-format
 msgid "Failed to opendir %s: %s"
 msgstr "Falló al abrir directorio %s: %s"
 
-#: git-send-email.perl:649
+#: git-send-email.perl:694
 #, perl-format
 msgid ""
 "fatal: %s: %s\n"
@@ -17991,7 +24063,7 @@ msgstr ""
 "fatal: %s: %s\n"
 "peligro: no se mandaron parches\n"
 
-#: git-send-email.perl:660
+#: git-send-email.perl:705
 msgid ""
 "\n"
 "No patch files specified!\n"
@@ -18001,17 +24073,17 @@ msgstr ""
 "No se especificaron parches!\n"
 "\n"
 
-#: git-send-email.perl:673
+#: git-send-email.perl:718
 #, perl-format
 msgid "No subject line in %s?"
-msgstr "No hay línea de subject en %s?"
+msgstr "¿No hay línea de subject en %s?"
 
-#: git-send-email.perl:683
+#: git-send-email.perl:728
 #, perl-format
 msgid "Failed to open for writing %s: %s"
 msgstr "Falló al abrir para escritura %s: %s"
 
-#: git-send-email.perl:694
+#: git-send-email.perl:739
 msgid ""
 "Lines beginning in \"GIT:\" will be removed.\n"
 "Consider including an overall diffstat or table of contents\n"
@@ -18019,33 +24091,33 @@ msgid ""
 "\n"
 "Clear the body content if you don't wish to send a summary.\n"
 msgstr ""
-"Lineas que comienzan en \"GIT:\" serán removidas.\n"
+"Lineas que comienzan en \"GIT:\" serán eliminadas.\n"
 "Considere incluir un diffstat global o una tabla de contenidos\n"
-"para el parche que esta escribiendo.\n"
+"para el parche que estás escribiendo.\n"
 "\n"
-"Limpiar el contenido de body si usted no desea mandar un resumen.\n"
+"Limpiar el contenido de body si no deseas mandar un resumen.\n"
 
-#: git-send-email.perl:718
+#: git-send-email.perl:763
 #, perl-format
 msgid "Failed to open %s: %s"
 msgstr "Falló al abrir %s: %s"
 
-#: git-send-email.perl:735
+#: git-send-email.perl:780
 #, perl-format
 msgid "Failed to open %s.final: %s"
 msgstr "Falló al abrir %s.final: %s"
 
-#: git-send-email.perl:778
+#: git-send-email.perl:823
 msgid "Summary email is empty, skipping it\n"
-msgstr "Archivo de resumen esta vacío, saltando al siguiente\n"
+msgstr "Archivo de resumen está vacío, saltando al siguiente\n"
 
 #. TRANSLATORS: please keep [y/N] as is.
-#: git-send-email.perl:813
+#: git-send-email.perl:858
 #, perl-format
 msgid "Are you sure you want to use <%s> [y/N]? "
-msgstr "Esta seguro de que desea usar <%s> [y/N]? "
+msgstr "¿Estás seguro de que deseas usar <%s> [y/N]? "
 
-#: git-send-email.perl:868
+#: git-send-email.perl:913
 msgid ""
 "The following files are 8bit, but do not declare a Content-Transfer-"
 "Encoding.\n"
@@ -18053,11 +24125,11 @@ msgstr ""
 "Los siguientes archivos son 8bit, pero no declaran un Content-Transfer-"
 "Encoding.\n"
 
-#: git-send-email.perl:873
+#: git-send-email.perl:918
 msgid "Which 8bit encoding should I declare [UTF-8]? "
-msgstr "Que codificación de 8bit debería declarar [UTF-8]? "
+msgstr "¿Que codificación de 8bit debería declarar [UTF-8]? "
 
-#: git-send-email.perl:881
+#: git-send-email.perl:926
 #, perl-format
 msgid ""
 "Refusing to send because the patch\n"
@@ -18070,39 +24142,39 @@ msgstr ""
 "tiene el template  '*** SUBJECT HERE ***'. Agrega --force si realmente lo "
 "deseas mandar.\n"
 
-#: git-send-email.perl:900
+#: git-send-email.perl:945
 msgid "To whom should the emails be sent (if anyone)?"
-msgstr "A quien se deben mandar los correos (si existe)?"
+msgstr "¿A quien se deben mandar los correos (si existe)?"
 
-#: git-send-email.perl:918
+#: git-send-email.perl:963
 #, perl-format
 msgid "fatal: alias '%s' expands to itself\n"
 msgstr "fatal: alias '%s' se expande a si mismo\n"
 
-#: git-send-email.perl:930
+#: git-send-email.perl:975
 msgid "Message-ID to be used as In-Reply-To for the first email (if any)? "
 msgstr ""
-"Qué id de mensaje será usado como En-Respuesta-Para en el primer email (si "
+"¿Qué id de mensaje será usado como En-Respuesta-Para en el primer email (si "
 "existe alguno)? "
 
-#: git-send-email.perl:988 git-send-email.perl:996
+#: git-send-email.perl:1033 git-send-email.perl:1041
 #, perl-format
 msgid "error: unable to extract a valid address from: %s\n"
-msgstr "error: no es posible extraer una dirección valida de %s\n"
+msgstr "error: no es posible extraer una dirección válida de %s\n"
 
 #. TRANSLATORS: Make sure to include [q] [d] [e] in your
 #. translation. The program will only accept English input
 #. at this point.
-#: git-send-email.perl:1000
+#: git-send-email.perl:1045
 msgid "What to do with this address? ([q]uit|[d]rop|[e]dit): "
-msgstr "Que hacer con esta dirección? ([q]salir|[d]botar|[e]ditar): "
+msgstr "¿Que hacer con esta dirección? ([q]salir|[d]botar|[e]ditar): "
 
-#: git-send-email.perl:1317
+#: git-send-email.perl:1362
 #, perl-format
 msgid "CA path \"%s\" does not exist"
 msgstr "Ruta CA \"%s\" no existe"
 
-#: git-send-email.perl:1400
+#: git-send-email.perl:1445
 msgid ""
 "    The Cc list above has been expanded by additional\n"
 "    addresses found in the patch commit message. By default\n"
@@ -18122,7 +24194,7 @@ msgstr ""
 "    Este comportamiento is controlado por el valor de configuración "
 "sendemail.confirm.\n"
 "\n"
-"    Para mas información, ejecuta 'git send-email --help'.\n"
+"    Para más información, ejecuta 'git send-email --help'.\n"
 "    Para mantener el comportamiento actual, pero evitar este mensaje,\n"
 "    ejecuta 'git config --global sendemail.confirm auto'.\n"
 "\n"
@@ -18130,133 +24202,445 @@ msgstr ""
 #. TRANSLATORS: Make sure to include [y] [n] [e] [q] [a] in your
 #. translation. The program will only accept English input
 #. at this point.
-#: git-send-email.perl:1415
+#: git-send-email.perl:1460
 msgid "Send this email? ([y]es|[n]o|[e]dit|[q]uit|[a]ll): "
-msgstr "Mandar este email? ([y]si||[n]o|[e]editar|[q]salir|[a]todo): "
+msgstr "¿Mandar este email? ([y]si||[n]o|[e]editar|[q]salir|[a]todo): "
 
-#: git-send-email.perl:1418
+#: git-send-email.perl:1463
 msgid "Send this email reply required"
 msgstr "Necesitas mandar esta respuesta de email"
 
-#: git-send-email.perl:1446
+#: git-send-email.perl:1491
 msgid "The required SMTP server is not properly defined."
 msgstr "El servidor SMTP no esta definido adecuadamente."
 
-#: git-send-email.perl:1493
+#: git-send-email.perl:1538
 #, perl-format
 msgid "Server does not support STARTTLS! %s"
-msgstr "Servidor no soporta STARTTLS! %s"
+msgstr "¡El servidor no soporta STARTTLS! %s"
 
-#: git-send-email.perl:1498 git-send-email.perl:1502
+#: git-send-email.perl:1543 git-send-email.perl:1547
 #, perl-format
 msgid "STARTTLS failed! %s"
-msgstr "Falló STARTTLS! %s"
+msgstr "¡Falló STARTTLS! %s"
 
-#: git-send-email.perl:1512
+#: git-send-email.perl:1556
 msgid "Unable to initialize SMTP properly. Check config and use --smtp-debug."
 msgstr ""
 "No es posible inicializar SMTP adecuadamente. Verificar config y usar ---"
 "smtp-debug."
 
-#: git-send-email.perl:1530
+#: git-send-email.perl:1574
 #, perl-format
 msgid "Failed to send %s\n"
 msgstr "Falló al enviar %s\n"
 
-#: git-send-email.perl:1533
+#: git-send-email.perl:1577
 #, perl-format
 msgid "Dry-Sent %s\n"
 msgstr "Dry-Sent %s\n"
 
-#: git-send-email.perl:1533
+#: git-send-email.perl:1577
 #, perl-format
 msgid "Sent %s\n"
 msgstr "Enviado %s\n"
 
-#: git-send-email.perl:1535
+#: git-send-email.perl:1579
 msgid "Dry-OK. Log says:\n"
 msgstr "Dry-OK. Log dice:\n"
 
-#: git-send-email.perl:1535
+#: git-send-email.perl:1579
 msgid "OK. Log says:\n"
 msgstr "OK. Log dice:\n"
 
-#: git-send-email.perl:1547
+#: git-send-email.perl:1591
 msgid "Result: "
 msgstr "Resultado: "
 
-#: git-send-email.perl:1550
+#: git-send-email.perl:1594
 msgid "Result: OK\n"
 msgstr "Resultado: OK\n"
 
-#: git-send-email.perl:1568
+#: git-send-email.perl:1612
 #, perl-format
 msgid "can't open file %s"
 msgstr "no se puede abrir el archivo %s"
 
-#: git-send-email.perl:1615 git-send-email.perl:1635
+#: git-send-email.perl:1659 git-send-email.perl:1679
 #, perl-format
 msgid "(mbox) Adding cc: %s from line '%s'\n"
 msgstr "(mbox) Agregando cc: %s de línea '%s'\n"
 
-#: git-send-email.perl:1621
+#: git-send-email.perl:1665
 #, perl-format
 msgid "(mbox) Adding to: %s from line '%s'\n"
 msgstr "(mbox) Agregando para: %s de la línea '%s'\n"
 
-#: git-send-email.perl:1674
+#: git-send-email.perl:1718
 #, perl-format
 msgid "(non-mbox) Adding cc: %s from line '%s'\n"
 msgstr "(non-mbox) Agregando cc: %s de la línea '%s'\n"
 
-#: git-send-email.perl:1699
+#: git-send-email.perl:1753
 #, perl-format
 msgid "(body) Adding cc: %s from line '%s'\n"
 msgstr "(body) Agregando cc: %s de la línea '%s'\n"
 
-#: git-send-email.perl:1817
+#: git-send-email.perl:1864
 #, perl-format
 msgid "(%s) Could not execute '%s'"
 msgstr "(%s) no se pudo ejecutar '%s'"
 
-#: git-send-email.perl:1824
+#: git-send-email.perl:1871
 #, perl-format
 msgid "(%s) Adding %s: %s from: '%s'\n"
 msgstr "(%s) Agregando %s: %s de: '%s'\n"
 
-#: git-send-email.perl:1828
+#: git-send-email.perl:1875
 #, perl-format
 msgid "(%s) failed to close pipe to '%s'"
 msgstr "(%s) falló al cerrar el pipe para '%s'"
 
-#: git-send-email.perl:1855
+#: git-send-email.perl:1905
 msgid "cannot send message as 7bit"
 msgstr "no se puede mandar mensaje como 7bit"
 
-#: git-send-email.perl:1863
+#: git-send-email.perl:1913
 msgid "invalid transfer encoding"
-msgstr "codificación de transferencia invalida"
+msgstr "codificación de transferencia inválida"
 
-#: git-send-email.perl:1901 git-send-email.perl:1952 git-send-email.perl:1962
+#: git-send-email.perl:1954 git-send-email.perl:2006 git-send-email.perl:2016
 #, perl-format
 msgid "unable to open %s: %s\n"
 msgstr "no es posible abrir %s: %s\n"
 
-#: git-send-email.perl:1904
+#: git-send-email.perl:1957
 #, perl-format
 msgid "%s: patch contains a line longer than 998 characters"
-msgstr "%s: el parche contiene una línea con mas de 998 caracteres"
+msgstr "%s: el parche contiene una línea con más de 998 caracteres"
 
-#: git-send-email.perl:1920
+#: git-send-email.perl:1974
 #, perl-format
 msgid "Skipping %s with backup suffix '%s'.\n"
 msgstr "Saltando %s con el sufijo de backup '%s'.\n"
 
 #. TRANSLATORS: please keep "[y|N]" as is.
-#: git-send-email.perl:1924
+#: git-send-email.perl:1978
 #, perl-format
 msgid "Do you really want to send %s? [y|N]: "
-msgstr "Realmente deseas mandar %s?[y|N]: "
+msgstr "¿Realmente deseas mandar %s?[y|N]: "
+
+#, c-format
+#~ msgid "unable to get tree for %s"
+#~ msgstr "no se pudo obtener árbol para %s"
+
+#~ msgid "Use an experimental heuristic to improve diffs"
+#~ msgstr "Usar un heurístico experimental para mejorar los diffs"
+
+#~ msgid "git commit-graph [--object-dir <objdir>]"
+#~ msgstr "git commit-graph [--object-dir <objdir>]"
+
+#~ msgid "git commit-graph read [--object-dir <objdir>]"
+#~ msgstr "git commit-graph read [--object-dir <objdir>]"
+
+#~ msgid "unknown core.untrackedCache value '%s'; using 'keep' default value"
+#~ msgstr ""
+#~ "valor core.untrackedCache '%s' desconocido; usando 'keep' como valor por "
+#~ "defecto"
+
+#~ msgid "cannot change partial clone promisor remote"
+#~ msgstr "no se puede cambiar un clon parcial remoto promisor"
+
+#~ msgid "error building trees"
+#~ msgstr "error construyendo árboles"
+
+#~ msgid "invalid date format '%s' in '%s'"
+#~ msgstr "formato de fecha inválido '%s' en '%s'"
+
+#~ msgid "writing root commit"
+#~ msgstr "escribiendo commit raíz"
+
+#~ msgid "staged changes in the following files may be lost: %s"
+#~ msgstr ""
+#~ "cambios en el área de stage en el siguiente archivo pueden ser perdidos: "
+#~ "%s"
+
+#~ msgid ""
+#~ "--filter can only be used with the remote configured in extensions."
+#~ "partialClone"
+#~ msgstr ""
+#~ "--filter solo puede ser usado con el remoto configurado en extensions."
+#~ "partialClone"
+
+#~ msgid "verify commit-msg hook"
+#~ msgstr "verificar el hook commit-msg"
+
+#~ msgid "cannot combine '--rebase-merges' with '--strategy-option'"
+#~ msgstr "no se puede combinar '--rebase-merges' con '--strategy-option'"
+
+#~ msgid "invalid sparse value '%s'"
+#~ msgstr "valor disperso inválido: '%s'"
+
+#~ msgid "Server supports multi_ack_detailed"
+#~ msgstr "El servidor soporta ulti_ack_detailed"
+
+#~ msgid "Server supports no-done"
+#~ msgstr "El servidor soporta no-done"
+
+#~ msgid "Server supports multi_ack"
+#~ msgstr "El servidor soporta multi_ack"
+
+#~ msgid "Server supports side-band-64k"
+#~ msgstr "El servidor soporta side-band-64k"
+
+#~ msgid "Server supports side-band"
+#~ msgstr "El servidor soporta side-band"
+
+#~ msgid "Server supports allow-tip-sha1-in-want"
+#~ msgstr "El servidor soporta allow-tip-sha1-in-want"
+
+#~ msgid "Server supports allow-reachable-sha1-in-want"
+#~ msgstr "El servidor soporta allow-reachable-sha1-in-want"
+
+#~ msgid "Server supports ofs-delta"
+#~ msgstr "El servidor soporta ofs-delta"
+
+#~ msgid "(HEAD detached at %s)"
+#~ msgstr "(HEAD desacoplado en %s)"
+
+#~ msgid "(HEAD detached from %s)"
+#~ msgstr "(HEAD desacoplado de %s)"
+
+#~ msgid "Checking out files"
+#~ msgstr "Revisando archivos"
+
+#~ msgid "cannot be interactive without stdin connected to a terminal."
+#~ msgstr "no se puede ser interactivo sin stdin conectado a un terminal."
+
+#~ msgid "failed to stat %s\n"
+#~ msgstr "falló al analizar %s\n"
+
+#~ msgid ""
+#~ "If you wish to skip this commit, use:\n"
+#~ "\n"
+#~ "    git reset\n"
+#~ "\n"
+#~ "Then \"git cherry-pick --continue\" will resume cherry-picking\n"
+#~ "the remaining commits.\n"
+#~ msgstr ""
+#~ "Si quiere saltar este commit, use:\n"
+#~ "\n"
+#~ "    git reset\n"
+#~ "\n"
+#~ "Luego \"git cherry-pick --continue\" continuara el cherry-picking\n"
+#~ "para los commits restantes.\n"
+
+#~ msgid "unrecognized verb: %s"
+#~ msgstr "verbo no reconocido: %s"
+
+#~ msgid "hash version %X does not match version %X"
+#~ msgstr "versión de hash %X no concuerda con versión %X"
+
+#~ msgid "option '%s' requires a value"
+#~ msgstr "opción '%s' requiere un valor"
+
+#~ msgid "could not transform the todo list"
+#~ msgstr "no se pudo transformar lista de pendientes"
+
+#~ msgid "default"
+#~ msgstr "default"
+
+#~ msgid "Could not create directory '%s'"
+#~ msgstr "No se pudo crear el directorio '%s'"
+
+#~ msgid "allow rerere to update index with resolved conflict"
+#~ msgstr "permitir rerere actualizar index con conflictos resueltos"
+
+#~ msgid "could not open %s"
+#~ msgstr "no se pudo abrir %s"
+
+#~ msgid "Could not move back to $head_name"
+#~ msgstr "No se puede regresar a $head_name"
+
+#~ msgid ""
+#~ "It seems that there is already a $state_dir_base directory, and\n"
+#~ "I wonder if you are in the middle of another rebase.  If that is the\n"
+#~ "case, please try\n"
+#~ "\t$cmd_live_rebase\n"
+#~ "If that is not the case, please\n"
+#~ "\t$cmd_clear_stale_rebase\n"
+#~ "and run me again.  I am stopping in case you still have something\n"
+#~ "valuable there."
+#~ msgstr ""
+#~ "Parece que ya hay un directorio $state_dir_base, y\n"
+#~ "me pregunto si está en medio de otro rebase. Si ese es el \n"
+#~ "caso, por favor intente\n"
+#~ "\t$cmd_live_rebase\n"
+#~ "Si no es el caso, por favor\n"
+#~ "\t$cmd_clear_stale_rebase\n"
+#~ "y ejecúteme nuevamente.  Me estoy deteniendo en caso de que tenga\n"
+#~ "algo de valor ahí."
+
+#~ msgid ""
+#~ "fatal: cannot combine am options with either interactive or merge options"
+#~ msgstr ""
+#~ "fatal: no se puede combinar opciones am con opciones interactivas o de "
+#~ "merge"
+
+#~ msgid "fatal: cannot combine '--signoff' with '--preserve-merges'"
+#~ msgstr "fatal: no se puede combinar '--signoff' con '--preserve-merges'"
+
+#~ msgid "fatal: cannot combine '--preserve-merges' with '--rebase-merges'"
+#~ msgstr ""
+#~ "fatal: no se puede combinar '--preserve-merges' con '--rebase-merges'"
+
+#~ msgid "fatal: cannot combine '--rebase-merges' with '--strategy-option'"
+#~ msgstr ""
+#~ "fatal: no se puede combinar '--rebase-merges' con '--strategy-option'"
+
+#~ msgid "fatal: cannot combine '--rebase-merges' with '--strategy'"
+#~ msgstr "fatal: no se puede combinar '--rebase-merges' con '--strategy'"
+
+#~ msgid "invalid upstream '$upstream_name'"
+#~ msgstr "upstream inválido '$upstream_name'"
+
+#~ msgid "$onto_name: there are more than one merge bases"
+#~ msgstr "$onto_name: hay más de una base de fusión"
+
+#~ msgid "$onto_name: there is no merge base"
+#~ msgstr "$onto_name: no hay base de fusión"
+
+#~ msgid "Does not point to a valid commit: $onto_name"
+#~ msgstr "No apunta a un commit válido: $onto_name"
+
+#~ msgid "fatal: no such branch/commit '$branch_name'"
+#~ msgstr "fatal: no existe la rama/commit: '$branch_name'"
+
+#~ msgid "Created autostash: $stash_abbrev"
+#~ msgstr "Autostash creado: $stash_abbrev"
+
+#~ msgid "Current branch $branch_name is up to date."
+#~ msgstr "La rama actual $branch_name está actualizada."
+
+#~ msgid "Current branch $branch_name is up to date, rebase forced."
+#~ msgstr "Rama actual $branch_name está actualizada, rebase forzado."
+
+#~ msgid "Changes to $onto:"
+#~ msgstr "Cambios hacia $onto:"
+
+#~ msgid "Changes from $mb to $onto:"
+#~ msgstr "Cambios desde $mb a $onto:"
+
+#~ msgid "Fast-forwarded $branch_name to $onto_name."
+#~ msgstr "Avance rápido de $branch_name a $onto_name."
+
+#~ msgid "First, rewinding head to replay your work on top of it..."
+#~ msgstr ""
+#~ "En primer lugar, rebobinando HEAD para después reproducir tus cambios "
+#~ "encima de ésta..."
+
+#~ msgid "ignoring unknown color-moved-ws mode '%s'"
+#~ msgstr "ignorando modo desconocido color-moved-ws '%s'"
+
+#~ msgid "only 'tree:0' is supported"
+#~ msgstr "solo 'tree:0' es soportado"
+
+#~ msgid "Renaming %s to %s and %s to %s instead"
+#~ msgstr "Renombrando %s a %s y %s a %s más bien"
+
+#~ msgid "Adding merged %s"
+#~ msgstr "Agregar %s fusionado"
+
+#~ msgid "Internal error"
+#~ msgstr "Error interno"
+
+#~ msgid "mainline was specified but commit %s is not a merge."
+#~ msgstr "línea principal especificada pero el commit %s no es una fusión."
+
+#~ msgid "unable to write sha1 filename %s"
+#~ msgstr "incapaz de escribir el nombre de archivo sha1 %s"
+
+#~ msgid "cannot read sha1_file for %s"
+#~ msgstr "no se puede leer sha1_file para %s"
+
+#~ msgid ""
+#~ "error: cannot combine interactive options (--interactive, --exec, --"
+#~ "rebase-merges, --preserve-merges, --keep-empty, --root + --onto) with am "
+#~ "options (%s)"
+#~ msgstr ""
+#~ "error: no se puede combinar opciones interactivas (--interactive, --exec, "
+#~ "--rebase-merges, --preserve-merges, --keep-empty, --root + --onto) con "
+#~ "opciones (%s)"
+
+#~ msgid ""
+#~ "error: cannot combine merge options (--merge, --strategy, --strategy-"
+#~ "option) with am options (%s)"
+#~ msgstr ""
+#~ "error: no se puede combinar opciones de merge (--merge, --strategy, --"
+#~ "strategy-option) con opciones de am (%s)"
+
+#~ msgid "unrecognised option: '$arg'"
+#~ msgstr "opción no reconocida: '$arg'"
+
+#~ msgid "'$invalid' is not a valid commit"
+#~ msgstr "'$invalid' no es un commit válido"
+
+#~ msgid "could not parse '%s' (looking for '%s')"
+#~ msgstr "no se pudo configurar '%s' (buscando '%s')"
+
+#~ msgid "deprecated synonym for --create-reflog"
+#~ msgstr "sinónimo deprecado para --create-reflog"
+
+#~ msgid "Can't stat %s"
+#~ msgstr "No se puede definir %s"
+
+#~ msgid "abort rebase"
+#~ msgstr "abortar rebase"
+
+#~ msgid "make rebase script"
+#~ msgstr "generar script de rebase"
+
+#~ msgid "No such remote: %s"
+#~ msgstr "No existe el remoto: %s"
+
+#~ msgid "cannot move a locked working tree"
+#~ msgstr "no se puede mover un árbol de trabajo encerrado"
+
+#~ msgid "cannot remove a locked working tree"
+#~ msgstr "no se puede eliminar árbol de trabajo encerrado"
+
+#~ msgid ""
+#~ "\n"
+#~ "\tHowever, if you remove everything, the rebase will be aborted.\n"
+#~ "\n"
+#~ "\t"
+#~ msgstr ""
+#~ "\n"
+#~ "\tComo sea, si quieres borrar todo, el rebase será abortado.\n"
+#~ "\n"
+#~ "\t"
+
+#~ msgid "Dirty index: cannot merge (dirty: %s)"
+#~ msgstr "Índice sucio: no se puede fusionar (sucio: %s)"
+
+#~ msgid "(+/-)x"
+#~ msgstr "(+/-)x"
+
+#~ msgid "<command>"
+#~ msgstr "<comando>"
+
+#~ msgid "push|fetch"
+#~ msgstr "push|fetch"
+
+#~ msgid "w[,i1[,i2]]"
+#~ msgstr "w[,i1[,i2]]"
+
+#~ msgid "Entering '$displaypath'"
+#~ msgstr "Entrando a '$displaypath'"
+
+#~ msgid "Stopping at '$displaypath'; script returned non-zero status."
+#~ msgstr ""
+#~ "Deteniendo en '$displaypath'; script devolvió un status distinto de cero."
 
 #~ msgid "Everyday Git With 20 Commands Or So"
 #~ msgstr "Git diario con 20 comandos o algo así"
@@ -18289,7 +24673,7 @@ msgstr "Realmente deseas mandar %s?[y|N]
 #~ msgstr "Error en el objeto"
 
 #~ msgid "git fetch-pack: expected ACK/NAK, got EOF"
-#~ msgstr "git getch-pack: se esperaba ACK/NAK, se obtuvo EOF"
+#~ msgstr "git fetch-pack: se esperaba ACK/NAK, se obtuvo EOF"
 
 #~ msgid "invalid filter-spec expression '%s'"
 #~ msgstr "expresión filter-spec inválida '%s'"
@@ -18316,15 +24700,9 @@ msgstr "Realmente deseas mandar %s?[y|N]
 #~ "los strings vacíos como pathspecs serán inválidas en las próximas "
 #~ "versiones. por favor use . si quería hacer coincidir todas las rutas"
 
-#~ msgid "unable to open '%s' for writing"
-#~ msgstr "No se pudo abrir '%s' para escritura"
-
 #~ msgid "could not truncate '%s'"
 #~ msgstr "no se pudo truncar '%s'"
 
-#~ msgid "could not finish '%s'"
-#~ msgstr "no se pudo finalizar '%s'"
-
 #~ msgid "could not close %s"
 #~ msgstr "no se pudo cerrar %s"
 
@@ -18337,12 +24715,6 @@ msgstr "Realmente deseas mandar %s?[y|N]
 #~ msgid "Don't know how to clone %s"
 #~ msgstr "No se sabe como clonar %s"
 
-#~ msgid "show ignored files"
-#~ msgstr "mostrar archivos ignorados"
-
-#~ msgid "%s is not a valid '%s' object"
-#~ msgstr "%s no es un objeto '%s' válido"
-
 #~ msgid "Don't know how to fetch from %s"
 #~ msgstr "No se sabe como extraer de %s"
 
@@ -18381,9 +24753,6 @@ msgstr "Realmente deseas mandar %s?[y|N]
 #~ msgid "basename"
 #~ msgstr "nombre base"
 
-#~ msgid "prepend parent project's basename to output"
-#~ msgstr "anteponer el nombre base del proyecto padre a la salida"
-
 #~ msgid ""
 #~ "Warning: the SHA-1 is missing or isn't a commit in the following line:\n"
 #~ " - $line"
diff -pruN 1.2.1+git2.18.0-1/git/po/fr.po 1.2.3+git2.25.1-1/git/po/fr.po
--- 1.2.1+git2.18.0-1/git/po/fr.po	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/po/fr.po	2020-02-17 04:47:35.000000000 +0000
@@ -1,7 +1,7 @@
 # French translations for Git.
-# Copyright (C) 2018 Jean-Noël Avila <jn.avila@free.fr>
+# Copyright (C) 2019 Jean-Noël Avila <jn.avila@free.fr>
 # This file is distributed under the same license as the Git package.
-# Jean-Noël Avila <jn.avila@free.fr>, 2018.
+# Jean-Noël Avila <jn.avila@free.fr>, 2013-2019.
 # Sébastien Helleu <flashcode@flashtux.org>, 2013.
 #
 # French translations of common Git words used in this file:
@@ -30,6 +30,7 @@
 #   to deflate       |  compresser
 #   email            |  courriel
 #   entry            |  élément
+#   fanout           |  dispersion
 #   fast-forward     |  avance rapide
 #   fast-forwarded   |  mis à jour en avance rapide
 #   to fetch         |  rapatrier
@@ -74,47 +75,475 @@ msgid ""
 msgstr ""
 "Project-Id-Version: git\n"
 "Report-Msgid-Bugs-To: Git Mailing List <git@vger.kernel.org>\n"
-"POT-Creation-Date: 2018-06-16 22:06+0800\n"
-"PO-Revision-Date: 2018-06-16 20:42+0200\n"
-"Last-Translator: Jean-Noël Avila <jn.avila@free.fr>\n"
+"POT-Creation-Date: 2019-12-30 08:48+0800\n"
+"PO-Revision-Date: 2019-12-31 17:37+0100\n"
+"Last-Translator: Cédric Malard <c.malard-git@valdun.net>\n"
 "Language-Team: Jean-Noël Avila <jn.avila@free.fr>\n"
 "Language: fr\n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
 "Plural-Forms: nplurals=2; plural=n<=1 ?0 : 1;\n"
+"X-Generator: Poedit 2.2.3\n"
 
-#: advice.c:92
+#: add-interactive.c:347
+#, c-format
+msgid "Huh (%s)?"
+msgstr "Hein (%s) ?"
+
+#: add-interactive.c:500 add-interactive.c:801 sequencer.c:3216
+#: sequencer.c:3656 builtin/rebase.c:871 builtin/rebase.c:1643
+#: builtin/rebase.c:2019 builtin/rebase.c:2063
+msgid "could not read index"
+msgstr "impossible de lire l'index"
+
+#: add-interactive.c:555 git-add--interactive.perl:269
+#: git-add--interactive.perl:294
+msgid "binary"
+msgstr "binaire"
+
+#: add-interactive.c:613 git-add--interactive.perl:278
+#: git-add--interactive.perl:332
+msgid "nothing"
+msgstr "rien"
+
+#: add-interactive.c:614 git-add--interactive.perl:314
+#: git-add--interactive.perl:329
+msgid "unchanged"
+msgstr "inchangé"
+
+#: add-interactive.c:651 git-add--interactive.perl:643
+msgid "Update"
+msgstr "Mise à jour"
+
+#: add-interactive.c:668 add-interactive.c:856
+#, c-format
+msgid "could not stage '%s'"
+msgstr "impossible d'indexer '%s'"
+
+#: add-interactive.c:674 add-interactive.c:863 sequencer.c:3409
+#: builtin/rebase.c:895
+msgid "could not write index"
+msgstr "impossible d'écrire l'index"
+
+#: add-interactive.c:677 git-add--interactive.perl:628
+#, c-format, perl-format
+msgid "updated %d path\n"
+msgid_plural "updated %d paths\n"
+msgstr[0] "%d chemin mis à jour\n"
+msgstr[1] "%d chemins mis à jour\n"
+
+#: add-interactive.c:695 git-add--interactive.perl:678
+#, c-format, perl-format
+msgid "note: %s is untracked now.\n"
+msgstr "note : %s n'est plus suivi à présent.\n"
+
+#: add-interactive.c:700 apply.c:4108 builtin/checkout.c:281
+#: builtin/reset.c:144
+#, c-format
+msgid "make_cache_entry failed for path '%s'"
+msgstr "échec de make_cache_entry pour le chemin '%s'"
+
+#: add-interactive.c:730 git-add--interactive.perl:655
+msgid "Revert"
+msgstr "Inverser"
+
+#: add-interactive.c:746
+msgid "Could not parse HEAD^{tree}"
+msgstr "impossible d'analyser HEAD^{tree}"
+
+#: add-interactive.c:784 git-add--interactive.perl:631
+#, c-format, perl-format
+msgid "reverted %d path\n"
+msgid_plural "reverted %d paths\n"
+msgstr[0] "%d chemin inversé\n"
+msgstr[1] "%d chemins inversés\n"
+
+#: add-interactive.c:835 git-add--interactive.perl:695
+#, c-format
+msgid "No untracked files.\n"
+msgstr "Aucun Fichier non suivi.\n"
+
+#: add-interactive.c:839 git-add--interactive.perl:689
+msgid "Add untracked"
+msgstr "Ajouter un fichier non-suivi"
+
+#: add-interactive.c:866 git-add--interactive.perl:625
+#, c-format, perl-format
+msgid "added %d path\n"
+msgid_plural "added %d paths\n"
+msgstr[0] "%d chemin ajouté\n"
+msgstr[1] "%d chemins ajoutés\n"
+
+#: add-interactive.c:896
+#, c-format
+msgid "ignoring unmerged: %s"
+msgstr "fichier non-fusionné ignoré : %s"
+
+#: add-interactive.c:908 add-patch.c:1331 git-add--interactive.perl:1366
+#, c-format
+msgid "Only binary files changed.\n"
+msgstr "Seuls des fichiers binaires ont changé.\n"
+
+#: add-interactive.c:910 add-patch.c:1329 git-add--interactive.perl:1368
+#, c-format
+msgid "No changes.\n"
+msgstr "Aucune modification.\n"
+
+#: add-interactive.c:914 git-add--interactive.perl:1376
+msgid "Patch update"
+msgstr "Mise à jour par patch"
+
+#: add-interactive.c:953 git-add--interactive.perl:1754
+msgid "Review diff"
+msgstr "Réviser la différence"
+
+#: add-interactive.c:981
+msgid "show paths with changes"
+msgstr "afficher les chemins comprenant des modifications"
+
+#: add-interactive.c:983
+msgid "add working tree state to the staged set of changes"
+msgstr "ajouter l'état de l'arbre de travail à l'ensemble des modifications indexées"
+
+#: add-interactive.c:985
+msgid "revert staged set of changes back to the HEAD version"
+msgstr "retourner l'ensemble de modifications indexées à la version HEAD"
+
+#: add-interactive.c:987
+msgid "pick hunks and update selectively"
+msgstr "sélection et mise à jour individuelle des sections"
+
+#: add-interactive.c:989
+msgid "view diff between HEAD and index"
+msgstr "visualiser les diffs entre HEAD et l'index"
+
+#: add-interactive.c:991
+msgid "add contents of untracked files to the staged set of changes"
+msgstr "ajouter le contenu des fichiers non-suivis à l'ensemble des modifications indexées"
+
+#: add-interactive.c:999 add-interactive.c:1048
+msgid "Prompt help:"
+msgstr "Aide :"
+
+#: add-interactive.c:1001
+msgid "select a single item"
+msgstr "sélectionner un seul élément"
+
+#: add-interactive.c:1003
+msgid "select a range of items"
+msgstr "sélectionner une plage d'éléments"
+
+#: add-interactive.c:1005
+msgid "select multiple ranges"
+msgstr "sélectionner plusieurs plages"
+
+#: add-interactive.c:1007 add-interactive.c:1052
+msgid "select item based on unique prefix"
+msgstr "sélectionner un élément basé sur une préfixe unique"
+
+#: add-interactive.c:1009
+msgid "unselect specified items"
+msgstr "désélectionner les éléments spécifiés"
+
+#: add-interactive.c:1011
+msgid "choose all items"
+msgstr "choisir tous les éléments"
+
+#: add-interactive.c:1013
+msgid "(empty) finish selecting"
+msgstr "(vide) arrêter de sélectionner"
+
+#: add-interactive.c:1050
+msgid "select a numbered item"
+msgstr "sélectionner un élément par son numéro"
+
+#: add-interactive.c:1054
+msgid "(empty) select nothing"
+msgstr "(vide) ne rien sélectionner"
+
+#: add-interactive.c:1062 builtin/clean.c:822 git-add--interactive.perl:1851
+msgid "*** Commands ***"
+msgstr "*** Commandes ***"
+
+#: add-interactive.c:1063 builtin/clean.c:823 git-add--interactive.perl:1848
+msgid "What now"
+msgstr "Et maintenant ?"
+
+#: add-interactive.c:1115 git-add--interactive.perl:213
+msgid "staged"
+msgstr "indexé"
+
+#: add-interactive.c:1115 git-add--interactive.perl:213
+msgid "unstaged"
+msgstr "non-indexé"
+
+#: add-interactive.c:1115 apply.c:4965 apply.c:4968 builtin/am.c:2197
+#: builtin/am.c:2200 builtin/clone.c:123 builtin/fetch.c:144
+#: builtin/merge.c:273 builtin/pull.c:209 builtin/submodule--helper.c:409
+#: builtin/submodule--helper.c:1379 builtin/submodule--helper.c:1382
+#: builtin/submodule--helper.c:1875 builtin/submodule--helper.c:1878
+#: builtin/submodule--helper.c:2119 git-add--interactive.perl:213
+msgid "path"
+msgstr "chemin"
+
+#: add-interactive.c:1122
+msgid "could not refresh index"
+msgstr "impossible de rafraîchir l'index"
+
+#: add-interactive.c:1136 builtin/clean.c:787 git-add--interactive.perl:1765
+#, c-format
+msgid "Bye.\n"
+msgstr "Au revoir.\n"
+
+#: add-patch.c:15
+#, c-format
+msgid "Stage mode change [y,n,a,q,d%s,?]? "
+msgstr "Indexer le changement de mode [y,n,a,q,d%s,?] ? "
+
+#: add-patch.c:16
+#, c-format
+msgid "Stage deletion [y,n,a,q,d%s,?]? "
+msgstr "Indexer la suppression [y,n,a,q,d%s,?] ? "
+
+#: add-patch.c:17
+#, c-format
+msgid "Stage this hunk [y,n,a,q,d%s,?]? "
+msgstr "Indexer cette section [y,n,a,q,d%s,?] ? "
+
+#: add-patch.c:111
+#, c-format
+msgid "could not parse hunk header '%.*s'"
+msgstr "impossible d'analyser l'entête de section '%.*s'"
+
+#: add-patch.c:130 add-patch.c:134
+#, c-format
+msgid "could not parse colored hunk header '%.*s'"
+msgstr "impossible d'analyser l'entête coloré de section '%.*s'"
+
+#: add-patch.c:176
+msgid "could not parse diff"
+msgstr "impossible d'analyser la diff"
+
+#: add-patch.c:194
+msgid "could not parse colored diff"
+msgstr "impossible d'analyser la diff colorée"
+
+#: add-patch.c:508
+#, c-format
+msgid ""
+"expected context line #%d in\n"
+"%.*s"
+msgstr ""
+"ligne de contexte attendue #%d dans\n"
+"%.*s"
+
+#: add-patch.c:523
+#, c-format
+msgid ""
+"hunks do not overlap:\n"
+"%.*s\n"
+"\tdoes not end with:\n"
+"%.*s"
+msgstr ""
+"les sections ne se recouvrent pas :\n"
+"%.*s\n"
+"\tne se termine pas par :\n"
+"%.*s"
+
+#: add-patch.c:799 git-add--interactive.perl:1112
+msgid "Manual hunk edit mode -- see bottom for a quick guide.\n"
+msgstr ""
+"Mode d'édition manuelle de section -- voir ci-dessous pour un guide rapide.\n"
+
+#: add-patch.c:803
+#, c-format
+msgid ""
+"---\n"
+"To remove '%c' lines, make them ' ' lines (context).\n"
+"To remove '%c' lines, delete them.\n"
+"Lines starting with %c will be removed.\n"
+msgstr ""
+"---\n"
+"Pour éliminer les lignes '%c', rendez-les ' ' (contexte).\n"
+"Pour éliminer les lignes '%c', effacez-les.\n"
+"Les lignes commençant par %c seront éliminées.\n"
+
+#: add-patch.c:810
+msgid ""
+"If the patch applies cleanly, the edited hunk will immediately be\n"
+"marked for staging.\n"
+msgstr ""
+"Si le patch s'applique proprement, la section éditée sera\n"
+"immédiatement marquée comme indexée.\n"
+
+#. TRANSLATORS: 'it' refers to the patch mentioned in the previous messages.
+#: add-patch.c:818 git-add--interactive.perl:1126
+msgid ""
+"If it does not apply cleanly, you will be given an opportunity to\n"
+"edit again.  If all lines of the hunk are removed, then the edit is\n"
+"aborted and the hunk is left unchanged.\n"
+msgstr ""
+"Si ça ne s'applique pas proprement, vous aurez la possibilité de\n"
+"l'éditer à nouveau. Si toutes les lignes de la section sont supprimées,\n"
+"alors l'édition sera abandonnée et la section conservée.\n"
+
+#: add-patch.c:851
+msgid "could not parse hunk header"
+msgstr "impossible d'analyser l'entête de section"
+
+#: add-patch.c:895 add-patch.c:1294
+msgid "'git apply --cached' failed"
+msgstr "'git apply --cached' a échoué"
+
+#. TRANSLATORS: do not translate [y/n]
+#. The program will only accept that input at this point.
+#. Consider translating (saying "no" discards!) as
+#. (saying "n" for "no" discards!) if the translation
+#. of the word "no" does not start with n.
+#.
+#. TRANSLATORS: do not translate [y/n]
+#. The program will only accept that input
+#. at this point.
+#. Consider translating (saying "no" discards!) as
+#. (saying "n" for "no" discards!) if the translation
+#. of the word "no" does not start with n.
+#: add-patch.c:952 git-add--interactive.perl:1239
+msgid ""
+"Your edited hunk does not apply. Edit again (saying \"no\" discards!) [y/n]? "
+msgstr ""
+"Votre section éditée ne s'applique pas. L'éditer à nouveau (\"no\" "
+"l'élimine !) [y|n] ? "
+
+#: add-patch.c:1009
+msgid ""
+"y - stage this hunk\n"
+"n - do not stage this hunk\n"
+"q - quit; do not stage this hunk or any of the remaining ones\n"
+"a - stage this and all the remaining hunks\n"
+"d - do not stage this hunk nor any of the remaining hunks\n"
+msgstr ""
+"y - indexer cette section\n"
+"n - ne pas indexer cette section\n"
+"q - quitter ; ne pas indexer cette section ni les autres restantes\n"
+"a - indexer cette section et toutes les suivantes\n"
+"d - ne pas indexer cette section ni les suivantes\n"
+
+#: add-patch.c:1016
+msgid ""
+"j - leave this hunk undecided, see next undecided hunk\n"
+"J - leave this hunk undecided, see next hunk\n"
+"k - leave this hunk undecided, see previous undecided hunk\n"
+"K - leave this hunk undecided, see previous hunk\n"
+"g - select a hunk to go to\n"
+"/ - search for a hunk matching the given regex\n"
+"s - split the current hunk into smaller hunks\n"
+"e - manually edit the current hunk\n"
+"? - print help\n"
+msgstr ""
+"j - laisser cette section non décidée et aller à la suivante non-décidée\n"
+"J - laisser cette section non décidée et aller à la suivante\n"
+"k - laisser cette section non décidée et aller à la précédente non-décidée\n"
+"K - laisser cette section non décidée et aller à la précédente\n"
+"g - sélectionner une section et s'y rendre\n"
+"/ - rechercher une section correspondant à une regex donnée\n"
+"s - découper la section en sections plus petites\n"
+"e - éditer manuellement la section actuelle\n"
+"? - afficher l'aide\n"
+
+#: add-patch.c:1137 add-patch.c:1147
+msgid "No previous hunk"
+msgstr "Pas de section précédente"
+
+#: add-patch.c:1142 add-patch.c:1152
+msgid "No next hunk"
+msgstr "Pas de section suivante"
+
+#: add-patch.c:1158
+msgid "No other hunks to goto"
+msgstr "Aucune autre section à atteindre"
+
+#: add-patch.c:1169 git-add--interactive.perl:1577
+msgid "go to which hunk (<ret> to see more)? "
+msgstr "aller à quelle section (<ret> pour voir plus) ? "
+
+#: add-patch.c:1170 git-add--interactive.perl:1579
+msgid "go to which hunk? "
+msgstr "aller à quelle section ? "
+
+#: add-patch.c:1181
+#, c-format
+msgid "Invalid number: '%s'"
+msgstr "Numéro invalide : '%s'"
+
+#: add-patch.c:1186
+#, c-format
+msgid "Sorry, only %d hunk available."
+msgid_plural "Sorry, only %d hunks available."
+msgstr[0] "Désolé, %d seule section disponible."
+msgstr[1] "Désolé, Seulement %d sections disponibles."
+
+#: add-patch.c:1195
+msgid "No other hunks to search"
+msgstr "aucune autre section à rechercher"
+
+#: add-patch.c:1201 git-add--interactive.perl:1623
+msgid "search for regex? "
+msgstr "rechercher la regex ? "
+
+#: add-patch.c:1216
+#, c-format
+msgid "Malformed search regexp %s: %s"
+msgstr "Regex de recherche malformée %s : %s"
+
+#: add-patch.c:1233
+msgid "No hunk matches the given pattern"
+msgstr "Aucune section ne correspond au motif donné"
+
+#: add-patch.c:1240
+msgid "Sorry, cannot split this hunk"
+msgstr "Désolé, impossible de découper cette section"
+
+#: add-patch.c:1244
+#, c-format
+msgid "Split into %d hunks."
+msgstr "Découpée en %d sections."
+
+#: add-patch.c:1248
+msgid "Sorry, cannot edit this hunk"
+msgstr "Désolé, impossible d'éditer cette section"
+
+#: advice.c:111
 #, c-format
 msgid "%shint: %.*s%s\n"
 msgstr "%sastuce: %.*s%s\n"
 
-#: advice.c:137
+#: advice.c:164
 msgid "Cherry-picking is not possible because you have unmerged files."
 msgstr "Impossible de picorer car vous avez des fichiers non fusionnés."
 
-#: advice.c:139
+#: advice.c:166
 msgid "Committing is not possible because you have unmerged files."
 msgstr "Impossible de valider car vous avez des fichiers non fusionnés."
 
-#: advice.c:141
+#: advice.c:168
 msgid "Merging is not possible because you have unmerged files."
 msgstr "Impossible de fusionner car vous avez des fichiers non fusionnés."
 
-#: advice.c:143
+#: advice.c:170
 msgid "Pulling is not possible because you have unmerged files."
 msgstr "Impossible de tirer car vous avez des fichiers non fusionnés."
 
-#: advice.c:145
+#: advice.c:172
 msgid "Reverting is not possible because you have unmerged files."
 msgstr "Impossible d'annuler car vous avez des fichiers non fusionnés."
 
-#: advice.c:147
+#: advice.c:174
 #, c-format
 msgid "It is not possible to %s because you have unmerged files."
 msgstr "%s n'est pas possible car vous avez des fichiers non fusionnés."
 
-#: advice.c:155
+#: advice.c:182
 msgid ""
 "Fix them up in the work tree, and then use 'git add/rm <file>'\n"
 "as appropriate to mark resolution and make a commit."
@@ -122,147 +551,158 @@ msgstr ""
 "Corrigez-les puis lancez 'git add/rm <fichier>'\n"
 "si nécessaire pour marquer la résolution et valider."
 
-#: advice.c:163
+#: advice.c:190
 msgid "Exiting because of an unresolved conflict."
 msgstr "Abandon à cause de conflit non résolu."
 
-#: advice.c:168 builtin/merge.c:1250
+#: advice.c:195 builtin/merge.c:1332
 msgid "You have not concluded your merge (MERGE_HEAD exists)."
 msgstr "Vous n'avez pas terminé votre fusion (MERGE_HEAD existe)."
 
-#: advice.c:170
+#: advice.c:197
 msgid "Please, commit your changes before merging."
 msgstr "Veuillez valider vos changements avant de fusionner."
 
-#: advice.c:171
+#: advice.c:198
 msgid "Exiting because of unfinished merge."
 msgstr "Abandon à cause d'une fusion non terminée."
 
-#: advice.c:177
+#: advice.c:204
 #, c-format
 msgid ""
-"Note: checking out '%s'.\n"
+"Note: switching to '%s'.\n"
 "\n"
 "You are in 'detached HEAD' state. You can look around, make experimental\n"
 "changes and commit them, and you can discard any commits you make in this\n"
-"state without impacting any branches by performing another checkout.\n"
+"state without impacting any branches by switching back to a branch.\n"
 "\n"
 "If you want to create a new branch to retain commits you create, you may\n"
-"do so (now or later) by using -b with the checkout command again. Example:\n"
+"do so (now or later) by using -c with the switch command. Example:\n"
+"\n"
+"  git switch -c <new-branch-name>\n"
+"\n"
+"Or undo this operation with:\n"
+"\n"
+"  git switch -\n"
 "\n"
-"  git checkout -b <new-branch-name>\n"
+"Turn off this advice by setting config variable advice.detachedHead to "
+"false\n"
 "\n"
 msgstr ""
-"Note : extraction de '%s'.\n"
+"Note : basculement sur '%s'.\n"
 "\n"
 "Vous êtes dans l'état « HEAD détachée ». Vous pouvez visiter, faire des "
 "modifications\n"
-"expérimentales et les valider. Il vous suffit de faire une autre extraction "
+"expérimentales et les valider. Il vous suffit de faire un autre basculement "
 "pour\n"
 "abandonner les commits que vous faites dans cet état sans impacter les "
 "autres branches\n"
 "\n"
 "Si vous voulez créer une nouvelle branche pour conserver les commits que "
 "vous créez,\n"
-"il vous suffit d'utiliser « checkout -b » (maintenant ou plus tard) comme "
-"ceci :\n"
+"il vous suffit d'utiliser l'option -c de la commande switch comme ceci :\n"
 "\n"
-"  git checkout -b <nom-de-la-nouvelle-branche>\n"
+"  git switch -c <nom-de-la-nouvelle-branche>\n"
 "\n"
+"Ou annuler cette opération avec :\n"
+"\n"
+"  git switch -\n"
+"\n"
+"Désactivez ce conseil en renseignant la variable de configuration advice."
+"detachedHead à false\n"
+"\n"
+
+#: alias.c:50
+msgid "cmdline ends with \\"
+msgstr "cmdline se termine par \\"
 
-#: apply.c:58
+#: alias.c:51
+msgid "unclosed quote"
+msgstr "citation non fermée"
+
+#: apply.c:69
 #, c-format
 msgid "unrecognized whitespace option '%s'"
 msgstr "option d'espace non reconnue '%s'"
 
-#: apply.c:74
+#: apply.c:85
 #, c-format
 msgid "unrecognized whitespace ignore option '%s'"
 msgstr "option d'ignorance d'espace non reconnue '%s'"
 
-#: apply.c:122
+#: apply.c:135
 msgid "--reject and --3way cannot be used together."
 msgstr "--reject et --3way ne peuvent pas être utilisés ensemble."
 
-#: apply.c:124
+#: apply.c:137
 msgid "--cached and --3way cannot be used together."
 msgstr "--cached et --3way ne peuvent pas être utilisés ensemble."
 
-#: apply.c:127
+#: apply.c:140
 msgid "--3way outside a repository"
 msgstr "--3way hors d'un dépôt"
 
-#: apply.c:138
+#: apply.c:151
 msgid "--index outside a repository"
 msgstr "--index hors d'un dépôt"
 
-#: apply.c:141
+#: apply.c:154
 msgid "--cached outside a repository"
 msgstr "--cached hors d'un dépôt"
 
-#: apply.c:821
+#: apply.c:801
 #, c-format
 msgid "Cannot prepare timestamp regexp %s"
 msgstr "Impossible de préparer la regexp d'horodatage %s"
 
-#: apply.c:830
+#: apply.c:810
 #, c-format
 msgid "regexec returned %d for input: %s"
 msgstr "regexec a retourné %d pour l'entrée : %s"
 
-#: apply.c:904
+#: apply.c:884
 #, c-format
 msgid "unable to find filename in patch at line %d"
 msgstr "nom de fichier du patch introuvable à la ligne %d"
 
-#: apply.c:942
+#: apply.c:922
 #, c-format
 msgid "git apply: bad git-diff - expected /dev/null, got %s on line %d"
 msgstr ""
 "git apply : mauvais format de git-diff - /dev/null attendu, %s trouvé à la "
 "ligne %d"
 
-#: apply.c:948
+#: apply.c:928
 #, c-format
 msgid "git apply: bad git-diff - inconsistent new filename on line %d"
 msgstr ""
 "git apply : mauvais format de git-diff - nouveau nom de fichier inconsistant "
 "à la ligne %d"
 
-#: apply.c:949
+#: apply.c:929
 #, c-format
 msgid "git apply: bad git-diff - inconsistent old filename on line %d"
 msgstr ""
 "git apply : mauvais format de git-diff - ancien nom de fichier inconsistant "
 "à la ligne %d"
 
-#: apply.c:954
+#: apply.c:934
 #, c-format
 msgid "git apply: bad git-diff - expected /dev/null on line %d"
 msgstr ""
 "git apply : mauvais format de git-diff - /dev/null attendu à la ligne %d"
 
-#: apply.c:983
+#: apply.c:963
 #, c-format
 msgid "invalid mode on line %d: %s"
 msgstr "mode invalide dans la ligne %d : %s"
 
-#: apply.c:1301
+#: apply.c:1282
 #, c-format
 msgid "inconsistent header lines %d and %d"
 msgstr "lignes d'entête inconsistantes %d et %d"
 
-#: apply.c:1473
-#, c-format
-msgid "recount: unexpected line: %.*s"
-msgstr "recomptage : ligne inattendue : %.*s"
-
-#: apply.c:1542
-#, c-format
-msgid "patch fragment without header at line %d: %.*s"
-msgstr "fragment de patch sans en-tête à la ligne %d : %.*s"
-
-#: apply.c:1562
+#: apply.c:1372
 #, c-format
 msgid ""
 "git diff header lacks filename information when removing %d leading pathname "
@@ -277,83 +717,93 @@ msgstr[1] ""
 "information de nom de fichier manquante dans l'en-tête de git diff lors de "
 "la suppression de %d composants de préfixe de chemin (ligne %d)"
 
-#: apply.c:1575
+#: apply.c:1385
 #, c-format
 msgid "git diff header lacks filename information (line %d)"
 msgstr ""
 "information de nom de fichier manquante dans l'en-tête de git diff (ligne %d)"
 
-#: apply.c:1763
+#: apply.c:1481
+#, c-format
+msgid "recount: unexpected line: %.*s"
+msgstr "recomptage : ligne inattendue : %.*s"
+
+#: apply.c:1550
+#, c-format
+msgid "patch fragment without header at line %d: %.*s"
+msgstr "fragment de patch sans en-tête à la ligne %d : %.*s"
+
+#: apply.c:1753
 msgid "new file depends on old contents"
 msgstr "le nouveau fichier dépend de contenus anciens"
 
-#: apply.c:1765
+#: apply.c:1755
 msgid "deleted file still has contents"
 msgstr "le fichier supprimé a encore du contenu"
 
-#: apply.c:1799
+#: apply.c:1789
 #, c-format
 msgid "corrupt patch at line %d"
 msgstr "patch corrompu à la ligne %d"
 
-#: apply.c:1836
+#: apply.c:1826
 #, c-format
 msgid "new file %s depends on old contents"
 msgstr "le nouveau fichier %s dépend de contenus anciens"
 
-#: apply.c:1838
+#: apply.c:1828
 #, c-format
 msgid "deleted file %s still has contents"
 msgstr "le fichier supprimé %s a encore du contenu"
 
-#: apply.c:1841
+#: apply.c:1831
 #, c-format
 msgid "** warning: file %s becomes empty but is not deleted"
 msgstr "** attention : le fichier %s devient vide mais n'est pas supprimé"
 
-#: apply.c:1988
+#: apply.c:1978
 #, c-format
 msgid "corrupt binary patch at line %d: %.*s"
 msgstr "patch binaire corrompu à la ligne %d : %.*s"
 
-#: apply.c:2025
+#: apply.c:2015
 #, c-format
 msgid "unrecognized binary patch at line %d"
 msgstr "patch binaire non reconnu à la ligne %d"
 
-#: apply.c:2185
+#: apply.c:2177
 #, c-format
 msgid "patch with only garbage at line %d"
 msgstr "patch totalement incompréhensible à la ligne %d"
 
-#: apply.c:2271
+#: apply.c:2263
 #, c-format
 msgid "unable to read symlink %s"
 msgstr "lecture du lien symbolique %s impossible"
 
-#: apply.c:2275
+#: apply.c:2267
 #, c-format
 msgid "unable to open or read %s"
 msgstr "ouverture ou lecture de %s impossible"
 
-#: apply.c:2934
+#: apply.c:2936
 #, c-format
 msgid "invalid start of line: '%c'"
 msgstr "début de ligne invalide : '%c'"
 
-#: apply.c:3055
+#: apply.c:3057
 #, c-format
 msgid "Hunk #%d succeeded at %d (offset %d line)."
 msgid_plural "Hunk #%d succeeded at %d (offset %d lines)."
 msgstr[0] "La section n°%d a réussi à la ligne %d (offset %d ligne)."
 msgstr[1] "La section n°%d a réussi à la ligne %d (offset %d lignes)."
 
-#: apply.c:3067
+#: apply.c:3069
 #, c-format
 msgid "Context reduced to (%ld/%ld) to apply fragment at %d"
 msgstr "Contexte réduit à (%ld/%ld) pour appliquer le fragment à la ligne %d"
 
-#: apply.c:3073
+#: apply.c:3075
 #, c-format
 msgid ""
 "while searching for:\n"
@@ -362,582 +812,648 @@ msgstr ""
 "pendant la recherche de :\n"
 "%.*s"
 
-#: apply.c:3095
+#: apply.c:3097
 #, c-format
 msgid "missing binary patch data for '%s'"
 msgstr "données de patch binaire manquantes pour '%s'"
 
-#: apply.c:3103
+#: apply.c:3105
 #, c-format
 msgid "cannot reverse-apply a binary patch without the reverse hunk to '%s'"
 msgstr ""
 "impossible d'appliquer l'inverse d'un patch binaire à '%s' sans la section "
 "inverse"
 
-#: apply.c:3149
+#: apply.c:3152
 #, c-format
 msgid "cannot apply binary patch to '%s' without full index line"
 msgstr ""
 "impossible d'appliquer un patch binaire à '%s' sans la ligne complète d'index"
 
-#: apply.c:3159
+#: apply.c:3162
 #, c-format
 msgid ""
 "the patch applies to '%s' (%s), which does not match the current contents."
 msgstr ""
 "le patch s'applique à '%s' (%s), ce qui ne correspond pas au contenu actuel."
 
-#: apply.c:3167
+#: apply.c:3170
 #, c-format
 msgid "the patch applies to an empty '%s' but it is not empty"
 msgstr "le patch s'applique à un '%s' vide mais ce n'est pas vide"
 
-#: apply.c:3185
+#: apply.c:3188
 #, c-format
 msgid "the necessary postimage %s for '%s' cannot be read"
 msgstr "l'image postérieure nécessaire %s pour '%s' ne peut pas être lue"
 
-#: apply.c:3198
+#: apply.c:3201
 #, c-format
 msgid "binary patch does not apply to '%s'"
 msgstr "le patch binaire ne s'applique par correctement à '%s'"
 
-#: apply.c:3204
+#: apply.c:3207
 #, c-format
 msgid "binary patch to '%s' creates incorrect result (expecting %s, got %s)"
 msgstr ""
 "le patch binaire sur '%s' crée un résultat incorrect (%s attendu, mais %s "
 "trouvé)"
 
-#: apply.c:3225
+#: apply.c:3228
 #, c-format
 msgid "patch failed: %s:%ld"
 msgstr "le patch a échoué : %s:%ld"
 
-#: apply.c:3347
+#: apply.c:3351
 #, c-format
 msgid "cannot checkout %s"
 msgstr "extraction de %s impossible"
 
-#: apply.c:3396 apply.c:3407 apply.c:3453 setup.c:278
+#: apply.c:3403 apply.c:3414 apply.c:3460 midx.c:61 setup.c:280
 #, c-format
 msgid "failed to read %s"
 msgstr "échec de la lecture de %s"
 
-#: apply.c:3404
+#: apply.c:3411
 #, c-format
 msgid "reading from '%s' beyond a symbolic link"
 msgstr "lecture depuis '%s' au-delà d'un lien symbolique"
 
-#: apply.c:3433 apply.c:3673
+#: apply.c:3440 apply.c:3683
 #, c-format
 msgid "path %s has been renamed/deleted"
 msgstr "le chemin %s a été renommé/supprimé"
 
-#: apply.c:3516 apply.c:3687
+#: apply.c:3526 apply.c:3698
 #, c-format
 msgid "%s: does not exist in index"
 msgstr "%s : n'existe pas dans l'index"
 
-#: apply.c:3525 apply.c:3695
+#: apply.c:3535 apply.c:3706
 #, c-format
 msgid "%s: does not match index"
 msgstr "%s : ne correspond pas à l'index"
 
-#: apply.c:3560
+#: apply.c:3570
 msgid "repository lacks the necessary blob to fall back on 3-way merge."
 msgstr ""
 "le dépôt n'a pas les blobs nécessaires pour un retour à une fusion à 3 "
 "points."
 
-#: apply.c:3563
+#: apply.c:3573
 #, c-format
 msgid "Falling back to three-way merge...\n"
 msgstr "Retour à une fusion à 3 points…\n"
 
-#: apply.c:3579 apply.c:3583
+#: apply.c:3589 apply.c:3593
 #, c-format
 msgid "cannot read the current contents of '%s'"
 msgstr "impossible de lire le contenu actuel de '%s'"
 
-#: apply.c:3595
+#: apply.c:3605
 #, c-format
 msgid "Failed to fall back on three-way merge...\n"
-msgstr "Echec du retour à une fusion à 3 points…\n"
+msgstr "Échec du retour à une fusion à 3 points…\n"
 
-#: apply.c:3609
+#: apply.c:3619
 #, c-format
 msgid "Applied patch to '%s' with conflicts.\n"
 msgstr "Patch %s appliqué avec des conflits.\n"
 
-#: apply.c:3614
+#: apply.c:3624
 #, c-format
 msgid "Applied patch to '%s' cleanly.\n"
 msgstr "Patch %s appliqué proprement.\n"
 
-#: apply.c:3640
+#: apply.c:3650
 msgid "removal patch leaves file contents"
 msgstr "le patch de suppression laisse un contenu dans le fichier"
 
-#: apply.c:3712
+#: apply.c:3723
 #, c-format
 msgid "%s: wrong type"
 msgstr "%s : type erroné"
 
-#: apply.c:3714
+#: apply.c:3725
 #, c-format
 msgid "%s has type %o, expected %o"
 msgstr "%s est de type %o, mais %o attendu"
 
-#: apply.c:3864 apply.c:3866
+#: apply.c:3876 apply.c:3878 read-cache.c:830 read-cache.c:856
+#: read-cache.c:1320
 #, c-format
 msgid "invalid path '%s'"
 msgstr "chemin invalide '%s'"
 
-#: apply.c:3922
+#: apply.c:3934
 #, c-format
 msgid "%s: already exists in index"
 msgstr "%s : existe déjà dans l'index"
 
-#: apply.c:3925
+#: apply.c:3937
 #, c-format
 msgid "%s: already exists in working directory"
 msgstr "%s : existe déjà dans la copie de travail"
 
-#: apply.c:3945
+#: apply.c:3957
 #, c-format
 msgid "new mode (%o) of %s does not match old mode (%o)"
 msgstr "le nouveau mode (%o) de %s ne correspond pas à l'ancien mode (%o)"
 
-#: apply.c:3950
+#: apply.c:3962
 #, c-format
 msgid "new mode (%o) of %s does not match old mode (%o) of %s"
 msgstr ""
 "le nouveau mode (%o) de %s ne correspond pas à l'ancien mode (%o) de %s"
 
-#: apply.c:3970
+#: apply.c:3982
 #, c-format
 msgid "affected file '%s' is beyond a symbolic link"
 msgstr "le fichier affecté '%s' est au-delà d'un lien symbolique"
 
-#: apply.c:3974
+#: apply.c:3986
 #, c-format
 msgid "%s: patch does not apply"
 msgstr "%s : le patch ne s'applique pas"
 
-#: apply.c:3989
+#: apply.c:4001
 #, c-format
 msgid "Checking patch %s..."
 msgstr "Vérification du patch %s..."
 
-#: apply.c:4080
+#: apply.c:4093
 #, c-format
 msgid "sha1 information is lacking or useless for submodule %s"
 msgstr ""
 "l'information sha1 est manquante ou inutilisable pour le sous-module %s"
 
-#: apply.c:4087
+#: apply.c:4100
 #, c-format
 msgid "mode change for %s, which is not in current HEAD"
 msgstr "le mode change pour %s, qui n'est pas dans la HEAD actuelle"
 
-#: apply.c:4090
+#: apply.c:4103
 #, c-format
 msgid "sha1 information is lacking or useless (%s)."
 msgstr "l'information de sha1 est manquante ou inutilisable (%s)."
 
-#: apply.c:4095 builtin/checkout.c:235 builtin/reset.c:140
-#, c-format
-msgid "make_cache_entry failed for path '%s'"
-msgstr "échec de make_cache_entry pour le chemin '%s'"
-
-#: apply.c:4099
+#: apply.c:4112
 #, c-format
 msgid "could not add %s to temporary index"
 msgstr "impossible d'ajouter %s à l'index temporaire"
 
-#: apply.c:4109
+#: apply.c:4122
 #, c-format
 msgid "could not write temporary index to %s"
 msgstr "impossible d'écrire l'index temporaire dans %s"
 
-#: apply.c:4247
+#: apply.c:4260
 #, c-format
 msgid "unable to remove %s from index"
 msgstr "suppression de %s dans l'index impossible"
 
-#: apply.c:4282
+#: apply.c:4294
 #, c-format
 msgid "corrupt patch for submodule %s"
 msgstr "patch corrompu pour le sous-module %s"
 
-#: apply.c:4288
+#: apply.c:4300
 #, c-format
 msgid "unable to stat newly created file '%s'"
 msgstr "stat du fichier nouvellement créé '%s' impossible"
 
-#: apply.c:4296
+#: apply.c:4308
 #, c-format
 msgid "unable to create backing store for newly created file %s"
 msgstr ""
 "création du magasin de stockage pour le fichier nouvellement créé %s "
 "impossible"
 
-#: apply.c:4302 apply.c:4446
+#: apply.c:4314 apply.c:4459
 #, c-format
 msgid "unable to add cache entry for %s"
 msgstr "ajout de l'élément de cache %s impossible"
 
-#: apply.c:4343
+#: apply.c:4357
 #, c-format
 msgid "failed to write to '%s'"
 msgstr "échec de l'écriture dans '%s'"
 
-#: apply.c:4347
+#: apply.c:4361
 #, c-format
 msgid "closing file '%s'"
 msgstr "fermeture du fichier '%s'"
 
-#: apply.c:4417
+#: apply.c:4431
 #, c-format
 msgid "unable to write file '%s' mode %o"
 msgstr "écriture du fichier '%s' mode %o impossible"
 
-#: apply.c:4515
+#: apply.c:4529
 #, c-format
 msgid "Applied patch %s cleanly."
 msgstr "Patch %s appliqué proprement."
 
-#: apply.c:4523
+#: apply.c:4537
 msgid "internal error"
 msgstr "erreur interne"
 
-#: apply.c:4526
+#: apply.c:4540
 #, c-format
 msgid "Applying patch %%s with %d reject..."
 msgid_plural "Applying patch %%s with %d rejects..."
 msgstr[0] "Application du patch %%s avec %d rejet..."
 msgstr[1] "Application du patch %%s avec %d rejets..."
 
-#: apply.c:4537
+#: apply.c:4551
 #, c-format
 msgid "truncating .rej filename to %.*s.rej"
 msgstr "troncature du nom de fichier .rej en %.*s.rej"
 
-#: apply.c:4545 builtin/fetch.c:786 builtin/fetch.c:1036
+#: apply.c:4559 builtin/fetch.c:901 builtin/fetch.c:1192
 #, c-format
 msgid "cannot open %s"
 msgstr "impossible d'ouvrir %s"
 
-#: apply.c:4559
+#: apply.c:4573
 #, c-format
 msgid "Hunk #%d applied cleanly."
 msgstr "Section n°%d appliquée proprement."
 
-#: apply.c:4563
+#: apply.c:4577
 #, c-format
 msgid "Rejected hunk #%d."
 msgstr "Section n°%d rejetée."
 
-#: apply.c:4673
+#: apply.c:4696
 #, c-format
 msgid "Skipped patch '%s'."
 msgstr "Chemin '%s' non traité."
 
-#: apply.c:4681
+#: apply.c:4704
 msgid "unrecognized input"
 msgstr "entrée non reconnue"
 
-#: apply.c:4700
+#: apply.c:4724
 msgid "unable to read index file"
 msgstr "lecture du fichier d'index impossible"
 
-#: apply.c:4837
+#: apply.c:4881
 #, c-format
 msgid "can't open patch '%s': %s"
 msgstr "ouverture impossible du patch '%s' :%s"
 
-#: apply.c:4864
+#: apply.c:4908
 #, c-format
 msgid "squelched %d whitespace error"
 msgid_plural "squelched %d whitespace errors"
 msgstr[0] "%d erreur d'espace ignorée"
 msgstr[1] "%d erreurs d'espace ignorées"
 
-#: apply.c:4870 apply.c:4885
+#: apply.c:4914 apply.c:4929
 #, c-format
 msgid "%d line adds whitespace errors."
 msgid_plural "%d lines add whitespace errors."
 msgstr[0] "%d ligne a ajouté des erreurs d'espace."
 msgstr[1] "%d lignes ont ajouté des erreurs d'espace."
 
-#: apply.c:4878
+#: apply.c:4922
 #, c-format
 msgid "%d line applied after fixing whitespace errors."
 msgid_plural "%d lines applied after fixing whitespace errors."
 msgstr[0] "%d ligne ajoutée après correction des erreurs d'espace."
 msgstr[1] "%d lignes ajoutées après correction des erreurs d'espace."
 
-#: apply.c:4894 builtin/add.c:538 builtin/mv.c:300 builtin/rm.c:389
+#: apply.c:4938 builtin/add.c:579 builtin/mv.c:301 builtin/rm.c:390
 msgid "Unable to write new index file"
 msgstr "Impossible d'écrire le nouveau fichier d'index"
 
-#: apply.c:4921 apply.c:4924 builtin/am.c:2254 builtin/am.c:2257
-#: builtin/clone.c:120 builtin/fetch.c:126 builtin/pull.c:198
-#: builtin/submodule--helper.c:405 builtin/submodule--helper.c:1210
-#: builtin/submodule--helper.c:1213 builtin/submodule--helper.c:1584
-#: builtin/submodule--helper.c:1587 builtin/submodule--helper.c:1807
-#: git-add--interactive.perl:197
-msgid "path"
-msgstr "chemin"
-
-#: apply.c:4922
+#: apply.c:4966
 msgid "don't apply changes matching the given path"
 msgstr "ne pas appliquer les modifications qui correspondent au chemin donné"
 
-#: apply.c:4925
+#: apply.c:4969
 msgid "apply changes matching the given path"
 msgstr "appliquer les modifications qui correspondent au chemin donné"
 
-#: apply.c:4927 builtin/am.c:2263
+#: apply.c:4971 builtin/am.c:2206
 msgid "num"
 msgstr "num"
 
-#: apply.c:4928
+#: apply.c:4972
 msgid "remove <num> leading slashes from traditional diff paths"
 msgstr "supprimer <num> barres obliques des chemins traditionnels de diff"
 
-#: apply.c:4931
+#: apply.c:4975
 msgid "ignore additions made by the patch"
 msgstr "ignorer les additions réalisées par le patch"
 
-#: apply.c:4933
+#: apply.c:4977
 msgid "instead of applying the patch, output diffstat for the input"
 msgstr "au lieu d'appliquer le patch, afficher le diffstat de l'entrée"
 
-#: apply.c:4937
+#: apply.c:4981
 msgid "show number of added and deleted lines in decimal notation"
 msgstr ""
 "afficher le nombre de lignes ajoutées et supprimées en notation décimale"
 
-#: apply.c:4939
+#: apply.c:4983
 msgid "instead of applying the patch, output a summary for the input"
 msgstr "au lieu d'appliquer le patch, afficher un résumé de l'entrée"
 
-#: apply.c:4941
+#: apply.c:4985
 msgid "instead of applying the patch, see if the patch is applicable"
 msgstr "au lieu d'appliquer le patch, voir si le patch est applicable"
 
-#: apply.c:4943
+#: apply.c:4987
 msgid "make sure the patch is applicable to the current index"
 msgstr "s'assurer que le patch est applicable sur l'index actuel"
 
-#: apply.c:4945
+#: apply.c:4989
+msgid "mark new files with `git add --intent-to-add`"
+msgstr "marquer les nouveaux fichiers `git add --intent-to-add`"
+
+#: apply.c:4991
 msgid "apply a patch without touching the working tree"
 msgstr "appliquer les patch sans toucher à la copie de travail"
 
-#: apply.c:4947
+#: apply.c:4993
 msgid "accept a patch that touches outside the working area"
 msgstr "accepter un patch qui touche hors de la copie de travail"
 
-#: apply.c:4950
+#: apply.c:4996
 msgid "also apply the patch (use with --stat/--summary/--check)"
-msgstr "appliquer aussi le patch (à utiliser avec ---stat/--summary/--check)"
+msgstr "appliquer aussi le patch (à utiliser avec --stat/--summary/--check)"
 
-#: apply.c:4952
+#: apply.c:4998
 msgid "attempt three-way merge if a patch does not apply"
 msgstr "tenter une fusion à 3 points si le patch ne s'applique pas proprement"
 
-#: apply.c:4954
+#: apply.c:5000
 msgid "build a temporary index based on embedded index information"
 msgstr ""
 "construire un index temporaire fondé sur l'information de l'index embarqué"
 
-#: apply.c:4957 builtin/checkout-index.c:168 builtin/ls-files.c:515
+#: apply.c:5003 builtin/checkout-index.c:173 builtin/ls-files.c:524
 msgid "paths are separated with NUL character"
 msgstr "les chemins sont séparés par un caractère NUL"
 
-#: apply.c:4959
+#: apply.c:5005
 msgid "ensure at least <n> lines of context match"
 msgstr "s'assurer d'au moins <n> lignes de correspondance de contexte"
 
-#: apply.c:4960 builtin/am.c:2242 builtin/interpret-trailers.c:95
-#: builtin/interpret-trailers.c:97 builtin/interpret-trailers.c:99
-#: builtin/pack-objects.c:3177
+#: apply.c:5006 builtin/am.c:2185 builtin/interpret-trailers.c:98
+#: builtin/interpret-trailers.c:100 builtin/interpret-trailers.c:102
+#: builtin/pack-objects.c:3310 builtin/rebase.c:1474
 msgid "action"
 msgstr "action"
 
-#: apply.c:4961
+#: apply.c:5007
 msgid "detect new or modified lines that have whitespace errors"
 msgstr ""
 "détecter des lignes nouvelles ou modifiées qui contiennent des erreurs "
 "d'espace"
 
-#: apply.c:4964 apply.c:4967
+#: apply.c:5010 apply.c:5013
 msgid "ignore changes in whitespace when finding context"
 msgstr "ignorer des modifications d'espace lors de la recherche de contexte"
 
-#: apply.c:4970
+#: apply.c:5016
 msgid "apply the patch in reverse"
 msgstr "appliquer le patch en sens inverse"
 
-#: apply.c:4972
+#: apply.c:5018
 msgid "don't expect at least one line of context"
 msgstr "ne pas s'attendre à au moins une ligne de contexte"
 
-#: apply.c:4974
+#: apply.c:5020
 msgid "leave the rejected hunks in corresponding *.rej files"
 msgstr "laisser les sections rejetées dans les fichiers *.rej correspondants"
 
-#: apply.c:4976
+#: apply.c:5022
 msgid "allow overlapping hunks"
 msgstr "accepter les recouvrements de sections"
 
-#: apply.c:4977 builtin/add.c:290 builtin/check-ignore.c:21
-#: builtin/commit.c:1301 builtin/count-objects.c:98 builtin/fsck.c:666
-#: builtin/log.c:1901 builtin/mv.c:122 builtin/read-tree.c:124
+#: apply.c:5023 builtin/add.c:309 builtin/check-ignore.c:22
+#: builtin/commit.c:1355 builtin/count-objects.c:98 builtin/fsck.c:774
+#: builtin/log.c:2166 builtin/mv.c:123 builtin/read-tree.c:128
 msgid "be verbose"
 msgstr "mode verbeux"
 
-#: apply.c:4979
+#: apply.c:5025
 msgid "tolerate incorrectly detected missing new-line at the end of file"
 msgstr ""
 "tolérer des erreurs de détection de retours chariot manquants en fin de "
 "fichier"
 
-#: apply.c:4982
+#: apply.c:5028
 msgid "do not trust the line counts in the hunk headers"
 msgstr "ne pas se fier au compte de lignes dans les en-têtes de section"
 
-#: apply.c:4984 builtin/am.c:2251
+#: apply.c:5030 builtin/am.c:2194
 msgid "root"
 msgstr "racine"
 
-#: apply.c:4985
+#: apply.c:5031
 msgid "prepend <root> to all filenames"
 msgstr "préfixer tous les noms de fichier avec <root>"
 
-#: archive.c:13
+#: archive.c:14
 msgid "git archive [<options>] <tree-ish> [<path>...]"
 msgstr "git archive [<options>] <arbre ou apparenté> [<chemin>...]"
 
-#: archive.c:14
+#: archive.c:15
 msgid "git archive --list"
 msgstr "git archive --list"
 
-#: archive.c:15
+#: archive.c:16
 msgid ""
 "git archive --remote <repo> [--exec <cmd>] [<options>] <tree-ish> [<path>...]"
 msgstr ""
 "git archive --remote <dépôt> [--exec <commande>] [<options>] <arbre ou "
 "apparenté> [<chemin>...]"
 
-#: archive.c:16
+#: archive.c:17
 msgid "git archive --remote <repo> [--exec <cmd>] --list"
 msgstr "git archive --remote <dépôt> [--exec <commande>] --list"
 
-#: archive.c:351 builtin/add.c:176 builtin/add.c:514 builtin/rm.c:298
+#: archive.c:372 builtin/add.c:180 builtin/add.c:555 builtin/rm.c:299
 #, c-format
 msgid "pathspec '%s' did not match any files"
 msgstr "le chemin '%s' ne correspond à aucun fichier"
 
-#: archive.c:434
+#: archive.c:396
+#, c-format
+msgid "no such ref: %.*s"
+msgstr "référence inexistante : %.*s"
+
+#: archive.c:401
+#, c-format
+msgid "not a valid object name: %s"
+msgstr "nom d'objet invalide : %s"
+
+#: archive.c:414
+#, c-format
+msgid "not a tree object: %s"
+msgstr "objet arbre invalide : %s"
+
+#: archive.c:426
+msgid "current working directory is untracked"
+msgstr "l'arbre de travail actuel est non-suivi"
+
+#: archive.c:457
 msgid "fmt"
 msgstr "fmt"
 
-#: archive.c:434
+#: archive.c:457
 msgid "archive format"
 msgstr "format d'archive"
 
-#: archive.c:435 builtin/log.c:1462
+#: archive.c:458 builtin/log.c:1653
 msgid "prefix"
 msgstr "préfixe"
 
-#: archive.c:436
+#: archive.c:459
 msgid "prepend prefix to each pathname in the archive"
 msgstr "préfixer chaque chemin de fichier dans l'archive"
 
-#: archive.c:437 builtin/blame.c:813 builtin/blame.c:814 builtin/config.c:127
-#: builtin/fast-export.c:1007 builtin/fast-export.c:1009 builtin/grep.c:869
-#: builtin/hash-object.c:103 builtin/ls-files.c:551 builtin/ls-files.c:554
-#: builtin/notes.c:405 builtin/notes.c:568 builtin/read-tree.c:119
-#: parse-options.h:165
+#: archive.c:460 builtin/blame.c:861 builtin/blame.c:865 builtin/blame.c:866
+#: builtin/commit-tree.c:117 builtin/config.c:129 builtin/fast-export.c:1162
+#: builtin/fast-export.c:1164 builtin/fast-export.c:1168 builtin/grep.c:899
+#: builtin/hash-object.c:105 builtin/ls-files.c:560 builtin/ls-files.c:563
+#: builtin/notes.c:412 builtin/notes.c:578 builtin/read-tree.c:123
+#: parse-options.h:190
 msgid "file"
 msgstr "fichier"
 
-#: archive.c:438 builtin/archive.c:89
+#: archive.c:461 builtin/archive.c:90
 msgid "write the archive to this file"
 msgstr "écrire l'archive dans ce fichier"
 
-#: archive.c:440
+#: archive.c:463
 msgid "read .gitattributes in working directory"
 msgstr "lire .gitattributes dans le répertoire de travail"
 
-#: archive.c:441
+#: archive.c:464
 msgid "report archived files on stderr"
 msgstr "afficher les fichiers archivés sur stderr"
 
-#: archive.c:442
+#: archive.c:465
 msgid "store only"
 msgstr "stockage seulement"
 
-#: archive.c:443
+#: archive.c:466
 msgid "compress faster"
 msgstr "compression rapide"
 
-#: archive.c:451
+#: archive.c:474
 msgid "compress better"
 msgstr "compression efficace"
 
-#: archive.c:454
+#: archive.c:477
 msgid "list supported archive formats"
 msgstr "afficher les formats d'archive supportés"
 
-#: archive.c:456 builtin/archive.c:90 builtin/clone.c:110 builtin/clone.c:113
-#: builtin/submodule--helper.c:1222 builtin/submodule--helper.c:1593
+#: archive.c:479 builtin/archive.c:91 builtin/clone.c:113 builtin/clone.c:116
+#: builtin/submodule--helper.c:1391 builtin/submodule--helper.c:1884
 msgid "repo"
 msgstr "dépôt"
 
-#: archive.c:457 builtin/archive.c:91
+#: archive.c:480 builtin/archive.c:92
 msgid "retrieve the archive from remote repository <repo>"
 msgstr "récupérer l'archive depuis le dépôt distant <dépôt>"
 
-#: archive.c:458 builtin/archive.c:92 builtin/notes.c:489
+#: archive.c:481 builtin/archive.c:93 builtin/difftool.c:715
+#: builtin/notes.c:498
 msgid "command"
 msgstr "commande"
 
-#: archive.c:459 builtin/archive.c:93
+#: archive.c:482 builtin/archive.c:94
 msgid "path to the remote git-upload-archive command"
 msgstr "chemin vers la commande distante git-upload-archive"
 
-#: archive.c:466
+#: archive.c:489
 msgid "Unexpected option --remote"
 msgstr "Option --remote inattendue"
 
-#: archive.c:468
+#: archive.c:491
 msgid "Option --exec can only be used together with --remote"
 msgstr "L'option --exec ne peut être utilisée qu'en complément de --remote"
 
-#: archive.c:470
+#: archive.c:493
 msgid "Unexpected option --output"
 msgstr "Option --output inattendue"
 
-#: archive.c:492
+#: archive.c:515
 #, c-format
 msgid "Unknown archive format '%s'"
 msgstr "Format d'archive inconnu '%s'"
 
-#: archive.c:499
+#: archive.c:522
 #, c-format
 msgid "Argument not supported for format '%s': -%d"
 msgstr "Argument non supporté pour le format '%s' : -%d"
 
-#: attr.c:218
+#: archive-tar.c:125 archive-zip.c:350
+#, c-format
+msgid "cannot stream blob %s"
+msgstr "impossible de transmettre le blob %s en flux"
+
+#: archive-tar.c:266 archive-zip.c:368
+#, c-format
+msgid "unsupported file mode: 0%o (SHA1: %s)"
+msgstr "mode de fichier non supporté :0%o (SHA1: %s)"
+
+#: archive-tar.c:293 archive-zip.c:358
+#, c-format
+msgid "cannot read %s"
+msgstr "impossible de lire %s"
+
+#: archive-tar.c:465
+#, c-format
+msgid "unable to start '%s' filter"
+msgstr "impossible de démarrer le filtre '%s'"
+
+#: archive-tar.c:468
+msgid "unable to redirect descriptor"
+msgstr "impossible de rediriger un descripteur"
+
+#: archive-tar.c:475
+#, c-format
+msgid "'%s' filter reported error"
+msgstr "le filtre '%s' a retourné une erreur"
+
+#: archive-zip.c:319
+#, c-format
+msgid "path is not valid UTF-8: %s"
+msgstr "le chemin n'est pas codé en UTF-8 valide : %s"
+
+#: archive-zip.c:323
+#, c-format
+msgid "path too long (%d chars, SHA1: %s): %s"
+msgstr "le chemin est trop long (%d caractères, SHA1 : %s) : %s"
+
+#: archive-zip.c:479 builtin/pack-objects.c:230 builtin/pack-objects.c:233
+#, c-format
+msgid "deflate error (%d)"
+msgstr "erreur de compression (%d)"
+
+#: archive-zip.c:614
+#, c-format
+msgid "timestamp too large for this system: %<PRIuMAX>"
+msgstr "l'horodatage est trop grand pour ce système : %<PRIuMAX>"
+
+#: attr.c:212
 #, c-format
 msgid "%.*s is not a valid attribute name"
 msgstr "%.*s n'est pas un nom valide d'attribut"
 
-#: attr.c:415
+#: attr.c:369
+#, c-format
+msgid "%s not allowed: %s:%d"
+msgstr "%s non permis : %s : %d"
+
+#: attr.c:409
 msgid ""
 "Negative patterns are ignored in git attributes\n"
 "Use '\\!' for literal leading exclamation."
@@ -945,22 +1461,22 @@ msgstr ""
 "Les motifs de négation sont ignorés dans les attributs git\n"
 "Utilisez '\\!' pour un point d'exclamation littéral."
 
-#: bisect.c:461
+#: bisect.c:468
 #, c-format
 msgid "Badly quoted content in file '%s': %s"
 msgstr "Contenu mal cité dans le fichier '%s' : %s"
 
-#: bisect.c:669
+#: bisect.c:678
 #, c-format
 msgid "We cannot bisect more!\n"
 msgstr "Impossible de pousser la bissection plus loin !\n"
 
-#: bisect.c:723
+#: bisect.c:733
 #, c-format
 msgid "Not a valid commit name %s"
 msgstr "%s n'est pas un nom de commit valide"
 
-#: bisect.c:747
+#: bisect.c:758
 #, c-format
 msgid ""
 "The merge base %s is bad.\n"
@@ -969,7 +1485,7 @@ msgstr ""
 "La base de fusion %s est mauvaise.\n"
 "Cela signifie que le bogue été corrigé entre %s et [%s].\n"
 
-#: bisect.c:752
+#: bisect.c:763
 #, c-format
 msgid ""
 "The merge base %s is new.\n"
@@ -978,7 +1494,7 @@ msgstr ""
 "La base de fusion %s est nouvelle.\n"
 "La propriété a changé entre %s et [%s].\n"
 
-#: bisect.c:757
+#: bisect.c:768
 #, c-format
 msgid ""
 "The merge base %s is %s.\n"
@@ -987,7 +1503,7 @@ msgstr ""
 "La base de fusion %s est %s.\n"
 "Ceci signifie que le premier commit '%s' est entre %s et [%s].\n"
 
-#: bisect.c:765
+#: bisect.c:776
 #, c-format
 msgid ""
 "Some %s revs are not ancestors of the %s rev.\n"
@@ -998,7 +1514,7 @@ msgstr ""
 "git bisect ne peut pas fonctionner correctement dans ce cas.\n"
 "Peut-être les révisions %s et %s ne sont-elles pas les bonnes ?\n"
 
-#: bisect.c:778
+#: bisect.c:789
 #, c-format
 msgid ""
 "the merge base between %s and [%s] must be skipped.\n"
@@ -1010,36 +1526,36 @@ msgstr ""
 "et %s.\n"
 "On continue tout de même."
 
-#: bisect.c:811
+#: bisect.c:822
 #, c-format
 msgid "Bisecting: a merge base must be tested\n"
 msgstr "Bissection : une base de fusion doit être testée\n"
 
-#: bisect.c:851
+#: bisect.c:865
 #, c-format
 msgid "a %s revision is needed"
 msgstr "une révision %s est nécessaire"
 
-#: bisect.c:870 builtin/notes.c:175 builtin/tag.c:236
+#: bisect.c:884 builtin/notes.c:177 builtin/tag.c:254
 #, c-format
 msgid "could not create file '%s'"
 msgstr "impossible de créer le fichier '%s'"
 
-#: bisect.c:921
+#: bisect.c:928 builtin/merge.c:148
 #, c-format
 msgid "could not read file '%s'"
 msgstr "impossible de lire le fichier '%s'"
 
-#: bisect.c:951
+#: bisect.c:958
 msgid "reading bisect refs failed"
 msgstr "impossible de lire les références de bissection"
 
-#: bisect.c:970
+#: bisect.c:977
 #, c-format
 msgid "%s was both %s and %s\n"
 msgstr "%s était à la fois %s et %s\n"
 
-#: bisect.c:978
+#: bisect.c:985
 #, c-format
 msgid ""
 "No testable commit found.\n"
@@ -1048,7 +1564,7 @@ msgstr ""
 "Aucun commit testable n'a été trouvé\n"
 "Peut-être avez-vous démarré avec un mauvais paramètre de chemin ?\n"
 
-#: bisect.c:997
+#: bisect.c:1004
 #, c-format
 msgid "(roughly %d step)"
 msgid_plural "(roughly %d steps)"
@@ -1058,52 +1574,53 @@ msgstr[1] "(à peu près %d étapes)"
 #. TRANSLATORS: the last %s will be replaced with "(roughly %d
 #. steps)" translation.
 #.
-#: bisect.c:1003
+#: bisect.c:1010
 #, c-format
 msgid "Bisecting: %d revision left to test after this %s\n"
 msgid_plural "Bisecting: %d revisions left to test after this %s\n"
-msgstr[0] "Bissection : %d révision à tester après cette %s\n"
-msgstr[1] "Bissection : %d révisions à tester après cette %s\n"
+msgstr[0] "Bissection : %d révision à tester après ceci %s\n"
+msgstr[1] "Bissection : %d révisions à tester après ceci %s\n"
 
-#: blame.c:1756
+#: blame.c:2700
 msgid "--contents and --reverse do not blend well."
 msgstr "--contents et --reverse ne font pas bon ménage."
 
-#: blame.c:1767
+#: blame.c:2714
 msgid "cannot use --contents with final commit object name"
 msgstr "on ne peut pas utiliser --contents avec un nom d'objet commit final"
 
-#: blame.c:1787
+#: blame.c:2735
 msgid "--reverse and --first-parent together require specified latest commit"
 msgstr ""
 "--reverse et --first-parent ensemble nécessitent la spécification d'un "
 "dernier commit"
 
-#: blame.c:1796 bundle.c:160 ref-filter.c:2075 sequencer.c:1861
-#: sequencer.c:3632 builtin/commit.c:981 builtin/log.c:366 builtin/log.c:920
-#: builtin/log.c:1371 builtin/log.c:1702 builtin/log.c:1950 builtin/merge.c:372
+#: blame.c:2744 bundle.c:167 ref-filter.c:2203 remote.c:1941 sequencer.c:2093
+#: sequencer.c:4460 builtin/commit.c:1040 builtin/log.c:388 builtin/log.c:991
+#: builtin/log.c:1520 builtin/log.c:1925 builtin/log.c:2215 builtin/merge.c:411
+#: builtin/pack-objects.c:3128 builtin/pack-objects.c:3143
 #: builtin/shortlog.c:192
 msgid "revision walk setup failed"
 msgstr "échec de la préparation du parcours des révisions"
 
-#: blame.c:1814
+#: blame.c:2762
 msgid ""
 "--reverse --first-parent together require range along first-parent chain"
 msgstr ""
 "--reverse --first-parent ensemble nécessitent une portée avec la chaîne de "
 "premier parent"
 
-#: blame.c:1825
+#: blame.c:2773
 #, c-format
 msgid "no such path %s in %s"
 msgstr "pas de chemin %s dans %s"
 
-#: blame.c:1836
+#: blame.c:2784
 #, c-format
 msgid "cannot read blob %s for path %s"
 msgstr "impossible de lire le blob %s  pour le chemin %s"
 
-#: branch.c:54
+#: branch.c:53
 #, c-format
 msgid ""
 "\n"
@@ -1114,99 +1631,99 @@ msgstr ""
 "\n"
 "Après correction de la cause de l'erreur, vous pouvez essayer de corriger\n"
 "l'information de suivi distant en invoquant\n"
-"\"git branch --setup-upstream-to=%s%s%s\"."
+"\"git branch --set-upstream-to=%s%s%s\"."
 
-#: branch.c:68
+#: branch.c:67
 #, c-format
 msgid "Not setting branch %s as its own upstream."
 msgstr "La branche %s ne peut pas être sa propre branche amont."
 
-#: branch.c:94
+#: branch.c:93
 #, c-format
 msgid "Branch '%s' set up to track remote branch '%s' from '%s' by rebasing."
 msgstr ""
 "La branche '%s' est paramétrée pour suivre la branche distante '%s' de '%s' "
 "en rebasant."
 
-#: branch.c:95
+#: branch.c:94
 #, c-format
 msgid "Branch '%s' set up to track remote branch '%s' from '%s'."
 msgstr ""
 "La branche '%s' est paramétrée pour suivre la branche distante '%s' depuis "
 "'%s'."
 
-#: branch.c:99
+#: branch.c:98
 #, c-format
 msgid "Branch '%s' set up to track local branch '%s' by rebasing."
 msgstr ""
 "La branche '%s' est paramétrée pour suivre la branche locale '%'s en "
 "rebasant."
 
-#: branch.c:100
+#: branch.c:99
 #, c-format
 msgid "Branch '%s' set up to track local branch '%s'."
 msgstr "La branche '%s' est paramétrée pour suivre la branche locale '%s'."
 
-#: branch.c:105
+#: branch.c:104
 #, c-format
 msgid "Branch '%s' set up to track remote ref '%s' by rebasing."
 msgstr ""
 "La branche '%s' est paramétrée pour suivre la référence distante '%s' en "
 "rebasant."
 
-#: branch.c:106
+#: branch.c:105
 #, c-format
 msgid "Branch '%s' set up to track remote ref '%s'."
 msgstr "La branche '%s' est paramétrée pour suivre la référence distante '%s'."
 
-#: branch.c:110
+#: branch.c:109
 #, c-format
 msgid "Branch '%s' set up to track local ref '%s' by rebasing."
 msgstr ""
 "La branche '%s' est paramétrée pour suivre la référence locale '%s' en "
 "rebasant."
 
-#: branch.c:111
+#: branch.c:110
 #, c-format
 msgid "Branch '%s' set up to track local ref '%s'."
 msgstr "La branche '%s' est paramétrée pour suivre la référence locale '%s'."
 
-#: branch.c:120
+#: branch.c:119
 msgid "Unable to write upstream branch configuration"
 msgstr "Échec de l'écriture de la configuration de branche amont"
 
-#: branch.c:157
+#: branch.c:156
 #, c-format
 msgid "Not tracking: ambiguous information for ref %s"
 msgstr "Pas de suivi : information ambiguë pour la référence %s"
 
-#: branch.c:190
+#: branch.c:189
 #, c-format
 msgid "'%s' is not a valid branch name."
 msgstr "'%s' n'est pas un nom de branche valide."
 
-#: branch.c:209
+#: branch.c:208
 #, c-format
 msgid "A branch named '%s' already exists."
 msgstr "Une branche nommée '%s' existe déjà."
 
-#: branch.c:214
+#: branch.c:213
 msgid "Cannot force update the current branch."
 msgstr "Impossible de forcer la mise à jour de la branche courante."
 
-#: branch.c:234
+#: branch.c:233
 #, c-format
 msgid "Cannot setup tracking information; starting point '%s' is not a branch."
 msgstr ""
 "Impossible de paramétrer le suivi de branche ; le point de départ '%s' n'est "
 "pas une branche."
 
-#: branch.c:236
+#: branch.c:235
 #, c-format
 msgid "the requested upstream branch '%s' does not exist"
 msgstr "la branche amont demandée '%s' n'existe pas"
 
-#: branch.c:238
+#: branch.c:237
 msgid ""
 "\n"
 "If you are planning on basing your work on an upstream\n"
@@ -1241,85 +1758,94 @@ msgstr "Nom d'objet ambigu : '%s'."
 msgid "Not a valid branch point: '%s'."
 msgstr "Point d'embranchement invalide : '%s'."
 
-#: branch.c:360
+#: branch.c:364
 #, c-format
 msgid "'%s' is already checked out at '%s'"
 msgstr "'%s' est déjà extrait dans '%s'"
 
-#: branch.c:383
+#: branch.c:387
 #, c-format
 msgid "HEAD of working tree %s is not updated"
 msgstr "la HEAD de la copie de travail %s n'est pas mise à jour"
 
-#: bundle.c:34
+#: bundle.c:36
 #, c-format
 msgid "'%s' does not look like a v2 bundle file"
 msgstr "'%s' ne semble pas être un fichier bundle v2"
 
-#: bundle.c:62
+#: bundle.c:64
 #, c-format
 msgid "unrecognized header: %s%s (%d)"
 msgstr "en-tête non reconnu : %s%s (%d)"
 
-#: bundle.c:88 sequencer.c:2081 sequencer.c:2558 builtin/commit.c:755
+#: bundle.c:90 rerere.c:480 rerere.c:690 sequencer.c:2344 sequencer.c:3108
+#: builtin/commit.c:811
 #, c-format
 msgid "could not open '%s'"
 msgstr "impossible d'ouvrir '%s'"
 
-#: bundle.c:139
+#: bundle.c:143
 msgid "Repository lacks these prerequisite commits:"
 msgstr "Le dépôt ne dispose pas des commits prérequis suivants :"
 
-#: bundle.c:190
+#: bundle.c:146
+msgid "need a repository to verify a bundle"
+msgstr "la vérification d'un colis requiert un dépôt"
+
+#: bundle.c:197
 #, c-format
 msgid "The bundle contains this ref:"
 msgid_plural "The bundle contains these %d refs:"
 msgstr[0] "Le colis contient cette référence :"
 msgstr[1] "Le colis contient ces %d références :"
 
-#: bundle.c:197
+#: bundle.c:204
 msgid "The bundle records a complete history."
 msgstr "Le colis enregistre l'historique complet."
 
-#: bundle.c:199
+#: bundle.c:206
 #, c-format
 msgid "The bundle requires this ref:"
 msgid_plural "The bundle requires these %d refs:"
 msgstr[0] "Le colis exige cette référence :"
 msgstr[1] "Le colis exige ces %d références :"
 
-#: bundle.c:258
+#: bundle.c:273
+msgid "unable to dup bundle descriptor"
+msgstr "impossible de dupliquer le descripteur de liasse"
+
+#: bundle.c:280
 msgid "Could not spawn pack-objects"
 msgstr "Impossible de créer des objets groupés"
 
-#: bundle.c:269
+#: bundle.c:291
 msgid "pack-objects died"
 msgstr "les objets groupés ont disparu"
 
-#: bundle.c:311
+#: bundle.c:333
 msgid "rev-list died"
 msgstr "rev-list a disparu"
 
-#: bundle.c:360
+#: bundle.c:382
 #, c-format
 msgid "ref '%s' is excluded by the rev-list options"
 msgstr "la référence '%s' est exclue par les options de rev-list"
 
-#: bundle.c:450 builtin/log.c:183 builtin/log.c:1607 builtin/shortlog.c:303
+#: bundle.c:461 builtin/log.c:203 builtin/log.c:1814 builtin/shortlog.c:306
 #, c-format
 msgid "unrecognized argument: %s"
 msgstr "argument non reconnu : %s"
 
-#: bundle.c:458
+#: bundle.c:469
 msgid "Refusing to create empty bundle."
 msgstr "Refus de créer un colis vide."
 
-#: bundle.c:470
+#: bundle.c:479
 #, c-format
 msgid "cannot create '%s'"
 msgstr "impossible de créer '%s'"
 
-#: bundle.c:498
+#: bundle.c:504
 msgid "index-pack died"
 msgstr "l'index de groupe a disparu"
 
@@ -1328,19 +1854,18 @@ msgstr "l'index de groupe a disparu"
 msgid "invalid color value: %.*s"
 msgstr "Valeur invalide de couleur : %.*s"
 
-#: commit.c:43 sequencer.c:2364 builtin/am.c:421 builtin/am.c:465
-#: builtin/am.c:1436 builtin/am.c:2072 builtin/replace.c:376
-#: builtin/replace.c:448
+#: commit.c:51 sequencer.c:2811 builtin/am.c:354 builtin/am.c:398
+#: builtin/am.c:1366 builtin/am.c:2009 builtin/replace.c:456
 #, c-format
 msgid "could not parse %s"
 msgstr "impossible d'analyser %s"
 
-#: commit.c:45
+#: commit.c:53
 #, c-format
 msgid "%s %s is not a commit!"
 msgstr "%s %s n'est pas un commit !"
 
-#: commit.c:182
+#: commit.c:193
 msgid ""
 "Support for <GIT_DIR>/info/grafts is deprecated\n"
 "and will be removed in a future Git version.\n"
@@ -1360,7 +1885,27 @@ msgstr ""
 "Supprimez ce message en lançant\n"
 "\"git config advice.graftFileDeprecated false\""
 
-#: commit.c:1540
+#: commit.c:1152
+#, c-format
+msgid "Commit %s has an untrusted GPG signature, allegedly by %s."
+msgstr "La validation %s a une signature GPG non fiable, prétendument par %s."
+
+#: commit.c:1155
+#, c-format
+msgid "Commit %s has a bad GPG signature allegedly by %s."
+msgstr "La validation %s a une mauvaise signature GPG prétendument par %s."
+
+#: commit.c:1158
+#, c-format
+msgid "Commit %s does not have a GPG signature."
+msgstr "La validation %s n'a pas de signature GPG."
+
+#: commit.c:1161
+#, c-format
+msgid "Commit %s has a good GPG signature by %s\n"
+msgstr "La validation %s a une signature GPG correcte par %s\n"
+
+#: commit.c:1415
 msgid ""
 "Warning: commit message did not conform to UTF-8.\n"
 "You may want to amend it after fixing the message, or set the config\n"
@@ -1372,201 +1917,608 @@ msgstr ""
 "variable de configuration i18n.commitencoding à l'encodage utilisé par votre "
 "projet.\n"
 
-#: commit-graph.c:669
+#: commit-graph.c:130
+msgid "commit-graph file is too small"
+msgstr "le graphe de commit est trop petit"
+
+#: commit-graph.c:195
+#, c-format
+msgid "commit-graph signature %X does not match signature %X"
+msgstr ""
+"la signature du graphe de commit %X ne correspond pas à la signature %X"
+
+#: commit-graph.c:202
+#, c-format
+msgid "commit-graph version %X does not match version %X"
+msgstr "la version %X du graphe de commit ne correspond pas à la version %X"
+
+#: commit-graph.c:209
+#, c-format
+msgid "commit-graph hash version %X does not match version %X"
+msgstr ""
+"l'empreinte de la version %X du graphe de commit ne correspond pas à la "
+"version %X"
+
+#: commit-graph.c:232
+msgid "commit-graph chunk lookup table entry missing; file may be incomplete"
+msgstr ""
+"entrée de table de consultation de morceaux de graphe de commite manquante ; "
+"le fichier est peut être incomplet"
+
+#: commit-graph.c:243
+#, c-format
+msgid "commit-graph improper chunk offset %08x%08x"
+msgstr "décalage de bloc %08x%08x du graphe de commit inadéquat"
+
+#: commit-graph.c:286
+#, c-format
+msgid "commit-graph chunk id %08x appears multiple times"
+msgstr "l'id de bloc de graphe de commit %08x apparaît des multiples fois"
+
+#: commit-graph.c:350
+msgid "commit-graph has no base graphs chunk"
+msgstr "le graphe de commit n'a pas de section de graphes de base"
+
+#: commit-graph.c:360
+msgid "commit-graph chain does not match"
+msgstr "la chaîne de graphe de commit ne correspond pas"
+
+#: commit-graph.c:407
+#, c-format
+msgid "invalid commit-graph chain: line '%s' not a hash"
+msgstr ""
+"chaîne de graphe de commit invalide : la ligne '%s' n'est pas une empreinte"
+
+#: commit-graph.c:433
+msgid "unable to find all commit-graph files"
+msgstr "impossible de trouver tous les fichiers du graphe de commit"
+
+#: commit-graph.c:564 commit-graph.c:624
+msgid "invalid commit position. commit-graph is likely corrupt"
+msgstr ""
+"position de commit invalide. Le graphe de commit est vraisemblablement "
+"corrompu"
+
+#: commit-graph.c:585
+#, c-format
+msgid "could not find commit %s"
+msgstr "impossible de trouver le commit %s"
+
+#: commit-graph.c:858 builtin/am.c:1287
+#, c-format
+msgid "unable to parse commit %s"
+msgstr "impossible d'analyser le commit %s"
+
+#: commit-graph.c:1017 builtin/pack-objects.c:2641
+#, c-format
+msgid "unable to get type of object %s"
+msgstr "impossible d'obtenir le type de l'objet %s"
+
+#: commit-graph.c:1049
+msgid "Loading known commits in commit graph"
+msgstr "Lecture des commits connus dans un graphe de commit"
+
+#: commit-graph.c:1066
+msgid "Expanding reachable commits in commit graph"
+msgstr "Expansion des commits joignables dans un graphe de commit"
+
+#: commit-graph.c:1085
+msgid "Clearing commit marks in commit graph"
+msgstr "Suppression les marques de commit dans le graphe de commits"
+
+#: commit-graph.c:1104
+msgid "Computing commit graph generation numbers"
+msgstr "Calcul des chiffres de génération du graphe de commits"
+
+#: commit-graph.c:1179
+#, c-format
+msgid "Finding commits for commit graph in %d pack"
+msgid_plural "Finding commits for commit graph in %d packs"
+msgstr[0] "Recherche de commits pour un graphe de commits dans %d paquet"
+msgstr[1] "Recherche de commits pour un graphe de commits dans %d paquets"
+
+#: commit-graph.c:1192
+#, c-format
+msgid "error adding pack %s"
+msgstr "erreur à l'ajout du packet %s"
+
+#: commit-graph.c:1196
+#, c-format
+msgid "error opening index for %s"
+msgstr "erreur à l'ouverture de l'index pour %s"
+
+#: commit-graph.c:1220
+#, c-format
+msgid "Finding commits for commit graph from %d ref"
+msgid_plural "Finding commits for commit graph from %d refs"
+msgstr[0] "Recherche de commits pour un graphe de commits depuis %d réf"
+msgstr[1] "Recherche de commits pour un graphe de commits depuis %d réfs"
+
+#: commit-graph.c:1240
+#, c-format
+msgid "invalid commit object id: %s"
+msgstr "identifiant d'objet commit invalide : %s"
+
+#: commit-graph.c:1255
+msgid "Finding commits for commit graph among packed objects"
+msgstr ""
+"Recherche de commits pour un graphe de commits parmi les objets empaquetés"
+
+#: commit-graph.c:1270
+msgid "Counting distinct commits in commit graph"
+msgstr "Comptage des commits distincts dans un graphe de commit"
+
+#: commit-graph.c:1300
+msgid "Finding extra edges in commit graph"
+msgstr "Recherche d'arêtes supplémentaires dans un graphe de commits"
+
+#: commit-graph.c:1346
+msgid "failed to write correct number of base graph ids"
+msgstr "échec à l'écriture le nombre correct d'id de base de fusion"
+
+#: commit-graph.c:1379 midx.c:814
+#, c-format
+msgid "unable to create leading directories of %s"
+msgstr "impossible de créer les répertoires de premier niveau de %s"
+
+#: commit-graph.c:1391 builtin/index-pack.c:306 builtin/repack.c:248
+#, c-format
+msgid "unable to create '%s'"
+msgstr "impossible de créer '%s'"
+
+#: commit-graph.c:1451
+#, c-format
+msgid "Writing out commit graph in %d pass"
+msgid_plural "Writing out commit graph in %d passes"
+msgstr[0] "Écriture le graphe de commits en %d passe"
+msgstr[1] "Écriture le graphe de commits en %d passes"
+
+#: commit-graph.c:1492
+msgid "unable to open commit-graph chain file"
+msgstr "impossible d'ouvrir le fichier de graphe de commit"
+
+#: commit-graph.c:1504
+msgid "failed to rename base commit-graph file"
+msgstr "échec du renommage du fichier de graphe de commits"
+
+#: commit-graph.c:1524
+msgid "failed to rename temporary commit-graph file"
+msgstr "impossible de renommer le fichier temporaire de graphe de commits"
+
+#: commit-graph.c:1635
+msgid "Scanning merged commits"
+msgstr "Analyse des commits de fusion"
+
+#: commit-graph.c:1646
+#, c-format
+msgid "unexpected duplicate commit id %s"
+msgstr "id de commit %s dupliqué inattendu"
+
+#: commit-graph.c:1670
+msgid "Merging commit-graph"
+msgstr "fusion du graphe de commits"
+
+#: commit-graph.c:1860
 #, c-format
 msgid "the commit graph format cannot write %d commits"
 msgstr "le graphe de commits ne peut pas écrire %d commits"
 
-#: commit-graph.c:696
+#: commit-graph.c:1871
 msgid "too many commits to write graph"
 msgstr "trop de commits pour écrire un graphe"
 
-#: commit-graph.c:707 builtin/init-db.c:516 builtin/init-db.c:521
+#: commit-graph.c:1961
+msgid "the commit-graph file has incorrect checksum and is likely corrupt"
+msgstr ""
+"le graphe de commit a une somme de contrôle incorrecte et est "
+"vraisemblablement corrompu"
+
+#: commit-graph.c:1971
 #, c-format
-msgid "cannot mkdir %s"
-msgstr "impossible de créer le répertoire (mkdir) %s"
+msgid "commit-graph has incorrect OID order: %s then %s"
+msgstr "le graphe de commit a un ordre d'OID incorrect : %s puis %s"
+
+#: commit-graph.c:1981 commit-graph.c:1996
+#, c-format
+msgid "commit-graph has incorrect fanout value: fanout[%d] = %u != %u"
+msgstr ""
+"le graphe de commit a une valeur de dispersion incorrecte : dispersion[%d] = "
+"%u != %u"
+
+#: commit-graph.c:1988
+#, c-format
+msgid "failed to parse commit %s from commit-graph"
+msgstr "échec de l'analyse le commit %s depuis le graphe de commits"
+
+#: commit-graph.c:2006
+msgid "Verifying commits in commit graph"
+msgstr "Verification des commits dans le graphe de commits"
+
+#: commit-graph.c:2020
+#, c-format
+msgid "failed to parse commit %s from object database for commit-graph"
+msgstr ""
+"échec de l'analyse du commit %s depuis la base de données d'objets pour le "
+"graphe de commit"
+
+#: commit-graph.c:2027
+#, c-format
+msgid "root tree OID for commit %s in commit-graph is %s != %s"
+msgstr ""
+"l'OID de l'arbre racine pour le commit %s dans le graphe de commit est %s != "
+"%s"
+
+#: commit-graph.c:2037
+#, c-format
+msgid "commit-graph parent list for commit %s is too long"
+msgstr ""
+"la liste des parents du graphe de commit pour le commit %s est trop longue"
+
+#: commit-graph.c:2046
+#, c-format
+msgid "commit-graph parent for %s is %s != %s"
+msgstr "le parent du graphe de commit pour %s est %s != %s"
+
+#: commit-graph.c:2059
+#, c-format
+msgid "commit-graph parent list for commit %s terminates early"
+msgstr ""
+"la liste de parents du graphe de commit pour le commit %s se termine trop tôt"
+
+#: commit-graph.c:2064
+#, c-format
+msgid ""
+"commit-graph has generation number zero for commit %s, but non-zero elsewhere"
+msgstr ""
+"le graphe de commit a un numéro de génération nul pour le commit %s, mais "
+"non-nul ailleurs"
+
+#: commit-graph.c:2068
+#, c-format
+msgid ""
+"commit-graph has non-zero generation number for commit %s, but zero elsewhere"
+msgstr ""
+"le graphe de commit a un numéro de génération non-nul pour le commit %s, "
+"mais nul ailleurs"
+
+#: commit-graph.c:2083
+#, c-format
+msgid "commit-graph generation for commit %s is %u != %u"
+msgstr "la génération du graphe de commit pour le commit %s est %u != %u"
+
+#: commit-graph.c:2089
+#, c-format
+msgid "commit date for commit %s in commit-graph is %<PRIuMAX> != %<PRIuMAX>"
+msgstr ""
+"la date de validation pour le commit %s dans le graphe de commit est "
+"%<PRIuMAX> != %<PRIuMAX>"
 
-#: compat/obstack.c:405 compat/obstack.c:407
+#: compat/obstack.c:406 compat/obstack.c:408
 msgid "memory exhausted"
 msgstr "plus de mémoire"
 
-#: config.c:187
+#: config.c:124
+#, c-format
+msgid ""
+"exceeded maximum include depth (%d) while including\n"
+"\t%s\n"
+"from\n"
+"\t%s\n"
+"This might be due to circular includes."
+msgstr ""
+"profondeur d'inclusion maximum (%d) dépassée à l'inclusion de\n"
+"\t%s\n"
+"depuis\n"
+"\t%s\n"
+"possibilité d'inclusions multiples."
+
+#: config.c:140
+#, c-format
+msgid "could not expand include path '%s'"
+msgstr "expansion impossible du chemin d'inclusion '%s'"
+
+#: config.c:151
+msgid "relative config includes must come from files"
+msgstr "les inclusions de configuration relatives doivent venir de fichiers"
+
+#: config.c:197
 msgid "relative config include conditionals must come from files"
 msgstr ""
 "les conditions d'inclusion de configuration relative doivent venir de "
 "fichiers"
 
-#: config.c:788
+#: config.c:376
+#, c-format
+msgid "key does not contain a section: %s"
+msgstr "la clé ne contient pas de section: %s"
+
+#: config.c:382
+#, c-format
+msgid "key does not contain variable name: %s"
+msgstr "la clé ne contient pas de nom de variable : %s"
+
+#: config.c:406 sequencer.c:2530
+#, c-format
+msgid "invalid key: %s"
+msgstr "clé invalide : %s"
+
+#: config.c:412
+#, c-format
+msgid "invalid key (newline): %s"
+msgstr "clé invalide (retour chariot) : %s"
+
+#: config.c:448 config.c:460
+#, c-format
+msgid "bogus config parameter: %s"
+msgstr "paramètre de configuration mal formé: %s"
+
+#: config.c:495
+#, c-format
+msgid "bogus format in %s"
+msgstr "formatage mal formé dans %s"
+
+#: config.c:821
 #, c-format
 msgid "bad config line %d in blob %s"
 msgstr "ligne %d de config incorrecte dans le blob %s"
 
-#: config.c:792
+#: config.c:825
 #, c-format
 msgid "bad config line %d in file %s"
 msgstr "ligne %d de config incorrecte dans le fichier %s"
 
-#: config.c:796
+#: config.c:829
 #, c-format
 msgid "bad config line %d in standard input"
 msgstr "ligne %d de config incorrecte dans l'entrée standard"
 
-#: config.c:800
+#: config.c:833
 #, c-format
 msgid "bad config line %d in submodule-blob %s"
 msgstr "ligne %d de config incorrecte dans le blob de sous-module %s"
 
-#: config.c:804
+#: config.c:837
 #, c-format
 msgid "bad config line %d in command line %s"
 msgstr "ligne %d de config incorrecte dans la ligne de commande %s"
 
-#: config.c:808
+#: config.c:841
 #, c-format
 msgid "bad config line %d in %s"
 msgstr "ligne %d de config incorrecte dans %s"
 
-#: config.c:936
+#: config.c:978
 msgid "out of range"
 msgstr "hors plage"
 
-#: config.c:936
+#: config.c:978
 msgid "invalid unit"
 msgstr "unité invalide"
 
-#: config.c:942
+#: config.c:979
 #, c-format
 msgid "bad numeric config value '%s' for '%s': %s"
 msgstr "valeur numérique de configuration invalide '%s' pour '%s' : %s"
 
-#: config.c:947
+#: config.c:998
 #, c-format
 msgid "bad numeric config value '%s' for '%s' in blob %s: %s"
 msgstr ""
 "valeur numérique de configuration incorrecte '%s' pour '%s' dans le blob "
 "%s : %s"
 
-#: config.c:950
+#: config.c:1001
 #, c-format
 msgid "bad numeric config value '%s' for '%s' in file %s: %s"
 msgstr ""
 "valeur numérique de configuration incorrecte '%s' pour '%s' dans le fichier "
 "%s : %s"
 
-#: config.c:953
+#: config.c:1004
 #, c-format
 msgid "bad numeric config value '%s' for '%s' in standard input: %s"
 msgstr ""
 "valeur numérique de configuration incorrecte '%s' pour '%s' dans l'entrée "
 "standard : %s"
 
-#: config.c:956
+#: config.c:1007
 #, c-format
 msgid "bad numeric config value '%s' for '%s' in submodule-blob %s: %s"
 msgstr ""
 "valeur numérique de configuration incorrecte '%s' pour '%s' dans le blob de "
 "sous-module %s : %s"
 
-#: config.c:959
+#: config.c:1010
 #, c-format
 msgid "bad numeric config value '%s' for '%s' in command line %s: %s"
 msgstr ""
 "valeur numérique de configuration incorrecte '%s' pour '%s' dans la ligne de "
 "commande %s : %s"
 
-#: config.c:962
+#: config.c:1013
 #, c-format
 msgid "bad numeric config value '%s' for '%s' in %s: %s"
 msgstr ""
 "valeur numérique de configuration incorrecte '%s' pour '%s' dans %s : %s"
 
-#: config.c:1057
+#: config.c:1108
 #, c-format
 msgid "failed to expand user dir in: '%s'"
 msgstr "impossible d'étendre le répertoire utilisateur dans : '%s'"
 
-#: config.c:1066
+#: config.c:1117
 #, c-format
 msgid "'%s' for '%s' is not a valid timestamp"
 msgstr "'%s' pour '%s' n'est pas un horodatage valide"
 
-#: config.c:1171 config.c:1182
+#: config.c:1208
+#, c-format
+msgid "abbrev length out of range: %d"
+msgstr "longueur d'abbrev hors plage : %d"
+
+#: config.c:1222 config.c:1233
 #, c-format
 msgid "bad zlib compression level %d"
 msgstr "niveau de compression zlib incorrect %d"
 
-#: config.c:1307
+#: config.c:1325
+msgid "core.commentChar should only be one character"
+msgstr "core.commentChar ne devrait être qu'un unique caractère"
+
+#: config.c:1358
 #, c-format
 msgid "invalid mode for object creation: %s"
 msgstr "mode invalide pour la création d'objet : %s"
 
-#: config.c:1473
+#: config.c:1430
+#, c-format
+msgid "malformed value for %s"
+msgstr "valeur mal formée pour %s"
+
+#: config.c:1456
+#, c-format
+msgid "malformed value for %s: %s"
+msgstr "valeur mal formée pour %s : %s"
+
+#: config.c:1457
+msgid "must be one of nothing, matching, simple, upstream or current"
+msgstr "doit être parmi nothing, matching, simple, upstream ou current"
+
+#: config.c:1518 builtin/pack-objects.c:3394
 #, c-format
 msgid "bad pack compression level %d"
 msgstr "niveau de compression du paquet %d"
 
-#: config.c:1681
+#: config.c:1639
+#, c-format
+msgid "unable to load config blob object '%s'"
+msgstr "impossible de charger l'objet blob de config '%s'"
+
+#: config.c:1642
+#, c-format
+msgid "reference '%s' does not point to a blob"
+msgstr "la référence '%s' ne pointe pas sur un blob"
+
+#: config.c:1659
+#, c-format
+msgid "unable to resolve config blob '%s'"
+msgstr "impossible de résoudre le blob de config '%s'"
+
+#: config.c:1689
+#, c-format
+msgid "failed to parse %s"
+msgstr "échec de l'analyse de %s"
+
+#: config.c:1745
 msgid "unable to parse command-line config"
 msgstr "lecture de la configuration de ligne de commande impossible"
 
-#: config.c:2013
+#: config.c:2096
 msgid "unknown error occurred while reading the configuration files"
 msgstr "erreur inconnue pendant la lecture des fichiers de configuration"
 
-#: config.c:2200
+#: config.c:2266
 #, c-format
 msgid "Invalid %s: '%s'"
 msgstr "%s invalide : '%s'"
 
-#: config.c:2243
-#, c-format
-msgid "unknown core.untrackedCache value '%s'; using 'keep' default value"
-msgstr ""
-"valeur '%s' de core.untrackedCache inconnue ; utilisation de 'keep' par "
-"défaut"
-
-#: config.c:2269
+#: config.c:2311
 #, c-format
 msgid "splitIndex.maxPercentChange value '%d' should be between 0 and 100"
 msgstr ""
 "la valeur '%d' de splitIndex.maxPercentChange devrait se situer entre 0 et "
 "100"
 
-#: config.c:2294
+#: config.c:2357
 #, c-format
 msgid "unable to parse '%s' from command-line config"
 msgstr ""
 "impossible d'analyser '%s' depuis le configuration en ligne de commande"
 
-#: config.c:2296
+#: config.c:2359
 #, c-format
 msgid "bad config variable '%s' in file '%s' at line %d"
 msgstr ""
 "variable de configuration '%s' incorrecte dans le fichier '%s' à la ligne %d"
 
-#: config.c:2402
+#: config.c:2440
+#, c-format
+msgid "invalid section name '%s'"
+msgstr "nom de section invalide '%s'"
+
+#: config.c:2472
 #, c-format
 msgid "%s has multiple values"
 msgstr "%s a des valeurs multiples"
 
-#: config.c:2766 config.c:3019
+#: config.c:2501
+#, c-format
+msgid "failed to write new configuration file %s"
+msgstr "impossible d'écrire le fichier de configuration %s"
+
+#: config.c:2753 config.c:3077
+#, c-format
+msgid "could not lock config file %s"
+msgstr "impossible de verrouiller le fichier de configuration %s"
+
+#: config.c:2764
+#, c-format
+msgid "opening %s"
+msgstr "ouverture de %s"
+
+#: config.c:2799 builtin/config.c:328
+#, c-format
+msgid "invalid pattern: %s"
+msgstr "motif invalide : %s"
+
+#: config.c:2824
+#, c-format
+msgid "invalid config file %s"
+msgstr "fichier de configuration invalide %s"
+
+#: config.c:2837 config.c:3090
 #, c-format
 msgid "fstat on %s failed"
 msgstr "échec de fstat sur %s"
 
-#: config.c:2905
+#: config.c:2848
+#, c-format
+msgid "unable to mmap '%s'"
+msgstr "impossible de réaliser un map de '%s'"
+
+#: config.c:2857 config.c:3095
+#, c-format
+msgid "chmod on %s failed"
+msgstr "échec de chmod sur %s"
+
+#: config.c:2942 config.c:3192
+#, c-format
+msgid "could not write config file %s"
+msgstr "impossible d'écrire le fichier de configuration %s"
+
+#: config.c:2976
 #, c-format
 msgid "could not set '%s' to '%s'"
 msgstr "impossible de régler '%s' à '%s'"
 
-#: config.c:2907 builtin/remote.c:779
+#: config.c:2978 builtin/remote.c:781
 #, c-format
 msgid "could not unset '%s'"
 msgstr "impossible de désinitialiser '%s'"
 
+#: config.c:3068
+#, c-format
+msgid "invalid section name: %s"
+msgstr "nom de section invalide : %s"
+
+#: config.c:3235
+#, c-format
+msgid "missing value for '%s'"
+msgstr "valeur manquante pour '%s'"
+
 #: connect.c:61
-msgid "The remote end hung up upon initial contact"
-msgstr "L'hôte distant a fermé la connexion lors du contact initial"
+msgid "the remote end hung up upon initial contact"
+msgstr "l'hôte distant a fermé la connexion lors du contact initial"
 
 #: connect.c:63
 msgid ""
@@ -1580,65 +2532,211 @@ msgstr ""
 "Veuillez vérifier que vous avez les droits d'accès\n"
 "et que le dépôt existe."
 
-#: connected.c:66 builtin/fsck.c:201 builtin/prune.c:145
-msgid "Checking connectivity"
-msgstr "Vérification de la connectivité"
-
-#: connected.c:78
-msgid "Could not run 'git rev-list'"
-msgstr "Impossible de lancer 'git rev-list'"
+#: connect.c:81
+#, c-format
+msgid "server doesn't support '%s'"
+msgstr "Le serveur ne supporte pas '%s'"
 
-#: connected.c:98
-msgid "failed write to rev-list"
-msgstr "impossible d'écrire dans la rev-list"
+#: connect.c:103
+#, c-format
+msgid "server doesn't support feature '%s'"
+msgstr "Le serveur ne supporte pas la fonctionnalité '%s'"
 
-#: connected.c:105
-msgid "failed to close rev-list's stdin"
-msgstr "impossible de fermer l'entrée standard du rev-list"
+#: connect.c:114
+msgid "expected flush after capabilities"
+msgstr "vidage attendu après les capacités"
 
-#: convert.c:206
+#: connect.c:233
 #, c-format
-msgid "CRLF would be replaced by LF in %s."
-msgstr "Les CRLF seraient remplacés par des LF dans %s."
+msgid "ignoring capabilities after first line '%s'"
+msgstr "capacités ignorées après la première ligne '%s'"
 
-#: convert.c:208
-#, c-format
-msgid ""
-"CRLF will be replaced by LF in %s.\n"
-"The file will have its original line endings in your working directory."
-msgstr ""
-"Les CRLF seront remplacés par des LF dans %s.\n"
-"Le fichier conservera ses fins de ligne d'origine dans votre copie de "
-"travail."
+#: connect.c:252
+msgid "protocol error: unexpected capabilities^{}"
+msgstr "erreur de protocole : capabilities^{} inattendu"
 
-#: convert.c:216
+#: connect.c:273
 #, c-format
-msgid "LF would be replaced by CRLF in %s"
+msgid "protocol error: expected shallow sha-1, got '%s'"
+msgstr "erreur de protocole : shallow sha-1 attendu, '%s' trouvé"
+
+#: connect.c:275
+msgid "repository on the other end cannot be shallow"
+msgstr "le dépôt distant ne peut pas être superficiel"
+
+#: connect.c:313
+msgid "invalid packet"
+msgstr "paquet invalide"
+
+#: connect.c:333
+#, c-format
+msgid "protocol error: unexpected '%s'"
+msgstr "erreur de protocole : '%s' attendu"
+
+#: connect.c:441
+#, c-format
+msgid "invalid ls-refs response: %s"
+msgstr "réponse à ls-ref invalide : %s"
+
+#: connect.c:445
+msgid "expected flush after ref listing"
+msgstr "vidage attendu après le listage de références"
+
+#: connect.c:544
+#, c-format
+msgid "protocol '%s' is not supported"
+msgstr "le protocole '%s' n'est pas supporté"
+
+#: connect.c:595
+msgid "unable to set SO_KEEPALIVE on socket"
+msgstr "impossible de positionner SO_KEEPALIVE sur la socket"
+
+#: connect.c:635 connect.c:698
+#, c-format
+msgid "Looking up %s ... "
+msgstr "Recherche de %s… "
+
+#: connect.c:639
+#, c-format
+msgid "unable to look up %s (port %s) (%s)"
+msgstr "impossible de rechercher %s (port %s) (%s)"
+
+#. TRANSLATORS: this is the end of "Looking up %s ... "
+#: connect.c:643 connect.c:714
+#, c-format
+msgid ""
+"done.\n"
+"Connecting to %s (port %s) ... "
+msgstr ""
+"fait.\n"
+"Connexion à %s (port %s)… "
+
+#: connect.c:665 connect.c:742
+#, c-format
+msgid ""
+"unable to connect to %s:\n"
+"%s"
+msgstr ""
+"impossible de se connecter à %s :\n"
+"%s"
+
+#. TRANSLATORS: this is the end of "Connecting to %s (port %s) ... "
+#: connect.c:671 connect.c:748
+msgid "done."
+msgstr "fait."
+
+#: connect.c:702
+#, c-format
+msgid "unable to look up %s (%s)"
+msgstr "impossible de rechercher %s (%s)"
+
+#: connect.c:708
+#, c-format
+msgid "unknown port %s"
+msgstr "port inconnu %s"
+
+#: connect.c:845 connect.c:1175
+#, c-format
+msgid "strange hostname '%s' blocked"
+msgstr "nom d'hôte étrange '%s' bloqué"
+
+#: connect.c:847
+#, c-format
+msgid "strange port '%s' blocked"
+msgstr "port étrange '%s' bloqué"
+
+#: connect.c:857
+#, c-format
+msgid "cannot start proxy %s"
+msgstr "impossible de démarrer un proxy %s"
+
+#: connect.c:928
+msgid "no path specified; see 'git help pull' for valid url syntax"
+msgstr ""
+"aucun chemin spécifié ; référez-vous à 'git help pull' pour une syntaxe "
+"d'URL valide"
+
+#: connect.c:1123
+msgid "ssh variant 'simple' does not support -4"
+msgstr "la variante ssh 'simple' ne supporte pas -4"
+
+#: connect.c:1135
+msgid "ssh variant 'simple' does not support -6"
+msgstr "la variante ssh 'simple' ne supporte pas -6"
+
+#: connect.c:1152
+msgid "ssh variant 'simple' does not support setting port"
+msgstr "la variante ssh 'simple' ne supporte pas de spécifier le port"
+
+#: connect.c:1264
+#, c-format
+msgid "strange pathname '%s' blocked"
+msgstr "chemin étrange '%s' bloqué"
+
+#: connect.c:1311
+msgid "unable to fork"
+msgstr "fork impossible"
+
+#: connected.c:89 builtin/fsck.c:208 builtin/prune.c:43
+msgid "Checking connectivity"
+msgstr "Vérification de la connectivité"
+
+#: connected.c:101
+msgid "Could not run 'git rev-list'"
+msgstr "Impossible de lancer 'git rev-list'"
+
+#: connected.c:121
+msgid "failed write to rev-list"
+msgstr "impossible d'écrire dans la rev-list"
+
+#: connected.c:128
+msgid "failed to close rev-list's stdin"
+msgstr "impossible de fermer l'entrée standard du rev-list"
+
+#: convert.c:194
+#, c-format
+msgid "illegal crlf_action %d"
+msgstr "crlf_action illégal %d"
+
+#: convert.c:207
+#, c-format
+msgid "CRLF would be replaced by LF in %s"
+msgstr "Les CRLF seraient remplacés par des LF dans %s"
+
+#: convert.c:209
+#, c-format
+msgid ""
+"CRLF will be replaced by LF in %s.\n"
+"The file will have its original line endings in your working directory"
+msgstr ""
+"Les CRLF seront remplacés par des LF dans %s.\n"
+"Le fichier conservera ses fins de ligne d'origine dans votre copie de travail"
+
+#: convert.c:217
+#, c-format
+msgid "LF would be replaced by CRLF in %s"
 msgstr "Les LF seraient remplacés par des CRLF dans %s"
 
-#: convert.c:218
+#: convert.c:219
 #, c-format
 msgid ""
 "LF will be replaced by CRLF in %s.\n"
-"The file will have its original line endings in your working directory."
+"The file will have its original line endings in your working directory"
 msgstr ""
 "Les LF seront remplacés par des CRLF dans %s.\n"
-"Le fichier conservera ses fins de ligne d'origine dans votre copie de "
-"travail."
+"Le fichier conservera ses fins de ligne d'origine dans votre copie de travail"
 
-#: convert.c:279
+#: convert.c:284
 #, c-format
 msgid "BOM is prohibited in '%s' if encoded as %s"
 msgstr "Aucun BOM n'est permis dans '%s' s'il est encodé comme %s"
 
-#: convert.c:286
+#: convert.c:291
 #, c-format
 msgid ""
-"The file '%s' contains a byte order mark (BOM). Please use UTF-%s as working-"
-"tree-encoding."
-msgstr ""
-"Le fichier '%s' contient un marqueur d'ordre d'octets (BOM). Veuillez "
-"utiliser UTF-%s comme encodage d'arbre de travail."
+"The file '%s' contains a byte order mark (BOM). Please use UTF-%.*s as "
+"working-tree-encoding."
+msgstr "Le fichier '%s' contient un marqueur d'ordre d'octets (BOM). Veuillez utiliser UTF-%.*s comme encodage d'arbre de travail."
 
 #: convert.c:304
 #, c-format
@@ -1655,69 +2753,121 @@ msgstr ""
 "utiliser UTF-%sBE ou UTF-%sLE (selon l'ordre désiré) comme encodage d'arbre "
 "de travail."
 
-#: convert.c:424
+#: convert.c:419 convert.c:490
 #, c-format
 msgid "failed to encode '%s' from %s to %s"
 msgstr "échec de l'encodage de '%s' de %s vers %s"
 
-#: convert.c:467
+#: convert.c:462
 #, c-format
 msgid "encoding '%s' from %s to %s and back is not the same"
 msgstr ""
 "encoder '%s' depuis %s vers %s puis inversement ne produit pas le même "
 "contenu"
 
-#: convert.c:1225
+#: convert.c:668
+#, c-format
+msgid "cannot fork to run external filter '%s'"
+msgstr "impossible de forker pour lancer le filtre externe '%s'"
+
+#: convert.c:688
+#, c-format
+msgid "cannot feed the input to external filter '%s'"
+msgstr "impossible de fournir l'entrée au filtre externe '%s'"
+
+#: convert.c:695
+#, c-format
+msgid "external filter '%s' failed %d"
+msgstr "le filtre externe '%s' a échoué %d"
+
+#: convert.c:730 convert.c:733
+#, c-format
+msgid "read from external filter '%s' failed"
+msgstr "la lecture depuis le filtre externe '%s' a échoué"
+
+#: convert.c:736 convert.c:791
+#, c-format
+msgid "external filter '%s' failed"
+msgstr "le filtre externe '%s' a échoué"
+
+#: convert.c:839
+msgid "unexpected filter type"
+msgstr "type de filtre inattendu"
+
+#: convert.c:850
+msgid "path name too long for external filter"
+msgstr "nom de chemin trop long pour un filtre externe"
+
+#: convert.c:924
+#, c-format
+msgid ""
+"external filter '%s' is not available anymore although not all paths have "
+"been filtered"
+msgstr ""
+"le filtre externe '%s' n'est plus disponible bien que tous les chemins "
+"n'aient pas été filtrés"
+
+#: convert.c:1223
 msgid "true/false are no valid working-tree-encodings"
 msgstr "true/false ne sont pas des encodages d'arbre de travail valides"
 
-#: date.c:116
+#: convert.c:1411 convert.c:1445
+#, c-format
+msgid "%s: clean filter '%s' failed"
+msgstr "%s : le filtre clean '%s' a échoué"
+
+#: convert.c:1489
+#, c-format
+msgid "%s: smudge filter %s failed"
+msgstr "%s : le filtre smudge '%s' a échoué"
+
+#: date.c:138
 msgid "in the future"
 msgstr "dans le futur"
 
-#: date.c:122
+#: date.c:144
 #, c-format
 msgid "%<PRIuMAX> second ago"
 msgid_plural "%<PRIuMAX> seconds ago"
 msgstr[0] "il y a %<PRIuMAX> seconde"
 msgstr[1] "il y a %<PRIuMAX> secondes"
 
-#: date.c:129
+#: date.c:151
 #, c-format
 msgid "%<PRIuMAX> minute ago"
 msgid_plural "%<PRIuMAX> minutes ago"
 msgstr[0] "il y a %<PRIuMAX> minute"
 msgstr[1] "il y a %<PRIuMAX> minutes"
 
-#: date.c:136
+#: date.c:158
 #, c-format
 msgid "%<PRIuMAX> hour ago"
 msgid_plural "%<PRIuMAX> hours ago"
 msgstr[0] "il y a %<PRIuMAX> heure"
 msgstr[1] "il y a %<PRIuMAX> heures"
 
-#: date.c:143
+#: date.c:165
 #, c-format
 msgid "%<PRIuMAX> day ago"
 msgid_plural "%<PRIuMAX> days ago"
 msgstr[0] "il y a %<PRIuMAX> jour"
 msgstr[1] "il y a %<PRIuMAX> jours"
 
-#: date.c:149
+#: date.c:171
 #, c-format
 msgid "%<PRIuMAX> week ago"
 msgid_plural "%<PRIuMAX> weeks ago"
 msgstr[0] "il y a %<PRIuMAX> semaine"
 msgstr[1] "il y a %<PRIuMAX> semaines"
 
-#: date.c:156
+#: date.c:178
 #, c-format
 msgid "%<PRIuMAX> month ago"
 msgid_plural "%<PRIuMAX> months ago"
 msgstr[0] "il y a %<PRIuMAX> mois"
 msgstr[1] "il y a %<PRIuMAX> mois"
 
-#: date.c:167
+#: date.c:189
 #, c-format
 msgid "%<PRIuMAX> year"
 msgid_plural "%<PRIuMAX> years"
@@ -1725,60 +2875,111 @@ msgstr[0] "%<PRIuMAX> an"
 msgstr[1] "%<PRIuMAX> ans"
 
 #. TRANSLATORS: "%s" is "<n> years"
-#: date.c:170
+#: date.c:192
 #, c-format
 msgid "%s, %<PRIuMAX> month ago"
 msgid_plural "%s, %<PRIuMAX> months ago"
 msgstr[0] "il y a %s et %<PRIuMAX> mois"
 msgstr[1] "il y a %s et %<PRIuMAX> mois"
 
-#: date.c:175 date.c:180
+#: date.c:197 date.c:202
 #, c-format
 msgid "%<PRIuMAX> year ago"
 msgid_plural "%<PRIuMAX> years ago"
 msgstr[0] "il y a %<PRIuMAX> an"
 msgstr[1] "il y a %<PRIuMAX> ans"
 
+#: delta-islands.c:272
+msgid "Propagating island marks"
+msgstr "Propagation des marques d'îlots"
+
+#: delta-islands.c:290
+#, c-format
+msgid "bad tree object %s"
+msgstr "objet arbre invalide %s"
+
+#: delta-islands.c:334
+#, c-format
+msgid "failed to load island regex for '%s': %s"
+msgstr "impossible de charger la regex île pour '%s' : %s"
+
+#: delta-islands.c:390
+#, c-format
+msgid "island regex from config has too many capture groups (max=%d)"
+msgstr ""
+"l'expression rationnelle depuis la configuration a trop de groupes de "
+"capture (max=%d)"
+
+#: delta-islands.c:467
+#, c-format
+msgid "Marked %d islands, done.\n"
+msgstr "Marquage de %d îlots, fait.\n"
+
 #: diffcore-order.c:24
 #, c-format
 msgid "failed to read orderfile '%s'"
 msgstr "impossible de lire le fichier de commande '%s'"
 
-#: diffcore-rename.c:535
+#: diffcore-rename.c:543
 msgid "Performing inexact rename detection"
 msgstr "Détection de renommage inexact en cours"
 
-#: diff.c:74
-#, c-format
-msgid "option '%s' requires a value"
-msgstr "le commutateur '%s' a besoin d'une valeur"
+#: diff-no-index.c:238
+msgid "git diff --no-index [<options>] <path> <path>"
+msgstr "git diff --no-index [<options>] <chemin> <chemin>"
+
+#: diff-no-index.c:263
+msgid ""
+"Not a git repository. Use --no-index to compare two paths outside a working "
+"tree"
+msgstr ""
+"Pas un dépôt git. Utilisez --no-index pour comparer deux chemins hors d'un "
+"arbre de travail"
 
-#: diff.c:152
+#: diff.c:155
 #, c-format
 msgid "  Failed to parse dirstat cut-off percentage '%s'\n"
 msgstr ""
 "  Impossible d'analyser le pourcentage de modification de dirstat '%s'\n"
 
-#: diff.c:157
+#: diff.c:160
 #, c-format
 msgid "  Unknown dirstat parameter '%s'\n"
 msgstr "  Paramètre dirstat inconnu '%s'\n"
 
-#: diff.c:281
+#: diff.c:296
 msgid ""
-"color moved setting must be one of 'no', 'default', 'zebra', 'dimmed_zebra', "
-"'plain'"
+"color moved setting must be one of 'no', 'default', 'blocks', 'zebra', "
+"'dimmed-zebra', 'plain'"
 msgstr ""
 "le paramètre de couleur de déplacement doit être parmi 'no', 'default', "
-"'zebra', 'dimmed_zebra', 'plain'"
+"'blocks', 'zebra', 'dimmed_zebra' ou 'plain'"
 
-#: diff.c:341
+#: diff.c:324
+#, c-format
+msgid ""
+"unknown color-moved-ws mode '%s', possible values are 'ignore-space-change', "
+"'ignore-space-at-eol', 'ignore-all-space', 'allow-indentation-change'"
+msgstr ""
+"mode unknown color-moved-ws inconnu '%s', les valeurs possibles sont 'ignore-"
+"space-change', 'ignore-space-at-eol', 'ignore-all-space', 'allow-indentation-"
+"change'"
+
+#: diff.c:332
+msgid ""
+"color-moved-ws: allow-indentation-change cannot be combined with other "
+"whitespace modes"
+msgstr ""
+"color-moved-ws : allow-indentation-change ne peut pas être combiné avec "
+"d'autres modes d'espace"
+
+#: diff.c:405
 #, c-format
 msgid "Unknown value for 'diff.submodule' config variable: '%s'"
 msgstr ""
 "Valeur inconnue pour la variable de configuration 'diff.submodule' : '%s'"
 
-#: diff.c:401
+#: diff.c:465
 #, c-format
 msgid ""
 "Found errors in 'diff.dirstat' config variable:\n"
@@ -1787,24 +2988,35 @@ msgstr ""
 "Erreurs dans la variable de configuration 'diff.dirstat' :\n"
 "%s"
 
-#: diff.c:3823
+#: diff.c:4202
 #, c-format
 msgid "external diff died, stopping at %s"
 msgstr "l'application de diff externe a disparu, arrêt à %s"
 
-#: diff.c:4153
+#: diff.c:4547
 msgid "--name-only, --name-status, --check and -s are mutually exclusive"
 msgstr "--name-only, --name-status, --check et -s sont mutuellement exclusifs"
 
-#: diff.c:4156
+#: diff.c:4550
 msgid "-G, -S and --find-object are mutually exclusive"
 msgstr "-G, -S et --find-object sont mutuellement exclusifs"
 
-#: diff.c:4244
+#: diff.c:4628
 msgid "--follow requires exactly one pathspec"
 msgstr "--follow a besoin d'une spécification de chemin unique"
 
-#: diff.c:4410
+#: diff.c:4676
+#, c-format
+msgid "invalid --stat value: %s"
+msgstr "valeur invalide de --stat : %s"
+
+#: diff.c:4681 diff.c:4686 diff.c:4691 diff.c:4696 diff.c:5209
+#: parse-options.c:199 parse-options.c:203
+#, c-format
+msgid "%s expects a numerical value"
+msgstr "%s attend une valeur numérique"
+
+#: diff.c:4713
 #, c-format
 msgid ""
 "Failed to parse --dirstat/-X option parameter:\n"
@@ -1813,11194 +3025,15617 @@ msgstr ""
 "Impossible d'analyser le paramètre de l'option --dirstat/-X :\n"
 "%s"
 
-#: diff.c:4424
+#: diff.c:4798
 #, c-format
-msgid "Failed to parse --submodule option parameter: '%s'"
-msgstr "Impossible d'analyser le paramètre de l'option --submodule : '%s'"
-
-#: diff.c:5500
-msgid "inexact rename detection was skipped due to too many files."
-msgstr ""
-"détection de renommage inexact annulée à cause d'un trop grand nombre de "
-"fichiers."
+msgid "unknown change class '%c' in --diff-filter=%s"
+msgstr "classe de modification inconnue '%c' dans --diff-fileter=%s"
 
-#: diff.c:5503
-msgid "only found copies from modified paths due to too many files."
-msgstr ""
-"recherche uniquement des copies par modification de chemin à cause d'un trop "
-"grand nombre de fichiers."
-
-#: diff.c:5506
+#: diff.c:4822
 #, c-format
-msgid ""
-"you may want to set your %s variable to at least %d and retry the command."
-msgstr ""
-"vous souhaitez peut-être régler la variable %s à au moins %d et réessayer le "
-"commande."
+msgid "unknown value after ws-error-highlight=%.*s"
+msgstr "valeur inconnue après ws-error-highlight=%.*s"
 
-#: dir.c:1867
+#: diff.c:4836
 #, c-format
-msgid "could not open directory '%s'"
-msgstr "impossible d'ouvrir le répertoire '%s'"
-
-#: dir.c:2109
-msgid "failed to get kernel name and information"
-msgstr "echec de l'obtention d'information de kernel"
+msgid "unable to resolve '%s'"
+msgstr "impossible de résoudre '%s'"
 
-#: dir.c:2233
-msgid "Untracked cache is disabled on this system or location."
-msgstr "Le cache non suivi est désactivé sur ce système ou sur cet endroit."
+#: diff.c:4886 diff.c:4892
+#, c-format
+msgid "%s expects <n>/<m> form"
+msgstr "forme <n>/<m> attendue par %s"
 
-#: dir.c:3075 dir.c:3080
+#: diff.c:4904
 #, c-format
-msgid "could not create directories for %s"
-msgstr "impossible de créer les répertoires pour %s"
+msgid "%s expects a character, got '%s'"
+msgstr "caractère attendu par %s, '%s' trouvé"
 
-#: dir.c:3109
+#: diff.c:4925
 #, c-format
-msgid "could not migrate git directory from '%s' to '%s'"
-msgstr "impossible de migrer le répertoire git de '%s' vers '%s'"
+msgid "bad --color-moved argument: %s"
+msgstr "mauvais argument --color-moved : %s"
 
-#: editor.c:61
+#: diff.c:4944
 #, c-format
-msgid "hint: Waiting for your editor to close the file...%c"
+msgid "invalid mode '%s' in --color-moved-ws"
+msgstr "mode invalide '%s' dans --color-moved-ws"
+
+#: diff.c:4984
+msgid ""
+"option diff-algorithm accepts \"myers\", \"minimal\", \"patience\" and "
+"\"histogram\""
 msgstr ""
-"suggestion : en attente de la fermeture du fichier par votre éditeur de "
-"texte…%c"
+"l'option diff-algorithm accept \"myers\", \"minimal\", \"patience\" et "
+"\"histogram\""
 
-#: entry.c:177
-msgid "Filtering content"
-msgstr "Filtrage du contenu"
+#: diff.c:5020 diff.c:5040
+#, c-format
+msgid "invalid argument to %s"
+msgstr "argument invalide pour %s"
 
-#: entry.c:435
+#: diff.c:5178
 #, c-format
-msgid "could not stat file '%s'"
-msgstr "impossible de stat le fichier '%s'"
+msgid "failed to parse --submodule option parameter: '%s'"
+msgstr "échec de l'analyse du paramètre de l'option --submodule : '%s'"
 
-#: fetch-object.c:17
-msgid "Remote with no URL"
-msgstr "Dépôt distant sans URL"
+#: diff.c:5234
+#, c-format
+msgid "bad --word-diff argument: %s"
+msgstr "mauvais argument pour --word-diff : %s"
 
-#: fetch-pack.c:254
-msgid "git fetch-pack: expected shallow list"
-msgstr "git fetch-pack : list courte attendue"
+#: diff.c:5257
+msgid "Diff output format options"
+msgstr "Options de format de sortie de diff"
 
-#: fetch-pack.c:266
-msgid "git fetch-pack: expected ACK/NAK, got a flush packet"
-msgstr "git fetch-pack : ACK/NACK attendu, paquet de nettoyage reçu"
+#: diff.c:5259 diff.c:5265
+msgid "generate patch"
+msgstr "générer la rustine"
 
-#: fetch-pack.c:285 builtin/archive.c:63
-#, c-format
-msgid "remote error: %s"
-msgstr "erreur distante : %s"
+#: diff.c:5262 builtin/log.c:173
+msgid "suppress diff output"
+msgstr "supprimer la sortie des différences"
 
-#: fetch-pack.c:286
-#, c-format
-msgid "git fetch-pack: expected ACK/NAK, got '%s'"
-msgstr "git fetch-pack : ACK/NACK attendu, '%s' reçu"
+#: diff.c:5267 diff.c:5381 diff.c:5388
+msgid "<n>"
+msgstr "<n>"
 
-#: fetch-pack.c:338
-msgid "--stateless-rpc requires multi_ack_detailed"
-msgstr "--stateless-rpc nécessite multi_ack_detailed"
+#: diff.c:5268 diff.c:5271
+msgid "generate diffs with <n> lines context"
+msgstr "générer les diffs avec <n> lignes de contexte"
 
-#: fetch-pack.c:429 fetch-pack.c:1310
-#, c-format
-msgid "invalid shallow line: %s"
-msgstr "ligne de superficiel invalide : %s"
+#: diff.c:5273
+msgid "generate the diff in raw format"
+msgstr "générer le diff en format brut"
 
-#: fetch-pack.c:435 fetch-pack.c:1316
-#, c-format
-msgid "invalid unshallow line: %s"
-msgstr "ligne de fin de superficiel invalide : %s"
+#: diff.c:5276
+msgid "synonym for '-p --raw'"
+msgstr "synonyme de '-p --raw'"
 
-#: fetch-pack.c:437 fetch-pack.c:1318
-#, c-format
-msgid "object not found: %s"
-msgstr "objet non trouvé : %s"
+#: diff.c:5280
+msgid "synonym for '-p --stat'"
+msgstr "synonyme de '-p --stat'"
 
-#: fetch-pack.c:440 fetch-pack.c:1321
-#, c-format
-msgid "error in object: %s"
-msgstr "Erreur dans l'objet : %s"
+#: diff.c:5284
+msgid "machine friendly --stat"
+msgstr "--stat pour traitement automatique"
 
-#: fetch-pack.c:442 fetch-pack.c:1323
-#, c-format
-msgid "no shallow found: %s"
-msgstr "Pas de superficiel trouvé : %s"
+#: diff.c:5287
+msgid "output only the last line of --stat"
+msgstr "afficher seulement la dernière ligne de --stat"
 
-#: fetch-pack.c:445 fetch-pack.c:1326
-#, c-format
-msgid "expected shallow/unshallow, got %s"
-msgstr "superficiel/non superficiel attendu, %s trouvé"
+#: diff.c:5289 diff.c:5297
+msgid "<param1,param2>..."
+msgstr "<param1,param2>..."
 
-#: fetch-pack.c:486
-#, c-format
-msgid "got %s %d %s"
-msgstr "réponse %s %d %s"
+#: diff.c:5290
+msgid ""
+"output the distribution of relative amount of changes for each sub-directory"
+msgstr ""
+"afficher la distribution des quantités de modifications relatives pour "
+"chaque sous-répertoire"
 
-#: fetch-pack.c:500
-#, c-format
-msgid "invalid commit %s"
-msgstr "commit invalide %s"
+#: diff.c:5294
+msgid "synonym for --dirstat=cumulative"
+msgstr "synonyme pour --dirstat=cumulative"
 
-#: fetch-pack.c:533
-msgid "giving up"
-msgstr "abandon"
+#: diff.c:5298
+msgid "synonym for --dirstat=files,param1,param2..."
+msgstr "synonyme pour --dirstat=files,param1,param2..."
 
-#: fetch-pack.c:543 progress.c:229
-msgid "done"
-msgstr "fait"
+#: diff.c:5302
+msgid "warn if changes introduce conflict markers or whitespace errors"
+msgstr ""
+"avertir si les modifications introduisent des marqueurs de conflit ou des "
+"erreurs d'espace"
 
-#: fetch-pack.c:555
-#, c-format
-msgid "got %s (%d) %s"
-msgstr "%s trouvé (%d) %s"
+#: diff.c:5305
+msgid "condensed summary such as creations, renames and mode changes"
+msgstr ""
+"résumé succinct tel que les créations, les renommages et les modifications "
+"de mode"
 
-#: fetch-pack.c:601
-#, c-format
-msgid "Marking %s as complete"
-msgstr "Marquage de %s comme terminé"
+#: diff.c:5308
+msgid "show only names of changed files"
+msgstr "n'afficher que les noms de fichiers modifiés"
 
-#: fetch-pack.c:828
-#, c-format
-msgid "already have %s (%s)"
-msgstr "%s déjà possédé (%s)"
+#: diff.c:5311
+msgid "show only names and status of changed files"
+msgstr "n'afficher que les noms et les status des fichiers modifiés"
 
-#: fetch-pack.c:869
-msgid "fetch-pack: unable to fork off sideband demultiplexer"
-msgstr "fetch-pack : impossible de dupliquer le démultiplexeur latéral"
+#: diff.c:5313
+msgid "<width>[,<name-width>[,<count>]]"
+msgstr "<largeur>[,<largeur-de-nom>[,<compte>]]"
 
-#: fetch-pack.c:877
-msgid "protocol error: bad pack header"
-msgstr "erreur de protocole : mauvais entête de paquet"
+#: diff.c:5314
+msgid "generate diffstat"
+msgstr "générer un diffstat"
 
-#: fetch-pack.c:944
-#, c-format
-msgid "fetch-pack: unable to fork off %s"
-msgstr "fetch-pack : impossible de dupliquer %s"
+#: diff.c:5316 diff.c:5319 diff.c:5322
+msgid "<width>"
+msgstr "<largeur>"
 
-#: fetch-pack.c:960
-#, c-format
-msgid "%s failed"
-msgstr "échec de %s"
+#: diff.c:5317
+msgid "generate diffstat with a given width"
+msgstr "générer un diffstat avec la largeur indiquée"
 
-#: fetch-pack.c:962
-msgid "error in sideband demultiplexer"
-msgstr "erreur dans le démultiplexer latéral"
+#: diff.c:5320
+msgid "generate diffstat with a given name width"
+msgstr "génerer un diffstat avec la largeur de nom indiquée"
 
-#: fetch-pack.c:989
-msgid "Server does not support shallow clients"
-msgstr "Le serveur ne supporte les clients superficiels"
+#: diff.c:5323
+msgid "generate diffstat with a given graph width"
+msgstr "génerer un diffstat avec la largeur de graphe indiquée"
 
-#: fetch-pack.c:993
-msgid "Server supports multi_ack_detailed"
-msgstr "Le serveur supporte multi_ack_detailed"
-
-#: fetch-pack.c:996
-msgid "Server supports no-done"
-msgstr "Le serveur support no-done"
-
-#: fetch-pack.c:1002
-msgid "Server supports multi_ack"
-msgstr "Le serveur supporte multi_ack"
-
-#: fetch-pack.c:1006
-msgid "Server supports side-band-64k"
-msgstr "Le serveur supporte side-band-64k"
-
-#: fetch-pack.c:1010
-msgid "Server supports side-band"
-msgstr "Le serveru supporte side-band"
-
-#: fetch-pack.c:1014
-msgid "Server supports allow-tip-sha1-in-want"
-msgstr "Le serveur supporte allow-tip-sha1-in-want"
-
-#: fetch-pack.c:1018
-msgid "Server supports allow-reachable-sha1-in-want"
-msgstr "Le serveur supporte allow-reachable-sha1-in-want"
-
-#: fetch-pack.c:1028
-msgid "Server supports ofs-delta"
-msgstr "Le serveur supporte ofs-delta"
+#: diff.c:5325
+msgid "<count>"
+msgstr "<compte>"
 
-#: fetch-pack.c:1034 fetch-pack.c:1204
-msgid "Server supports filter"
-msgstr "Le serveur supporte filter"
+#: diff.c:5326
+msgid "generate diffstat with limited lines"
+msgstr "générer un diffstat avec des lignes limitées"
 
-#: fetch-pack.c:1042
-#, c-format
-msgid "Server version is %.*s"
-msgstr "La version du serveur est %.*s"
+#: diff.c:5329
+msgid "generate compact summary in diffstat"
+msgstr "générer une résumé compact dans le diffstat"
 
-#: fetch-pack.c:1048
-msgid "Server does not support --shallow-since"
-msgstr "Le receveur ne gère pas --shallow-since"
+#: diff.c:5332
+msgid "output a binary diff that can be applied"
+msgstr "produire un diff binaire qui peut être appliqué"
 
-#: fetch-pack.c:1052
-msgid "Server does not support --shallow-exclude"
-msgstr "Le receveur ne gère pas --shallow-exclude"
+#: diff.c:5335
+msgid "show full pre- and post-image object names on the \"index\" lines"
+msgstr ""
+"afficher les noms complets des objets pre- et post-image sur les lignes "
+"\"index\""
 
-#: fetch-pack.c:1054
-msgid "Server does not support --deepen"
-msgstr "Le receveur ne gère pas --deepen"
+#: diff.c:5337
+msgid "show colored diff"
+msgstr "afficher un diff coloré"
 
-#: fetch-pack.c:1065
-msgid "no common commits"
-msgstr "pas de commit commun"
+#: diff.c:5338
+msgid "<kind>"
+msgstr "<sorte>"
 
-#: fetch-pack.c:1077 fetch-pack.c:1414
-msgid "git fetch-pack: fetch failed."
-msgstr "git fetch-pack : échec de le récupération."
+#: diff.c:5339
+msgid ""
+"highlight whitespace errors in the 'context', 'old' or 'new' lines in the "
+"diff"
+msgstr ""
+"surligner les erreurs d'espace dans les lignes 'contexte', 'ancien', "
+"'nouveau' dans le diff"
 
-#: fetch-pack.c:1199
-msgid "Server does not support shallow requests"
-msgstr "Le serveur ne supporte les requêtes superficielles"
+#: diff.c:5342
+msgid ""
+"do not munge pathnames and use NULs as output field terminators in --raw or "
+"--numstat"
+msgstr ""
+"ne pas compresser les chemins et utiliser des NULs comme terminateurs de "
+"champs dans --raw ou --numstat"
 
-#: fetch-pack.c:1584
-msgid "no matching remote head"
-msgstr "pas de HEAD distante correspondante"
+#: diff.c:5345 diff.c:5348 diff.c:5351 diff.c:5457
+msgid "<prefix>"
+msgstr "<préfixe>"
 
-#: fetch-pack.c:1610
-#, c-format
-msgid "no such remote ref %s"
-msgstr "référence distante inconnue %s"
+#: diff.c:5346
+msgid "show the given source prefix instead of \"a/\""
+msgstr "afficher le préfixe de source indiqué au lieu de \"a/\""
 
-#: fetch-pack.c:1613
-#, c-format
-msgid "Server does not allow request for unadvertised object %s"
-msgstr "Le serveur n'autorise pas de requête pour l'objet %s non annoncé"
+#: diff.c:5349
+msgid "show the given destination prefix instead of \"b/\""
+msgstr "afficher le préfixe de destination indiqué au lieu de \"b/\""
 
-#: gpg-interface.c:185
-msgid "gpg failed to sign the data"
-msgstr "gpg n'a pas pu signer les données"
+#: diff.c:5352
+msgid "prepend an additional prefix to every line of output"
+msgstr "préfixer toutes les lignes en sortie avec la chaîne indiquée"
 
-#: gpg-interface.c:210
-msgid "could not create temporary file"
-msgstr "impossible de créer un fichier temporaire"
+#: diff.c:5355
+msgid "do not show any source or destination prefix"
+msgstr "n'afficher aucun préfixe, ni de source, ni de destination"
 
-#: gpg-interface.c:213
-#, c-format
-msgid "failed writing detached signature to '%s'"
-msgstr "impossible d'écrire la signature détachée dans '%s'"
+#: diff.c:5358
+msgid "show context between diff hunks up to the specified number of lines"
+msgstr ""
+"afficher le contexte entre les sections à concurrence du nombre de ligne "
+"indiqué"
 
-#: graph.c:97
-#, c-format
-msgid "ignore invalid color '%.*s' in log.graphColors"
-msgstr "couleur invalide '%.*s' ignorée dans log.graphColors"
+#: diff.c:5362 diff.c:5367 diff.c:5372
+msgid "<char>"
+msgstr "<caractère>"
 
-#: grep.c:2020
-#, c-format
-msgid "'%s': unable to read %s"
-msgstr "'%s' : lecture de %s impossible"
+#: diff.c:5363
+msgid "specify the character to indicate a new line instead of '+'"
+msgstr "spécifier le caractère pour indiquer une nouvelle ligne au lieu de '+'"
 
-#: grep.c:2037 setup.c:164 builtin/clone.c:409 builtin/diff.c:81
-#: builtin/rm.c:134
-#, c-format
-msgid "failed to stat '%s'"
-msgstr "échec du stat de '%s'"
+#: diff.c:5368
+msgid "specify the character to indicate an old line instead of '-'"
+msgstr "spécifier le caractère pour indiquer une ancienne ligne au lieu de '-'"
 
-#: grep.c:2048
-#, c-format
-msgid "'%s': short read"
-msgstr "'%s' : lecture tronquée"
+#: diff.c:5373
+msgid "specify the character to indicate a context instead of ' '"
+msgstr ""
+"spécifier le caractère pour indiquer une ligne de contexte au lieu de ' '"
 
-#: help.c:23
-msgid "start a working area (see also: git help tutorial)"
-msgstr "démarrer une zone de travail (voir aussi : git help tutorial)"
+#: diff.c:5376
+msgid "Diff rename options"
+msgstr "Options de renommage de diff"
 
-#: help.c:24
-msgid "work on the current change (see also: git help everyday)"
-msgstr ""
-"travailler sur la modification actuelle (voir aussi : git help revisions)"
+#: diff.c:5377
+msgid "<n>[/<m>]"
+msgstr "<n>[/<m>]"
 
-#: help.c:25
-msgid "examine the history and state (see also: git help revisions)"
-msgstr "examiner l'historique et l'état (voir aussi : git help revisions)"
+#: diff.c:5378
+msgid "break complete rewrite changes into pairs of delete and create"
+msgstr ""
+"casser les modifications d'une réécrire complète en paires de suppression et "
+"création"
 
-#: help.c:26
-msgid "grow, mark and tweak your common history"
-msgstr "agrandir, marquer et modifier votre historique"
+#: diff.c:5382
+msgid "detect renames"
+msgstr "détecter les renommages"
 
-#: help.c:27
-msgid "collaborate (see also: git help workflows)"
-msgstr "collaborer (voir aussi : git help workflows)"
+#: diff.c:5386
+msgid "omit the preimage for deletes"
+msgstr "supprimer la pré-image pour les suppressions"
 
-#: help.c:31
-msgid "Main Porcelain Commands"
-msgstr "Commandes Porcelaine Principales"
+#: diff.c:5389
+msgid "detect copies"
+msgstr "détecter les copies"
 
-#: help.c:32
-msgid "Ancillary Commands / Manipulators"
-msgstr "Commandes Auxiliaires / Manipulateurs"
+#: diff.c:5393
+msgid "use unmodified files as source to find copies"
+msgstr ""
+"utiliser les fichiers non-modifiés comme sources pour trouver des copies"
 
-#: help.c:33
-msgid "Ancillary Commands / Interrogators"
-msgstr "Commandes Auxiliaires / Interrogateurs"
+#: diff.c:5395
+msgid "disable rename detection"
+msgstr "désactiver la détection de renommage"
 
-#: help.c:34
-msgid "Interacting with Others"
-msgstr "Interaction avec d'autres développeurs"
+#: diff.c:5398
+msgid "use empty blobs as rename source"
+msgstr "utiliser des blobs vides comme source de renommage"
 
-#: help.c:35
-msgid "Low-level Commands / Manipulators"
-msgstr "Commandes bas-niveau / Manipulateurs"
+#: diff.c:5400
+msgid "continue listing the history of a file beyond renames"
+msgstr "continuer à afficher l'historique d'un fichier au delà des renommages"
 
-#: help.c:36
-msgid "Low-level Commands / Interrogators"
-msgstr "Commandes bas niveau / Interrogateurs"
+#: diff.c:5403
+msgid ""
+"prevent rename/copy detection if the number of rename/copy targets exceeds "
+"given limit"
+msgstr ""
+"empêcher la détection de renommage/copie si le nombre de cibles de renommage/"
+"copie excède la limite indiquée"
 
-#: help.c:37
-msgid "Low-level Commands / Synching Repositories"
-msgstr "Commandes bas niveau / Synchronisation de dépôts"
+#: diff.c:5405
+msgid "Diff algorithm options"
+msgstr "Options de l'algorithme de diff"
 
-#: help.c:38
-msgid "Low-level Commands / Internal Helpers"
-msgstr "Commandes bas niveau / Assistants internes"
+#: diff.c:5407
+msgid "produce the smallest possible diff"
+msgstr "produire le diff le plus petit possible"
 
-#: help.c:293
-#, c-format
-msgid "available git commands in '%s'"
-msgstr "commandes git disponibles dans '%s'"
+#: diff.c:5410
+msgid "ignore whitespace when comparing lines"
+msgstr "ignorer les espaces lors de la comparaison de ligne"
 
-#: help.c:300
-msgid "git commands available from elsewhere on your $PATH"
-msgstr "commandes git disponibles depuis un autre endroit de votre $PATH"
+#: diff.c:5413
+msgid "ignore changes in amount of whitespace"
+msgstr "ignorer des modifications du nombre d'espaces"
 
-#: help.c:309
-msgid "These are common Git commands used in various situations:"
-msgstr "Ci-dessous les commandes Git habituelles dans diverses situations :"
+#: diff.c:5416
+msgid "ignore changes in whitespace at EOL"
+msgstr "ignorer des modifications d'espace en fin de ligne"
 
-#: help.c:358 git.c:90
-#, c-format
-msgid "unsupported command listing type '%s'"
-msgstr "type de liste de commandes non supporté '%s'"
+#: diff.c:5419
+msgid "ignore carrier-return at the end of line"
+msgstr "ignore le retour chariot en fin de ligne"
 
-#: help.c:405
-msgid "The common Git guides are:"
-msgstr "Les guides Git populaires sont :"
+#: diff.c:5422
+msgid "ignore changes whose lines are all blank"
+msgstr "ignorer les modifications dont les lignes sont vides"
 
-#: help.c:467
-#, c-format
-msgid ""
-"'%s' appears to be a git command, but we were not\n"
-"able to execute it. Maybe git-%s is broken?"
+#: diff.c:5425
+msgid "heuristic to shift diff hunk boundaries for easy reading"
 msgstr ""
-"'%s' semble être une commande git, mais elle n'a pas pu\n"
-"être exécutée. Peut-être git-%s est-elle cassée ?"
+"heuristique qui déplace les limites de sections de diff pour faciliter la "
+"lecture"
 
-#: help.c:526
-msgid "Uh oh. Your system reports no Git commands at all."
-msgstr "Ahem. Votre système n'indique aucune commande Git."
+#: diff.c:5428
+msgid "generate diff using the \"patience diff\" algorithm"
+msgstr "générer un diff en utilisant l'algorithme de différence \"patience\""
 
-#: help.c:548
-#, c-format
-msgid "WARNING: You called a Git command named '%s', which does not exist."
+#: diff.c:5432
+msgid "generate diff using the \"histogram diff\" algorithm"
 msgstr ""
-"ATTENTION : vous avez invoqué une commande Git nommée '%s' qui n'existe pas."
+"générer un diff en utilisant l'algorithme de différence \"histogramme\""
 
-#: help.c:553
-#, c-format
-msgid "Continuing under the assumption that you meant '%s'."
-msgstr "Continuons en supposant que vous avez voulu dire '%s'."
+#: diff.c:5434
+msgid "<algorithm>"
+msgstr "<algorithme>"
 
-#: help.c:558
-#, c-format
-msgid "Continuing in %0.1f seconds, assuming that you meant '%s'."
+#: diff.c:5435
+msgid "choose a diff algorithm"
+msgstr "choisir un algorithme de différence"
+
+#: diff.c:5437
+msgid "<text>"
+msgstr "<texte>"
+
+#: diff.c:5438
+msgid "generate diff using the \"anchored diff\" algorithm"
+msgstr "générer un diff en utilisant l'algorithme de différence \"ancré\""
+
+#: diff.c:5440 diff.c:5449 diff.c:5452
+msgid "<mode>"
+msgstr "<mode>"
+
+#: diff.c:5441
+msgid "show word diff, using <mode> to delimit changed words"
 msgstr ""
-"Continuons dans %0.1f secondes en supposant que vous avez voulu dire '%s'."
+"afficher des différences par mot, en utilisant <mode> pour délimiter les "
+"mots modifiés"
 
-#: help.c:566
-#, c-format
-msgid "git: '%s' is not a git command. See 'git --help'."
-msgstr "git : '%s' n'est pas une commande git. Voir 'git --help'."
+#: diff.c:5443 diff.c:5446 diff.c:5491
+msgid "<regex>"
+msgstr "<regex>"
 
-#: help.c:570
-msgid ""
-"\n"
-"The most similar command is"
-msgid_plural ""
-"\n"
-"The most similar commands are"
-msgstr[0] ""
-"\n"
-"La commande la plus ressemblante est"
-msgstr[1] ""
-"\n"
-"Les commandes les plus ressemblantes sont"
+#: diff.c:5444
+msgid "use <regex> to decide what a word is"
+msgstr "utiliser <regex> pour décider ce qu'est un mot"
 
-#: help.c:585
-msgid "git version [<options>]"
-msgstr "git version [<options>]"
+#: diff.c:5447
+msgid "equivalent to --word-diff=color --word-diff-regex=<regex>"
+msgstr "équivalent à --word-diff=color --word-diff-regex=<regex>"
 
-#: help.c:652
-#, c-format
-msgid "%s: %s - %s"
-msgstr "%s: %s - %s"
+#: diff.c:5450
+msgid "moved lines of code are colored differently"
+msgstr "les lignes déplacées sont colorées différemment"
 
-#: help.c:656
-msgid ""
-"\n"
-"Did you mean this?"
-msgid_plural ""
-"\n"
-"Did you mean one of these?"
-msgstr[0] ""
-"\n"
-"Vouliez-vous dire cela ?"
-msgstr[1] ""
-"\n"
-"Vouliez-vous dire un de ceux-là ?"
+#: diff.c:5453
+msgid "how white spaces are ignored in --color-moved"
+msgstr "comment les espaces sont ignorés dans --color-moved"
 
-#: ident.c:342
-msgid ""
-"\n"
-"*** Please tell me who you are.\n"
-"\n"
-"Run\n"
-"\n"
-"  git config --global user.email \"you@example.com\"\n"
-"  git config --global user.name \"Your Name\"\n"
-"\n"
-"to set your account's default identity.\n"
-"Omit --global to set the identity only in this repository.\n"
-"\n"
+#: diff.c:5456
+msgid "Other diff options"
+msgstr "Autres options diff"
+
+#: diff.c:5458
+msgid "when run from subdir, exclude changes outside and show relative paths"
 msgstr ""
-"\n"
-"*** Veuillez me dire qui vous êtes.\n"
-"\n"
-"Lancez\n"
-"\n"
-"  git config --global user.email \"Vous@exemple.com\"\n"
-"  git config --global user.name \"Votre Nom\"\n"
-"\n"
-"pour régler l'identité par défaut de votre compte.\n"
-"Éliminez --global pour ne faire les réglages que dans ce dépôt.\n"
-"\n"
+"lancé depuis un sous-répertoire, exclure les modifications en dehors et "
+"afficher les chemins relatifs"
 
-#: ident.c:366
-msgid "no email was given and auto-detection is disabled"
-msgstr "aucun courriel fourni et l'auto-détection est désactivée"
+#: diff.c:5462
+msgid "treat all files as text"
+msgstr "traiter les fichiers comme texte"
 
-#: ident.c:371
-#, c-format
-msgid "unable to auto-detect email address (got '%s')"
-msgstr "impossible de détecter automatiquement l'adresse ('%s' trouvé)"
+#: diff.c:5464
+msgid "swap two inputs, reverse the diff"
+msgstr "échanger les entrées, inverser le diff"
 
-#: ident.c:381
-msgid "no name was given and auto-detection is disabled"
-msgstr "aucun nom fourni et l'auto-détection est désactivée"
+#: diff.c:5466
+msgid "exit with 1 if there were differences, 0 otherwise"
+msgstr "sortir un code d'erreur 1 s'il y avait de différences, 0 sinon"
 
-#: ident.c:387
-#, c-format
-msgid "unable to auto-detect name (got '%s')"
-msgstr "impossible de détecter automatiquement le nom ('%s' trouvé)"
+#: diff.c:5468
+msgid "disable all output of the program"
+msgstr "désactiver tous les affichages du programme"
 
-#: ident.c:395
-#, c-format
-msgid "empty ident name (for <%s>) not allowed"
-msgstr "nom d'identifiant vide (pour <%s>) non permis"
+#: diff.c:5470
+msgid "allow an external diff helper to be executed"
+msgstr "autoriser l'exécution d'un assistant externe de diff"
 
-#: ident.c:401
-#, c-format
-msgid "name consists only of disallowed characters: %s"
-msgstr "le nom n'est constitué que de caractères interdits : %s"
+#: diff.c:5472
+msgid "run external text conversion filters when comparing binary files"
+msgstr ""
+"lancer les filtres externes de conversion en texte lors de la comparaison de "
+"fichiers binaires"
 
-#: ident.c:416 builtin/commit.c:587
-#, c-format
-msgid "invalid date format: %s"
-msgstr "format de date invalide : %s"
+#: diff.c:5474
+msgid "<when>"
+msgstr "<quand>"
 
-#: list-objects-filter-options.c:36
-msgid "multiple filter-specs cannot be combined"
-msgstr "impossible de combiner des spécificateurs multiples de filtre"
+#: diff.c:5475
+msgid "ignore changes to submodules in the diff generation"
+msgstr ""
+"ignorer les modifications dans les sous-modules lors de la génération de diff"
 
-#: list-objects-filter-options.c:126
-msgid "cannot change partial clone promisor remote"
-msgstr "impossible de modifier le prometteur distant de clone partiel"
+#: diff.c:5478
+msgid "<format>"
+msgstr "<format>"
 
-#: lockfile.c:151
-#, c-format
+#: diff.c:5479
+msgid "specify how differences in submodules are shown"
+msgstr "spécifier comment les différences dans les sous-modules sont affichées"
+
+#: diff.c:5483
+msgid "hide 'git add -N' entries from the index"
+msgstr "masquer les entrées 'git add -N' de l'index"
+
+#: diff.c:5486
+msgid "treat 'git add -N' entries as real in the index"
+msgstr "traiter les entrées 'git add -N' comme réelles dans l'index"
+
+#: diff.c:5488
+msgid "<string>"
+msgstr "<chaîne>"
+
+#: diff.c:5489
 msgid ""
-"Unable to create '%s.lock': %s.\n"
-"\n"
-"Another git process seems to be running in this repository, e.g.\n"
-"an editor opened by 'git commit'. Please make sure all processes\n"
-"are terminated then try again. If it still fails, a git process\n"
-"may have crashed in this repository earlier:\n"
-"remove the file manually to continue."
+"look for differences that change the number of occurrences of the specified "
+"string"
 msgstr ""
-"Impossible de créer '%s.lock' : %s.\n"
-"\n"
-"Il semble qu'un autre processus git est déjà lancé dans ce dépôt,\n"
-"par exemple un éditeur ouvert par 'git commit'. Veuillez vous assurer\n"
-"que tous les processus sont terminés et réessayez. Si l'echec persiste,\n"
-"un processus git peut avoir planté :\n"
-"supprimez le fichier manuellement pour poursuivre."
+"rechercher les différences qui modifient le nombre d'occurrences de la "
+"chaîne spécifiée"
 
-#: lockfile.c:159
-#, c-format
-msgid "Unable to create '%s.lock': %s"
-msgstr "Impossible de créer '%s.lock' : %s"
+#: diff.c:5492
+msgid ""
+"look for differences that change the number of occurrences of the specified "
+"regex"
+msgstr ""
+"rechercher les différences qui modifient le nombre d'occurrences de la regex "
+"spécifiée"
 
-#: merge.c:71
-msgid "failed to read the cache"
-msgstr "impossible de lire le cache"
+#: diff.c:5495
+msgid "show all changes in the changeset with -S or -G"
+msgstr ""
+"afficher toutes les modifications dans l'ensemble de modifications avec -S "
+"ou -G"
 
-#: merge.c:136 builtin/am.c:1946 builtin/am.c:1980 builtin/checkout.c:378
-#: builtin/checkout.c:606 builtin/clone.c:761
-msgid "unable to write new index file"
-msgstr "impossible d'écrire le nouveau fichier d'index"
+#: diff.c:5498
+msgid "treat <string> in -S as extended POSIX regular expression"
+msgstr ""
+"traiter <chaîne> dans -S comme une expression rationnelle POSIX étendue"
 
-#: merge-recursive.c:298
-msgid "(bad commit)\n"
-msgstr "(mauvais commit)\n"
+#: diff.c:5501
+msgid "control the order in which files appear in the output"
+msgstr "contrôler l'ordre dans lequel les fichiers apparaissent dans la sortie"
 
-#: merge-recursive.c:320
-#, c-format
-msgid "add_cacheinfo failed for path '%s'; merge aborting."
-msgstr "échec de addinfo_cache pour le chemin '%s' ; abandon de la fusion."
+#: diff.c:5502
+msgid "<object-id>"
+msgstr "<id-objet>"
 
-#: merge-recursive.c:328
-#, c-format
-msgid "add_cacheinfo failed to refresh for path '%s'; merge aborting."
-msgstr "échec de addinfo_cache pour le chemin '%s' ; abandon de la fusion."
+#: diff.c:5503
+msgid ""
+"look for differences that change the number of occurrences of the specified "
+"object"
+msgstr ""
+"rechercher les différences qui modifient le nombre d'occurrences de l'objet "
+"indiqué"
 
-#: merge-recursive.c:410
-msgid "error building trees"
-msgstr "erreur de construction des arbres"
+#: diff.c:5505
+msgid "[(A|C|D|M|R|T|U|X|B)...[*]]"
+msgstr "[(A|C|D|M|R|T|U|X|B)...[*]]"
 
-#: merge-recursive.c:881
-#, c-format
-msgid "failed to create path '%s'%s"
-msgstr "impossible de créer le chemin '%s' %s"
+#: diff.c:5506
+msgid "select files by diff type"
+msgstr "sélectionner les fichiers par types de diff"
 
-#: merge-recursive.c:892
-#, c-format
-msgid "Removing %s to make room for subdirectory\n"
-msgstr "Suppression de %s pour faire de la place pour le sous-répertoire\n"
+#: diff.c:5508
+msgid "<file>"
+msgstr "<fichier>"
+
+#: diff.c:5509
+msgid "Output to a specific file"
+msgstr "Sortie vers un fichier spécifié"
 
-#: merge-recursive.c:906 merge-recursive.c:925
-msgid ": perhaps a D/F conflict?"
-msgstr ": peut-être un conflit D/F ?"
+#: diff.c:6164
+msgid "inexact rename detection was skipped due to too many files."
+msgstr ""
+"détection de renommage inexact annulée à cause d'un trop grand nombre de "
+"fichiers."
+
+#: diff.c:6167
+msgid "only found copies from modified paths due to too many files."
+msgstr ""
+"recherche uniquement des copies par modification de chemin à cause d'un trop "
+"grand nombre de fichiers."
 
-#: merge-recursive.c:915
+#: diff.c:6170
 #, c-format
-msgid "refusing to lose untracked file at '%s'"
-msgstr "refus de perdre le fichier non suivi '%s'"
+msgid ""
+"you may want to set your %s variable to at least %d and retry the command."
+msgstr ""
+"vous souhaitez peut-être régler la variable %s à au moins %d et réessayer le "
+"commande."
 
-#: merge-recursive.c:957 builtin/cat-file.c:37
+#: dir.c:554
 #, c-format
-msgid "cannot read object %s '%s'"
-msgstr "impossible de lire l'objet %s '%s'"
+msgid "pathspec '%s' did not match any file(s) known to git"
+msgstr ""
+"le spécificateur de chemin '%s' ne correspond à aucun fichier connu de git"
 
-#: merge-recursive.c:959
+#: dir.c:664
 #, c-format
-msgid "blob expected for %s '%s'"
-msgstr "blob attendu pour %s '%s'"
+msgid "unrecognized pattern: '%s'"
+msgstr "motif non reconnu : '%s'"
 
-#: merge-recursive.c:983
+#: dir.c:682 dir.c:696
 #, c-format
-msgid "failed to open '%s': %s"
-msgstr "échec à l'ouverture de '%s' : %s"
+msgid "unrecognized negative pattern: '%s'"
+msgstr "motif négatif non reconnu : '%s'"
 
-#: merge-recursive.c:994
+#: dir.c:714
 #, c-format
-msgid "failed to symlink '%s': %s"
-msgstr "échec à la création du lien symbolique '%s' : %s"
+msgid "your sparse-checkout file may have issues: pattern '%s' is repeated"
+msgstr "votre fichier d'extraction partielle pourrait présenter des problèmes : le motif '%s' est répété"
 
-#: merge-recursive.c:999
+#: dir.c:724
+msgid "disabling cone pattern matching"
+msgstr "désactivation de la correspondance de motif de cone"
+
+#: dir.c:1101
 #, c-format
-msgid "do not know what to do with %06o %s '%s'"
-msgstr "ne sait pas traiter %06o %s '%s'"
+msgid "cannot use %s as an exclude file"
+msgstr "impossible d'utiliser %s comme fichier d'exclusion"
 
-#: merge-recursive.c:1186
+#: dir.c:2078
 #, c-format
-msgid "Failed to merge submodule %s (not checked out)"
-msgstr "Échec de la fusion du sous-module %s (non extrait)"
-
-#: merge-recursive.c:1193
-#, c-format
-msgid "Failed to merge submodule %s (commits not present)"
-msgstr "Échec de fusion du sous-module %s (commits non présents)"
+msgid "could not open directory '%s'"
+msgstr "impossible d'ouvrir le répertoire '%s'"
 
-#: merge-recursive.c:1200
-#, c-format
-msgid "Failed to merge submodule %s (commits don't follow merge-base)"
-msgstr ""
-"Échec de la fusion du sous-module %s (les commits ne descendent pas de la "
-"base de fusion)"
+#: dir.c:2415
+msgid "failed to get kernel name and information"
+msgstr "echec de l'obtention d'information de kernel"
 
-#: merge-recursive.c:1208 merge-recursive.c:1220
-#, c-format
-msgid "Fast-forwarding submodule %s to the following commit:"
-msgstr "Avance rapide du sous-module %s au commit suivant :"
+#: dir.c:2539
+msgid "untracked cache is disabled on this system or location"
+msgstr "Le cache non suivi est désactivé sur ce système ou sur cet endroit"
 
-#: merge-recursive.c:1211 merge-recursive.c:1223
+#: dir.c:3343
 #, c-format
-msgid "Fast-forwarding submodule %s"
-msgstr "Avance rapide du sous-module %s"
+msgid "index file corrupt in repo %s"
+msgstr "fichier d'index corrompu dans le dépôt %s"
 
-#: merge-recursive.c:1245
+#: dir.c:3388 dir.c:3393
 #, c-format
-msgid "Failed to merge submodule %s (merge following commits not found)"
-msgstr ""
-"Échec de fusion du sous-module %s (fusion suivant les commits non trouvée)"
+msgid "could not create directories for %s"
+msgstr "impossible de créer les répertoires pour %s"
 
-#: merge-recursive.c:1249
+#: dir.c:3422
 #, c-format
-msgid "Failed to merge submodule %s (not fast-forward)"
-msgstr "Échec de fusion du sous-module %s (pas en avance rapide)"
-
-#: merge-recursive.c:1250
-msgid "Found a possible merge resolution for the submodule:\n"
-msgstr "Résolution possible de fusion trouvée pour le sous-module :\n"
+msgid "could not migrate git directory from '%s' to '%s'"
+msgstr "impossible de migrer le répertoire git de '%s' vers '%s'"
 
-#: merge-recursive.c:1253
+#: editor.c:73
 #, c-format
-msgid ""
-"If this is correct simply add it to the index for example\n"
-"by using:\n"
-"\n"
-"  git update-index --cacheinfo 160000 %s \"%s\"\n"
-"\n"
-"which will accept this suggestion.\n"
+msgid "hint: Waiting for your editor to close the file...%c"
 msgstr ""
-"Si c'est correct, ajoutez le simplement à l'index\n"
-"en utilisant par exemple :\n"
-"\n"
-"  git update-index --cacheinfo 160000 %s \"%s\"\n"
-"\n"
-"qui acceptera cette suggestion.\n"
-
-#: merge-recursive.c:1262
-#, c-format
-msgid "Failed to merge submodule %s (multiple merges found)"
-msgstr "Échec de fusion du sous-module %s (plusieurs fusions trouvées)"
+"suggestion : en attente de la fermeture du fichier par votre éditeur de "
+"texte…%c"
 
-#: merge-recursive.c:1321
-msgid "Failed to execute internal merge"
-msgstr "Échec à l'exécution de la fusion interne"
+#: entry.c:178
+msgid "Filtering content"
+msgstr "Filtrage du contenu"
 
-#: merge-recursive.c:1326
+#: entry.c:476
 #, c-format
-msgid "Unable to add %s to database"
-msgstr "Impossible d'ajouter %s à la base de données"
+msgid "could not stat file '%s'"
+msgstr "impossible de stat le fichier '%s'"
 
-#: merge-recursive.c:1358
+#: environment.c:149
 #, c-format
-msgid "Auto-merging %s"
-msgstr "Fusion automatique de %s"
+msgid "bad git namespace path \"%s\""
+msgstr "Espaces de nom de Git \"%s\""
 
-#: merge-recursive.c:1423
+#: environment.c:331
 #, c-format
-msgid "Error: Refusing to lose untracked file at %s; writing to %s instead."
-msgstr ""
-"Erreur : refus de perdre le fichier non suivi %s ; écriture dans %s à la "
-"place."
+msgid "could not set GIT_DIR to '%s'"
+msgstr "impossible de régler GIT_DIR à '%s'"
 
-#: merge-recursive.c:1475
+#: exec-cmd.c:363
 #, c-format
-msgid ""
-"CONFLICT (%s/delete): %s deleted in %s and %s in %s. Version %s of %s left "
-"in tree."
-msgstr ""
-"CONFLIT (%s/suppression) : %s supprimé dans %s et %s dans %s. Version %s de "
-"%s laissée dans l'arbre."
+msgid "too many args to run %s"
+msgstr "trop d'arguments pour lancer %s"
 
-#: merge-recursive.c:1480
-#, c-format
-msgid ""
-"CONFLICT (%s/delete): %s deleted in %s and %s to %s in %s. Version %s of %s "
-"left in tree."
-msgstr ""
-"CONFLIT (%s/suppression) : %s supprimé dans %s et %s à %s dans %s. Version "
-"%s de %s laissée dans l'arbre."
+#: fetch-pack.c:150
+msgid "git fetch-pack: expected shallow list"
+msgstr "git fetch-pack : liste superficielle attendue"
 
-#: merge-recursive.c:1487
-#, c-format
-msgid ""
-"CONFLICT (%s/delete): %s deleted in %s and %s in %s. Version %s of %s left "
-"in tree at %s."
+#: fetch-pack.c:153
+msgid "git fetch-pack: expected a flush packet after shallow list"
 msgstr ""
-"CONFLIT (%s/suppression) : %s supprimé dans %s et %s dans %s. Version %s de "
-"%s laissée dans l'arbre dans le fichier %s."
+"git fetch-pack : paquet de vidage attendu après une liste superficielle"
+
+#: fetch-pack.c:164
+msgid "git fetch-pack: expected ACK/NAK, got a flush packet"
+msgstr "git fetch-pack : ACK/NACK attendu, paquet de nettoyage reçu"
 
-#: merge-recursive.c:1492
+#: fetch-pack.c:184
 #, c-format
-msgid ""
-"CONFLICT (%s/delete): %s deleted in %s and %s to %s in %s. Version %s of %s "
-"left in tree at %s."
-msgstr ""
-"CONFLIT (%s/suppression) : %s supprimé dans %s et %s à %s dans %s. Version "
-"%s de %s laissée dans l'arbre dans le fichier %s."
+msgid "git fetch-pack: expected ACK/NAK, got '%s'"
+msgstr "git fetch-pack : ACK/NACK attendu, '%s' reçu"
 
-#: merge-recursive.c:1526
-msgid "rename"
-msgstr "renommage"
+#: fetch-pack.c:195
+msgid "unable to write to remote"
+msgstr "impossible d'écrire sur un distant"
 
-#: merge-recursive.c:1526
-msgid "renamed"
-msgstr "renommé"
+#: fetch-pack.c:257
+msgid "--stateless-rpc requires multi_ack_detailed"
+msgstr "--stateless-rpc nécessite multi_ack_detailed"
 
-#: merge-recursive.c:1580 merge-recursive.c:1736 merge-recursive.c:2368
-#: merge-recursive.c:3086
+#: fetch-pack.c:356 fetch-pack.c:1340
 #, c-format
-msgid "Refusing to lose dirty file at %s"
-msgstr "Refus de perdre le fichier modifié %s"
+msgid "invalid shallow line: %s"
+msgstr "ligne de superficiel invalide : %s"
 
-#: merge-recursive.c:1594
+#: fetch-pack.c:362 fetch-pack.c:1346
 #, c-format
-msgid "%s is a directory in %s adding as %s instead"
-msgstr "%s est un répertoire dans %s ajouté plutôt comme %s"
+msgid "invalid unshallow line: %s"
+msgstr "ligne de fin de superficiel invalide : %s"
 
-#: merge-recursive.c:1599
+#: fetch-pack.c:364 fetch-pack.c:1348
 #, c-format
-msgid "Refusing to lose untracked file at %s; adding as %s instead"
-msgstr "Refus de perdre le fichier non suivi %s ; ajout comme %s à la place"
+msgid "object not found: %s"
+msgstr "objet non trouvé : %s"
 
-#: merge-recursive.c:1625
+#: fetch-pack.c:367 fetch-pack.c:1351
 #, c-format
-msgid ""
-"CONFLICT (rename/rename): Rename \"%s\"->\"%s\" in branch \"%s\" rename \"%s"
-"\"->\"%s\" in \"%s\"%s"
-msgstr ""
-"CONFLIT (renommage/renommage) : Renommage de \"%s\"->\"%s\" dans la branche "
-"\"%s\" et renommage \"%s\"->\"%s\" dans \"%s\"%s"
-
-#: merge-recursive.c:1630
-msgid " (left unresolved)"
-msgstr " (laissé non résolu)"
+msgid "error in object: %s"
+msgstr "Erreur dans l'objet : %s"
 
-#: merge-recursive.c:1694
+#: fetch-pack.c:369 fetch-pack.c:1353
 #, c-format
-msgid "CONFLICT (rename/rename): Rename %s->%s in %s. Rename %s->%s in %s"
-msgstr ""
-"CONFLIT (renommage/renommage) : renommage '%s'->'%s' dans %s. Renommage '%s'-"
-">'%s' dans %s"
+msgid "no shallow found: %s"
+msgstr "Pas de superficiel trouvé : %s"
 
-#: merge-recursive.c:1733
+#: fetch-pack.c:372 fetch-pack.c:1357
 #, c-format
-msgid "Renaming %s to %s and %s to %s instead"
-msgstr "Renommage de %s en %s et de %s en %s à la place"
+msgid "expected shallow/unshallow, got %s"
+msgstr "superficiel/non superficiel attendu, %s trouvé"
 
-#: merge-recursive.c:1745
+#: fetch-pack.c:414
 #, c-format
-msgid "Refusing to lose untracked file at %s, even though it's in the way."
-msgstr "Refus de perdre le fichier non suivi %s, même s'il gêne."
+msgid "got %s %d %s"
+msgstr "réponse %s %d %s"
 
-#: merge-recursive.c:1951
+#: fetch-pack.c:431
 #, c-format
-msgid ""
-"CONFLICT (directory rename split): Unclear where to place %s because "
-"directory %s was renamed to multiple other directories, with no destination "
-"getting a majority of the files."
-msgstr ""
-"CONFLIT (renommage de répertoire coupé) : la place de %s n'est pas claire "
-"parce que le répertoire %s a été renommé en plusieurs autres répertoires, "
-"sans aucune destination récupérant la majorité des fichiers."
+msgid "invalid commit %s"
+msgstr "commit invalide %s"
 
-#: merge-recursive.c:1983
-#, c-format
-msgid ""
-"CONFLICT (implicit dir rename): Existing file/dir at %s in the way of "
-"implicit directory rename(s) putting the following path(s) there: %s."
-msgstr ""
-"CONFLIT (renommage implicite de répertoire) : le répertoire/fichier %s gêne "
-"des renommages implicites de répertoire déplaçant les chemins suivants : %s."
+#: fetch-pack.c:462
+msgid "giving up"
+msgstr "abandon"
 
-#: merge-recursive.c:1993
-#, c-format
-msgid ""
-"CONFLICT (implicit dir rename): Cannot map more than one path to %s; "
-"implicit directory renames tried to put these paths there: %s"
-msgstr ""
-"CONFLIT (renommage implicite de répertoire) : impossible de transformer "
-"plusieurs chemins sur %s ; les chemins concernés sont : %s"
+#: fetch-pack.c:475 progress.c:323
+msgid "done"
+msgstr "fait"
 
-#: merge-recursive.c:2085
+#: fetch-pack.c:487
 #, c-format
-msgid ""
-"CONFLICT (rename/rename): Rename directory %s->%s in %s. Rename directory %s-"
-">%s in %s"
-msgstr ""
-"CONFLIT (renommage/renommage) : renommage du répertoire %s->%s dans %s. "
-"Renommage de répertoire %s->%s dans %s"
+msgid "got %s (%d) %s"
+msgstr "%s trouvé (%d) %s"
 
-#: merge-recursive.c:2330
+#: fetch-pack.c:533
 #, c-format
-msgid ""
-"WARNING: Avoiding applying %s -> %s rename to %s, because %s itself was "
-"renamed."
-msgstr ""
-"AVERTISSEMENT : ne renomme pas %s->%s dans %s, parce que %s lui-même a été "
-"renommé."
+msgid "Marking %s as complete"
+msgstr "Marquage de %s comme terminé"
 
-#: merge-recursive.c:2736
+#: fetch-pack.c:754
 #, c-format
-msgid "CONFLICT (rename/add): Rename %s->%s in %s. %s added in %s"
-msgstr ""
-"CONFLIT (renommage/ajout) : Renommage de %s->%s dans %s. %s ajouté dans %s"
+msgid "already have %s (%s)"
+msgstr "%s déjà possédé (%s)"
+
+#: fetch-pack.c:818
+msgid "fetch-pack: unable to fork off sideband demultiplexer"
+msgstr "fetch-pack : impossible de dupliquer le démultiplexeur latéral"
+
+#: fetch-pack.c:826
+msgid "protocol error: bad pack header"
+msgstr "erreur de protocole : mauvais entête de paquet"
 
-#: merge-recursive.c:2751
+#: fetch-pack.c:900
 #, c-format
-msgid "Adding merged %s"
-msgstr "Ajout de %s fusionné"
+msgid "fetch-pack: unable to fork off %s"
+msgstr "fetch-pack : impossible de dupliquer %s"
 
-#: merge-recursive.c:2758 merge-recursive.c:3089
+#: fetch-pack.c:916
 #, c-format
-msgid "Adding as %s instead"
-msgstr "Ajout plutôt comme %s"
+msgid "%s failed"
+msgstr "échec de %s"
 
-#: merge-recursive.c:2914
+#: fetch-pack.c:918
+msgid "error in sideband demultiplexer"
+msgstr "erreur dans le démultiplexer latéral"
+
+#: fetch-pack.c:965
 #, c-format
-msgid "cannot read object %s"
-msgstr "impossible de lire l'objet %s"
+msgid "Server version is %.*s"
+msgstr "La version du serveur est %.*s"
 
-#: merge-recursive.c:2917
+#: fetch-pack.c:970 fetch-pack.c:976 fetch-pack.c:979 fetch-pack.c:985
+#: fetch-pack.c:989 fetch-pack.c:993 fetch-pack.c:997 fetch-pack.c:1001
+#: fetch-pack.c:1005 fetch-pack.c:1009 fetch-pack.c:1013 fetch-pack.c:1017
+#: fetch-pack.c:1023 fetch-pack.c:1029 fetch-pack.c:1034 fetch-pack.c:1039
 #, c-format
-msgid "object %s is not a blob"
-msgstr "l'objet %s n'est pas un blob"
+msgid "Server supports %s"
+msgstr "Le serveur supporte %s"
 
-#: merge-recursive.c:2986
-msgid "modify"
-msgstr "modification"
+#: fetch-pack.c:972
+msgid "Server does not support shallow clients"
+msgstr "Le serveur ne supporte les clients superficiels"
 
-#: merge-recursive.c:2986
-msgid "modified"
-msgstr "modifié"
+#: fetch-pack.c:1032
+msgid "Server does not support --shallow-since"
+msgstr "Le receveur ne gère pas --shallow-since"
 
-#: merge-recursive.c:2997
-msgid "content"
-msgstr "contenu"
+#: fetch-pack.c:1037
+msgid "Server does not support --shallow-exclude"
+msgstr "Le receveur ne gère pas --shallow-exclude"
 
-#: merge-recursive.c:3004
-msgid "add/add"
-msgstr "ajout/ajout"
+#: fetch-pack.c:1041
+msgid "Server does not support --deepen"
+msgstr "Le receveur ne gère pas --deepen"
 
-#: merge-recursive.c:3046
-#, c-format
-msgid "Skipped %s (merged same as existing)"
-msgstr "%s sauté (fusion identique à l'existant)"
+#: fetch-pack.c:1058
+msgid "no common commits"
+msgstr "pas de commit commun"
 
-#: merge-recursive.c:3055 git-submodule.sh:895
-msgid "submodule"
-msgstr "sous-module"
+#: fetch-pack.c:1070 fetch-pack.c:1536
+msgid "git fetch-pack: fetch failed."
+msgstr "git fetch-pack : échec de le récupération."
 
-#: merge-recursive.c:3056
-#, c-format
-msgid "CONFLICT (%s): Merge conflict in %s"
-msgstr "CONFLIT (%s) : Conflit de fusion dans %s"
+#: fetch-pack.c:1209
+msgid "Server does not support shallow requests"
+msgstr "Le serveur ne supporte les requêtes superficielles"
 
-#: merge-recursive.c:3178
-#, c-format
-msgid "Removing %s"
-msgstr "Suppression de %s"
+#: fetch-pack.c:1216
+msgid "Server supports filter"
+msgstr "Le serveur supporte filter"
 
-#: merge-recursive.c:3204
-msgid "file/directory"
-msgstr "fichier/répertoire"
+#: fetch-pack.c:1239
+msgid "unable to write request to remote"
+msgstr "impossible d'écrire la requête sur le distant"
 
-#: merge-recursive.c:3210
-msgid "directory/file"
-msgstr "répertoire/fichier"
+#: fetch-pack.c:1257
+#, c-format
+msgid "error reading section header '%s'"
+msgstr "erreur à la lecture de l'entête de section '%s'"
 
-#: merge-recursive.c:3217
+#: fetch-pack.c:1263
 #, c-format
-msgid "CONFLICT (%s): There is a directory with name %s in %s. Adding %s as %s"
-msgstr ""
-"CONFLIT (%s) : Il y a un répertoire nommé %s dans %s. Ajout de %s comme %s"
+msgid "expected '%s', received '%s'"
+msgstr "'%s' attendu, '%s' reçu"
 
-#: merge-recursive.c:3226
+#: fetch-pack.c:1303
 #, c-format
-msgid "Adding %s"
-msgstr "Ajout de %s"
+msgid "unexpected acknowledgment line: '%s'"
+msgstr "ligne d'acquittement inattendue : '%s'"
 
-#: merge-recursive.c:3267
+#: fetch-pack.c:1308
 #, c-format
-msgid "Dirty index: cannot merge (dirty: %s)"
-msgstr "Index sale : fusion impossible (sales : %s)"
+msgid "error processing acks: %d"
+msgstr "erreur lors du traitement des acquittements : %d"
 
-#: merge-recursive.c:3271
-msgid "Already up to date!"
-msgstr "Déjà à jour !"
-
-#: merge-recursive.c:3280
-#, c-format
-msgid "merging of trees %s and %s failed"
-msgstr "échec de fusion des arbres %s et %s"
+#: fetch-pack.c:1318
+msgid "expected packfile to be sent after 'ready'"
+msgstr "fichier paquet attendu à envoyer après 'ready'"
 
-#: merge-recursive.c:3379
-msgid "Merging:"
-msgstr "Fusion :"
+#: fetch-pack.c:1320
+msgid "expected no other sections to be sent after no 'ready'"
+msgstr "aucune autre section attendue à envoyer après absence de 'ready'"
 
-#: merge-recursive.c:3392
+#: fetch-pack.c:1362
 #, c-format
-msgid "found %u common ancestor:"
-msgid_plural "found %u common ancestors:"
-msgstr[0] "%u ancêtre commun trouvé :"
-msgstr[1] "%u ancêtres communs trouvés :"
+msgid "error processing shallow info: %d"
+msgstr "erreur lors du traitement de l'information de superficialité : %d"
 
-#: merge-recursive.c:3431
-msgid "merge returned no commit"
-msgstr "la fusion n'a pas retourné de commit"
-
-#: merge-recursive.c:3495
+#: fetch-pack.c:1409
 #, c-format
-msgid "Could not parse object '%s'"
-msgstr "Impossible d'analyser l'objet '%s'"
-
-#: merge-recursive.c:3511 builtin/merge.c:659 builtin/merge.c:816
-msgid "Unable to write index."
-msgstr "Impossible d'écrire l'index."
+msgid "expected wanted-ref, got '%s'"
+msgstr "wanted-ref attendu, '%s' trouvé"
 
-#: notes-merge.c:272
+#: fetch-pack.c:1414
 #, c-format
-msgid ""
-"You have not concluded your previous notes merge (%s exists).\n"
-"Please, use 'git notes merge --commit' or 'git notes merge --abort' to "
-"commit/abort the previous merge before you start a new notes merge."
-msgstr ""
-"Vous n'avez pas terminé votre précédente fusion de notes (%s existe).\n"
-"Veuillez utiliser 'git notes merge --commit' ou 'git notes merge --abort' "
-"pour valider/abandonner la fusion en cours avant d'en démarrer une nouvelle."
+msgid "unexpected wanted-ref: '%s'"
+msgstr "wanted-ref inattendu : '%s'"
 
-#: notes-merge.c:279
+#: fetch-pack.c:1419
 #, c-format
-msgid "You have not concluded your notes merge (%s exists)."
-msgstr "Vous n'avez pas terminé votre fusion de notes (%s existe)."
+msgid "error processing wanted refs: %d"
+msgstr "erreur lors du traitement des références voulues : %d"
 
-#: notes-utils.c:43
-msgid "Cannot commit uninitialized/unreferenced notes tree"
-msgstr "Impossible de valider un arbre de notes non initialisé/référencé"
+#: fetch-pack.c:1762
+msgid "no matching remote head"
+msgstr "pas de HEAD distante correspondante"
 
-#: notes-utils.c:102
-#, c-format
-msgid "Bad notes.rewriteMode value: '%s'"
-msgstr "Mauvaise valeur de notes.rewriteMode : '%s'"
+#: fetch-pack.c:1785 builtin/clone.c:688
+msgid "remote did not send all necessary objects"
+msgstr "le serveur distant n'a pas envoyé tous les objets nécessaires"
 
-#: notes-utils.c:112
+#: fetch-pack.c:1812
 #, c-format
-msgid "Refusing to rewrite notes in %s (outside of refs/notes/)"
-msgstr "Refus de réécrire des notes dans %s (hors de refs/notes/)"
+msgid "no such remote ref %s"
+msgstr "référence distante inconnue %s"
 
-#. TRANSLATORS: The first %s is the name of
-#. the environment variable, the second %s is
-#. its value.
-#.
-#: notes-utils.c:142
+#: fetch-pack.c:1815
 #, c-format
-msgid "Bad %s value: '%s'"
-msgstr "Mauvaise valeur de %s : '%s'"
+msgid "Server does not allow request for unadvertised object %s"
+msgstr "Le serveur n'autorise pas de requête pour l'objet %s non annoncé"
+
+#: gpg-interface.c:223
+msgid "could not create temporary file"
+msgstr "impossible de créer un fichier temporaire"
 
-#: object.c:242
+#: gpg-interface.c:226
 #, c-format
-msgid "unable to parse object: %s"
-msgstr "impossible d'analyser l'objet : %s"
+msgid "failed writing detached signature to '%s'"
+msgstr "impossible d'écrire la signature détachée dans '%s'"
 
-#: packfile.c:563
-msgid "offset before end of packfile (broken .idx?)"
-msgstr "offset avant la fin du fichier paquet (.idx cassé ?)"
+#: gpg-interface.c:390
+msgid "gpg failed to sign the data"
+msgstr "gpg n'a pas pu signer les données"
 
-#: packfile.c:1742
+#: graph.c:98
 #, c-format
-msgid "offset before start of pack index for %s (corrupt index?)"
-msgstr "offset avant le début de l'index de paquet pour %s (index corrompu ?)"
+msgid "ignore invalid color '%.*s' in log.graphColors"
+msgstr "couleur invalide '%.*s' ignorée dans log.graphColors"
 
-#: packfile.c:1746
-#, c-format
-msgid "offset beyond end of pack index for %s (truncated index?)"
+#: grep.c:668
+msgid ""
+"given pattern contains NULL byte (via -f <file>). This is only supported "
+"with -P under PCRE v2"
 msgstr ""
-"offset au delà de la fin de l'index de paquet pour %s (index tronqué ?)"
-
-#: parse-options.c:621
-msgid "..."
-msgstr "..."
+"le motif fourni contient des octets NUL (via -f <fichier>). Ce n'est "
+"supporté qu'avec -P avec PCRE v2"
 
-#: parse-options.c:640
+#: grep.c:2124
 #, c-format
-msgid "usage: %s"
-msgstr "usage : %s"
+msgid "'%s': unable to read %s"
+msgstr "'%s' : lecture de %s impossible"
 
-#. TRANSLATORS: the colon here should align with the
-#. one in "usage: %s" translation.
-#.
-#: parse-options.c:646
+#: grep.c:2141 setup.c:165 builtin/clone.c:411 builtin/diff.c:82
+#: builtin/rm.c:135
 #, c-format
-msgid "   or: %s"
-msgstr "   ou : %s"
+msgid "failed to stat '%s'"
+msgstr "échec du stat de '%s'"
 
-#: parse-options.c:649
+#: grep.c:2152
 #, c-format
-msgid "    %s"
-msgstr "    %s"
+msgid "'%s': short read"
+msgstr "'%s' : lecture tronquée"
 
-#: parse-options.c:688
-msgid "-NUM"
-msgstr "-NUM"
+#: help.c:23
+msgid "start a working area (see also: git help tutorial)"
+msgstr "démarrer une zone de travail (voir aussi : git help tutorial)"
 
-#: parse-options-cb.c:44
-#, c-format
-msgid "malformed expiration date '%s'"
-msgstr "date d'expiration malformée : '%s'"
+#: help.c:24
+msgid "work on the current change (see also: git help everyday)"
+msgstr ""
+"travailler sur la modification actuelle (voir aussi : git help revisions)"
 
-#: parse-options-cb.c:112
-#, c-format
-msgid "malformed object name '%s'"
-msgstr "nom d'objet malformé '%s'"
+#: help.c:25
+msgid "examine the history and state (see also: git help revisions)"
+msgstr "examiner l'historique et l'état (voir aussi : git help revisions)"
 
-#: path.c:892
-#, c-format
-msgid "Could not make %s writable by group"
-msgstr "Impossible de rendre %s inscriptible pour le groupe"
+#: help.c:26
+msgid "grow, mark and tweak your common history"
+msgstr "agrandir, marquer et modifier votre historique"
 
-#: pathspec.c:129
-msgid "Escape character '\\' not allowed as last character in attr value"
-msgstr ""
-"Le caractère d'échappement '\\\\' interdit comme dernier caractère dans une "
-"valeur d'attribut"
+#: help.c:27
+msgid "collaborate (see also: git help workflows)"
+msgstr "collaborer (voir aussi : git help workflows)"
 
-#: pathspec.c:147
-msgid "Only one 'attr:' specification is allowed."
-msgstr "Une seule spécification 'attr:' est autorisée."
+#: help.c:31
+msgid "Main Porcelain Commands"
+msgstr "Commandes Porcelaine Principales"
 
-#: pathspec.c:150
-msgid "attr spec must not be empty"
-msgstr "un spécificateur d'attribut ne peut pas être vide"
+#: help.c:32
+msgid "Ancillary Commands / Manipulators"
+msgstr "Commandes Auxiliaires / Manipulateurs"
 
-#: pathspec.c:193
-#, c-format
-msgid "invalid attribute name %s"
-msgstr "nom d'attribut invalide %s"
+#: help.c:33
+msgid "Ancillary Commands / Interrogators"
+msgstr "Commandes Auxiliaires / Interrogateurs"
 
-#: pathspec.c:258
-msgid "global 'glob' and 'noglob' pathspec settings are incompatible"
-msgstr ""
-"les réglages de spécificateurs de chemin généraux 'glob' et 'noglob' sont "
-"incompatibles"
+#: help.c:34
+msgid "Interacting with Others"
+msgstr "Interaction avec d'autres développeurs"
 
-#: pathspec.c:265
-msgid ""
-"global 'literal' pathspec setting is incompatible with all other global "
-"pathspec settings"
-msgstr ""
-"le réglage global de spécificateur de chemin 'literal' est incompatible avec "
-"tous les autres réglages globaux de spécificateur de chemin"
+#: help.c:35
+msgid "Low-level Commands / Manipulators"
+msgstr "Commandes bas-niveau / Manipulateurs"
 
-#: pathspec.c:305
-msgid "invalid parameter for pathspec magic 'prefix'"
-msgstr "paramètre invalide pour le spécificateur magique de chemin 'prefix'"
+#: help.c:36
+msgid "Low-level Commands / Interrogators"
+msgstr "Commandes bas niveau / Interrogateurs"
 
-#: pathspec.c:326
-#, c-format
-msgid "Invalid pathspec magic '%.*s' in '%s'"
-msgstr "La spécification magique de chemin '%.*s' est invalide dans '%s'"
+#: help.c:37
+msgid "Low-level Commands / Syncing Repositories"
+msgstr "Commandes bas niveau / Synchronisation de dépôts"
 
-#: pathspec.c:331
-#, c-format
-msgid "Missing ')' at the end of pathspec magic in '%s'"
-msgstr "')' manquante à la fin du spécificateur magique de chemin dans '%s'"
+#: help.c:38
+msgid "Low-level Commands / Internal Helpers"
+msgstr "Commandes bas niveau / Assistants internes"
 
-#: pathspec.c:369
+#: help.c:298
 #, c-format
-msgid "Unimplemented pathspec magic '%c' in '%s'"
-msgstr "Spécificateur magique '%c' non implémenté dans '%s'"
+msgid "available git commands in '%s'"
+msgstr "commandes git disponibles dans '%s'"
 
-#: pathspec.c:428
-#, c-format
-msgid "%s: 'literal' and 'glob' are incompatible"
-msgstr "%s : 'literal' et 'glob' sont incompatibles"
+#: help.c:305
+msgid "git commands available from elsewhere on your $PATH"
+msgstr "commandes git disponibles depuis un autre endroit de votre $PATH"
 
-#: pathspec.c:441
-#, c-format
-msgid "%s: '%s' is outside repository"
-msgstr "%s : '%s' est hors du dépôt"
+#: help.c:314
+msgid "These are common Git commands used in various situations:"
+msgstr "Ci-dessous les commandes Git habituelles dans diverses situations :"
 
-#: pathspec.c:515
+#: help.c:363 git.c:98
 #, c-format
-msgid "'%s' (mnemonic: '%c')"
-msgstr "'%s' (mnémonique : '%c')"
+msgid "unsupported command listing type '%s'"
+msgstr "type de liste de commandes non supporté '%s'"
 
-#: pathspec.c:525
-#, c-format
-msgid "%s: pathspec magic not supported by this command: %s"
+#: help.c:403
+msgid "The common Git guides are:"
+msgstr "Les guides Git populaires sont :"
+
+#: help.c:512
+msgid "See 'git help <command>' to read about a specific subcommand"
 msgstr ""
-"%s : le spécificateur magique de chemin n'est pas supporté par cette "
-"commande : %s"
+"Référez-vous à 'git help <commande>' pour des informations sur une sous-"
+"commande spécifique"
 
-#: pathspec.c:592
-#, c-format
-msgid "pathspec '%s' is beyond a symbolic link"
-msgstr "le chemin '%s' est au-delà d'un lien symbolique"
+#: help.c:517
+msgid "External commands"
+msgstr "Commandes externes"
 
-#: pretty.c:962
-msgid "unable to parse --pretty format"
-msgstr "impossible d'analyser le format --pretty"
+#: help.c:532
+msgid "Command aliases"
+msgstr "Alias de commande"
 
-#: read-cache.c:1500
+#: help.c:596
 #, c-format
 msgid ""
-"index.version set, but the value is invalid.\n"
-"Using version %i"
+"'%s' appears to be a git command, but we were not\n"
+"able to execute it. Maybe git-%s is broken?"
 msgstr ""
-"version d'index renseignée, mais la valeur est invalide.\n"
-"Utilisation de la version %i"
+"'%s' semble être une commande git, mais elle n'a pas pu\n"
+"être exécutée. Peut-être git-%s est-elle cassée ?"
 
-#: read-cache.c:1510
-#, c-format
-msgid ""
-"GIT_INDEX_VERSION set, but the value is invalid.\n"
-"Using version %i"
-msgstr ""
-"GIT_INDEX_VERSION est renseigné, mais la valeur est invalide.\n"
-"Utilisation de la version %i"
+#: help.c:655
+msgid "Uh oh. Your system reports no Git commands at all."
+msgstr "Ahem. Votre système n'indique aucune commande Git."
 
-#: read-cache.c:2404 sequencer.c:4338 wrapper.c:658 builtin/merge.c:1048
+#: help.c:677
 #, c-format
-msgid "could not close '%s'"
-msgstr "impossible de fermer '%s'"
+msgid "WARNING: You called a Git command named '%s', which does not exist."
+msgstr ""
+"ATTENTION : vous avez invoqué une commande Git nommée '%s' qui n'existe pas."
 
-#: read-cache.c:2477 sequencer.c:2102 sequencer.c:3234
+#: help.c:682
 #, c-format
-msgid "could not stat '%s'"
-msgstr "stat impossible de '%s'"
+msgid "Continuing under the assumption that you meant '%s'."
+msgstr "Continuons en supposant que vous avez voulu dire '%s'."
 
-#: read-cache.c:2490
+#: help.c:687
 #, c-format
-msgid "unable to open git dir: %s"
-msgstr "impossible d'ouvrir le répertoire git : %s"
+msgid "Continuing in %0.1f seconds, assuming that you meant '%s'."
+msgstr ""
+"Continuons dans %0.1f secondes en supposant que vous avez voulu dire '%s'."
 
-#: read-cache.c:2502
+#: help.c:695
 #, c-format
-msgid "unable to unlink: %s"
-msgstr "échec lors de l'unlink : %s"
+msgid "git: '%s' is not a git command. See 'git --help'."
+msgstr "git : '%s' n'est pas une commande git. Voir 'git --help'."
 
-#: refs.c:732 sequencer.c:4334 sequencer.c:4393 wrapper.c:225 wrapper.c:395
-#: builtin/am.c:779
-#, c-format
-msgid "could not open '%s' for writing"
-msgstr "impossible d'ouvrir '%s' en écriture"
+#: help.c:699
+msgid ""
+"\n"
+"The most similar command is"
+msgid_plural ""
+"\n"
+"The most similar commands are"
+msgstr[0] ""
+"\n"
+"La commande la plus ressemblante est"
+msgstr[1] ""
+"\n"
+"Les commandes les plus ressemblantes sont"
 
-#: refs.c:1880
-msgid "ref updates forbidden inside quarantine environment"
-msgstr "mises à jour des références interdites en environnement de quarantaine"
+#: help.c:714
+msgid "git version [<options>]"
+msgstr "git version [<options>]"
 
-#: refs/files-backend.c:1191
+#: help.c:783
 #, c-format
-msgid "could not remove reference %s"
-msgstr "impossible de supprimer la référence %s"
+msgid "%s: %s - %s"
+msgstr "%s: %s - %s"
 
-#: refs/files-backend.c:1205 refs/packed-backend.c:1531
-#: refs/packed-backend.c:1541
-#, c-format
-msgid "could not delete reference %s: %s"
-msgstr "Impossible de supprimer la référence %s : %s"
+#: help.c:787
+msgid ""
+"\n"
+"Did you mean this?"
+msgid_plural ""
+"\n"
+"Did you mean one of these?"
+msgstr[0] ""
+"\n"
+"Vouliez-vous dire cela ?"
+msgstr[1] ""
+"\n"
+"Vouliez-vous dire un de ceux-là ?"
 
-#: refs/files-backend.c:1208 refs/packed-backend.c:1544
-#, c-format
-msgid "could not delete references: %s"
-msgstr "impossible de supprimer les références : %s"
+#: ident.c:349
+msgid ""
+"\n"
+"*** Please tell me who you are.\n"
+"\n"
+"Run\n"
+"\n"
+"  git config --global user.email \"you@example.com\"\n"
+"  git config --global user.name \"Your Name\"\n"
+"\n"
+"to set your account's default identity.\n"
+"Omit --global to set the identity only in this repository.\n"
+"\n"
+msgstr ""
+"\n"
+"*** Veuillez me dire qui vous êtes.\n"
+"\n"
+"Lancez\n"
+"\n"
+"  git config --global user.email \"Vous@exemple.com\"\n"
+"  git config --global user.name \"Votre Nom\"\n"
+"\n"
+"pour régler l'identité par défaut de votre compte.\n"
+"Éliminez --global pour ne faire les réglages que dans ce dépôt.\n"
+"\n"
 
-# à priori on parle d'une branche ici
-#: ref-filter.c:35 wt-status.c:1850
-msgid "gone"
-msgstr "disparue"
+#: ident.c:379
+msgid "no email was given and auto-detection is disabled"
+msgstr "aucun courriel fourni et l'auto-détection est désactivée"
 
-#: ref-filter.c:36
+#: ident.c:384
 #, c-format
-msgid "ahead %d"
-msgstr "en avance de %d"
+msgid "unable to auto-detect email address (got '%s')"
+msgstr "impossible de détecter automatiquement l'adresse ('%s' trouvé)"
 
-#: ref-filter.c:37
-#, c-format
-msgid "behind %d"
-msgstr "en retard de %d"
+#: ident.c:401
+msgid "no name was given and auto-detection is disabled"
+msgstr "aucun nom fourni et l'auto-détection est désactivée"
 
-#: ref-filter.c:38
+#: ident.c:407
 #, c-format
-msgid "ahead %d, behind %d"
-msgstr "en avance de %d, en retard de %d"
+msgid "unable to auto-detect name (got '%s')"
+msgstr "impossible de détecter automatiquement le nom ('%s' trouvé)"
 
-#: ref-filter.c:121
+#: ident.c:415
 #, c-format
-msgid "expected format: %%(color:<color>)"
-msgstr "format attendu : %%(color:<couleur>)"
+msgid "empty ident name (for <%s>) not allowed"
+msgstr "nom d'identifiant vide (pour <%s>) non permis"
 
-#: ref-filter.c:123
+#: ident.c:421
 #, c-format
-msgid "unrecognized color: %%(color:%s)"
-msgstr "couleur non reconnue : %%(color:%s)"
+msgid "name consists only of disallowed characters: %s"
+msgstr "le nom n'est constitué que de caractères interdits : %s"
 
-#: ref-filter.c:145
+#: ident.c:436 builtin/commit.c:631
 #, c-format
-msgid "Integer value expected refname:lstrip=%s"
-msgstr "Valeur entière attendue refname:lstrip=%s"
+msgid "invalid date format: %s"
+msgstr "format de date invalide : %s"
 
-#: ref-filter.c:149
+#: list-objects.c:127
 #, c-format
-msgid "Integer value expected refname:rstrip=%s"
-msgstr "Valeur entière attendue refname:rstrip=%s"
+msgid "entry '%s' in tree %s has tree mode, but is not a tree"
+msgstr ""
+"l'entrée '%s' dans l'arbre %s a un mode d'arbre, mais n'est pas un arbre"
 
-#: ref-filter.c:151
+#: list-objects.c:140
 #, c-format
-msgid "unrecognized %%(%s) argument: %s"
-msgstr "argument %%(%s) non reconnu : %s"
+msgid "entry '%s' in tree %s has blob mode, but is not a blob"
+msgstr ""
+"l'entrée '%s' dans l'arbre %s a un mode de blob, mais n'est pas un blob"
 
-#: ref-filter.c:206
+#: list-objects.c:375
 #, c-format
-msgid "%%(body) does not take arguments"
-msgstr "%%(body) n'accepte pas d'argument"
+msgid "unable to load root tree for commit %s"
+msgstr "impossible de charger l'arbre racine pour le commit %s"
 
-#: ref-filter.c:215
+#: list-objects-filter.c:492
 #, c-format
-msgid "%%(subject) does not take arguments"
-msgstr "%%(subject) n'accepte pas d'argument"
+msgid "unable to access sparse blob in '%s'"
+msgstr "impossible d'accéder au blob clairsemé dans '%s'"
 
-#: ref-filter.c:235
+#: list-objects-filter.c:495
 #, c-format
-msgid "unknown %%(trailers) argument: %s"
-msgstr "argument %%(trailers) inconnu : %s"
+msgid "unable to parse sparse filter data in %s"
+msgstr "impossible d'analyser la donnée de filtre clairsemé dans %s"
 
-#: ref-filter.c:264
-#, c-format
-msgid "positive value expected contents:lines=%s"
-msgstr "valeur positive attendue contents:lines=%s"
+#: list-objects-filter-options.c:58
+msgid "expected 'tree:<depth>'"
+msgstr "attendu : 'tree:<profondeur>'"
 
-#: ref-filter.c:266
-#, c-format
-msgid "unrecognized %%(contents) argument: %s"
-msgstr "argument %%(contents) non reconnu : %s"
+#: list-objects-filter-options.c:73
+msgid "sparse:path filters support has been dropped"
+msgstr "sparse : le support des filtres de chemin a été abandonné"
 
-#: ref-filter.c:281
+#: list-objects-filter-options.c:86
 #, c-format
-msgid "positive value expected objectname:short=%s"
-msgstr "valeur positive attendue objectname:short=%s"
+msgid "invalid filter-spec '%s'"
+msgstr "spécificateur de filtre invalide '%s'"
 
-#: ref-filter.c:285
+#: list-objects-filter-options.c:102
 #, c-format
-msgid "unrecognized %%(objectname) argument: %s"
-msgstr "argument %%(objectname) non reconnu : %s"
+msgid "must escape char in sub-filter-spec: '%c'"
+msgstr ""
+"le caractère doit être échappé dans le spécificateur de sous-filtre : '%c'"
 
-#: ref-filter.c:315
-#, c-format
-msgid "expected format: %%(align:<width>,<position>)"
-msgstr "format attendu : %%(align:<largeur>,<position>)"
+#: list-objects-filter-options.c:144
+msgid "expected something after combine:"
+msgstr "quelque chose attendu après combine :"
 
-#: ref-filter.c:327
-#, c-format
-msgid "unrecognized position:%s"
-msgstr "position non reconnue : %s"
+#: list-objects-filter-options.c:226
+msgid "multiple filter-specs cannot be combined"
+msgstr "impossible de combiner des spécificateurs multiples de filtre"
 
-#: ref-filter.c:334
+#: lockfile.c:151
 #, c-format
-msgid "unrecognized width:%s"
-msgstr "largeur non reconnue : %s"
+msgid ""
+"Unable to create '%s.lock': %s.\n"
+"\n"
+"Another git process seems to be running in this repository, e.g.\n"
+"an editor opened by 'git commit'. Please make sure all processes\n"
+"are terminated then try again. If it still fails, a git process\n"
+"may have crashed in this repository earlier:\n"
+"remove the file manually to continue."
+msgstr ""
+"Impossible de créer '%s.lock' : %s.\n"
+"\n"
+"Il semble qu'un autre processus git est déjà lancé dans ce dépôt,\n"
+"par exemple un éditeur ouvert par 'git commit'. Veuillez vous assurer\n"
+"que tous les processus sont terminés et réessayez. Si l'échec persiste,\n"
+"un processus git peut avoir planté :\n"
+"supprimez le fichier manuellement pour poursuivre."
 
-#: ref-filter.c:343
+#: lockfile.c:159
 #, c-format
-msgid "unrecognized %%(align) argument: %s"
-msgstr "argument %%(align) non reconnu : %s"
+msgid "Unable to create '%s.lock': %s"
+msgstr "Impossible de créer '%s.lock' : %s"
 
-#: ref-filter.c:351
-#, c-format
-msgid "positive width expected with the %%(align) atom"
-msgstr "valeur positive attendue avec l'atome %%(align)"
+#: merge.c:41
+msgid "failed to read the cache"
+msgstr "impossible de lire le cache"
 
-#: ref-filter.c:369
-#, c-format
-msgid "unrecognized %%(if) argument: %s"
-msgstr "argument %%(if) non reconnu : %s"
+#: merge.c:107 rerere.c:720 builtin/am.c:1874 builtin/am.c:1908
+#: builtin/checkout.c:539 builtin/checkout.c:798 builtin/clone.c:809
+#: builtin/stash.c:264
+msgid "unable to write new index file"
+msgstr "impossible d'écrire le nouveau fichier d'index"
 
-#: ref-filter.c:464
-#, c-format
-msgid "malformed field name: %.*s"
-msgstr "nom de champ malformé %.*s"
+#: merge-recursive.c:367
+msgid "(bad commit)\n"
+msgstr "(mauvais commit)\n"
 
-#: ref-filter.c:491
+#: merge-recursive.c:390
 #, c-format
-msgid "unknown field name: %.*s"
-msgstr "nom de champ inconnu : %.*s"
+msgid "add_cacheinfo failed for path '%s'; merge aborting."
+msgstr "échec de addinfo_cache pour le chemin '%s' ; abandon de la fusion."
 
-#: ref-filter.c:608
+#: merge-recursive.c:399
 #, c-format
-msgid "format: %%(if) atom used without a %%(then) atom"
-msgstr "format : atome %%(if) utilisé sans un atome %%(then)"
+msgid "add_cacheinfo failed to refresh for path '%s'; merge aborting."
+msgstr "échec de addinfo_cache pour le chemin '%s' ; abandon de la fusion."
 
-#: ref-filter.c:671
+#: merge-recursive.c:885
 #, c-format
-msgid "format: %%(then) atom used without an %%(if) atom"
-msgstr "format : atome %%(then) utilisé sans un atome %%(if)"
+msgid "failed to create path '%s'%s"
+msgstr "impossible de créer le chemin '%s' %s"
 
-#: ref-filter.c:673
+#: merge-recursive.c:896
 #, c-format
-msgid "format: %%(then) atom used more than once"
-msgstr "format : atome %%(then) utilisé plus d'une fois"
+msgid "Removing %s to make room for subdirectory\n"
+msgstr "Suppression de %s pour faire de la place pour le sous-répertoire\n"
 
-#: ref-filter.c:675
-#, c-format
-msgid "format: %%(then) atom used after %%(else)"
-msgstr "format: atome %%(then) utilisé après %%(else)"
+#: merge-recursive.c:910 merge-recursive.c:929
+msgid ": perhaps a D/F conflict?"
+msgstr ": peut-être un conflit D/F ?"
 
-#: ref-filter.c:703
+#: merge-recursive.c:919
 #, c-format
-msgid "format: %%(else) atom used without an %%(if) atom"
-msgstr "format : atome %%(else) utilisé sans un atome %%(if)"
+msgid "refusing to lose untracked file at '%s'"
+msgstr "refus de perdre le fichier non suivi '%s'"
 
-#: ref-filter.c:705
+#: merge-recursive.c:960 builtin/cat-file.c:41
 #, c-format
-msgid "format: %%(else) atom used without a %%(then) atom"
-msgstr "format : atome %%(else) utilisé sans un atome %%(then)"
+msgid "cannot read object %s '%s'"
+msgstr "impossible de lire l'objet %s '%s'"
 
-#: ref-filter.c:707
+#: merge-recursive.c:965
 #, c-format
-msgid "format: %%(else) atom used more than once"
-msgstr "format : atome %%(else) utilisé plus d'une fois"
+msgid "blob expected for %s '%s'"
+msgstr "blob attendu pour %s '%s'"
 
-#: ref-filter.c:722
+#: merge-recursive.c:990
 #, c-format
-msgid "format: %%(end) atom used without corresponding atom"
-msgstr "format : atome %%(end) utilisé sans atome correspondant"
+msgid "failed to open '%s': %s"
+msgstr "échec à l'ouverture de '%s' : %s"
 
-#: ref-filter.c:779
+#: merge-recursive.c:1001
 #, c-format
-msgid "malformed format string %s"
-msgstr "Chaîne de formatage mal formée %s"
+msgid "failed to symlink '%s': %s"
+msgstr "échec à la création du lien symbolique '%s' : %s"
 
-#: ref-filter.c:1387
+#: merge-recursive.c:1006
 #, c-format
-msgid "(no branch, rebasing %s)"
-msgstr "(aucune branche, rebasage de %s)"
+msgid "do not know what to do with %06o %s '%s'"
+msgstr "ne sait pas traiter %06o %s '%s'"
 
-#: ref-filter.c:1390
+#: merge-recursive.c:1199
 #, c-format
-msgid "(no branch, rebasing detached HEAD %s)"
-msgstr "(aucune branche, rebasage de la HEAD détachée %s)"
+msgid "Failed to merge submodule %s (not checked out)"
+msgstr "Échec de la fusion du sous-module %s (non extrait)"
 
-#: ref-filter.c:1393
+#: merge-recursive.c:1206
 #, c-format
-msgid "(no branch, bisect started on %s)"
-msgstr "(aucune branche, bisect a démarré sur %s)"
+msgid "Failed to merge submodule %s (commits not present)"
+msgstr "Échec de fusion du sous-module %s (commits non présents)"
 
-#. TRANSLATORS: make sure this matches "HEAD
-#. detached at " in wt-status.c
-#.
-#: ref-filter.c:1401
+#: merge-recursive.c:1213
 #, c-format
-msgid "(HEAD detached at %s)"
-msgstr "(HEAD détachée sur %s)"
+msgid "Failed to merge submodule %s (commits don't follow merge-base)"
+msgstr ""
+"Échec de la fusion du sous-module %s (les commits ne descendent pas de la "
+"base de fusion)"
 
-#. TRANSLATORS: make sure this matches "HEAD
-#. detached from " in wt-status.c
-#.
-#: ref-filter.c:1408
+#: merge-recursive.c:1221 merge-recursive.c:1233
 #, c-format
-msgid "(HEAD detached from %s)"
-msgstr "(HEAD détachée depuis %s)"
-
-#: ref-filter.c:1412
-msgid "(no branch)"
-msgstr "(aucune branche)"
+msgid "Fast-forwarding submodule %s to the following commit:"
+msgstr "Avance rapide du sous-module %s au commit suivant :"
 
-#: ref-filter.c:1442
+#: merge-recursive.c:1224 merge-recursive.c:1236
 #, c-format
-msgid "missing object %s for %s"
-msgstr "objet manquant %s pour %s"
+msgid "Fast-forwarding submodule %s"
+msgstr "Avance rapide du sous-module %s"
 
-#: ref-filter.c:1445
+#: merge-recursive.c:1259
 #, c-format
-msgid "parse_object_buffer failed on %s for %s"
-msgstr "echec de parse_object_buffer sur %s pour %s"
+msgid "Failed to merge submodule %s (merge following commits not found)"
+msgstr ""
+"Échec de fusion du sous-module %s (fusion suivant les commits non trouvée)"
 
-#: ref-filter.c:1902
+#: merge-recursive.c:1263
 #, c-format
-msgid "malformed object at '%s'"
-msgstr "objet malformé à '%s'"
+msgid "Failed to merge submodule %s (not fast-forward)"
+msgstr "Échec de fusion du sous-module %s (pas en avance rapide)"
 
-#: ref-filter.c:1984
-#, c-format
-msgid "ignoring ref with broken name %s"
-msgstr "réf avec un nom cassé %s ignoré"
+#: merge-recursive.c:1264
+msgid "Found a possible merge resolution for the submodule:\n"
+msgstr "Résolution possible de fusion trouvée pour le sous-module :\n"
 
-#: ref-filter.c:1989
+#: merge-recursive.c:1267
 #, c-format
-msgid "ignoring broken ref %s"
-msgstr "réf cassé %s ignoré"
+msgid ""
+"If this is correct simply add it to the index for example\n"
+"by using:\n"
+"\n"
+"  git update-index --cacheinfo 160000 %s \"%s\"\n"
+"\n"
+"which will accept this suggestion.\n"
+msgstr ""
+"Si c'est correct, ajoutez le simplement à l'index\n"
+"en utilisant par exemple :\n"
+"\n"
+"  git update-index --cacheinfo 160000 %s \"%s\"\n"
+"\n"
+"qui acceptera cette suggestion.\n"
 
-#: ref-filter.c:2261
+#: merge-recursive.c:1276
 #, c-format
-msgid "format: %%(end) atom missing"
-msgstr "format: atome %%(end) manquant"
+msgid "Failed to merge submodule %s (multiple merges found)"
+msgstr "Échec de fusion du sous-module %s (plusieurs fusions trouvées)"
 
-#: ref-filter.c:2365
-#, c-format
-msgid "malformed object name %s"
-msgstr "nom d'objet malformé %s"
+#: merge-recursive.c:1349
+msgid "Failed to execute internal merge"
+msgstr "Échec à l'exécution de la fusion interne"
 
-#: remote.c:605
+#: merge-recursive.c:1354
 #, c-format
-msgid "Cannot fetch both %s and %s to %s"
-msgstr "Impossible de récupérer à la fois %s et %s pour %s"
+msgid "Unable to add %s to database"
+msgstr "Impossible d'ajouter %s à la base de données"
 
-#: remote.c:609
+#: merge-recursive.c:1386
 #, c-format
-msgid "%s usually tracks %s, not %s"
-msgstr "%s suit habituellement %s, pas %s"
+msgid "Auto-merging %s"
+msgstr "Fusion automatique de %s"
 
-#: remote.c:613
+#: merge-recursive.c:1410
 #, c-format
-msgid "%s tracks both %s and %s"
-msgstr "%s suit à la fois %s et %s"
-
-#: remote.c:621
-msgid "Internal error"
-msgstr "Erreur interne"
+msgid "Error: Refusing to lose untracked file at %s; writing to %s instead."
+msgstr ""
+"Erreur : refus de perdre le fichier non suivi %s ; écriture dans %s à la "
+"place."
 
-#: remote.c:1534 remote.c:1635
-msgid "HEAD does not point to a branch"
-msgstr "HEAD ne pointe pas sur une branche"
-
-#: remote.c:1543
-#, c-format
-msgid "no such branch: '%s'"
-msgstr "pas de branche '%s'"
-
-#: remote.c:1546
-#, c-format
-msgid "no upstream configured for branch '%s'"
-msgstr "aucune branche amont configurée pour la branche '%s'"
-
-#: remote.c:1552
+#: merge-recursive.c:1482
 #, c-format
-msgid "upstream branch '%s' not stored as a remote-tracking branch"
-msgstr "la branche amont '%s' n'est pas stockée comme branche de suivi"
+msgid ""
+"CONFLICT (%s/delete): %s deleted in %s and %s in %s. Version %s of %s left "
+"in tree."
+msgstr ""
+"CONFLIT (%s/suppression) : %s supprimé dans %s et %s dans %s. Version %s de "
+"%s laissée dans l'arbre."
 
-#: remote.c:1567
+#: merge-recursive.c:1487
 #, c-format
-msgid "push destination '%s' on remote '%s' has no local tracking branch"
+msgid ""
+"CONFLICT (%s/delete): %s deleted in %s and %s to %s in %s. Version %s of %s "
+"left in tree."
 msgstr ""
-"la destination de poussée '%s' sur le serveur distant '%s' n'a pas de "
-"branche locale de suivi"
+"CONFLIT (%s/suppression) : %s supprimé dans %s et %s à %s dans %s. Version "
+"%s de %s laissée dans l'arbre."
 
-#: remote.c:1579
+#: merge-recursive.c:1494
 #, c-format
-msgid "branch '%s' has no remote for pushing"
-msgstr "la branche '%s' n'a aucune branche distante de poussée"
+msgid ""
+"CONFLICT (%s/delete): %s deleted in %s and %s in %s. Version %s of %s left "
+"in tree at %s."
+msgstr ""
+"CONFLIT (%s/suppression) : %s supprimé dans %s et %s dans %s. Version %s de "
+"%s laissée dans l'arbre dans le fichier %s."
 
-#: remote.c:1589
+#: merge-recursive.c:1499
 #, c-format
-msgid "push refspecs for '%s' do not include '%s'"
-msgstr "les références de spec pour '%s' n'incluent pas '%s'"
-
-#: remote.c:1602
-msgid "push has no destination (push.default is 'nothing')"
-msgstr "la poussée n'a pas de destination (push.default vaut 'nothing')"
-
-#: remote.c:1624
-msgid "cannot resolve 'simple' push to a single destination"
+msgid ""
+"CONFLICT (%s/delete): %s deleted in %s and %s to %s in %s. Version %s of %s "
+"left in tree at %s."
 msgstr ""
-"impossible de résoudre une poussée 'simple' pour une destination unique"
+"CONFLIT (%s/suppression) : %s supprimé dans %s et %s à %s dans %s. Version "
+"%s de %s laissée dans l'arbre dans le fichier %s."
 
-#: remote.c:1939
-#, c-format
-msgid "Your branch is based on '%s', but the upstream is gone.\n"
-msgstr "Votre branche est basée sur '%s', mais la branche amont a disparu.\n"
+#: merge-recursive.c:1534
+msgid "rename"
+msgstr "renommage"
 
-#: remote.c:1943
-msgid "  (use \"git branch --unset-upstream\" to fixup)\n"
-msgstr "  (utilisez \"git branch --unset-upstream\" pour corriger)\n"
+#: merge-recursive.c:1534
+msgid "renamed"
+msgstr "renommé"
 
-#: remote.c:1946
+#: merge-recursive.c:1614 merge-recursive.c:2530 merge-recursive.c:3175
 #, c-format
-msgid "Your branch is up to date with '%s'.\n"
-msgstr "Votre branche est à jour avec '%s'.\n"
+msgid "Refusing to lose dirty file at %s"
+msgstr "Refus de perdre le fichier modifié %s"
 
-#: remote.c:1950
+#: merge-recursive.c:1624
 #, c-format
-msgid "Your branch and '%s' refer to different commits.\n"
-msgstr "Votre branche et '%s' font référence à des commits différents.\n"
+msgid "Refusing to lose untracked file at %s, even though it's in the way."
+msgstr "Refus de perdre le fichier non suivi %s, même s'il gêne."
 
-#: remote.c:1953
+#: merge-recursive.c:1682
 #, c-format
-msgid "  (use \"%s\" for details)\n"
-msgstr "  (utilisez \"%s\" pour plus de détails)\n"
+msgid "CONFLICT (rename/add): Rename %s->%s in %s.  Added %s in %s"
+msgstr ""
+"CONFLIT (renommage/ajout) : Renommage de %s->%s dans %s. %s ajouté dans %s"
 
-#: remote.c:1957
+#: merge-recursive.c:1713
 #, c-format
-msgid "Your branch is ahead of '%s' by %d commit.\n"
-msgid_plural "Your branch is ahead of '%s' by %d commits.\n"
-msgstr[0] "Votre branche est en avance sur '%s' de %d commit.\n"
-msgstr[1] "Votre branche est en avance sur '%s' de %d commits.\n"
-
-#: remote.c:1963
-msgid "  (use \"git push\" to publish your local commits)\n"
-msgstr "  (utilisez \"git push\" pour publier vos commits locaux)\n"
+msgid "%s is a directory in %s adding as %s instead"
+msgstr "%s est un répertoire dans %s ajouté plutôt comme %s"
 
-#: remote.c:1966
+#: merge-recursive.c:1718
 #, c-format
-msgid "Your branch is behind '%s' by %d commit, and can be fast-forwarded.\n"
-msgid_plural ""
-"Your branch is behind '%s' by %d commits, and can be fast-forwarded.\n"
-msgstr[0] ""
-"Votre branche est en retard sur '%s' de %d commit, et peut être mise à jour "
-"en avance rapide.\n"
-msgstr[1] ""
-"Votre branche est en retard sur '%s' de %d commits, et peut être mise à jour "
-"en avance rapide.\n"
-
-#: remote.c:1974
-msgid "  (use \"git pull\" to update your local branch)\n"
-msgstr "  (utilisez \"git pull\" pour mettre à jour votre branche locale)\n"
+msgid "Refusing to lose untracked file at %s; adding as %s instead"
+msgstr "Refus de perdre le fichier non suivi %s ; ajout comme %s à la place"
 
-#: remote.c:1977
+#: merge-recursive.c:1737
 #, c-format
 msgid ""
-"Your branch and '%s' have diverged,\n"
-"and have %d and %d different commit each, respectively.\n"
-msgid_plural ""
-"Your branch and '%s' have diverged,\n"
-"and have %d and %d different commits each, respectively.\n"
-msgstr[0] ""
-"Votre branche et '%s' ont divergé,\n"
-"et ont %d et %d commit différent chacune respectivement.\n"
-msgstr[1] ""
-"Votre branche et '%s' ont divergé,\n"
-"et ont %d et %d commits différents chacune respectivement.\n"
-
-#: remote.c:1987
-msgid "  (use \"git pull\" to merge the remote branch into yours)\n"
+"CONFLICT (rename/rename): Rename \"%s\"->\"%s\" in branch \"%s\" rename \"%s"
+"\"->\"%s\" in \"%s\"%s"
 msgstr ""
-"  (utilisez \"git pull\" pour fusionner la branche distante dans la vôtre)\n"
+"CONFLIT (renommage/renommage) : Renommage de \"%s\"->\"%s\" dans la branche "
+"\"%s\" et renommage \"%s\"->\"%s\" dans \"%s\"%s"
 
-#: revision.c:2289
-msgid "your current branch appears to be broken"
-msgstr "votre branche actuelle semble cassée"
+#: merge-recursive.c:1742
+msgid " (left unresolved)"
+msgstr " (laissé non résolu)"
 
-#: revision.c:2292
+#: merge-recursive.c:1851
 #, c-format
-msgid "your current branch '%s' does not have any commits yet"
-msgstr "votre branche actuelle '%s' ne contient encore aucun commit"
-
-#: revision.c:2489
-msgid "--first-parent is incompatible with --bisect"
-msgstr "--first-parent est incompatible avec --bisect"
+msgid "CONFLICT (rename/rename): Rename %s->%s in %s. Rename %s->%s in %s"
+msgstr ""
+"CONFLIT (renommage/renommage) : renommage '%s'->'%s' dans %s. Renommage '%s'-"
+">'%s' dans %s"
 
-#: run-command.c:728
-msgid "open /dev/null failed"
-msgstr "échec de l'ouverture de /dev/null"
+#: merge-recursive.c:2114
+#, c-format
+msgid ""
+"CONFLICT (directory rename split): Unclear where to place %s because "
+"directory %s was renamed to multiple other directories, with no destination "
+"getting a majority of the files."
+msgstr ""
+"CONFLIT (renommage de répertoire coupé) : la place de %s n'est pas claire "
+"parce que le répertoire %s a été renommé en plusieurs autres répertoires, "
+"sans aucune destination récupérant la majorité des fichiers."
 
-#: run-command.c:1271
+#: merge-recursive.c:2146
 #, c-format
 msgid ""
-"The '%s' hook was ignored because it's not set as executable.\n"
-"You can disable this warning with `git config advice.ignoredHook false`."
+"CONFLICT (implicit dir rename): Existing file/dir at %s in the way of "
+"implicit directory rename(s) putting the following path(s) there: %s."
 msgstr ""
-"Le crochet '%s' a été ignoré parce qu'il n'est pas marqué comme exécutable.\n"
-"Vous pouvez désactiver cet avertissement avec `git config advice.ignoredHook "
-"false`."
+"CONFLIT (renommage implicite de répertoire) : le répertoire/fichier %s gêne "
+"des renommages implicites de répertoire déplaçant les chemins suivants : %s."
 
-#: send-pack.c:141
-msgid "unexpected flush packet while reading remote unpack status"
+#: merge-recursive.c:2156
+#, c-format
+msgid ""
+"CONFLICT (implicit dir rename): Cannot map more than one path to %s; "
+"implicit directory renames tried to put these paths there: %s"
 msgstr ""
-"paquet de nettoyage inattendu pendant la lecture de l'état de dépaquetage "
-"distant"
+"CONFLIT (renommage implicite de répertoire) : impossible de transformer "
+"plusieurs chemins sur %s ; les chemins concernés sont : %s"
 
-#: send-pack.c:143
+#: merge-recursive.c:2248
 #, c-format
-msgid "unable to parse remote unpack status: %s"
-msgstr "impossible d'analyser l'état de dépaquetage distant : %s"
+msgid ""
+"CONFLICT (rename/rename): Rename directory %s->%s in %s. Rename directory %s-"
+">%s in %s"
+msgstr ""
+"CONFLIT (renommage/renommage) : renommage du répertoire %s->%s dans %s. "
+"Renommage de répertoire %s->%s dans %s"
 
-#: send-pack.c:145
+#: merge-recursive.c:2493
 #, c-format
-msgid "remote unpack failed: %s"
-msgstr "le dépaquetage a échoué : %s"
+msgid ""
+"WARNING: Avoiding applying %s -> %s rename to %s, because %s itself was "
+"renamed."
+msgstr ""
+"AVERTISSEMENT : ne renomme pas %s->%s dans %s, parce que %s lui-même a été "
+"renommé."
 
-#: send-pack.c:308
-msgid "failed to sign the push certificate"
-msgstr "impossible de signer le certificat de poussée"
+#: merge-recursive.c:3019
+#, c-format
+msgid "cannot read object %s"
+msgstr "impossible de lire l'objet %s"
 
-#: send-pack.c:421
-msgid "the receiving end does not support --signed push"
-msgstr "Le receveur ne gère pas les poussées avec --signed"
+#: merge-recursive.c:3022
+#, c-format
+msgid "object %s is not a blob"
+msgstr "l'objet %s n'est pas un blob"
 
-#: send-pack.c:423
-msgid ""
-"not sending a push certificate since the receiving end does not support --"
-"signed push"
-msgstr ""
-"pas d'envoi de certificat de poussée car le receveur ne gère pas les "
-"poussées avec --signed"
+#: merge-recursive.c:3086
+msgid "modify"
+msgstr "modification"
 
-#: send-pack.c:435
-msgid "the receiving end does not support --atomic push"
-msgstr "Le receveur ne gère pas les poussées avec --atomic"
+#: merge-recursive.c:3086
+msgid "modified"
+msgstr "modifié"
 
-#: send-pack.c:440
-msgid "the receiving end does not support push options"
-msgstr "Le receveur ne gère pas les options de poussées"
+#: merge-recursive.c:3098
+msgid "content"
+msgstr "contenu"
 
-#: sequencer.c:175
-#, c-format
-msgid "invalid commit message cleanup mode '%s'"
-msgstr "mode de nettoyage invalide de message de validation '%s'"
+#: merge-recursive.c:3102
+msgid "add/add"
+msgstr "ajout/ajout"
 
-#: sequencer.c:275
+#: merge-recursive.c:3125
 #, c-format
-msgid "could not delete '%s'"
-msgstr "Impossible de supprimer '%s'"
-
-#: sequencer.c:301
-msgid "revert"
-msgstr "revert"
+msgid "Skipped %s (merged same as existing)"
+msgstr "%s sauté (fusion identique à l'existant)"
 
-#: sequencer.c:303
-msgid "cherry-pick"
-msgstr "cherry-pick"
+#: merge-recursive.c:3147 git-submodule.sh:993
+msgid "submodule"
+msgstr "sous-module"
 
-#: sequencer.c:305
-msgid "rebase -i"
-msgstr "rebase -i"
+#: merge-recursive.c:3148
+#, c-format
+msgid "CONFLICT (%s): Merge conflict in %s"
+msgstr "CONFLIT (%s) : Conflit de fusion dans %s"
 
-#: sequencer.c:307
+#: merge-recursive.c:3178
 #, c-format
-msgid "Unknown action: %d"
-msgstr "Action inconnue : %d"
+msgid "Adding as %s instead"
+msgstr "Ajout plutôt comme %s"
 
-#: sequencer.c:364
+#: merge-recursive.c:3261
+#, c-format
 msgid ""
-"after resolving the conflicts, mark the corrected paths\n"
-"with 'git add <paths>' or 'git rm <paths>'"
+"Path updated: %s added in %s inside a directory that was renamed in %s; "
+"moving it to %s."
 msgstr ""
-"après résolution des conflits, marquez les chemins corrigés\n"
-"avec 'git add <chemins>' ou 'git rm <chemins>'"
+"Chemin mis à jour : %s ajouté dans %s dans un répertoire qui a été renommé "
+"en %s ; déplacé dans %s."
 
-#: sequencer.c:367
+#: merge-recursive.c:3264
+#, c-format
 msgid ""
-"after resolving the conflicts, mark the corrected paths\n"
-"with 'git add <paths>' or 'git rm <paths>'\n"
-"and commit the result with 'git commit'"
+"CONFLICT (file location): %s added in %s inside a directory that was renamed "
+"in %s, suggesting it should perhaps be moved to %s."
 msgstr ""
-"après résolution des conflits, marquez les chemins corrigés\n"
-"avec 'git add <chemins>' ou 'git rm <chemins>'\n"
-"puis validez le résultat avec 'git commit'"
+"CONFLIT (localisation de fichier) : %s ajouté dans %s dans un répertoire qui "
+"a été renommé dans %s, ce qui suggère qu'il devrait peut-être être déplacé "
+"vers %s."
 
-#: sequencer.c:380 sequencer.c:2468
+#: merge-recursive.c:3268
 #, c-format
-msgid "could not lock '%s'"
-msgstr "impossible de verrouiller '%s'"
+msgid ""
+"Path updated: %s renamed to %s in %s, inside a directory that was renamed in "
+"%s; moving it to %s."
+msgstr ""
+"Chemin mis à jour : %s renommé en %s dans %s, dans un répertoire qui a été "
+"renommé en %s ; déplacé dans %s."
 
-#: sequencer.c:382 sequencer.c:2346 sequencer.c:2472 sequencer.c:2486
-#: sequencer.c:2694 sequencer.c:4336 sequencer.c:4399 wrapper.c:656
+#: merge-recursive.c:3271
 #, c-format
-msgid "could not write to '%s'"
-msgstr "impossible d'écrire dans '%s'"
+msgid ""
+"CONFLICT (file location): %s renamed to %s in %s, inside a directory that "
+"was renamed in %s, suggesting it should perhaps be moved to %s."
+msgstr ""
+"CONFLIT (localisation de fichier) : %s renommé en %s dans %s, dans un "
+"répertoire qui a été renommé dans %s, ce qui suggère qu'il devrait peut-être "
+"être déplacé vers %s."
 
-#: sequencer.c:387
+#: merge-recursive.c:3385
 #, c-format
-msgid "could not write eol to '%s'"
-msgstr "impossible d'écrire la fin de ligne dans '%s'"
+msgid "Removing %s"
+msgstr "Suppression de %s"
 
-#: sequencer.c:392 sequencer.c:2351 sequencer.c:2474 sequencer.c:2488
-#: sequencer.c:2702
-#, c-format
-msgid "failed to finalize '%s'"
-msgstr "échec lors de la finalisation de '%s'"
+#: merge-recursive.c:3408
+msgid "file/directory"
+msgstr "fichier/répertoire"
+
+#: merge-recursive.c:3413
+msgid "directory/file"
+msgstr "répertoire/fichier"
 
-#: sequencer.c:415 sequencer.c:804 sequencer.c:1493 sequencer.c:2371
-#: sequencer.c:2684 sequencer.c:2788 builtin/am.c:259 builtin/commit.c:727
-#: builtin/merge.c:1046
+#: merge-recursive.c:3420
 #, c-format
-msgid "could not read '%s'"
-msgstr "impossible de lire '%s'"
+msgid "CONFLICT (%s): There is a directory with name %s in %s. Adding %s as %s"
+msgstr ""
+"CONFLIT (%s) : Il y a un répertoire nommé %s dans %s. Ajout de %s comme %s"
 
-#: sequencer.c:441
+#: merge-recursive.c:3429
 #, c-format
-msgid "your local changes would be overwritten by %s."
-msgstr "vos modifications locales seraient écrasées par %s."
-
-#: sequencer.c:445
-msgid "commit your changes or stash them to proceed."
-msgstr "validez vos modifications ou les remiser pour continuer."
+msgid "Adding %s"
+msgstr "Ajout de %s"
 
-#: sequencer.c:474
+#: merge-recursive.c:3438
 #, c-format
-msgid "%s: fast-forward"
-msgstr "%s : avance rapide"
+msgid "CONFLICT (add/add): Merge conflict in %s"
+msgstr "CONFLIT (ajout/ajout) : Conflit de fusion dans %s"
 
-#. TRANSLATORS: %s will be "revert", "cherry-pick" or
-#. "rebase -i".
-#.
-#: sequencer.c:563
+#: merge-recursive.c:3482
+msgid "Already up to date!"
+msgstr "Déjà à jour !"
+
+#: merge-recursive.c:3491
 #, c-format
-msgid "%s: Unable to write new index file"
-msgstr "%s: Impossible d'écrire le nouveau fichier index"
+msgid "merging of trees %s and %s failed"
+msgstr "échec de fusion des arbres %s et %s"
 
-#: sequencer.c:579
-msgid "unable to update cache tree"
-msgstr "impossible de mettre à jour l'arbre de cache"
+#: merge-recursive.c:3595
+msgid "Merging:"
+msgstr "Fusion :"
 
-#: sequencer.c:592
-msgid "could not resolve HEAD commit"
-msgstr "impossible de résoudre le commit HEAD"
+#: merge-recursive.c:3608
+#, c-format
+msgid "found %u common ancestor:"
+msgid_plural "found %u common ancestors:"
+msgstr[0] "%u ancêtre commun trouvé :"
+msgstr[1] "%u ancêtres communs trouvés :"
+
+#: merge-recursive.c:3658
+msgid "merge returned no commit"
+msgstr "la fusion n'a pas retourné de commit"
 
-#: sequencer.c:749
+#: merge-recursive.c:3717
 #, c-format
 msgid ""
-"you have staged changes in your working tree\n"
-"If these changes are meant to be squashed into the previous commit, run:\n"
-"\n"
-"  git commit --amend %s\n"
-"\n"
-"If they are meant to go into a new commit, run:\n"
-"\n"
-"  git commit %s\n"
-"\n"
-"In both cases, once you're done, continue with:\n"
-"\n"
-"  git rebase --continue\n"
+"Your local changes to the following files would be overwritten by merge:\n"
+"  %s"
 msgstr ""
-"Vous avez des modifications indexées dans votre copie de travail.\n"
-"Si elles devaient être ajoutées dans le commit précédent, lancez :\n"
-"\n"
-"  git commit --amend %s\n"
-"\n"
-"Si elles devaient aller dans un nouveau commit, lancez :\n"
-"\n"
-"  git commit %s\n"
-"\n"
-"Dans les deux cas, une fois fini, continuez avec :\n"
-"\n"
-"  git rebase --continue\n"
+"Vos modifications locales aux fichiers suivants seraient écrasées par la "
+"fusion :\n"
+"  %s"
 
-#: sequencer.c:818
-msgid "writing root commit"
-msgstr "écriture du commit racine"
+#: merge-recursive.c:3814
+#, c-format
+msgid "Could not parse object '%s'"
+msgstr "Impossible d'analyser l'objet '%s'"
 
-#: sequencer.c:1043
-msgid "'prepare-commit-msg' hook failed"
-msgstr "échec du crochet 'prepare-commit-msg'"
+#: merge-recursive.c:3832 builtin/merge.c:694 builtin/merge.c:874
+msgid "Unable to write index."
+msgstr "Impossible d'écrire l'index."
 
-#: sequencer.c:1050
-msgid ""
-"Your name and email address were configured automatically based\n"
-"on your username and hostname. Please check that they are accurate.\n"
-"You can suppress this message by setting them explicitly. Run the\n"
-"following command and follow the instructions in your editor to edit\n"
-"your configuration file:\n"
-"\n"
-"    git config --global --edit\n"
-"\n"
-"After doing this, you may fix the identity used for this commit with:\n"
-"\n"
-"    git commit --amend --reset-author\n"
-msgstr ""
-"Votre nom et votre adresse courriel ont été configurés automatiquement en "
-"se\n"
-"fondant sur votre nom d'utilisateur et le nom de votre machine. Veuillez \n"
-"vérifier qu'ils sont corrects. Vous pouvez supprimer ce message en les \n"
-"paramétrant explicitement. Lancez les commandes suivantes et suivez les\n"
-"instruction dans votre éditeur pour éditer votre fichier de configuration :\n"
-"\n"
-"    git config --global --edit\n"
-"\n"
-"Après ceci, vous pouvez corriger l'identité utilisée pour cette validation "
-"avec :\n"
-"\n"
-"    git commit --amend --reset-author\n"
+#: midx.c:68
+#, c-format
+msgid "multi-pack-index file %s is too small"
+msgstr "le fichier d'index multi-paquet %s est trop petit"
 
-#: sequencer.c:1063
-msgid ""
-"Your name and email address were configured automatically based\n"
-"on your username and hostname. Please check that they are accurate.\n"
-"You can suppress this message by setting them explicitly:\n"
-"\n"
-"    git config --global user.name \"Your Name\"\n"
-"    git config --global user.email you@example.com\n"
-"\n"
-"After doing this, you may fix the identity used for this commit with:\n"
-"\n"
-"    git commit --amend --reset-author\n"
+#: midx.c:84
+#, c-format
+msgid "multi-pack-index signature 0x%08x does not match signature 0x%08x"
 msgstr ""
-"Votre nom et votre adresse courriel ont été configurés automatiquement en se "
-"fondant\n"
-"sur votre nom d'utilisateur et le nom de votre machine. Veuillez vérifier "
-"qu'ils sont corrects.\n"
-"Vous pouvez supprimer ce message en les paramétrant explicitement :\n"
-"\n"
-"    git config --global user.name \"Votre Nom\"\n"
-"    git config --global user.email vous@exemple.com\n"
-"\n"
-"Après ceci, vous pouvez corriger l'identité utilisée pour ce commit avec :\n"
-"\n"
-"    git commit --amend --reset-author\n"
+"la signature de l'index multi-paquet 0x%08x ne correspond pas à la signature "
+"0x%08x"
 
-#: sequencer.c:1103
-msgid "couldn't look up newly created commit"
-msgstr "impossible de retrouver le commit nouvellement créé"
+#: midx.c:89
+#, c-format
+msgid "multi-pack-index version %d not recognized"
+msgstr "la version d'index multi-paquet %d n'est pas reconnue"
 
-#: sequencer.c:1105
-msgid "could not parse newly created commit"
-msgstr "impossible d'analyser le commit nouvellement créé"
+#: midx.c:94
+#, c-format
+msgid "hash version %u does not match"
+msgstr "la version %u du condensé ne correspond pas"
 
-#: sequencer.c:1151
-msgid "unable to resolve HEAD after creating commit"
-msgstr "impossible de résoudre HEAD après création du commit"
+#: midx.c:108
+msgid "invalid chunk offset (too large)"
+msgstr "décalage de section invalide (trop grand)"
 
-#: sequencer.c:1153
-msgid "detached HEAD"
-msgstr "HEAD détachée"
+#: midx.c:132
+msgid "terminating multi-pack-index chunk id appears earlier than expected"
+msgstr ""
+"identifiant de terminaison de tronçon d'index multi-paquet terminant "
+"apparaît plus tôt qu'attendu"
 
-#: sequencer.c:1157
-msgid " (root-commit)"
-msgstr " (commit racine)"
+#: midx.c:145
+msgid "multi-pack-index missing required pack-name chunk"
+msgstr "index multi-paquet manque de tronçon de nom de paquet"
 
-#: sequencer.c:1178
-msgid "could not parse HEAD"
-msgstr "impossible de lire HEAD"
+#: midx.c:147
+msgid "multi-pack-index missing required OID fanout chunk"
+msgstr "index multi-paquet manque de tronçon de d'étalement OID requis"
+
+#: midx.c:149
+msgid "multi-pack-index missing required OID lookup chunk"
+msgstr "index multi-paquet manque de tronçon de recherche OID"
 
-#: sequencer.c:1180
+#: midx.c:151
+msgid "multi-pack-index missing required object offsets chunk"
+msgstr "index multi-paquet manque de tronçon de décalage d'objet"
+
+#: midx.c:165
 #, c-format
-msgid "HEAD %s is not a commit!"
-msgstr "HEAD %s n'est pas un commit !"
+msgid "multi-pack-index pack names out of order: '%s' before '%s'"
+msgstr ""
+"index multi-paquet les noms de paquets sont en désordre : '%s' avant '%s'"
 
-#: sequencer.c:1184 builtin/commit.c:1528
-msgid "could not parse HEAD commit"
-msgstr "impossible d'analyser le commit HEAD"
+#: midx.c:210
+#, c-format
+msgid "bad pack-int-id: %u (%u total packs)"
+msgstr "mauvais pack-int-id : %u (%u paquets au total)"
 
-#: sequencer.c:1235 sequencer.c:1832
-msgid "unable to parse commit author"
-msgstr "impossible d'analyser l'auteur du commit"
+#: midx.c:260
+msgid "multi-pack-index stores a 64-bit offset, but off_t is too small"
+msgstr ""
+"multi-pack-index stock un décalage en 64-bit, mais off_t est trop petit"
 
-#: sequencer.c:1245 builtin/am.c:1630 builtin/merge.c:645
-msgid "git write-tree failed to write a tree"
-msgstr "git write-tree a échoué à écrire un arbre"
+#: midx.c:288
+msgid "error preparing packfile from multi-pack-index"
+msgstr "erreur à la préparation du fichier paquet depuis un index multi-paquet"
 
-#: sequencer.c:1262 sequencer.c:1317
+#: midx.c:472
 #, c-format
-msgid "unable to read commit message from '%s'"
-msgstr "impossible de lire le message de validation de '%s'"
+msgid "failed to add packfile '%s'"
+msgstr "échec de l'ajout du fichier paquet '%s'"
 
-#: sequencer.c:1284 builtin/am.c:1650 builtin/commit.c:1631 builtin/merge.c:825
-#: builtin/merge.c:850
-msgid "failed to write commit object"
-msgstr "échec de l'écriture de l'objet commit"
-
-#: sequencer.c:1344
+#: midx.c:478
 #, c-format
-msgid "could not parse commit %s"
-msgstr "impossible d'analyser le commit %s"
+msgid "failed to open pack-index '%s'"
+msgstr "échec à l'ouverture du fichier paquet '%s'"
 
-#: sequencer.c:1349
+#: midx.c:538
 #, c-format
-msgid "could not parse parent commit %s"
-msgstr "impossible d'analyser le commit parent %s"
+msgid "failed to locate object %d in packfile"
+msgstr "échec de localisation de l'objet %d dans le fichier paquet"
+
+#: midx.c:842
+msgid "Adding packfiles to multi-pack-index"
+msgstr "Ajout de fichiers paquet à un index multi-paquet"
 
-#: sequencer.c:1500 sequencer.c:1525
+#: midx.c:875
 #, c-format
-msgid "This is a combination of %d commits."
-msgstr "Ceci est la combinaison de %d commits."
+msgid "did not see pack-file %s to drop"
+msgstr "fichier paquet à éliminer %s non trouvé"
 
-#: sequencer.c:1510 sequencer.c:4355
-msgid "need a HEAD to fixup"
-msgstr "une HEAD est nécessaire à la correction"
+#: midx.c:973
+msgid "Writing chunks to multi-pack-index"
+msgstr "Écriture des sections dans l'index multi-paquet"
 
-#: sequencer.c:1512 sequencer.c:2729
-msgid "could not read HEAD"
-msgstr "Impossible de lire HEAD"
+#: midx.c:1052
+#, c-format
+msgid "failed to clear multi-pack-index at %s"
+msgstr "échec du nettoyage de l'index de multi-paquet à %s"
 
-#: sequencer.c:1514
-msgid "could not read HEAD's commit message"
-msgstr "impossible de lire le message de validation de HEAD"
+#: midx.c:1108
+msgid "Looking for referenced packfiles"
+msgstr "Recherche de fichiers paquets référencés"
 
-#: sequencer.c:1520
+#: midx.c:1123
 #, c-format
-msgid "cannot write '%s'"
-msgstr "impossible d'écrire '%s'"
+msgid ""
+"oid fanout out of order: fanout[%d] = %<PRIx32> > %<PRIx32> = fanout[%d]"
+msgstr ""
+"étalement oid en désordre : étalement[%d] = %<PRIx32> > %<PRIx32> = "
+"étalement[%d]"
 
-#: sequencer.c:1527 git-rebase--interactive.sh:457
-msgid "This is the 1st commit message:"
-msgstr "Ceci est le premier message de validation :"
+#: midx.c:1128
+msgid "Verifying OID order in multi-pack-index"
+msgstr "Vérification de l'ordre des OID dans l'index multi-paquet"
 
-#: sequencer.c:1535
+#: midx.c:1137
 #, c-format
-msgid "could not read commit message of %s"
-msgstr "impossible de lire le message de validation de %s"
+msgid "oid lookup out of order: oid[%d] = %s >= %s = oid[%d]"
+msgstr "recherche d'oid en désordre : oid[%d] = %s >= %s = oid[%d]"
+
+#: midx.c:1157
+msgid "Sorting objects by packfile"
+msgstr "Classement des objets par fichier paquet"
 
-#: sequencer.c:1542
+#: midx.c:1164
+msgid "Verifying object offsets"
+msgstr "Vérification des décalages des objets"
+
+#: midx.c:1180
 #, c-format
-msgid "This is the commit message #%d:"
-msgstr "Ceci est le message de validation numéro %d :"
+msgid "failed to load pack entry for oid[%d] = %s"
+msgstr "échec de la lecture de l'élément de cache pour oid[%d] = %s"
 
-#: sequencer.c:1548
+#: midx.c:1186
 #, c-format
-msgid "The commit message #%d will be skipped:"
-msgstr "Le message de validation %d sera ignoré :"
+msgid "failed to load pack-index for packfile %s"
+msgstr "impossible de lire le fichier paquet %s"
 
-#: sequencer.c:1553
+#: midx.c:1195
 #, c-format
-msgid "unknown command: %d"
-msgstr "commande inconnue : %d"
+msgid "incorrect object offset for oid[%d] = %s: %<PRIx64> != %<PRIx64>"
+msgstr "décalage d'objet incorrect pour oid[%d] = %s : %<PRIx64> != %<PRIx64>"
 
-#: sequencer.c:1631
-msgid "your index file is unmerged."
-msgstr "votre fichier d'index n'est pas fusionné."
+#: midx.c:1220
+msgid "Counting referenced objects"
+msgstr "Comptage des objets référencés"
 
-#: sequencer.c:1638
-msgid "cannot fixup root commit"
-msgstr "impossible de réparer le commit racine"
+#: midx.c:1230
+msgid "Finding and deleting unreferenced packfiles"
+msgstr "Recherche et effacement des fichiers paquets non-référencés"
 
-#: sequencer.c:1657
-#, c-format
-msgid "commit %s is a merge but no -m option was given."
-msgstr "le commit %s est une fusion mais l'option -m n'a pas été spécifiée."
+#: midx.c:1388
+msgid "could not start pack-objects"
+msgstr "Impossible de démarrer le groupement d'objets"
 
-#: sequencer.c:1665
-#, c-format
-msgid "commit %s does not have parent %d"
-msgstr "le commit %s n'a pas de parent %d"
+#: midx.c:1407
+msgid "could not finish pack-objects"
+msgstr "Impossible de finir le groupement d'objets"
 
-#: sequencer.c:1669
+#: name-hash.c:537
 #, c-format
-msgid "mainline was specified but commit %s is not a merge."
-msgstr ""
-"une branche principale a été spécifiée mais le commit %s n'est pas une "
-"fusion."
+msgid "unable to create lazy_dir thread: %s"
+msgstr "impossible de créer le fil lazy_dir : %s"
 
-#: sequencer.c:1675
+#: name-hash.c:559
 #, c-format
-msgid "cannot get commit message for %s"
-msgstr "impossible d'obtenir un message de validation pour %s"
+msgid "unable to create lazy_name thread: %s"
+msgstr "impossible de créer le fil lazy_name : %s"
 
-#. TRANSLATORS: The first %s will be a "todo" command like
-#. "revert" or "pick", the second %s a SHA1.
-#: sequencer.c:1694
+#: name-hash.c:565
 #, c-format
-msgid "%s: cannot parse parent commit %s"
-msgstr "%s : impossible d'analyser le commit parent %s"
+msgid "unable to join lazy_name thread: %s"
+msgstr "impossible de joindre le fil lazy_name : %s"
 
-#: sequencer.c:1759
+#: notes-merge.c:277
 #, c-format
-msgid "could not rename '%s' to '%s'"
-msgstr "impossible de renommer '%s' en '%s'"
+msgid ""
+"You have not concluded your previous notes merge (%s exists).\n"
+"Please, use 'git notes merge --commit' or 'git notes merge --abort' to "
+"commit/abort the previous merge before you start a new notes merge."
+msgstr ""
+"Vous n'avez pas terminé votre précédente fusion de notes (%s existe).\n"
+"Veuillez utiliser 'git notes merge --commit' ou 'git notes merge --abort' "
+"pour valider/abandonner la fusion en cours avant d'en démarrer une nouvelle."
 
-#: sequencer.c:1813
+#: notes-merge.c:284
 #, c-format
-msgid "could not revert %s... %s"
-msgstr "impossible d'annuler %s... %s"
+msgid "You have not concluded your notes merge (%s exists)."
+msgstr "Vous n'avez pas terminé votre fusion de notes (%s existe)."
 
-#: sequencer.c:1814
-#, c-format
-msgid "could not apply %s... %s"
-msgstr "impossible d'appliquer %s... %s"
+#: notes-utils.c:46
+msgid "Cannot commit uninitialized/unreferenced notes tree"
+msgstr "Impossible de valider un arbre de notes non initialisé/référencé"
 
-#: sequencer.c:1864
-msgid "empty commit set passed"
-msgstr "l'ensemble de commits spécifié est vide"
+#: notes-utils.c:105
+#, c-format
+msgid "Bad notes.rewriteMode value: '%s'"
+msgstr "Mauvaise valeur de notes.rewriteMode : '%s'"
 
-#: sequencer.c:1874
+#: notes-utils.c:115
 #, c-format
-msgid "git %s: failed to read the index"
-msgstr "git %s : échec à la lecture de l'index"
+msgid "Refusing to rewrite notes in %s (outside of refs/notes/)"
+msgstr "Refus de réécrire des notes dans %s (hors de refs/notes/)"
 
-#: sequencer.c:1881
+#. TRANSLATORS: The first %s is the name of
+#. the environment variable, the second %s is
+#. its value.
+#.
+#: notes-utils.c:145
 #, c-format
-msgid "git %s: failed to refresh the index"
-msgstr "git %s : échec du rafraîchissement de l'index"
+msgid "Bad %s value: '%s'"
+msgstr "Mauvaise valeur de %s : '%s'"
 
-#: sequencer.c:1961
+#: object.c:53
 #, c-format
-msgid "%s does not accept arguments: '%s'"
-msgstr "%s n'accepte pas d'argument : '%s'"
+msgid "invalid object type \"%s\""
+msgstr "type d'objet invalide \"%s\""
 
-#: sequencer.c:1970
+#: object.c:173
 #, c-format
-msgid "missing arguments for %s"
-msgstr "argument manquant pour %s"
+msgid "object %s is a %s, not a %s"
+msgstr "l'objet %s est de type %s, pas de type %s"
 
-#: sequencer.c:2029
+#: object.c:233
 #, c-format
-msgid "invalid line %d: %.*s"
-msgstr "ligne %d invalide : %.*s"
+msgid "object %s has unknown type id %d"
+msgstr "l'objet %s a un id de type inconnu %d"
 
-#: sequencer.c:2037
+#: object.c:246
 #, c-format
-msgid "cannot '%s' without a previous commit"
-msgstr "'%s' impossible avec le commit précédent"
+msgid "unable to parse object: %s"
+msgstr "impossible d'analyser l'objet : %s"
 
-#: sequencer.c:2085 sequencer.c:4138 sequencer.c:4173
+#: object.c:266 object.c:277
 #, c-format
-msgid "could not read '%s'."
-msgstr "impossible de lire '%s'."
+msgid "hash mismatch %s"
+msgstr "incohérence de hachage %s"
 
-#: sequencer.c:2108
-msgid "please fix this using 'git rebase --edit-todo'."
-msgstr "veuillez corriger ceci en utilisant 'git rebase --edit-todo'."
+#: packfile.c:641
+msgid "offset before end of packfile (broken .idx?)"
+msgstr "offset avant la fin du fichier paquet (.idx cassé ?)"
 
-#: sequencer.c:2110
+#: packfile.c:1888
 #, c-format
-msgid "unusable instruction sheet: '%s'"
-msgstr "feuille d'instruction inutilisable : '%s'"
+msgid "offset before start of pack index for %s (corrupt index?)"
+msgstr "offset avant le début de l'index de paquet pour %s (index corrompu ?)"
 
-#: sequencer.c:2115
-msgid "no commits parsed."
-msgstr "aucun commit analysé."
+#: packfile.c:1892
+#, c-format
+msgid "offset beyond end of pack index for %s (truncated index?)"
+msgstr ""
+"offset au delà de la fin de l'index de paquet pour %s (index tronqué ?)"
 
-#: sequencer.c:2126
-msgid "cannot cherry-pick during a revert."
-msgstr "impossible de picorer pendant l'annulation d'un commit."
+#: parse-options.c:38
+#, c-format
+msgid "%s requires a value"
+msgstr "%s a besoin d'une valeur"
 
-#: sequencer.c:2128
-msgid "cannot revert during a cherry-pick."
-msgstr "impossible d'annuler un commit pendant un picorage."
+#: parse-options.c:73
+#, c-format
+msgid "%s is incompatible with %s"
+msgstr "%s est incompatible avec %s"
 
-#: sequencer.c:2195
+#: parse-options.c:78
 #, c-format
-msgid "invalid key: %s"
-msgstr "clé invalide : %s"
+msgid "%s : incompatible with something else"
+msgstr "%s est incompatible avec toute autre option"
 
-#: sequencer.c:2198
+#: parse-options.c:92 parse-options.c:96 parse-options.c:319
 #, c-format
-msgid "invalid value for %s: %s"
-msgstr "valeur invalide pour %s : %s"
+msgid "%s takes no value"
+msgstr "%s n'accepte aucune valeur"
 
-#: sequencer.c:2269
-msgid "unusable squash-onto"
-msgstr "\"écrase-sur\" inutilisable"
+#: parse-options.c:94
+#, c-format
+msgid "%s isn't available"
+msgstr "%s n'est pas disponible"
 
-#: sequencer.c:2285
+#: parse-options.c:219
 #, c-format
-msgid "malformed options sheet: '%s'"
-msgstr "feuille d'options malformée : %s"
+msgid "%s expects a non-negative integer value with an optional k/m/g suffix"
+msgstr "%s attend une valeur entière non négative avec une suffixe k/m/g"
 
-#: sequencer.c:2323
-msgid "a cherry-pick or revert is already in progress"
-msgstr "un picorage ou un retour est déjà en cours"
-
-#: sequencer.c:2324
-msgid "try \"git cherry-pick (--continue | --quit | --abort)\""
-msgstr "essayez \"git cherry-pick (--continue|--quit|-- abort)\""
+#: parse-options.c:389
+#, c-format
+msgid "ambiguous option: %s (could be --%s%s or --%s%s)"
+msgstr "option ambigüe : %s (devrait être --%s%s ou --%s%s)"
 
-#: sequencer.c:2327
+#: parse-options.c:423 parse-options.c:431
 #, c-format
-msgid "could not create sequencer directory '%s'"
-msgstr "impossible de créer le répertoire de séquenceur '%s'"
+msgid "did you mean `--%s` (with two dashes ?)"
+msgstr "vouliez-vous dire `--%s` (avec deux signes moins)?"
 
-#: sequencer.c:2341
-msgid "could not lock HEAD"
-msgstr "impossible de verrouiller HEAD"
+#: parse-options.c:860
+#, c-format
+msgid "unknown option `%s'"
+msgstr "option inconnue « %s »"
 
-#: sequencer.c:2396 sequencer.c:3403
-msgid "no cherry-pick or revert in progress"
-msgstr "aucun picorage ou retour en cours"
+#: parse-options.c:862
+#, c-format
+msgid "unknown switch `%c'"
+msgstr "bascule inconnue « %c »"
 
-#: sequencer.c:2398
-msgid "cannot resolve HEAD"
-msgstr "impossible de résoudre HEAD"
+#: parse-options.c:864
+#, c-format
+msgid "unknown non-ascii option in string: `%s'"
+msgstr "option non-ascii inconnue dans la chaîne : '%s'"
 
-#: sequencer.c:2400 sequencer.c:2435
-msgid "cannot abort from a branch yet to be born"
-msgstr "impossible d'abandonner depuis une branche non encore créée"
+#: parse-options.c:888
+msgid "..."
+msgstr "..."
 
-#: sequencer.c:2421 builtin/grep.c:720
+#: parse-options.c:907
 #, c-format
-msgid "cannot open '%s'"
-msgstr "impossible d'ouvrir '%s'"
+msgid "usage: %s"
+msgstr "usage : %s"
 
-#: sequencer.c:2423
+#. TRANSLATORS: the colon here should align with the
+#. one in "usage: %s" translation.
+#.
+#: parse-options.c:913
 #, c-format
-msgid "cannot read '%s': %s"
-msgstr "impossible de lire '%s' : %s"
-
-#: sequencer.c:2424
-msgid "unexpected end of file"
-msgstr "fin de fichier inattendue"
+msgid "   or: %s"
+msgstr "   ou : %s"
 
-#: sequencer.c:2430
+#: parse-options.c:916
 #, c-format
-msgid "stored pre-cherry-pick HEAD file '%s' is corrupt"
-msgstr "le fichier HEAD de préparation de picorage '%s' est corrompu"
+msgid "    %s"
+msgstr "    %s"
 
-#: sequencer.c:2441
-msgid "You seem to have moved HEAD. Not rewinding, check your HEAD!"
-msgstr ""
-"Vous semblez avoir déplacé la HEAD. Pas de rembobinage, vérifiez votre HEAD !"
+#: parse-options.c:955
+msgid "-NUM"
+msgstr "-NUM"
 
-#: sequencer.c:2545 sequencer.c:3321
+#: parse-options.c:969
 #, c-format
-msgid "could not update %s"
-msgstr "impossible de mettre à jour %s"
-
-#: sequencer.c:2583 sequencer.c:3301
-msgid "cannot read HEAD"
-msgstr "impossible de lire HEAD"
+msgid "alias of --%s"
+msgstr "alias pour --%s"
 
-#: sequencer.c:2618 sequencer.c:2622 builtin/difftool.c:639
+#: parse-options-cb.c:20 parse-options-cb.c:24
 #, c-format
-msgid "could not copy '%s' to '%s'"
-msgstr "impossible de copier '%s' vers '%s'"
+msgid "option `%s' expects a numerical value"
+msgstr "l'option '%s' attend une valeur numérique"
 
-#: sequencer.c:2641
-msgid "could not read index"
-msgstr "impossible de lire l'index"
+#: parse-options-cb.c:41
+#, c-format
+msgid "malformed expiration date '%s'"
+msgstr "date d'expiration malformée : '%s'"
 
-#: sequencer.c:2646
+#: parse-options-cb.c:54
 #, c-format
-msgid ""
-"execution failed: %s\n"
-"%sYou can fix the problem, and then run\n"
-"\n"
-"  git rebase --continue\n"
-"\n"
-msgstr ""
-"échec d'exécution : %s\n"
-"%sVous pouvez corriger le problème, puis lancer\n"
-"\n"
-"git rebase --continue\n"
-"\n"
+msgid "option `%s' expects \"always\", \"auto\", or \"never\""
+msgstr "l'option '%s' attend \"always\", \"auto\" ou \"never\""
 
-#: sequencer.c:2652
-msgid "and made changes to the index and/or the working tree\n"
-msgstr "et a mis à jour l'index ou l'arbre de travail\n"
+#: parse-options-cb.c:130 parse-options-cb.c:147
+#, c-format
+msgid "malformed object name '%s'"
+msgstr "nom d'objet malformé '%s'"
 
-#: sequencer.c:2658
+#: path.c:915
 #, c-format
-msgid ""
-"execution succeeded: %s\n"
-"but left changes to the index and/or the working tree\n"
-"Commit or stash your changes, and then run\n"
-"\n"
-"  git rebase --continue\n"
-"\n"
+msgid "Could not make %s writable by group"
+msgstr "Impossible de rendre %s inscriptible pour le groupe"
+
+#: pathspec.c:130
+msgid "Escape character '\\' not allowed as last character in attr value"
 msgstr ""
-"L'exécution a réussi : %s\n"
-"mais a laissé des modifications dans l'index ou la copie de travail\n"
-"Validez ou remisez vos modification, puis lancez\n"
-"\n"
-"  git rebase --continue\n"
-"\n"
+"Le caractère d'échappement '\\\\' interdit comme dernier caractère dans une "
+"valeur d'attribut"
 
-#: sequencer.c:2771
-msgid "writing fake root commit"
-msgstr "écriture d'un commit racine bidon"
+#: pathspec.c:148
+msgid "Only one 'attr:' specification is allowed."
+msgstr "Une seule spécification 'attr:' est autorisée."
 
-#: sequencer.c:2776
-msgid "writing squash-onto"
-msgstr "écriture de 'écraser-sur'"
+#: pathspec.c:151
+msgid "attr spec must not be empty"
+msgstr "un spécificateur d'attribut ne peut pas être vide"
 
-#: sequencer.c:2811
+#: pathspec.c:194
 #, c-format
-msgid "failed to find tree of %s"
-msgstr "impossible de trouver l'arbre de %s"
+msgid "invalid attribute name %s"
+msgstr "nom d'attribut invalide %s"
 
-#: sequencer.c:2829
-msgid "could not write index"
-msgstr "impossible d'écrire l'index"
+#: pathspec.c:259
+msgid "global 'glob' and 'noglob' pathspec settings are incompatible"
+msgstr ""
+"les réglages de spécificateurs de chemin généraux 'glob' et 'noglob' sont "
+"incompatibles"
 
-#: sequencer.c:2861
-msgid "cannot merge without a current revision"
-msgstr "impossible de fusionner avec une révision courante"
+#: pathspec.c:266
+msgid ""
+"global 'literal' pathspec setting is incompatible with all other global "
+"pathspec settings"
+msgstr ""
+"le réglage global de spécificateur de chemin 'literal' est incompatible avec "
+"tous les autres réglages globaux de spécificateur de chemin"
 
-#: sequencer.c:2884
-#, c-format
-msgid "could not resolve '%s'"
-msgstr "impossible de résoudre '%s'"
+#: pathspec.c:306
+msgid "invalid parameter for pathspec magic 'prefix'"
+msgstr "paramètre invalide pour le spécificateur magique de chemin 'prefix'"
 
-#: sequencer.c:2906
+#: pathspec.c:327
 #, c-format
-msgid "could not get commit message of '%s'"
-msgstr "impossible de lire le message de validation de '%s'"
+msgid "Invalid pathspec magic '%.*s' in '%s'"
+msgstr "La spécification magique de chemin '%.*s' est invalide dans '%s'"
 
-#: sequencer.c:2916 sequencer.c:2941
+#: pathspec.c:332
 #, c-format
-msgid "could not write '%s'"
-msgstr "impossible d'écrire '%s'"
+msgid "Missing ')' at the end of pathspec magic in '%s'"
+msgstr "')' manquante à la fin du spécificateur magique de chemin dans '%s'"
 
-#: sequencer.c:3005
+#: pathspec.c:370
 #, c-format
-msgid "could not even attempt to merge '%.*s'"
-msgstr "impossible de seulement essayer de fusionner '%.*s'"
+msgid "Unimplemented pathspec magic '%c' in '%s'"
+msgstr "Spécificateur magique '%c' non implémenté dans '%s'"
 
-#: sequencer.c:3021
-msgid "merge: Unable to write new index file"
-msgstr "fusion : Impossible d'écrire le nouveau fichier index"
+#: pathspec.c:429
+#, c-format
+msgid "%s: 'literal' and 'glob' are incompatible"
+msgstr "%s : 'literal' et 'glob' sont incompatibles"
 
-#: sequencer.c:3088
+#: pathspec.c:442
 #, c-format
-msgid "Applied autostash.\n"
-msgstr "Autoremisage appliqué.\n"
+msgid "%s: '%s' is outside repository"
+msgstr "%s : '%s' est hors du dépôt"
 
-#: sequencer.c:3100
+#: pathspec.c:516
 #, c-format
-msgid "cannot store %s"
-msgstr "impossible de stocker %s"
+msgid "'%s' (mnemonic: '%c')"
+msgstr "'%s' (mnémonique : '%c')"
 
-#: sequencer.c:3103 git-rebase.sh:188
+#: pathspec.c:526
 #, c-format
-msgid ""
-"Applying autostash resulted in conflicts.\n"
-"Your changes are safe in the stash.\n"
-"You can run \"git stash pop\" or \"git stash drop\" at any time.\n"
+msgid "%s: pathspec magic not supported by this command: %s"
 msgstr ""
-"L'application de l'autoremisage a provoqué des conflits\n"
-"Vos  modifications sont à l'abri dans la remise.\n"
-"Vous pouvez lancer \"git stash pop\" ou \"git stash drop\" à tout moment.\n"
+"%s : le spécificateur magique de chemin n'est pas supporté par cette "
+"commande : %s"
 
-#: sequencer.c:3134
+#: pathspec.c:593
 #, c-format
-msgid ""
-"Could not execute the todo command\n"
-"\n"
-"    %.*s\n"
-"It has been rescheduled; To edit the command before continuing, please\n"
-"edit the todo list first:\n"
-"\n"
-"    git rebase --edit-todo\n"
-"    git rebase --continue\n"
+msgid "pathspec '%s' is beyond a symbolic link"
+msgstr "le chemin '%s' est au-delà d'un lien symbolique"
+
+#: pathspec.c:638
+#, c-format
+msgid "line is badly quoted: %s"
+msgstr "la ligne est mal citée : %s"
+
+#: pkt-line.c:92
+msgid "unable to write flush packet"
+msgstr "impossible d'écrire le paquet de vidage"
+
+#: pkt-line.c:99
+msgid "unable to write delim packet"
+msgstr "impossible d'écrire le paquet de délimitation"
+
+#: pkt-line.c:106
+msgid "flush packet write failed"
+msgstr "échec de l'écriture du vidage de paquet"
+
+#: pkt-line.c:146 pkt-line.c:232
+msgid "protocol error: impossibly long line"
+msgstr "erreur de protocole : ligne impossiblement trop longue"
+
+#: pkt-line.c:162 pkt-line.c:164
+msgid "packet write with format failed"
+msgstr "échec de l'écriture d'un paquet avec format"
+
+#: pkt-line.c:196
+msgid "packet write failed - data exceeds max packet size"
 msgstr ""
-"Impossible d'exécuter la commande\n"
-"\n"
-"    %.*s\n"
-"Elle a été reprogrammée ; pour éditer la commande avant de poursuivre,\n"
-"veuillez éditer la liste de commandes en premier :\n"
-"\n"
-"    git rebase --edit-todo\n"
-"    git rebase --continue\n"
+"échec de l'écriture d'un paquet ‑ les données dépassent la taille maximale "
+"d'un paquet"
+
+#: pkt-line.c:203 pkt-line.c:210
+msgid "packet write failed"
+msgstr "échec de l'écriture d'un paquet"
 
-#: sequencer.c:3202
+#: pkt-line.c:295
+msgid "read error"
+msgstr "erreur de lecture"
+
+#: pkt-line.c:303
+msgid "the remote end hung up unexpectedly"
+msgstr "L'hôte distant a fermé la connexion de manière inattendue"
+
+#: pkt-line.c:331
 #, c-format
-msgid "Stopped at %s...  %.*s\n"
-msgstr "arrêt à %s... %.*s\n"
+msgid "protocol error: bad line length character: %.4s"
+msgstr "erreur de protocole : mauvais caractère de longueur de ligne : %.4s"
 
-#: sequencer.c:3264
+#: pkt-line.c:341 pkt-line.c:346
 #, c-format
-msgid "unknown command %d"
-msgstr "commande inconnue %d"
+msgid "protocol error: bad line length %d"
+msgstr "erreur de protocole : mauvaise longueur de ligne %d"
 
-#: sequencer.c:3309
-msgid "could not read orig-head"
-msgstr "impossible de lire orig-head"
+#: pkt-line.c:362
+#, c-format
+msgid "remote error: %s"
+msgstr "erreur distante : %s"
 
-#: sequencer.c:3314 sequencer.c:4352
-msgid "could not read 'onto'"
-msgstr "impossible de lire 'onto'"
+#: preload-index.c:119
+msgid "Refreshing index"
+msgstr "Rafraîchissement de l'index"
 
-#: sequencer.c:3328
+#: preload-index.c:138
 #, c-format
-msgid "could not update HEAD to %s"
-msgstr "impossible de mettre à jour HEAD sur %s"
+msgid "unable to create threaded lstat: %s"
+msgstr "impossible de créer le lstat en fil : %s"
 
-#: sequencer.c:3414
-msgid "cannot rebase: You have unstaged changes."
-msgstr "impossible de rebaser : vous avez des modifications non indexées."
+#: pretty.c:981
+msgid "unable to parse --pretty format"
+msgstr "impossible d'analyser le format --pretty"
 
-#: sequencer.c:3423
-msgid "cannot amend non-existing commit"
-msgstr "impossible de corriger un commit non-existant"
+#: promisor-remote.c:23
+msgid "Remote with no URL"
+msgstr "Dépôt distant sans URL"
 
-#: sequencer.c:3425
+#: promisor-remote.c:58
 #, c-format
-msgid "invalid file: '%s'"
-msgstr "fichier invalide : '%s'"
+msgid "promisor remote name cannot begin with '/': %s"
+msgstr "un nom de prometteur distant ne peut pas commencer par '/' : %s"
 
-#: sequencer.c:3427
-#, c-format
-msgid "invalid contents: '%s'"
-msgstr "contenu invalide : '%s'"
+#: range-diff.c:75
+msgid "could not start `log`"
+msgstr "impossible de démarrer `log`"
 
-#: sequencer.c:3430
-msgid ""
-"\n"
-"You have uncommitted changes in your working tree. Please, commit them\n"
-"first and then run 'git rebase --continue' again."
-msgstr ""
-"\n"
-"Vous avez des modifications non validées dans votre copie de travail.\n"
-"Veuillez les valider d'abord, puis relancer 'git rebase --continue'."
+#: range-diff.c:77
+msgid "could not read `log` output"
+msgstr "impossible de lire la sortie de `log`"
 
-#: sequencer.c:3455 sequencer.c:3493
+#: range-diff.c:96 sequencer.c:5163
 #, c-format
-msgid "could not write file: '%s'"
-msgstr "impossible d'écrire le fichier : '%s'"
+msgid "could not parse commit '%s'"
+msgstr "impossible d'analyser le commit '%s'"
 
-#: sequencer.c:3508
-msgid "could not remove CHERRY_PICK_HEAD"
-msgstr "impossible de supprimer CHERRY_PICK_HEAD"
+#: range-diff.c:122
+#, c-format
+msgid "could not parse git header '%.*s'"
+msgstr "impossible d'analyser l'entête git '%.*s'"
 
-#: sequencer.c:3515
-msgid "could not commit staged changes."
-msgstr "impossible de valider les modifications indexées."
+#: range-diff.c:285
+msgid "failed to generate diff"
+msgstr "échec de la génération de diff"
 
-#: sequencer.c:3612
+#: range-diff.c:518 range-diff.c:520
 #, c-format
-msgid "%s: can't cherry-pick a %s"
-msgstr "%s : impossible de picorer un %s"
+msgid "could not parse log for '%s'"
+msgstr "impossible d'analyser le journal pour '%s'"
 
-#: sequencer.c:3616
+#: read-cache.c:680
 #, c-format
-msgid "%s: bad revision"
-msgstr "%s : mauvaise révision"
-
-#: sequencer.c:3649
-msgid "can't revert as initial commit"
-msgstr "impossible d'annuler en tant que commit initial"
-
-#: sequencer.c:4098
-msgid "make_script: unhandled options"
-msgstr "make_script : options non gérées"
-
-#: sequencer.c:4101
-msgid "make_script: error preparing revisions"
-msgstr "make_script : erreur lors de la préparation des révisions"
+msgid "will not add file alias '%s' ('%s' already exists in index)"
+msgstr "pas d'ajout d'alias de fichier '%s'(« %s » existe déjà dans l'index)"
 
-#: sequencer.c:4142 sequencer.c:4177
-#, c-format
-msgid "unusable todo list: '%s'"
-msgstr "liste à faire inutilisable : '%s'"
+#: read-cache.c:696
+msgid "cannot create an empty blob in the object database"
+msgstr "impossible de créer un blob vide dans la base de donnée d'objets"
 
-#: sequencer.c:4236
+#: read-cache.c:718
 #, c-format
-msgid ""
-"unrecognized setting %s for option rebase.missingCommitsCheck. Ignoring."
+msgid "%s: can only add regular files, symbolic links or git-directories"
 msgstr ""
-"paramètre non reconnu %s pour l'option rebase.missingCommitsCheck. Ignoré."
+"%s : ne peut ajouter que des fichiers normaux, des liens symboliques ou des "
+"répertoires git"
 
-#: sequencer.c:4302
+#: read-cache.c:723
 #, c-format
-msgid ""
-"Warning: some commits may have been dropped accidentally.\n"
-"Dropped commits (newer to older):\n"
-msgstr ""
-"Attention : certains commits ont pu être accidentellement supprimés.\n"
-"Commits supprimés (du plus jeune au plus vieux) :\n"
+msgid "'%s' does not have a commit checked out"
+msgstr "'%s' n'a pas de commit extrait"
 
-#: sequencer.c:4309
+#: read-cache.c:775
 #, c-format
-msgid ""
-"To avoid this message, use \"drop\" to explicitly remove a commit.\n"
-"\n"
-"Use 'git config rebase.missingCommitsCheck' to change the level of "
-"warnings.\n"
-"The possible behaviours are: ignore, warn, error.\n"
-"\n"
-msgstr ""
-"Pour éviter ce message, utilisez \"drop\" pour supprimer explicitement un "
-"commit.\n"
-"\n"
-"Utilisez 'git config rebase.missingCommitsCheck' pour changer le niveau "
-"d'avertissements.\n"
-"Les comportements disponibles sont : ignore, warn, error.\n"
-"\n"
+msgid "unable to index file '%s'"
+msgstr "indexation du fichier '%s' impossible"
 
-#: sequencer.c:4321
+#: read-cache.c:794
 #, c-format
-msgid ""
-"You can fix this with 'git rebase --edit-todo' and then run 'git rebase --"
-"continue'.\n"
-"Or you can abort the rebase with 'git rebase --abort'.\n"
-msgstr ""
-"Vous pouvez corriger ceci avec 'git rebase --edit-todo' puis lancez 'git "
-"rebase --continue'.\n"
-"Ou vous pouvez abandonner le rebasage avec 'git rebase --abort'.\n"
+msgid "unable to add '%s' to index"
+msgstr "impossible d'ajouter '%s' à l'index"
 
-#: sequencer.c:4375
+#: read-cache.c:805
 #, c-format
-msgid "could not parse commit '%s'"
-msgstr "impossible d'analyser le commit '%s'"
-
-#: sequencer.c:4490
-msgid "the script was already rearranged."
-msgstr "le script a déjà été réarrangé."
+msgid "unable to stat '%s'"
+msgstr "fstat de '%s' impossible"
 
-#: setup.c:123
+#: read-cache.c:1325
 #, c-format
-msgid "'%s' is outside repository"
-msgstr "'%s' est hors du dépôt"
+msgid "'%s' appears as both a file and as a directory"
+msgstr "'%s' existe à la fois comme un fichier et un répertoire"
 
-#: setup.c:172
+#: read-cache.c:1531
+msgid "Refresh index"
+msgstr "Rafraîchir l'index"
+
+#: read-cache.c:1646
 #, c-format
 msgid ""
-"%s: no such path in the working tree.\n"
-"Use 'git <command> -- <path>...' to specify paths that do not exist locally."
+"index.version set, but the value is invalid.\n"
+"Using version %i"
 msgstr ""
-"%s : ce chemin n'existe pas dans la copie de travail.\n"
-"Utilisez 'git <commande> -- <chemin>...' pour spécifier des chemins qui "
-"n'existent pas localement."
+"version d'index renseignée, mais la valeur est invalide.\n"
+"Utilisation de la version %i"
 
-#: setup.c:185
+#: read-cache.c:1656
 #, c-format
 msgid ""
-"ambiguous argument '%s': unknown revision or path not in the working tree.\n"
-"Use '--' to separate paths from revisions, like this:\n"
-"'git <command> [<revision>...] -- [<file>...]'"
+"GIT_INDEX_VERSION set, but the value is invalid.\n"
+"Using version %i"
 msgstr ""
-"argument '%s' ambigu : révision inconnue ou chemin inexistant.\n"
-"Utilisez '--' pour séparer les chemins des révisions, comme ceci :\n"
-"'git <commande> [<révision>...] -- [<chemin>...]'"
+"GIT_INDEX_VERSION est renseigné, mais la valeur est invalide.\n"
+"Utilisation de la version %i"
 
-#: setup.c:234
+#: read-cache.c:1712
 #, c-format
-msgid "option '%s' must come before non-option arguments"
-msgstr ""
-"l'option '%s' doit être présente avant les arguments qui ne sont pas des "
-"options"
+msgid "bad signature 0x%08x"
+msgstr "signature incorrecte 0x%08x"
 
-#: setup.c:253
+#: read-cache.c:1715
 #, c-format
-msgid ""
-"ambiguous argument '%s': both revision and filename\n"
-"Use '--' to separate paths from revisions, like this:\n"
-"'git <command> [<revision>...] -- [<file>...]'"
-msgstr ""
-"argument '%s' ambigu : révision et chemin spécifiés.\n"
-"Utilisez '--' pour séparer les chemins des révisions, comme ceci :\n"
-"'git <commande> [<révision>...] -- [<chemin>...]'"
-
-#: setup.c:389
-msgid "unable to set up work tree using invalid config"
-msgstr ""
-"impossible de mettre en place le répertoire de travail en utilisant une "
-"configuration invalide"
+msgid "bad index version %d"
+msgstr "mauvaise version d'index %d"
 
-#: setup.c:393
-msgid "this operation must be run in a work tree"
-msgstr "Cette opération doit être effectuée dans un arbre de travail"
+#: read-cache.c:1724
+msgid "bad index file sha1 signature"
+msgstr "mauvaise signature sha1 d'index"
 
-#: setup.c:503
+#: read-cache.c:1754
 #, c-format
-msgid "Expected git repo version <= %d, found %d"
-msgstr "Version attendue du dépôt git <= %d, %d trouvée"
-
-#: setup.c:511
-msgid "unknown repository extensions found:"
-msgstr "extensions de dépôt inconnues trouvées :"
+msgid "index uses %.4s extension, which we do not understand"
+msgstr "l'index utilise l'extension %.4s qui n'est pas comprise"
 
-#: setup.c:530
+#: read-cache.c:1756
 #, c-format
-msgid "error opening '%s'"
-msgstr "erreur à l'ouverture de '%s'"
+msgid "ignoring %.4s extension"
+msgstr "extension %.4s ignorée"
 
-#: setup.c:532
+#: read-cache.c:1793
 #, c-format
-msgid "too large to be a .git file: '%s'"
-msgstr "trop gros pour être une fichier .git : '%s'"
+msgid "unknown index entry format 0x%08x"
+msgstr "format d'entrée d'index inconnu 0x%08x"
 
-#: setup.c:534
+#: read-cache.c:1809
 #, c-format
-msgid "error reading %s"
-msgstr "erreur à la lecture de %s"
+msgid "malformed name field in the index, near path '%s'"
+msgstr "champ de nom malformé dans l'index, près du chemin '%s'"
 
-#: setup.c:536
-#, c-format
-msgid "invalid gitfile format: %s"
-msgstr "format de fichier git invalide : %s"
+#: read-cache.c:1866
+msgid "unordered stage entries in index"
+msgstr "entrées de préparation non ordonnées dans l'index"
 
-#: setup.c:538
+#: read-cache.c:1869
 #, c-format
-msgid "no path in gitfile: %s"
-msgstr "aucun chemin dans le fichier git : %s"
+msgid "multiple stage entries for merged file '%s'"
+msgstr "entrées multiples de préparation pour le fichier fusionné '%s'"
 
-#: setup.c:540
+#: read-cache.c:1872
 #, c-format
-msgid "not a git repository: %s"
-msgstr "ce n'est pas un dépôt git : %s"
+msgid "unordered stage entries for '%s'"
+msgstr "entrées de préparation non ordonnées pour '%s'"
 
-#: setup.c:639
-#, c-format
-msgid "'$%s' too big"
-msgstr "'$%s' trop gros"
+#: read-cache.c:1978 read-cache.c:2266 rerere.c:565 rerere.c:599 rerere.c:1111
+#: builtin/add.c:499 builtin/check-ignore.c:178 builtin/checkout.c:470
+#: builtin/checkout.c:654 builtin/clean.c:967 builtin/commit.c:367
+#: builtin/diff-tree.c:120 builtin/grep.c:499 builtin/mv.c:145
+#: builtin/reset.c:246 builtin/rm.c:271 builtin/submodule--helper.c:332
+msgid "index file corrupt"
+msgstr "fichier d'index corrompu"
 
-#: setup.c:653
+#: read-cache.c:2119
 #, c-format
-msgid "not a git repository: '%s'"
-msgstr "ce n'est pas un dépôt git : '%s'"
+msgid "unable to create load_cache_entries thread: %s"
+msgstr "impossible de créer le fil load_cache_entries : %s"
 
-#: setup.c:682 setup.c:684 setup.c:715
+#: read-cache.c:2132
 #, c-format
-msgid "cannot chdir to '%s'"
-msgstr "impossible de se déplacer vers le répertoire (chdir) '%s'"
-
-#: setup.c:687 setup.c:743 setup.c:753 setup.c:792 setup.c:800 setup.c:815
-msgid "cannot come back to cwd"
-msgstr "impossible de revenir au répertoire de travail courant"
+msgid "unable to join load_cache_entries thread: %s"
+msgstr "impossible de joindre le fil load_cach_entries : %s"
 
-#: setup.c:813
+#: read-cache.c:2165
 #, c-format
-msgid "not a git repository (or any of the parent directories): %s"
-msgstr "ni ceci ni aucun de ses répertoires parents n'est un dépôt git : %s"
+msgid "%s: index file open failed"
+msgstr "%s : l'ouverture du fichier d'index a échoué"
 
-#: setup.c:824
+#: read-cache.c:2169
 #, c-format
-msgid "failed to stat '%*s%s%s'"
-msgstr "échec du stat de '%*s%s%s'"
-
-#: setup.c:1054
-msgid "Unable to read current working directory"
-msgstr "Impossible d'accéder au répertoire de travail courant"
+msgid "%s: cannot stat the open index"
+msgstr "%s : impossible de faire un stat sur l'index ouvert"
 
-#: setup.c:1066 setup.c:1072
+#: read-cache.c:2173
 #, c-format
-msgid "cannot change to '%s'"
-msgstr "impossible de modifier en '%s'"
+msgid "%s: index file smaller than expected"
+msgstr "%s : fichier d'index plus petit qu'attendu"
 
-#: setup.c:1085
+#: read-cache.c:2177
 #, c-format
-msgid ""
-"not a git repository (or any parent up to mount point %s)\n"
-"Stopping at filesystem boundary (GIT_DISCOVERY_ACROSS_FILESYSTEM not set)."
-msgstr ""
-"ni ceci ni aucun de ses répertoires parents (jusqu'au point de montage %s) "
-"n'est un dépôt git\n"
-"Arrêt à la limite du système de fichiers (GIT_DISCOVERY_ACROSS_FILESYSTEM "
-"n'est pas défini)."
+msgid "%s: unable to map index file"
+msgstr "%s : impossible de mapper le fichier d'index"
 
-#: setup.c:1168
+#: read-cache.c:2219
 #, c-format
-msgid ""
-"problem with core.sharedRepository filemode value (0%.3o).\n"
-"The owner of files must always have read and write permissions."
-msgstr ""
-"problème avec la valeur de core.sharedRepository (0%.3o).\n"
-"Le propriétaire des fichiers doit toujours avoir les droits en lecture et "
-"écriture."
+msgid "unable to create load_index_extensions thread: %s"
+msgstr "impossible de créer le fil load_index_extensions : %s"
 
-#: setup.c:1211
-msgid "open /dev/null or dup failed"
-msgstr "échec de l'ouverture ou au dup de /dev/null"
+#: read-cache.c:2246
+#, c-format
+msgid "unable to join load_index_extensions thread: %s"
+msgstr "impossible de joindre le fil load_index_extensions : %s"
 
-#: setup.c:1226
-msgid "fork failed"
-msgstr "échec de la bifurcation"
+#: read-cache.c:2278
+#, c-format
+msgid "could not freshen shared index '%s'"
+msgstr "impossible de rafraîchir l'index partagé '%s'"
 
-#: setup.c:1231
-msgid "setsid failed"
-msgstr "échec du setsid"
+#: read-cache.c:2325
+#, c-format
+msgid "broken index, expect %s in %s, got %s"
+msgstr "index cassé, %s attendu dans %s, %s obtenu"
 
-#: sha1-file.c:625
+#: read-cache.c:3021 strbuf.c:1145 wrapper.c:622 builtin/merge.c:1119
 #, c-format
-msgid "path '%s' does not exist"
-msgstr "le chemin '%s' n'existe pas"
+msgid "could not close '%s'"
+msgstr "impossible de fermer '%s'"
 
-#: sha1-file.c:651
+#: read-cache.c:3124 sequencer.c:2429 sequencer.c:4069
 #, c-format
-msgid "reference repository '%s' as a linked checkout is not supported yet."
-msgstr ""
-"extraire le dépôt de référence '%s' comme une extraction liée n'est pas "
-"encore supporté."
+msgid "could not stat '%s'"
+msgstr "stat impossible de '%s'"
 
-#: sha1-file.c:657
+#: read-cache.c:3137
 #, c-format
-msgid "reference repository '%s' is not a local repository."
-msgstr "le dépôt de référence '%s' n'est pas un dépôt local."
+msgid "unable to open git dir: %s"
+msgstr "impossible d'ouvrir le répertoire git : %s"
 
-#: sha1-file.c:663
+#: read-cache.c:3149
 #, c-format
-msgid "reference repository '%s' is shallow"
-msgstr "le dépôt de référence '%s' est superficiel"
+msgid "unable to unlink: %s"
+msgstr "échec lors de l'unlink : %s"
 
-#: sha1-file.c:671
+#: read-cache.c:3174
 #, c-format
-msgid "reference repository '%s' is grafted"
-msgstr "le dépôt de référence '%s' est greffé"
+msgid "cannot fix permission bits on '%s'"
+msgstr "impossible de régler les bits de droit de '%s'"
 
-#: sha1-name.c:442
+#: read-cache.c:3323
 #, c-format
-msgid "short SHA1 %s is ambiguous"
-msgstr "le SHA1 court %s est ambigu"
+msgid "%s: cannot drop to stage #0"
+msgstr "%s : impossible de revenir à l'étape 0"
 
-#: sha1-name.c:453
-msgid "The candidates are:"
-msgstr "Les candidats sont :"
+#: rebase-interactive.c:26
+#, c-format
+msgid ""
+"unrecognized setting %s for option rebase.missingCommitsCheck. Ignoring."
+msgstr ""
+"paramètre non reconnu %s pour l'option rebase.missingCommitsCheck. Ignoré."
 
-#: sha1-name.c:695
+#: rebase-interactive.c:35
 msgid ""
-"Git normally never creates a ref that ends with 40 hex characters\n"
-"because it will be ignored when you just specify 40-hex. These refs\n"
-"may be created by mistake. For example,\n"
 "\n"
-"  git checkout -b $br $(git rev-parse ...)\n"
+"Commands:\n"
+"p, pick <commit> = use commit\n"
+"r, reword <commit> = use commit, but edit the commit message\n"
+"e, edit <commit> = use commit, but stop for amending\n"
+"s, squash <commit> = use commit, but meld into previous commit\n"
+"f, fixup <commit> = like \"squash\", but discard this commit's log message\n"
+"x, exec <command> = run command (the rest of the line) using shell\n"
+"b, break = stop here (continue rebase later with 'git rebase --continue')\n"
+"d, drop <commit> = remove commit\n"
+"l, label <label> = label current HEAD with a name\n"
+"t, reset <label> = reset HEAD to a label\n"
+"m, merge [-C <commit> | -c <commit>] <label> [# <oneline>]\n"
+".       create a merge commit using the original merge commit's\n"
+".       message (or the oneline, if no original merge commit was\n"
+".       specified). Use -c <commit> to reword the commit message.\n"
 "\n"
-"where \"$br\" is somehow empty and a 40-hex ref is created. Please\n"
-"examine these refs and maybe delete them. Turn this message off by\n"
-"running \"git config advice.objectNameWarning false\""
+"These lines can be re-ordered; they are executed from top to bottom.\n"
 msgstr ""
-"Git ne crée normalement jamais de référence qui se termine par 40 caractères "
-"hexa\n"
-"car elle serait ignorée si vous spécifiiez 40-hexa. Ces références\n"
-"peuvent être créées par erreur. Par exemple,\n"
 "\n"
-"  git checkout -b $br $(git rev-parse ...)\n"
+"Commandes :\n"
+" p, pick <commit> = utiliser le commit\n"
+" r, reword <commit> = utiliser le commit, mais reformuler son message\n"
+" e, edit <commit> = utiliser le commit, mais s'arrêter pour le modifier\n"
+" s, squash <commit> = utiliser le commit, mais le fusionner avec le "
+"précédent\n"
+" f, fixup <commit> = comme \"squash\", mais en éliminant son message\n"
+" x, exec <commit> = lancer la commande (reste de la ligne) dans un shell\n"
+" b, break = s'arrêter ici (on peut continuer ensuite avec 'git rebase --"
+"continue')\n"
+" d, drop <commit> = supprimer le commit\n"
+" l, label <label> = étiqueter la HEAD courante avec un nom\n"
+" t, reset <label> = réinitialiser HEAD à label\n"
+" m, merge [-C <commit> | -c <commit>] <label> [# <uniligne>]\n"
+"         créer un commit de fusion utilisant le message de fusion original\n"
+"         (ou l'uniligne, si aucun commit de fusion n'a été spécifié).\n"
+"         Utilisez -c <commit> pour reformuler le message de validation.\n"
 "\n"
-"où \"$br\" est d'une manière ou d'une autre vide et une référence 40-hexa "
-"est créée.\n"
-"Veuillez examiner ces références et peut-être les supprimer. Désactivez ce "
-"message\n"
-"en lançant \"git config advice.objectNameWarning false\""
-
-#: submodule.c:97 submodule.c:131
-msgid "Cannot change unmerged .gitmodules, resolve merge conflicts first"
-msgstr ""
-"Modification impossible de .gitmodules non fusionné, résolvez les conflits "
-"d'abord"
-
-#: submodule.c:101 submodule.c:135
-#, c-format
-msgid "Could not find section in .gitmodules where path=%s"
-msgstr "Impossible de trouver une section où path=%s dans .gitmodules"
+"Vous pouvez réordonner ces lignes ; elles sont exécutées de haut en bas.\n"
 
-#: submodule.c:109
+#: rebase-interactive.c:56
 #, c-format
-msgid "Could not update .gitmodules entry %s"
-msgstr "Impossible de mettre à jour l'élément %s de .gitmodules"
+msgid "Rebase %s onto %s (%d command)"
+msgid_plural "Rebase %s onto %s (%d commands)"
+msgstr[0] "Rebasage de %s sur %s (%d commande)"
+msgstr[1] "Rebasage de %s sur %s (%d commandes)"
 
-# ici %s est un chemin
-#: submodule.c:142
-#, c-format
-msgid "Could not remove .gitmodules entry for %s"
-msgstr "Impossible de supprimer l'élément de .gitmodules pour %s"
+#: rebase-interactive.c:65 git-rebase--preserve-merges.sh:228
+msgid ""
+"\n"
+"Do not remove any line. Use 'drop' explicitly to remove a commit.\n"
+msgstr ""
+"\n"
+"Ne supprimez aucune ligne. Utilisez 'drop' explicitement pour supprimer un "
+"commit.\n"
 
-#: submodule.c:153
-msgid "staging updated .gitmodules failed"
-msgstr "échec de la mise en index du .gitmodules mis à jour"
+#: rebase-interactive.c:68 git-rebase--preserve-merges.sh:232
+msgid ""
+"\n"
+"If you remove a line here THAT COMMIT WILL BE LOST.\n"
+msgstr ""
+"\n"
+"Si vous éliminez une ligne ici, LE COMMIT CORRESPONDANT SERA PERDU.\n"
 
-#: submodule.c:315
-#, c-format
-msgid "in unpopulated submodule '%s'"
-msgstr "dans le sous-module '%s' non populé"
-
-#: submodule.c:346
-#, c-format
-msgid "Pathspec '%s' is in submodule '%.*s'"
-msgstr "Le chemin '%s' est dans le sous-module '%.*s'"
-
-#: submodule.c:837
-#, c-format
-msgid "submodule entry '%s' (%s) is a %s, not a commit"
-msgstr "l'entrée de sous-module '%s' (%s) est un %s, pas un commit"
+#: rebase-interactive.c:74 git-rebase--preserve-merges.sh:871
+msgid ""
+"\n"
+"You are editing the todo file of an ongoing interactive rebase.\n"
+"To continue rebase after editing, run:\n"
+"    git rebase --continue\n"
+"\n"
+msgstr ""
+"\n"
+"Vous êtes en train d'éditer le fichier todo d'un rebasage interactif en "
+"cours.\n"
+"Pour continuer le rebasage après édition, lancez :\n"
+"    git rebase --continue\n"
+"\n"
 
-#: submodule.c:1069 builtin/branch.c:651 builtin/submodule--helper.c:1743
-msgid "Failed to resolve HEAD as a valid ref."
-msgstr "Échec de résolution de HEAD comme référence valide."
+#: rebase-interactive.c:79 git-rebase--preserve-merges.sh:948
+msgid ""
+"\n"
+"However, if you remove everything, the rebase will be aborted.\n"
+"\n"
+msgstr ""
+"\n"
+"Cependant, si vous effacez tout, le rebasage sera annulé.\n"
+"\n"
 
-#: submodule.c:1375
-#, c-format
-msgid "'%s' not recognized as a git repository"
-msgstr "'%s' n'est pas reconnu comme dépôt git"
+#: rebase-interactive.c:85 git-rebase--preserve-merges.sh:955
+msgid "Note that empty commits are commented out"
+msgstr "Veuillez noter que les commits vides sont en commentaire"
 
-#: submodule.c:1513
+#: rebase-interactive.c:105 rerere.c:485 rerere.c:692 sequencer.c:3536
+#: sequencer.c:3562 sequencer.c:5263 builtin/fsck.c:346 builtin/rebase.c:254
 #, c-format
-msgid "could not start 'git status' in submodule '%s'"
-msgstr "impossible de démarrer 'git status' dans le sous-module '%s'"
+msgid "could not write '%s'"
+msgstr "impossible d'écrire '%s'"
 
-#: submodule.c:1526
+#: rebase-interactive.c:108
 #, c-format
-msgid "could not run 'git status' in submodule '%s'"
-msgstr "impossible de lancer 'git status' dans le sous-module '%s'"
+msgid "could not copy '%s' to '%s'."
+msgstr "impossible de copier '%s' vers '%s'."
 
-#: submodule.c:1619
+#: rebase-interactive.c:173
 #, c-format
-msgid "submodule '%s' has dirty index"
-msgstr "le sous-module '%s' a un index sale"
+msgid ""
+"Warning: some commits may have been dropped accidentally.\n"
+"Dropped commits (newer to older):\n"
+msgstr ""
+"Attention : certains commits ont pu être accidentellement supprimés.\n"
+"Commits supprimés (du plus jeune au plus vieux) :\n"
 
-#: submodule.c:1718
+#: rebase-interactive.c:180
 #, c-format
 msgid ""
-"relocate_gitdir for submodule '%s' with more than one worktree not supported"
+"To avoid this message, use \"drop\" to explicitly remove a commit.\n"
+"\n"
+"Use 'git config rebase.missingCommitsCheck' to change the level of "
+"warnings.\n"
+"The possible behaviours are: ignore, warn, error.\n"
+"\n"
 msgstr ""
-"relocate_gitdir pour le sous-module '%s' avec plus d'un arbre de travail "
-"n'est pas supporté"
+"Pour éviter ce message, utilisez \"drop\" pour supprimer explicitement un "
+"commit.\n"
+"\n"
+"Utilisez 'git config rebase.missingCommitsCheck' pour changer le niveau "
+"d'avertissements.\n"
+"Les comportements disponibles sont : ignore, warn, error.\n"
+"\n"
 
-#: submodule.c:1730 submodule.c:1786
+#: refs.c:262
 #, c-format
-msgid "could not lookup name for submodule '%s'"
-msgstr "impossible de trouve le nom pour le sous-module '%s'"
+msgid "%s does not point to a valid object!"
+msgstr "%s ne pointe pas sur un objet valide!"
 
-#: submodule.c:1734 builtin/submodule--helper.c:1261
-#: builtin/submodule--helper.c:1271
+#: refs.c:667
 #, c-format
-msgid "could not create directory '%s'"
-msgstr "impossible de créer le répertoire '%s'"
+msgid "ignoring dangling symref %s"
+msgstr "symref pendant %s ignoré"
 
-#: submodule.c:1737
+#: refs.c:669 ref-filter.c:2098
 #, c-format
-msgid ""
-"Migrating git directory of '%s%s' from\n"
-"'%s' to\n"
-"'%s'\n"
-msgstr ""
-"Migration du répertoire git de '%s%s' depuis\n"
-"'%s' sur\n"
-"'%s'\n"
+msgid "ignoring broken ref %s"
+msgstr "réf cassé %s ignoré"
 
-#: submodule.c:1821
+#: refs.c:804
 #, c-format
-msgid "could not recurse into submodule '%s'"
-msgstr "récursion impossible dans le sous-module '%s'"
+msgid "could not open '%s' for writing: %s"
+msgstr "impossible d'ouvrir '%s' en écriture : %s"
 
-#: submodule.c:1865
-msgid "could not start ls-files in .."
-msgstr "impossible de démarrer ls-files dans .."
-
-#: submodule.c:1904
+#: refs.c:814 refs.c:865
 #, c-format
-msgid "ls-tree returned unexpected return code %d"
-msgstr "ls-tree a renvoyé un code de retour inattendu %d"
+msgid "could not read ref '%s'"
+msgstr "impossible de lire la réf '%s'"
 
-#: submodule-config.c:230
+#: refs.c:820
 #, c-format
-msgid "ignoring suspicious submodule name: %s"
-msgstr "nom de sous-module suspicieux %s ignoré"
-
-#: submodule-config.c:294
-msgid "negative values not allowed for submodule.fetchjobs"
-msgstr "les valeurs négatives ne sont pas permises pour submodule.fetchJobs"
+msgid "ref '%s' already exists"
+msgstr "la référence '%s' existe déjà"
 
-#: submodule-config.c:467
+#: refs.c:825
 #, c-format
-msgid "invalid value for %s"
-msgstr "Valeur invalide pour %s"
+msgid "unexpected object ID when writing '%s'"
+msgstr "id d'objet inattendu pendant l'écriture de '%s'"
 
-#: trailer.c:238
+#: refs.c:833 sequencer.c:405 sequencer.c:2793 sequencer.c:2997
+#: sequencer.c:3011 sequencer.c:3269 sequencer.c:5179 strbuf.c:1142
+#: wrapper.c:620
 #, c-format
-msgid "running trailer command '%s' failed"
-msgstr "échec de la commande trailer '%s'"
+msgid "could not write to '%s'"
+msgstr "impossible d'écrire dans '%s'"
 
-#: trailer.c:485 trailer.c:490 trailer.c:495 trailer.c:549 trailer.c:553
-#: trailer.c:557
+#: refs.c:860 strbuf.c:1140 wrapper.c:188 wrapper.c:358 builtin/am.c:714
+#: builtin/rebase.c:1031
 #, c-format
-msgid "unknown value '%s' for key '%s'"
-msgstr "valeur inconnue '%s' pour la clé '%s'"
+msgid "could not open '%s' for writing"
+msgstr "impossible d'ouvrir '%s' en écriture"
 
-#: trailer.c:539 trailer.c:544 builtin/remote.c:293
+#: refs.c:867
 #, c-format
-msgid "more than one %s"
-msgstr "plus d'un %s"
+msgid "unexpected object ID when deleting '%s'"
+msgstr "id d'objet inattendu pendant la suppression de '%s'"
 
-#: trailer.c:730
+#: refs.c:998
 #, c-format
-msgid "empty trailer token in trailer '%.*s'"
-msgstr "symbole vide dans la ligne de fin '%.*s'"
+msgid "log for ref %s has gap after %s"
+msgstr "le journal pour la réf %s contient un trou après %s"
 
-#: trailer.c:750
+#: refs.c:1004
 #, c-format
-msgid "could not read input file '%s'"
-msgstr "impossible de lire le fichier d'entrée '%s'"
+msgid "log for ref %s unexpectedly ended on %s"
+msgstr "le journal pour la réf %s s'arrête de manière inattendue sur %s"
 
-#: trailer.c:753
-msgid "could not read from stdin"
-msgstr "Impossible de lire depuis l'entrée standard"
+#: refs.c:1063
+#, c-format
+msgid "log for %s is empty"
+msgstr "le journal pour la réf %s est vide"
 
-#: trailer.c:1008 builtin/am.c:46
+#: refs.c:1155
 #, c-format
-msgid "could not stat %s"
-msgstr "stat impossible de %s"
+msgid "refusing to update ref with bad name '%s'"
+msgstr "refus de mettre à jour une réf avec un nom cassé '%s'"
 
-#: trailer.c:1010
+#: refs.c:1231
 #, c-format
-msgid "file %s is not a regular file"
-msgstr "%s n'est pas un fichier régulier"
+msgid "update_ref failed for ref '%s': %s"
+msgstr "échec de update_ref pour la réf '%s' : %s"
 
-#: trailer.c:1012
+#: refs.c:2023
 #, c-format
-msgid "file %s is not writable by user"
-msgstr "le fichier %s n'est pas inscriptible par l'utilisateur"
+msgid "multiple updates for ref '%s' not allowed"
+msgstr "mises à jour multiples pour la réf '%s' non permises"
 
-#: trailer.c:1024
-msgid "could not open temporary file"
-msgstr "impossible de créer un fichier temporaire"
+#: refs.c:2055
+msgid "ref updates forbidden inside quarantine environment"
+msgstr "mises à jour des références interdites en environnement de quarantaine"
 
-#: trailer.c:1064
+#: refs.c:2151 refs.c:2181
 #, c-format
-msgid "could not rename temporary file to %s"
-msgstr "impossible de renommer un fichier temporaire en %s"
+msgid "'%s' exists; cannot create '%s'"
+msgstr "'%s' existe ; impossible de créer '%s'"
 
-#: transport.c:116
+#: refs.c:2157 refs.c:2192
 #, c-format
-msgid "Would set upstream of '%s' to '%s' of '%s'\n"
-msgstr "Positionnerait la branche amont de '%s' sur '%s' de '%s'\n"
+msgid "cannot process '%s' and '%s' at the same time"
+msgstr "impossible de traiter '%s' et '%s' en même temps"
 
-#: transport.c:208
+#: refs/files-backend.c:1234
 #, c-format
-msgid "transport: invalid depth option '%s'"
-msgstr "transport : option de profondeur invalide '%s'"
+msgid "could not remove reference %s"
+msgstr "impossible de supprimer la référence %s"
 
-#: transport.c:584
-msgid "could not parse transport.color.* config"
-msgstr "impossible d'analyser la configuration transport.color.*"
+#: refs/files-backend.c:1248 refs/packed-backend.c:1541
+#: refs/packed-backend.c:1551
+#, c-format
+msgid "could not delete reference %s: %s"
+msgstr "Impossible de supprimer la référence %s : %s"
 
-#: transport.c:996
+#: refs/files-backend.c:1251 refs/packed-backend.c:1554
 #, c-format
-msgid ""
-"The following submodule paths contain changes that can\n"
-"not be found on any remote:\n"
-msgstr ""
-"Les chemins suivant de sous-module contiennent des modifications\n"
-"qui ne peuvent être trouvées sur aucun distant :\n"
+msgid "could not delete references: %s"
+msgstr "impossible de supprimer les références : %s"
 
-#: transport.c:1000
+#: refspec.c:137
 #, c-format
-msgid ""
-"\n"
-"Please try\n"
-"\n"
-"\tgit push --recurse-submodules=on-demand\n"
-"\n"
-"or cd to the path and use\n"
-"\n"
-"\tgit push\n"
-"\n"
-"to push them to a remote.\n"
-"\n"
-msgstr ""
-"\n"
-"Veuillez essayer\n"
-"\n"
-"\tgit push --recurse-submodules=on-demand\n"
-"\n"
-"ou bien changez de répertoire et utilisez\n"
-"\n"
-"\tgit push\n"
-"\n"
-"pour les pousser vers un serveur distant.\n"
-"\n"
+msgid "invalid refspec '%s'"
+msgstr "spécificateur de réference invalide : '%s'"
 
-#: transport.c:1008
-msgid "Aborting."
-msgstr "Abandon."
+# à priori on parle d'une branche ici
+#: ref-filter.c:42 wt-status.c:1938
+msgid "gone"
+msgstr "disparue"
 
-#: transport-helper.c:1087
+#: ref-filter.c:43
 #, c-format
-msgid "Could not read ref %s"
-msgstr "impossible de lire la réf %s"
-
-#: tree-walk.c:31
-msgid "too-short tree object"
-msgstr "objet arbre trop court"
+msgid "ahead %d"
+msgstr "en avance de %d"
 
-#: tree-walk.c:37
-msgid "malformed mode in tree entry"
-msgstr "mode invalide dans l'entrée d'arbre"
+#: ref-filter.c:44
+#, c-format
+msgid "behind %d"
+msgstr "en retard de %d"
 
-#: tree-walk.c:41
-msgid "empty filename in tree entry"
-msgstr "nom de fichier vide dans une entrée de l'arbre"
+#: ref-filter.c:45
+#, c-format
+msgid "ahead %d, behind %d"
+msgstr "en avance de %d, en retard de %d"
 
-#: tree-walk.c:113
-msgid "too-short tree file"
-msgstr "fichier arbre trop court"
+#: ref-filter.c:165
+#, c-format
+msgid "expected format: %%(color:<color>)"
+msgstr "format attendu : %%(color:<couleur>)"
 
-#: unpack-trees.c:111
+#: ref-filter.c:167
 #, c-format
-msgid ""
-"Your local changes to the following files would be overwritten by checkout:\n"
-"%%sPlease commit your changes or stash them before you switch branches."
-msgstr ""
-"Vos modifications locales aux fichiers suivants seraient écrasées par "
-"l'extraction :\n"
-"%%sVeuillez valider ou remiser vos modifications avant de basculer de "
-"branche."
+msgid "unrecognized color: %%(color:%s)"
+msgstr "couleur non reconnue : %%(color:%s)"
 
-#: unpack-trees.c:113
+#: ref-filter.c:189
 #, c-format
-msgid ""
-"Your local changes to the following files would be overwritten by checkout:\n"
-"%%s"
-msgstr ""
-"Vos modifications locales aux fichiers suivants seraient écrasées par "
-"l'extraction :\n"
-"%%s"
+msgid "Integer value expected refname:lstrip=%s"
+msgstr "Valeur entière attendue refname:lstrip=%s"
 
-#: unpack-trees.c:116
+#: ref-filter.c:193
 #, c-format
-msgid ""
-"Your local changes to the following files would be overwritten by merge:\n"
-"%%sPlease commit your changes or stash them before you merge."
-msgstr ""
-"Vos modifications locales aux fichiers suivants seraient écrasées par la "
-"fusion :\n"
-"%%sVeuillez valider ou remiser vos modifications avant la fusion."
+msgid "Integer value expected refname:rstrip=%s"
+msgstr "Valeur entière attendue refname:rstrip=%s"
 
-#: unpack-trees.c:118
+#: ref-filter.c:195
 #, c-format
-msgid ""
-"Your local changes to the following files would be overwritten by merge:\n"
-"%%s"
-msgstr ""
-"Vos modifications locales aux fichiers suivants seraient écrasées par la "
-"fusion :\n"
-"%%s"
+msgid "unrecognized %%(%s) argument: %s"
+msgstr "argument %%(%s) non reconnu : %s"
 
-#: unpack-trees.c:121
+#: ref-filter.c:250
 #, c-format
-msgid ""
-"Your local changes to the following files would be overwritten by %s:\n"
-"%%sPlease commit your changes or stash them before you %s."
-msgstr ""
-"Vos modifications locales aux fichiers suivants seraient écrasées par %s :\n"
-"%%sVeuillez valider ou remiser vos modifications avant %s."
+msgid "%%(objecttype) does not take arguments"
+msgstr "%%(objecttype) n'accepte pas d'argument"
 
-#: unpack-trees.c:123
+#: ref-filter.c:272
 #, c-format
-msgid ""
-"Your local changes to the following files would be overwritten by %s:\n"
-"%%s"
-msgstr ""
-"Vos modifications locales aux fichiers suivants seraient écrasées par %s :\n"
-"%%s"
+msgid "unrecognized %%(objectsize) argument: %s"
+msgstr "argument %%(objectsize) non reconnu : %s"
 
-#: unpack-trees.c:128
+#: ref-filter.c:280
 #, c-format
-msgid ""
-"Updating the following directories would lose untracked files in them:\n"
-"%s"
-msgstr ""
-"La mise à jour des répertoires suivants effacerait les fichiers non suivis "
-"contenus :\n"
-"%s"
+msgid "%%(deltabase) does not take arguments"
+msgstr "%%(deltabase) n'accepte pas d'argument"
 
-#: unpack-trees.c:132
+#: ref-filter.c:292
 #, c-format
-msgid ""
-"The following untracked working tree files would be removed by checkout:\n"
-"%%sPlease move or remove them before you switch branches."
-msgstr ""
-"Les fichiers suivants non suivis de la copie de travail seraient effacés par "
-"l'extraction :\n"
-"%%sVeuillez renommer ou effacer ces fichiers avant de basculer de branche."
+msgid "%%(body) does not take arguments"
+msgstr "%%(body) n'accepte pas d'argument"
 
-#: unpack-trees.c:134
+#: ref-filter.c:301
 #, c-format
-msgid ""
-"The following untracked working tree files would be removed by checkout:\n"
-"%%s"
-msgstr ""
-"Les fichiers suivants non suivis seraient effacés par l'extraction :\n"
-"%%s"
+msgid "%%(subject) does not take arguments"
+msgstr "%%(subject) n'accepte pas d'argument"
 
-#: unpack-trees.c:137
+#: ref-filter.c:323
 #, c-format
-msgid ""
-"The following untracked working tree files would be removed by merge:\n"
-"%%sPlease move or remove them before you merge."
-msgstr ""
-"Les fichiers suivants non suivis de la copie de travail seraient effacés par "
-"la fusion :\n"
-"%%sVeuillez renommer ou effacer ces fichiers avant la fusion."
+msgid "unknown %%(trailers) argument: %s"
+msgstr "argument %%(trailers) inconnu : %s"
 
-#: unpack-trees.c:139
+#: ref-filter.c:352
 #, c-format
-msgid ""
-"The following untracked working tree files would be removed by merge:\n"
-"%%s"
-msgstr ""
-"Les fichiers suivants non suivis seraient effacés par la fusion :\n"
-"%%s"
+msgid "positive value expected contents:lines=%s"
+msgstr "valeur positive attendue contents:lines=%s"
 
-#: unpack-trees.c:142
+#: ref-filter.c:354
 #, c-format
-msgid ""
-"The following untracked working tree files would be removed by %s:\n"
-"%%sPlease move or remove them before you %s."
-msgstr ""
-"Les fichiers suivants non suivis de la copie de travail seraient effacés par "
-"%s :\n"
-"%%sVeuillez renommer ou effacer ces fichiers avant %s."
+msgid "unrecognized %%(contents) argument: %s"
+msgstr "argument %%(contents) non reconnu : %s"
 
-#: unpack-trees.c:144
+#: ref-filter.c:369
 #, c-format
-msgid ""
-"The following untracked working tree files would be removed by %s:\n"
-"%%s"
-msgstr ""
-"Les fichiers suivants non suivis seraient effacés par %s :\n"
-"%%s"
+msgid "positive value expected objectname:short=%s"
+msgstr "valeur positive attendue objectname:short=%s"
 
-#: unpack-trees.c:150
+#: ref-filter.c:373
 #, c-format
-msgid ""
-"The following untracked working tree files would be overwritten by "
-"checkout:\n"
-"%%sPlease move or remove them before you switch branches."
-msgstr ""
-"Les fichiers suivants non suivis de la copie de travail seraient écrasés par "
-"l'extraction :\n"
-"%%sVeuillez renommer ou effacer ces fichiers avant de basculer de branche."
+msgid "unrecognized %%(objectname) argument: %s"
+msgstr "argument %%(objectname) non reconnu : %s"
 
-#: unpack-trees.c:152
+#: ref-filter.c:403
 #, c-format
-msgid ""
-"The following untracked working tree files would be overwritten by "
-"checkout:\n"
-"%%s"
-msgstr ""
-"Les fichiers suivants non suivis seraient écrasés par l'extraction :\n"
-"%%s"
+msgid "expected format: %%(align:<width>,<position>)"
+msgstr "format attendu : %%(align:<largeur>,<position>)"
 
-#: unpack-trees.c:155
+#: ref-filter.c:415
 #, c-format
-msgid ""
-"The following untracked working tree files would be overwritten by merge:\n"
-"%%sPlease move or remove them before you merge."
-msgstr ""
-"Les fichiers suivants non suivis de la copie de travail seraient effacés par "
-"la fusion :\n"
-"%%sVeuillez renommer ou effacer ces fichiers avant la fusion."
+msgid "unrecognized position:%s"
+msgstr "position non reconnue : %s"
 
-#: unpack-trees.c:157
+#: ref-filter.c:422
 #, c-format
-msgid ""
-"The following untracked working tree files would be overwritten by merge:\n"
-"%%s"
-msgstr ""
-"Les fichiers suivants non suivis seraient écrasés par la fusion :\n"
-"%%s"
+msgid "unrecognized width:%s"
+msgstr "largeur non reconnue : %s"
 
-#: unpack-trees.c:160
+#: ref-filter.c:431
 #, c-format
-msgid ""
-"The following untracked working tree files would be overwritten by %s:\n"
-"%%sPlease move or remove them before you %s."
-msgstr ""
-"Les fichiers suivants non suivis de la copie de travail seraient écrasés par "
-"%s :\n"
-"%%sVeuillez renommer ou effacer ces fichiers avant %s."
+msgid "unrecognized %%(align) argument: %s"
+msgstr "argument %%(align) non reconnu : %s"
 
-#: unpack-trees.c:162
+#: ref-filter.c:439
 #, c-format
-msgid ""
-"The following untracked working tree files would be overwritten by %s:\n"
-"%%s"
-msgstr ""
-"Les fichiers suivants non suivis seraient écrasés par %s :\n"
-"%%s"
+msgid "positive width expected with the %%(align) atom"
+msgstr "valeur positive attendue avec l'atome %%(align)"
 
-#: unpack-trees.c:170
+#: ref-filter.c:457
 #, c-format
-msgid "Entry '%s' overlaps with '%s'.  Cannot bind."
-msgstr "L'entrée '%s' surcharge avec '%s'. Affectation impossible."
+msgid "unrecognized %%(if) argument: %s"
+msgstr "argument %%(if) non reconnu : %s"
 
-#: unpack-trees.c:173
+#: ref-filter.c:559
 #, c-format
-msgid ""
-"Cannot update sparse checkout: the following entries are not up to date:\n"
-"%s"
-msgstr ""
-"Mise à jour d'extraction creuse impossible : les entrées suivantes ne sont "
-"pas à jour :\n"
-"%s"
+msgid "malformed field name: %.*s"
+msgstr "nom de champ malformé %.*s"
 
-#: unpack-trees.c:175
+#: ref-filter.c:586
 #, c-format
-msgid ""
-"The following working tree files would be overwritten by sparse checkout "
-"update:\n"
-"%s"
-msgstr ""
-"Les fichiers suivants de la copie de travail seraient écrasés par la mise à "
-"jour par l'extraction creuse :\n"
-"%s"
+msgid "unknown field name: %.*s"
+msgstr "nom de champ inconnu : %.*s"
 
-#: unpack-trees.c:177
+#: ref-filter.c:590
 #, c-format
 msgid ""
-"The following working tree files would be removed by sparse checkout "
-"update:\n"
-"%s"
+"not a git repository, but the field '%.*s' requires access to object data"
 msgstr ""
-"Les fichiers suivants de la copie de travail seraient supprimés par la mise "
-"à jour par extraction creuse :\n"
-"%s"
+"pas un dépôt git, mais le champ '%.*s' nécessite l'accès aux données d'objet"
 
-#: unpack-trees.c:179
+#: ref-filter.c:714
 #, c-format
-msgid ""
-"Cannot update submodule:\n"
-"%s"
-msgstr ""
-"Mise à jour impossible pour le sous-module :\n"
-"%s"
+msgid "format: %%(if) atom used without a %%(then) atom"
+msgstr "format : atome %%(if) utilisé sans un atome %%(then)"
 
-#: unpack-trees.c:262
+#: ref-filter.c:777
 #, c-format
-msgid "Aborting\n"
-msgstr "Abandon\n"
+msgid "format: %%(then) atom used without an %%(if) atom"
+msgstr "format : atome %%(then) utilisé sans un atome %%(if)"
 
-#: unpack-trees.c:344
-msgid "Checking out files"
-msgstr "Extraction des fichiers"
+#: ref-filter.c:779
+#, c-format
+msgid "format: %%(then) atom used more than once"
+msgstr "format : atome %%(then) utilisé plus d'une fois"
 
-#: urlmatch.c:163
-msgid "invalid URL scheme name or missing '://' suffix"
-msgstr "nom de schéma d'URL invalide ou suffixe '://' manquant"
+#: ref-filter.c:781
+#, c-format
+msgid "format: %%(then) atom used after %%(else)"
+msgstr "format: atome %%(then) utilisé après %%(else)"
 
-#: urlmatch.c:187 urlmatch.c:346 urlmatch.c:405
+#: ref-filter.c:809
 #, c-format
-msgid "invalid %XX escape sequence"
-msgstr "séquence d'échappement %XX invalide"
+msgid "format: %%(else) atom used without an %%(if) atom"
+msgstr "format : atome %%(else) utilisé sans un atome %%(if)"
 
-#: urlmatch.c:215
-msgid "missing host and scheme is not 'file:'"
-msgstr "hôte manquant et le schéma n'est pas 'file:'"
+#: ref-filter.c:811
+#, c-format
+msgid "format: %%(else) atom used without a %%(then) atom"
+msgstr "format : atome %%(else) utilisé sans un atome %%(then)"
 
-#: urlmatch.c:232
-msgid "a 'file:' URL may not have a port number"
-msgstr "une URL 'file:' ne peut pas contenir de numéro de port"
+#: ref-filter.c:813
+#, c-format
+msgid "format: %%(else) atom used more than once"
+msgstr "format : atome %%(else) utilisé plus d'une fois"
 
-#: urlmatch.c:247
-msgid "invalid characters in host name"
-msgstr "caractères invalides dans le nom d'hôte"
+#: ref-filter.c:828
+#, c-format
+msgid "format: %%(end) atom used without corresponding atom"
+msgstr "format : atome %%(end) utilisé sans atome correspondant"
 
-#: urlmatch.c:292 urlmatch.c:303
-msgid "invalid port number"
-msgstr "numéro de port invalide"
+#: ref-filter.c:885
+#, c-format
+msgid "malformed format string %s"
+msgstr "Chaîne de formatage mal formée %s"
 
-#: urlmatch.c:371
-msgid "invalid '..' path segment"
-msgstr "segment de chemin '..' invalide"
+#: ref-filter.c:1488
+#, c-format
+msgid "no branch, rebasing %s"
+msgstr "aucune branche, rebasage de %s"
 
-#: worktree.c:245 builtin/am.c:2147
+#: ref-filter.c:1491
 #, c-format
-msgid "failed to read '%s'"
-msgstr "échec de la lecture de '%s'"
+msgid "no branch, rebasing detached HEAD %s"
+msgstr "aucune branche, rebasage de la HEAD détachée %s"
 
-#: worktree.c:291
+#: ref-filter.c:1494
 #, c-format
-msgid "'%s' at main working tree is not the repository directory"
-msgstr ""
-"'%s' dans l'arbre de travail principal n'est pas le répertoire de dépôt"
+msgid "no branch, bisect started on %s"
+msgstr "aucune branche, bisect a démarré sur %s"
 
-#: worktree.c:302
+#: ref-filter.c:1504
+msgid "no branch"
+msgstr "aucune branche"
+
+#: ref-filter.c:1540 ref-filter.c:1749
 #, c-format
-msgid "'%s' file does not contain absolute path to the working tree location"
-msgstr ""
-"le fichier '%s' ne contient pas de chemin absolu à l'emplacement de l'arbre "
-"de travail"
+msgid "missing object %s for %s"
+msgstr "objet manquant %s pour %s"
 
-#: worktree.c:314
+#: ref-filter.c:1550
 #, c-format
-msgid "'%s' does not exist"
-msgstr "'%s' n'existe pas"
+msgid "parse_object_buffer failed on %s for %s"
+msgstr "échec de parse_object_buffer sur %s pour %s"
 
-#: worktree.c:320
+#: ref-filter.c:2004
 #, c-format
-msgid "'%s' is not a .git file, error code %d"
-msgstr "'%s' n'est pas un fichier .git, code d'erreur %d"
+msgid "malformed object at '%s'"
+msgstr "objet malformé à '%s'"
 
-#: worktree.c:328
+#: ref-filter.c:2093
 #, c-format
-msgid "'%s' does not point back to '%s'"
-msgstr "'%s' ne pointe pas en retour sur '%s'"
+msgid "ignoring ref with broken name %s"
+msgstr "réf avec un nom cassé %s ignoré"
 
-#: wrapper.c:223 wrapper.c:393
+#: ref-filter.c:2389
 #, c-format
-msgid "could not open '%s' for reading and writing"
-msgstr "impossible d'ouvrir '%s' en lecture/écriture"
+msgid "format: %%(end) atom missing"
+msgstr "format: atome %%(end) manquant"
 
-#: wrapper.c:227 wrapper.c:397 builtin/am.c:320 builtin/am.c:770
-#: builtin/am.c:862 builtin/merge.c:1043
+#: ref-filter.c:2489
 #, c-format
-msgid "could not open '%s' for reading"
-msgstr "impossible d'ouvrir '%s' en lecture"
+msgid "option `%s' is incompatible with --merged"
+msgstr "l'option « %s » est incompatible avec --merged"
 
-#: wrapper.c:424 wrapper.c:624
+#: ref-filter.c:2492
 #, c-format
-msgid "unable to access '%s'"
-msgstr "impossible d'accéder à '%s'"
+msgid "option `%s' is incompatible with --no-merged"
+msgstr "l'option « %s » est incompatible avec --no-merged"
 
-#: wrapper.c:632
-msgid "unable to get current working directory"
-msgstr "impossible d'accéder au répertoire de travail courant"
+#: ref-filter.c:2502
+#, c-format
+msgid "malformed object name %s"
+msgstr "nom d'objet malformé %s"
 
-#: wt-status.c:154
-msgid "Unmerged paths:"
-msgstr "Chemins non fusionnés :"
+#: ref-filter.c:2507
+#, c-format
+msgid "option `%s' must point to a commit"
+msgstr "l'option '%s' doit pointer sur un commit"
 
-#: wt-status.c:181 wt-status.c:208
+#: remote.c:366
 #, c-format
-msgid "  (use \"git reset %s <file>...\" to unstage)"
-msgstr "  (utilisez \"git reset %s <fichier>...\" pour désindexer)"
+msgid "config remote shorthand cannot begin with '/': %s"
+msgstr ""
+"un raccourci de configuration de distant ne peut pas commencer par '/' : %s"
 
-#: wt-status.c:183 wt-status.c:210
-msgid "  (use \"git rm --cached <file>...\" to unstage)"
-msgstr "  (utilisez \"git rm --cached <fichier>...\" pour désindexer)"
+#: remote.c:413
+msgid "more than one receivepack given, using the first"
+msgstr "plus d'un receivepack fournis, utilisation du premier"
 
-#: wt-status.c:187
-msgid "  (use \"git add <file>...\" to mark resolution)"
-msgstr "  (utilisez \"git add <fichier>...\" pour marquer comme résolu)"
+#: remote.c:421
+msgid "more than one uploadpack given, using the first"
+msgstr "plus d'un uploadpack fournis, utilisation du premier"
 
-#: wt-status.c:189 wt-status.c:193
-msgid "  (use \"git add/rm <file>...\" as appropriate to mark resolution)"
-msgstr ""
-"  (utilisez \"git add/rm <fichier>...\" si nécessaire pour marquer comme "
-"résolu)"
+#: remote.c:611
+#, c-format
+msgid "Cannot fetch both %s and %s to %s"
+msgstr "Impossible de récupérer à la fois %s et %s pour %s"
 
-#: wt-status.c:191
-msgid "  (use \"git rm <file>...\" to mark resolution)"
-msgstr "  (utilisez \"git rm <fichier>...\" pour marquer comme résolu)"
+#: remote.c:615
+#, c-format
+msgid "%s usually tracks %s, not %s"
+msgstr "%s suit habituellement %s, pas %s"
 
-#: wt-status.c:202 wt-status.c:1015
-msgid "Changes to be committed:"
-msgstr "Modifications qui seront validées :"
+#: remote.c:619
+#, c-format
+msgid "%s tracks both %s and %s"
+msgstr "%s suit à la fois %s et %s"
 
-#: wt-status.c:220 wt-status.c:1024
-msgid "Changes not staged for commit:"
-msgstr "Modifications qui ne seront pas validées :"
+#: remote.c:687
+#, c-format
+msgid "key '%s' of pattern had no '*'"
+msgstr "la clé '%s' du modèle n'a pas de '*'"
 
-#: wt-status.c:224
-msgid "  (use \"git add <file>...\" to update what will be committed)"
-msgstr ""
-"  (utilisez \"git add <fichier>...\" pour mettre à jour ce qui sera validé)"
+#: remote.c:697
+#, c-format
+msgid "value '%s' of pattern has no '*'"
+msgstr "la valeur '%s' du modèle n'a pas de '*'"
 
-#: wt-status.c:226
-msgid "  (use \"git add/rm <file>...\" to update what will be committed)"
+#: remote.c:1003
+#, c-format
+msgid "src refspec %s does not match any"
 msgstr ""
-"  (utilisez \"git add/rm <fichier>...\" pour mettre à jour ce qui sera "
-"validé)"
+"le spécificateur de référence source %s ne correspond à aucune référence"
 
-#: wt-status.c:227
-msgid ""
-"  (use \"git checkout -- <file>...\" to discard changes in working directory)"
+#: remote.c:1008
+#, c-format
+msgid "src refspec %s matches more than one"
 msgstr ""
-"  (utilisez \"git checkout -- <fichier>...\" pour annuler les modifications "
-"dans la copie de travail)"
+"le spécificateur de référence source %s correspond à plus d'une référence"
 
-#: wt-status.c:229
-msgid "  (commit or discard the untracked or modified content in submodules)"
+#. TRANSLATORS: "matches '%s'%" is the <dst> part of "git push
+#. <remote> <src>:<dst>" push, and "being pushed ('%s')" is
+#. the <src>.
+#.
+#: remote.c:1023
+#, c-format
+msgid ""
+"The destination you provided is not a full refname (i.e.,\n"
+"starting with \"refs/\"). We tried to guess what you meant by:\n"
+"\n"
+"- Looking for a ref that matches '%s' on the remote side.\n"
+"- Checking if the <src> being pushed ('%s')\n"
+"  is a ref in \"refs/{heads,tags}/\". If so we add a corresponding\n"
+"  refs/{heads,tags}/ prefix on the remote side.\n"
+"\n"
+"Neither worked, so we gave up. You must fully qualify the ref."
 msgstr ""
-"  (valider ou annuler le contenu non suivi ou modifié dans les sous-modules)"
+"La destination que vous avez fournie n'est pas un nom de référence complète\n"
+"(c'est-à-dire commençant par \"ref/\"). Essai d'approximation par :\n"
+"\n"
+"- Recherche d'une référence qui correspond à '%s' sur le serveur distant.\n"
+"- Vérification si la <source> en cours de poussée ('%s')\n"
+"  est une référence dans \"refs/{heads,tags}/\". Si oui, ajout du préfixe\n"
+"  refs/{heads,tags}/ correspondant du côté distant.\n"
+"\n"
+"Aucune n'a fonctionné, donc abandon. Veuillez spécifier une référence "
+"totalement qualifiée."
 
-#: wt-status.c:241
+#: remote.c:1043
 #, c-format
-msgid "  (use \"git %s <file>...\" to include in what will be committed)"
+msgid ""
+"The <src> part of the refspec is a commit object.\n"
+"Did you mean to create a new branch by pushing to\n"
+"'%s:refs/heads/%s'?"
 msgstr ""
-"  (utilisez \"git %s <fichier>...\" pour inclure dans ce qui sera validé)"
+"la partie <source> du spécificateur de référence est un objet commit.\n"
+"Souhaitiez-vous créer une nouvelle branche en poussant sur\n"
+"'%s:refs/heads/%s' ?"
 
-#: wt-status.c:256
-msgid "both deleted:"
-msgstr "supprimé des deux côtés :"
+#: remote.c:1048
+#, c-format
+msgid ""
+"The <src> part of the refspec is a tag object.\n"
+"Did you mean to create a new tag by pushing to\n"
+"'%s:refs/tags/%s'?"
+msgstr ""
+"la partie <source> du spécificateur de référence est un objet étiquette.\n"
+"Souhaitiez-vous créer une nouvelle étiquette en poussant sur\n"
+"'%s:refs/tags/%s' ?"
 
-#: wt-status.c:258
-msgid "added by us:"
-msgstr "ajouté par nous :"
+#: remote.c:1053
+#, c-format
+msgid ""
+"The <src> part of the refspec is a tree object.\n"
+"Did you mean to tag a new tree by pushing to\n"
+"'%s:refs/tags/%s'?"
+msgstr ""
+"la partie <source> du spécificateur de référence est un objet arbre.\n"
+"Souhaitiez-vous créer un nouvel arbre en poussant sur\n"
+"'%s:refs/tags/%s' ?"
 
-#: wt-status.c:260
-msgid "deleted by them:"
-msgstr "supprimé par eux :"
+#: remote.c:1058
+#, c-format
+msgid ""
+"The <src> part of the refspec is a blob object.\n"
+"Did you mean to tag a new blob by pushing to\n"
+"'%s:refs/tags/%s'?"
+msgstr ""
+"la partie <source> du spécificateur de référence est un objet blob.\n"
+"Souhaitiez-vous créer un nouveau blob en poussant sur\n"
+"'%s:refs/tags/%s' ?"
 
-#: wt-status.c:262
-msgid "added by them:"
-msgstr "ajouté par eux :"
+#: remote.c:1094
+#, c-format
+msgid "%s cannot be resolved to branch"
+msgstr "'%s' ne peut pas être résolue comme une branche"
 
-#: wt-status.c:264
-msgid "deleted by us:"
-msgstr "supprimé par nous :"
+#: remote.c:1105
+#, c-format
+msgid "unable to delete '%s': remote ref does not exist"
+msgstr "suppression d '%s' impossible : la référence distante n'existe pas"
 
-#: wt-status.c:266
-msgid "both added:"
-msgstr "ajouté de deux côtés :"
+#: remote.c:1117
+#, c-format
+msgid "dst refspec %s matches more than one"
+msgstr ""
+"le spécificateur de référence dst %s correspond à plus d'un spécificateur de "
+"références"
 
-#: wt-status.c:268
-msgid "both modified:"
-msgstr "modifié des deux côtés :"
+#: remote.c:1124
+#, c-format
+msgid "dst ref %s receives from more than one src"
+msgstr "le spécificateur de référence dst %s reçoit depuis plus d'une source"
 
-#: wt-status.c:278
-msgid "new file:"
-msgstr "nouveau fichier :"
+#: remote.c:1627 remote.c:1728
+msgid "HEAD does not point to a branch"
+msgstr "HEAD ne pointe pas sur une branche"
 
-#: wt-status.c:280
-msgid "copied:"
-msgstr "copié :"
+#: remote.c:1636
+#, c-format
+msgid "no such branch: '%s'"
+msgstr "pas de branche '%s'"
 
-#: wt-status.c:282
-msgid "deleted:"
-msgstr "supprimé :"
+#: remote.c:1639
+#, c-format
+msgid "no upstream configured for branch '%s'"
+msgstr "aucune branche amont configurée pour la branche '%s'"
 
-#: wt-status.c:284
-msgid "modified:"
-msgstr "modifié :"
+#: remote.c:1645
+#, c-format
+msgid "upstream branch '%s' not stored as a remote-tracking branch"
+msgstr "la branche amont '%s' n'est pas stockée comme branche de suivi"
 
-#: wt-status.c:286
-msgid "renamed:"
-msgstr "renommé :"
+#: remote.c:1660
+#, c-format
+msgid "push destination '%s' on remote '%s' has no local tracking branch"
+msgstr ""
+"la destination de poussée '%s' sur le serveur distant '%s' n'a pas de "
+"branche locale de suivi"
 
-#: wt-status.c:288
-msgid "typechange:"
-msgstr "modif. type :"
+#: remote.c:1672
+#, c-format
+msgid "branch '%s' has no remote for pushing"
+msgstr "la branche '%s' n'a aucune branche distante de poussée"
 
-#: wt-status.c:290
-msgid "unknown:"
-msgstr "inconnu :"
+#: remote.c:1682
+#, c-format
+msgid "push refspecs for '%s' do not include '%s'"
+msgstr "les références de spec pour '%s' n'incluent pas '%s'"
 
-#: wt-status.c:292
-msgid "unmerged:"
-msgstr "non fusionné :"
+#: remote.c:1695
+msgid "push has no destination (push.default is 'nothing')"
+msgstr "la poussée n'a pas de destination (push.default vaut 'nothing')"
 
-#: wt-status.c:372
-msgid "new commits, "
-msgstr "nouveaux commits, "
+#: remote.c:1717
+msgid "cannot resolve 'simple' push to a single destination"
+msgstr ""
+"impossible de résoudre une poussée 'simple' pour une destination unique"
 
-#: wt-status.c:374
-msgid "modified content, "
-msgstr "contenu modifié, "
+#: remote.c:1843
+#, c-format
+msgid "couldn't find remote ref %s"
+msgstr "impossible de trouver la référence distante %s"
 
-#: wt-status.c:376
-msgid "untracked content, "
-msgstr "contenu non suivi, "
+#: remote.c:1856
+#, c-format
+msgid "* Ignoring funny ref '%s' locally"
+msgstr "* Référence bizarre '%s' ignorée localement"
 
-#: wt-status.c:853
+#: remote.c:2019
 #, c-format
-msgid "Your stash currently has %d entry"
-msgid_plural "Your stash currently has %d entries"
-msgstr[0] "Votre remisage contient actuellement %d entrée"
-msgstr[1] "Votre remisage contient actuellement %d entrées"
+msgid "Your branch is based on '%s', but the upstream is gone.\n"
+msgstr "Votre branche est basée sur '%s', mais la branche amont a disparu.\n"
 
-#: wt-status.c:885
-msgid "Submodules changed but not updated:"
-msgstr "Sous-modules modifiés mais non mis à jour :"
+#: remote.c:2023
+msgid "  (use \"git branch --unset-upstream\" to fixup)\n"
+msgstr "  (utilisez \"git branch --unset-upstream\" pour corriger)\n"
 
-#: wt-status.c:887
-msgid "Submodule changes to be committed:"
-msgstr "Changements du sous-module à valider :"
+#: remote.c:2026
+#, c-format
+msgid "Your branch is up to date with '%s'.\n"
+msgstr "Votre branche est à jour avec '%s'.\n"
 
-#: wt-status.c:969
-msgid ""
-"Do not modify or remove the line above.\n"
-"Everything below it will be ignored."
-msgstr ""
-"Ne touchez pas à la ligne ci-dessus.\n"
-"Tout ce qui suit sera éliminé."
+#: remote.c:2030
+#, c-format
+msgid "Your branch and '%s' refer to different commits.\n"
+msgstr "Votre branche et '%s' font référence à des commits différents.\n"
 
-#: wt-status.c:1084
-msgid "You have unmerged paths."
-msgstr "Vous avez des chemins non fusionnés."
+#: remote.c:2033
+#, c-format
+msgid "  (use \"%s\" for details)\n"
+msgstr "  (utilisez \"%s\" pour plus de détails)\n"
 
-#: wt-status.c:1087
-msgid "  (fix conflicts and run \"git commit\")"
-msgstr "  (réglez les conflits puis lancez \"git commit\")"
+#: remote.c:2037
+#, c-format
+msgid "Your branch is ahead of '%s' by %d commit.\n"
+msgid_plural "Your branch is ahead of '%s' by %d commits.\n"
+msgstr[0] "Votre branche est en avance sur '%s' de %d commit.\n"
+msgstr[1] "Votre branche est en avance sur '%s' de %d commits.\n"
 
-#: wt-status.c:1089
-msgid "  (use \"git merge --abort\" to abort the merge)"
-msgstr "  (utilisez \"git merge --abort\" pour annuler la fusion)"
+#: remote.c:2043
+msgid "  (use \"git push\" to publish your local commits)\n"
+msgstr "  (utilisez \"git push\" pour publier vos commits locaux)\n"
 
-#: wt-status.c:1094
-msgid "All conflicts fixed but you are still merging."
-msgstr "Tous les conflits sont réglés mais la fusion n'est pas terminée."
+#: remote.c:2046
+#, c-format
+msgid "Your branch is behind '%s' by %d commit, and can be fast-forwarded.\n"
+msgid_plural ""
+"Your branch is behind '%s' by %d commits, and can be fast-forwarded.\n"
+msgstr[0] ""
+"Votre branche est en retard sur '%s' de %d commit, et peut être mise à jour "
+"en avance rapide.\n"
+msgstr[1] ""
+"Votre branche est en retard sur '%s' de %d commits, et peut être mise à jour "
+"en avance rapide.\n"
 
-#: wt-status.c:1097
-msgid "  (use \"git commit\" to conclude merge)"
-msgstr "  (utilisez \"git commit\" pour terminer la fusion)"
+#: remote.c:2054
+msgid "  (use \"git pull\" to update your local branch)\n"
+msgstr "  (utilisez \"git pull\" pour mettre à jour votre branche locale)\n"
 
-#: wt-status.c:1107
-msgid "You are in the middle of an am session."
-msgstr "Vous êtes au milieu d'une session am."
+#: remote.c:2057
+#, c-format
+msgid ""
+"Your branch and '%s' have diverged,\n"
+"and have %d and %d different commit each, respectively.\n"
+msgid_plural ""
+"Your branch and '%s' have diverged,\n"
+"and have %d and %d different commits each, respectively.\n"
+msgstr[0] ""
+"Votre branche et '%s' ont divergé,\n"
+"et ont %d et %d commit différent chacune respectivement.\n"
+msgstr[1] ""
+"Votre branche et '%s' ont divergé,\n"
+"et ont %d et %d commits différents chacune respectivement.\n"
 
-#: wt-status.c:1110
-msgid "The current patch is empty."
-msgstr "Le patch actuel est vide."
+#: remote.c:2067
+msgid "  (use \"git pull\" to merge the remote branch into yours)\n"
+msgstr ""
+"  (utilisez \"git pull\" pour fusionner la branche distante dans la vôtre)\n"
 
-#: wt-status.c:1114
-msgid "  (fix conflicts and then run \"git am --continue\")"
-msgstr "  (réglez les conflits puis lancez \"git am --continue\")"
+#: remote.c:2250
+#, c-format
+msgid "cannot parse expected object name '%s'"
+msgstr "impossible d'analyser le nom attendu d'objet '%s'"
 
-#: wt-status.c:1116
-msgid "  (use \"git am --skip\" to skip this patch)"
-msgstr "  (utilisez \"git am --skip\" pour sauter ce patch)"
+#: replace-object.c:21
+#, c-format
+msgid "bad replace ref name: %s"
+msgstr "mauvaise références de remplacement : %s"
 
-#: wt-status.c:1118
-msgid "  (use \"git am --abort\" to restore the original branch)"
-msgstr "  (utilisez \"git am --abort\" pour restaurer la branche d'origine)"
+#: replace-object.c:30
+#, c-format
+msgid "duplicate replace ref: %s"
+msgstr "référence de remplacement dupliquée : %s"
 
-#: wt-status.c:1250
-msgid "git-rebase-todo is missing."
-msgstr "git-rebase-todo est manquant."
+#: replace-object.c:73
+#, c-format
+msgid "replace depth too high for object %s"
+msgstr "profondeur de remplacement trop grande pour l'objet %s"
 
-#: wt-status.c:1252
-msgid "No commands done."
-msgstr "Aucune commande réalisée."
+#: rerere.c:217 rerere.c:226 rerere.c:229
+msgid "corrupt MERGE_RR"
+msgstr "MERGE_RR corrompu"
+
+#: rerere.c:264 rerere.c:269
+msgid "unable to write rerere record"
+msgstr "impossible d'écrire l'enregistrement rerere"
 
-#: wt-status.c:1255
+#: rerere.c:495
 #, c-format
-msgid "Last command done (%d command done):"
-msgid_plural "Last commands done (%d commands done):"
-msgstr[0] "Dernière commande effectuée (%d commande effectuée) :"
-msgstr[1] "Dernières commandes effectuées (%d commandes effectuées) :"
+msgid "there were errors while writing '%s' (%s)"
+msgstr "il y a eu des erreurs à l'écriture de '%s' (%s)"
 
-#: wt-status.c:1266
+#: rerere.c:498
 #, c-format
-msgid "  (see more in file %s)"
-msgstr "  (voir plus dans le fichier %s)"
+msgid "failed to flush '%s'"
+msgstr "échec du flush de '%s'"
 
-#: wt-status.c:1271
-msgid "No commands remaining."
-msgstr "Aucune commande restante."
+#: rerere.c:503 rerere.c:1039
+#, c-format
+msgid "could not parse conflict hunks in '%s'"
+msgstr "impossible d'analyser la section en conflit dans '%s'"
 
-#: wt-status.c:1274
+#: rerere.c:684
 #, c-format
-msgid "Next command to do (%d remaining command):"
-msgid_plural "Next commands to do (%d remaining commands):"
-msgstr[0] "Prochaine commande à effectuer (%d commande restante) :"
-msgstr[1] "Prochaines commandes à effectuer (%d commandes restantes) :"
+msgid "failed utime() on '%s'"
+msgstr "échec de utime() sur '%s'"
 
-#: wt-status.c:1282
-msgid "  (use \"git rebase --edit-todo\" to view and edit)"
-msgstr "  (utilisez \"git rebase --edit-todo\" pour voir et éditer)"
+#: rerere.c:694
+#, c-format
+msgid "writing '%s' failed"
+msgstr "échec de l'écriture de '%s'"
 
-#: wt-status.c:1295
+#: rerere.c:714
 #, c-format
-msgid "You are currently rebasing branch '%s' on '%s'."
-msgstr "Vous êtes en train de rebaser la branche '%s' sur '%s'."
+msgid "Staged '%s' using previous resolution."
+msgstr "'%s' indexé en utilisant la résolution pré-existante."
 
-#: wt-status.c:1300
-msgid "You are currently rebasing."
-msgstr "Vous êtes en train de rebaser."
+#: rerere.c:753
+#, c-format
+msgid "Recorded resolution for '%s'."
+msgstr "Résolution enregistrée pour '%s'."
 
-#: wt-status.c:1314
-msgid "  (fix conflicts and then run \"git rebase --continue\")"
-msgstr "  (réglez les conflits puis lancez \"git rebase --continue\")"
+#: rerere.c:788
+#, c-format
+msgid "Resolved '%s' using previous resolution."
+msgstr "'%s' résolu en utilisant la résolution pré-existante."
 
-#: wt-status.c:1316
-msgid "  (use \"git rebase --skip\" to skip this patch)"
-msgstr "  (utilisez \"git rebase --skip\" pour sauter ce patch)"
+#: rerere.c:803
+#, c-format
+msgid "cannot unlink stray '%s'"
+msgstr "impossible de délier '%s' qui est errant"
 
-#: wt-status.c:1318
-msgid "  (use \"git rebase --abort\" to check out the original branch)"
-msgstr "  (utilisez \"git rebase --abort\" pour extraire la branche d'origine)"
+#: rerere.c:807
+#, c-format
+msgid "Recorded preimage for '%s'"
+msgstr "Pré-image enregistrée pour '%s'"
 
-#: wt-status.c:1324
-msgid "  (all conflicts fixed: run \"git rebase --continue\")"
-msgstr "  (tous les conflits sont réglés : lancez \"git rebase --continue\")"
+#: rerere.c:881 submodule.c:2067 builtin/log.c:1871
+#: builtin/submodule--helper.c:1436 builtin/submodule--helper.c:1448
+#, c-format
+msgid "could not create directory '%s'"
+msgstr "impossible de créer le répertoire '%s'"
 
-#: wt-status.c:1328
+#: rerere.c:1057
 #, c-format
-msgid ""
-"You are currently splitting a commit while rebasing branch '%s' on '%s'."
-msgstr ""
-"Vous êtes actuellement en train de fractionner un commit pendant un rebasage "
-"de la branche '%s' sur '%s'."
+msgid "failed to update conflicted state in '%s'"
+msgstr "échec de la mise à jour de l'état en conflit dans '%s'"
 
-#: wt-status.c:1333
-msgid "You are currently splitting a commit during a rebase."
-msgstr ""
-"Vous êtes actuellement en train de fractionner un commit pendant un rebasage."
+#: rerere.c:1068 rerere.c:1075
+#, c-format
+msgid "no remembered resolution for '%s'"
+msgstr "Aucune résolution enregistrée pour '%s'"
 
-#: wt-status.c:1336
-msgid "  (Once your working directory is clean, run \"git rebase --continue\")"
-msgstr ""
-"  (Une fois la copie de travail nettoyée, lancez \"git rebase --continue\")"
+#: rerere.c:1077
+#, c-format
+msgid "cannot unlink '%s'"
+msgstr "impossible de délier '%s'"
 
-#: wt-status.c:1340
+#: rerere.c:1087
 #, c-format
-msgid "You are currently editing a commit while rebasing branch '%s' on '%s'."
-msgstr ""
-"Vous êtes actuellement en train d'éditer un commit pendant un rebasage de la "
-"branche '%s' sur '%s'."
+msgid "Updated preimage for '%s'"
+msgstr "Pré-image mise à jour pour '%s'"
 
-#: wt-status.c:1345
-msgid "You are currently editing a commit during a rebase."
-msgstr ""
-"Vous êtes actuellement en train d'éditer un commit pendant un rebasage."
+#: rerere.c:1096
+#, c-format
+msgid "Forgot resolution for '%s'\n"
+msgstr "Résolution  pour '%s' oubliée\n"
 
-#: wt-status.c:1348
-msgid "  (use \"git commit --amend\" to amend the current commit)"
-msgstr "  (utilisez \"git commit --amend\" pour corriger le commit actuel)"
+#: rerere.c:1199
+msgid "unable to open rr-cache directory"
+msgstr "impossible d'ouvrir le répertoire rr-cache"
 
-#: wt-status.c:1350
-msgid ""
-"  (use \"git rebase --continue\" once you are satisfied with your changes)"
-msgstr ""
-"  (utilisez \"git rebase --continue\" quand vous avez effectué toutes vos "
-"modifications)"
+#: revision.c:2497
+msgid "your current branch appears to be broken"
+msgstr "votre branche actuelle semble cassée"
 
-#: wt-status.c:1360
+#: revision.c:2500
 #, c-format
-msgid "You are currently cherry-picking commit %s."
-msgstr "Vous êtes actuellement en train de picorer le commit %s."
+msgid "your current branch '%s' does not have any commits yet"
+msgstr "votre branche actuelle '%s' ne contient encore aucun commit"
 
-#: wt-status.c:1365
-msgid "  (fix conflicts and run \"git cherry-pick --continue\")"
-msgstr "  (réglez les conflits puis lancez \"git cherry-pick --continue\")"
+#: revision.c:2708
+msgid "--first-parent is incompatible with --bisect"
+msgstr "--first-parent est incompatible avec --bisect"
 
-#: wt-status.c:1368
-msgid "  (all conflicts fixed: run \"git cherry-pick --continue\")"
-msgstr ""
-"  (tous les conflits sont réglés : lancez \"git cherry-pick --continue\")"
+#: revision.c:2712
+msgid "-L does not yet support diff formats besides -p and -s"
+msgstr "-L ne supporte pas encore les formats de diff autres que -p et -s"
 
-#: wt-status.c:1370
-msgid "  (use \"git cherry-pick --abort\" to cancel the cherry-pick operation)"
-msgstr "  (utilisez \"git cherry-pick --abort\" pour annuler le picorage)"
+#: run-command.c:762
+msgid "open /dev/null failed"
+msgstr "échec de l'ouverture de /dev/null"
 
-#: wt-status.c:1379
+#: run-command.c:1268
 #, c-format
-msgid "You are currently reverting commit %s."
-msgstr "Vous êtes actuellement en train de rétablir le commit %s."
-
-#: wt-status.c:1384
-msgid "  (fix conflicts and run \"git revert --continue\")"
-msgstr "  (réglez les conflits puis lancez \"git revert --continue\")"
-
-#: wt-status.c:1387
-msgid "  (all conflicts fixed: run \"git revert --continue\")"
-msgstr "  (tous les conflits sont réglés : lancez \"git revert --continue\")"
-
-#: wt-status.c:1389
-msgid "  (use \"git revert --abort\" to cancel the revert operation)"
-msgstr "  (utilisez \"git revert --abort\" pour annuler le rétablissement)"
+msgid "cannot create async thread: %s"
+msgstr "impossible de créer un fil asynchrone : %s"
 
-#: wt-status.c:1400
+#: run-command.c:1332
 #, c-format
-msgid "You are currently bisecting, started from branch '%s'."
-msgstr "Vous êtes en cours de bissection, depuis la branche '%s'."
-
-#: wt-status.c:1404
-msgid "You are currently bisecting."
-msgstr "Vous êtes en cours de bissection."
-
-#: wt-status.c:1407
-msgid "  (use \"git bisect reset\" to get back to the original branch)"
-msgstr "  (utilisez \"git bisect reset\" pour revenir à la branche d'origine)"
-
-#: wt-status.c:1604
-msgid "On branch "
-msgstr "Sur la branche "
+msgid ""
+"The '%s' hook was ignored because it's not set as executable.\n"
+"You can disable this warning with `git config advice.ignoredHook false`."
+msgstr ""
+"Le crochet '%s' a été ignoré parce qu'il n'est pas marqué comme exécutable.\n"
+"Vous pouvez désactiver cet avertissement avec `git config advice.ignoredHook "
+"false`."
 
-#: wt-status.c:1610
-msgid "interactive rebase in progress; onto "
-msgstr "rebasage interactif en cours ; sur "
+#: send-pack.c:144
+msgid "unexpected flush packet while reading remote unpack status"
+msgstr ""
+"paquet de nettoyage inattendu pendant la lecture de l'état de dépaquetage "
+"distant"
 
-#: wt-status.c:1612
-msgid "rebase in progress; onto "
-msgstr "rebasage en cours ; sur "
+#: send-pack.c:146
+#, c-format
+msgid "unable to parse remote unpack status: %s"
+msgstr "impossible d'analyser l'état de dépaquetage distant : %s"
 
-#: wt-status.c:1617
-msgid "HEAD detached at "
-msgstr "HEAD détachée sur "
+#: send-pack.c:148
+#, c-format
+msgid "remote unpack failed: %s"
+msgstr "le dépaquetage a échoué : %s"
 
-#: wt-status.c:1619
-msgid "HEAD detached from "
-msgstr "HEAD détachée depuis "
+#: send-pack.c:309
+msgid "failed to sign the push certificate"
+msgstr "impossible de signer le certificat de poussée"
 
-#: wt-status.c:1622
-msgid "Not currently on any branch."
-msgstr "Actuellement sur aucun branche."
+#: send-pack.c:423
+msgid "the receiving end does not support --signed push"
+msgstr "Le receveur ne gère pas les poussées avec --signed"
 
-#: wt-status.c:1642
-msgid "Initial commit"
-msgstr "Validation initiale"
+#: send-pack.c:425
+msgid ""
+"not sending a push certificate since the receiving end does not support --"
+"signed push"
+msgstr ""
+"pas d'envoi de certificat de poussée car le receveur ne gère pas les "
+"poussées avec --signed"
 
-#: wt-status.c:1643
-msgid "No commits yet"
-msgstr "Aucun commit"
+#: send-pack.c:437
+msgid "the receiving end does not support --atomic push"
+msgstr "Le receveur ne gère pas les poussées avec --atomic"
 
-#: wt-status.c:1657
-msgid "Untracked files"
-msgstr "Fichiers non suivis"
+#: send-pack.c:442
+msgid "the receiving end does not support push options"
+msgstr "Le receveur ne gère pas les options de poussées"
 
-#: wt-status.c:1659
-msgid "Ignored files"
-msgstr "Fichiers ignorés"
+#: sequencer.c:189
+#, c-format
+msgid "invalid commit message cleanup mode '%s'"
+msgstr "mode de nettoyage invalide de message de validation '%s'"
 
-#: wt-status.c:1663
+#: sequencer.c:294
 #, c-format
-msgid ""
-"It took %.2f seconds to enumerate untracked files. 'status -uno'\n"
-"may speed it up, but you have to be careful not to forget to add\n"
-"new files yourself (see 'git help status')."
-msgstr ""
-"L'énumération des fichiers non suivis a duré %.2f secondes. 'status -uno'\n"
-"peut l'accélérer, mais vous devez alors faire attention à ne pas\n"
-"oublier d'ajouter les nouveaux fichiers par vous-même (voir 'git help "
-"status')."
+msgid "could not delete '%s'"
+msgstr "Impossible de supprimer '%s'"
 
-#: wt-status.c:1669
+#: sequencer.c:313 builtin/rebase.c:781 builtin/rebase.c:1706 builtin/rm.c:369
 #, c-format
-msgid "Untracked files not listed%s"
-msgstr "Fichiers non suivis non affichés%s"
+msgid "could not remove '%s'"
+msgstr "impossible de supprimer '%s'"
 
-#: wt-status.c:1671
-msgid " (use -u option to show untracked files)"
-msgstr " (utilisez -u pour afficher les fichiers non suivis)"
+#: sequencer.c:323
+msgid "revert"
+msgstr "revert"
 
-#: wt-status.c:1677
-msgid "No changes"
-msgstr "Aucune modification"
+#: sequencer.c:325
+msgid "cherry-pick"
+msgstr "cherry-pick"
 
-#: wt-status.c:1682
-#, c-format
-msgid "no changes added to commit (use \"git add\" and/or \"git commit -a\")\n"
-msgstr ""
-"aucune modification n'a été ajoutée à la validation (utilisez \"git add\" ou "
-"\"git commit -a\")\n"
+#: sequencer.c:327
+msgid "rebase -i"
+msgstr "rebase -i"
 
-#: wt-status.c:1685
+#: sequencer.c:329
 #, c-format
-msgid "no changes added to commit\n"
-msgstr "aucune modification ajoutée à la validation\n"
+msgid "unknown action: %d"
+msgstr "action inconnue : %d"
 
-#: wt-status.c:1688
-#, c-format
+#: sequencer.c:387
 msgid ""
-"nothing added to commit but untracked files present (use \"git add\" to "
-"track)\n"
+"after resolving the conflicts, mark the corrected paths\n"
+"with 'git add <paths>' or 'git rm <paths>'"
 msgstr ""
-"aucune modification ajoutée à la validation mais des fichiers non suivis "
-"sont présents (utilisez \"git add\" pour les suivre)\n"
+"après résolution des conflits, marquez les chemins corrigés\n"
+"avec 'git add <chemins>' ou 'git rm <chemins>'"
 
-#: wt-status.c:1691
-#, c-format
-msgid "nothing added to commit but untracked files present\n"
+#: sequencer.c:390
+msgid ""
+"after resolving the conflicts, mark the corrected paths\n"
+"with 'git add <paths>' or 'git rm <paths>'\n"
+"and commit the result with 'git commit'"
 msgstr ""
-"aucune modification ajoutée à la validation mais des fichiers non suivis "
-"sont présents\n"
+"après résolution des conflits, marquez les chemins corrigés\n"
+"avec 'git add <chemins>' ou 'git rm <chemins>'\n"
+"puis validez le résultat avec 'git commit'"
 
-#: wt-status.c:1694
+#: sequencer.c:403 sequencer.c:2993
 #, c-format
-msgid "nothing to commit (create/copy files and use \"git add\" to track)\n"
-msgstr ""
-"rien à valider (créez/copiez des fichiers et utilisez \"git add\" pour les "
-"suivre)\n"
+msgid "could not lock '%s'"
+msgstr "impossible de verrouiller '%s'"
 
-#: wt-status.c:1697 wt-status.c:1702
+#: sequencer.c:410
 #, c-format
-msgid "nothing to commit\n"
-msgstr "rien à valider\n"
+msgid "could not write eol to '%s'"
+msgstr "impossible d'écrire la fin de ligne dans '%s'"
 
-#: wt-status.c:1700
+#: sequencer.c:415 sequencer.c:2798 sequencer.c:2999 sequencer.c:3013
+#: sequencer.c:3277
 #, c-format
-msgid "nothing to commit (use -u to show untracked files)\n"
-msgstr "rien à valider (utilisez -u pour afficher les fichiers non suivis)\n"
+msgid "failed to finalize '%s'"
+msgstr "échec lors de la finalisation de '%s'"
 
-#: wt-status.c:1704
+#: sequencer.c:438 sequencer.c:1707 sequencer.c:2818 sequencer.c:3259
+#: sequencer.c:3368 builtin/am.c:244 builtin/commit.c:783 builtin/merge.c:1117
+#: builtin/rebase.c:589
 #, c-format
-msgid "nothing to commit, working tree clean\n"
-msgstr "rien à valider, la copie de travail est propre\n"
-
-#: wt-status.c:1817
-msgid "No commits yet on "
-msgstr "Encore aucun commit sur "
-
-#: wt-status.c:1821
-msgid "HEAD (no branch)"
-msgstr "HEAD (aucune branche)"
-
-#: wt-status.c:1852
-msgid "different"
-msgstr "différent"
-
-#: wt-status.c:1854 wt-status.c:1862
-msgid "behind "
-msgstr "derrière "
-
-#: wt-status.c:1857 wt-status.c:1860
-msgid "ahead "
-msgstr "devant "
+msgid "could not read '%s'"
+msgstr "impossible de lire '%s'"
 
-#. TRANSLATORS: the action is e.g. "pull with rebase"
-#: wt-status.c:2366
+#: sequencer.c:464
 #, c-format
-msgid "cannot %s: You have unstaged changes."
-msgstr "Impossible de %s : vous avez des modifications non indexées."
-
-#: wt-status.c:2372
-msgid "additionally, your index contains uncommitted changes."
-msgstr "de plus, votre index contient des modifications non validées."
+msgid "your local changes would be overwritten by %s."
+msgstr "vos modifications locales seraient écrasées par %s."
 
-#: wt-status.c:2374
-#, c-format
-msgid "cannot %s: Your index contains uncommitted changes."
-msgstr "%s impossible : votre index contient des modifications non validées."
+#: sequencer.c:468
+msgid "commit your changes or stash them to proceed."
+msgstr "validez vos modifications ou les remiser pour continuer."
 
-#: compat/precompose_utf8.c:58 builtin/clone.c:442
+#: sequencer.c:500
 #, c-format
-msgid "failed to unlink '%s'"
-msgstr "échec lors de l'unlink de '%s'"
-
-#: builtin/add.c:24
-msgid "git add [<options>] [--] <pathspec>..."
-msgstr "git add [<options>] [--] <chemin>..."
+msgid "%s: fast-forward"
+msgstr "%s : avance rapide"
 
-#: builtin/add.c:83
+#: sequencer.c:539 builtin/tag.c:565
 #, c-format
-msgid "unexpected diff status %c"
-msgstr "état de diff inattendu %c"
-
-#: builtin/add.c:88 builtin/commit.c:266
-msgid "updating files failed"
-msgstr "échec de la mise à jour des fichiers"
+msgid "Invalid cleanup mode %s"
+msgstr "Mode de nettoyage invalide %s"
 
-#: builtin/add.c:98
+#. TRANSLATORS: %s will be "revert", "cherry-pick" or
+#. "rebase -i".
+#.
+#: sequencer.c:633
 #, c-format
-msgid "remove '%s'\n"
-msgstr "suppression de '%s'\n"
+msgid "%s: Unable to write new index file"
+msgstr "%s: Impossible d'écrire le nouveau fichier index"
 
-#: builtin/add.c:173
-msgid "Unstaged changes after refreshing the index:"
-msgstr "Modifications non indexées après rafraîchissement de l'index :"
+#: sequencer.c:650
+msgid "unable to update cache tree"
+msgstr "impossible de mettre à jour l'arbre de cache"
 
-#: builtin/add.c:233 builtin/rev-parse.c:892
-msgid "Could not read the index"
-msgstr "Impossible de lire l'index"
+#: sequencer.c:664
+msgid "could not resolve HEAD commit"
+msgstr "impossible de résoudre le commit HEAD"
 
-#: builtin/add.c:244
+#: sequencer.c:744
 #, c-format
-msgid "Could not open '%s' for writing."
-msgstr "Impossible d'ouvrir '%s' en écriture."
-
-#: builtin/add.c:248
-msgid "Could not write patch"
-msgstr "Impossible d'écrire le patch"
+msgid "no key present in '%.*s'"
+msgstr "aucune clé présente dans '%.*s'"
 
-#: builtin/add.c:251
-msgid "editing patch failed"
-msgstr "échec de l'édition du patch"
+#: sequencer.c:755
+#, c-format
+msgid "unable to dequote value of '%s'"
+msgstr "Impossible de décoter la valeur de '%s'"
 
-#: builtin/add.c:254
+#: sequencer.c:792 wrapper.c:190 wrapper.c:360 builtin/am.c:705
+#: builtin/am.c:797 builtin/merge.c:1114 builtin/rebase.c:1074
 #, c-format
-msgid "Could not stat '%s'"
-msgstr "Stat de '%s' impossible"
+msgid "could not open '%s' for reading"
+msgstr "impossible d'ouvrir '%s' en lecture"
 
-#: builtin/add.c:256
-msgid "Empty patch. Aborted."
-msgstr "Patch vide. Abandon."
+#: sequencer.c:802
+msgid "'GIT_AUTHOR_NAME' already given"
+msgstr "'GIT_AUTHOR_NAME' déjà fourni"
 
-#: builtin/add.c:261
-#, c-format
-msgid "Could not apply '%s'"
-msgstr "Impossible d'appliquer '%s'"
+#: sequencer.c:807
+msgid "'GIT_AUTHOR_EMAIL' already given"
+msgstr "'GIT_AUTHOR_EMAIL' déjà fourni"
 
-#: builtin/add.c:269
-msgid "The following paths are ignored by one of your .gitignore files:\n"
-msgstr ""
-"Les chemins suivants sont ignorés par un de vos fichiers .gitignore :\n"
+#: sequencer.c:812
+msgid "'GIT_AUTHOR_DATE' already given"
+msgstr "'GIT_AUTHOR_DATE' déjà fourni"
 
-#: builtin/add.c:289 builtin/clean.c:911 builtin/fetch.c:145 builtin/mv.c:123
-#: builtin/prune-packed.c:55 builtin/pull.c:212 builtin/push.c:557
-#: builtin/remote.c:1342 builtin/rm.c:240 builtin/send-pack.c:165
-msgid "dry run"
-msgstr "simuler l'action"
+#: sequencer.c:816
+#, c-format
+msgid "unknown variable '%s'"
+msgstr "variable inconnue '%s'"
 
-#: builtin/add.c:292
-msgid "interactive picking"
-msgstr "sélection interactive"
+#: sequencer.c:821
+msgid "missing 'GIT_AUTHOR_NAME'"
+msgstr "'GIT_AUTHOR_NAME' manquant"
 
-#: builtin/add.c:293 builtin/checkout.c:1135 builtin/reset.c:302
-msgid "select hunks interactively"
-msgstr "sélection interactive des sections"
+#: sequencer.c:823
+msgid "missing 'GIT_AUTHOR_EMAIL'"
+msgstr "'GIT_AUTHOR_EMAIL' manquant"
 
-#: builtin/add.c:294
-msgid "edit current diff and apply"
-msgstr "édition du diff actuel et application"
+#: sequencer.c:825
+msgid "missing 'GIT_AUTHOR_DATE'"
+msgstr "'GIT_AUTHOR_DATE' manquant"
 
-#: builtin/add.c:295
-msgid "allow adding otherwise ignored files"
-msgstr "permettre l'ajout de fichiers ignorés"
+#: sequencer.c:902 sequencer.c:1427
+msgid "malformed ident line"
+msgstr "ligne d'identification malformée"
 
-#: builtin/add.c:296
-msgid "update tracked files"
-msgstr "mettre à jour les fichiers suivis"
-
-#: builtin/add.c:297
-msgid "renormalize EOL of tracked files (implies -u)"
-msgstr ""
-"renormaliser les fins de lignes (EOL) des fichiers suivis (implique -u)"
-
-#: builtin/add.c:298
-msgid "record only the fact that the path will be added later"
-msgstr "enregistrer seulement le fait que le chemin sera ajouté plus tard"
-
-#: builtin/add.c:299
-msgid "add changes from all tracked and untracked files"
-msgstr "ajouter les modifications de tous les fichiers suivis et non suivis"
-
-#: builtin/add.c:302
-msgid "ignore paths removed in the working tree (same as --no-all)"
+#: sequencer.c:925
+#, c-format
+msgid ""
+"you have staged changes in your working tree\n"
+"If these changes are meant to be squashed into the previous commit, run:\n"
+"\n"
+"  git commit --amend %s\n"
+"\n"
+"If they are meant to go into a new commit, run:\n"
+"\n"
+"  git commit %s\n"
+"\n"
+"In both cases, once you're done, continue with:\n"
+"\n"
+"  git rebase --continue\n"
 msgstr ""
-"ignorer les chemins effacés dans la copie de travail (identique à --no-all)"
+"Vous avez des modifications indexées dans votre copie de travail.\n"
+"Si elles devaient être ajoutées dans le commit précédent, lancez :\n"
+"\n"
+"  git commit --amend %s\n"
+"\n"
+"Si elles devaient aller dans un nouveau commit, lancez :\n"
+"\n"
+"  git commit %s\n"
+"\n"
+"Dans les deux cas, une fois fini, continuez avec :\n"
+"\n"
+"  git rebase --continue\n"
 
-#: builtin/add.c:304
-msgid "don't add, only refresh the index"
-msgstr "ne pas ajouter, juste rafraîchir l'index"
+#: sequencer.c:1218
+msgid "'prepare-commit-msg' hook failed"
+msgstr "échec du crochet 'prepare-commit-msg'"
 
-#: builtin/add.c:305
-msgid "just skip files which cannot be added because of errors"
+#: sequencer.c:1224
+msgid ""
+"Your name and email address were configured automatically based\n"
+"on your username and hostname. Please check that they are accurate.\n"
+"You can suppress this message by setting them explicitly. Run the\n"
+"following command and follow the instructions in your editor to edit\n"
+"your configuration file:\n"
+"\n"
+"    git config --global --edit\n"
+"\n"
+"After doing this, you may fix the identity used for this commit with:\n"
+"\n"
+"    git commit --amend --reset-author\n"
 msgstr ""
-"sauter seulement les fichiers qui ne peuvent pas être ajoutés du fait "
-"d'erreurs"
-
-#: builtin/add.c:306
-msgid "check if - even missing - files are ignored in dry run"
-msgstr "vérifier si des fichiers - même manquants - sont ignorés, à vide"
-
-#: builtin/add.c:307 builtin/update-index.c:974
-msgid "(+/-)x"
-msgstr "(+/-)x"
-
-#: builtin/add.c:307 builtin/update-index.c:975
-msgid "override the executable bit of the listed files"
-msgstr "outrepasser le bit exécutable pour les fichiers listés"
-
-#: builtin/add.c:309
-msgid "warn when adding an embedded repository"
-msgstr "avertir lors de l'ajout d'un dépôt embarqué"
+"Votre nom et votre adresse courriel ont été configurés automatiquement en "
+"se\n"
+"fondant sur votre nom d'utilisateur et le nom de votre machine. Veuillez \n"
+"vérifier qu'ils sont corrects. Vous pouvez supprimer ce message en les \n"
+"paramétrant explicitement. Lancez les commandes suivantes et suivez les\n"
+"instructions dans votre éditeur pour éditer votre fichier de "
+"configuration :\n"
+"\n"
+"    git config --global --edit\n"
+"\n"
+"Après ceci, vous pouvez corriger l'identité utilisée pour cette validation "
+"avec :\n"
+"\n"
+"    git commit --amend --reset-author\n"
 
-#: builtin/add.c:324
-#, c-format
+#: sequencer.c:1237
 msgid ""
-"You've added another git repository inside your current repository.\n"
-"Clones of the outer repository will not contain the contents of\n"
-"the embedded repository and will not know how to obtain it.\n"
-"If you meant to add a submodule, use:\n"
-"\n"
-"\tgit submodule add <url> %s\n"
+"Your name and email address were configured automatically based\n"
+"on your username and hostname. Please check that they are accurate.\n"
+"You can suppress this message by setting them explicitly:\n"
 "\n"
-"If you added this path by mistake, you can remove it from the\n"
-"index with:\n"
+"    git config --global user.name \"Your Name\"\n"
+"    git config --global user.email you@example.com\n"
 "\n"
-"\tgit rm --cached %s\n"
+"After doing this, you may fix the identity used for this commit with:\n"
 "\n"
-"See \"git help submodule\" for more information."
+"    git commit --amend --reset-author\n"
 msgstr ""
-"Vous avez ajouté un autre dépôt git dans votre dépôt actuel.\n"
-"Les clones du dépôt conteneur ne contiendrons pas le contenu\n"
-"du dépôt embarqué et ne sauront pas comment l'obtenir.\n"
-"Si vous vouliez ajouter un sous-module, utilisez :\n"
-"\n"
-"\tgit submodule add <url> %s\n"
+"Votre nom et votre adresse courriel ont été configurés automatiquement en se "
+"fondant\n"
+"sur votre nom d'utilisateur et le nom de votre machine. Veuillez vérifier "
+"qu'ils sont corrects.\n"
+"Vous pouvez supprimer ce message en les paramétrant explicitement :\n"
 "\n"
-"Si vous avez ajouté ce chemin par erreur, vous pouvez le\n"
-"supprimer de l'index avec :\n"
+"    git config --global user.name \"Votre Nom\"\n"
+"    git config --global user.email vous@exemple.com\n"
 "\n"
-"\tgit rm --cached %s\n"
+"Après ceci, vous pouvez corriger l'identité utilisée pour ce commit avec :\n"
 "\n"
-"Référez-vous à \"git help submodule\" pour plus d'information."
+"    git commit --amend --reset-author\n"
 
-#: builtin/add.c:352
-#, c-format
-msgid "adding embedded git repository: %s"
-msgstr "dépôt git embarqué ajouté : %s"
+#: sequencer.c:1279
+msgid "couldn't look up newly created commit"
+msgstr "impossible de retrouver le commit nouvellement créé"
 
-#: builtin/add.c:370
-#, c-format
-msgid "Use -f if you really want to add them.\n"
-msgstr "Utilisez -f si vous voulez réellement les ajouter.\n"
+#: sequencer.c:1281
+msgid "could not parse newly created commit"
+msgstr "impossible d'analyser le commit nouvellement créé"
 
-#: builtin/add.c:378
-msgid "adding files failed"
-msgstr "échec de l'ajout de fichiers"
+#: sequencer.c:1327
+msgid "unable to resolve HEAD after creating commit"
+msgstr "impossible de résoudre HEAD après création du commit"
 
-#: builtin/add.c:416
-msgid "-A and -u are mutually incompatible"
-msgstr "-A et -u sont mutuellement incompatibles"
+#: sequencer.c:1329
+msgid "detached HEAD"
+msgstr "HEAD détachée"
 
-#: builtin/add.c:423
-msgid "Option --ignore-missing can only be used together with --dry-run"
-msgstr ""
-"L'option --ignore-missing ne peut être utilisée qu'en complément de --dry-run"
+#: sequencer.c:1333
+msgid " (root-commit)"
+msgstr " (commit racine)"
 
-#: builtin/add.c:427
-#, c-format
-msgid "--chmod param '%s' must be either -x or +x"
-msgstr "Le paramètre '%s' de --chmod doit être soit -x soit +x"
+#: sequencer.c:1354
+msgid "could not parse HEAD"
+msgstr "impossible de lire HEAD"
 
-#: builtin/add.c:442
+#: sequencer.c:1356
 #, c-format
-msgid "Nothing specified, nothing added.\n"
-msgstr "Rien de spécifié, rien n'a été ajouté.\n"
+msgid "HEAD %s is not a commit!"
+msgstr "HEAD %s n'est pas un commit !"
 
-#: builtin/add.c:443
-#, c-format
-msgid "Maybe you wanted to say 'git add .'?\n"
-msgstr "Vous vouliez sûrement dire 'git add .' ?\n"
+#: sequencer.c:1360 sequencer.c:1458 builtin/commit.c:1569
+msgid "could not parse HEAD commit"
+msgstr "impossible d'analyser le commit HEAD"
 
-#: builtin/add.c:448 builtin/check-ignore.c:177 builtin/checkout.c:280
-#: builtin/checkout.c:483 builtin/clean.c:958 builtin/commit.c:325
-#: builtin/diff-tree.c:114 builtin/mv.c:144 builtin/reset.c:241
-#: builtin/rm.c:270 builtin/submodule--helper.c:328
-msgid "index file corrupt"
-msgstr "fichier d'index corrompu"
+#: sequencer.c:1411 sequencer.c:2055
+msgid "unable to parse commit author"
+msgstr "impossible d'analyser l'auteur du commit"
 
-#: builtin/am.c:414
-msgid "could not parse author script"
-msgstr "impossible d'analyser le script author"
+#: sequencer.c:1431
+msgid "corrupted author without date information"
+msgstr "ligne author corrompue sans information de date"
 
-#: builtin/am.c:498
-#, c-format
-msgid "'%s' was deleted by the applypatch-msg hook"
-msgstr "'%s' a été effacé par le crochet applypatch-msg"
+#: sequencer.c:1447 builtin/am.c:1561 builtin/merge.c:684
+msgid "git write-tree failed to write a tree"
+msgstr "git write-tree a échoué à écrire un arbre"
 
-#: builtin/am.c:539
+#: sequencer.c:1480 sequencer.c:1550
 #, c-format
-msgid "Malformed input line: '%s'."
-msgstr "Ligne en entrée malformée : '%s'."
+msgid "unable to read commit message from '%s'"
+msgstr "impossible de lire le message de validation de '%s'"
 
-#: builtin/am.c:576
-#, c-format
-msgid "Failed to copy notes from '%s' to '%s'"
-msgstr "Impossible de copier les notes de '%s' vers '%s'"
+#: sequencer.c:1516 builtin/am.c:1583 builtin/commit.c:1668 builtin/merge.c:883
+#: builtin/merge.c:908
+msgid "failed to write commit object"
+msgstr "échec de l'écriture de l'objet commit"
 
-#: builtin/am.c:602
-msgid "fseek failed"
-msgstr "échec de fseek"
+#: sequencer.c:1577
+#, c-format
+msgid "could not parse commit %s"
+msgstr "impossible d'analyser le commit %s"
 
-#: builtin/am.c:790
+#: sequencer.c:1582
 #, c-format
-msgid "could not parse patch '%s'"
-msgstr "impossible d'analyser le patch '%s'"
+msgid "could not parse parent commit %s"
+msgstr "impossible d'analyser le commit parent %s"
 
-#: builtin/am.c:855
-msgid "Only one StGIT patch series can be applied at once"
-msgstr "Seulement une série de patchs StGIT peut être appliquée à la fois"
+#: sequencer.c:1656 sequencer.c:1767
+#, c-format
+msgid "unknown command: %d"
+msgstr "commande inconnue : %d"
 
-#: builtin/am.c:903
-msgid "invalid timestamp"
-msgstr "horodatage invalide"
+#: sequencer.c:1714 sequencer.c:1739
+#, c-format
+msgid "This is a combination of %d commits."
+msgstr "Ceci est la combinaison de %d commits."
 
-#: builtin/am.c:908 builtin/am.c:920
-msgid "invalid Date line"
-msgstr "ligne de Date invalide"
+#: sequencer.c:1724
+msgid "need a HEAD to fixup"
+msgstr "une HEAD est nécessaire à la correction"
 
-#: builtin/am.c:915
-msgid "invalid timezone offset"
-msgstr "décalage horaire invalide"
+#: sequencer.c:1726 sequencer.c:3304
+msgid "could not read HEAD"
+msgstr "Impossible de lire HEAD"
 
-#: builtin/am.c:1008
-msgid "Patch format detection failed."
-msgstr "Échec de détection du format du patch."
+#: sequencer.c:1728
+msgid "could not read HEAD's commit message"
+msgstr "impossible de lire le message de validation de HEAD"
 
-#: builtin/am.c:1013 builtin/clone.c:407
+#: sequencer.c:1734
 #, c-format
-msgid "failed to create directory '%s'"
-msgstr "échec de la création du répertoire '%s'"
-
-#: builtin/am.c:1018
-msgid "Failed to split patches."
-msgstr "Échec de découpage des patchs."
+msgid "cannot write '%s'"
+msgstr "impossible d'écrire '%s'"
 
-#: builtin/am.c:1148 builtin/commit.c:351
-msgid "unable to write index file"
-msgstr "impossible d'écrire le fichier d'index"
+#: sequencer.c:1741 git-rebase--preserve-merges.sh:496
+msgid "This is the 1st commit message:"
+msgstr "Ceci est le premier message de validation :"
 
-#: builtin/am.c:1162
+#: sequencer.c:1749
 #, c-format
-msgid "When you have resolved this problem, run \"%s --continue\"."
-msgstr "Quand vous avez résolu ce problème, lancez \"%s --continue\"."
+msgid "could not read commit message of %s"
+msgstr "impossible de lire le message de validation de %s"
 
-#: builtin/am.c:1163
+#: sequencer.c:1756
 #, c-format
-msgid "If you prefer to skip this patch, run \"%s --skip\" instead."
-msgstr "Si vous préférez plutôt sauter ce patch, lancez \"%s --skip\"."
+msgid "This is the commit message #%d:"
+msgstr "Ceci est le message de validation numéro %d :"
 
-#: builtin/am.c:1164
+#: sequencer.c:1762
 #, c-format
-msgid "To restore the original branch and stop patching, run \"%s --abort\"."
-msgstr ""
-"Pour restaurer la branche originale et arrêter de patcher, lancez \"%s --"
-"abort\"."
+msgid "The commit message #%d will be skipped:"
+msgstr "Le message de validation %d sera ignoré :"
 
-#: builtin/am.c:1271
-msgid "Patch is empty."
-msgstr "Le patch actuel est vide."
+#: sequencer.c:1850
+msgid "your index file is unmerged."
+msgstr "votre fichier d'index n'est pas fusionné."
+
+#: sequencer.c:1857
+msgid "cannot fixup root commit"
+msgstr "impossible de réparer le commit racine"
 
-#: builtin/am.c:1337
+#: sequencer.c:1876
 #, c-format
-msgid "invalid ident line: %.*s"
-msgstr "ligne d'identification invalide : %.*s"
+msgid "commit %s is a merge but no -m option was given."
+msgstr "le commit %s est une fusion mais l'option -m n'a pas été spécifiée."
 
-#: builtin/am.c:1359
+#: sequencer.c:1884 sequencer.c:1892
 #, c-format
-msgid "unable to parse commit %s"
-msgstr "impossible d'analyser le commit %s"
+msgid "commit %s does not have parent %d"
+msgstr "le commit %s n'a pas de parent %d"
 
-#: builtin/am.c:1554
-msgid "Repository lacks necessary blobs to fall back on 3-way merge."
-msgstr ""
-"Le dépôt n'a pas les blobs nécessaires pour un retour à une fusion à 3 "
-"points."
+#: sequencer.c:1898
+#, c-format
+msgid "cannot get commit message for %s"
+msgstr "impossible d'obtenir un message de validation pour %s"
 
-#: builtin/am.c:1556
-msgid "Using index info to reconstruct a base tree..."
-msgstr ""
-"Utilisation de l'information de l'index pour reconstruire un arbre de base..."
-
-#: builtin/am.c:1575
-msgid ""
-"Did you hand edit your patch?\n"
-"It does not apply to blobs recorded in its index."
-msgstr ""
-"Avez-vous édité le patch à la main ?\n"
-"Il ne s'applique pas aux blobs enregistrés dans son index."
-
-#: builtin/am.c:1581
-msgid "Falling back to patching base and 3-way merge..."
-msgstr "Retour à un patch de la base et fusion à 3 points..."
-
-#: builtin/am.c:1606
-msgid "Failed to merge in the changes."
-msgstr "Échec d'intégration des modifications."
-
-#: builtin/am.c:1637
-msgid "applying to an empty history"
-msgstr "application à un historique vide"
-
-#: builtin/am.c:1683 builtin/am.c:1687
+#. TRANSLATORS: The first %s will be a "todo" command like
+#. "revert" or "pick", the second %s a SHA1.
+#: sequencer.c:1917
 #, c-format
-msgid "cannot resume: %s does not exist."
-msgstr "impossible de continuer : %s n'existe pas."
+msgid "%s: cannot parse parent commit %s"
+msgstr "%s : impossible d'analyser le commit parent %s"
 
-#: builtin/am.c:1703
-msgid "cannot be interactive without stdin connected to a terminal."
-msgstr ""
-"impossible d'être interactif sans entrée standard connectée à un terminal."
+#: sequencer.c:1982
+#, c-format
+msgid "could not rename '%s' to '%s'"
+msgstr "impossible de renommer '%s' en '%s'"
 
-#: builtin/am.c:1708
-msgid "Commit Body is:"
-msgstr "Le corps de la validation est :"
+#: sequencer.c:2037
+#, c-format
+msgid "could not revert %s... %s"
+msgstr "impossible d'annuler %s... %s"
 
-#. TRANSLATORS: Make sure to include [y], [n], [e], [v] and [a]
-#. in your translation. The program will only accept English
-#. input at this point.
-#.
-#: builtin/am.c:1718
-msgid "Apply? [y]es/[n]o/[e]dit/[v]iew patch/[a]ccept all: "
-msgstr "Appliquer ? [y]es/[n]o/[e]dit/[v]iew patch/[a]ccept all : "
+#: sequencer.c:2038
+#, c-format
+msgid "could not apply %s... %s"
+msgstr "impossible d'appliquer %s... %s"
 
-#: builtin/am.c:1768
+#: sequencer.c:2105
 #, c-format
-msgid "Dirty index: cannot apply patches (dirty: %s)"
-msgstr "Index sale : impossible d'appliquer des patchs (sales : %s)"
+msgid "git %s: failed to read the index"
+msgstr "git %s : échec à la lecture de l'index"
 
-#: builtin/am.c:1808 builtin/am.c:1879
+#: sequencer.c:2112
 #, c-format
-msgid "Applying: %.*s"
-msgstr "Application de  %.*s"
+msgid "git %s: failed to refresh the index"
+msgstr "git %s : échec du rafraîchissement de l'index"
 
-#: builtin/am.c:1824
-msgid "No changes -- Patch already applied."
-msgstr "Pas de changement -- Patch déjà appliqué."
+#: sequencer.c:2189
+#, c-format
+msgid "%s does not accept arguments: '%s'"
+msgstr "%s n'accepte pas d'argument : '%s'"
 
-#: builtin/am.c:1832
+#: sequencer.c:2198
 #, c-format
-msgid "Patch failed at %s %.*s"
-msgstr "le patch a échoué à %s %.*s"
+msgid "missing arguments for %s"
+msgstr "argument manquant pour %s"
 
-#: builtin/am.c:1838
-msgid "Use 'git am --show-current-patch' to see the failed patch"
-msgstr ""
-"Utilisez 'git am --show-current-patch' pour visualiser le patch en échec"
+#: sequencer.c:2235
+#, c-format
+msgid "could not parse '%.*s'"
+msgstr "impossible d'analyser '%.*s'"
 
-#: builtin/am.c:1882
-msgid ""
-"No changes - did you forget to use 'git add'?\n"
-"If there is nothing left to stage, chances are that something else\n"
-"already introduced the same changes; you might want to skip this patch."
-msgstr ""
-"Aucun changement - avez-vous oublié d'utiliser 'git add' ?\n"
-"S'il n'y a plus rien à indexer, il se peut qu'autre chose ait déjà\n"
-"introduit les mêmes changements ; vous pourriez avoir envie de sauter ce "
-"patch."
+#: sequencer.c:2289
+#, c-format
+msgid "invalid line %d: %.*s"
+msgstr "ligne %d invalide : %.*s"
 
-#: builtin/am.c:1889
-msgid ""
-"You still have unmerged paths in your index.\n"
-"You should 'git add' each file with resolved conflicts to mark them as "
-"such.\n"
-"You might run `git rm` on a file to accept \"deleted by them\" for it."
-msgstr ""
-"Vous avez encore des chemin non-fusionnés dans votre index.\n"
-"Vous devriez lancer 'git add' sur chaque conflit résolu pour les marquer "
-"comme tel.\n"
-"Vous pouvez lancer 'git rm' sur un fichier \"supprimé par eux\" pour "
-"accepter son état."
+#: sequencer.c:2300
+#, c-format
+msgid "cannot '%s' without a previous commit"
+msgstr "'%s' impossible avec le commit précédent"
 
-#: builtin/am.c:1996 builtin/am.c:2000 builtin/am.c:2012 builtin/reset.c:324
-#: builtin/reset.c:332
+#: sequencer.c:2348 builtin/rebase.c:172 builtin/rebase.c:197
+#: builtin/rebase.c:223 builtin/rebase.c:248
 #, c-format
-msgid "Could not parse object '%s'."
-msgstr "Impossible d'analyser l'objet '%s'."
+msgid "could not read '%s'."
+msgstr "impossible de lire '%s'."
 
-#: builtin/am.c:2048
-msgid "failed to clean index"
-msgstr "échec du nettoyage de l'index"
+#: sequencer.c:2384
+msgid "cancelling a cherry picking in progress"
+msgstr "annulation d'un picorage en cours"
+
+#: sequencer.c:2391
+msgid "cancelling a revert in progress"
+msgstr "annulation d'un retour en cours"
 
-#: builtin/am.c:2083
-msgid ""
-"You seem to have moved HEAD since the last 'am' failure.\n"
-"Not rewinding to ORIG_HEAD"
-msgstr ""
-"Vous semblez avoir déplacé la HEAD depuis le dernier échec de 'am'.\n"
-"Pas de retour à ORIG_HEAD"
+#: sequencer.c:2435
+msgid "please fix this using 'git rebase --edit-todo'."
+msgstr "veuillez corriger ceci en utilisant 'git rebase --edit-todo'."
 
-#: builtin/am.c:2174
+#: sequencer.c:2437
 #, c-format
-msgid "Invalid value for --patch-format: %s"
-msgstr "Valeur invalide pour --patch-format : %s"
-
-#: builtin/am.c:2210
-msgid "git am [<options>] [(<mbox> | <Maildir>)...]"
-msgstr "git am [<options>] [(<mbox> | <Maildir>)...]"
-
-#: builtin/am.c:2211
-msgid "git am [<options>] (--continue | --skip | --abort)"
-msgstr "git am [<options>] (--continue | --quit | --abort)"
+msgid "unusable instruction sheet: '%s'"
+msgstr "feuille d'instruction inutilisable : '%s'"
 
-#: builtin/am.c:2217
-msgid "run interactively"
-msgstr "exécution interactive"
+#: sequencer.c:2442
+msgid "no commits parsed."
+msgstr "aucun commit analysé."
 
-#: builtin/am.c:2219
-msgid "historical option -- no-op"
-msgstr "option historique -- no-op"
+#: sequencer.c:2453
+msgid "cannot cherry-pick during a revert."
+msgstr "impossible de picorer pendant l'annulation d'un commit."
 
-#: builtin/am.c:2221
-msgid "allow fall back on 3way merging if needed"
-msgstr "permettre de revenir à une fusion à 3 points si nécessaire"
+#: sequencer.c:2455
+msgid "cannot revert during a cherry-pick."
+msgstr "impossible d'annuler un commit pendant un picorage."
 
-#: builtin/am.c:2222 builtin/init-db.c:484 builtin/prune-packed.c:57
-#: builtin/repack.c:192
-msgid "be quiet"
-msgstr "être silencieux"
+#: sequencer.c:2533
+#, c-format
+msgid "invalid value for %s: %s"
+msgstr "valeur invalide pour %s : %s"
 
-#: builtin/am.c:2224
-msgid "add a Signed-off-by line to the commit message"
-msgstr "ajouter une ligne Signed-off-by au message de validation"
+#: sequencer.c:2630
+msgid "unusable squash-onto"
+msgstr "\"écrase-sur\" inutilisable"
 
-#: builtin/am.c:2227
-msgid "recode into utf8 (default)"
-msgstr "recoder en utf-8 (par défaut)"
+#: sequencer.c:2646
+#, c-format
+msgid "malformed options sheet: '%s'"
+msgstr "feuille d'options malformée : %s"
 
-#: builtin/am.c:2229
-msgid "pass -k flag to git-mailinfo"
-msgstr "passer l'option -k à git-mailinfo"
+#: sequencer.c:2736 sequencer.c:4463
+msgid "empty commit set passed"
+msgstr "l'ensemble de commits spécifié est vide"
 
-#: builtin/am.c:2231
-msgid "pass -b flag to git-mailinfo"
-msgstr "passer l'option -b à git-mailinfo"
+#: sequencer.c:2752
+msgid "revert is already in progress"
+msgstr "un retour est déjà en cours"
 
-#: builtin/am.c:2233
-msgid "pass -m flag to git-mailinfo"
-msgstr "passer l'option -m à git-mailinfo"
+#: sequencer.c:2754
+#, c-format
+msgid "try \"git revert (--continue | %s--abort | --quit)\""
+msgstr "essayez \"git revert (--continue | %s--abort | --quit)\""
 
-#: builtin/am.c:2235
-msgid "pass --keep-cr flag to git-mailsplit for mbox format"
-msgstr "passer l'option --keep-cr à git-mailsplit fpour le format mbox"
+#: sequencer.c:2757
+msgid "cherry-pick is already in progress"
+msgstr "un picorage est déjà en cours"
 
-#: builtin/am.c:2238
-msgid "do not pass --keep-cr flag to git-mailsplit independent of am.keepcr"
-msgstr ""
-"ne pas passer l'option --keep-cr à git-mailsplit indépendamment de am.keepcr"
+#: sequencer.c:2759
+#, c-format
+msgid "try \"git cherry-pick (--continue | %s--abort | --quit)\""
+msgstr "essayez \"git cherry-pick (--continue | %s--abort | --quit)\""
 
-#: builtin/am.c:2241
-msgid "strip everything before a scissors line"
-msgstr "retirer tout le contenu avant la ligne des ciseaux"
+#: sequencer.c:2773
+#, c-format
+msgid "could not create sequencer directory '%s'"
+msgstr "impossible de créer le répertoire de séquenceur '%s'"
 
-#: builtin/am.c:2243 builtin/am.c:2246 builtin/am.c:2249 builtin/am.c:2252
-#: builtin/am.c:2255 builtin/am.c:2258 builtin/am.c:2261 builtin/am.c:2264
-#: builtin/am.c:2270
-msgid "pass it through git-apply"
-msgstr "le passer jusqu'à git-apply"
+#: sequencer.c:2788
+msgid "could not lock HEAD"
+msgstr "impossible de verrouiller HEAD"
 
-#: builtin/am.c:2260 builtin/commit.c:1332 builtin/fmt-merge-msg.c:665
-#: builtin/fmt-merge-msg.c:668 builtin/grep.c:853 builtin/merge.c:208
-#: builtin/pull.c:150 builtin/pull.c:208 builtin/repack.c:201
-#: builtin/repack.c:205 builtin/repack.c:207 builtin/show-branch.c:631
-#: builtin/show-ref.c:169 builtin/tag.c:383 parse-options.h:144
-#: parse-options.h:146 parse-options.h:258
-msgid "n"
-msgstr "n"
+#: sequencer.c:2848 sequencer.c:4209
+msgid "no cherry-pick or revert in progress"
+msgstr "aucun picorage ou retour en cours"
 
-#: builtin/am.c:2266 builtin/branch.c:632 builtin/for-each-ref.c:38
-#: builtin/replace.c:543 builtin/tag.c:419 builtin/verify-tag.c:39
-msgid "format"
-msgstr "format"
+#: sequencer.c:2850 sequencer.c:2861
+msgid "cannot resolve HEAD"
+msgstr "impossible de résoudre HEAD"
 
-#: builtin/am.c:2267
-msgid "format the patch(es) are in"
-msgstr "format de présentation des patchs"
+#: sequencer.c:2852 sequencer.c:2896
+msgid "cannot abort from a branch yet to be born"
+msgstr "impossible d'abandonner depuis une branche non encore créée"
 
-#: builtin/am.c:2273
-msgid "override error message when patch failure occurs"
-msgstr "surcharger le message d'erreur lors d'un échec d'application de patch"
+#: sequencer.c:2882 builtin/grep.c:736
+#, c-format
+msgid "cannot open '%s'"
+msgstr "impossible d'ouvrir '%s'"
 
-#: builtin/am.c:2275
-msgid "continue applying patches after resolving a conflict"
-msgstr "continuer à appliquer les patchs après résolution d'un conflit"
+#: sequencer.c:2884
+#, c-format
+msgid "cannot read '%s': %s"
+msgstr "impossible de lire '%s' : %s"
 
-#: builtin/am.c:2278
-msgid "synonyms for --continue"
-msgstr "synonymes de --continue"
+#: sequencer.c:2885
+msgid "unexpected end of file"
+msgstr "fin de fichier inattendue"
 
-#: builtin/am.c:2281
-msgid "skip the current patch"
-msgstr "sauter le patch courant"
+#: sequencer.c:2891
+#, c-format
+msgid "stored pre-cherry-pick HEAD file '%s' is corrupt"
+msgstr "le fichier HEAD de préparation de picorage '%s' est corrompu"
 
-#: builtin/am.c:2284
-msgid "restore the original branch and abort the patching operation."
+#: sequencer.c:2902
+msgid "You seem to have moved HEAD. Not rewinding, check your HEAD!"
 msgstr ""
-"restaurer la branche originale et abandonner les applications de patch."
-
-#: builtin/am.c:2287
-msgid "abort the patching operation but keep HEAD where it is."
-msgstr "abandonne l'opération de patch mais garde HEAD où il est."
-
-#: builtin/am.c:2290
-msgid "show the patch being applied."
-msgstr "afficher le patch en cours d'application."
-
-#: builtin/am.c:2294
-msgid "lie about committer date"
-msgstr "mentir sur la date de validation"
+"Vous semblez avoir déplacé la HEAD. Pas de rembobinage, vérifiez votre HEAD !"
 
-#: builtin/am.c:2296
-msgid "use current timestamp for author date"
-msgstr "utiliser l'horodatage actuel pour la date d'auteur"
+#: sequencer.c:2943
+msgid "no revert in progress"
+msgstr "Pas de retour en cours ?"
 
-#: builtin/am.c:2298 builtin/commit.c:1468 builtin/merge.c:239
-#: builtin/pull.c:183 builtin/revert.c:112 builtin/tag.c:399
-msgid "key-id"
-msgstr "id-clé"
+#: sequencer.c:2951
+msgid "no cherry-pick in progress"
+msgstr "aucun picorage en cours"
 
-#: builtin/am.c:2299
-msgid "GPG-sign commits"
-msgstr "signer les commits avec GPG"
+#: sequencer.c:2961
+msgid "failed to skip the commit"
+msgstr "échec du saut de commit"
 
-#: builtin/am.c:2302
-msgid "(internal use for git-rebase)"
-msgstr "(utilisation interne pour git-rebase)"
+#: sequencer.c:2968
+msgid "there is nothing to skip"
+msgstr "il n'y a rien à sauter"
 
-#: builtin/am.c:2320
+#: sequencer.c:2971
+#, c-format
 msgid ""
-"The -b/--binary option has been a no-op for long time, and\n"
-"it will be removed. Please do not use it anymore."
+"have you committed already?\n"
+"try \"git %s --continue\""
 msgstr ""
-"L'option -b/--binary ne fait plus rien depuis longtemps,\n"
-"et elle sera supprimée. Veuillez ne plus l'utiliser."
+"Avez-vous déjà validé ?\n"
+"essayez \"git %s -continue\""
 
-#: builtin/am.c:2327
-msgid "failed to read the index"
-msgstr "échec à la lecture de l'index"
+#: sequencer.c:3095 sequencer.c:4121
+#, c-format
+msgid "could not update %s"
+msgstr "impossible de mettre à jour %s"
 
-#: builtin/am.c:2342
+#: sequencer.c:3134 sequencer.c:4101
+msgid "cannot read HEAD"
+msgstr "impossible de lire HEAD"
+
+#: sequencer.c:3151
 #, c-format
-msgid "previous rebase directory %s still exists but mbox given."
-msgstr ""
-"le répertoire précédent de rebasage %s existe toujours mais mbox donnée."
+msgid "unable to copy '%s' to '%s'"
+msgstr "impossible de copier '%s' vers '%s'"
 
-#: builtin/am.c:2366
+#: sequencer.c:3159
 #, c-format
 msgid ""
-"Stray %s directory found.\n"
-"Use \"git am --abort\" to remove it."
+"You can amend the commit now, with\n"
+"\n"
+"  git commit --amend %s\n"
+"\n"
+"Once you are satisfied with your changes, run\n"
+"\n"
+"  git rebase --continue\n"
 msgstr ""
-"Répertoire abandonné %s trouvé.\n"
-"Utilisez \"git am --abort\" pour le supprimer."
-
-#: builtin/am.c:2372
-msgid "Resolve operation not in progress, we are not resuming."
-msgstr ""
-"Pas de résolution de l'opération en cours, nous ne sommes pas dans une "
-"reprise."
+"Vous pouvez corriger le commit maintenant, avec\n"
+"\n"
+"  git commit --amend %s\n"
+"\n"
+"après avoir réalisé vos modifications, lancez\n"
+"\n"
+"  git rebase --continue\n"
 
-#: builtin/apply.c:8
-msgid "git apply [<options>] [<patch>...]"
-msgstr "git apply [<options>] [<patch>...]"
+#: sequencer.c:3169
+#, c-format
+msgid "Could not apply %s... %.*s"
+msgstr "impossible d'appliquer %s... %.*s"
 
-#: builtin/archive.c:17
+#: sequencer.c:3176
 #, c-format
-msgid "could not create archive file '%s'"
-msgstr "création impossible du fichier d'archive '%s'"
+msgid "Could not merge %.*s"
+msgstr "Impossible de fusionner %.*s"
 
-#: builtin/archive.c:20
-msgid "could not redirect output"
-msgstr "impossible de rediriger la sortie"
+#: sequencer.c:3190 sequencer.c:3194 builtin/difftool.c:641
+#, c-format
+msgid "could not copy '%s' to '%s'"
+msgstr "impossible de copier '%s' vers '%s'"
 
-#: builtin/archive.c:37
-msgid "git archive: Remote with no URL"
-msgstr "git archive : Dépôt distant sans URL"
+#: sequencer.c:3221
+#, c-format
+msgid ""
+"execution failed: %s\n"
+"%sYou can fix the problem, and then run\n"
+"\n"
+"  git rebase --continue\n"
+"\n"
+msgstr ""
+"échec d'exécution : %s\n"
+"%sVous pouvez corriger le problème, puis lancer\n"
+"\n"
+"git rebase --continue\n"
+"\n"
 
-#: builtin/archive.c:58
-msgid "git archive: expected ACK/NAK, got a flush packet"
-msgstr "git archive : ACK/NACK attendu, paquet de nettoyage reçu"
+#: sequencer.c:3227
+msgid "and made changes to the index and/or the working tree\n"
+msgstr "et a mis à jour l'index ou l'arbre de travail\n"
 
-#: builtin/archive.c:61
+#: sequencer.c:3233
 #, c-format
-msgid "git archive: NACK %s"
-msgstr "git archive : NACK %s"
-
-#: builtin/archive.c:64
-msgid "git archive: protocol error"
-msgstr "git archive : erreur de protocole"
+msgid ""
+"execution succeeded: %s\n"
+"but left changes to the index and/or the working tree\n"
+"Commit or stash your changes, and then run\n"
+"\n"
+"  git rebase --continue\n"
+"\n"
+msgstr ""
+"L'exécution a réussi : %s\n"
+"mais a laissé des modifications dans l'index ou la copie de travail\n"
+"Validez ou remisez vos modification, puis lancez\n"
+"\n"
+"  git rebase --continue\n"
+"\n"
 
-#: builtin/archive.c:68
-msgid "git archive: expected a flush"
-msgstr "git archive : vidage attendu"
+#: sequencer.c:3294
+#, c-format
+msgid "illegal label name: '%.*s'"
+msgstr "nom de label illégal '%.*s'"
 
-#: builtin/bisect--helper.c:12
-msgid "git bisect--helper --next-all [--no-checkout]"
-msgstr "git bisect --helper --next-all [--no-checkout]"
+#: sequencer.c:3348
+msgid "writing fake root commit"
+msgstr "écriture d'un commit racine bidon"
 
-#: builtin/bisect--helper.c:13
-msgid "git bisect--helper --write-terms <bad_term> <good_term>"
-msgstr "git bisect--helper --write-terms <terme-pour-mauvais> <terme-pour-bon>"
+#: sequencer.c:3353
+msgid "writing squash-onto"
+msgstr "écriture de 'écraser-sur'"
 
-#: builtin/bisect--helper.c:14
-msgid "git bisect--helper --bisect-clean-state"
-msgstr "git bisect--helper --bisect-clean-state"
+#: sequencer.c:3391 builtin/rebase.c:876 builtin/rebase.c:882
+#, c-format
+msgid "failed to find tree of %s"
+msgstr "impossible de trouver l'arbre de %s"
 
-#: builtin/bisect--helper.c:46
+#: sequencer.c:3436
 #, c-format
-msgid "'%s' is not a valid term"
-msgstr "'%s' n'est pas un terme valide"
+msgid "could not resolve '%s'"
+msgstr "impossible de résoudre '%s'"
 
-#: builtin/bisect--helper.c:50
+#: sequencer.c:3467
+msgid "cannot merge without a current revision"
+msgstr "impossible de fusionner avec une révision courante"
+
+#: sequencer.c:3489
 #, c-format
-msgid "can't use the builtin command '%s' as a term"
-msgstr "impossible d'utiliser la commande incluse '%s' comme terme"
+msgid "unable to parse '%.*s'"
+msgstr "impossible d'analyser '%.*s'"
 
-#: builtin/bisect--helper.c:60
+#: sequencer.c:3498
 #, c-format
-msgid "can't change the meaning of the term '%s'"
-msgstr "impossible de modifier la signification du terme '%s'"
+msgid "nothing to merge: '%.*s'"
+msgstr "rien à fusionner : '%.*s'"
 
-#: builtin/bisect--helper.c:71
-msgid "please use two different terms"
-msgstr "veuillez utiliser deux termes différents"
+#: sequencer.c:3510
+msgid "octopus merge cannot be executed on top of a [new root]"
+msgstr ""
+"une fusion octopus ne peut pas être exécutée par dessus une nouvelle racine"
 
-#: builtin/bisect--helper.c:78
-msgid "could not open the file BISECT_TERMS"
-msgstr "impossible d'ouvrir le fichier BISECT_TERMS"
+#: sequencer.c:3526
+#, c-format
+msgid "could not get commit message of '%s'"
+msgstr "impossible de lire le message de validation de '%s'"
 
-#: builtin/bisect--helper.c:120
-msgid "perform 'git bisect next'"
-msgstr "effectuer 'git bisect next'"
+#: sequencer.c:3688
+#, c-format
+msgid "could not even attempt to merge '%.*s'"
+msgstr "impossible de seulement essayer de fusionner '%.*s'"
 
-#: builtin/bisect--helper.c:122
-msgid "write the terms to .git/BISECT_TERMS"
-msgstr "écrire les termes dans .git/BISECT_TERMS"
+#: sequencer.c:3704
+msgid "merge: Unable to write new index file"
+msgstr "fusion : Impossible d'écrire le nouveau fichier index"
 
-#: builtin/bisect--helper.c:124
-msgid "cleanup the bisection state"
-msgstr "vérifier l'état de la bissection"
+#: sequencer.c:3773 builtin/rebase.c:733
+#, c-format
+msgid "Applied autostash.\n"
+msgstr "Autoremisage appliqué.\n"
 
-#: builtin/bisect--helper.c:126
-msgid "check for expected revs"
-msgstr "vérifier si des révisions sont attendues"
+#: sequencer.c:3785
+#, c-format
+msgid "cannot store %s"
+msgstr "impossible de stocker %s"
 
-#: builtin/bisect--helper.c:128
-msgid "update BISECT_HEAD instead of checking out the current commit"
-msgstr "mettre à jour BISECT_HEAD au lieu d'extraire le commit actuel"
+#: sequencer.c:3788 builtin/rebase.c:749 git-rebase--preserve-merges.sh:113
+#, c-format
+msgid ""
+"Applying autostash resulted in conflicts.\n"
+"Your changes are safe in the stash.\n"
+"You can run \"git stash pop\" or \"git stash drop\" at any time.\n"
+msgstr ""
+"L'application de l'autoremisage a provoqué des conflits\n"
+"Vos  modifications sont à l'abri dans la remise.\n"
+"Vous pouvez lancer \"git stash pop\" ou \"git stash drop\" à tout moment.\n"
 
-#: builtin/bisect--helper.c:143
-msgid "--write-terms requires two arguments"
-msgstr "--write-terms exige deux arguments"
+#: sequencer.c:3849
+#, c-format
+msgid "could not checkout %s"
+msgstr "extraction de %s impossible"
 
-#: builtin/bisect--helper.c:147
-msgid "--bisect-clean-state requires no arguments"
-msgstr "--bisect-clean-state ne supporte aucun argument"
+#: sequencer.c:3863
+#, c-format
+msgid "%s: not a valid OID"
+msgstr "%s n'est pas un OID valide"
 
-#: builtin/blame.c:29
-msgid "git blame [<options>] [<rev-opts>] [<rev>] [--] <file>"
-msgstr "git blame [<options>] [<rev-opts>] [<rev>] [--] <fichier>"
+#: sequencer.c:3868 git-rebase--preserve-merges.sh:779
+msgid "could not detach HEAD"
+msgstr "Impossible de détacher HEAD"
 
-#: builtin/blame.c:34
-msgid "<rev-opts> are documented in git-rev-list(1)"
-msgstr "<options-de-révision> sont documentés dans git-rev-list(1)"
+#: sequencer.c:3883
+#, c-format
+msgid "Stopped at HEAD\n"
+msgstr "arrêt à HEAD\n"
 
-#: builtin/blame.c:404
+#: sequencer.c:3885
 #, c-format
-msgid "expecting a color: %s"
-msgstr "couleur attendue : %s"
+msgid "Stopped at %s\n"
+msgstr "Arrêté à %s\n"
 
-#: builtin/blame.c:411
-msgid "must end with a color"
-msgstr "doit finir avec une couleur"
+#: sequencer.c:3893
+#, c-format
+msgid ""
+"Could not execute the todo command\n"
+"\n"
+"    %.*s\n"
+"It has been rescheduled; To edit the command before continuing, please\n"
+"edit the todo list first:\n"
+"\n"
+"    git rebase --edit-todo\n"
+"    git rebase --continue\n"
+msgstr ""
+"Impossible d'exécuter la commande\n"
+"\n"
+"    %.*s\n"
+"Elle a été reprogrammée ; pour éditer la commande avant de poursuivre,\n"
+"veuillez éditer la liste de commandes en premier :\n"
+"\n"
+"    git rebase --edit-todo\n"
+"    git rebase --continue\n"
 
-#: builtin/blame.c:697
+#: sequencer.c:3979
 #, c-format
-msgid "invalid color '%s' in color.blame.repeatedLines"
-msgstr "couleur invalide '%s' dans color.blame.repeatedlines"
+msgid "Stopped at %s...  %.*s\n"
+msgstr "arrêt à %s... %.*s\n"
 
-#: builtin/blame.c:715
-msgid "invalid value for blame.coloring"
-msgstr "valeur invalide pour blame.coloring"
+#: sequencer.c:4050
+#, c-format
+msgid "unknown command %d"
+msgstr "commande inconnue %d"
 
-#: builtin/blame.c:786
-msgid "Show blame entries as we find them, incrementally"
-msgstr ""
-"Montrer les éléments de blâme au fur et à mesure de leur découverte, de "
-"manière incrémentale"
+#: sequencer.c:4109
+msgid "could not read orig-head"
+msgstr "impossible de lire orig-head"
 
-#: builtin/blame.c:787
-msgid "Show blank SHA-1 for boundary commits (Default: off)"
-msgstr "Montrer un SHA-1 blanc pour les commits de limite (Défaut : désactivé)"
+#: sequencer.c:4114
+msgid "could not read 'onto'"
+msgstr "impossible de lire 'onto'"
 
-#: builtin/blame.c:788
-msgid "Do not treat root commits as boundaries (Default: off)"
-msgstr ""
-"Ne pas traiter les commits racine comme des limites (Défaut : désactivé)"
+#: sequencer.c:4128
+#, c-format
+msgid "could not update HEAD to %s"
+msgstr "impossible de mettre à jour HEAD sur %s"
 
-#: builtin/blame.c:789
-msgid "Show work cost statistics"
-msgstr "Montrer les statistiques de coût d'activité"
+#: sequencer.c:4221
+msgid "cannot rebase: You have unstaged changes."
+msgstr "impossible de rebaser : vous avez des modifications non indexées."
 
-#: builtin/blame.c:790
-msgid "Force progress reporting"
-msgstr "Forcer l'affichage de l'état d'avancement"
+#: sequencer.c:4230
+msgid "cannot amend non-existing commit"
+msgstr "impossible de corriger un commit non-existant"
 
-#: builtin/blame.c:791
-msgid "Show output score for blame entries"
-msgstr "Montrer le score de sortie pour les éléments de blâme"
+#: sequencer.c:4232
+#, c-format
+msgid "invalid file: '%s'"
+msgstr "fichier invalide : '%s'"
 
-#: builtin/blame.c:792
-msgid "Show original filename (Default: auto)"
-msgstr "Montrer les noms de fichier originaux (Défaut : auto)"
+#: sequencer.c:4234
+#, c-format
+msgid "invalid contents: '%s'"
+msgstr "contenu invalide : '%s'"
 
-#: builtin/blame.c:793
-msgid "Show original linenumber (Default: off)"
-msgstr "Montrer les numéros de lignes originaux (Défaut : désactivé)"
+#: sequencer.c:4237
+msgid ""
+"\n"
+"You have uncommitted changes in your working tree. Please, commit them\n"
+"first and then run 'git rebase --continue' again."
+msgstr ""
+"\n"
+"Vous avez des modifications non validées dans votre copie de travail.\n"
+"Veuillez les valider d'abord, puis relancer 'git rebase --continue'."
 
-#: builtin/blame.c:794
-msgid "Show in a format designed for machine consumption"
-msgstr "Afficher dans un format propice à la consommation par machine"
+#: sequencer.c:4273 sequencer.c:4312
+#, c-format
+msgid "could not write file: '%s'"
+msgstr "impossible d'écrire le fichier : '%s'"
 
-#: builtin/blame.c:795
-msgid "Show porcelain format with per-line commit information"
-msgstr "Afficher en format porcelaine avec l'information de commit par ligne"
+#: sequencer.c:4327
+msgid "could not remove CHERRY_PICK_HEAD"
+msgstr "impossible de supprimer CHERRY_PICK_HEAD"
 
-#: builtin/blame.c:796
-msgid "Use the same output mode as git-annotate (Default: off)"
-msgstr "Utiliser le même mode de sortie que git-annotate (Défaut : désactivé)"
+#: sequencer.c:4334
+msgid "could not commit staged changes."
+msgstr "impossible de valider les modifications indexées."
 
-#: builtin/blame.c:797
-msgid "Show raw timestamp (Default: off)"
-msgstr "Afficher les horodatages bruts (Défaut : désactivé)"
+#: sequencer.c:4440
+#, c-format
+msgid "%s: can't cherry-pick a %s"
+msgstr "%s : impossible de picorer un %s"
 
-#: builtin/blame.c:798
-msgid "Show long commit SHA1 (Default: off)"
-msgstr "Afficher les longs SHA1 de commits (Défaut : désactivé)"
+#: sequencer.c:4444
+#, c-format
+msgid "%s: bad revision"
+msgstr "%s : mauvaise révision"
 
-#: builtin/blame.c:799
-msgid "Suppress author name and timestamp (Default: off)"
-msgstr "Supprimer le nom de l'auteur et l'horodatage (Défaut : désactivé)"
+#: sequencer.c:4479
+msgid "can't revert as initial commit"
+msgstr "impossible d'annuler en tant que commit initial"
 
-#: builtin/blame.c:800
-msgid "Show author email instead of name (Default: off)"
-msgstr "Afficher le courriel de l'auteur au lieu du nom (Défaut : désactivé)"
+#: sequencer.c:4952
+msgid "make_script: unhandled options"
+msgstr "make_script : options non gérées"
 
-#: builtin/blame.c:801
-msgid "Ignore whitespace differences"
-msgstr "Ignorer les différences d'espace"
+#: sequencer.c:4955
+msgid "make_script: error preparing revisions"
+msgstr "make_script : erreur lors de la préparation des révisions"
 
-#: builtin/blame.c:802
-msgid "color redundant metadata from previous line differently"
-msgstr ""
-"colorer différemment les métadonnées redondantes avec la ligne précédente"
+#: sequencer.c:5113
+msgid ""
+"You can fix this with 'git rebase --edit-todo' and then run 'git rebase --"
+"continue'.\n"
+"Or you can abort the rebase with 'git rebase --abort'.\n"
+msgstr ""
+"Vous pouvez corriger ceci avec 'git rebase --edit-todo' puis lancez 'git "
+"rebase --continue'.\n"
+"Ou vous pouvez abandonner le rebasage avec 'git rebase --abort'.\n"
 
-#: builtin/blame.c:803
-msgid "color lines by age"
-msgstr "colorier les lignes par âge"
+#: sequencer.c:5226 sequencer.c:5243
+msgid "nothing to do"
+msgstr "rien à faire"
+
+#: sequencer.c:5257
+msgid "could not skip unnecessary pick commands"
+msgstr "impossible d'éviter les commandes de picorage non nécessaires"
 
-#: builtin/blame.c:810
-msgid "Use an experimental heuristic to improve diffs"
-msgstr "Utiliser une heuristique expérimentale pour améliorer les diffs"
+#: sequencer.c:5351
+msgid "the script was already rearranged."
+msgstr "le script a déjà été réarrangé."
 
-#: builtin/blame.c:812
-msgid "Spend extra cycles to find better match"
+#: setup.c:124
+#, c-format
+msgid "'%s' is outside repository"
+msgstr "'%s' est hors du dépôt"
+
+#: setup.c:174
+#, c-format
+msgid ""
+"%s: no such path in the working tree.\n"
+"Use 'git <command> -- <path>...' to specify paths that do not exist locally."
 msgstr ""
-"Dépenser des cycles supplémentaires pour trouver une meilleure correspondance"
+"%s : ce chemin n'existe pas dans la copie de travail.\n"
+"Utilisez 'git <commande> -- <chemin>...' pour spécifier des chemins qui "
+"n'existent pas localement."
 
-#: builtin/blame.c:813
-msgid "Use revisions from <file> instead of calling git-rev-list"
+#: setup.c:187
+#, c-format
+msgid ""
+"ambiguous argument '%s': unknown revision or path not in the working tree.\n"
+"Use '--' to separate paths from revisions, like this:\n"
+"'git <command> [<revision>...] -- [<file>...]'"
 msgstr ""
-"Utiliser les révisions du fichier <fichier> au lieu d'appeler git-rev-list"
+"argument '%s' ambigu : révision inconnue ou chemin inexistant.\n"
+"Utilisez '--' pour séparer les chemins des révisions, comme ceci :\n"
+"'git <commande> [<révision>...] -- [<chemin>...]'"
 
-#: builtin/blame.c:814
-msgid "Use <file>'s contents as the final image"
-msgstr "Utiliser le contenu de <fichier> comme image finale"
+#: setup.c:236
+#, c-format
+msgid "option '%s' must come before non-option arguments"
+msgstr ""
+"l'option '%s' doit être présente avant les arguments qui ne sont pas des "
+"options"
 
-#: builtin/blame.c:815 builtin/blame.c:816
-msgid "score"
-msgstr "score"
+#: setup.c:255
+#, c-format
+msgid ""
+"ambiguous argument '%s': both revision and filename\n"
+"Use '--' to separate paths from revisions, like this:\n"
+"'git <command> [<revision>...] -- [<file>...]'"
+msgstr ""
+"argument '%s' ambigu : révision et chemin spécifiés.\n"
+"Utilisez '--' pour séparer les chemins des révisions, comme ceci :\n"
+"'git <commande> [<révision>...] -- [<chemin>...]'"
 
-#: builtin/blame.c:815
-msgid "Find line copies within and across files"
-msgstr "Trouver les copies de ligne dans et entre les fichiers"
+#: setup.c:391
+msgid "unable to set up work tree using invalid config"
+msgstr ""
+"impossible de mettre en place le répertoire de travail en utilisant une "
+"configuration invalide"
 
-#: builtin/blame.c:816
-msgid "Find line movements within and across files"
-msgstr "Trouver les mouvements de ligne dans et entre les fichiers"
+#: setup.c:395
+msgid "this operation must be run in a work tree"
+msgstr "Cette opération doit être effectuée dans un arbre de travail"
 
-#: builtin/blame.c:817
-msgid "n,m"
-msgstr "n,m"
+#: setup.c:541
+#, c-format
+msgid "Expected git repo version <= %d, found %d"
+msgstr "Version attendue du dépôt git <= %d, %d trouvée"
 
-#: builtin/blame.c:817
-msgid "Process only line range n,m, counting from 1"
-msgstr ""
-"Traiter seulement l'intervalle de ligne n,m en commençant le compte à 1"
+#: setup.c:549
+msgid "unknown repository extensions found:"
+msgstr "extensions de dépôt inconnues trouvées :"
 
-#: builtin/blame.c:866
-msgid "--progress can't be used with --incremental or porcelain formats"
-msgstr ""
-"--progress ne peut pas être utilisé avec --incremental ou les formats "
-"porcelaine"
+#: setup.c:568
+#, c-format
+msgid "error opening '%s'"
+msgstr "erreur à l'ouverture de '%s'"
 
-#. TRANSLATORS: This string is used to tell us the
-#. maximum display width for a relative timestamp in
-#. "git blame" output.  For C locale, "4 years, 11
-#. months ago", which takes 22 places, is the longest
-#. among various forms of relative timestamps, but
-#. your language may need more or fewer display
-#. columns.
-#.
-#: builtin/blame.c:917
-msgid "4 years, 11 months ago"
-msgstr "il y a 10 ans et 11 mois"
+#: setup.c:570
+#, c-format
+msgid "too large to be a .git file: '%s'"
+msgstr "trop gros pour être une fichier .git : '%s'"
 
-#: builtin/blame.c:1003
+#: setup.c:572
 #, c-format
-msgid "file %s has only %lu line"
-msgid_plural "file %s has only %lu lines"
-msgstr[0] "le fichier %s n'a qu'%lu ligne"
-msgstr[1] "le fichier %s n'a que %lu lignes"
+msgid "error reading %s"
+msgstr "erreur à la lecture de %s"
 
-#: builtin/blame.c:1049
-msgid "Blaming lines"
-msgstr "Assignation de blâme aux lignes"
+#: setup.c:574
+#, c-format
+msgid "invalid gitfile format: %s"
+msgstr "format de fichier git invalide : %s"
 
-#: builtin/branch.c:27
-msgid "git branch [<options>] [-r | -a] [--merged | --no-merged]"
-msgstr "git branch [<options>] [-r | -a] [--merged | --no-merged]"
+#: setup.c:576
+#, c-format
+msgid "no path in gitfile: %s"
+msgstr "aucun chemin dans le fichier git : %s"
 
-#: builtin/branch.c:28
-msgid "git branch [<options>] [-l] [-f] <branch-name> [<start-point>]"
-msgstr "git branch [<options] [-l] [-f] <nom-de-branche> [<point-de-départ>]"
+#: setup.c:578
+#, c-format
+msgid "not a git repository: %s"
+msgstr "ce n'est pas un dépôt git : %s"
 
-#: builtin/branch.c:29
-msgid "git branch [<options>] [-r] (-d | -D) <branch-name>..."
-msgstr "git branch [<options>] [-r] (-d | -D) <nom-de-branche>..."
+#: setup.c:677
+#, c-format
+msgid "'$%s' too big"
+msgstr "'$%s' trop gros"
 
-#: builtin/branch.c:30
-msgid "git branch [<options>] (-m | -M) [<old-branch>] <new-branch>"
-msgstr ""
-"git branch [<options>] (-m | -M) [<ancienne-branche>] <nouvelle-branche>"
+#: setup.c:691
+#, c-format
+msgid "not a git repository: '%s'"
+msgstr "ce n'est pas un dépôt git : '%s'"
 
-#: builtin/branch.c:31
-msgid "git branch [<options>] (-c | -C) [<old-branch>] <new-branch>"
-msgstr ""
-"git branch [<options>] (-c | -C) [<ancienne-branche>] <nouvelle-branche>"
+#: setup.c:720 setup.c:722 setup.c:753
+#, c-format
+msgid "cannot chdir to '%s'"
+msgstr "impossible de se déplacer vers le répertoire (chdir) '%s'"
 
-#: builtin/branch.c:32
-msgid "git branch [<options>] [-r | -a] [--points-at]"
-msgstr "git branch [<options>] [-r | -a] [--points-at]"
+#: setup.c:725 setup.c:781 setup.c:791 setup.c:830 setup.c:838
+msgid "cannot come back to cwd"
+msgstr "impossible de revenir au répertoire de travail courant"
 
-#: builtin/branch.c:33
-msgid "git branch [<options>] [-r | -a] [--format]"
-msgstr "git branch [<options>] [-r | -a] [--format]"
+#: setup.c:852
+#, c-format
+msgid "failed to stat '%*s%s%s'"
+msgstr "échec du stat de '%*s%s%s'"
+
+#: setup.c:1090
+msgid "Unable to read current working directory"
+msgstr "Impossible d'accéder au répertoire de travail courant"
 
-#: builtin/branch.c:146
+#: setup.c:1099 setup.c:1105
 #, c-format
-msgid ""
-"deleting branch '%s' that has been merged to\n"
-"         '%s', but not yet merged to HEAD."
-msgstr ""
-"suppression de la branche '%s' qui a été fusionnée dans\n"
-"         '%s', mais pas dans HEAD."
+msgid "cannot change to '%s'"
+msgstr "impossible de modifier en '%s'"
 
-#: builtin/branch.c:150
+#: setup.c:1110
 #, c-format
-msgid ""
-"not deleting branch '%s' that is not yet merged to\n"
-"         '%s', even though it is merged to HEAD."
-msgstr ""
-"branche '%s' non supprimée car elle n'a pas été fusionnée dans\n"
-"         '%s', même si elle est fusionnée dans HEAD."
+msgid "not a git repository (or any of the parent directories): %s"
+msgstr "ni ceci ni aucun de ses répertoires parents n'est un dépôt git : %s"
 
-#: builtin/branch.c:164
+#: setup.c:1116
 #, c-format
-msgid "Couldn't look up commit object for '%s'"
-msgstr "Impossible de rechercher l'objet commit pour '%s'"
+msgid ""
+"not a git repository (or any parent up to mount point %s)\n"
+"Stopping at filesystem boundary (GIT_DISCOVERY_ACROSS_FILESYSTEM not set)."
+msgstr ""
+"ni ceci ni aucun de ses répertoires parents (jusqu'au point de montage %s) "
+"n'est un dépôt git\n"
+"Arrêt à la limite du système de fichiers (GIT_DISCOVERY_ACROSS_FILESYSTEM "
+"n'est pas défini)."
 
-#: builtin/branch.c:168
+#: setup.c:1227
 #, c-format
 msgid ""
-"The branch '%s' is not fully merged.\n"
-"If you are sure you want to delete it, run 'git branch -D %s'."
+"problem with core.sharedRepository filemode value (0%.3o).\n"
+"The owner of files must always have read and write permissions."
 msgstr ""
-"La branche '%s' n'est pas totalement fusionnée.\n"
-"Si vous souhaitez réellement la supprimer, lancez 'git branch -D %s'."
+"problème avec la valeur de core.sharedRepository (0%.3o).\n"
+"Le propriétaire des fichiers doit toujours avoir les droits en lecture et "
+"écriture."
 
-#: builtin/branch.c:181
-msgid "Update of config-file failed"
-msgstr "Échec de la mise à jour du fichier de configuration"
+#: setup.c:1271
+msgid "open /dev/null or dup failed"
+msgstr "échec de l'ouverture ou au dup de /dev/null"
 
-#: builtin/branch.c:212
-msgid "cannot use -a with -d"
-msgstr "impossible d'utiliser -a avec -d"
+#: setup.c:1286
+msgid "fork failed"
+msgstr "échec de la bifurcation"
 
-#: builtin/branch.c:218
-msgid "Couldn't look up commit object for HEAD"
-msgstr "Impossible de rechercher l'objet commit pour HEAD"
+#: setup.c:1291
+msgid "setsid failed"
+msgstr "échec du setsid"
 
-#: builtin/branch.c:232
+#: sha1-file.c:452
 #, c-format
-msgid "Cannot delete branch '%s' checked out at '%s'"
-msgstr "Impossible de supprimer la branche '%s' extraite dans '%s'"
+msgid "object directory %s does not exist; check .git/objects/info/alternates"
+msgstr ""
+"le répertoire objet %s n'existe pas ; vérifiez .git/objects/info/alternates"
 
-#: builtin/branch.c:247
+#: sha1-file.c:503
 #, c-format
-msgid "remote-tracking branch '%s' not found."
-msgstr "branche de suivi '%s' non trouvée."
+msgid "unable to normalize alternate object path: %s"
+msgstr "impossible de normaliser le chemin d'objet alternatif : %s"
 
-#: builtin/branch.c:248
+#: sha1-file.c:575
 #, c-format
-msgid "branch '%s' not found."
-msgstr "branche '%s' non trouvée."
+msgid "%s: ignoring alternate object stores, nesting too deep"
+msgstr "%s : magasins d'objets alternatifs ignorés, récursion trop profonde"
 
-#: builtin/branch.c:263
+#: sha1-file.c:582
 #, c-format
-msgid "Error deleting remote-tracking branch '%s'"
-msgstr "Erreur lors de la suppression de la branche de suivi '%s'"
+msgid "unable to normalize object directory: %s"
+msgstr "impossible de normaliser le répertoire d'objet : %s"
+
+#: sha1-file.c:625
+msgid "unable to fdopen alternates lockfile"
+msgstr "impossible d'ouvrir (fdopen) le fichier verrou des alternatives"
 
-#: builtin/branch.c:264
+#: sha1-file.c:643
+msgid "unable to read alternates file"
+msgstr "lecture du fichier d'alternatives impossible"
+
+#: sha1-file.c:650
+msgid "unable to move new alternates file into place"
+msgstr "impossible de déplacer le nouveau fichier d'alternative"
+
+#: sha1-file.c:685
 #, c-format
-msgid "Error deleting branch '%s'"
-msgstr "Erreur lors de la suppression de la branche '%s'"
+msgid "path '%s' does not exist"
+msgstr "le chemin '%s' n'existe pas"
 
-#: builtin/branch.c:271
+#: sha1-file.c:711
 #, c-format
-msgid "Deleted remote-tracking branch %s (was %s).\n"
-msgstr "Branche de suivi %s supprimée (précédemment %s).\n"
+msgid "reference repository '%s' as a linked checkout is not supported yet."
+msgstr ""
+"extraire le dépôt de référence '%s' comme une extraction liée n'est pas "
+"encore supporté."
 
-#: builtin/branch.c:272
+#: sha1-file.c:717
 #, c-format
-msgid "Deleted branch %s (was %s).\n"
-msgstr "Branche %s supprimée (précédemment %s).\n"
+msgid "reference repository '%s' is not a local repository."
+msgstr "le dépôt de référence '%s' n'est pas un dépôt local."
 
-#: builtin/branch.c:416 builtin/tag.c:58
-msgid "unable to parse format string"
-msgstr "impossible d'analyser la chaîne de format"
+#: sha1-file.c:723
+#, c-format
+msgid "reference repository '%s' is shallow"
+msgstr "le dépôt de référence '%s' est superficiel"
 
-#: builtin/branch.c:453
+#: sha1-file.c:731
 #, c-format
-msgid "Branch %s is being rebased at %s"
-msgstr "La branche %s est en cours de rebasage sur %s"
+msgid "reference repository '%s' is grafted"
+msgstr "le dépôt de référence '%s' est greffé"
 
-#: builtin/branch.c:457
+#: sha1-file.c:791
 #, c-format
-msgid "Branch %s is being bisected at %s"
-msgstr "La branche %s est en cours de bissection sur %s"
+msgid "invalid line while parsing alternate refs: %s"
+msgstr "ligne invalide pendant l'analyse des refs alternatives : %s"
 
-#: builtin/branch.c:474
-msgid "cannot copy the current branch while not on any."
-msgstr "impossible de copier la branche actuelle, il n'y en a pas."
+#: sha1-file.c:943
+#, c-format
+msgid "attempting to mmap %<PRIuMAX> over limit %<PRIuMAX>"
+msgstr "essai de mmap %<PRIuMAX> au delà de la limite %<PRIuMAX>"
 
-#: builtin/branch.c:476
-msgid "cannot rename the current branch while not on any."
-msgstr "impossible de renommer la branche actuelle, il n'y en a pas."
+#: sha1-file.c:964
+msgid "mmap failed"
+msgstr "échec de mmap"
 
-#: builtin/branch.c:487
+#: sha1-file.c:1128
 #, c-format
-msgid "Invalid branch name: '%s'"
-msgstr "Nom de branche invalide : '%s'"
+msgid "object file %s is empty"
+msgstr "le fichier objet %s est vide"
 
-#: builtin/branch.c:514
-msgid "Branch rename failed"
-msgstr "Échec de renommage de la branche"
+#: sha1-file.c:1252 sha1-file.c:2392
+#, c-format
+msgid "corrupt loose object '%s'"
+msgstr "objet libre corrompu '%s'"
 
-#: builtin/branch.c:516
-msgid "Branch copy failed"
-msgstr "Échec de copie de la branche"
+#: sha1-file.c:1254 sha1-file.c:2396
+#, c-format
+msgid "garbage at end of loose object '%s'"
+msgstr "données incorrectes à la fin de l'objet libre '%s'"
+
+#: sha1-file.c:1296
+msgid "invalid object type"
+msgstr "type d'objet invalide"
 
-#: builtin/branch.c:520
+#: sha1-file.c:1380
 #, c-format
-msgid "Created a copy of a misnamed branch '%s'"
-msgstr "Création d'une copie d'une branche mal nommée '%s'"
+msgid "unable to unpack %s header with --allow-unknown-type"
+msgstr "impossible de dépaqueter l'entête %s avec --allow-unknow-type"
 
-#: builtin/branch.c:523
+#: sha1-file.c:1383
 #, c-format
-msgid "Renamed a misnamed branch '%s' away"
-msgstr "Renommage d'une branche mal nommée '%s'"
+msgid "unable to unpack %s header"
+msgstr "impossible de dépaqueter l'entête %s"
 
-#: builtin/branch.c:529
+#: sha1-file.c:1389
 #, c-format
-msgid "Branch renamed to %s, but HEAD is not updated!"
-msgstr "La branche a été renommée en %s, mais HEAD n'est pas mise à jour !"
+msgid "unable to parse %s header with --allow-unknown-type"
+msgstr "impossible d'analyser l'entête %s avec --allow-unknow-type"
 
-#: builtin/branch.c:538
-msgid "Branch is renamed, but update of config-file failed"
-msgstr ""
-"La branche est renommée, mais la mise à jour du fichier de configuration a "
-"échoué"
+#: sha1-file.c:1392
+#, c-format
+msgid "unable to parse %s header"
+msgstr "impossible d'analyser l'entête %s"
 
-#: builtin/branch.c:540
-msgid "Branch is copied, but update of config-file failed"
-msgstr ""
-"La branche est copiée, mais la mise à jour du fichier de configuration a "
-"échoué"
+#: sha1-file.c:1584
+#, c-format
+msgid "failed to read object %s"
+msgstr "impossible de lire l'objet %s"
 
-#: builtin/branch.c:556
+#: sha1-file.c:1588
 #, c-format
-msgid ""
-"Please edit the description for the branch\n"
-"  %s\n"
-"Lines starting with '%c' will be stripped.\n"
-msgstr ""
-"Veuillez éditer la description de la branche\n"
-"  %s\n"
-"Les lignes commençant par '%c' seront ignorées.\n"
+msgid "replacement %s not found for %s"
+msgstr "remplacement %s non trouvé pour %s"
 
-#: builtin/branch.c:589
-msgid "Generic options"
-msgstr "Options génériques"
+#: sha1-file.c:1592
+#, c-format
+msgid "loose object %s (stored in %s) is corrupt"
+msgstr "l'objet libre %s (stocké dans %s) est corrompu"
 
-#: builtin/branch.c:591
-msgid "show hash and subject, give twice for upstream branch"
-msgstr "afficher le hachage et le sujet, doublé pour la branche amont"
+#: sha1-file.c:1596
+#, c-format
+msgid "packed object %s (stored in %s) is corrupt"
+msgstr "l'objet empaqueté %s (stocké dans %s) est corrompu"
 
-#: builtin/branch.c:592
-msgid "suppress informational messages"
-msgstr "supprimer les messages d'information"
+#: sha1-file.c:1699
+#, c-format
+msgid "unable to write file %s"
+msgstr "impossible d'écrire le fichier %s"
 
-#: builtin/branch.c:593
-msgid "set up tracking mode (see git-pull(1))"
-msgstr "régler le mode de suivi (voir git-pull(1))"
+#: sha1-file.c:1706
+#, c-format
+msgid "unable to set permission to '%s'"
+msgstr "impossible de régler les droits de '%s'"
 
-#: builtin/branch.c:595
-msgid "do not use"
-msgstr "ne pas utiliser"
+#: sha1-file.c:1713
+msgid "file write error"
+msgstr "erreur d'écriture d'un fichier"
 
-#: builtin/branch.c:597
-msgid "upstream"
-msgstr "amont"
+#: sha1-file.c:1732
+msgid "error when closing loose object file"
+msgstr "erreur en fermeture du fichier d'objet esseulé"
 
-#: builtin/branch.c:597
-msgid "change the upstream info"
-msgstr "modifier l'information amont"
+#: sha1-file.c:1797
+#, c-format
+msgid "insufficient permission for adding an object to repository database %s"
+msgstr ""
+"droits insuffisants pour ajouter un objet à la base de données %s du dépôt"
 
-#: builtin/branch.c:598
-msgid "Unset the upstream info"
-msgstr "Désactiver l'information amont"
+#: sha1-file.c:1799
+msgid "unable to create temporary file"
+msgstr "impossible de créer un fichier temporaire"
 
-#: builtin/branch.c:599
-msgid "use colored output"
-msgstr "utiliser la coloration dans la sortie"
+#: sha1-file.c:1823
+msgid "unable to write loose object file"
+msgstr "impossible d'écrire le fichier d'objet esseulé"
 
-#: builtin/branch.c:600
-msgid "act on remote-tracking branches"
-msgstr "agir sur les branches de suivi distantes"
+#: sha1-file.c:1829
+#, c-format
+msgid "unable to deflate new object %s (%d)"
+msgstr "impossible de compresser le nouvel objet %s (%d)"
 
-#: builtin/branch.c:602 builtin/branch.c:604
-msgid "print only branches that contain the commit"
-msgstr "afficher seulement les branches qui contiennent le commit"
+#: sha1-file.c:1833
+#, c-format
+msgid "deflateEnd on object %s failed (%d)"
+msgstr "échec de deflateEnd sur l'objet %s (%d)"
 
-#: builtin/branch.c:603 builtin/branch.c:605
-msgid "print only branches that don't contain the commit"
-msgstr "afficher seulement les branches qui ne contiennent pas le commit"
+#: sha1-file.c:1837
+#, c-format
+msgid "confused by unstable object source data for %s"
+msgstr "données de source d'objet instable pour %s"
 
-#: builtin/branch.c:608
-msgid "Specific git-branch actions:"
-msgstr "Actions spécifiques à git-branch :"
+#: sha1-file.c:1847 builtin/pack-objects.c:925
+#, c-format
+msgid "failed utime() on %s"
+msgstr "échec de utime() sur %s"
 
-#: builtin/branch.c:609
-msgid "list both remote-tracking and local branches"
-msgstr "afficher à la fois les branches de suivi et les branches locales"
+#: sha1-file.c:1922
+#, c-format
+msgid "cannot read object for %s"
+msgstr "impossible de lire l'objet pour %s"
 
-#: builtin/branch.c:611
-msgid "delete fully merged branch"
-msgstr "supprimer une branche totalement fusionnée"
+#: sha1-file.c:1962
+msgid "corrupt commit"
+msgstr "commit corrompu"
 
-#: builtin/branch.c:612
-msgid "delete branch (even if not merged)"
-msgstr "supprimer une branche (même non fusionnée)"
+#: sha1-file.c:1970
+msgid "corrupt tag"
+msgstr "étiquette corrompue"
 
-#: builtin/branch.c:613
-msgid "move/rename a branch and its reflog"
-msgstr "déplacer/renommer une branche et son reflog"
+#: sha1-file.c:2069
+#, c-format
+msgid "read error while indexing %s"
+msgstr "erreur de lecture à l'indexation de %s"
 
-#: builtin/branch.c:614
-msgid "move/rename a branch, even if target exists"
-msgstr "déplacer/renommer une branche, même si la cible existe"
+#: sha1-file.c:2072
+#, c-format
+msgid "short read while indexing %s"
+msgstr "lecture tronquée pendant l'indexation de %s"
 
-#: builtin/branch.c:615
-msgid "copy a branch and its reflog"
-msgstr "copier une branche et son reflog"
+#: sha1-file.c:2145 sha1-file.c:2154
+#, c-format
+msgid "%s: failed to insert into database"
+msgstr "%s : échec de l'insertion dans la base de données"
 
-#: builtin/branch.c:616
-msgid "copy a branch, even if target exists"
-msgstr "copier une branche, même si la cible existe"
+#: sha1-file.c:2160
+#, c-format
+msgid "%s: unsupported file type"
+msgstr "%s : type de fichier non supporté"
 
-#: builtin/branch.c:617
-msgid "list branch names"
-msgstr "afficher les noms des branches"
+#: sha1-file.c:2184
+#, c-format
+msgid "%s is not a valid object"
+msgstr "%s n'est pas un objet valide"
 
-#: builtin/branch.c:618
-msgid "create the branch's reflog"
-msgstr "créer le reflog de la branche"
+#: sha1-file.c:2186
+#, c-format
+msgid "%s is not a valid '%s' object"
+msgstr "%s n'est pas un objet '%s' valide"
 
-#: builtin/branch.c:620
-msgid "edit the description for the branch"
-msgstr "éditer la description de la branche"
+#: sha1-file.c:2213 builtin/index-pack.c:155
+#, c-format
+msgid "unable to open %s"
+msgstr "impossible d'ouvrir %s"
 
-#: builtin/branch.c:621
-msgid "force creation, move/rename, deletion"
-msgstr "forcer la création, le déplacement/renommage, ou la suppression"
+#: sha1-file.c:2403 sha1-file.c:2455
+#, c-format
+msgid "hash mismatch for %s (expected %s)"
+msgstr "incohérence de hachage pour %s (%s attendu)"
 
-#: builtin/branch.c:622
-msgid "print only branches that are merged"
-msgstr "afficher seulement les branches qui sont fusionnées"
+#: sha1-file.c:2427
+#, c-format
+msgid "unable to mmap %s"
+msgstr "impossible de mmap %s"
 
-#: builtin/branch.c:623
-msgid "print only branches that are not merged"
-msgstr "afficher seulement les branches qui ne sont pas fusionnées"
+#: sha1-file.c:2432
+#, c-format
+msgid "unable to unpack header of %s"
+msgstr "impossible de dépaqueter l'entête de %s"
 
-#: builtin/branch.c:624
-msgid "list branches in columns"
-msgstr "afficher les branches en colonnes"
+#: sha1-file.c:2438
+#, c-format
+msgid "unable to parse header of %s"
+msgstr "impossible d'analyser l'entête de %s"
 
-#: builtin/branch.c:625 builtin/for-each-ref.c:40 builtin/ls-remote.c:70
-#: builtin/tag.c:412
-msgid "key"
-msgstr "clé"
+#: sha1-file.c:2449
+#, c-format
+msgid "unable to unpack contents of %s"
+msgstr "impossible de dépaqueter le contenu de %s"
 
-#: builtin/branch.c:626 builtin/for-each-ref.c:41 builtin/ls-remote.c:71
-#: builtin/tag.c:413
-msgid "field name to sort on"
-msgstr "nom du champ servant à trier"
+#: sha1-name.c:487
+#, c-format
+msgid "short SHA1 %s is ambiguous"
+msgstr "le SHA1 court %s est ambigu"
 
-#: builtin/branch.c:628 builtin/for-each-ref.c:43 builtin/notes.c:408
-#: builtin/notes.c:411 builtin/notes.c:571 builtin/notes.c:574
-#: builtin/tag.c:415
-msgid "object"
-msgstr "objet"
+#: sha1-name.c:498
+msgid "The candidates are:"
+msgstr "Les candidats sont :"
 
-#: builtin/branch.c:629
-msgid "print only branches of the object"
-msgstr "afficher seulement les branches de l'objet"
+#: sha1-name.c:797
+msgid ""
+"Git normally never creates a ref that ends with 40 hex characters\n"
+"because it will be ignored when you just specify 40-hex. These refs\n"
+"may be created by mistake. For example,\n"
+"\n"
+"  git switch -c $br $(git rev-parse ...)\n"
+"\n"
+"where \"$br\" is somehow empty and a 40-hex ref is created. Please\n"
+"examine these refs and maybe delete them. Turn this message off by\n"
+"running \"git config advice.objectNameWarning false\""
+msgstr ""
+"Git ne crée normalement jamais de référence qui se termine par 40\n"
+"caractères hexa car elle serait ignorée si vous spécifiez juste\n"
+"40-hexa. Ces références peuvent être créées par erreur. Par exemple,\n"
+"\n"
+"  git switch -c $br $(git rev-parse ...)\n"
+"\n"
+"où \"$br\" est d'une manière ou d'une autre vide et une référence 40-hexa "
+"est créée.\n"
+"Veuillez examiner ces références et peut-être les supprimer. Désactivez ce "
+"message\n"
+"en lançant \"git config advice.objectNameWarning false\""
 
-#: builtin/branch.c:631 builtin/for-each-ref.c:49 builtin/tag.c:422
-msgid "sorting and filtering are case insensitive"
-msgstr "le tri et le filtrage sont non-sensibles à la casse"
+#. TRANSLATORS: IEC 80000-13:2008 gibibyte
+#: strbuf.c:822
+#, c-format
+msgid "%u.%2.2u GiB"
+msgstr "%u.%2.2u Gio"
 
-#: builtin/branch.c:632 builtin/for-each-ref.c:38 builtin/tag.c:420
-#: builtin/verify-tag.c:39
-msgid "format to use for the output"
-msgstr "format à utiliser pour la sortie"
+#. TRANSLATORS: IEC 80000-13:2008 gibibyte/second
+#: strbuf.c:824
+#, c-format
+msgid "%u.%2.2u GiB/s"
+msgstr "%u.%2.2u Gio/s"
 
-#: builtin/branch.c:655 builtin/clone.c:737
-msgid "HEAD not found below refs/heads!"
-msgstr "HEAD non trouvée sous refs/heads !"
+#. TRANSLATORS: IEC 80000-13:2008 mebibyte
+#: strbuf.c:832
+#, c-format
+msgid "%u.%2.2u MiB"
+msgstr "%u.%2.2u Mio"
 
-#: builtin/branch.c:678
-msgid "--column and --verbose are incompatible"
-msgstr "--column et --verbose sont incompatibles"
+#. TRANSLATORS: IEC 80000-13:2008 mebibyte/second
+#: strbuf.c:834
+#, c-format
+msgid "%u.%2.2u MiB/s"
+msgstr "%u.%2.2u Mio/s"
 
-#: builtin/branch.c:693 builtin/branch.c:745 builtin/branch.c:754
-msgid "branch name required"
-msgstr "le nom de branche est requis"
+#. TRANSLATORS: IEC 80000-13:2008 kibibyte
+#: strbuf.c:841
+#, c-format
+msgid "%u.%2.2u KiB"
+msgstr "%u.%2.2u Kio"
 
-#: builtin/branch.c:721
-msgid "Cannot give description to detached HEAD"
-msgstr "Impossible de décrire une HEAD détachée"
+#. TRANSLATORS: IEC 80000-13:2008 kibibyte/second
+#: strbuf.c:843
+#, c-format
+msgid "%u.%2.2u KiB/s"
+msgstr "%u.%2.2u Kio/s"
 
-#: builtin/branch.c:726
-msgid "cannot edit description of more than one branch"
-msgstr "impossible d'éditer la description de plus d'une branche"
+#. TRANSLATORS: IEC 80000-13:2008 byte
+#: strbuf.c:849
+#, c-format
+msgid "%u byte"
+msgid_plural "%u bytes"
+msgstr[0] "%u octet"
+msgstr[1] "%u octets"
 
-#: builtin/branch.c:733
+#. TRANSLATORS: IEC 80000-13:2008 byte/second
+#: strbuf.c:851
 #, c-format
-msgid "No commit on branch '%s' yet."
-msgstr "Aucun commit sur la branche '%s'."
+msgid "%u byte/s"
+msgid_plural "%u bytes/s"
+msgstr[0] "%u octet/s"
+msgstr[1] "%u octets/s"
 
-#: builtin/branch.c:736
+#: strbuf.c:1149
 #, c-format
-msgid "No branch named '%s'."
-msgstr "Aucune branche nommée '%s'."
+msgid "could not edit '%s'"
+msgstr "impossible d'éditer '%s'"
 
-#: builtin/branch.c:751
-msgid "too many branches for a copy operation"
-msgstr "trop de branches pour une opération de copie"
+#: submodule.c:114 submodule.c:143
+msgid "Cannot change unmerged .gitmodules, resolve merge conflicts first"
+msgstr ""
+"Modification impossible de .gitmodules non fusionné, résolvez les conflits "
+"d'abord"
 
-#: builtin/branch.c:760
-msgid "too many arguments for a rename operation"
-msgstr "trop d'arguments pour une opération de renommage"
+#: submodule.c:118 submodule.c:147
+#, c-format
+msgid "Could not find section in .gitmodules where path=%s"
+msgstr "Impossible de trouver une section où path=%s dans .gitmodules"
 
-#: builtin/branch.c:765
-msgid "too many arguments to set new upstream"
-msgstr "trop d'arguments pour spécifier une branche amont"
+# ici %s est un chemin
+#: submodule.c:154
+#, c-format
+msgid "Could not remove .gitmodules entry for %s"
+msgstr "Impossible de supprimer l'élément de .gitmodules pour %s"
+
+#: submodule.c:165
+msgid "staging updated .gitmodules failed"
+msgstr "échec de la mise en index du .gitmodules mis à jour"
 
-#: builtin/branch.c:769
+#: submodule.c:327
 #, c-format
-msgid ""
-"could not set upstream of HEAD to %s when it does not point to any branch."
-msgstr ""
-"impossible de spécifier une branche amont de HEAD par %s qui ne pointe sur "
-"aucune branche."
+msgid "in unpopulated submodule '%s'"
+msgstr "dans le sous-module '%s' non populé"
 
-#: builtin/branch.c:772 builtin/branch.c:794 builtin/branch.c:810
+#: submodule.c:358
 #, c-format
-msgid "no such branch '%s'"
-msgstr "pas de branche '%s'"
+msgid "Pathspec '%s' is in submodule '%.*s'"
+msgstr "Le chemin '%s' est dans le sous-module '%.*s'"
 
-#: builtin/branch.c:776
+#: submodule.c:910
 #, c-format
-msgid "branch '%s' does not exist"
-msgstr "la branche '%s' n'existe pas"
+msgid "submodule entry '%s' (%s) is a %s, not a commit"
+msgstr "l'entrée de sous-module '%s' (%s) est un %s, pas un commit"
 
-#: builtin/branch.c:788
-msgid "too many arguments to unset upstream"
-msgstr "trop d'arguments pour désactiver un amont"
+#: submodule.c:1147 builtin/branch.c:680 builtin/submodule--helper.c:2016
+msgid "Failed to resolve HEAD as a valid ref."
+msgstr "Échec de résolution de HEAD comme référence valide."
 
-#: builtin/branch.c:792
-msgid "could not unset upstream of HEAD when it does not point to any branch."
-msgstr ""
-"impossible de désactiver une branche amont de HEAD quand elle ne pointe sur "
-"aucune branche."
+#: submodule.c:1481
+#, c-format
+msgid "Could not access submodule '%s'"
+msgstr "Impossible d'accéder au sous-module '%s'"
 
-#: builtin/branch.c:798
+#: submodule.c:1651
 #, c-format
-msgid "Branch '%s' has no upstream information"
-msgstr "La branche '%s' n'a aucune information de branche amont"
+msgid "'%s' not recognized as a git repository"
+msgstr "'%s' n'est pas reconnu comme dépôt git"
 
-#: builtin/branch.c:813
-msgid "-a and -r options to 'git branch' do not make sense with a branch name"
-msgstr ""
-"les options -a et -r de 'git branch' n'ont pas de sens avec un nom de branche"
+#: submodule.c:1789
+#, c-format
+msgid "could not start 'git status' in submodule '%s'"
+msgstr "impossible de démarrer 'git status' dans le sous-module '%s'"
 
-#: builtin/branch.c:816
-msgid ""
-"the '--set-upstream' option is no longer supported. Please use '--track' or "
-"'--set-upstream-to' instead."
-msgstr ""
-"l'option '--set-upstream' est obsolète. Utilisez '--track' ou '--set-"
-"upstream-to' à la place."
+#: submodule.c:1802
+#, c-format
+msgid "could not run 'git status' in submodule '%s'"
+msgstr "impossible de lancer 'git status' dans le sous-module '%s'"
 
-#: builtin/bundle.c:45
+#: submodule.c:1817
 #, c-format
-msgid "%s is okay\n"
-msgstr "%s est correct\n"
+msgid "Could not unset core.worktree setting in submodule '%s'"
+msgstr "Impossible de désactiver core.worktree dans le sous-module '%s'"
 
-#: builtin/bundle.c:58
-msgid "Need a repository to create a bundle."
-msgstr "La création d'un colis requiert un dépôt."
+#: submodule.c:1907
+#, c-format
+msgid "submodule '%s' has dirty index"
+msgstr "le sous-module '%s' a un index sale"
 
-#: builtin/bundle.c:62
-msgid "Need a repository to unbundle."
-msgstr "Le dépaquetage d'un colis requiert un dépôt."
+#: submodule.c:1959
+#, c-format
+msgid "Submodule '%s' could not be updated."
+msgstr "le sous-module '%s' n'a pas pu être mis à jour."
 
-#: builtin/cat-file.c:525
-msgid ""
-"git cat-file (-t [--allow-unknown-type] | -s [--allow-unknown-type] | -e | -"
-"p | <type> | --textconv | --filters) [--path=<path>] <object>"
-msgstr ""
-"git cat-file (-t [--allow-unknow-type] | -s [--allow-unknow-type] | -e | -p "
-"| <type> | --textconv | --filters) [--path=<chemin>] <objet>"
+#: submodule.c:2027
+#, c-format
+msgid "submodule git dir '%s' is inside git dir '%.*s'"
+msgstr "le répertoire git du sous-module '%s' est à l'intérieur du répertoire git '%.*s'"
 
-#: builtin/cat-file.c:526
+#: submodule.c:2048
+#, c-format
 msgid ""
-"git cat-file (--batch | --batch-check) [--follow-symlinks] [--textconv | --"
-"filters]"
+"relocate_gitdir for submodule '%s' with more than one worktree not supported"
 msgstr ""
-"git cat-file (--batch | --batch-check) [--follow-symlinks] [--textconv | --"
-"filters]"
+"relocate_gitdir pour le sous-module '%s' avec plus d'un arbre de travail "
+"n'est pas supporté"
 
-#: builtin/cat-file.c:563
-msgid "<type> can be one of: blob, tree, commit, tag"
-msgstr "<type> peut être : blob, tree, commit ou tag"
+#: submodule.c:2060 submodule.c:2119
+#, c-format
+msgid "could not lookup name for submodule '%s'"
+msgstr "impossible de trouve le nom pour le sous-module '%s'"
 
-#: builtin/cat-file.c:564
-msgid "show object type"
-msgstr "afficher le type de l'objet"
+#: submodule.c:2064
+#, c-format
+msgid "refusing to move '%s' into an existing git dir"
+msgstr "refus de déplacer '%s' dans une répertoire git existant"
 
-#: builtin/cat-file.c:565
-msgid "show object size"
-msgstr "afficher la taille de l'objet"
+#: submodule.c:2071
+#, c-format
+msgid ""
+"Migrating git directory of '%s%s' from\n"
+"'%s' to\n"
+"'%s'\n"
+msgstr ""
+"Migration du répertoire git de '%s%s' depuis\n"
+"'%s' sur\n"
+"'%s'\n"
 
-#: builtin/cat-file.c:567
-msgid "exit with zero when there's no error"
-msgstr "sortir avec un code d'erreur nul quand il n'y a aucune erreur"
+#: submodule.c:2154
+#, c-format
+msgid "could not recurse into submodule '%s'"
+msgstr "récursion impossible dans le sous-module '%s'"
 
-#: builtin/cat-file.c:568
-msgid "pretty-print object's content"
-msgstr "afficher avec mise en forme le contenu de l'objet"
+#: submodule.c:2198
+msgid "could not start ls-files in .."
+msgstr "impossible de démarrer ls-files dans .."
 
-#: builtin/cat-file.c:570
-msgid "for blob objects, run textconv on object's content"
-msgstr "pour les objets blob, lancer textconv sur le contenu de l'objet"
+#: submodule.c:2237
+#, c-format
+msgid "ls-tree returned unexpected return code %d"
+msgstr "ls-tree a renvoyé un code de retour inattendu %d"
 
-#: builtin/cat-file.c:572
-msgid "for blob objects, run filters on object's content"
-msgstr "pour les objets blob, lancer les filtres sur le contenu de l'objet"
+#: submodule-config.c:236
+#, c-format
+msgid "ignoring suspicious submodule name: %s"
+msgstr "nom de sous-module suspicieux %s ignoré"
 
-#: builtin/cat-file.c:573 git-submodule.sh:894
-msgid "blob"
-msgstr "blob"
+#: submodule-config.c:303
+msgid "negative values not allowed for submodule.fetchjobs"
+msgstr "les valeurs négatives ne sont pas permises pour submodule.fetchJobs"
 
-#: builtin/cat-file.c:574
-msgid "use a specific path for --textconv/--filters"
-msgstr "utiliser un chemin spécifique pour --textconv/--filters"
+#: submodule-config.c:401
+#, c-format
+msgid "ignoring '%s' which may be interpreted as a command-line option: %s"
+msgstr ""
+"'%s' ignoré et qui peut être interprété comme une option de ligne de "
+"commande : %s"
 
-#: builtin/cat-file.c:576
-msgid "allow -s and -t to work with broken/corrupt objects"
-msgstr "autoriser -s et -t à travailler sur des objets cassés/corrompus"
+#: submodule-config.c:498
+#, c-format
+msgid "invalid value for %s"
+msgstr "Valeur invalide pour %s"
 
-#: builtin/cat-file.c:577
-msgid "buffer --batch output"
-msgstr "bufferiser la sortie de --batch"
+#: submodule-config.c:769
+#, c-format
+msgid "Could not update .gitmodules entry %s"
+msgstr "Impossible de mettre à jour l'élément %s de .gitmodules"
 
-#: builtin/cat-file.c:579
-msgid "show info and content of objects fed from the standard input"
-msgstr ""
-"afficher l'information et le contenu des objets passés en entrée standard"
+#: trailer.c:238
+#, c-format
+msgid "running trailer command '%s' failed"
+msgstr "échec de la commande trailer '%s'"
 
-#: builtin/cat-file.c:582
-msgid "show info about objects fed from the standard input"
-msgstr "afficher l'information des objets passés en entrée standard"
+#: trailer.c:485 trailer.c:490 trailer.c:495 trailer.c:549 trailer.c:553
+#: trailer.c:557
+#, c-format
+msgid "unknown value '%s' for key '%s'"
+msgstr "valeur inconnue '%s' pour la clé '%s'"
 
-#: builtin/cat-file.c:585
-msgid "follow in-tree symlinks (used with --batch or --batch-check)"
-msgstr ""
-"suivre les liens symbolique internes à la copie de travail (utilisé avec --"
-"batch ou --batch-check)"
+#: trailer.c:539 trailer.c:544 builtin/remote.c:295
+#, c-format
+msgid "more than one %s"
+msgstr "plus d'un %s"
 
-#: builtin/cat-file.c:587
-msgid "show all objects with --batch or --batch-check"
-msgstr "montrer tous les objets avec --batch ou --batch-check"
+#: trailer.c:730
+#, c-format
+msgid "empty trailer token in trailer '%.*s'"
+msgstr "symbole vide dans la ligne de fin '%.*s'"
 
-#: builtin/check-attr.c:12
-msgid "git check-attr [-a | --all | <attr>...] [--] <pathname>..."
-msgstr "git check-attr [-a | --all | <attr>...] [--] <chemin>..."
+#: trailer.c:750
+#, c-format
+msgid "could not read input file '%s'"
+msgstr "impossible de lire le fichier d'entrée '%s'"
 
-#: builtin/check-attr.c:13
-msgid "git check-attr --stdin [-z] [-a | --all | <attr>...]"
-msgstr "git check-attr --stdin [-z] [-a | --all | <attr>...]"
+#: trailer.c:753
+msgid "could not read from stdin"
+msgstr "Impossible de lire depuis l'entrée standard"
 
-#: builtin/check-attr.c:20
-msgid "report all attributes set on file"
-msgstr "afficher tous les attributs associés au fichier"
+#: trailer.c:1011 wrapper.c:665
+#, c-format
+msgid "could not stat %s"
+msgstr "stat impossible de %s"
 
-#: builtin/check-attr.c:21
-msgid "use .gitattributes only from the index"
-msgstr "utiliser .gitattributes seulement depuis l'index"
+#: trailer.c:1013
+#, c-format
+msgid "file %s is not a regular file"
+msgstr "%s n'est pas un fichier régulier"
 
-#: builtin/check-attr.c:22 builtin/check-ignore.c:24 builtin/hash-object.c:100
-msgid "read file names from stdin"
-msgstr "lire les noms de fichier depuis l'entrée standard"
+#: trailer.c:1015
+#, c-format
+msgid "file %s is not writable by user"
+msgstr "le fichier %s n'est pas inscriptible par l'utilisateur"
 
-#: builtin/check-attr.c:24 builtin/check-ignore.c:26
-msgid "terminate input and output records by a NUL character"
-msgstr ""
-"terminer les enregistrements en entrée et en sortie par un caractère NUL"
+#: trailer.c:1027
+msgid "could not open temporary file"
+msgstr "impossible de créer un fichier temporaire"
 
-#: builtin/check-ignore.c:20 builtin/checkout.c:1113 builtin/gc.c:500
-msgid "suppress progress reporting"
-msgstr "supprimer l'état d'avancement"
+#: trailer.c:1067
+#, c-format
+msgid "could not rename temporary file to %s"
+msgstr "impossible de renommer un fichier temporaire en %s"
 
-#: builtin/check-ignore.c:28
-msgid "show non-matching input paths"
-msgstr "afficher les chemins en entrée qui ne correspondent pas"
+#: transport.c:116
+#, c-format
+msgid "Would set upstream of '%s' to '%s' of '%s'\n"
+msgstr "Positionnerait la branche amont de '%s' sur '%s' de '%s'\n"
 
-#: builtin/check-ignore.c:30
-msgid "ignore index when checking"
-msgstr "ignorer l'index pendant la vérification"
+#: transport.c:145
+#, c-format
+msgid "could not read bundle '%s'"
+msgstr "impossible de lire la liasse '%s'"
 
-#: builtin/check-ignore.c:159
-msgid "cannot specify pathnames with --stdin"
-msgstr "impossible de spécifier les chemins avec --stdin"
+#: transport.c:214
+#, c-format
+msgid "transport: invalid depth option '%s'"
+msgstr "transport : option de profondeur invalide '%s'"
 
-#: builtin/check-ignore.c:162
-msgid "-z only makes sense with --stdin"
-msgstr "-z n'a de sens qu'avec l'option --stdin"
+#: transport.c:266
+msgid "see protocol.version in 'git help config' for more details"
+msgstr "voir protocol.version dans 'git help config' pour plus d'information"
+
+#: transport.c:267
+msgid "server options require protocol version 2 or later"
+msgstr "les options de serveur exigent une version 2 ou supérieure"
 
-#: builtin/check-ignore.c:164
-msgid "no path specified"
-msgstr "aucun chemin spécifié"
+#: transport.c:632
+msgid "could not parse transport.color.* config"
+msgstr "impossible d'analyser la configuration transport.color.*"
 
-#: builtin/check-ignore.c:168
-msgid "--quiet is only valid with a single pathname"
-msgstr "--quiet n'est valide qu'avec un seul chemin"
+#: transport.c:705
+msgid "support for protocol v2 not implemented yet"
+msgstr "le support du protocole v2 n'est pas encore implanté"
 
-#: builtin/check-ignore.c:170
-msgid "cannot have both --quiet and --verbose"
-msgstr "impossible d'avoir --quiet et --verbose"
+#: transport.c:831
+#, c-format
+msgid "unknown value for config '%s': %s"
+msgstr "valeur inconnue pour la config '%s' : %s"
 
-#: builtin/check-ignore.c:173
-msgid "--non-matching is only valid with --verbose"
-msgstr "--non-matching n'est valide qu'avec --verbose"
+#: transport.c:897
+#, c-format
+msgid "transport '%s' not allowed"
+msgstr "transport '%s' non permis"
 
-#: builtin/check-mailmap.c:9
-msgid "git check-mailmap [<options>] <contact>..."
-msgstr "git check-mailmap [<options>] <contact>..."
+#: transport.c:949
+msgid "git-over-rsync is no longer supported"
+msgstr "git-over-rsync n'est plus supporté"
 
-#: builtin/check-mailmap.c:14
-msgid "also read contacts from stdin"
-msgstr "lire aussi les contacts depuis l'entrée standard"
+#: transport.c:1044
+#, c-format
+msgid ""
+"The following submodule paths contain changes that can\n"
+"not be found on any remote:\n"
+msgstr ""
+"Les chemins suivants de sous-module contiennent des modifications\n"
+"qui ne peuvent être trouvées sur aucun distant :\n"
 
-#: builtin/check-mailmap.c:25
+#: transport.c:1048
 #, c-format
-msgid "unable to parse contact: %s"
-msgstr "impossible d'analyser le contact : %s"
+msgid ""
+"\n"
+"Please try\n"
+"\n"
+"\tgit push --recurse-submodules=on-demand\n"
+"\n"
+"or cd to the path and use\n"
+"\n"
+"\tgit push\n"
+"\n"
+"to push them to a remote.\n"
+"\n"
+msgstr ""
+"\n"
+"Veuillez essayer\n"
+"\n"
+"\tgit push --recurse-submodules=on-demand\n"
+"\n"
+"ou bien changez de répertoire et utilisez\n"
+"\n"
+"\tgit push\n"
+"\n"
+"pour les pousser vers un serveur distant.\n"
+"\n"
 
-#: builtin/check-mailmap.c:48
-msgid "no contacts specified"
-msgstr "aucun contact spécifié"
+#: transport.c:1056
+msgid "Aborting."
+msgstr "Abandon."
 
-#: builtin/checkout-index.c:128
-msgid "git checkout-index [<options>] [--] [<file>...]"
-msgstr "git checkout-index [<options>] [--] [<fichier>...]"
+#: transport.c:1201
+msgid "failed to push all needed submodules"
+msgstr "échec de la poussée de tous les sous-modules nécessaires"
 
-#: builtin/checkout-index.c:143
-msgid "stage should be between 1 and 3 or all"
-msgstr "stage doit valoir entre 1 et 3, ou all"
+#: transport.c:1345 transport-helper.c:656
+msgid "operation not supported by protocol"
+msgstr "option non supportée par le protocole"
 
-#: builtin/checkout-index.c:159
-msgid "check out all files in the index"
-msgstr "extraire tous les fichiers présents dans l'index"
+#: transport-helper.c:61 transport-helper.c:90
+msgid "full write to remote helper failed"
+msgstr "échec de l'écriture totale sur l'assistant distant"
 
-#: builtin/checkout-index.c:160
-msgid "force overwrite of existing files"
-msgstr "forcer l'écrasement des fichiers existants"
+#: transport-helper.c:144
+#, c-format
+msgid "unable to find remote helper for '%s'"
+msgstr "Impossible de trouver un assistant distant pour '%s'"
 
-#: builtin/checkout-index.c:162
-msgid "no warning for existing files and files not in index"
+#: transport-helper.c:160 transport-helper.c:570
+msgid "can't dup helper output fd"
 msgstr ""
-"pas d'avertissement pour les fichiers existants et les fichiers absents de "
-"l'index"
+"impossible de dupliquer le descripteur de flux de sortie de l'assistant"
 
-#: builtin/checkout-index.c:164
-msgid "don't checkout new files"
-msgstr "ne pas extraire les nouveaux fichiers"
+#: transport-helper.c:211
+#, c-format
+msgid ""
+"unknown mandatory capability %s; this remote helper probably needs newer "
+"version of Git"
+msgstr ""
+"capacité obligatoire inconnue %s ; cet assistant distant requiert "
+"probablement une une nouvelle version de Git"
 
-#: builtin/checkout-index.c:166
-msgid "update stat information in the index file"
-msgstr "mettre à jour l'information de stat dans le fichier d'index"
+#: transport-helper.c:217
+msgid "this remote helper should implement refspec capability"
+msgstr "cet assistant distant devrait supporter la capacité refspec"
 
-#: builtin/checkout-index.c:170
-msgid "read list of paths from the standard input"
-msgstr "lire la liste des chemins depuis l'entrée standard"
+#: transport-helper.c:284 transport-helper.c:424
+#, c-format
+msgid "%s unexpectedly said: '%s'"
+msgstr "%s a dit de manière inattendue : '%s'"
 
-#: builtin/checkout-index.c:172
-msgid "write the content to temporary files"
-msgstr "écrire le contenu dans des fichiers temporaires"
+#: transport-helper.c:413
+#, c-format
+msgid "%s also locked %s"
+msgstr "%s a aussi verrouillé %s"
 
-#: builtin/checkout-index.c:173 builtin/column.c:31
-#: builtin/submodule--helper.c:1216 builtin/submodule--helper.c:1219
-#: builtin/submodule--helper.c:1227 builtin/submodule--helper.c:1591
-#: builtin/worktree.c:610
-msgid "string"
-msgstr "chaîne"
+#: transport-helper.c:492
+msgid "couldn't run fast-import"
+msgstr "impossible de lancer fast-import"
 
-#: builtin/checkout-index.c:174
-msgid "when creating files, prepend <string>"
-msgstr "lors de la création de fichiers, préfixer par <chaîne>"
+#: transport-helper.c:515
+msgid "error while running fast-import"
+msgstr "erreur au lancement de fast-import"
 
-#: builtin/checkout-index.c:176
-msgid "copy out the files from named stage"
-msgstr "copier les fichiers depuis l'index nommé"
+#: transport-helper.c:544 transport-helper.c:1133
+#, c-format
+msgid "could not read ref %s"
+msgstr "impossible de lire la réf %s"
 
-#: builtin/checkout.c:27
-msgid "git checkout [<options>] <branch>"
-msgstr "git checkout [<options>] <branche>"
+#: transport-helper.c:589
+#, c-format
+msgid "unknown response to connect: %s"
+msgstr "réponse inconnue à connect : %s"
 
-#: builtin/checkout.c:28
-msgid "git checkout [<options>] [<branch>] -- <file>..."
-msgstr "git checkout [<options>] [<branche>] -- <fichier>..."
+#: transport-helper.c:611
+msgid "setting remote service path not supported by protocol"
+msgstr ""
+"la spécification du chemin de service distant n'est pas supportée par le "
+"protocole"
 
-#: builtin/checkout.c:136 builtin/checkout.c:169
-#, c-format
-msgid "path '%s' does not have our version"
-msgstr "le chemin '%s' n'a pas notre version"
+#: transport-helper.c:613
+msgid "invalid remote service path"
+msgstr "chemin de service distant invalide"
 
-#: builtin/checkout.c:138 builtin/checkout.c:171
+#: transport-helper.c:659
 #, c-format
-msgid "path '%s' does not have their version"
-msgstr "le chemin '%s' n'a pas leur version"
+msgid "can't connect to subservice %s"
+msgstr "impossible de se connecter au sous-service %s"
 
-#: builtin/checkout.c:154
+#: transport-helper.c:735
 #, c-format
-msgid "path '%s' does not have all necessary versions"
-msgstr "le chemin '%s' n'a aucune des versions nécessaires"
+msgid "expected ok/error, helper said '%s'"
+msgstr "ok/error attendu, l'assistant a dit '%s'"
 
-#: builtin/checkout.c:198
+#: transport-helper.c:788
 #, c-format
-msgid "path '%s' does not have necessary versions"
-msgstr "le chemin '%s' n'a pas les versions nécessaires"
+msgid "helper reported unexpected status of %s"
+msgstr "l'assistant a renvoyé un statut de retour inattendu %s"
 
-#: builtin/checkout.c:215
+#: transport-helper.c:849
 #, c-format
-msgid "path '%s': cannot merge"
-msgstr "chemin '%s' : impossible de fusionner"
+msgid "helper %s does not support dry-run"
+msgstr "l'assistant %s ne gère pas dry-run"
 
-#: builtin/checkout.c:231
+#: transport-helper.c:852
 #, c-format
-msgid "Unable to add merge result for '%s'"
-msgstr "Impossible d'ajouter le résultat de fusion pour '%s'"
+msgid "helper %s does not support --signed"
+msgstr "l'assistant %s ne gère pas --signed"
 
-#: builtin/checkout.c:253 builtin/checkout.c:256 builtin/checkout.c:259
-#: builtin/checkout.c:262
+#: transport-helper.c:855
 #, c-format
-msgid "'%s' cannot be used with updating paths"
-msgstr "'%s' ne peut pas être utilisé avec des mises à jour de chemins"
+msgid "helper %s does not support --signed=if-asked"
+msgstr "l'assistant %s ne gère pas --signed=if-asked"
 
-#: builtin/checkout.c:265 builtin/checkout.c:268
+#: transport-helper.c:860
 #, c-format
-msgid "'%s' cannot be used with %s"
-msgstr "'%s' ne peut pas être utilisé avec %s"
+msgid "helper %s does not support --atomic"
+msgstr "l'assistant %s ne gère pas --atomic"
 
-#: builtin/checkout.c:271
+#: transport-helper.c:866
 #, c-format
-msgid "Cannot update paths and switch to branch '%s' at the same time."
+msgid "helper %s does not support 'push-option'"
+msgstr "l'assistant %s ne gère pas 'push-option'"
+
+#: transport-helper.c:964
+msgid "remote-helper doesn't support push; refspec needed"
 msgstr ""
-"Impossible de mettre à jour les chemins et basculer sur la branche '%s' en "
-"même temps."
+"l'assistant %s ne gère pas push ; un spécificateur de référence est "
+"nécessaire"
 
-#: builtin/checkout.c:340 builtin/checkout.c:347
+#: transport-helper.c:969
 #, c-format
-msgid "path '%s' is unmerged"
-msgstr "le chemin '%s' n'est pas fusionné"
+msgid "helper %s does not support 'force'"
+msgstr "l'assistant %s ne gère pas 'force'"
 
-#: builtin/checkout.c:506
-msgid "you need to resolve your current index first"
-msgstr "vous devez d'abord résoudre votre index courant"
+#: transport-helper.c:1016
+msgid "couldn't run fast-export"
+msgstr "impossible de lancer fast-export"
+
+#: transport-helper.c:1021
+msgid "error while running fast-export"
+msgstr "erreur au lancement de fast-export"
 
-#: builtin/checkout.c:643
+#: transport-helper.c:1046
 #, c-format
-msgid "Can not do reflog for '%s': %s\n"
-msgstr "Impossible de faire un reflog pour '%s' : %s\n"
+msgid ""
+"No refs in common and none specified; doing nothing.\n"
+"Perhaps you should specify a branch such as 'master'.\n"
+msgstr ""
+"Aucune référence en commun et aucune spécfiée ; rien à faire.\n"
+"Vous devriez peut-être spécifier une branche telle que 'master'.\n"
 
-#: builtin/checkout.c:684
-msgid "HEAD is now at"
-msgstr "HEAD est maintenant sur"
-
-#: builtin/checkout.c:688 builtin/clone.c:691
-msgid "unable to update HEAD"
-msgstr "impossible de mettre à jour HEAD"
-
-#: builtin/checkout.c:692
+#: transport-helper.c:1119
 #, c-format
-msgid "Reset branch '%s'\n"
-msgstr "Remise à zéro de la branche '%s'\n"
+msgid "malformed response in ref list: %s"
+msgstr "réponse malformée dans le liste de réfs : %s"
 
-#: builtin/checkout.c:695
+#: transport-helper.c:1271
 #, c-format
-msgid "Already on '%s'\n"
-msgstr "Déjà sur '%s'\n"
+msgid "read(%s) failed"
+msgstr "échec de read(%s)"
 
-#: builtin/checkout.c:699
+#: transport-helper.c:1298
 #, c-format
-msgid "Switched to and reset branch '%s'\n"
-msgstr "Basculement et remise à zéro de la branche '%s'\n"
+msgid "write(%s) failed"
+msgstr "échec de write(%s)"
 
-#: builtin/checkout.c:701 builtin/checkout.c:1046
+#: transport-helper.c:1347
 #, c-format
-msgid "Switched to a new branch '%s'\n"
-msgstr "Basculement sur la nouvelle branche '%s'\n"
+msgid "%s thread failed"
+msgstr "échec du fil d'exécution %s"
 
-#: builtin/checkout.c:703
+#: transport-helper.c:1351
 #, c-format
-msgid "Switched to branch '%s'\n"
-msgstr "Basculement sur la branche '%s'\n"
+msgid "%s thread failed to join: %s"
+msgstr "échec de jonction du fil d'exécution %s : %s"
 
-#: builtin/checkout.c:754
+#: transport-helper.c:1370 transport-helper.c:1374
 #, c-format
-msgid " ... and %d more.\n"
-msgstr " ... et %d en plus.\n"
+msgid "can't start thread for copying data: %s"
+msgstr "impossible de démarrer le fil d'exécution pour copier les données : %s"
 
-#: builtin/checkout.c:760
+#: transport-helper.c:1411
 #, c-format
-msgid ""
-"Warning: you are leaving %d commit behind, not connected to\n"
-"any of your branches:\n"
-"\n"
-"%s\n"
-msgid_plural ""
-"Warning: you are leaving %d commits behind, not connected to\n"
-"any of your branches:\n"
-"\n"
-"%s\n"
-msgstr[0] ""
-"Attention : vous abandonnez %d commit, non connecté à\n"
-"une branche :\n"
-"\n"
-"%s\n"
-msgstr[1] ""
-"Attention : vous abandonnez %d commits, non connectés à\n"
-"une branche :\n"
-"\n"
-"%s\n"
+msgid "%s process failed to wait"
+msgstr "échec du processus %s pour l'attente"
 
-#: builtin/checkout.c:779
+#: transport-helper.c:1415
 #, c-format
-msgid ""
-"If you want to keep it by creating a new branch, this may be a good time\n"
-"to do so with:\n"
-"\n"
-" git branch <new-branch-name> %s\n"
-"\n"
-msgid_plural ""
-"If you want to keep them by creating a new branch, this may be a good time\n"
-"to do so with:\n"
-"\n"
-" git branch <new-branch-name> %s\n"
-"\n"
-msgstr[0] ""
-"Si vous souhaitez le garder en créant une nouvelle branche, c'est le bon "
-"moment\n"
-"pour le faire avec :\n"
-"\n"
-"git branch <nouvelle-branche> %s\n"
-"\n"
-msgstr[1] ""
-"Si vous souhaitez les garder en créant une nouvelle branche, c'est le bon "
-"moment\n"
-"pour le faire avec :\n"
-"\n"
-"git branch <nouvelle-branche> %s\n"
-"\n"
+msgid "%s process failed"
+msgstr "échec du processus %s"
 
-#: builtin/checkout.c:811
-msgid "internal error in revision walk"
-msgstr "erreur interne lors du parcours des révisions"
-
-#: builtin/checkout.c:815
-msgid "Previous HEAD position was"
-msgstr "La position précédente de HEAD était sur"
+#: transport-helper.c:1433 transport-helper.c:1442
+msgid "can't start thread for copying data"
+msgstr "impossible de démarrer le fil d'exécution pour copier les données"
 
-#: builtin/checkout.c:843 builtin/checkout.c:1041
-msgid "You are on a branch yet to be born"
-msgstr "Vous êtes sur une branche qui doit encore naître"
+#: tree-walk.c:33
+msgid "too-short tree object"
+msgstr "objet arbre trop court"
 
-#: builtin/checkout.c:947
-#, c-format
-msgid "only one reference expected, %d given."
-msgstr "une seule référence attendue, %d fournies."
+#: tree-walk.c:39
+msgid "malformed mode in tree entry"
+msgstr "mode invalide dans l'entrée d'arbre"
 
-#: builtin/checkout.c:987 builtin/worktree.c:240 builtin/worktree.c:389
-#, c-format
-msgid "invalid reference: %s"
-msgstr "référence invalide : %s"
+#: tree-walk.c:43
+msgid "empty filename in tree entry"
+msgstr "nom de fichier vide dans une entrée de l'arbre"
 
-#: builtin/checkout.c:1016
+#: tree-walk.c:48
 #, c-format
-msgid "reference is not a tree: %s"
-msgstr "la référence n'est pas un arbre : %s"
+msgid "filename in tree entry contains backslash: '%s'"
+msgstr "le nom du fichier dans l'entrée de l'arbre contient une barre oblique inversée : '%s'"
 
-#: builtin/checkout.c:1055
-msgid "paths cannot be used with switching branches"
-msgstr "impossible d'utiliser des chemins avec un basculement de branches"
+#: tree-walk.c:124
+msgid "too-short tree file"
+msgstr "fichier arbre trop court"
 
-#: builtin/checkout.c:1058 builtin/checkout.c:1062
+#: unpack-trees.c:110
 #, c-format
-msgid "'%s' cannot be used with switching branches"
-msgstr "'%s' ne peut pas être utilisé avec un basculement de branches"
+msgid ""
+"Your local changes to the following files would be overwritten by checkout:\n"
+"%%sPlease commit your changes or stash them before you switch branches."
+msgstr ""
+"Vos modifications locales aux fichiers suivants seraient écrasées par "
+"l'extraction :\n"
+"%%sVeuillez valider ou remiser vos modifications avant de basculer de "
+"branche."
 
-#: builtin/checkout.c:1066 builtin/checkout.c:1069 builtin/checkout.c:1074
-#: builtin/checkout.c:1077
+#: unpack-trees.c:112
 #, c-format
-msgid "'%s' cannot be used with '%s'"
-msgstr "'%s' ne peut pas être utilisé avec '%s'"
+msgid ""
+"Your local changes to the following files would be overwritten by checkout:\n"
+"%%s"
+msgstr ""
+"Vos modifications locales aux fichiers suivants seraient écrasées par "
+"l'extraction :\n"
+"%%s"
 
-#: builtin/checkout.c:1082
+#: unpack-trees.c:115
 #, c-format
-msgid "Cannot switch branch to a non-commit '%s'"
-msgstr "Impossible de basculer de branche vers '%s' qui n'est pas un commit"
-
-#: builtin/checkout.c:1114 builtin/checkout.c:1116 builtin/clone.c:118
-#: builtin/remote.c:167 builtin/remote.c:169 builtin/worktree.c:433
-#: builtin/worktree.c:435
-msgid "branch"
-msgstr "branche"
-
-#: builtin/checkout.c:1115
-msgid "create and checkout a new branch"
-msgstr "créer et extraire une nouvelle branche"
-
-#: builtin/checkout.c:1117
-msgid "create/reset and checkout a branch"
-msgstr "créer/réinitialiser et extraire une branche"
-
-#: builtin/checkout.c:1118
-msgid "create reflog for new branch"
-msgstr "créer un reflog pour une nouvelle branche"
-
-#: builtin/checkout.c:1119 builtin/worktree.c:437
-msgid "detach HEAD at named commit"
-msgstr "détacher la HEAD au commit nommé"
-
-#: builtin/checkout.c:1120
-msgid "set upstream info for new branch"
-msgstr "paramétrer les coordonnées de branche amont pour une nouvelle branche"
-
-#: builtin/checkout.c:1122
-msgid "new-branch"
-msgstr "nouvelle branche"
-
-#: builtin/checkout.c:1122
-msgid "new unparented branch"
-msgstr "nouvelle branche sans parent"
-
-#: builtin/checkout.c:1123
-msgid "checkout our version for unmerged files"
-msgstr "extraire notre version pour les fichiers non fusionnés"
-
-#: builtin/checkout.c:1125
-msgid "checkout their version for unmerged files"
-msgstr "extraire leur version pour les fichiers non fusionnés"
-
-#: builtin/checkout.c:1127
-msgid "force checkout (throw away local modifications)"
-msgstr "forcer l'extraction (laisser tomber les modifications locales)"
-
-#: builtin/checkout.c:1129
-msgid "perform a 3-way merge with the new branch"
-msgstr "effectuer une fusion à 3 points avec la nouvelle branche"
-
-#: builtin/checkout.c:1131 builtin/merge.c:241
-msgid "update ignored files (default)"
-msgstr "mettre à jour les fichiers ignorés (par défaut)"
-
-#: builtin/checkout.c:1133 builtin/log.c:1499 parse-options.h:264
-msgid "style"
-msgstr "style"
-
-#: builtin/checkout.c:1134
-msgid "conflict style (merge or diff3)"
-msgstr "style de conflit (merge (fusion) ou diff3)"
-
-#: builtin/checkout.c:1137
-msgid "do not limit pathspecs to sparse entries only"
-msgstr "ne pas limiter les spécificateurs de chemins aux seuls éléments creux"
-
-#: builtin/checkout.c:1139
-msgid "second guess 'git checkout <no-such-branch>'"
-msgstr "réessayer d'interpréter 'git checkout <branche-inexistante>'"
-
-#: builtin/checkout.c:1141
-msgid "do not check if another worktree is holding the given ref"
+msgid ""
+"Your local changes to the following files would be overwritten by merge:\n"
+"%%sPlease commit your changes or stash them before you merge."
 msgstr ""
-"ne pas vérifier si une autre copie de travail contient le référence fournie"
-
-#: builtin/checkout.c:1145 builtin/clone.c:85 builtin/fetch.c:149
-#: builtin/merge.c:238 builtin/pull.c:128 builtin/push.c:572
-#: builtin/send-pack.c:174
-msgid "force progress reporting"
-msgstr "forcer l'affichage de l'état d'avancement"
-
-#: builtin/checkout.c:1175
-msgid "-b, -B and --orphan are mutually exclusive"
-msgstr "-b, -B et --orphan sont mutuellement exclusifs"
-
-#: builtin/checkout.c:1192
-msgid "--track needs a branch name"
-msgstr "--track requiert un nom de branche"
-
-#: builtin/checkout.c:1197
-msgid "Missing branch name; try -b"
-msgstr "Nom de branche manquant ; essayez -b"
-
-#: builtin/checkout.c:1233
-msgid "invalid path specification"
-msgstr "spécification de chemin invalide"
+"Vos modifications locales aux fichiers suivants seraient écrasées par la "
+"fusion :\n"
+"%%sVeuillez valider ou remiser vos modifications avant la fusion."
 
-#: builtin/checkout.c:1240
+#: unpack-trees.c:117
 #, c-format
-msgid "'%s' is not a commit and a branch '%s' cannot be created from it"
+msgid ""
+"Your local changes to the following files would be overwritten by merge:\n"
+"%%s"
 msgstr ""
-"'%s' n'est pas un commit et une branche '%s' ne peut pas en être créée depuis"
+"Vos modifications locales aux fichiers suivants seraient écrasées par la "
+"fusion :\n"
+"%%s"
 
-#: builtin/checkout.c:1244
+#: unpack-trees.c:120
 #, c-format
-msgid "git checkout: --detach does not take a path argument '%s'"
-msgstr "git checkout: --detach n'accepte pas un argument de chemin '%s'"
-
-#: builtin/checkout.c:1248
 msgid ""
-"git checkout: --ours/--theirs, --force and --merge are incompatible when\n"
-"checking out of the index."
+"Your local changes to the following files would be overwritten by %s:\n"
+"%%sPlease commit your changes or stash them before you %s."
 msgstr ""
-"git checkout: --ours/--theirs, --force et --merge sont incompatibles lors\n"
-"de l'extraction de l'index."
+"Vos modifications locales aux fichiers suivants seraient écrasées par %s :\n"
+"%%sVeuillez valider ou remiser vos modifications avant %s."
 
-#: builtin/clean.c:26
+#: unpack-trees.c:122
+#, c-format
 msgid ""
-"git clean [-d] [-f] [-i] [-n] [-q] [-e <pattern>] [-x | -X] [--] <paths>..."
+"Your local changes to the following files would be overwritten by %s:\n"
+"%%s"
 msgstr ""
-"git clean [-d] [-f] [-i] [-n] [-q] [-e <motif>] [-x | -X] [--] <chemins>..."
+"Vos modifications locales aux fichiers suivants seraient écrasées par %s :\n"
+"%%s"
 
-#: builtin/clean.c:30
+#: unpack-trees.c:127
 #, c-format
-msgid "Removing %s\n"
-msgstr "Suppression de %s\n"
+msgid ""
+"Updating the following directories would lose untracked files in them:\n"
+"%s"
+msgstr ""
+"La mise à jour des répertoires suivants effacerait les fichiers non suivis "
+"contenus :\n"
+"%s"
 
-#: builtin/clean.c:31
+#: unpack-trees.c:131
 #, c-format
-msgid "Would remove %s\n"
-msgstr "Supprimerait %s\n"
+msgid ""
+"The following untracked working tree files would be removed by checkout:\n"
+"%%sPlease move or remove them before you switch branches."
+msgstr ""
+"Les fichiers suivants non suivis de la copie de travail seraient effacés par "
+"l'extraction :\n"
+"%%sVeuillez renommer ou effacer ces fichiers avant de basculer de branche."
 
-#: builtin/clean.c:32
+#: unpack-trees.c:133
 #, c-format
-msgid "Skipping repository %s\n"
-msgstr "Ignore le dépôt %s\n"
+msgid ""
+"The following untracked working tree files would be removed by checkout:\n"
+"%%s"
+msgstr ""
+"Les fichiers suivants non suivis seraient effacés par l'extraction :\n"
+"%%s"
 
-#: builtin/clean.c:33
+#: unpack-trees.c:136
 #, c-format
-msgid "Would skip repository %s\n"
-msgstr "Ignorerait le dépôt %s\n"
+msgid ""
+"The following untracked working tree files would be removed by merge:\n"
+"%%sPlease move or remove them before you merge."
+msgstr ""
+"Les fichiers suivants non suivis de la copie de travail seraient effacés par "
+"la fusion :\n"
+"%%sVeuillez renommer ou effacer ces fichiers avant la fusion."
 
-#: builtin/clean.c:34
+#: unpack-trees.c:138
 #, c-format
-msgid "failed to remove %s"
-msgstr "échec de la suppression de %s"
+msgid ""
+"The following untracked working tree files would be removed by merge:\n"
+"%%s"
+msgstr ""
+"Les fichiers suivants non suivis seraient effacés par la fusion :\n"
+"%%s"
 
-#: builtin/clean.c:302 git-add--interactive.perl:579
+#: unpack-trees.c:141
 #, c-format
 msgid ""
-"Prompt help:\n"
-"1          - select a numbered item\n"
-"foo        - select item based on unique prefix\n"
-"           - (empty) select nothing\n"
+"The following untracked working tree files would be removed by %s:\n"
+"%%sPlease move or remove them before you %s."
 msgstr ""
-"Aide en ligne :\n"
-"1           - sélectionner un élément numéroté\n"
-"foo         - sélectionner un élément par un préfixe unique\n"
-"            - (vide) ne rien sélectionner\n"
+"Les fichiers suivants non suivis de la copie de travail seraient effacés par "
+"%s :\n"
+"%%sVeuillez renommer ou effacer ces fichiers avant %s."
 
-#: builtin/clean.c:306 git-add--interactive.perl:588
+#: unpack-trees.c:143
 #, c-format
 msgid ""
-"Prompt help:\n"
-"1          - select a single item\n"
-"3-5        - select a range of items\n"
-"2-3,6-9    - select multiple ranges\n"
-"foo        - select item based on unique prefix\n"
-"-...       - unselect specified items\n"
-"*          - choose all items\n"
-"           - (empty) finish selecting\n"
+"The following untracked working tree files would be removed by %s:\n"
+"%%s"
 msgstr ""
-"Aide en ligne :\n"
-"1          - sélectionner un seul élément\n"
-"3-5        - sélectionner une plage d'éléments\n"
-"2-3,6-9    - sélectionner plusieurs plages\n"
-"foo        - sélectionner un élément par un préfixe unique\n"
-"-...       - désélectionner les éléments spécifiés\n"
-"*          - choisir tous les éléments\n"
-"           - (vide) terminer la sélection\n"
+"Les fichiers suivants non suivis seraient effacés par %s :\n"
+"%%s"
 
-#: builtin/clean.c:522 git-add--interactive.perl:554
-#: git-add--interactive.perl:559
-#, c-format, perl-format
-msgid "Huh (%s)?\n"
-msgstr "Hein (%s) ?\n"
+#: unpack-trees.c:149
+#, c-format
+msgid ""
+"The following untracked working tree files would be overwritten by "
+"checkout:\n"
+"%%sPlease move or remove them before you switch branches."
+msgstr ""
+"Les fichiers suivants non suivis de la copie de travail seraient écrasés par "
+"l'extraction :\n"
+"%%sVeuillez renommer ou effacer ces fichiers avant de basculer de branche."
 
-#: builtin/clean.c:664
+#: unpack-trees.c:151
 #, c-format
-msgid "Input ignore patterns>> "
-msgstr "Entrez les motifs à ignorer>> "
+msgid ""
+"The following untracked working tree files would be overwritten by "
+"checkout:\n"
+"%%s"
+msgstr ""
+"Les fichiers suivants non suivis seraient écrasés par l'extraction :\n"
+"%%s"
 
-#: builtin/clean.c:701
+#: unpack-trees.c:154
 #, c-format
-msgid "WARNING: Cannot find items matched by: %s"
-msgstr "ATTENTION : Impossible de trouver les éléments correspondant à : %s"
+msgid ""
+"The following untracked working tree files would be overwritten by merge:\n"
+"%%sPlease move or remove them before you merge."
+msgstr ""
+"Les fichiers suivants non suivis de la copie de travail seraient effacés par "
+"la fusion :\n"
+"%%sVeuillez renommer ou effacer ces fichiers avant la fusion."
 
-#: builtin/clean.c:722
-msgid "Select items to delete"
-msgstr "Sélectionner les éléments à supprimer"
+#: unpack-trees.c:156
+#, c-format
+msgid ""
+"The following untracked working tree files would be overwritten by merge:\n"
+"%%s"
+msgstr ""
+"Les fichiers suivants non suivis seraient écrasés par la fusion :\n"
+"%%s"
 
-#. TRANSLATORS: Make sure to keep [y/N] as is
-#: builtin/clean.c:763
+#: unpack-trees.c:159
 #, c-format
-msgid "Remove %s [y/N]? "
-msgstr "Supprimer %s [y/N] ? "
+msgid ""
+"The following untracked working tree files would be overwritten by %s:\n"
+"%%sPlease move or remove them before you %s."
+msgstr ""
+"Les fichiers suivants non suivis de la copie de travail seraient écrasés par "
+"%s :\n"
+"%%sVeuillez renommer ou effacer ces fichiers avant %s."
 
-#: builtin/clean.c:788 git-add--interactive.perl:1717
+#: unpack-trees.c:161
 #, c-format
-msgid "Bye.\n"
-msgstr "Au revoir.\n"
+msgid ""
+"The following untracked working tree files would be overwritten by %s:\n"
+"%%s"
+msgstr ""
+"Les fichiers suivants non suivis seraient écrasés par %s :\n"
+"%%s"
+
+#: unpack-trees.c:169
+#, c-format
+msgid "Entry '%s' overlaps with '%s'.  Cannot bind."
+msgstr "L'entrée '%s' surcharge avec '%s'. Affectation impossible."
 
-#: builtin/clean.c:796
+#: unpack-trees.c:172
+#, c-format
 msgid ""
-"clean               - start cleaning\n"
-"filter by pattern   - exclude items from deletion\n"
-"select by numbers   - select items to be deleted by numbers\n"
-"ask each            - confirm each deletion (like \"rm -i\")\n"
-"quit                - stop cleaning\n"
-"help                - this screen\n"
-"?                   - help for prompt selection"
+"Cannot update sparse checkout: the following entries are not up to date:\n"
+"%s"
 msgstr ""
-"clean               - démarrer le nettoyage\n"
-"filter by pattern   - exclure des éléments par motif\n"
-"select by numbers   - sélectionner les éléments à supprimer par numéros\n"
-"ask each            - confirmer chaque suppression (comme \"rm -i\")\n"
-"quit                - arrêter le nettoyage\n"
-"help                - cet écran\n"
-"?                   - aide pour la sélection en ligne"
+"Mise à jour d'extraction creuse impossible : les entrées suivantes ne sont "
+"pas à jour :\n"
+"%s"
 
-#: builtin/clean.c:823 git-add--interactive.perl:1793
-msgid "*** Commands ***"
-msgstr "*** Commandes ***"
+#: unpack-trees.c:174
+#, c-format
+msgid ""
+"The following working tree files would be overwritten by sparse checkout "
+"update:\n"
+"%s"
+msgstr ""
+"Les fichiers suivants de la copie de travail seraient écrasés par la mise à "
+"jour par l'extraction creuse :\n"
+"%s"
 
-#: builtin/clean.c:824 git-add--interactive.perl:1790
-msgid "What now"
-msgstr "Et maintenant ?"
+#: unpack-trees.c:176
+#, c-format
+msgid ""
+"The following working tree files would be removed by sparse checkout "
+"update:\n"
+"%s"
+msgstr ""
+"Les fichiers suivants de la copie de travail seraient supprimés par la mise "
+"à jour par extraction creuse :\n"
+"%s"
 
-#: builtin/clean.c:832
-msgid "Would remove the following item:"
-msgid_plural "Would remove the following items:"
-msgstr[0] "Supprimerait l'élément suivant :"
-msgstr[1] "Supprimerait les éléments suivants :"
+#: unpack-trees.c:178
+#, c-format
+msgid ""
+"Cannot update submodule:\n"
+"%s"
+msgstr ""
+"Mise à jour impossible pour le sous-module :\n"
+"%s"
 
-#: builtin/clean.c:848
-msgid "No more files to clean, exiting."
-msgstr "Plus de fichier à nettoyer, sortie."
+#: unpack-trees.c:255
+#, c-format
+msgid "Aborting\n"
+msgstr "Abandon\n"
 
-#: builtin/clean.c:910
-msgid "do not print names of files removed"
-msgstr "ne pas afficher les noms des fichiers supprimés"
+#: unpack-trees.c:317
+msgid "Updating files"
+msgstr "Mise à jour des fichiers"
+
+#: unpack-trees.c:349
+msgid ""
+"the following paths have collided (e.g. case-sensitive paths\n"
+"on a case-insensitive filesystem) and only one from the same\n"
+"colliding group is in the working tree:\n"
+msgstr ""
+"Les chemins suivants sont en collision (par exemple par des chemins\n"
+"sensibles à la casse dans une système de fichier insensible) et un\n"
+"seul du groupe en collision est dans l'arbre de travail :\n"
+
+#: unpack-trees.c:1441
+msgid "Updating index flags"
+msgstr "Mise à jour des drapeaux de l'index"
 
-#: builtin/clean.c:912
-msgid "force"
-msgstr "forcer"
+#: urlmatch.c:163
+msgid "invalid URL scheme name or missing '://' suffix"
+msgstr "nom de schéma d'URL invalide ou suffixe '://' manquant"
 
-#: builtin/clean.c:913
-msgid "interactive cleaning"
-msgstr "nettoyage interactif"
+#: urlmatch.c:187 urlmatch.c:346 urlmatch.c:405
+#, c-format
+msgid "invalid %XX escape sequence"
+msgstr "séquence d'échappement %XX invalide"
 
-#: builtin/clean.c:915
-msgid "remove whole directories"
-msgstr "supprimer les répertoires entiers"
+#: urlmatch.c:215
+msgid "missing host and scheme is not 'file:'"
+msgstr "hôte manquant et le schéma n'est pas 'file:'"
 
-#: builtin/clean.c:916 builtin/describe.c:533 builtin/describe.c:535
-#: builtin/grep.c:871 builtin/log.c:157 builtin/log.c:159
-#: builtin/ls-files.c:548 builtin/name-rev.c:397 builtin/name-rev.c:399
-#: builtin/show-ref.c:176
-msgid "pattern"
-msgstr "motif"
+#: urlmatch.c:232
+msgid "a 'file:' URL may not have a port number"
+msgstr "une URL 'file:' ne peut pas contenir de numéro de port"
 
-#: builtin/clean.c:917
-msgid "add <pattern> to ignore rules"
-msgstr "ajouter <motif> aux règles ignore"
+#: urlmatch.c:247
+msgid "invalid characters in host name"
+msgstr "caractères invalides dans le nom d'hôte"
 
-#: builtin/clean.c:918
-msgid "remove ignored files, too"
-msgstr "supprimer les fichiers ignorés, aussi"
+#: urlmatch.c:292 urlmatch.c:303
+msgid "invalid port number"
+msgstr "numéro de port invalide"
 
-#: builtin/clean.c:920
-msgid "remove only ignored files"
-msgstr "supprimer seulement les fichiers ignorés"
+#: urlmatch.c:371
+msgid "invalid '..' path segment"
+msgstr "segment de chemin '..' invalide"
 
-#: builtin/clean.c:938
-msgid "-x and -X cannot be used together"
-msgstr "-x et -X ne peuvent pas être utilisés ensemble"
+#: worktree.c:258 builtin/am.c:2084
+#, c-format
+msgid "failed to read '%s'"
+msgstr "échec de la lecture de '%s'"
 
-#: builtin/clean.c:942
-msgid ""
-"clean.requireForce set to true and neither -i, -n, nor -f given; refusing to "
-"clean"
+#: worktree.c:304
+#, c-format
+msgid "'%s' at main working tree is not the repository directory"
 msgstr ""
-"clean.requireForce positionné à true et ni -i, -n ou -f fourni ; refus de "
-"nettoyer"
+"'%s' dans l'arbre de travail principal n'est pas le répertoire de dépôt"
 
-#: builtin/clean.c:945
-msgid ""
-"clean.requireForce defaults to true and neither -i, -n, nor -f given; "
-"refusing to clean"
+#: worktree.c:315
+#, c-format
+msgid "'%s' file does not contain absolute path to the working tree location"
 msgstr ""
-"clean.requireForce à true par défaut et ni -i, -n ou -f fourni ; refus de "
-"nettoyer"
+"le fichier '%s' ne contient pas de chemin absolu à l'emplacement de l'arbre "
+"de travail"
 
-#: builtin/clone.c:42
-msgid "git clone [<options>] [--] <repo> [<dir>]"
-msgstr "git clone [<options>] [--] <dépôt> [<répertoire>]"
+#: worktree.c:327
+#, c-format
+msgid "'%s' does not exist"
+msgstr "'%s' n'existe pas"
 
-#: builtin/clone.c:87
-msgid "don't create a checkout"
-msgstr "ne pas créer d'extraction"
+#: worktree.c:333
+#, c-format
+msgid "'%s' is not a .git file, error code %d"
+msgstr "'%s' n'est pas un fichier .git, code d'erreur %d"
 
-#: builtin/clone.c:88 builtin/clone.c:90 builtin/init-db.c:479
-msgid "create a bare repository"
-msgstr "créer un dépôt nu"
+#: worktree.c:341
+#, c-format
+msgid "'%s' does not point back to '%s'"
+msgstr "'%s' ne pointe pas en retour sur '%s'"
 
-#: builtin/clone.c:92
-msgid "create a mirror repository (implies bare)"
-msgstr "créer un dépôt miroir (implique dépôt nu)"
+#: wrapper.c:186 wrapper.c:356
+#, c-format
+msgid "could not open '%s' for reading and writing"
+msgstr "impossible d'ouvrir '%s' en lecture/écriture"
 
-#: builtin/clone.c:94
-msgid "to clone from a local repository"
-msgstr "pour cloner depuis un dépôt local"
+#: wrapper.c:387 wrapper.c:588
+#, c-format
+msgid "unable to access '%s'"
+msgstr "impossible d'accéder à '%s'"
 
-#: builtin/clone.c:96
-msgid "don't use local hardlinks, always copy"
-msgstr "ne pas utiliser de liens durs locaux, toujours copier"
+#: wrapper.c:596
+msgid "unable to get current working directory"
+msgstr "impossible d'accéder au répertoire de travail courant"
 
-#: builtin/clone.c:98
-msgid "setup as shared repository"
-msgstr "régler comme dépôt partagé"
+#: wt-status.c:158
+msgid "Unmerged paths:"
+msgstr "Chemins non fusionnés :"
 
-#: builtin/clone.c:100 builtin/clone.c:104
-msgid "pathspec"
-msgstr "spécificateur de chemin"
+#: wt-status.c:187 wt-status.c:219
+msgid "  (use \"git restore --staged <file>...\" to unstage)"
+msgstr "  (utilisez \"git restore --staged <fichier>...\" pour désindexer)"
 
-#: builtin/clone.c:100 builtin/clone.c:104
-msgid "initialize submodules in the clone"
-msgstr "initialiser les sous-modules dans le clone"
+#: wt-status.c:190 wt-status.c:222
+#, c-format
+msgid "  (use \"git restore --source=%s --staged <file>...\" to unstage)"
+msgstr ""
+"  (utilisez \"git restore --source=%s --staged <fichier>...\" pour "
+"désindexer)"
 
-#: builtin/clone.c:107
-msgid "number of submodules cloned in parallel"
-msgstr "nombre de sous-modules clonés en parallèle"
+#: wt-status.c:193 wt-status.c:225
+msgid "  (use \"git rm --cached <file>...\" to unstage)"
+msgstr "  (utilisez \"git rm --cached <fichier>...\" pour désindexer)"
 
-#: builtin/clone.c:108 builtin/init-db.c:476
-msgid "template-directory"
-msgstr "répertoire-modèle"
+#: wt-status.c:197
+msgid "  (use \"git add <file>...\" to mark resolution)"
+msgstr "  (utilisez \"git add <fichier>...\" pour marquer comme résolu)"
 
-#: builtin/clone.c:109 builtin/init-db.c:477
-msgid "directory from which templates will be used"
-msgstr "répertoire depuis lequel les modèles vont être utilisés"
+#: wt-status.c:199 wt-status.c:203
+msgid "  (use \"git add/rm <file>...\" as appropriate to mark resolution)"
+msgstr ""
+"  (utilisez \"git add/rm <fichier>...\" si nécessaire pour marquer comme "
+"résolu)"
 
-#: builtin/clone.c:111 builtin/clone.c:113 builtin/submodule--helper.c:1223
-#: builtin/submodule--helper.c:1594
-msgid "reference repository"
-msgstr "dépôt de référence"
+#: wt-status.c:201
+msgid "  (use \"git rm <file>...\" to mark resolution)"
+msgstr "  (utilisez \"git rm <fichier>...\" pour marquer comme résolu)"
 
-#: builtin/clone.c:115 builtin/submodule--helper.c:1225
-#: builtin/submodule--helper.c:1596
-msgid "use --reference only while cloning"
-msgstr "utiliser seulement --reference pour cloner"
+#: wt-status.c:211 wt-status.c:1074
+msgid "Changes to be committed:"
+msgstr "Modifications qui seront validées :"
 
-#: builtin/clone.c:116 builtin/column.c:27 builtin/merge-file.c:44
-#: builtin/pack-objects.c:3166 builtin/repack.c:213
-msgid "name"
-msgstr "nom"
+#: wt-status.c:234 wt-status.c:1083
+msgid "Changes not staged for commit:"
+msgstr "Modifications qui ne seront pas validées :"
 
-#: builtin/clone.c:117
-msgid "use <name> instead of 'origin' to track upstream"
-msgstr "utiliser <nom> au lieu de 'origin' pour suivre la branche amont"
+#: wt-status.c:238
+msgid "  (use \"git add <file>...\" to update what will be committed)"
+msgstr ""
+"  (utilisez \"git add <fichier>...\" pour mettre à jour ce qui sera validé)"
 
-#: builtin/clone.c:119
-msgid "checkout <branch> instead of the remote's HEAD"
-msgstr "extraire <branche> au lieu de la HEAD du répertoire distant"
+#: wt-status.c:240
+msgid "  (use \"git add/rm <file>...\" to update what will be committed)"
+msgstr ""
+"  (utilisez \"git add/rm <fichier>...\" pour mettre à jour ce qui sera "
+"validé)"
 
-#: builtin/clone.c:121
-msgid "path to git-upload-pack on the remote"
-msgstr "chemin vers git-upload-pack sur le serveur distant"
+#: wt-status.c:241
+msgid ""
+"  (use \"git restore <file>...\" to discard changes in working directory)"
+msgstr ""
+"  (utilisez \"git restore <fichier>...\" pour annuler les modifications dans "
+"le répertoire de travail)"
 
-#: builtin/clone.c:122 builtin/fetch.c:150 builtin/grep.c:813
-#: builtin/pull.c:216
-msgid "depth"
-msgstr "profondeur"
+#: wt-status.c:243
+msgid "  (commit or discard the untracked or modified content in submodules)"
+msgstr ""
+"  (valider ou annuler le contenu non suivi ou modifié dans les sous-modules)"
 
-#: builtin/clone.c:123
-msgid "create a shallow clone of that depth"
-msgstr "créer un clone superficiel de cette profondeur"
+#: wt-status.c:254
+#, c-format
+msgid "  (use \"git %s <file>...\" to include in what will be committed)"
+msgstr ""
+"  (utilisez \"git %s <fichier>...\" pour inclure dans ce qui sera validé)"
 
-#: builtin/clone.c:124 builtin/fetch.c:152 builtin/pack-objects.c:3157
-#: parse-options.h:154
-msgid "time"
-msgstr "heure"
+#: wt-status.c:268
+msgid "both deleted:"
+msgstr "supprimé des deux côtés :"
 
-#: builtin/clone.c:125
-msgid "create a shallow clone since a specific time"
-msgstr "créer un clone superficiel depuis une date spécifique"
+#: wt-status.c:270
+msgid "added by us:"
+msgstr "ajouté par nous :"
 
-#: builtin/clone.c:126 builtin/fetch.c:154
-msgid "revision"
-msgstr "révision"
+#: wt-status.c:272
+msgid "deleted by them:"
+msgstr "supprimé par eux :"
 
-#: builtin/clone.c:127 builtin/fetch.c:155
-msgid "deepen history of shallow clone, excluding rev"
-msgstr ""
-"approfondir l'historique d'un clone superficiel en excluant une révision"
+#: wt-status.c:274
+msgid "added by them:"
+msgstr "ajouté par eux :"
 
-#: builtin/clone.c:129
-msgid "clone only one branch, HEAD or --branch"
-msgstr "cloner seulement une branche, HEAD ou --branch"
+#: wt-status.c:276
+msgid "deleted by us:"
+msgstr "supprimé par nous :"
 
-#: builtin/clone.c:131
-msgid "don't clone any tags, and make later fetches not to follow them"
-msgstr ""
-"ne pas cloner les tags et indiquer aux récupérations futures de ne pas le "
-"faire"
+#: wt-status.c:278
+msgid "both added:"
+msgstr "ajouté de deux côtés :"
 
-#: builtin/clone.c:133
-msgid "any cloned submodules will be shallow"
-msgstr "tous les sous-modules clonés seront superficiels"
+#: wt-status.c:280
+msgid "both modified:"
+msgstr "modifié des deux côtés :"
 
-#: builtin/clone.c:134 builtin/init-db.c:485
-msgid "gitdir"
-msgstr "gitdir"
+#: wt-status.c:290
+msgid "new file:"
+msgstr "nouveau fichier :"
 
-#: builtin/clone.c:135 builtin/init-db.c:486
-msgid "separate git dir from working tree"
-msgstr "séparer le répertoire git de la copie de travail"
+#: wt-status.c:292
+msgid "copied:"
+msgstr "copié :"
 
-#: builtin/clone.c:136
-msgid "key=value"
-msgstr "clé=valeur"
+#: wt-status.c:294
+msgid "deleted:"
+msgstr "supprimé :"
 
-#: builtin/clone.c:137
-msgid "set config inside the new repository"
-msgstr "régler la configuration dans le nouveau dépôt"
+#: wt-status.c:296
+msgid "modified:"
+msgstr "modifié :"
 
-#: builtin/clone.c:138 builtin/fetch.c:173 builtin/pull.c:229
-#: builtin/push.c:583
-msgid "use IPv4 addresses only"
-msgstr "n'utiliser que des adresses IPv4"
+#: wt-status.c:298
+msgid "renamed:"
+msgstr "renommé :"
 
-#: builtin/clone.c:140 builtin/fetch.c:175 builtin/pull.c:232
-#: builtin/push.c:585
-msgid "use IPv6 addresses only"
-msgstr "n'utiliser que des adresses IPv6"
+#: wt-status.c:300
+msgid "typechange:"
+msgstr "modif. type :"
 
-#: builtin/clone.c:278
-msgid ""
-"No directory name could be guessed.\n"
-"Please specify a directory on the command line"
-msgstr ""
-"Aucun nom de répertoire n'a pu être deviné\n"
-"Veuillez spécifier un répertoire dans la ligne de commande"
+#: wt-status.c:302
+msgid "unknown:"
+msgstr "inconnu :"
 
-#: builtin/clone.c:331
-#, c-format
-msgid "info: Could not add alternate for '%s': %s\n"
-msgstr "info : impossible d'ajouter une alternative pour '%s' : %s\n"
+#: wt-status.c:304
+msgid "unmerged:"
+msgstr "non fusionné :"
 
-#: builtin/clone.c:403
-#, c-format
-msgid "failed to open '%s'"
-msgstr "échec à l'ouverture de '%s'"
+#: wt-status.c:384
+msgid "new commits, "
+msgstr "nouveaux commits, "
 
-#: builtin/clone.c:411
-#, c-format
-msgid "%s exists and is not a directory"
-msgstr "%s existe et n'est pas un répertoire"
+#: wt-status.c:386
+msgid "modified content, "
+msgstr "contenu modifié, "
 
-#: builtin/clone.c:425
-#, c-format
-msgid "failed to stat %s\n"
-msgstr "échec du stat de %s\n"
+#: wt-status.c:388
+msgid "untracked content, "
+msgstr "contenu non suivi, "
 
-#: builtin/clone.c:447
+#: wt-status.c:906
 #, c-format
-msgid "failed to create link '%s'"
-msgstr "échec de la création du lien '%s'"
+msgid "Your stash currently has %d entry"
+msgid_plural "Your stash currently has %d entries"
+msgstr[0] "Votre remisage contient actuellement %d entrée"
+msgstr[1] "Votre remisage contient actuellement %d entrées"
 
-#: builtin/clone.c:451
-#, c-format
-msgid "failed to copy file to '%s'"
-msgstr "échec de la copie vers '%s'"
+#: wt-status.c:938
+msgid "Submodules changed but not updated:"
+msgstr "Sous-modules modifiés mais non mis à jour :"
 
-#: builtin/clone.c:477
-#, c-format
-msgid "done.\n"
-msgstr "fait.\n"
+#: wt-status.c:940
+msgid "Submodule changes to be committed:"
+msgstr "Changements du sous-module à valider :"
 
-#: builtin/clone.c:491
+#: wt-status.c:1022
 msgid ""
-"Clone succeeded, but checkout failed.\n"
-"You can inspect what was checked out with 'git status'\n"
-"and retry the checkout with 'git checkout -f HEAD'\n"
+"Do not modify or remove the line above.\n"
+"Everything below it will be ignored."
 msgstr ""
-"Le clone a réussi, mais l'extraction a échoué.\n"
-"Vous pouvez inspecter ce qui a été extrait avec 'git status'\n"
-"et réessayer l'extraction avec 'git checkout -f HEAD'\n"
+"Ne touchez pas à la ligne ci-dessus.\n"
+"Tout ce qui suit sera éliminé."
 
-#: builtin/clone.c:568
+#: wt-status.c:1114
 #, c-format
-msgid "Could not find remote branch %s to clone."
-msgstr "Impossible de trouver la branche distante '%s' à cloner."
+msgid ""
+"\n"
+"It took %.2f seconds to compute the branch ahead/behind values.\n"
+"You can use '--no-ahead-behind' to avoid this.\n"
+msgstr ""
+"\n"
+"%.2f secondes ont été nécessaires pour calculer les valeurs d'avance/retard "
+"de la branche.\n"
+"Vous pouvez utiliser '--no-ahead-behind' pour éviter ceci.\n"
 
-#: builtin/clone.c:663
-msgid "remote did not send all necessary objects"
-msgstr "le serveur distant n'a pas envoyé tous les objets nécessaires"
+#: wt-status.c:1144
+msgid "You have unmerged paths."
+msgstr "Vous avez des chemins non fusionnés."
 
-#: builtin/clone.c:679
-#, c-format
-msgid "unable to update %s"
-msgstr "impossible de mettre à jour %s"
+#: wt-status.c:1147
+msgid "  (fix conflicts and run \"git commit\")"
+msgstr "  (réglez les conflits puis lancez \"git commit\")"
 
-#: builtin/clone.c:728
-msgid "remote HEAD refers to nonexistent ref, unable to checkout.\n"
-msgstr ""
-"la HEAD distante réfère à une référence non existante, impossible de "
-"l'extraire.\n"
+#: wt-status.c:1149
+msgid "  (use \"git merge --abort\" to abort the merge)"
+msgstr "  (utilisez \"git merge --abort\" pour annuler la fusion)"
 
-#: builtin/clone.c:758
-msgid "unable to checkout working tree"
-msgstr "impossible d'extraire la copie de travail"
+#: wt-status.c:1153
+msgid "All conflicts fixed but you are still merging."
+msgstr "Tous les conflits sont réglés mais la fusion n'est pas terminée."
 
-#: builtin/clone.c:803
-msgid "unable to write parameters to config file"
-msgstr "impossible d'écrire les paramètres dans le fichier de configuration"
+#: wt-status.c:1156
+msgid "  (use \"git commit\" to conclude merge)"
+msgstr "  (utilisez \"git commit\" pour terminer la fusion)"
 
-#: builtin/clone.c:866
-msgid "cannot repack to clean up"
-msgstr "impossible de remballer pour nettoyer"
+#: wt-status.c:1165
+msgid "You are in the middle of an am session."
+msgstr "Vous êtes au milieu d'une session am."
 
-#: builtin/clone.c:868
-msgid "cannot unlink temporary alternates file"
-msgstr "impossible de unlinker le fichier temporaire alternates"
+#: wt-status.c:1168
+msgid "The current patch is empty."
+msgstr "Le patch actuel est vide."
 
-#: builtin/clone.c:907 builtin/receive-pack.c:1947
-msgid "Too many arguments."
-msgstr "Trop d'arguments."
+#: wt-status.c:1172
+msgid "  (fix conflicts and then run \"git am --continue\")"
+msgstr "  (réglez les conflits puis lancez \"git am --continue\")"
 
-#: builtin/clone.c:911
-msgid "You must specify a repository to clone."
-msgstr "Vous devez spécifier un dépôt à cloner."
+#: wt-status.c:1174
+msgid "  (use \"git am --skip\" to skip this patch)"
+msgstr "  (utilisez \"git am --skip\" pour sauter ce patch)"
 
-#: builtin/clone.c:924
-#, c-format
-msgid "--bare and --origin %s options are incompatible."
-msgstr "les options --bare et --origin %s sont incompatibles."
+#: wt-status.c:1176
+msgid "  (use \"git am --abort\" to restore the original branch)"
+msgstr "  (utilisez \"git am --abort\" pour restaurer la branche d'origine)"
 
-#: builtin/clone.c:927
-msgid "--bare and --separate-git-dir are incompatible."
-msgstr "--bare et --separate-git-dir sont incompatibles."
+#: wt-status.c:1309
+msgid "git-rebase-todo is missing."
+msgstr "git-rebase-todo est manquant."
 
-#: builtin/clone.c:940
-#, c-format
-msgid "repository '%s' does not exist"
-msgstr "le dépôt '%s' n'existe pas"
+#: wt-status.c:1311
+msgid "No commands done."
+msgstr "Aucune commande réalisée."
 
-#: builtin/clone.c:946 builtin/fetch.c:1460
+#: wt-status.c:1314
 #, c-format
-msgid "depth %s is not a positive number"
-msgstr "la profondeur %s n'est pas un entier positif"
+msgid "Last command done (%d command done):"
+msgid_plural "Last commands done (%d commands done):"
+msgstr[0] "Dernière commande effectuée (%d commande effectuée) :"
+msgstr[1] "Dernières commandes effectuées (%d commandes effectuées) :"
 
-#: builtin/clone.c:956
+#: wt-status.c:1325
 #, c-format
-msgid "destination path '%s' already exists and is not an empty directory."
-msgstr ""
-"le chemin de destination '%s' existe déjà et n'est pas un répertoire vide."
+msgid "  (see more in file %s)"
+msgstr "  (voir plus dans le fichier %s)"
 
-#: builtin/clone.c:966
-#, c-format
-msgid "working tree '%s' already exists."
-msgstr "la copie de travail '%s' existe déjà."
+#: wt-status.c:1330
+msgid "No commands remaining."
+msgstr "Aucune commande restante."
 
-#: builtin/clone.c:981 builtin/clone.c:1002 builtin/difftool.c:270
-#: builtin/worktree.c:246 builtin/worktree.c:276
+#: wt-status.c:1333
 #, c-format
-msgid "could not create leading directories of '%s'"
-msgstr "impossible de créer les répertoires de premier niveau dans '%s'"
+msgid "Next command to do (%d remaining command):"
+msgid_plural "Next commands to do (%d remaining commands):"
+msgstr[0] "Prochaine commande à effectuer (%d commande restante) :"
+msgstr[1] "Prochaines commandes à effectuer (%d commandes restantes) :"
 
-#: builtin/clone.c:986
-#, c-format
-msgid "could not create work tree dir '%s'"
-msgstr "impossible de créer le répertoire de la copie de travail '%s'"
+#: wt-status.c:1341
+msgid "  (use \"git rebase --edit-todo\" to view and edit)"
+msgstr "  (utilisez \"git rebase --edit-todo\" pour voir et éditer)"
 
-#: builtin/clone.c:1006
+#: wt-status.c:1353
 #, c-format
-msgid "Cloning into bare repository '%s'...\n"
-msgstr "Clonage dans le dépôt nu '%s'\n"
+msgid "You are currently rebasing branch '%s' on '%s'."
+msgstr "Vous êtes en train de rebaser la branche '%s' sur '%s'."
 
-#: builtin/clone.c:1008
-#, c-format
-msgid "Cloning into '%s'...\n"
-msgstr "Clonage dans '%s'...\n"
+#: wt-status.c:1358
+msgid "You are currently rebasing."
+msgstr "Vous êtes en train de rebaser."
+
+#: wt-status.c:1371
+msgid "  (fix conflicts and then run \"git rebase --continue\")"
+msgstr "  (réglez les conflits puis lancez \"git rebase --continue\")"
+
+#: wt-status.c:1373
+msgid "  (use \"git rebase --skip\" to skip this patch)"
+msgstr "  (utilisez \"git rebase --skip\" pour sauter ce patch)"
+
+#: wt-status.c:1375
+msgid "  (use \"git rebase --abort\" to check out the original branch)"
+msgstr "  (utilisez \"git rebase --abort\" pour extraire la branche d'origine)"
+
+#: wt-status.c:1382
+msgid "  (all conflicts fixed: run \"git rebase --continue\")"
+msgstr "  (tous les conflits sont réglés : lancez \"git rebase --continue\")"
 
-#: builtin/clone.c:1032
+#: wt-status.c:1386
+#, c-format
 msgid ""
-"clone --recursive is not compatible with both --reference and --reference-if-"
-"able"
+"You are currently splitting a commit while rebasing branch '%s' on '%s'."
 msgstr ""
-"clone --recursive n'est pas compatible avec à la fois --reference et --"
-"reference-if-able"
+"Vous êtes actuellement en train de fractionner un commit pendant un rebasage "
+"de la branche '%s' sur '%s'."
 
-#: builtin/clone.c:1093
-msgid "--depth is ignored in local clones; use file:// instead."
+#: wt-status.c:1391
+msgid "You are currently splitting a commit during a rebase."
 msgstr ""
-"--depth est ignoré dans les clones locaux : utilisez plutôt \"file://\"."
+"Vous êtes actuellement en train de fractionner un commit pendant un rebasage."
 
-#: builtin/clone.c:1095
-msgid "--shallow-since is ignored in local clones; use file:// instead."
+#: wt-status.c:1394
+msgid "  (Once your working directory is clean, run \"git rebase --continue\")"
 msgstr ""
-"--shallow-since est ignoré dans les clones locaux : utilisez plutôt \"file://"
-"\"."
+"  (Une fois la copie de travail nettoyée, lancez \"git rebase --continue\")"
 
-#: builtin/clone.c:1097
-msgid "--shallow-exclude is ignored in local clones; use file:// instead."
+#: wt-status.c:1398
+#, c-format
+msgid "You are currently editing a commit while rebasing branch '%s' on '%s'."
 msgstr ""
-"--shallow-exclude est ignoré dans les clones locaux : utilisez plutôt "
-"\"file://\"."
+"Vous êtes actuellement en train d'éditer un commit pendant un rebasage de la "
+"branche '%s' sur '%s'."
 
-#: builtin/clone.c:1099
-msgid "--filter is ignored in local clones; use file:// instead."
-msgstr "--filter est ignoré dans les clones locaux ; utilisez plutôt file:// ."
+#: wt-status.c:1403
+msgid "You are currently editing a commit during a rebase."
+msgstr ""
+"Vous êtes actuellement en train d'éditer un commit pendant un rebasage."
 
-#: builtin/clone.c:1102
-msgid "source repository is shallow, ignoring --local"
-msgstr "le dépôt source est superficiel, option --local ignorée"
+#: wt-status.c:1406
+msgid "  (use \"git commit --amend\" to amend the current commit)"
+msgstr "  (utilisez \"git commit --amend\" pour corriger le commit actuel)"
 
-#: builtin/clone.c:1107
-msgid "--local is ignored"
-msgstr "--local est ignoré"
+#: wt-status.c:1408
+msgid ""
+"  (use \"git rebase --continue\" once you are satisfied with your changes)"
+msgstr ""
+"  (utilisez \"git rebase --continue\" quand vous avez effectué toutes vos "
+"modifications)"
 
-#: builtin/clone.c:1169 builtin/clone.c:1177
-#, c-format
-msgid "Remote branch %s not found in upstream %s"
-msgstr "La branche distante %s n'a pas été trouvée dans le dépôt amont %s"
+#: wt-status.c:1419
+msgid "Cherry-pick currently in progress."
+msgstr "Picorage en cours."
 
-#: builtin/clone.c:1180
-msgid "You appear to have cloned an empty repository."
-msgstr "Vous semblez avoir cloné un dépôt vide."
+#: wt-status.c:1422
+#, c-format
+msgid "You are currently cherry-picking commit %s."
+msgstr "Vous êtes actuellement en train de picorer le commit %s."
 
-#: builtin/column.c:10
-msgid "git column [<options>]"
-msgstr "git column [<options>]"
+#: wt-status.c:1429
+msgid "  (fix conflicts and run \"git cherry-pick --continue\")"
+msgstr "  (réglez les conflits puis lancez \"git cherry-pick --continue\")"
 
-#: builtin/column.c:27
-msgid "lookup config vars"
-msgstr "rechercher les variables de configuration"
+#: wt-status.c:1432
+msgid "  (run \"git cherry-pick --continue\" to continue)"
+msgstr "  (lancez \"git cherry-pick --continue\" pour continuer)"
 
-#: builtin/column.c:28 builtin/column.c:29
-msgid "layout to use"
-msgstr "mise en page à utiliser"
+#: wt-status.c:1435
+msgid "  (all conflicts fixed: run \"git cherry-pick --continue\")"
+msgstr ""
+"  (tous les conflits sont réglés : lancez \"git cherry-pick --continue\")"
 
-#: builtin/column.c:30
-msgid "Maximum width"
-msgstr "Largeur maximale"
+#: wt-status.c:1437
+msgid "  (use \"git cherry-pick --skip\" to skip this patch)"
+msgstr "  (utilisez \"git cherry-pick --skip\" pour sauter ce patch)"
 
-#: builtin/column.c:31
-msgid "Padding space on left border"
-msgstr "Remplissage d'espace sur la bordure gauche"
+#: wt-status.c:1439
+msgid "  (use \"git cherry-pick --abort\" to cancel the cherry-pick operation)"
+msgstr "  (utilisez \"git cherry-pick --abort\" pour annuler le picorage)"
 
-#: builtin/column.c:32
-msgid "Padding space on right border"
-msgstr "Remplissage d'espace sur le côté droit"
+#: wt-status.c:1449
+msgid "Revert currently in progress."
+msgstr "Rétablissement en cours."
 
-#: builtin/column.c:33
-msgid "Padding space between columns"
-msgstr "Remplissage d'espace entre les colonnes"
+#: wt-status.c:1452
+#, c-format
+msgid "You are currently reverting commit %s."
+msgstr "Vous êtes actuellement en train de rétablir le commit %s."
 
-#: builtin/column.c:51
-msgid "--command must be the first argument"
-msgstr "--command doit être le premier argument"
+#: wt-status.c:1458
+msgid "  (fix conflicts and run \"git revert --continue\")"
+msgstr "  (réglez les conflits puis lancez \"git revert --continue\")"
 
-#: builtin/commit.c:37
-msgid "git commit [<options>] [--] <pathspec>..."
-msgstr "git commit [<options>] [--] <spécification-de-chemin>..."
+#: wt-status.c:1461
+msgid "  (run \"git revert --continue\" to continue)"
+msgstr "  (lancez \"git revert --continue\" pour continuer)"
 
-#: builtin/commit.c:42
-msgid "git status [<options>] [--] <pathspec>..."
-msgstr "git status [<options>] [--] <spécification-de-chemin>..."
+#: wt-status.c:1464
+msgid "  (all conflicts fixed: run \"git revert --continue\")"
+msgstr "  (tous les conflits sont réglés : lancez \"git revert --continue\")"
 
-#: builtin/commit.c:47
-msgid ""
-"You asked to amend the most recent commit, but doing so would make\n"
-"it empty. You can repeat your command with --allow-empty, or you can\n"
-"remove the commit entirely with \"git reset HEAD^\".\n"
-msgstr ""
-"Vous avez demandé de corriger le commit le plus récent, mais le faire le "
-"rendrait\n"
-"vide. Vous pouvez répéter votre commande avec --allow-empty, ou vous pouvez\n"
-"supprimer complètement le commit avec \"git reset HEAD^\".\n"
+#: wt-status.c:1466
+msgid "  (use \"git revert --skip\" to skip this patch)"
+msgstr "  (utilisez \"git revert --skip\" pour sauter ce patch)"
 
-#: builtin/commit.c:52
-msgid ""
-"The previous cherry-pick is now empty, possibly due to conflict resolution.\n"
-"If you wish to commit it anyway, use:\n"
-"\n"
-"    git commit --allow-empty\n"
-"\n"
-msgstr ""
-"Le picorage précédent est à présent vide, vraisemblablement dû à une "
-"résolution de conflit.\n"
-"Si vous souhaitez tout de même le valider, utilisez :\n"
-"\n"
-"    git commit --allow-empty\n"
-"\n"
+#: wt-status.c:1468
+msgid "  (use \"git revert --abort\" to cancel the revert operation)"
+msgstr "  (utilisez \"git revert --abort\" pour annuler le rétablissement)"
 
-#: builtin/commit.c:59
-msgid "Otherwise, please use 'git reset'\n"
-msgstr "Sinon, veuillez utiliser 'git reset'\n"
+#: wt-status.c:1478
+#, c-format
+msgid "You are currently bisecting, started from branch '%s'."
+msgstr "Vous êtes en cours de bissection, depuis la branche '%s'."
 
-#: builtin/commit.c:62
-msgid ""
-"If you wish to skip this commit, use:\n"
-"\n"
-"    git reset\n"
-"\n"
-"Then \"git cherry-pick --continue\" will resume cherry-picking\n"
-"the remaining commits.\n"
-msgstr ""
-"Si vous souhaitez sauter ce commit, utilisez :\n"
-"\n"
-"    git reset\n"
-"\n"
-"Puis \"git cherry-pick --continue\" continuera le picorage \n"
-"des commits restants.\n"
+#: wt-status.c:1482
+msgid "You are currently bisecting."
+msgstr "Vous êtes en cours de bissection."
 
-#: builtin/commit.c:293
-msgid "failed to unpack HEAD tree object"
-msgstr "échec du dépaquetage de l'objet arbre HEAD"
+#: wt-status.c:1485
+msgid "  (use \"git bisect reset\" to get back to the original branch)"
+msgstr "  (utilisez \"git bisect reset\" pour revenir à la branche d'origine)"
 
-#: builtin/commit.c:334
-msgid "unable to create temporary index"
-msgstr "impossible de créer l'index temporaire"
+#: wt-status.c:1694
+msgid "On branch "
+msgstr "Sur la branche "
 
-#: builtin/commit.c:340
-msgid "interactive add failed"
-msgstr "échec de l'ajout interactif"
+#: wt-status.c:1701
+msgid "interactive rebase in progress; onto "
+msgstr "rebasage interactif en cours ; sur "
 
-#: builtin/commit.c:353
-msgid "unable to update temporary index"
-msgstr "impossible de mettre à jour l'index temporaire"
+#: wt-status.c:1703
+msgid "rebase in progress; onto "
+msgstr "rebasage en cours ; sur "
 
-#: builtin/commit.c:355
-msgid "Failed to update main cache tree"
-msgstr "Impossible de mettre à jour l'arbre de cache principal"
+#: wt-status.c:1713
+msgid "Not currently on any branch."
+msgstr "Actuellement sur aucun branche."
 
-#: builtin/commit.c:380 builtin/commit.c:403 builtin/commit.c:449
-msgid "unable to write new_index file"
-msgstr "impossible d'écrire le fichier new_index"
+#: wt-status.c:1730
+msgid "Initial commit"
+msgstr "Validation initiale"
 
-#: builtin/commit.c:432
-msgid "cannot do a partial commit during a merge."
-msgstr "impossible de faire une validation partielle pendant une fusion."
+#: wt-status.c:1731
+msgid "No commits yet"
+msgstr "Aucun commit"
 
-#: builtin/commit.c:434
-msgid "cannot do a partial commit during a cherry-pick."
-msgstr "impossible de faire une validation partielle pendant un picorage."
+#: wt-status.c:1745
+msgid "Untracked files"
+msgstr "Fichiers non suivis"
 
-#: builtin/commit.c:442
-msgid "cannot read the index"
-msgstr "impossible de lire l'index"
+#: wt-status.c:1747
+msgid "Ignored files"
+msgstr "Fichiers ignorés"
 
-#: builtin/commit.c:461
-msgid "unable to write temporary index file"
-msgstr "impossible d'écrire le fichier d'index temporaire"
+#: wt-status.c:1751
+#, c-format
+msgid ""
+"It took %.2f seconds to enumerate untracked files. 'status -uno'\n"
+"may speed it up, but you have to be careful not to forget to add\n"
+"new files yourself (see 'git help status')."
+msgstr ""
+"L'énumération des fichiers non suivis a duré %.2f secondes. 'status -uno'\n"
+"peut l'accélérer, mais vous devez alors faire attention à ne pas\n"
+"oublier d'ajouter les nouveaux fichiers par vous-même (voir 'git help "
+"status')."
 
-#: builtin/commit.c:558
+#: wt-status.c:1757
 #, c-format
-msgid "commit '%s' lacks author header"
-msgstr "entête d'auteur manquant dans le commit '%s'"
+msgid "Untracked files not listed%s"
+msgstr "Fichiers non suivis non affichés%s"
+
+#: wt-status.c:1759
+msgid " (use -u option to show untracked files)"
+msgstr " (utilisez -u pour afficher les fichiers non suivis)"
+
+#: wt-status.c:1765
+msgid "No changes"
+msgstr "Aucune modification"
 
-#: builtin/commit.c:560
+#: wt-status.c:1770
 #, c-format
-msgid "commit '%s' has malformed author line"
-msgstr "le commit '%s' a une ligne d'auteur malformée"
+msgid "no changes added to commit (use \"git add\" and/or \"git commit -a\")\n"
+msgstr ""
+"aucune modification n'a été ajoutée à la validation (utilisez \"git add\" ou "
+"\"git commit -a\")\n"
 
-#: builtin/commit.c:579
-msgid "malformed --author parameter"
-msgstr "paramètre --author mal formé"
+#: wt-status.c:1773
+#, c-format
+msgid "no changes added to commit\n"
+msgstr "aucune modification ajoutée à la validation\n"
 
-#: builtin/commit.c:631
+#: wt-status.c:1776
+#, c-format
 msgid ""
-"unable to select a comment character that is not used\n"
-"in the current commit message"
+"nothing added to commit but untracked files present (use \"git add\" to "
+"track)\n"
 msgstr ""
-"impossible de sélectionner un caractère de commentaire\n"
-"qui n'est pas utilisé dans le message de validation actuel"
+"aucune modification ajoutée à la validation mais des fichiers non suivis "
+"sont présents (utilisez \"git add\" pour les suivre)\n"
 
-#: builtin/commit.c:668 builtin/commit.c:701 builtin/commit.c:1029
+#: wt-status.c:1779
 #, c-format
-msgid "could not lookup commit %s"
-msgstr "impossible de rechercher le commit %s"
+msgid "nothing added to commit but untracked files present\n"
+msgstr ""
+"aucune modification ajoutée à la validation mais des fichiers non suivis "
+"sont présents\n"
 
-#: builtin/commit.c:680 builtin/shortlog.c:316
+#: wt-status.c:1782
 #, c-format
-msgid "(reading log message from standard input)\n"
-msgstr "(lecture du message de journal depuis l'entrée standard)\n"
+msgid "nothing to commit (create/copy files and use \"git add\" to track)\n"
+msgstr ""
+"rien à valider (créez/copiez des fichiers et utilisez \"git add\" pour les "
+"suivre)\n"
 
-#: builtin/commit.c:682
-msgid "could not read log from standard input"
-msgstr "impossible de lire le journal depuis l'entrée standard"
+#: wt-status.c:1785 wt-status.c:1790
+#, c-format
+msgid "nothing to commit\n"
+msgstr "rien à valider\n"
 
-#: builtin/commit.c:686
+#: wt-status.c:1788
 #, c-format
-msgid "could not read log file '%s'"
-msgstr "impossible de lire le fichier de journal '%s'"
+msgid "nothing to commit (use -u to show untracked files)\n"
+msgstr "rien à valider (utilisez -u pour afficher les fichiers non suivis)\n"
 
-#: builtin/commit.c:715 builtin/commit.c:723
-msgid "could not read SQUASH_MSG"
-msgstr "impossible de lire SQUASH_MSG"
+#: wt-status.c:1792
+#, c-format
+msgid "nothing to commit, working tree clean\n"
+msgstr "rien à valider, la copie de travail est propre\n"
 
-#: builtin/commit.c:720
-msgid "could not read MERGE_MSG"
-msgstr "impossible de lire MERGE_MSG"
+#: wt-status.c:1905
+msgid "No commits yet on "
+msgstr "Encore aucun commit sur "
 
-#: builtin/commit.c:774
-msgid "could not write commit template"
-msgstr "impossible d'écrire le modèle de commit"
+#: wt-status.c:1909
+msgid "HEAD (no branch)"
+msgstr "HEAD (aucune branche)"
 
-#: builtin/commit.c:792
-#, c-format
-msgid ""
-"\n"
-"It looks like you may be committing a merge.\n"
-"If this is not correct, please remove the file\n"
-"\t%s\n"
-"and try again.\n"
-msgstr ""
-"\n"
-"Il semble que vous validiez une fusion.\n"
-"Si ce n'est pas le cas, veuillez supprimer le fichier\n"
-"\t%s\n"
-"et essayez à nouveau.\n"
+#: wt-status.c:1940
+msgid "different"
+msgstr "différent"
 
-#: builtin/commit.c:797
-#, c-format
-msgid ""
-"\n"
-"It looks like you may be committing a cherry-pick.\n"
-"If this is not correct, please remove the file\n"
-"\t%s\n"
-"and try again.\n"
-msgstr ""
-"\n"
-"Il semble que vous validiez un picorage.\n"
-"Si ce n'est pas le cas, veuillez supprimer le fichier\n"
-"\t%s\n"
-"et essayez à nouveau.\n"
+#: wt-status.c:1942 wt-status.c:1950
+msgid "behind "
+msgstr "derrière "
 
-#: builtin/commit.c:810
-#, c-format
-msgid ""
-"Please enter the commit message for your changes. Lines starting\n"
-"with '%c' will be ignored, and an empty message aborts the commit.\n"
-msgstr ""
-"Veuillez saisir le message de validation pour vos modifications. Les lignes\n"
-"commençant par '%c' seront ignorées, et un message vide abandonne la "
-"validation.\n"
+#: wt-status.c:1945 wt-status.c:1948
+msgid "ahead "
+msgstr "devant "
 
-#: builtin/commit.c:818
+#. TRANSLATORS: the action is e.g. "pull with rebase"
+#: wt-status.c:2470
 #, c-format
-msgid ""
-"Please enter the commit message for your changes. Lines starting\n"
-"with '%c' will be kept; you may remove them yourself if you want to.\n"
-"An empty message aborts the commit.\n"
-msgstr ""
-"Veuillez saisir le message de validation pour vos modifications. Les lignes\n"
-"commençant par '%c' seront conservées ; vous pouvez les supprimer vous-même\n"
-"si vous le souhaitez. Un message vide abandonne la validation.\n"
+msgid "cannot %s: You have unstaged changes."
+msgstr "Impossible de %s : vous avez des modifications non indexées."
 
-#: builtin/commit.c:835
-#, c-format
-msgid "%sAuthor:    %.*s <%.*s>"
-msgstr "%sAuteur :     %.*s <%.*s>"
+#: wt-status.c:2476
+msgid "additionally, your index contains uncommitted changes."
+msgstr "de plus, votre index contient des modifications non validées."
 
-#: builtin/commit.c:843
+#: wt-status.c:2478
 #, c-format
-msgid "%sDate:      %s"
-msgstr "%sDate :       %s"
+msgid "cannot %s: Your index contains uncommitted changes."
+msgstr "%s impossible : votre index contient des modifications non validées."
 
-#: builtin/commit.c:850
+#: compat/precompose_utf8.c:58 builtin/clone.c:455
 #, c-format
-msgid "%sCommitter: %.*s <%.*s>"
-msgstr "%sValidateur : %.*s <%.*s>"
-
-#: builtin/commit.c:867
-msgid "Cannot read index"
-msgstr "Impossible de lire l'index"
+msgid "failed to unlink '%s'"
+msgstr "échec pour délier '%s'"
 
-#: builtin/commit.c:933
-msgid "Error building trees"
-msgstr "Erreur lors de la construction des arbres"
+#: builtin/add.c:26
+msgid "git add [<options>] [--] <pathspec>..."
+msgstr "git add [<options>] [--] <chemin>..."
 
-#: builtin/commit.c:947 builtin/tag.c:257
+#: builtin/add.c:87
 #, c-format
-msgid "Please supply the message using either -m or -F option.\n"
-msgstr "Veuillez fournir le message en utilisant l'option -m ou -F.\n"
+msgid "unexpected diff status %c"
+msgstr "état de diff inattendu %c"
 
-#: builtin/commit.c:991
-#, c-format
-msgid "--author '%s' is not 'Name <email>' and matches no existing author"
-msgstr ""
-"--author '%s' n'est pas de la forme 'Nom <email>' ni ne correspond à aucun "
-"auteur existant"
+#: builtin/add.c:92 builtin/commit.c:288
+msgid "updating files failed"
+msgstr "échec de la mise à jour des fichiers"
 
-#: builtin/commit.c:1005
+#: builtin/add.c:102
 #, c-format
-msgid "Invalid ignored mode '%s'"
-msgstr "Mode de fichier ignoré invalide '%s'"
+msgid "remove '%s'\n"
+msgstr "suppression de '%s'\n"
 
-#: builtin/commit.c:1019 builtin/commit.c:1269
-#, c-format
-msgid "Invalid untracked files mode '%s'"
-msgstr "Mode de fichier non suivi invalide '%s'"
+#: builtin/add.c:177
+msgid "Unstaged changes after refreshing the index:"
+msgstr "Modifications non indexées après rafraîchissement de l'index :"
 
-#: builtin/commit.c:1057
-msgid "--long and -z are incompatible"
-msgstr "--long et -z sont incompatibles"
+#: builtin/add.c:252 builtin/rev-parse.c:899
+msgid "Could not read the index"
+msgstr "Impossible de lire l'index"
 
-#: builtin/commit.c:1090
-msgid "Using both --reset-author and --author does not make sense"
-msgstr "L'utilisation simultanée de --reset-author et --author n'a pas de sens"
+#: builtin/add.c:263
+#, c-format
+msgid "Could not open '%s' for writing."
+msgstr "Impossible d'ouvrir '%s' en écriture."
 
-#: builtin/commit.c:1099
-msgid "You have nothing to amend."
-msgstr "Il n'y a rien à corriger."
+#: builtin/add.c:267
+msgid "Could not write patch"
+msgstr "Impossible d'écrire le patch"
 
-#: builtin/commit.c:1102
-msgid "You are in the middle of a merge -- cannot amend."
-msgstr "Vous êtes en pleine fusion -- impossible de corriger (amend)."
+#: builtin/add.c:270
+msgid "editing patch failed"
+msgstr "échec de l'édition du patch"
 
-#: builtin/commit.c:1104
-msgid "You are in the middle of a cherry-pick -- cannot amend."
-msgstr "Vous êtes en plein picorage -- impossible de corriger (amend)."
+#: builtin/add.c:273
+#, c-format
+msgid "Could not stat '%s'"
+msgstr "Stat de '%s' impossible"
 
-#: builtin/commit.c:1107
-msgid "Options --squash and --fixup cannot be used together"
-msgstr "Les options --squash et --fixup ne peuvent pas être utilisées ensemble"
+#: builtin/add.c:275
+msgid "Empty patch. Aborted."
+msgstr "Patch vide. Abandon."
 
-#: builtin/commit.c:1117
-msgid "Only one of -c/-C/-F/--fixup can be used."
-msgstr "Une seule option parmi -c/-C/-F/--fixup peut être utilisée."
+#: builtin/add.c:280
+#, c-format
+msgid "Could not apply '%s'"
+msgstr "Impossible d'appliquer '%s'"
 
-#: builtin/commit.c:1119
-msgid "Option -m cannot be combined with -c/-C/-F."
-msgstr "L'option -m ne peut pas être combinée avec -c/-C/-F."
+#: builtin/add.c:288
+msgid "The following paths are ignored by one of your .gitignore files:\n"
+msgstr ""
+"Les chemins suivants sont ignorés par un de vos fichiers .gitignore :\n"
 
-#: builtin/commit.c:1127
-msgid "--reset-author can be used only with -C, -c or --amend."
-msgstr "--reset-author ne peut être utilisé qu'avec -C, -c ou --amend."
+#: builtin/add.c:308 builtin/clean.c:910 builtin/fetch.c:163 builtin/mv.c:124
+#: builtin/prune-packed.c:56 builtin/pull.c:223 builtin/push.c:548
+#: builtin/remote.c:1344 builtin/rm.c:241 builtin/send-pack.c:165
+msgid "dry run"
+msgstr "simuler l'action"
 
-#: builtin/commit.c:1144
-msgid "Only one of --include/--only/--all/--interactive/--patch can be used."
-msgstr ""
-"Une seule option parmi --include/--only/--all/--interactive/--patch peut "
-"être utilisée."
+#: builtin/add.c:311
+msgid "interactive picking"
+msgstr "sélection interactive"
 
-#: builtin/commit.c:1146
-msgid "No paths with --include/--only does not make sense."
-msgstr "Aucun chemin avec les options --include/--only n'a pas de sens."
+#: builtin/add.c:312 builtin/checkout.c:1482 builtin/reset.c:307
+msgid "select hunks interactively"
+msgstr "sélection interactive des sections"
 
-#: builtin/commit.c:1160 builtin/tag.c:543
-#, c-format
-msgid "Invalid cleanup mode %s"
-msgstr "Mode de nettoyage invalide %s"
+#: builtin/add.c:313
+msgid "edit current diff and apply"
+msgstr "édition du diff actuel et application"
 
-#: builtin/commit.c:1165
-msgid "Paths with -a does not make sense."
-msgstr "Spécifier des chemins avec l'option -a n'a pas de sens."
+#: builtin/add.c:314
+msgid "allow adding otherwise ignored files"
+msgstr "permettre l'ajout de fichiers ignorés"
 
-#: builtin/commit.c:1303 builtin/commit.c:1480
-msgid "show status concisely"
-msgstr "afficher l'état avec concision"
+#: builtin/add.c:315
+msgid "update tracked files"
+msgstr "mettre à jour les fichiers suivis"
 
-#: builtin/commit.c:1305 builtin/commit.c:1482
-msgid "show branch information"
-msgstr "afficher l'information de branche"
+#: builtin/add.c:316
+msgid "renormalize EOL of tracked files (implies -u)"
+msgstr ""
+"renormaliser les fins de lignes (EOL) des fichiers suivis (implique -u)"
 
-#: builtin/commit.c:1307
-msgid "show stash information"
-msgstr "afficher l'information de remisage"
+#: builtin/add.c:317
+msgid "record only the fact that the path will be added later"
+msgstr "enregistrer seulement le fait que le chemin sera ajouté plus tard"
 
-#: builtin/commit.c:1309 builtin/commit.c:1484
-msgid "compute full ahead/behind values"
-msgstr "calcule les valeurs complètes en avance/en retard"
+#: builtin/add.c:318
+msgid "add changes from all tracked and untracked files"
+msgstr "ajouter les modifications de tous les fichiers suivis et non suivis"
 
-#: builtin/commit.c:1311
-msgid "version"
-msgstr "version"
+#: builtin/add.c:321
+msgid "ignore paths removed in the working tree (same as --no-all)"
+msgstr ""
+"ignorer les chemins effacés dans la copie de travail (identique à --no-all)"
 
-#: builtin/commit.c:1311 builtin/commit.c:1486 builtin/push.c:558
-#: builtin/worktree.c:581
-msgid "machine-readable output"
-msgstr "sortie pour traitement automatique"
+#: builtin/add.c:323
+msgid "don't add, only refresh the index"
+msgstr "ne pas ajouter, juste rafraîchir l'index"
 
-#: builtin/commit.c:1314 builtin/commit.c:1488
-msgid "show status in long format (default)"
-msgstr "afficher l'état en format long (par défaut)"
+#: builtin/add.c:324
+msgid "just skip files which cannot be added because of errors"
+msgstr ""
+"sauter seulement les fichiers qui ne peuvent pas être ajoutés du fait "
+"d'erreurs"
 
-#: builtin/commit.c:1317 builtin/commit.c:1491
-msgid "terminate entries with NUL"
-msgstr "terminer les éléments par NUL"
+#: builtin/add.c:325
+msgid "check if - even missing - files are ignored in dry run"
+msgstr "vérifier si des fichiers - même manquants - sont ignorés, à vide"
 
-#: builtin/commit.c:1319 builtin/commit.c:1323 builtin/commit.c:1494
-#: builtin/fast-export.c:1001 builtin/fast-export.c:1004 builtin/tag.c:397
-msgid "mode"
-msgstr "mode"
+#: builtin/add.c:327 builtin/update-index.c:1004
+msgid "override the executable bit of the listed files"
+msgstr "outrepasser le bit exécutable pour les fichiers listés"
 
-#: builtin/commit.c:1320 builtin/commit.c:1494
-msgid "show untracked files, optional modes: all, normal, no. (Default: all)"
-msgstr ""
-"afficher les fichiers non suivis, \"mode\" facultatif : all (tous), normal, "
-"no. (Défaut : all)"
+#: builtin/add.c:329
+msgid "warn when adding an embedded repository"
+msgstr "avertir lors de l'ajout d'un dépôt embarqué"
 
-#: builtin/commit.c:1324
+#: builtin/add.c:347
+#, c-format
 msgid ""
-"show ignored files, optional modes: traditional, matching, no. (Default: "
-"traditional)"
+"You've added another git repository inside your current repository.\n"
+"Clones of the outer repository will not contain the contents of\n"
+"the embedded repository and will not know how to obtain it.\n"
+"If you meant to add a submodule, use:\n"
+"\n"
+"\tgit submodule add <url> %s\n"
+"\n"
+"If you added this path by mistake, you can remove it from the\n"
+"index with:\n"
+"\n"
+"\tgit rm --cached %s\n"
+"\n"
+"See \"git help submodule\" for more information."
 msgstr ""
-"afficher les fichiers ignorés, \"mode\" facultatif : traditional "
-"(traditionnel), matching (correspondant), no. (Défaut : traditional)"
+"Vous avez ajouté un autre dépôt git dans votre dépôt actuel.\n"
+"Les clones du dépôt conteneur ne contiendrons pas le contenu\n"
+"du dépôt embarqué et ne sauront pas comment l'obtenir.\n"
+"Si vous vouliez ajouter un sous-module, utilisez :\n"
+"\n"
+"\tgit submodule add <url> %s\n"
+"\n"
+"Si vous avez ajouté ce chemin par erreur, vous pouvez le\n"
+"supprimer de l'index avec :\n"
+"\n"
+"\tgit rm --cached %s\n"
+"\n"
+"Référez-vous à \"git help submodule\" pour plus d'information."
 
-#: builtin/commit.c:1326 parse-options.h:167
-msgid "when"
-msgstr "quand"
+#: builtin/add.c:375
+#, c-format
+msgid "adding embedded git repository: %s"
+msgstr "dépôt git embarqué ajouté : %s"
 
-#: builtin/commit.c:1327
-msgid ""
-"ignore changes to submodules, optional when: all, dirty, untracked. "
-"(Default: all)"
-msgstr ""
-"ignorer les modifications dans les sous-modules, \"quand\" facultatif : all "
-"(tous), dirty (sale), untracked (non suivi). (Défaut : all)"
+#: builtin/add.c:393
+#, c-format
+msgid "Use -f if you really want to add them.\n"
+msgstr "Utilisez -f si vous voulez réellement les ajouter.\n"
 
-#: builtin/commit.c:1329
-msgid "list untracked files in columns"
-msgstr "afficher les fichiers non suivis en colonnes"
+#: builtin/add.c:400
+msgid "adding files failed"
+msgstr "échec de l'ajout de fichiers"
 
-#: builtin/commit.c:1330
-msgid "do not detect renames"
-msgstr "ne pas détecter les renommages"
+#: builtin/add.c:428 builtin/commit.c:348
+msgid "--pathspec-from-file is incompatible with --interactive/--patch"
+msgstr "--pathspec-from-file est incompatible avec --interactive/--patch"
+
+#: builtin/add.c:434
+msgid "--pathspec-from-file is incompatible with --edit"
+msgstr "--pathspec-from-file est incompatible avec --edit"
 
-#: builtin/commit.c:1332
-msgid "detect renames, optionally set similarity index"
-msgstr ""
-"détecter les renommages, en spécifiant optionnellement le facteur de "
-"similarité"
+#: builtin/add.c:446
+msgid "-A and -u are mutually incompatible"
+msgstr "-A et -u sont mutuellement incompatibles"
 
-#: builtin/commit.c:1352
-msgid "Unsupported combination of ignored and untracked-files arguments"
+#: builtin/add.c:449
+msgid "Option --ignore-missing can only be used together with --dry-run"
 msgstr ""
-"Combinaison non supportée d'arguments sur les fichiers ignorés et non-suivis"
+"L'option --ignore-missing ne peut être utilisée qu'en complément de --dry-run"
 
-#: builtin/commit.c:1450
-msgid "suppress summary after successful commit"
-msgstr "supprimer le résumé après une validation réussie"
+#: builtin/add.c:453
+#, c-format
+msgid "--chmod param '%s' must be either -x or +x"
+msgstr "Le paramètre '%s' de --chmod doit être soit -x soit +x"
 
-#: builtin/commit.c:1451
-msgid "show diff in commit message template"
-msgstr "afficher les diff dans le modèle de message de validation"
+#: builtin/add.c:471 builtin/checkout.c:1648 builtin/commit.c:354
+#: builtin/reset.c:327
+msgid "--pathspec-from-file is incompatible with pathspec arguments"
+msgstr "--pathspec-from-file est incompatible avec pathspec arguments"
+
+#: builtin/add.c:478 builtin/checkout.c:1660 builtin/commit.c:360
+#: builtin/reset.c:333
+msgid "--pathspec-file-nul requires --pathspec-from-file"
+msgstr "--pathspec-file-nul nécessite --pathspec-from-file"
 
-#: builtin/commit.c:1453
-msgid "Commit message options"
-msgstr "Options du message de validation"
+#: builtin/add.c:482
+#, c-format
+msgid "Nothing specified, nothing added.\n"
+msgstr "Rien de spécifié, rien n'a été ajouté.\n"
 
-#: builtin/commit.c:1454 builtin/tag.c:394
-msgid "read message from file"
-msgstr "lire le message depuis un fichier"
+#: builtin/add.c:483
+#, c-format
+msgid "Maybe you wanted to say 'git add .'?\n"
+msgstr "Vous vouliez sûrement dire 'git add .' ?\n"
 
-#: builtin/commit.c:1455
-msgid "author"
-msgstr "auteur"
+#: builtin/am.c:347
+msgid "could not parse author script"
+msgstr "impossible d'analyser l'auteur du script"
 
-#: builtin/commit.c:1455
-msgid "override author for commit"
-msgstr "remplacer l'auteur pour la validation"
+#: builtin/am.c:431
+#, c-format
+msgid "'%s' was deleted by the applypatch-msg hook"
+msgstr "'%s' a été effacé par le crochet applypatch-msg"
 
-#: builtin/commit.c:1456 builtin/gc.c:501
-msgid "date"
-msgstr "date"
+#: builtin/am.c:473
+#, c-format
+msgid "Malformed input line: '%s'."
+msgstr "Ligne en entrée malformée : '%s'."
 
-#: builtin/commit.c:1456
-msgid "override date for commit"
-msgstr "remplacer la date pour la validation"
+#: builtin/am.c:511
+#, c-format
+msgid "Failed to copy notes from '%s' to '%s'"
+msgstr "Impossible de copier les notes de '%s' vers '%s'"
 
-#: builtin/commit.c:1457 builtin/merge.c:228 builtin/notes.c:402
-#: builtin/notes.c:565 builtin/tag.c:392
-msgid "message"
-msgstr "message"
+#: builtin/am.c:537
+msgid "fseek failed"
+msgstr "échec de fseek"
 
-#: builtin/commit.c:1457
-msgid "commit message"
-msgstr "message de validation"
+#: builtin/am.c:725
+#, c-format
+msgid "could not parse patch '%s'"
+msgstr "impossible d'analyser le patch '%s'"
 
-#: builtin/commit.c:1458 builtin/commit.c:1459 builtin/commit.c:1460
-#: builtin/commit.c:1461 parse-options.h:270 ref-filter.h:92
-msgid "commit"
-msgstr "commit"
+#: builtin/am.c:790
+msgid "Only one StGIT patch series can be applied at once"
+msgstr "Seulement une série de patchs StGIT peut être appliquée à la fois"
 
-#: builtin/commit.c:1458
-msgid "reuse and edit message from specified commit"
-msgstr "réutiliser et éditer le message du commit spécifié"
+#: builtin/am.c:838
+msgid "invalid timestamp"
+msgstr "horodatage invalide"
 
-#: builtin/commit.c:1459
-msgid "reuse message from specified commit"
-msgstr "réutiliser le message du commit spécifié"
+#: builtin/am.c:843 builtin/am.c:855
+msgid "invalid Date line"
+msgstr "ligne de Date invalide"
 
-#: builtin/commit.c:1460
-msgid "use autosquash formatted message to fixup specified commit"
-msgstr ""
-"utiliser un message au format autosquash pour corriger le commit spécifié"
+#: builtin/am.c:850
+msgid "invalid timezone offset"
+msgstr "décalage horaire invalide"
 
-#: builtin/commit.c:1461
-msgid "use autosquash formatted message to squash specified commit"
-msgstr ""
-"utiliser un message au format autosquash pour compresser le commit spécifié"
+#: builtin/am.c:943
+msgid "Patch format detection failed."
+msgstr "Échec de détection du format du patch."
 
-#: builtin/commit.c:1462
-msgid "the commit is authored by me now (used with -C/-c/--amend)"
-msgstr ""
-"à présent je suis l'auteur de la validation (utilisé avec -C/-c/--amend)"
+#: builtin/am.c:948 builtin/clone.c:409
+#, c-format
+msgid "failed to create directory '%s'"
+msgstr "échec de la création du répertoire '%s'"
 
-#: builtin/commit.c:1463 builtin/log.c:1446 builtin/merge.c:242
-#: builtin/pull.c:154 builtin/revert.c:105
-msgid "add Signed-off-by:"
-msgstr "ajouter une entrée Signed-off-by :"
+#: builtin/am.c:953
+msgid "Failed to split patches."
+msgstr "Échec de découpage des patchs."
 
-#: builtin/commit.c:1464
-msgid "use specified template file"
-msgstr "utiliser le fichier de modèle spécifié"
+#: builtin/am.c:1084
+#, c-format
+msgid "When you have resolved this problem, run \"%s --continue\"."
+msgstr "Quand vous avez résolu ce problème, lancez \"%s --continue\"."
 
-#: builtin/commit.c:1465
-msgid "force edit of commit"
-msgstr "forcer l'édition du commit"
+#: builtin/am.c:1085
+#, c-format
+msgid "If you prefer to skip this patch, run \"%s --skip\" instead."
+msgstr "Si vous préférez plutôt sauter ce patch, lancez \"%s --skip\"."
 
-#: builtin/commit.c:1466
-msgid "default"
-msgstr "défaut"
+#: builtin/am.c:1086
+#, c-format
+msgid "To restore the original branch and stop patching, run \"%s --abort\"."
+msgstr ""
+"Pour restaurer la branche originale et arrêter de patcher, lancez \"%s --"
+"abort\"."
 
-#: builtin/commit.c:1466 builtin/tag.c:398
-msgid "how to strip spaces and #comments from message"
-msgstr "comment éliminer les espaces et les commentaires # du message"
+#: builtin/am.c:1169
+msgid "Patch sent with format=flowed; space at the end of lines might be lost."
+msgstr ""
+"Rustine envoyée avec format=flowed ; les espaces en fin de ligne peuvent "
+"être perdus."
 
-#: builtin/commit.c:1467
-msgid "include status in commit message template"
-msgstr "inclure l'état dans le modèle de message de validation"
+#: builtin/am.c:1197
+msgid "Patch is empty."
+msgstr "Le patch actuel est vide."
 
-#: builtin/commit.c:1469 builtin/merge.c:240 builtin/pull.c:184
-#: builtin/revert.c:113
-msgid "GPG sign commit"
-msgstr "signer la validation avec GPG"
+#: builtin/am.c:1262
+#, c-format
+msgid "missing author line in commit %s"
+msgstr "ligne d'auteur manquante dans le commit %s"
 
-#: builtin/commit.c:1472
-msgid "Commit contents options"
-msgstr "Valider les options des contenus"
+#: builtin/am.c:1265
+#, c-format
+msgid "invalid ident line: %.*s"
+msgstr "ligne d'identification invalide : %.*s"
 
-#: builtin/commit.c:1473
-msgid "commit all changed files"
-msgstr "valider tous les fichiers modifiés"
+#: builtin/am.c:1484
+msgid "Repository lacks necessary blobs to fall back on 3-way merge."
+msgstr ""
+"Le dépôt n'a pas les blobs nécessaires pour un retour à une fusion à 3 "
+"points."
 
-#: builtin/commit.c:1474
-msgid "add specified files to index for commit"
-msgstr "ajouter les fichiers spécifiés à l'index pour la validation"
+#: builtin/am.c:1486
+msgid "Using index info to reconstruct a base tree..."
+msgstr ""
+"Utilisation de l'information de l'index pour reconstruire un arbre de base..."
 
-#: builtin/commit.c:1475
-msgid "interactively add files"
-msgstr "ajouter des fichiers en mode interactif"
+#: builtin/am.c:1505
+msgid ""
+"Did you hand edit your patch?\n"
+"It does not apply to blobs recorded in its index."
+msgstr ""
+"Avez-vous édité le patch à la main ?\n"
+"Il ne s'applique pas aux blobs enregistrés dans son index."
 
-#: builtin/commit.c:1476
-msgid "interactively add changes"
-msgstr "ajouter les modifications en mode interactif"
+#: builtin/am.c:1511
+msgid "Falling back to patching base and 3-way merge..."
+msgstr "Retour à un patch de la base et fusion à 3 points..."
 
-#: builtin/commit.c:1477
-msgid "commit only specified files"
-msgstr "valider seulement les fichiers spécifiés"
+#: builtin/am.c:1537
+msgid "Failed to merge in the changes."
+msgstr "Échec d'intégration des modifications."
 
-#: builtin/commit.c:1478
-msgid "bypass pre-commit and commit-msg hooks"
-msgstr "éviter d'utiliser les crochets pre-commit et commit-msg"
+#: builtin/am.c:1569
+msgid "applying to an empty history"
+msgstr "application à un historique vide"
 
-#: builtin/commit.c:1479
-msgid "show what would be committed"
-msgstr "afficher ce qui serait validé"
+#: builtin/am.c:1616 builtin/am.c:1620
+#, c-format
+msgid "cannot resume: %s does not exist."
+msgstr "impossible de continuer : %s n'existe pas."
 
-#: builtin/commit.c:1492
-msgid "amend previous commit"
-msgstr "corriger la validation précédente"
+#: builtin/am.c:1638
+msgid "Commit Body is:"
+msgstr "Le corps de la validation est :"
 
-#: builtin/commit.c:1493
-msgid "bypass post-rewrite hook"
-msgstr "éviter d'utiliser le crochet post-rewrite"
+#. TRANSLATORS: Make sure to include [y], [n], [e], [v] and [a]
+#. in your translation. The program will only accept English
+#. input at this point.
+#.
+#: builtin/am.c:1648
+#, c-format
+msgid "Apply? [y]es/[n]o/[e]dit/[v]iew patch/[a]ccept all: "
+msgstr "Appliquer ? [y]es/[n]o/[e]dit/[v]iew patch/[a]ccept all : "
 
-#: builtin/commit.c:1498
-msgid "ok to record an empty change"
-msgstr "accepter d'enregistrer une modification vide"
+#: builtin/am.c:1695 builtin/commit.c:394
+msgid "unable to write index file"
+msgstr "impossible d'écrire le fichier d'index"
 
-#: builtin/commit.c:1500
-msgid "ok to record a change with an empty message"
-msgstr "accepter d'enregistrer une modification avec un message vide"
+#: builtin/am.c:1699
+#, c-format
+msgid "Dirty index: cannot apply patches (dirty: %s)"
+msgstr "Index sale : impossible d'appliquer des patchs (sales : %s)"
 
-#: builtin/commit.c:1573
+#: builtin/am.c:1739 builtin/am.c:1807
 #, c-format
-msgid "Corrupt MERGE_HEAD file (%s)"
-msgstr "Fichier MERGE_HEAD corrompu (%s)"
+msgid "Applying: %.*s"
+msgstr "Application de  %.*s"
 
-#: builtin/commit.c:1580
-msgid "could not read MERGE_MODE"
-msgstr "impossible de lire MERGE_MODE"
+#: builtin/am.c:1756
+msgid "No changes -- Patch already applied."
+msgstr "Pas de changement -- Patch déjà appliqué."
 
-#: builtin/commit.c:1599
+#: builtin/am.c:1762
 #, c-format
-msgid "could not read commit message: %s"
-msgstr "impossible de lire le message de validation : %s"
+msgid "Patch failed at %s %.*s"
+msgstr "le patch a échoué à %s %.*s"
 
-#: builtin/commit.c:1610
-#, c-format
-msgid "Aborting commit due to empty commit message.\n"
-msgstr "Abandon de la validation dû à un message de validation vide.\n"
+#: builtin/am.c:1766
+msgid "Use 'git am --show-current-patch' to see the failed patch"
+msgstr ""
+"Utilisez 'git am --show-current-patch' pour visualiser le patch en échec"
 
-#: builtin/commit.c:1615
-#, c-format
-msgid "Aborting commit; you did not edit the message.\n"
-msgstr "Abandon de la validation ; vous n'avez pas édité le message\n"
+#: builtin/am.c:1810
+msgid ""
+"No changes - did you forget to use 'git add'?\n"
+"If there is nothing left to stage, chances are that something else\n"
+"already introduced the same changes; you might want to skip this patch."
+msgstr ""
+"Aucun changement - avez-vous oublié d'utiliser 'git add' ?\n"
+"S'il n'y a plus rien à indexer, il se peut qu'autre chose ait déjà\n"
+"introduit les mêmes changements ; vous pourriez avoir envie de sauter ce "
+"patch."
 
-#: builtin/commit.c:1650
+#: builtin/am.c:1817
 msgid ""
-"Repository has been updated, but unable to write\n"
-"new_index file. Check that disk is not full and quota is\n"
-"not exceeded, and then \"git reset HEAD\" to recover."
+"You still have unmerged paths in your index.\n"
+"You should 'git add' each file with resolved conflicts to mark them as "
+"such.\n"
+"You might run `git rm` on a file to accept \"deleted by them\" for it."
 msgstr ""
-"Le dépôt a été mis à jour, mais impossible d'écrire le fichier\n"
-"new_index. Vérifiez que le disque n'est pas plein ou que le quota\n"
-"n'a pas été dépassé, puis lancez \"git reset HEAD\" pour réparer."
+"Vous avez encore des chemin non-fusionnés dans votre index.\n"
+"Vous devriez lancer 'git add' sur chaque conflit résolu pour les marquer "
+"comme tel.\n"
+"Vous pouvez lancer 'git rm' sur un fichier \"supprimé par eux\" pour "
+"accepter son état."
 
-#: builtin/commit-graph.c:9
-msgid "git commit-graph [--object-dir <objdir>]"
-msgstr "git commit-graph [--object-dir <objdir>]"
+#: builtin/am.c:1924 builtin/am.c:1928 builtin/am.c:1940 builtin/reset.c:346
+#: builtin/reset.c:354
+#, c-format
+msgid "Could not parse object '%s'."
+msgstr "Impossible d'analyser l'objet '%s'."
 
-#: builtin/commit-graph.c:10 builtin/commit-graph.c:16
-msgid "git commit-graph read [--object-dir <objdir>]"
-msgstr "git commit-graph read [--object-dir <objdir>]"
+#: builtin/am.c:1976
+msgid "failed to clean index"
+msgstr "échec du nettoyage de l'index"
 
-#: builtin/commit-graph.c:11 builtin/commit-graph.c:21
+#: builtin/am.c:2020
 msgid ""
-"git commit-graph write [--object-dir <objdir>] [--append] [--stdin-packs|--"
-"stdin-commits]"
+"You seem to have moved HEAD since the last 'am' failure.\n"
+"Not rewinding to ORIG_HEAD"
 msgstr ""
-"git commit-graph write [--object-dir <objdir>] [--append] [--stdin-packs|--"
-"stdin-commits]"
+"Vous semblez avoir déplacé la HEAD depuis le dernier échec de 'am'.\n"
+"Pas de retour à ORIG_HEAD"
 
-#: builtin/commit-graph.c:39 builtin/commit-graph.c:92
-#: builtin/commit-graph.c:147 builtin/fetch.c:161 builtin/log.c:1466
-msgid "dir"
-msgstr "répertoire"
+#: builtin/am.c:2117
+#, c-format
+msgid "Invalid value for --patch-format: %s"
+msgstr "Valeur invalide pour --patch-format : %s"
 
-#: builtin/commit-graph.c:40 builtin/commit-graph.c:93
-#: builtin/commit-graph.c:148
-msgid "The object directory to store the graph"
-msgstr "Le répertoire d'objet où stocker le graphe"
+#: builtin/am.c:2153
+msgid "git am [<options>] [(<mbox> | <Maildir>)...]"
+msgstr "git am [<options>] [(<mbox> | <Maildir>)...]"
 
-#: builtin/commit-graph.c:95
-msgid "scan pack-indexes listed by stdin for commits"
-msgstr "scanner les index compactés listés sur stdin à la recherche de commits"
+#: builtin/am.c:2154
+msgid "git am [<options>] (--continue | --skip | --abort)"
+msgstr "git am [<options>] (--continue | --skip | --abort)"
 
-#: builtin/commit-graph.c:97
-msgid "start walk at commits listed by stdin"
-msgstr "commencer le parcours aux commits listés sur stdin"
+#: builtin/am.c:2160
+msgid "run interactively"
+msgstr "exécution interactive"
 
-#: builtin/commit-graph.c:99
-msgid "include all commits already in the commit-graph file"
-msgstr ""
-"inclure tous les commits déjà présents dans le fichier de graphe de commits"
+#: builtin/am.c:2162
+msgid "historical option -- no-op"
+msgstr "option historique -- no-op"
 
-#: builtin/commit-graph.c:108
-msgid "cannot use both --stdin-commits and --stdin-packs"
-msgstr "impossible d'utiliser à la fois --stdin-commits et --stdin-packs"
+#: builtin/am.c:2164
+msgid "allow fall back on 3way merging if needed"
+msgstr "permettre de revenir à une fusion à 3 points si nécessaire"
 
-#: builtin/config.c:10
-msgid "git config [<options>]"
-msgstr "git config [<options>]"
+#: builtin/am.c:2165 builtin/init-db.c:494 builtin/prune-packed.c:58
+#: builtin/repack.c:304 builtin/stash.c:811
+msgid "be quiet"
+msgstr "être silencieux"
 
-#: builtin/config.c:101
-#, c-format
-msgid "unrecognized --type argument, %s"
-msgstr "argument --type non reconnu, %s"
+#: builtin/am.c:2167
+msgid "add a Signed-off-by line to the commit message"
+msgstr "ajouter une ligne Signed-off-by au message de validation"
 
-#: builtin/config.c:123
-msgid "Config file location"
-msgstr "Emplacement du fichier de configuration"
+#: builtin/am.c:2170
+msgid "recode into utf8 (default)"
+msgstr "recoder en utf-8 (par défaut)"
 
-#: builtin/config.c:124
-msgid "use global config file"
-msgstr "utiliser les fichier de configuration global"
+#: builtin/am.c:2172
+msgid "pass -k flag to git-mailinfo"
+msgstr "passer l'option -k à git-mailinfo"
 
-#: builtin/config.c:125
-msgid "use system config file"
-msgstr "utiliser le fichier de configuration du système"
+#: builtin/am.c:2174
+msgid "pass -b flag to git-mailinfo"
+msgstr "passer l'option -b à git-mailinfo"
 
-#: builtin/config.c:126
-msgid "use repository config file"
-msgstr "utiliser le fichier de configuration du dépôt"
+#: builtin/am.c:2176
+msgid "pass -m flag to git-mailinfo"
+msgstr "passer l'option -m à git-mailinfo"
 
-#: builtin/config.c:127
-msgid "use given config file"
-msgstr "utiliser le fichier de configuration spécifié"
+#: builtin/am.c:2178
+msgid "pass --keep-cr flag to git-mailsplit for mbox format"
+msgstr "passer l'option --keep-cr à git-mailsplit fpour le format mbox"
 
-#: builtin/config.c:128
-msgid "blob-id"
-msgstr "blob-id"
+#: builtin/am.c:2181
+msgid "do not pass --keep-cr flag to git-mailsplit independent of am.keepcr"
+msgstr ""
+"ne pas passer l'option --keep-cr à git-mailsplit indépendamment de am.keepcr"
 
-#: builtin/config.c:128
-msgid "read config from given blob object"
-msgstr "lire la configuration depuis l'objet blob fourni"
+#: builtin/am.c:2184
+msgid "strip everything before a scissors line"
+msgstr "retirer tout le contenu avant la ligne des ciseaux"
 
-#: builtin/config.c:129
-msgid "Action"
-msgstr "Action"
+#: builtin/am.c:2186 builtin/am.c:2189 builtin/am.c:2192 builtin/am.c:2195
+#: builtin/am.c:2198 builtin/am.c:2201 builtin/am.c:2204 builtin/am.c:2207
+#: builtin/am.c:2213
+msgid "pass it through git-apply"
+msgstr "le passer jusqu'à git-apply"
 
-#: builtin/config.c:130
-msgid "get value: name [value-regex]"
-msgstr "obtenir la valeur : nom [regex-de-valeur]"
+#: builtin/am.c:2203 builtin/commit.c:1386 builtin/fmt-merge-msg.c:673
+#: builtin/fmt-merge-msg.c:676 builtin/grep.c:883 builtin/merge.c:249
+#: builtin/pull.c:160 builtin/pull.c:219 builtin/rebase.c:1469
+#: builtin/repack.c:315 builtin/repack.c:319 builtin/repack.c:321
+#: builtin/show-branch.c:650 builtin/show-ref.c:172 builtin/tag.c:403
+#: parse-options.h:154 parse-options.h:175 parse-options.h:316
+msgid "n"
+msgstr "n"
 
-#: builtin/config.c:131
-msgid "get all values: key [value-regex]"
-msgstr "obtenir toutes les valeurs : clé [regex-de-valeur]"
+#: builtin/am.c:2209 builtin/branch.c:661 builtin/for-each-ref.c:38
+#: builtin/replace.c:555 builtin/tag.c:437 builtin/verify-tag.c:38
+msgid "format"
+msgstr "format"
 
-#: builtin/config.c:132
-msgid "get values for regexp: name-regex [value-regex]"
-msgstr "obtenir les valeur pour la regexp : regex-de-nom [regex-de-valeur]"
+#: builtin/am.c:2210
+msgid "format the patch(es) are in"
+msgstr "format de présentation des patchs"
 
-#: builtin/config.c:133
-msgid "get value specific for the URL: section[.var] URL"
-msgstr "obtenir la valeur spécifique pour l'URL : section[.var] URL"
+#: builtin/am.c:2216
+msgid "override error message when patch failure occurs"
+msgstr "surcharger le message d'erreur lors d'un échec d'application de patch"
 
-#: builtin/config.c:134
-msgid "replace all matching variables: name value [value_regex]"
+#: builtin/am.c:2218
+msgid "continue applying patches after resolving a conflict"
+msgstr "continuer à appliquer les patchs après résolution d'un conflit"
+
+#: builtin/am.c:2221
+msgid "synonyms for --continue"
+msgstr "synonymes de --continue"
+
+#: builtin/am.c:2224
+msgid "skip the current patch"
+msgstr "sauter le patch courant"
+
+#: builtin/am.c:2227
+msgid "restore the original branch and abort the patching operation."
 msgstr ""
-"remplacer toutes les variables correspondant : nom valeur [regex-de-valeur]"
+"restaurer la branche originale et abandonner les applications de patch."
 
-#: builtin/config.c:135
-msgid "add a new variable: name value"
-msgstr "ajouter une nouvelle variable : nom valeur"
+#: builtin/am.c:2230
+msgid "abort the patching operation but keep HEAD where it is."
+msgstr "abandonne l'opération de patch mais garde HEAD où il est."
 
-#: builtin/config.c:136
-msgid "remove a variable: name [value-regex]"
-msgstr "supprimer une variable : nom [regex-de-valeur]"
+#: builtin/am.c:2233
+msgid "show the patch being applied."
+msgstr "afficher le patch en cours d'application."
 
-#: builtin/config.c:137
-msgid "remove all matches: name [value-regex]"
-msgstr "supprimer toutes les correspondances nom [regex-de-valeur]"
+#: builtin/am.c:2237
+msgid "lie about committer date"
+msgstr "mentir sur la date de validation"
 
-#: builtin/config.c:138
-msgid "rename section: old-name new-name"
-msgstr "renommer une section : ancien-nom nouveau-nom"
+#: builtin/am.c:2239
+msgid "use current timestamp for author date"
+msgstr "utiliser l'horodatage actuel pour la date d'auteur"
 
-#: builtin/config.c:139
-msgid "remove a section: name"
-msgstr "supprimer une section : nom"
+#: builtin/am.c:2241 builtin/commit-tree.c:120 builtin/commit.c:1507
+#: builtin/merge.c:286 builtin/pull.c:194 builtin/rebase.c:509
+#: builtin/rebase.c:1513 builtin/revert.c:117 builtin/tag.c:418
+msgid "key-id"
+msgstr "id-clé"
 
-#: builtin/config.c:140
-msgid "list all"
-msgstr "afficher tout"
+#: builtin/am.c:2242 builtin/rebase.c:510 builtin/rebase.c:1514
+msgid "GPG-sign commits"
+msgstr "signer les commits avec GPG"
 
-#: builtin/config.c:141
-msgid "open an editor"
-msgstr "ouvrir un éditeur"
+#: builtin/am.c:2245
+msgid "(internal use for git-rebase)"
+msgstr "(utilisation interne pour git-rebase)"
 
-#: builtin/config.c:142
-msgid "find the color configured: slot [default]"
-msgstr "trouver la couleur configurée : slot [par défaut]"
+#: builtin/am.c:2263
+msgid ""
+"The -b/--binary option has been a no-op for long time, and\n"
+"it will be removed. Please do not use it anymore."
+msgstr ""
+"L'option -b/--binary ne fait plus rien depuis longtemps,\n"
+"et elle sera supprimée. Veuillez ne plus l'utiliser."
 
-#: builtin/config.c:143
-msgid "find the color setting: slot [stdout-is-tty]"
-msgstr "trouver le réglage de la couleur : slot [stdout-est-tty]"
+#: builtin/am.c:2270
+msgid "failed to read the index"
+msgstr "échec à la lecture de l'index"
 
-#: builtin/config.c:144
-msgid "Type"
-msgstr "Type"
+#: builtin/am.c:2285
+#, c-format
+msgid "previous rebase directory %s still exists but mbox given."
+msgstr ""
+"le répertoire précédent de rebasage %s existe toujours mais mbox donnée."
 
-#: builtin/config.c:145
-msgid "value is given this type"
-msgstr "ce type est assigné à la valeur"
+#: builtin/am.c:2309
+#, c-format
+msgid ""
+"Stray %s directory found.\n"
+"Use \"git am --abort\" to remove it."
+msgstr ""
+"Répertoire abandonné %s trouvé.\n"
+"Utilisez \"git am --abort\" pour le supprimer."
 
-#: builtin/config.c:146
-msgid "value is \"true\" or \"false\""
-msgstr "la valeur est \"true\" (vrai) ou \"false\" (faux)"
+#: builtin/am.c:2315
+msgid "Resolve operation not in progress, we are not resuming."
+msgstr ""
+"Pas de résolution de l'opération en cours, nous ne sommes pas dans une "
+"reprise."
 
-#: builtin/config.c:147
-msgid "value is decimal number"
-msgstr "la valeur est un nombre décimal"
+#: builtin/am.c:2325
+msgid "interactive mode requires patches on the command line"
+msgstr "le mode interactif requiert des rustines sur la ligne de commande"
 
-#: builtin/config.c:148
-msgid "value is --bool or --int"
-msgstr "la valeur est --bool ou --int"
+#: builtin/apply.c:8
+msgid "git apply [<options>] [<patch>...]"
+msgstr "git apply [<options>] [<patch>...]"
 
-#: builtin/config.c:149
-msgid "value is a path (file or directory name)"
-msgstr "la valeur est un chemin (vers un fichier ou un répertoire)"
+#: builtin/archive.c:17
+#, c-format
+msgid "could not create archive file '%s'"
+msgstr "création impossible du fichier d'archive '%s'"
 
-#: builtin/config.c:150
-msgid "value is an expiry date"
-msgstr "la valeur est une date d'expiration"
+#: builtin/archive.c:20
+msgid "could not redirect output"
+msgstr "impossible de rediriger la sortie"
 
-#: builtin/config.c:151
-msgid "Other"
-msgstr "Autre"
+#: builtin/archive.c:37
+msgid "git archive: Remote with no URL"
+msgstr "git archive : Dépôt distant sans URL"
 
-#: builtin/config.c:152
-msgid "terminate values with NUL byte"
-msgstr "terminer les valeurs avec un caractère NUL"
+#: builtin/archive.c:61
+msgid "git archive: expected ACK/NAK, got a flush packet"
+msgstr "git archive : ACK/NACK attendu, paquet de nettoyage reçu"
 
-#: builtin/config.c:153
-msgid "show variable names only"
-msgstr "n'afficher que les noms de variable"
+#: builtin/archive.c:64
+#, c-format
+msgid "git archive: NACK %s"
+msgstr "git archive : NACK %s"
 
-#: builtin/config.c:154
-msgid "respect include directives on lookup"
-msgstr "respecter les directives d'inclusion lors de la recherche"
+#: builtin/archive.c:65
+msgid "git archive: protocol error"
+msgstr "git archive : erreur de protocole"
 
-#: builtin/config.c:155
-msgid "show origin of config (file, standard input, blob, command line)"
-msgstr ""
-"afficher l'origine de la configuration (fichier, entrée standard, blob, "
-"ligne de commande)"
+#: builtin/archive.c:69
+msgid "git archive: expected a flush"
+msgstr "git archive : vidage attendu"
 
-#: builtin/config.c:156
-msgid "value"
-msgstr "valeur"
+#: builtin/bisect--helper.c:22
+msgid "git bisect--helper --next-all [--no-checkout]"
+msgstr "git bisect --helper --next-all [--no-checkout]"
 
-#: builtin/config.c:156
-msgid "with --get, use default value when missing entry"
-msgstr "avec --get, utiliser le valeur par défaut quand l'entrée n'existe pas"
+#: builtin/bisect--helper.c:23
+msgid "git bisect--helper --write-terms <bad_term> <good_term>"
+msgstr "git bisect--helper --write-terms <terme-pour-mauvais> <terme-pour-bon>"
 
-#: builtin/config.c:332
-#, c-format
-msgid "failed to format default config value: %s"
-msgstr "échec du formatage de la valeur de config par défaut : %s"
+#: builtin/bisect--helper.c:24
+msgid "git bisect--helper --bisect-clean-state"
+msgstr "git bisect--helper --bisect-clean-state"
 
-#: builtin/config.c:431
-msgid "unable to parse default color value"
-msgstr "impossible de lire la valeur de couleur par défaut"
+#: builtin/bisect--helper.c:25
+msgid "git bisect--helper --bisect-reset [<commit>]"
+msgstr "git bisect--helper --bisect-reset [<commit>]"
 
-#: builtin/config.c:575
-#, c-format
+#: builtin/bisect--helper.c:26
 msgid ""
-"# This is Git's per-user configuration file.\n"
-"[user]\n"
-"# Please adapt and uncomment the following lines:\n"
-"#\tname = %s\n"
-"#\temail = %s\n"
+"git bisect--helper --bisect-write [--no-log] <state> <revision> <good_term> "
+"<bad_term>"
 msgstr ""
-"# Ceci est le fichier de configuration personnel de Git.\n"
-"[user]\n"
-"# Veuillez adapter et décommenter les lignes suivantes :\n"
-"#\tname = %s\n"
-"#\temail = %s\n"
-
-#: builtin/config.c:603
-msgid "--local can only be used inside a git repository"
-msgstr "--local ne peut être utilisé qu'à l'intérieur d'un dépôt git"
+"git bisect--helper --bisect-write [--no-log] <état> <révision> <terme-pour-"
+"bon> <terme-pour-mauvais>"
 
-#: builtin/config.c:606
-msgid "--blob can only be used inside a git repository"
-msgstr "--blob ne peut être utilisé qu'à l'intérieur d'un dépôt git"
+#: builtin/bisect--helper.c:27
+msgid ""
+"git bisect--helper --bisect-check-and-set-terms <command> <good_term> "
+"<bad_term>"
+msgstr ""
+"git bisect--helper --bisect-check-and-set-terms <commande> <terme-pour-bon> "
+"<terme-pour-mauvais>"
 
-#: builtin/config.c:735
-#, c-format
-msgid "cannot create configuration file %s"
-msgstr "création impossible du fichier de configuration '%s'"
+#: builtin/bisect--helper.c:28
+msgid "git bisect--helper --bisect-next-check <good_term> <bad_term> [<term>]"
+msgstr ""
+"git bisect--helper --bisect-next-check <terme-pour-bon> <terme-pour-mauvais> "
+"[<term>]"
 
-#: builtin/config.c:748
-#, c-format
+#: builtin/bisect--helper.c:29
 msgid ""
-"cannot overwrite multiple values with a single value\n"
-"       Use a regexp, --add or --replace-all to change %s."
+"git bisect--helper --bisect-terms [--term-good | --term-old | --term-bad | --"
+"term-new]"
 msgstr ""
-"impossible de surcharger des valeurs multiples avec une seule valeur\n"
-"       Utilisez une regexp, --add ou --replace-all pour modifier %s."
+"git bisect--helper --bisect-terms [--term-good | --term-old | --term-bad | --"
+"term-new]"
 
-#: builtin/count-objects.c:90
-msgid "git count-objects [-v] [-H | --human-readable]"
-msgstr "git count-objects [-v] [-H | --human-readable]"
+#: builtin/bisect--helper.c:30
+msgid ""
+"git bisect--helper --bisect-start [--term-{old,good}=<term> --term-{new,bad}"
+"=<term>][--no-checkout] [<bad> [<good>...]] [--] [<paths>...]"
+msgstr ""
+"git bisect--helper --bisect-start [--term-{old,good}=<terme> --term-{new,bad}"
+"=<terme>][--no-checkout] [<mauvais> [<bon>...]] [--] [<chemins>...]"
 
-#: builtin/count-objects.c:100
-msgid "print sizes in human readable format"
-msgstr "affiche les tailles dans un format humainement lisible"
+#: builtin/bisect--helper.c:86
+#, c-format
+msgid "'%s' is not a valid term"
+msgstr "'%s' n'est pas un terme valide"
 
-#: builtin/describe.c:22
-msgid "git describe [<options>] [<commit-ish>...]"
-msgstr "git describe [<options>] <commit ou apparenté>*"
+#: builtin/bisect--helper.c:90
+#, c-format
+msgid "can't use the builtin command '%s' as a term"
+msgstr "impossible d'utiliser la commande incluse '%s' comme terme"
 
-#: builtin/describe.c:23
-msgid "git describe [<options>] --dirty"
-msgstr "git describe [<options>] --dirty"
+#: builtin/bisect--helper.c:100
+#, c-format
+msgid "can't change the meaning of the term '%s'"
+msgstr "impossible de modifier la signification du terme '%s'"
 
-#: builtin/describe.c:57
-msgid "head"
-msgstr "tête"
+#: builtin/bisect--helper.c:111
+msgid "please use two different terms"
+msgstr "veuillez utiliser deux termes différents"
 
-#: builtin/describe.c:57
-msgid "lightweight"
-msgstr "léger"
+#: builtin/bisect--helper.c:118
+msgid "could not open the file BISECT_TERMS"
+msgstr "impossible d'ouvrir le fichier BISECT_TERMS"
 
-#: builtin/describe.c:57
-msgid "annotated"
-msgstr "annoté"
+#: builtin/bisect--helper.c:155
+#, c-format
+msgid "We are not bisecting.\n"
+msgstr "Pas de bissection en cours.\n"
 
-#: builtin/describe.c:267
+#: builtin/bisect--helper.c:163
 #, c-format
-msgid "annotated tag %s not available"
-msgstr "l'étiquette annotée %s n'est pas disponible"
+msgid "'%s' is not a valid commit"
+msgstr "'%s' n'est pas un commit valide"
 
-#: builtin/describe.c:271
+#: builtin/bisect--helper.c:172
 #, c-format
-msgid "annotated tag %s has no embedded name"
-msgstr "l'étiquette annotée %s n'a pas de nom embarqué"
+msgid ""
+"could not check out original HEAD '%s'. Try 'git bisect reset <commit>'."
+msgstr ""
+"Échec d'extraction de la HEAD d'origine '%s'. Essayez 'git bisect reset "
+"<commit>'."
 
-#: builtin/describe.c:273
+#: builtin/bisect--helper.c:216
 #, c-format
-msgid "tag '%s' is really '%s' here"
-msgstr "l'étiquette '%s' est en fait '%s'"
+msgid "Bad bisect_write argument: %s"
+msgstr "Mauvais argument pour bisect_write : %s"
 
-#: builtin/describe.c:317
+#: builtin/bisect--helper.c:221
 #, c-format
-msgid "no tag exactly matches '%s'"
-msgstr "aucune étiquette ne correspond parfaitement à '%s'"
+msgid "couldn't get the oid of the rev '%s'"
+msgstr "impossible d'obtenir l'oid de la révision '%s'"
 
-#: builtin/describe.c:319
+#: builtin/bisect--helper.c:233
 #, c-format
-msgid "No exact match on refs or tags, searching to describe\n"
-msgstr ""
-"Pas de correspondance exacte sur des réfs ou des étiquettes, recherche par "
-"describe\n"
+msgid "couldn't open the file '%s'"
+msgstr "impossible d'ouvrir le fichier '%s'"
 
-#: builtin/describe.c:366
+#: builtin/bisect--helper.c:259
 #, c-format
-msgid "finished search at %s\n"
-msgstr "recherche terminée à %s\n"
+msgid "Invalid command: you're currently in a %s/%s bisect"
+msgstr "Commande invalide : vous êtes actuellement dans une bissection %s/%s"
 
-#: builtin/describe.c:392
+#: builtin/bisect--helper.c:286
 #, c-format
 msgid ""
-"No annotated tags can describe '%s'.\n"
-"However, there were unannotated tags: try --tags."
+"You need to give me at least one %s and %s revision.\n"
+"You can use \"git bisect %s\" and \"git bisect %s\" for that."
 msgstr ""
-"Aucune étiquette annotée ne peut décrire '%s'.\n"
-"Cependant, il existe des étiquettes non-annotées : essayez avec --tags."
+"Vous devez me donner au moins une révision %s et une révision %s.\n"
+"Vous pouvez utiliser \"git bisect %s\" et \"git bisect %s\" pour cela."
 
-#: builtin/describe.c:396
+#: builtin/bisect--helper.c:290
 #, c-format
 msgid ""
-"No tags can describe '%s'.\n"
-"Try --always, or create some tags."
+"You need to start by \"git bisect start\".\n"
+"You then need to give me at least one %s and %s revision.\n"
+"You can use \"git bisect %s\" and \"git bisect %s\" for that."
 msgstr ""
-"Aucune étiquette ne peut décrire '%s'.\n"
-"Essayez --always, ou créez des étiquettes."
+"Vous devez démarrer avec \"git bisect start\".\n"
+"Puis vous devez me donner au moins une révision %s et une révision %s.\n"
+"Vous pouvez utiliser \"git bisect %s\" et \"git bisect %s\" pour cela."
 
-#: builtin/describe.c:426
+#: builtin/bisect--helper.c:322
 #, c-format
-msgid "traversed %lu commits\n"
-msgstr "%lu commits parcourus\n"
+msgid "bisecting only with a %s commit"
+msgstr "Attention : bissection avec seulement une validation %s"
+
+#. TRANSLATORS: Make sure to include [Y] and [n] in your
+#. translation. The program will only accept English input
+#. at this point.
+#.
+#: builtin/bisect--helper.c:330
+msgid "Are you sure [Y/n]? "
+msgstr "Confirmez-vous [Y/n] ? "
 
-#: builtin/describe.c:429
+#: builtin/bisect--helper.c:377
+msgid "no terms defined"
+msgstr "aucun terme défini"
+
+#: builtin/bisect--helper.c:380
 #, c-format
 msgid ""
-"more than %i tags found; listed %i most recent\n"
-"gave up search at %s\n"
+"Your current terms are %s for the old state\n"
+"and %s for the new state.\n"
 msgstr ""
-"plus de %i étiquettes ont été trouvées; seules les %i plus récentes sont "
-"affichées\n"
-"abandon de la recherche à %s\n"
+"Vos termes actuels sont %s pour l'état ancien\n"
+"et %s pour le nouvel état.\n"
 
-#: builtin/describe.c:497
+#: builtin/bisect--helper.c:390
 #, c-format
-msgid "describe %s\n"
-msgstr "décrire %s\n"
+msgid ""
+"invalid argument %s for 'git bisect terms'.\n"
+"Supported options are: --term-good|--term-old and --term-bad|--term-new."
+msgstr ""
+"argument invalide %s pour 'git bisect terms'.\n"
+"Les options supportées sont : --term-good|--term-old et --term-bad|--term-"
+"new."
 
-#: builtin/describe.c:500 builtin/log.c:502
+#: builtin/bisect--helper.c:476
 #, c-format
-msgid "Not a valid object name %s"
-msgstr "%s n'est pas un nom d'objet valide"
+msgid "unrecognized option: '%s'"
+msgstr "option non reconnue : %s"
 
-#: builtin/describe.c:508
+#: builtin/bisect--helper.c:480
 #, c-format
-msgid "%s is neither a commit nor blob"
-msgstr "%s n'est ni un commit ni un blob"
-
-#: builtin/describe.c:522
-msgid "find the tag that comes after the commit"
-msgstr "rechercher l'étiquette qui suit le commit"
-
-#: builtin/describe.c:523
-msgid "debug search strategy on stderr"
-msgstr "déboguer la stratégie de recherche sur stderr"
+msgid "'%s' does not appear to be a valid revision"
+msgstr "'%s' ne semble être une révision valide"
 
-#: builtin/describe.c:524
-msgid "use any ref"
-msgstr "utiliser n'importe quelle référence"
+#: builtin/bisect--helper.c:512
+msgid "bad HEAD - I need a HEAD"
+msgstr "mauvaise HEAD - j'ai besoin d'une HEAD"
 
-#: builtin/describe.c:525
-msgid "use any tag, even unannotated"
-msgstr "utiliser n'importe quelle étiquette, même non-annotée"
+#: builtin/bisect--helper.c:527
+#, c-format
+msgid "checking out '%s' failed. Try 'git bisect start <valid-branch>'."
+msgstr ""
+"L'extraction de '%s' a échoué. Essayez 'git bisect start <branche-valide>'."
 
-#: builtin/describe.c:526
-msgid "always use long format"
-msgstr "toujours utiliser le format long"
+#: builtin/bisect--helper.c:548
+msgid "won't bisect on cg-seek'ed tree"
+msgstr "refus de bissecter sur un arbre 'cg-seeked'"
 
-#: builtin/describe.c:527
-msgid "only follow first parent"
-msgstr "ne suivre que le premier parent"
+#: builtin/bisect--helper.c:551
+msgid "bad HEAD - strange symbolic ref"
+msgstr "mauvaise HEAD - référence symbolique douteuse"
 
-#: builtin/describe.c:530
-msgid "only output exact matches"
-msgstr "n'afficher que les correspondances exactes"
+#: builtin/bisect--helper.c:575
+#, c-format
+msgid "invalid ref: '%s'"
+msgstr "réference invalide : '%s'"
 
-#: builtin/describe.c:532
-msgid "consider <n> most recent tags (default: 10)"
-msgstr ""
-"considérer uniquement les <n> étiquettes le plus récentes (défaut : 10)"
+#: builtin/bisect--helper.c:631
+msgid "perform 'git bisect next'"
+msgstr "effectuer 'git bisect next'"
 
-#: builtin/describe.c:534
-msgid "only consider tags matching <pattern>"
-msgstr "ne considérer que les étiquettes correspondant à <motif>"
+#: builtin/bisect--helper.c:633
+msgid "write the terms to .git/BISECT_TERMS"
+msgstr "écrire les termes dans .git/BISECT_TERMS"
 
-#: builtin/describe.c:536
-msgid "do not consider tags matching <pattern>"
-msgstr "ne pas considérer les étiquettes correspondant à <motif>"
+#: builtin/bisect--helper.c:635
+msgid "cleanup the bisection state"
+msgstr "vérifier l'état de la bissection"
 
-#: builtin/describe.c:538 builtin/name-rev.c:406
-msgid "show abbreviated commit object as fallback"
-msgstr "afficher les objets commits abrégés en dernier recours"
+#: builtin/bisect--helper.c:637
+msgid "check for expected revs"
+msgstr "vérifier si des révisions sont attendues"
 
-#: builtin/describe.c:539 builtin/describe.c:542
-msgid "mark"
-msgstr "marque"
+#: builtin/bisect--helper.c:639
+msgid "reset the bisection state"
+msgstr "réinitialiser l'état de la bissection"
+
+#: builtin/bisect--helper.c:641
+msgid "write out the bisection state in BISECT_LOG"
+msgstr "écrire l'état de la bissection dans BISECT_LOG"
+
+#: builtin/bisect--helper.c:643
+msgid "check and set terms in a bisection state"
+msgstr "vérifier et régler les termes dans un état de la bissection"
+
+#: builtin/bisect--helper.c:645
+msgid "check whether bad or good terms exist"
+msgstr "vérifier si les termes bons ou mauvais existent"
+
+#: builtin/bisect--helper.c:647
+msgid "print out the bisect terms"
+msgstr "afficher les termes de bissection"
+
+#: builtin/bisect--helper.c:649
+msgid "start the bisect session"
+msgstr "démarrer une session de bissection"
 
-#: builtin/describe.c:540
-msgid "append <mark> on dirty working tree (default: \"-dirty\")"
-msgstr "ajouter <marque> si la copie de travail est sale (défaut : \"-dirty\")"
+#: builtin/bisect--helper.c:651
+msgid "update BISECT_HEAD instead of checking out the current commit"
+msgstr "mettre à jour BISECT_HEAD au lieu d'extraire le commit actuel"
 
-#: builtin/describe.c:543
-msgid "append <mark> on broken working tree (default: \"-broken\")"
-msgstr ""
-"ajouter <marque> si la copie de travail est cassée (défaut : \"-broken\")"
+#: builtin/bisect--helper.c:653
+msgid "no log for BISECT_WRITE"
+msgstr "pas de journal pour BISECT_WRITE"
 
-#: builtin/describe.c:561
-msgid "--long is incompatible with --abbrev=0"
-msgstr "--long et --abbrev=0 sont incompatibles"
+#: builtin/bisect--helper.c:670
+msgid "--write-terms requires two arguments"
+msgstr "--write-terms exige deux arguments"
 
-#: builtin/describe.c:590
-msgid "No names found, cannot describe anything."
-msgstr "aucun nom trouvé, impossible de décrire quoi que ce soit."
+#: builtin/bisect--helper.c:674
+msgid "--bisect-clean-state requires no arguments"
+msgstr "--bisect-clean-state ne supporte aucun argument"
 
-#: builtin/describe.c:640
-msgid "--dirty is incompatible with commit-ishes"
-msgstr "--dirty est incompatible avec la spécification de commits ou assimilés"
+#: builtin/bisect--helper.c:681
+msgid "--bisect-reset requires either no argument or a commit"
+msgstr "--bisect-reset supporte soit aucun argument, soit un commit"
+
+#: builtin/bisect--helper.c:685
+msgid "--bisect-write requires either 4 or 5 arguments"
+msgstr "--bisect-write supporte soit 4 arguments, soit 5 arguments"
+
+#: builtin/bisect--helper.c:691
+msgid "--check-and-set-terms requires 3 arguments"
+msgstr "--check-and-set-terms exige 3 arguments"
+
+#: builtin/bisect--helper.c:697
+msgid "--bisect-next-check requires 2 or 3 arguments"
+msgstr "--bisect-next-check exige 2 ou 3 arguments"
+
+#: builtin/bisect--helper.c:703
+msgid "--bisect-terms requires 0 or 1 argument"
+msgstr "--bisect-terms exige 0 ou 1 argument"
 
-#: builtin/describe.c:642
-msgid "--broken is incompatible with commit-ishes"
-msgstr "--broken est incompatible avec les commits ou assimilés"
+#: builtin/blame.c:31
+msgid "git blame [<options>] [<rev-opts>] [<rev>] [--] <file>"
+msgstr "git blame [<options>] [<rev-opts>] [<rev>] [--] <fichier>"
 
-#: builtin/diff.c:83
-#, c-format
-msgid "'%s': not a regular file or symlink"
-msgstr "'%s' : n'est pas un fichier régulier ni un lien symbolique"
+#: builtin/blame.c:36
+msgid "<rev-opts> are documented in git-rev-list(1)"
+msgstr "<options-de-révision> sont documentés dans git-rev-list(1)"
 
-#: builtin/diff.c:234
+#: builtin/blame.c:409
 #, c-format
-msgid "invalid option: %s"
-msgstr "option invalide : %s"
+msgid "expecting a color: %s"
+msgstr "couleur attendue : %s"
 
-#: builtin/diff.c:356
-msgid "Not a git repository"
-msgstr "Ce n'est pas un dépôt git !"
+#: builtin/blame.c:416
+msgid "must end with a color"
+msgstr "doit finir avec une couleur"
 
-#: builtin/diff.c:399
+#: builtin/blame.c:729
 #, c-format
-msgid "invalid object '%s' given."
-msgstr "objet spécifié '%s' invalide."
+msgid "invalid color '%s' in color.blame.repeatedLines"
+msgstr "couleur invalide '%s' dans color.blame.repeatedlines"
 
-#: builtin/diff.c:408
-#, c-format
-msgid "more than two blobs given: '%s'"
-msgstr "plus de deux blobs spécifiés : '%s'"
+#: builtin/blame.c:747
+msgid "invalid value for blame.coloring"
+msgstr "valeur invalide pour blame.coloring"
 
-#: builtin/diff.c:413
+#: builtin/blame.c:822
 #, c-format
-msgid "unhandled object '%s' given."
-msgstr "objet non géré '%s' spécifié."
+msgid "cannot find revision %s to ignore"
+msgstr "référence à ignorer %s introuvable"
 
-#: builtin/difftool.c:29
-msgid "git difftool [<options>] [<commit> [<commit>]] [--] [<path>...]"
-msgstr "git difftool [<options>] [<commit> [<commit>]] [--] [<chemin>...]"
+#: builtin/blame.c:844
+msgid "Show blame entries as we find them, incrementally"
+msgstr ""
+"Montrer les éléments de blâme au fur et à mesure de leur découverte, de "
+"manière incrémentale"
 
-#: builtin/difftool.c:259
-#, c-format
-msgid "failed: %d"
-msgstr "échec : %d"
+#: builtin/blame.c:845
+msgid "Show blank SHA-1 for boundary commits (Default: off)"
+msgstr "Montrer un SHA-1 blanc pour les commits de limite (Défaut : désactivé)"
 
-#: builtin/difftool.c:301
-#, c-format
-msgid "could not read symlink %s"
-msgstr "lecture du lien symbolique %s impossible"
+#: builtin/blame.c:846
+msgid "Do not treat root commits as boundaries (Default: off)"
+msgstr ""
+"Ne pas traiter les commits racine comme des limites (Défaut : désactivé)"
 
-#: builtin/difftool.c:303
-#, c-format
-msgid "could not read symlink file %s"
-msgstr "impossible de lire le fichier symlink %s"
+#: builtin/blame.c:847
+msgid "Show work cost statistics"
+msgstr "Montrer les statistiques de coût d'activité"
 
-#: builtin/difftool.c:311
-#, c-format
-msgid "could not read object %s for symlink %s"
-msgstr "Impossible de lire l'objet %s pour le symlink %s"
+#: builtin/blame.c:848
+msgid "Force progress reporting"
+msgstr "Forcer l'affichage de l'état d'avancement"
 
-#: builtin/difftool.c:412
-msgid ""
-"combined diff formats('-c' and '--cc') are not supported in\n"
-"directory diff mode('-d' and '--dir-diff')."
-msgstr ""
-"les formats de diff combinés ('-c' et '--cc') ne sont pas supportés\n"
-"dans le mode de diff de répertoire ('-d' et '--dir-diff')."
+#: builtin/blame.c:849
+msgid "Show output score for blame entries"
+msgstr "Montrer le score de sortie pour les éléments de blâme"
 
-#: builtin/difftool.c:632
-#, c-format
-msgid "both files modified: '%s' and '%s'."
-msgstr "les deux fichiers sont modifiés : '%s' et '%s'."
+#: builtin/blame.c:850
+msgid "Show original filename (Default: auto)"
+msgstr "Montrer les noms de fichier originaux (Défaut : auto)"
 
-#: builtin/difftool.c:634
-msgid "working tree file has been left."
-msgstr "le fichier dans l'arbre de travail a été laissé."
+#: builtin/blame.c:851
+msgid "Show original linenumber (Default: off)"
+msgstr "Montrer les numéros de lignes originaux (Défaut : désactivé)"
 
-#: builtin/difftool.c:645
-#, c-format
-msgid "temporary files exist in '%s'."
-msgstr "des fichiers temporaires existent dans '%s'."
+#: builtin/blame.c:852
+msgid "Show in a format designed for machine consumption"
+msgstr "Afficher dans un format propice à la consommation par machine"
 
-#: builtin/difftool.c:646
-msgid "you may want to cleanup or recover these."
-msgstr "vous pourriez souhaiter les nettoyer ou les récupérer."
+#: builtin/blame.c:853
+msgid "Show porcelain format with per-line commit information"
+msgstr "Afficher en format porcelaine avec l'information de commit par ligne"
 
-#: builtin/difftool.c:695
-msgid "use `diff.guitool` instead of `diff.tool`"
-msgstr "utiliser `diff.guitool` au lieu de `diff.tool`"
+#: builtin/blame.c:854
+msgid "Use the same output mode as git-annotate (Default: off)"
+msgstr "Utiliser le même mode de sortie que git-annotate (Défaut : désactivé)"
 
-#: builtin/difftool.c:697
-msgid "perform a full-directory diff"
-msgstr "réalise un diff de répertoire complet"
+#: builtin/blame.c:855
+msgid "Show raw timestamp (Default: off)"
+msgstr "Afficher les horodatages bruts (Défaut : désactivé)"
 
-#: builtin/difftool.c:699
-msgid "do not prompt before launching a diff tool"
-msgstr "ne pas confirmer avant de lancer l'outil de diff"
+#: builtin/blame.c:856
+msgid "Show long commit SHA1 (Default: off)"
+msgstr "Afficher les longs SHA1 de commits (Défaut : désactivé)"
 
-#: builtin/difftool.c:704
-msgid "use symlinks in dir-diff mode"
-msgstr "utiliser les liens symboliques en mode de diff de répertoire"
+#: builtin/blame.c:857
+msgid "Suppress author name and timestamp (Default: off)"
+msgstr "Supprimer le nom de l'auteur et l'horodatage (Défaut : désactivé)"
 
-#: builtin/difftool.c:705
-msgid "<tool>"
-msgstr "<outil>"
+#: builtin/blame.c:858
+msgid "Show author email instead of name (Default: off)"
+msgstr "Afficher le courriel de l'auteur au lieu du nom (Défaut : désactivé)"
 
-#: builtin/difftool.c:706
-msgid "use the specified diff tool"
-msgstr "utiliser l'outil de diff spécifié"
+#: builtin/blame.c:859
+msgid "Ignore whitespace differences"
+msgstr "Ignorer les différences d'espace"
 
-#: builtin/difftool.c:708
-msgid "print a list of diff tools that may be used with `--tool`"
-msgstr "afficher une liste des outils de diff utilisables avec `--tool`"
+#: builtin/blame.c:860 builtin/log.c:1702
+msgid "rev"
+msgstr "rév"
+
+#: builtin/blame.c:860
+msgid "Ignore <rev> when blaming"
+msgstr "ignore <rev> pendant le blâme"
+
+#: builtin/blame.c:861
+msgid "Ignore revisions from <file>"
+msgstr "ignorer les révisions listées dans <fichier>"
 
-#: builtin/difftool.c:711
-msgid ""
-"make 'git-difftool' exit when an invoked diff tool returns a non - zero exit "
-"code"
+#: builtin/blame.c:862
+msgid "color redundant metadata from previous line differently"
 msgstr ""
-"provoque la fin de 'git-difftool' si l'outil de diff invoqué renvoie un code "
-"non-nul"
+"colorer différemment les métadonnées redondantes avec la ligne précédente"
 
-#: builtin/difftool.c:713
-msgid "<command>"
-msgstr "<commande>"
+#: builtin/blame.c:863
+msgid "color lines by age"
+msgstr "colorier les lignes par âge"
 
-#: builtin/difftool.c:714
-msgid "specify a custom command for viewing diffs"
-msgstr "spécifier une commande personnalisée pour visualiser les différences"
-
-#: builtin/difftool.c:738
-msgid "no <tool> given for --tool=<tool>"
-msgstr "pas d'<outil> spécifié pour --tool=<outil>"
+#: builtin/blame.c:864
+msgid "Spend extra cycles to find better match"
+msgstr ""
+"Dépenser des cycles supplémentaires pour trouver une meilleure correspondance"
 
-#: builtin/difftool.c:745
-msgid "no <cmd> given for --extcmd=<cmd>"
-msgstr "pas de <commande> spécifié pour --extcmd=<commande>"
+#: builtin/blame.c:865
+msgid "Use revisions from <file> instead of calling git-rev-list"
+msgstr ""
+"Utiliser les révisions du fichier <fichier> au lieu d'appeler git-rev-list"
 
-#: builtin/fast-export.c:27
-msgid "git fast-export [rev-list-opts]"
-msgstr "git fast-export [options-de-liste-de-révisions]"
+#: builtin/blame.c:866
+msgid "Use <file>'s contents as the final image"
+msgstr "Utiliser le contenu de <fichier> comme image finale"
 
-#: builtin/fast-export.c:1000
-msgid "show progress after <n> objects"
-msgstr "afficher la progression après <n> objets"
+#: builtin/blame.c:867 builtin/blame.c:868
+msgid "score"
+msgstr "score"
 
-#: builtin/fast-export.c:1002
-msgid "select handling of signed tags"
-msgstr "sélectionner la gestion des étiquettes signées"
+#: builtin/blame.c:867
+msgid "Find line copies within and across files"
+msgstr "Trouver les copies de ligne dans et entre les fichiers"
 
-#: builtin/fast-export.c:1005
-msgid "select handling of tags that tag filtered objects"
-msgstr ""
-"sélectionner la gestion des étiquettes qui pointent sur des objets filtrés"
+#: builtin/blame.c:868
+msgid "Find line movements within and across files"
+msgstr "Trouver les mouvements de ligne dans et entre les fichiers"
 
-#: builtin/fast-export.c:1008
-msgid "Dump marks to this file"
-msgstr "Enregistrer les marques dans ce fichier"
+#: builtin/blame.c:869
+msgid "n,m"
+msgstr "n,m"
 
-#: builtin/fast-export.c:1010
-msgid "Import marks from this file"
-msgstr "importer les marques depuis ce fichier"
+#: builtin/blame.c:869
+msgid "Process only line range n,m, counting from 1"
+msgstr ""
+"Traiter seulement l'intervalle de ligne n,m en commençant le compte à 1"
 
-#: builtin/fast-export.c:1012
-msgid "Fake a tagger when tags lack one"
-msgstr "falsifier un auteur d'étiquette si l'étiquette n'en présente pas"
+#: builtin/blame.c:921
+msgid "--progress can't be used with --incremental or porcelain formats"
+msgstr ""
+"--progress ne peut pas être utilisé avec --incremental ou les formats "
+"porcelaine"
 
-#: builtin/fast-export.c:1014
-msgid "Output full tree for each commit"
-msgstr "Afficher l'arbre complet pour chaque commit"
+#. TRANSLATORS: This string is used to tell us the
+#. maximum display width for a relative timestamp in
+#. "git blame" output.  For C locale, "4 years, 11
+#. months ago", which takes 22 places, is the longest
+#. among various forms of relative timestamps, but
+#. your language may need more or fewer display
+#. columns.
+#.
+#: builtin/blame.c:972
+msgid "4 years, 11 months ago"
+msgstr "il y a 10 ans et 11 mois"
 
-#: builtin/fast-export.c:1016
-msgid "Use the done feature to terminate the stream"
-msgstr "Utiliser la fonction \"done\" pour terminer le flux"
+#: builtin/blame.c:1079
+#, c-format
+msgid "file %s has only %lu line"
+msgid_plural "file %s has only %lu lines"
+msgstr[0] "le fichier %s n'a qu'%lu ligne"
+msgstr[1] "le fichier %s n'a que %lu lignes"
 
-#: builtin/fast-export.c:1017
-msgid "Skip output of blob data"
-msgstr "Sauter l'affichage de données de blob"
+#: builtin/blame.c:1125
+msgid "Blaming lines"
+msgstr "Assignation de blâme aux lignes"
 
-#: builtin/fast-export.c:1018
-msgid "refspec"
-msgstr "spécificateur de référence"
+#: builtin/branch.c:29
+msgid "git branch [<options>] [-r | -a] [--merged | --no-merged]"
+msgstr "git branch [<options>] [-r | -a] [--merged | --no-merged]"
 
-#: builtin/fast-export.c:1019
-msgid "Apply refspec to exported refs"
-msgstr "Appliquer le spécificateur de référence aux références exportées"
+#: builtin/branch.c:30
+msgid "git branch [<options>] [-l] [-f] <branch-name> [<start-point>]"
+msgstr "git branch [<options] [-l] [-f] <nom-de-branche> [<point-de-départ>]"
 
-#: builtin/fast-export.c:1020
-msgid "anonymize output"
-msgstr "anonymise la sortie"
+#: builtin/branch.c:31
+msgid "git branch [<options>] [-r] (-d | -D) <branch-name>..."
+msgstr "git branch [<options>] [-r] (-d | -D) <nom-de-branche>..."
 
-#: builtin/fetch.c:26
-msgid "git fetch [<options>] [<repository> [<refspec>...]]"
-msgstr "git fetch [<options>] [<dépôt> [<spécification-de-référence>...]]"
+#: builtin/branch.c:32
+msgid "git branch [<options>] (-m | -M) [<old-branch>] <new-branch>"
+msgstr ""
+"git branch [<options>] (-m | -M) [<ancienne-branche>] <nouvelle-branche>"
 
-#: builtin/fetch.c:27
-msgid "git fetch [<options>] <group>"
-msgstr "git fetch [<options>] <groupe>"
+#: builtin/branch.c:33
+msgid "git branch [<options>] (-c | -C) [<old-branch>] <new-branch>"
+msgstr ""
+"git branch [<options>] (-c | -C) [<ancienne-branche>] <nouvelle-branche>"
 
-#: builtin/fetch.c:28
-msgid "git fetch --multiple [<options>] [(<repository> | <group>)...]"
-msgstr "git fetch --multiple [<options>] [(<dépôt> | <groupe>)...]"
+#: builtin/branch.c:34
+msgid "git branch [<options>] [-r | -a] [--points-at]"
+msgstr "git branch [<options>] [-r | -a] [--points-at]"
 
-#: builtin/fetch.c:29
-msgid "git fetch --all [<options>]"
-msgstr "git fetch --all [<options>]"
+#: builtin/branch.c:35
+msgid "git branch [<options>] [-r | -a] [--format]"
+msgstr "git branch [<options>] [-r | -a] [--format]"
 
-#: builtin/fetch.c:123 builtin/pull.c:193
-msgid "fetch from all remotes"
-msgstr "récupérer depuis tous les dépôts distants"
+#: builtin/branch.c:154
+#, c-format
+msgid ""
+"deleting branch '%s' that has been merged to\n"
+"         '%s', but not yet merged to HEAD."
+msgstr ""
+"suppression de la branche '%s' qui a été fusionnée dans\n"
+"         '%s', mais pas dans HEAD."
 
-#: builtin/fetch.c:125 builtin/pull.c:196
-msgid "append to .git/FETCH_HEAD instead of overwriting"
-msgstr "ajouter à .git/FETCH_HEAD au lieu de l'écraser"
+#: builtin/branch.c:158
+#, c-format
+msgid ""
+"not deleting branch '%s' that is not yet merged to\n"
+"         '%s', even though it is merged to HEAD."
+msgstr ""
+"branche '%s' non supprimée car elle n'a pas été fusionnée dans\n"
+"         '%s', même si elle est fusionnée dans HEAD."
 
-#: builtin/fetch.c:127 builtin/pull.c:199
-msgid "path to upload pack on remote end"
-msgstr "chemin vers lequel télécharger le paquet sur le poste distant"
+#: builtin/branch.c:172
+#, c-format
+msgid "Couldn't look up commit object for '%s'"
+msgstr "Impossible de rechercher l'objet commit pour '%s'"
 
-#: builtin/fetch.c:128 builtin/pull.c:201
-msgid "force overwrite of local branch"
-msgstr "forcer l'écrasement de la branche locale"
+#: builtin/branch.c:176
+#, c-format
+msgid ""
+"The branch '%s' is not fully merged.\n"
+"If you are sure you want to delete it, run 'git branch -D %s'."
+msgstr ""
+"La branche '%s' n'est pas totalement fusionnée.\n"
+"Si vous souhaitez réellement la supprimer, lancez 'git branch -D %s'."
 
-#: builtin/fetch.c:130
-msgid "fetch from multiple remotes"
-msgstr "récupérer depuis plusieurs dépôts distants"
+#: builtin/branch.c:189
+msgid "Update of config-file failed"
+msgstr "Échec de la mise à jour du fichier de configuration"
 
-#: builtin/fetch.c:132 builtin/pull.c:203
-msgid "fetch all tags and associated objects"
-msgstr "récupérer toutes les étiquettes et leurs objets associés"
+#: builtin/branch.c:220
+msgid "cannot use -a with -d"
+msgstr "impossible d'utiliser -a avec -d"
 
-#: builtin/fetch.c:134
-msgid "do not fetch all tags (--no-tags)"
-msgstr "ne pas récupérer toutes les étiquettes (--no-tags)"
+#: builtin/branch.c:226
+msgid "Couldn't look up commit object for HEAD"
+msgstr "Impossible de rechercher l'objet commit pour HEAD"
 
-#: builtin/fetch.c:136
-msgid "number of submodules fetched in parallel"
-msgstr "nombre de sous-modules récupérés en parallèle"
+#: builtin/branch.c:240
+#, c-format
+msgid "Cannot delete branch '%s' checked out at '%s'"
+msgstr "Impossible de supprimer la branche '%s' extraite dans '%s'"
 
-#: builtin/fetch.c:138 builtin/pull.c:206
-msgid "prune remote-tracking branches no longer on remote"
-msgstr ""
-"éliminer les branches de suivi distant si la branche n'existe plus dans le "
-"dépôt distant"
+#: builtin/branch.c:255
+#, c-format
+msgid "remote-tracking branch '%s' not found."
+msgstr "branche de suivi '%s' non trouvée."
 
-#: builtin/fetch.c:140
-msgid "prune local tags no longer on remote and clobber changed tags"
-msgstr ""
-"éliminer les étiquettes locales qui ont disparu du dépôt distant et qui "
-"encombrent les étiquettes modifiées"
+#: builtin/branch.c:256
+#, c-format
+msgid "branch '%s' not found."
+msgstr "branche '%s' non trouvée."
 
-#: builtin/fetch.c:141 builtin/fetch.c:164 builtin/pull.c:131
-msgid "on-demand"
-msgstr "à la demande"
+#: builtin/branch.c:271
+#, c-format
+msgid "Error deleting remote-tracking branch '%s'"
+msgstr "Erreur lors de la suppression de la branche de suivi '%s'"
 
-#: builtin/fetch.c:142
-msgid "control recursive fetching of submodules"
-msgstr "contrôler la récupération récursive dans les sous-modules"
+#: builtin/branch.c:272
+#, c-format
+msgid "Error deleting branch '%s'"
+msgstr "Erreur lors de la suppression de la branche '%s'"
 
-#: builtin/fetch.c:146 builtin/pull.c:214
-msgid "keep downloaded pack"
-msgstr "conserver le paquet téléchargé"
+#: builtin/branch.c:279
+#, c-format
+msgid "Deleted remote-tracking branch %s (was %s).\n"
+msgstr "Branche de suivi %s supprimée (précédemment %s).\n"
 
-#: builtin/fetch.c:148
-msgid "allow updating of HEAD ref"
-msgstr "permettre la mise à jour de la référence HEAD"
+#: builtin/branch.c:280
+#, c-format
+msgid "Deleted branch %s (was %s).\n"
+msgstr "Branche %s supprimée (précédemment %s).\n"
 
-#: builtin/fetch.c:151 builtin/fetch.c:157 builtin/pull.c:217
-msgid "deepen history of shallow clone"
-msgstr "approfondir l'historique d'un clone superficiel"
+#: builtin/branch.c:429 builtin/tag.c:61
+msgid "unable to parse format string"
+msgstr "impossible d'analyser la chaîne de format"
 
-#: builtin/fetch.c:153
-msgid "deepen history of shallow repository based on time"
-msgstr "approfondir l'historique d'un clone superficiel en fonction d'une date"
+#: builtin/branch.c:460
+msgid "could not resolve HEAD"
+msgstr "impossible de résoudre HEAD"
 
-#: builtin/fetch.c:159 builtin/pull.c:220
-msgid "convert to a complete repository"
-msgstr "convertir en un dépôt complet"
+#: builtin/branch.c:466
+#, c-format
+msgid "HEAD (%s) points outside of refs/heads/"
+msgstr "HEAD (%s) pointe hors de refs/heads/"
 
-#: builtin/fetch.c:162
-msgid "prepend this to submodule path output"
-msgstr "préfixer ceci à la sortie du chemin du sous-module"
+#: builtin/branch.c:481
+#, c-format
+msgid "Branch %s is being rebased at %s"
+msgstr "La branche %s est en cours de rebasage sur %s"
 
-#: builtin/fetch.c:165
-msgid ""
-"default for recursive fetching of submodules (lower priority than config "
-"files)"
-msgstr ""
-"par défaut pour la récupération récursive de sous-modules (priorité plus "
-"basse que les fichiers de config)"
+#: builtin/branch.c:485
+#, c-format
+msgid "Branch %s is being bisected at %s"
+msgstr "La branche %s est en cours de bissection sur %s"
 
-#: builtin/fetch.c:169 builtin/pull.c:223
-msgid "accept refs that update .git/shallow"
-msgstr "accepter les références qui mettent à jour .git/shallow"
+#: builtin/branch.c:502
+msgid "cannot copy the current branch while not on any."
+msgstr "impossible de copier la branche actuelle, il n'y en a pas."
 
-#: builtin/fetch.c:170 builtin/pull.c:225
-msgid "refmap"
-msgstr "correspondance de référence"
+#: builtin/branch.c:504
+msgid "cannot rename the current branch while not on any."
+msgstr "impossible de renommer la branche actuelle, il n'y en a pas."
 
-#: builtin/fetch.c:171 builtin/pull.c:226
-msgid "specify fetch refmap"
-msgstr "spécifier une correspondance de référence pour la récupération"
+#: builtin/branch.c:515
+#, c-format
+msgid "Invalid branch name: '%s'"
+msgstr "Nom de branche invalide : '%s'"
 
-#: builtin/fetch.c:172 builtin/ls-remote.c:77 builtin/push.c:582
-#: builtin/send-pack.c:172
-msgid "server-specific"
-msgstr "spécifique au serveur"
+#: builtin/branch.c:542
+msgid "Branch rename failed"
+msgstr "Échec de renommage de la branche"
 
-#: builtin/fetch.c:172 builtin/ls-remote.c:77 builtin/push.c:582
-#: builtin/send-pack.c:173
-msgid "option to transmit"
-msgstr "option à transmettre"
+#: builtin/branch.c:544
+msgid "Branch copy failed"
+msgstr "Échec de copie de la branche"
 
-#: builtin/fetch.c:442
-msgid "Couldn't find remote ref HEAD"
-msgstr "impossible de trouver la référence HEAD distante"
+#: builtin/branch.c:548
+#, c-format
+msgid "Created a copy of a misnamed branch '%s'"
+msgstr "Création d'une copie d'une branche mal nommée '%s'"
 
-#: builtin/fetch.c:560
+#: builtin/branch.c:551
 #, c-format
-msgid "configuration fetch.output contains invalid value %s"
-msgstr ""
-"le paramètre de configuration fetch.output contient une valeur invalide %s"
+msgid "Renamed a misnamed branch '%s' away"
+msgstr "Renommage d'une branche mal nommée '%s'"
 
-#: builtin/fetch.c:653
+#: builtin/branch.c:557
 #, c-format
-msgid "object %s not found"
-msgstr "objet %s non trouvé"
+msgid "Branch renamed to %s, but HEAD is not updated!"
+msgstr "La branche a été renommée en %s, mais HEAD n'est pas mise à jour !"
 
-#: builtin/fetch.c:657
-msgid "[up to date]"
-msgstr "[à jour]"
+#: builtin/branch.c:566
+msgid "Branch is renamed, but update of config-file failed"
+msgstr ""
+"La branche est renommée, mais la mise à jour du fichier de configuration a "
+"échoué"
 
-#: builtin/fetch.c:670 builtin/fetch.c:750
-msgid "[rejected]"
-msgstr "[rejeté]"
-
-#: builtin/fetch.c:671
-msgid "can't fetch in current branch"
-msgstr "impossible de récupérer dans la branche actuelle"
+#: builtin/branch.c:568
+msgid "Branch is copied, but update of config-file failed"
+msgstr ""
+"La branche est copiée, mais la mise à jour du fichier de configuration a "
+"échoué"
 
-#: builtin/fetch.c:680
-msgid "[tag update]"
-msgstr "[mise à jour de l'étiquette]"
+#: builtin/branch.c:584
+#, c-format
+msgid ""
+"Please edit the description for the branch\n"
+"  %s\n"
+"Lines starting with '%c' will be stripped.\n"
+msgstr ""
+"Veuillez éditer la description de la branche\n"
+"  %s\n"
+"Les lignes commençant par '%c' seront ignorées.\n"
 
-#: builtin/fetch.c:681 builtin/fetch.c:714 builtin/fetch.c:730
-#: builtin/fetch.c:745
-msgid "unable to update local ref"
-msgstr "impossible de mettre à jour la référence locale"
+#: builtin/branch.c:618
+msgid "Generic options"
+msgstr "Options génériques"
 
-#: builtin/fetch.c:700
-msgid "[new tag]"
-msgstr "[nouvelle étiquette]"
+#: builtin/branch.c:620
+msgid "show hash and subject, give twice for upstream branch"
+msgstr "afficher le hachage et le sujet, doublé pour la branche amont"
 
-#: builtin/fetch.c:703
-msgid "[new branch]"
-msgstr "[nouvelle branche]"
+#: builtin/branch.c:621
+msgid "suppress informational messages"
+msgstr "supprimer les messages d'information"
 
-#: builtin/fetch.c:706
-msgid "[new ref]"
-msgstr "[nouvelle référence]"
+#: builtin/branch.c:622
+msgid "set up tracking mode (see git-pull(1))"
+msgstr "régler le mode de suivi (voir git-pull(1))"
 
-#: builtin/fetch.c:745
-msgid "forced update"
-msgstr "mise à jour forcée"
+#: builtin/branch.c:624
+msgid "do not use"
+msgstr "ne pas utiliser"
 
-#: builtin/fetch.c:750
-msgid "non-fast-forward"
-msgstr "pas en avance rapide"
+#: builtin/branch.c:626 builtin/rebase.c:505
+msgid "upstream"
+msgstr "amont"
 
-#: builtin/fetch.c:795
-#, c-format
-msgid "%s did not send all necessary objects\n"
-msgstr "%s n'a pas envoyé tous les objets nécessaires\n"
+#: builtin/branch.c:626
+msgid "change the upstream info"
+msgstr "modifier l'information amont"
 
-#: builtin/fetch.c:815
-#, c-format
-msgid "reject %s because shallow roots are not allowed to be updated"
-msgstr ""
-"%s rejeté parce que les racines superficielles ne sont pas mises à jour"
+#: builtin/branch.c:627
+msgid "unset the upstream info"
+msgstr "désactiver l'information amont"
 
-#: builtin/fetch.c:903 builtin/fetch.c:999
-#, c-format
-msgid "From %.*s\n"
-msgstr "Depuis %.*s\n"
+#: builtin/branch.c:628
+msgid "use colored output"
+msgstr "utiliser la coloration dans la sortie"
 
-#: builtin/fetch.c:914
-#, c-format
-msgid ""
-"some local refs could not be updated; try running\n"
-" 'git remote prune %s' to remove any old, conflicting branches"
-msgstr ""
-"des références locales n'ont pas pu être mises à jour ; essayez de lancer\n"
-" 'git remote prune %s' pour supprimer des branches anciennes en conflit"
+#: builtin/branch.c:629
+msgid "act on remote-tracking branches"
+msgstr "agir sur les branches de suivi distantes"
 
-#: builtin/fetch.c:969
-#, c-format
-msgid "   (%s will become dangling)"
-msgstr "   (%s sera en suspens)"
+#: builtin/branch.c:631 builtin/branch.c:633
+msgid "print only branches that contain the commit"
+msgstr "afficher seulement les branches qui contiennent le commit"
 
-#: builtin/fetch.c:970
-#, c-format
-msgid "   (%s has become dangling)"
-msgstr "   (%s est devenu en suspens)"
+#: builtin/branch.c:632 builtin/branch.c:634
+msgid "print only branches that don't contain the commit"
+msgstr "afficher seulement les branches qui ne contiennent pas le commit"
 
-#: builtin/fetch.c:1002
-msgid "[deleted]"
-msgstr "[supprimé]"
+#: builtin/branch.c:637
+msgid "Specific git-branch actions:"
+msgstr "Actions spécifiques à git-branch :"
 
-#: builtin/fetch.c:1003 builtin/remote.c:1033
-msgid "(none)"
-msgstr "(aucun(e))"
+#: builtin/branch.c:638
+msgid "list both remote-tracking and local branches"
+msgstr "afficher à la fois les branches de suivi et les branches locales"
 
-#: builtin/fetch.c:1026
-#, c-format
-msgid "Refusing to fetch into current branch %s of non-bare repository"
-msgstr "Refus de récupérer dans la branche courant %s d'un dépôt non nu"
+#: builtin/branch.c:640
+msgid "delete fully merged branch"
+msgstr "supprimer une branche totalement fusionnée"
 
-#: builtin/fetch.c:1045
-#, c-format
-msgid "Option \"%s\" value \"%s\" is not valid for %s"
-msgstr "La valeur \"%2$s\" de l'option \"%1$s\" est invalide pour %3$s"
+#: builtin/branch.c:641
+msgid "delete branch (even if not merged)"
+msgstr "supprimer une branche (même non fusionnée)"
 
-#: builtin/fetch.c:1048
-#, c-format
-msgid "Option \"%s\" is ignored for %s\n"
-msgstr "L'option \"%s\" est ignorée pour %s\n"
+#: builtin/branch.c:642
+msgid "move/rename a branch and its reflog"
+msgstr "déplacer/renommer une branche et son reflog"
 
-#: builtin/fetch.c:1287
-#, c-format
-msgid "Fetching %s\n"
-msgstr "Récupération de %s\n"
+#: builtin/branch.c:643
+msgid "move/rename a branch, even if target exists"
+msgstr "déplacer/renommer une branche, même si la cible existe"
 
-#: builtin/fetch.c:1289 builtin/remote.c:98
-#, c-format
-msgid "Could not fetch %s"
-msgstr "Impossible de récupérer %s"
+#: builtin/branch.c:644
+msgid "copy a branch and its reflog"
+msgstr "copier une branche et son reflog"
 
-#: builtin/fetch.c:1335 builtin/fetch.c:1503
-msgid ""
-"--filter can only be used with the remote configured in core.partialClone"
-msgstr ""
-"--filter ne peut être utilisé qu'avec le dépôt distant configuré dans core."
-"partialClone"
+#: builtin/branch.c:645
+msgid "copy a branch, even if target exists"
+msgstr "copier une branche, même si la cible existe"
 
-#: builtin/fetch.c:1358
-msgid ""
-"No remote repository specified.  Please, specify either a URL or a\n"
-"remote name from which new revisions should be fetched."
-msgstr ""
-"Aucun dépôt distant spécifié. Veuillez spécifier une URL ou un nom\n"
-"distant depuis lesquels les nouvelles révisions devraient être récupérées."
+#: builtin/branch.c:646
+msgid "list branch names"
+msgstr "afficher les noms des branches"
 
-#: builtin/fetch.c:1395
-msgid "You need to specify a tag name."
-msgstr "Vous devez spécifier un nom d'étiquette."
+#: builtin/branch.c:647
+msgid "show current branch name"
+msgstr "afficher le nom de la branche courante"
 
-#: builtin/fetch.c:1444
-msgid "Negative depth in --deepen is not supported"
-msgstr "Une profondeur négative dans --deepen n'est pas supportée"
+#: builtin/branch.c:648
+msgid "create the branch's reflog"
+msgstr "créer le reflog de la branche"
 
-#: builtin/fetch.c:1446
-msgid "--deepen and --depth are mutually exclusive"
-msgstr "--deepen et --depth sont mutuellement exclusifs"
+#: builtin/branch.c:650
+msgid "edit the description for the branch"
+msgstr "éditer la description de la branche"
 
-#: builtin/fetch.c:1451
-msgid "--depth and --unshallow cannot be used together"
-msgstr "--depth et --unshallow ne peuvent pas être utilisés ensemble"
+#: builtin/branch.c:651
+msgid "force creation, move/rename, deletion"
+msgstr "forcer la création, le déplacement/renommage, ou la suppression"
 
-#: builtin/fetch.c:1453
-msgid "--unshallow on a complete repository does not make sense"
-msgstr "--unshallow sur un dépôt complet n'a pas de sens"
+#: builtin/branch.c:652
+msgid "print only branches that are merged"
+msgstr "afficher seulement les branches qui sont fusionnées"
 
-#: builtin/fetch.c:1469
-msgid "fetch --all does not take a repository argument"
-msgstr "fetch --all n'accepte pas d'argument de dépôt"
+#: builtin/branch.c:653
+msgid "print only branches that are not merged"
+msgstr "afficher seulement les branches qui ne sont pas fusionnées"
 
-#: builtin/fetch.c:1471
-msgid "fetch --all does not make sense with refspecs"
-msgstr "fetch --all n'a pas de sens avec des spécifications de référence"
+#: builtin/branch.c:654
+msgid "list branches in columns"
+msgstr "afficher les branches en colonnes"
 
-#: builtin/fetch.c:1480
-#, c-format
-msgid "No such remote or remote group: %s"
-msgstr "distant ou groupe distant inexistant : %s"
+#: builtin/branch.c:657 builtin/for-each-ref.c:42 builtin/notes.c:415
+#: builtin/notes.c:418 builtin/notes.c:581 builtin/notes.c:584
+#: builtin/tag.c:433
+msgid "object"
+msgstr "objet"
 
-#: builtin/fetch.c:1487
-msgid "Fetching a group and specifying refspecs does not make sense"
-msgstr ""
-"La récupération d'un groupe et les spécifications de référence n'ont pas de "
-"sens"
+#: builtin/branch.c:658
+msgid "print only branches of the object"
+msgstr "afficher seulement les branches de l'objet"
 
-#: builtin/fmt-merge-msg.c:15
-msgid ""
-"git fmt-merge-msg [-m <message>] [--log[=<n>] | --no-log] [--file <file>]"
-msgstr ""
-"git fmt-merge-msg [-m <message>] [--log[=<n>] | --no-log] [--file <fichier>]"
+#: builtin/branch.c:660 builtin/for-each-ref.c:48 builtin/tag.c:440
+msgid "sorting and filtering are case insensitive"
+msgstr "le tri et le filtrage sont non-sensibles à la casse"
 
-#: builtin/fmt-merge-msg.c:666
-msgid "populate log with at most <n> entries from shortlog"
-msgstr "peupler le journal avec au plus <n> éléments depuis le journal court"
+#: builtin/branch.c:661 builtin/for-each-ref.c:38 builtin/tag.c:438
+#: builtin/verify-tag.c:38
+msgid "format to use for the output"
+msgstr "format à utiliser pour la sortie"
 
-#: builtin/fmt-merge-msg.c:669
-msgid "alias for --log (deprecated)"
-msgstr "alias pour --log (obsolète)"
+#: builtin/branch.c:684 builtin/clone.c:784
+msgid "HEAD not found below refs/heads!"
+msgstr "HEAD non trouvée sous refs/heads !"
 
-#: builtin/fmt-merge-msg.c:672
-msgid "text"
-msgstr "texte"
+#: builtin/branch.c:708
+msgid "--column and --verbose are incompatible"
+msgstr "--column et --verbose sont incompatibles"
 
-#: builtin/fmt-merge-msg.c:673
-msgid "use <text> as start of message"
-msgstr "utiliser <texte> comme début de message"
+#: builtin/branch.c:723 builtin/branch.c:777 builtin/branch.c:786
+msgid "branch name required"
+msgstr "le nom de branche est requis"
 
-#: builtin/fmt-merge-msg.c:674
-msgid "file to read from"
-msgstr "fichier d'où lire"
+#: builtin/branch.c:753
+msgid "Cannot give description to detached HEAD"
+msgstr "Impossible de décrire une HEAD détachée"
 
-#: builtin/for-each-ref.c:10
-msgid "git for-each-ref [<options>] [<pattern>]"
-msgstr "git for-each-ref [<options>] [<motif>]"
+#: builtin/branch.c:758
+msgid "cannot edit description of more than one branch"
+msgstr "impossible d'éditer la description de plus d'une branche"
 
-#: builtin/for-each-ref.c:11
-msgid "git for-each-ref [--points-at <object>]"
-msgstr "git for-each-ref [--point-at <objet>]"
+#: builtin/branch.c:765
+#, c-format
+msgid "No commit on branch '%s' yet."
+msgstr "Aucun commit sur la branche '%s'."
 
-#: builtin/for-each-ref.c:12
-msgid "git for-each-ref [(--merged | --no-merged) [<commit>]]"
-msgstr "git for-each-ref [(--merged | --no-merged) [<commit>]]"
+#: builtin/branch.c:768
+#, c-format
+msgid "No branch named '%s'."
+msgstr "Aucune branche nommée '%s'."
 
-#: builtin/for-each-ref.c:13
-msgid "git for-each-ref [--contains [<commit>]] [--no-contains [<commit>]]"
-msgstr "git for-each-ref [--contains [<commit>]] [--no-contains [<commit>]]"
+#: builtin/branch.c:783
+msgid "too many branches for a copy operation"
+msgstr "trop de branches pour une opération de copie"
 
-#: builtin/for-each-ref.c:28
-msgid "quote placeholders suitably for shells"
-msgstr "échapper les champs réservés pour les interpréteurs de commandes"
+#: builtin/branch.c:792
+msgid "too many arguments for a rename operation"
+msgstr "trop d'arguments pour une opération de renommage"
 
-#: builtin/for-each-ref.c:30
-msgid "quote placeholders suitably for perl"
-msgstr "échapper les champs réservés pour perl"
+#: builtin/branch.c:797
+msgid "too many arguments to set new upstream"
+msgstr "trop d'arguments pour spécifier une branche amont"
 
-#: builtin/for-each-ref.c:32
-msgid "quote placeholders suitably for python"
-msgstr "échapper les champs réservés pour python"
+#: builtin/branch.c:801
+#, c-format
+msgid ""
+"could not set upstream of HEAD to %s when it does not point to any branch."
+msgstr ""
+"impossible de spécifier une branche amont de HEAD par %s qui ne pointe sur "
+"aucune branche."
 
-#: builtin/for-each-ref.c:34
-msgid "quote placeholders suitably for Tcl"
-msgstr "échapper les champs réservés pour compatibilité avec Tcl"
+#: builtin/branch.c:804 builtin/branch.c:827
+#, c-format
+msgid "no such branch '%s'"
+msgstr "pas de branche '%s'"
 
-#: builtin/for-each-ref.c:37
-msgid "show only <n> matched refs"
-msgstr "n'afficher que <n> références correspondant"
+#: builtin/branch.c:808
+#, c-format
+msgid "branch '%s' does not exist"
+msgstr "la branche '%s' n'existe pas"
 
-#: builtin/for-each-ref.c:39 builtin/tag.c:421
-msgid "respect format colors"
-msgstr "respecter les couleurs de formatage"
+#: builtin/branch.c:821
+msgid "too many arguments to unset upstream"
+msgstr "trop d'arguments pour désactiver un amont"
 
-#: builtin/for-each-ref.c:43
-msgid "print only refs which points at the given object"
-msgstr "afficher seulement les références pointant sur l'objet"
+#: builtin/branch.c:825
+msgid "could not unset upstream of HEAD when it does not point to any branch."
+msgstr ""
+"impossible de désactiver une branche amont de HEAD quand elle ne pointe sur "
+"aucune branche."
 
-#: builtin/for-each-ref.c:45
-msgid "print only refs that are merged"
-msgstr "afficher seulement les références qui sont fusionnées"
-
-#: builtin/for-each-ref.c:46
-msgid "print only refs that are not merged"
-msgstr "afficher seulement les références qui ne sont pas fusionnées"
-
-#: builtin/for-each-ref.c:47
-msgid "print only refs which contain the commit"
-msgstr "afficher seulement les références qui contiennent le commit"
+#: builtin/branch.c:831
+#, c-format
+msgid "Branch '%s' has no upstream information"
+msgstr "La branche '%s' n'a aucune information de branche amont"
 
-#: builtin/for-each-ref.c:48
-msgid "print only refs which don't contain the commit"
-msgstr "afficher seulement les références qui ne contiennent pas le commit"
+#: builtin/branch.c:841
+msgid ""
+"The -a, and -r, options to 'git branch' do not take a branch name.\n"
+"Did you mean to use: -a|-r --list <pattern>?"
+msgstr ""
+"Les options -a et -r de 'git branch' n'ont pas de sens avec un nom de "
+"branche.\n"
+"Vouliez-vous plutôt dire -a|-r --list <motif> ?"
 
-#: builtin/fsck.c:569
-msgid "Checking object directories"
-msgstr "Vérification des répertoires d'objet"
+#: builtin/branch.c:845
+msgid ""
+"the '--set-upstream' option is no longer supported. Please use '--track' or "
+"'--set-upstream-to' instead."
+msgstr ""
+"l'option '--set-upstream' est obsolète. Utilisez '--track' ou '--set-"
+"upstream-to' à la place."
 
-#: builtin/fsck.c:661
-msgid "git fsck [<options>] [<object>...]"
-msgstr "git fsck [<options>] [<objet>...]"
+#: builtin/bundle.c:15 builtin/bundle.c:23
+msgid "git bundle create [<options>] <file> <git-rev-list args>"
+msgstr "git bundle create [<options>] <fichier> <args git-rev-list>"
+
+#: builtin/bundle.c:16 builtin/bundle.c:28
+msgid "git bundle verify [<options>] <file>"
+msgstr "git bundle verify [<options>] <fichier>"
+
+#: builtin/bundle.c:17 builtin/bundle.c:33
+msgid "git bundle list-heads <file> [<refname>...]"
+msgstr "git bundle list-heads <fichier> [<nom-de-ref>...]"
+
+#: builtin/bundle.c:18 builtin/bundle.c:38
+msgid "git bundle unbundle <file> [<refname>...]"
+msgstr "git bundle unbundle <fichier> [<nom-de-ref>...]"
 
-#: builtin/fsck.c:667
-msgid "show unreachable objects"
-msgstr "afficher les objets inaccessibles"
+#: builtin/bundle.c:66 builtin/pack-objects.c:3228
+msgid "do not show progress meter"
+msgstr "ne pas afficher la barre de progression"
 
-#: builtin/fsck.c:668
-msgid "show dangling objects"
-msgstr "afficher les objets en suspens"
+#: builtin/bundle.c:68 builtin/pack-objects.c:3230
+msgid "show progress meter"
+msgstr "afficher la barre de progression"
 
-#: builtin/fsck.c:669
-msgid "report tags"
-msgstr "afficher les étiquettes"
+#: builtin/bundle.c:70 builtin/pack-objects.c:3232
+msgid "show progress meter during object writing phase"
+msgstr "afficher la barre de progression durant la phase d'écrite des objets"
 
-#: builtin/fsck.c:670
-msgid "report root nodes"
-msgstr "signaler les nœuds racines"
+#: builtin/bundle.c:73 builtin/pack-objects.c:3235
+msgid "similar to --all-progress when progress meter is shown"
+msgstr "similaire à --all-progress quand la barre de progression est affichée"
 
-#: builtin/fsck.c:671
-msgid "make index objects head nodes"
-msgstr "considérer les objets de l'index comme nœuds tête"
+#: builtin/bundle.c:93
+msgid "Need a repository to create a bundle."
+msgstr "La création d'un colis requiert un dépôt."
 
-# translated from man page
-#: builtin/fsck.c:672
-msgid "make reflogs head nodes (default)"
-msgstr "considérer les reflogs comme nœuds tête (par défaut)"
+#: builtin/bundle.c:104
+msgid "do not show bundle details"
+msgstr "ne pas afficher les détails du colis"
 
-#: builtin/fsck.c:673
-msgid "also consider packs and alternate objects"
-msgstr "inspecter aussi les objets pack et alternatifs"
+#: builtin/bundle.c:119
+#, c-format
+msgid "%s is okay\n"
+msgstr "%s est correct\n"
 
-#: builtin/fsck.c:674
-msgid "check only connectivity"
-msgstr "ne vérifier que la connectivité"
+#: builtin/bundle.c:160
+msgid "Need a repository to unbundle."
+msgstr "Le dépaquetage d'un colis requiert un dépôt."
 
-#: builtin/fsck.c:675
-msgid "enable more strict checking"
-msgstr "activer une vérification plus strict"
+#: builtin/bundle.c:168 builtin/remote.c:1609
+msgid "be verbose; must be placed before a subcommand"
+msgstr "être verbeux : doit être placé avant une sous-commande"
 
-#: builtin/fsck.c:677
-msgid "write dangling objects in .git/lost-found"
-msgstr "écrire les objets en suspens dans .git/lost-found"
+#: builtin/bundle.c:190 builtin/remote.c:1640
+#, c-format
+msgid "Unknown subcommand: %s"
+msgstr "Sous-commande inconnue : %s"
 
-#: builtin/fsck.c:678 builtin/prune.c:109
-msgid "show progress"
-msgstr "afficher la progression"
+#: builtin/cat-file.c:595
+msgid ""
+"git cat-file (-t [--allow-unknown-type] | -s [--allow-unknown-type] | -e | -"
+"p | <type> | --textconv | --filters) [--path=<path>] <object>"
+msgstr ""
+"git cat-file (-t [--allow-unknow-type] | -s [--allow-unknow-type] | -e | -p "
+"| <type> | --textconv | --filters) [--path=<chemin>] <objet>"
 
-#: builtin/fsck.c:679
-msgid "show verbose names for reachable objects"
-msgstr "afficher les noms étendus pour les objets inaccessibles"
+#: builtin/cat-file.c:596
+msgid ""
+"git cat-file (--batch | --batch-check) [--follow-symlinks] [--textconv | --"
+"filters]"
+msgstr ""
+"git cat-file (--batch | --batch-check) [--follow-symlinks] [--textconv | --"
+"filters]"
 
-#: builtin/fsck.c:745
-msgid "Checking objects"
-msgstr "Vérification des objets"
+#: builtin/cat-file.c:617
+msgid "only one batch option may be specified"
+msgstr "une seule option de traitement ne peut être spécifiée à la fois"
 
-#: builtin/gc.c:33
-msgid "git gc [<options>]"
-msgstr "git gc [<options>]"
+#: builtin/cat-file.c:635
+msgid "<type> can be one of: blob, tree, commit, tag"
+msgstr "<type> peut être : blob, tree, commit ou tag"
 
-#: builtin/gc.c:88
-#, c-format
-msgid "Failed to fstat %s: %s"
-msgstr "Échec du stat de %s : %s"
+#: builtin/cat-file.c:636
+msgid "show object type"
+msgstr "afficher le type de l'objet"
 
-#: builtin/gc.c:452
-#, c-format
-msgid "Can't stat %s"
-msgstr "impossible de faire un stat de %s"
+#: builtin/cat-file.c:637
+msgid "show object size"
+msgstr "afficher la taille de l'objet"
 
-#: builtin/gc.c:461
-#, c-format
-msgid ""
-"The last gc run reported the following. Please correct the root cause\n"
-"and remove %s.\n"
-"Automatic cleanup will not be performed until the file is removed.\n"
-"\n"
-"%s"
-msgstr ""
-"Le dernier lancement de gc a rapporté l'erreur suivante. Veuillez corriger\n"
-"la cause et supprimer %s.\n"
-"Le nettoyage automatique n'aura pas lieu jusqu'à ce que le fichier soit "
-"supprimé.\n"
-"\n"
-"%s"
+#: builtin/cat-file.c:639
+msgid "exit with zero when there's no error"
+msgstr "sortir avec un code d'erreur nul quand il n'y a aucune erreur"
 
-#: builtin/gc.c:502
-msgid "prune unreferenced objects"
-msgstr "éliminer les objets non référencés"
+#: builtin/cat-file.c:640
+msgid "pretty-print object's content"
+msgstr "afficher avec mise en forme le contenu de l'objet"
 
-#: builtin/gc.c:504
-msgid "be more thorough (increased runtime)"
-msgstr "être plus consciencieux (durée de traitement allongée)"
+#: builtin/cat-file.c:642
+msgid "for blob objects, run textconv on object's content"
+msgstr "pour les objets blob, lancer textconv sur le contenu de l'objet"
 
-#: builtin/gc.c:505
-msgid "enable auto-gc mode"
-msgstr "activer le mode auto-gc"
+#: builtin/cat-file.c:644
+msgid "for blob objects, run filters on object's content"
+msgstr "pour les objets blob, lancer les filtres sur le contenu de l'objet"
 
-#: builtin/gc.c:508
-msgid "force running gc even if there may be another gc running"
-msgstr ""
-"forcer le lancement du ramasse-miettes même si un autre ramasse-miettes "
-"tourne déjà"
+#: builtin/cat-file.c:645 git-submodule.sh:992
+msgid "blob"
+msgstr "blob"
 
-#: builtin/gc.c:511
-msgid "repack all other packs except the largest pack"
-msgstr "recompacter tous les autres paquets excepté le plus gros paquet"
+#: builtin/cat-file.c:646
+msgid "use a specific path for --textconv/--filters"
+msgstr "utiliser un chemin spécifique pour --textconv/--filters"
 
-#: builtin/gc.c:528
-#, c-format
-msgid "failed to parse gc.logexpiry value %s"
-msgstr "impossible d'analyser gc.logexpiry %s"
+#: builtin/cat-file.c:648
+msgid "allow -s and -t to work with broken/corrupt objects"
+msgstr "autoriser -s et -t à travailler sur des objets cassés/corrompus"
 
-#: builtin/gc.c:539
-#, c-format
-msgid "failed to parse prune expiry value %s"
-msgstr "impossible d'analyser la valeur d'expiration d'élagage %s"
+#: builtin/cat-file.c:649
+msgid "buffer --batch output"
+msgstr "bufferiser la sortie de --batch"
 
-#: builtin/gc.c:559
-#, c-format
-msgid "Auto packing the repository in background for optimum performance.\n"
+#: builtin/cat-file.c:651
+msgid "show info and content of objects fed from the standard input"
 msgstr ""
-"Compression automatique du dépôt en tâche de fond pour optimiser les "
-"performances.\n"
-
-#: builtin/gc.c:561
-#, c-format
-msgid "Auto packing the repository for optimum performance.\n"
-msgstr "Compression du dépôt pour optimiser les performances.\n"
+"afficher l'information et le contenu des objets passés en entrée standard"
 
-#: builtin/gc.c:562
-#, c-format
-msgid "See \"git help gc\" for manual housekeeping.\n"
-msgstr "Voir \"git help gc\" pour toute information sur le nettoyage manuel.\n"
+#: builtin/cat-file.c:655
+msgid "show info about objects fed from the standard input"
+msgstr "afficher l'information des objets passés en entrée standard"
 
-#: builtin/gc.c:598
-#, c-format
-msgid ""
-"gc is already running on machine '%s' pid %<PRIuMAX> (use --force if not)"
+#: builtin/cat-file.c:659
+msgid "follow in-tree symlinks (used with --batch or --batch-check)"
 msgstr ""
-"un ramasse-miettes est déjà en cours sur la machine '%s' pid %<PRIuMAX> "
-"(utilisez --force si ce n'est pas le cas)"
+"suivre les liens symbolique internes à la copie de travail (utilisé avec --"
+"batch ou --batch-check)"
 
-#: builtin/gc.c:645
-msgid ""
-"There are too many unreachable loose objects; run 'git prune' to remove them."
-msgstr ""
-"Il y a trop d'objets seuls inaccessibles ; lancez 'git prune' pour les "
-"supprimer."
+#: builtin/cat-file.c:661
+msgid "show all objects with --batch or --batch-check"
+msgstr "montrer tous les objets avec --batch ou --batch-check"
 
-#: builtin/grep.c:28
-msgid "git grep [<options>] [-e] <pattern> [<rev>...] [[--] <path>...]"
-msgstr "git grep [<options>] [-e] <motif> [<révision>...] [[--] <chemin>...]"
+#: builtin/cat-file.c:663
+msgid "do not order --batch-all-objects output"
+msgstr "ne pas ordonner la sortie de --batch-all-objects"
 
-#: builtin/grep.c:226
-#, c-format
-msgid "grep: failed to create thread: %s"
-msgstr "grep : échec de création du fil: %s"
+#: builtin/check-attr.c:13
+msgid "git check-attr [-a | --all | <attr>...] [--] <pathname>..."
+msgstr "git check-attr [-a | --all | <attr>...] [--] <chemin>..."
 
-#: builtin/grep.c:284
-#, c-format
-msgid "invalid number of threads specified (%d) for %s"
-msgstr "nombre de fils spécifié invalide (%d) pour %s"
+#: builtin/check-attr.c:14
+msgid "git check-attr --stdin [-z] [-a | --all | <attr>...]"
+msgstr "git check-attr --stdin [-z] [-a | --all | <attr>...]"
 
-#. TRANSLATORS: %s is the configuration
-#. variable for tweaking threads, currently
-#. grep.threads
-#.
-#: builtin/grep.c:293 builtin/index-pack.c:1535 builtin/index-pack.c:1727
-#, c-format
-msgid "no threads support, ignoring %s"
-msgstr "pas de support des fils, ignore %s"
+#: builtin/check-attr.c:21
+msgid "report all attributes set on file"
+msgstr "afficher tous les attributs associés au fichier"
 
-#: builtin/grep.c:461 builtin/grep.c:582 builtin/grep.c:623
-#, c-format
-msgid "unable to read tree (%s)"
-msgstr "impossible de lire l'arbre (%s)"
+#: builtin/check-attr.c:22
+msgid "use .gitattributes only from the index"
+msgstr "utiliser .gitattributes seulement depuis l'index"
 
-#: builtin/grep.c:638
-#, c-format
-msgid "unable to grep from object of type %s"
-msgstr "impossible de faire un grep sur un objet de type %s"
+#: builtin/check-attr.c:23 builtin/check-ignore.c:25 builtin/hash-object.c:102
+msgid "read file names from stdin"
+msgstr "lire les noms de fichier depuis l'entrée standard"
 
-#: builtin/grep.c:703
-#, c-format
-msgid "switch `%c' expects a numerical value"
-msgstr "l'option '%c' attend un valeur numérique"
+#: builtin/check-attr.c:25 builtin/check-ignore.c:27
+msgid "terminate input and output records by a NUL character"
+msgstr ""
+"terminer les enregistrements en entrée et en sortie par un caractère NUL"
 
-#: builtin/grep.c:790
-msgid "search in index instead of in the work tree"
-msgstr "rechercher dans l'index plutôt que dans la copie de travail"
+#: builtin/check-ignore.c:21 builtin/checkout.c:1435 builtin/gc.c:537
+#: builtin/worktree.c:506
+msgid "suppress progress reporting"
+msgstr "supprimer l'état d'avancement"
 
-#: builtin/grep.c:792
-msgid "find in contents not managed by git"
-msgstr "rechercher dans les contenus non gérés par git"
+#: builtin/check-ignore.c:29
+msgid "show non-matching input paths"
+msgstr "afficher les chemins en entrée qui ne correspondent pas"
 
-#: builtin/grep.c:794
-msgid "search in both tracked and untracked files"
-msgstr "rechercher dans les fichiers suivis et non-suivis"
+#: builtin/check-ignore.c:31
+msgid "ignore index when checking"
+msgstr "ignorer l'index pendant la vérification"
 
-#: builtin/grep.c:796
-msgid "ignore files specified via '.gitignore'"
-msgstr "ignorer les fichiers spécifiés via '.gitignore'"
+#: builtin/check-ignore.c:160
+msgid "cannot specify pathnames with --stdin"
+msgstr "impossible de spécifier les chemins avec --stdin"
 
-#: builtin/grep.c:798
-msgid "recursively search in each submodule"
-msgstr "rechercher récursivement dans chaque sous-module"
+#: builtin/check-ignore.c:163
+msgid "-z only makes sense with --stdin"
+msgstr "-z n'a de sens qu'avec l'option --stdin"
 
-#: builtin/grep.c:801
-msgid "show non-matching lines"
-msgstr "afficher les lignes qui ne correspondent pas"
+#: builtin/check-ignore.c:165
+msgid "no path specified"
+msgstr "aucun chemin spécifié"
 
-#: builtin/grep.c:803
-msgid "case insensitive matching"
-msgstr "correspondance insensible à la casse"
+#: builtin/check-ignore.c:169
+msgid "--quiet is only valid with a single pathname"
+msgstr "--quiet n'est valide qu'avec un seul chemin"
 
-#: builtin/grep.c:805
-msgid "match patterns only at word boundaries"
-msgstr "rechercher les motifs aux séparateurs de mots"
+#: builtin/check-ignore.c:171
+msgid "cannot have both --quiet and --verbose"
+msgstr "impossible d'avoir --quiet et --verbose"
 
-#: builtin/grep.c:807
-msgid "process binary files as text"
-msgstr "traiter les fichiers binaires comme texte"
+#: builtin/check-ignore.c:174
+msgid "--non-matching is only valid with --verbose"
+msgstr "--non-matching n'est valide qu'avec --verbose"
 
-#: builtin/grep.c:809
-msgid "don't match patterns in binary files"
-msgstr "ne pas chercher les motifs dans les fichiers binaires"
-
-#: builtin/grep.c:812
-msgid "process binary files with textconv filters"
-msgstr "traiter les fichiers binaires avec les filtres textconv"
-
-#: builtin/grep.c:814
-msgid "descend at most <depth> levels"
-msgstr "descendre au plus de <profondeur> dans l'arborescence"
-
-#: builtin/grep.c:818
-msgid "use extended POSIX regular expressions"
-msgstr "utiliser des expressions régulières étendues POSIX"
-
-#: builtin/grep.c:821
-msgid "use basic POSIX regular expressions (default)"
-msgstr "utiliser des expressions régulières basiques POSIX (par défaut)"
-
-#: builtin/grep.c:824
-msgid "interpret patterns as fixed strings"
-msgstr "interpréter les motifs comme de chaînes fixes"
-
-#: builtin/grep.c:827
-msgid "use Perl-compatible regular expressions"
-msgstr "utiliser des expressions régulières compatibles avec Perl"
-
-#: builtin/grep.c:830
-msgid "show line numbers"
-msgstr "afficher les numéros de ligne"
-
-#: builtin/grep.c:831
-msgid "don't show filenames"
-msgstr "ne pas pas afficher les noms de fichier"
-
-#: builtin/grep.c:832
-msgid "show filenames"
-msgstr "afficher les noms de fichier"
+#: builtin/check-mailmap.c:9
+msgid "git check-mailmap [<options>] <contact>..."
+msgstr "git check-mailmap [<options>] <contact>..."
 
-#: builtin/grep.c:834
-msgid "show filenames relative to top directory"
-msgstr "afficher les noms de fichiers relativement au répertoire de base"
+#: builtin/check-mailmap.c:14
+msgid "also read contacts from stdin"
+msgstr "lire aussi les contacts depuis l'entrée standard"
 
-#: builtin/grep.c:836
-msgid "show only filenames instead of matching lines"
-msgstr "n'afficher que les noms de fichiers au lieu des lignes correspondant"
+#: builtin/check-mailmap.c:25
+#, c-format
+msgid "unable to parse contact: %s"
+msgstr "impossible d'analyser le contact : %s"
 
-#: builtin/grep.c:838
-msgid "synonym for --files-with-matches"
-msgstr "synonyme pour --files-with-matches"
+#: builtin/check-mailmap.c:48
+msgid "no contacts specified"
+msgstr "aucun contact spécifié"
 
-#: builtin/grep.c:841
-msgid "show only the names of files without match"
-msgstr "n'afficher que les noms des fichiers sans correspondance"
+#: builtin/checkout-index.c:131
+msgid "git checkout-index [<options>] [--] [<file>...]"
+msgstr "git checkout-index [<options>] [--] [<fichier>...]"
 
-#: builtin/grep.c:843
-msgid "print NUL after filenames"
-msgstr "imprimer une caractère NUL après le noms de fichier"
+#: builtin/checkout-index.c:148
+msgid "stage should be between 1 and 3 or all"
+msgstr "stage doit valoir entre 1 et 3, ou all"
 
-#: builtin/grep.c:846
-msgid "show the number of matches instead of matching lines"
-msgstr "afficher le nombre de correspondances au lieu des lignes correspondant"
+#: builtin/checkout-index.c:164
+msgid "check out all files in the index"
+msgstr "extraire tous les fichiers présents dans l'index"
 
-#: builtin/grep.c:847
-msgid "highlight matches"
-msgstr "mettre en évidence les correspondances"
+#: builtin/checkout-index.c:165
+msgid "force overwrite of existing files"
+msgstr "forcer l'écrasement des fichiers existants"
 
-#: builtin/grep.c:849
-msgid "print empty line between matches from different files"
+#: builtin/checkout-index.c:167
+msgid "no warning for existing files and files not in index"
 msgstr ""
-"imprimer une ligne vide entre les correspondances de fichiers différents"
+"pas d'avertissement pour les fichiers existants et les fichiers absents de "
+"l'index"
 
-#: builtin/grep.c:851
-msgid "show filename only once above matches from same file"
-msgstr ""
-"afficher le nom de fichier une fois au dessus des correspondances du même "
-"fichier"
+#: builtin/checkout-index.c:169
+msgid "don't checkout new files"
+msgstr "ne pas extraire les nouveaux fichiers"
 
-#: builtin/grep.c:854
-msgid "show <n> context lines before and after matches"
-msgstr "afficher <n> lignes de contexte avant et après les correspondances"
+#: builtin/checkout-index.c:171
+msgid "update stat information in the index file"
+msgstr "mettre à jour l'information de stat dans le fichier d'index"
 
-#: builtin/grep.c:857
-msgid "show <n> context lines before matches"
-msgstr "afficher <n> lignes de contexte avant les correspondances"
+#: builtin/checkout-index.c:175
+msgid "read list of paths from the standard input"
+msgstr "lire la liste des chemins depuis l'entrée standard"
 
-#: builtin/grep.c:859
-msgid "show <n> context lines after matches"
-msgstr "afficher <n> lignes de contexte après les correspondances"
+#: builtin/checkout-index.c:177
+msgid "write the content to temporary files"
+msgstr "écrire le contenu dans des fichiers temporaires"
 
-#: builtin/grep.c:861
-msgid "use <n> worker threads"
-msgstr "utiliser <n> fils de travail"
+#: builtin/checkout-index.c:178 builtin/column.c:31
+#: builtin/submodule--helper.c:1385 builtin/submodule--helper.c:1388
+#: builtin/submodule--helper.c:1396 builtin/submodule--helper.c:1882
+#: builtin/worktree.c:679
+msgid "string"
+msgstr "chaîne"
 
-#: builtin/grep.c:862
-msgid "shortcut for -C NUM"
-msgstr "raccourci pour -C NUM"
+#: builtin/checkout-index.c:179
+msgid "when creating files, prepend <string>"
+msgstr "lors de la création de fichiers, préfixer par <chaîne>"
 
-#: builtin/grep.c:865
-msgid "show a line with the function name before matches"
-msgstr ""
-"afficher une ligne avec le nom de la fonction avant les correspondances"
+#: builtin/checkout-index.c:181
+msgid "copy out the files from named stage"
+msgstr "copier les fichiers depuis l'index nommé"
 
-#: builtin/grep.c:867
-msgid "show the surrounding function"
-msgstr "afficher la fonction contenante"
+#: builtin/checkout.c:31
+msgid "git checkout [<options>] <branch>"
+msgstr "git checkout [<options>] <branche>"
 
-#: builtin/grep.c:870
-msgid "read patterns from file"
-msgstr "lire les motifs depuis fichier"
+#: builtin/checkout.c:32
+msgid "git checkout [<options>] [<branch>] -- <file>..."
+msgstr "git checkout [<options>] [<branche>] -- <fichier>..."
 
-#: builtin/grep.c:872
-msgid "match <pattern>"
-msgstr "rechercher <motif>"
+#: builtin/checkout.c:37
+msgid "git switch [<options>] [<branch>]"
+msgstr "git switch [<options>] <branche>"
+
+#: builtin/checkout.c:42
+msgid "git restore [<options>] [--source=<branch>] <file>..."
+msgstr "git restore [<options>] [--source=<branche>] <fichier>..."
 
-#: builtin/grep.c:874
-msgid "combine patterns specified with -e"
-msgstr "combiner les motifs spécifiés par -e"
+#: builtin/checkout.c:175 builtin/checkout.c:214
+#, c-format
+msgid "path '%s' does not have our version"
+msgstr "le chemin '%s' n'a pas notre version"
 
-#: builtin/grep.c:886
-msgid "indicate hit with exit status without output"
-msgstr ""
-"indiquer des correspondances avec le code de sortie mais sans rien afficher"
+#: builtin/checkout.c:177 builtin/checkout.c:216
+#, c-format
+msgid "path '%s' does not have their version"
+msgstr "le chemin '%s' n'a pas leur version"
 
-#: builtin/grep.c:888
-msgid "show only matches from files that match all patterns"
-msgstr ""
-"n'afficher que les correspondances de fichiers qui correspondent à tous les "
-"motifs"
+#: builtin/checkout.c:193
+#, c-format
+msgid "path '%s' does not have all necessary versions"
+msgstr "le chemin '%s' n'a aucune des versions nécessaires"
 
-#: builtin/grep.c:890
-msgid "show parse tree for grep expression"
-msgstr "afficher l'arbre d'analyse pour le motif grep"
+#: builtin/checkout.c:243
+#, c-format
+msgid "path '%s' does not have necessary versions"
+msgstr "le chemin '%s' n'a pas les versions nécessaires"
 
-#: builtin/grep.c:894
-msgid "pager"
-msgstr "pagineur"
+#: builtin/checkout.c:261
+#, c-format
+msgid "path '%s': cannot merge"
+msgstr "chemin '%s' : impossible de fusionner"
 
-#: builtin/grep.c:894
-msgid "show matching files in the pager"
-msgstr "afficher les fichiers correspondant dans le pagineur"
+#: builtin/checkout.c:277
+#, c-format
+msgid "Unable to add merge result for '%s'"
+msgstr "Impossible d'ajouter le résultat de fusion pour '%s'"
 
-#: builtin/grep.c:898
-msgid "allow calling of grep(1) (ignored by this build)"
-msgstr "permettre l'appel de grep(1) (ignoré par ce build)"
+#: builtin/checkout.c:377
+#, c-format
+msgid "Recreated %d merge conflict"
+msgid_plural "Recreated %d merge conflicts"
+msgstr[0] "%d conflit du fusion recréé"
+msgstr[1] "%d conflits du fusion recréés"
 
-#: builtin/grep.c:962
-msgid "no pattern given."
-msgstr "aucun motif fourni."
+#: builtin/checkout.c:382
+#, c-format
+msgid "Updated %d path from %s"
+msgid_plural "Updated %d paths from %s"
+msgstr[0] "%d chemin mis à jour depuis %s"
+msgstr[1] "%d chemins mis à jour depuis %s"
 
-#: builtin/grep.c:994
-msgid "--no-index or --untracked cannot be used with revs"
-msgstr ""
-"--no-index ou --untracked ne peuvent pas être utilisés avec des révisions"
+#: builtin/checkout.c:389
+#, c-format
+msgid "Updated %d path from the index"
+msgid_plural "Updated %d paths from the index"
+msgstr[0] "%d chemin mis à jour depuis l'index"
+msgstr[1] "%d chemins mis à jour depuis l'index"
 
-#: builtin/grep.c:1001
+#: builtin/checkout.c:412 builtin/checkout.c:415 builtin/checkout.c:418
+#: builtin/checkout.c:422
 #, c-format
-msgid "unable to resolve revision: %s"
-msgstr "impossible de résoudre la révision : %s"
+msgid "'%s' cannot be used with updating paths"
+msgstr "'%s' ne peut pas être utilisé avec des mises à jour de chemins"
 
-#: builtin/grep.c:1036 builtin/index-pack.c:1531
+#: builtin/checkout.c:425 builtin/checkout.c:428
 #, c-format
-msgid "invalid number of threads specified (%d)"
-msgstr "nombre de fils spécifié invalide (%d)"
+msgid "'%s' cannot be used with %s"
+msgstr "'%s' ne peut pas être utilisé avec %s"
 
-#: builtin/grep.c:1041
-msgid "no threads support, ignoring --threads"
-msgstr "pas de support des fils, ignore --threads"
+#: builtin/checkout.c:432
+#, c-format
+msgid "Cannot update paths and switch to branch '%s' at the same time."
+msgstr ""
+"Impossible de mettre à jour les chemins et basculer sur la branche '%s' en "
+"même temps."
 
-#: builtin/grep.c:1065
-msgid "--open-files-in-pager only works on the worktree"
-msgstr "--open-files-in-pager ne fonctionne que sur la copie de travail"
+#: builtin/checkout.c:436
+#, c-format
+msgid "neither '%s' or '%s' is specified"
+msgstr "ni '%s', ni '%s' spécifié"
 
-#: builtin/grep.c:1088
-msgid "option not supported with --recurse-submodules."
-msgstr "option non supportée avec --recurse-submodules."
+#: builtin/checkout.c:440
+#, c-format
+msgid "'%s' must be used when '%s' is not specified"
+msgstr "'%s' ne peut pas être utilisé quand '%s' n'est pas spécifié"
 
-#: builtin/grep.c:1094
-msgid "--cached or --untracked cannot be used with --no-index."
-msgstr "--cached ou --untracked ne peuvent pas être utilisés avec --no-index."
+#: builtin/checkout.c:445 builtin/checkout.c:450
+#, c-format
+msgid "'%s' or '%s' cannot be used with %s"
+msgstr "'%s' ou '%s' ne peut pas être utilisé avec %s"
 
-#: builtin/grep.c:1100
-msgid "--[no-]exclude-standard cannot be used for tracked contents."
-msgstr ""
-"--[no-]exclude-standard ne peut pas être utilisé avec du contenu suivi."
+#: builtin/checkout.c:509 builtin/checkout.c:516
+#, c-format
+msgid "path '%s' is unmerged"
+msgstr "le chemin '%s' n'est pas fusionné"
 
-#: builtin/grep.c:1108
-msgid "both --cached and trees are given."
-msgstr "--cached et des arbres sont fournis en même temps."
+#: builtin/checkout.c:682 builtin/sparse-checkout.c:82
+msgid "you need to resolve your current index first"
+msgstr "vous devez d'abord résoudre votre index courant"
 
-#: builtin/hash-object.c:83
+#: builtin/checkout.c:732
+#, c-format
 msgid ""
-"git hash-object [-t <type>] [-w] [--path=<file> | --no-filters] [--stdin] "
-"[--] <file>..."
+"cannot continue with staged changes in the following files:\n"
+"%s"
 msgstr ""
-"git hash-object [-t <type>] [-w] [--path=<fichier> | --no-filters] [--stdin] "
-"[--] <fichier>..."
-
-#: builtin/hash-object.c:84
-msgid "git hash-object  --stdin-paths"
-msgstr "git hash-object  --stdin-paths"
-
-#: builtin/hash-object.c:96
-msgid "type"
-msgstr "type"
-
-#: builtin/hash-object.c:96
-msgid "object type"
-msgstr "type d'objet"
+"impossible de continuer avec des modifications indexées dans les fichiers "
+"suivants :\n"
+"%s"
 
-#: builtin/hash-object.c:97
-msgid "write the object into the object database"
-msgstr "écrire l'objet dans la base de donnée d'objets"
+#: builtin/checkout.c:835
+#, c-format
+msgid "Can not do reflog for '%s': %s\n"
+msgstr "Impossible de faire un reflog pour '%s' : %s\n"
 
-#: builtin/hash-object.c:99
-msgid "read the object from stdin"
-msgstr "lire l'objet depuis l'entrée standard"
+#: builtin/checkout.c:877
+msgid "HEAD is now at"
+msgstr "HEAD est maintenant sur"
 
-#: builtin/hash-object.c:101
-msgid "store file as is without filters"
-msgstr "stocker le fichier tel quel sans filtrage"
+#: builtin/checkout.c:881 builtin/clone.c:716
+msgid "unable to update HEAD"
+msgstr "impossible de mettre à jour HEAD"
 
-#: builtin/hash-object.c:102
-msgid ""
-"just hash any random garbage to create corrupt objects for debugging Git"
-msgstr ""
-"juste hasher n'importe quel contenu pour créer des objets corrompus pour "
-"debugger Git"
+#: builtin/checkout.c:885
+#, c-format
+msgid "Reset branch '%s'\n"
+msgstr "Remise à zéro de la branche '%s'\n"
 
-#: builtin/hash-object.c:103
-msgid "process file as it were from this path"
-msgstr "traiter le fichier comme s'il venait de ce chemin"
+#: builtin/checkout.c:888
+#, c-format
+msgid "Already on '%s'\n"
+msgstr "Déjà sur '%s'\n"
 
-#: builtin/help.c:45
-msgid "print all available commands"
-msgstr "afficher toutes les commandes disponibles"
+#: builtin/checkout.c:892
+#, c-format
+msgid "Switched to and reset branch '%s'\n"
+msgstr "Basculement et remise à zéro de la branche '%s'\n"
 
-#: builtin/help.c:46
-msgid "exclude guides"
-msgstr "exclure les guides"
+#: builtin/checkout.c:894 builtin/checkout.c:1291
+#, c-format
+msgid "Switched to a new branch '%s'\n"
+msgstr "Basculement sur la nouvelle branche '%s'\n"
 
-#: builtin/help.c:47
-msgid "print list of useful guides"
-msgstr "afficher une liste de guides utiles"
+#: builtin/checkout.c:896
+#, c-format
+msgid "Switched to branch '%s'\n"
+msgstr "Basculement sur la branche '%s'\n"
 
-#: builtin/help.c:48
-msgid "show man page"
-msgstr "afficher la page de manuel"
+#: builtin/checkout.c:947
+#, c-format
+msgid " ... and %d more.\n"
+msgstr " ... et %d en plus.\n"
 
-#: builtin/help.c:49
-msgid "show manual in web browser"
-msgstr "afficher le manuel dans un navigateur web"
-
-#: builtin/help.c:51
-msgid "show info page"
-msgstr "afficher la page info"
-
-#: builtin/help.c:53
-msgid "print command description"
-msgstr "afficher la description de la commande"
-
-#: builtin/help.c:58
-msgid "git help [--all] [--guides] [--man | --web | --info] [<command>]"
-msgstr "git help [--all] [--guides] [--man | --web | --info] [<commande>]"
+#: builtin/checkout.c:953
+#, c-format
+msgid ""
+"Warning: you are leaving %d commit behind, not connected to\n"
+"any of your branches:\n"
+"\n"
+"%s\n"
+msgid_plural ""
+"Warning: you are leaving %d commits behind, not connected to\n"
+"any of your branches:\n"
+"\n"
+"%s\n"
+msgstr[0] ""
+"Attention : vous abandonnez %d commit, non connecté à\n"
+"une branche :\n"
+"\n"
+"%s\n"
+msgstr[1] ""
+"Attention : vous abandonnez %d commits, non connectés à\n"
+"une branche :\n"
+"\n"
+"%s\n"
 
-#: builtin/help.c:70
+#: builtin/checkout.c:972
 #, c-format
-msgid "unrecognized help format '%s'"
-msgstr "format d'aide non reconnu '%s'"
+msgid ""
+"If you want to keep it by creating a new branch, this may be a good time\n"
+"to do so with:\n"
+"\n"
+" git branch <new-branch-name> %s\n"
+"\n"
+msgid_plural ""
+"If you want to keep them by creating a new branch, this may be a good time\n"
+"to do so with:\n"
+"\n"
+" git branch <new-branch-name> %s\n"
+"\n"
+msgstr[0] ""
+"Si vous souhaitez le garder en créant une nouvelle branche, c'est le bon "
+"moment\n"
+"pour le faire avec :\n"
+"\n"
+"git branch <nouvelle-branche> %s\n"
+"\n"
+msgstr[1] ""
+"Si vous souhaitez les garder en créant une nouvelle branche, c'est le bon "
+"moment\n"
+"pour le faire avec :\n"
+"\n"
+"git branch <nouvelle-branche> %s\n"
+"\n"
 
-#: builtin/help.c:97
-msgid "Failed to start emacsclient."
-msgstr "échec de démarrage d'emacsclient."
+#: builtin/checkout.c:1007
+msgid "internal error in revision walk"
+msgstr "erreur interne lors du parcours des révisions"
 
-#: builtin/help.c:110
-msgid "Failed to parse emacsclient version."
-msgstr "échec d'analyse de la version d'emacsclient."
+#: builtin/checkout.c:1011
+msgid "Previous HEAD position was"
+msgstr "La position précédente de HEAD était sur"
 
-#: builtin/help.c:118
-#, c-format
-msgid "emacsclient version '%d' too old (< 22)."
-msgstr "la version d'emacsclient '%d' est trop ancienne (<22)."
+#: builtin/checkout.c:1051 builtin/checkout.c:1286
+msgid "You are on a branch yet to be born"
+msgstr "Vous êtes sur une branche qui doit encore naître"
 
-#: builtin/help.c:136 builtin/help.c:158 builtin/help.c:168 builtin/help.c:176
-#, c-format
-msgid "failed to exec '%s'"
-msgstr "échec de l'exécution de '%s'"
+#: builtin/checkout.c:1178
+msgid "only one reference expected"
+msgstr "une seule référence attendue"
 
-#: builtin/help.c:214
+#: builtin/checkout.c:1195
 #, c-format
-msgid ""
-"'%s': path for unsupported man viewer.\n"
-"Please consider using 'man.<tool>.cmd' instead."
-msgstr ""
-"'%s' : chemin pour l'utilitaire de visualisation de manuel non supporté.\n"
-"Veuillez utiliser plutôt 'man.<outil>.cmd'."
+msgid "only one reference expected, %d given."
+msgstr "une seule référence attendue, %d fournies."
 
-#: builtin/help.c:226
+#: builtin/checkout.c:1232
 #, c-format
 msgid ""
-"'%s': cmd for supported man viewer.\n"
-"Please consider using 'man.<tool>.path' instead."
+"'%s' could be both a local file and a tracking branch.\n"
+"Please use -- (and optionally --no-guess) to disambiguate"
 msgstr ""
-"'%s' : chemin pour l'utilitaire de visualisation de manuel supporté.\n"
-"Veuillez utiliser plutôt 'man.<outil>.cmd'."
+"'%s' pourrait être un fichier local ou un branche de suivi.\n"
+"Veuillez utiliser -- (et --no-guess en facultatif) pour les distinguer"
 
-#: builtin/help.c:343
+#: builtin/checkout.c:1245 builtin/worktree.c:290 builtin/worktree.c:455
 #, c-format
-msgid "'%s': unknown man viewer."
-msgstr "'%s' : visualiseur de manuel inconnu."
-
-#: builtin/help.c:360
-msgid "no man viewer handled the request"
-msgstr "aucun visualiseur de manuel n'a pris en charge la demande"
-
-#: builtin/help.c:368
-msgid "no info viewer handled the request"
-msgstr "aucun visualiseur de 'info' n'a pris en charge la demande"
+msgid "invalid reference: %s"
+msgstr "référence invalide : %s"
 
-#: builtin/help.c:415
+#: builtin/checkout.c:1258 builtin/checkout.c:1622
 #, c-format
-msgid "'%s' is aliased to '%s'"
-msgstr "'%s' est un alias de '%s'"
+msgid "reference is not a tree: %s"
+msgstr "la référence n'est pas un arbre : %s"
 
-#: builtin/help.c:442 builtin/help.c:459
+#: builtin/checkout.c:1305
 #, c-format
-msgid "usage: %s%s"
-msgstr "usage : %s%s"
+msgid "a branch is expected, got tag '%s'"
+msgstr "branche attendue, mais étiquette '%s' reçue"
 
-#: builtin/index-pack.c:158
+#: builtin/checkout.c:1307
 #, c-format
-msgid "unable to open %s"
-msgstr "impossible d'ouvrir %s"
+msgid "a branch is expected, got remote branch '%s'"
+msgstr "une branche est attendue, mais une branche distante '%s' a été reçue"
 
-#: builtin/index-pack.c:208
+#: builtin/checkout.c:1308 builtin/checkout.c:1316
 #, c-format
-msgid "object type mismatch at %s"
-msgstr "type d'objet non correspondant à %s"
+msgid "a branch is expected, got '%s'"
+msgstr "une branche est attendue, mais '%s' a été reçue"
 
-#: builtin/index-pack.c:228
+#: builtin/checkout.c:1311
 #, c-format
-msgid "did not receive expected object %s"
-msgstr "objet attendu non reçu %s"
+msgid "a branch is expected, got commit '%s'"
+msgstr "une branche est attendue, mais un commit '%s' a été reçu"
 
-#: builtin/index-pack.c:231
-#, c-format
-msgid "object %s: expected type %s, found %s"
-msgstr "objet %s : type attendu %s, reçu %s"
+#: builtin/checkout.c:1327
+msgid ""
+"cannot switch branch while merging\n"
+"Consider \"git merge --quit\" or \"git worktree add\"."
+msgstr ""
+"impossible de basculer de branche pendant une fusion\n"
+"Envisagez \"git merge --quit\" ou \"git worktree add\"."
 
-#: builtin/index-pack.c:273
-#, c-format
-msgid "cannot fill %d byte"
-msgid_plural "cannot fill %d bytes"
-msgstr[0] "impossible de remplir %d octet"
-msgstr[1] "impossible de remplir %d octets"
+#: builtin/checkout.c:1331
+msgid ""
+"cannot switch branch in the middle of an am session\n"
+"Consider \"git am --quit\" or \"git worktree add\"."
+msgstr ""
+"impossible de basculer de branche pendant une session am\n"
+"Envisagez \"git am --quit\" ou \"git worktree add\"."
 
-#: builtin/index-pack.c:283
-msgid "early EOF"
-msgstr "fin de fichier prématurée"
+#: builtin/checkout.c:1335
+msgid ""
+"cannot switch branch while rebasing\n"
+"Consider \"git rebase --quit\" or \"git worktree add\"."
+msgstr ""
+"impossible de basculer de branche pendant un rebasage\n"
+"Envisagez \"git rebase --quit\" ou \"git worktree add\"."
 
-#: builtin/index-pack.c:284
-msgid "read error on input"
-msgstr "erreur de lecture sur l'entrée"
+#: builtin/checkout.c:1339
+msgid ""
+"cannot switch branch while cherry-picking\n"
+"Consider \"git cherry-pick --quit\" or \"git worktree add\"."
+msgstr ""
+"impossible de basculer de branche pendant un picorage\n"
+"Envisagez \"git cherry-pick --quit\" ou \"git worktree add\"."
 
-#: builtin/index-pack.c:296
-msgid "used more bytes than were available"
-msgstr "plus d'octets utilisés que disponibles"
+#: builtin/checkout.c:1343
+msgid ""
+"cannot switch branch while reverting\n"
+"Consider \"git revert --quit\" or \"git worktree add\"."
+msgstr ""
+"impossible de basculer de branche pendant un retour\n"
+"Envisagez \"git revert --quit\" ou \"git worktree add\"."
 
-#: builtin/index-pack.c:303
-msgid "pack too large for current definition of off_t"
-msgstr "le paquet est trop grand pour la définition actuelle de off_t"
+#: builtin/checkout.c:1347
+msgid "you are switching branch while bisecting"
+msgstr "Vous basculez de branche en cours de bissection"
 
-#: builtin/index-pack.c:306 builtin/unpack-objects.c:93
-msgid "pack exceeds maximum allowed size"
-msgstr "le paquet dépasse la taille maximale permise"
+#: builtin/checkout.c:1354
+msgid "paths cannot be used with switching branches"
+msgstr "impossible d'utiliser des chemins avec un basculement de branches"
 
-#: builtin/index-pack.c:321
+#: builtin/checkout.c:1357 builtin/checkout.c:1361 builtin/checkout.c:1365
 #, c-format
-msgid "unable to create '%s'"
-msgstr "impossible de créer '%s'"
+msgid "'%s' cannot be used with switching branches"
+msgstr "'%s' ne peut pas être utilisé avec un basculement de branches"
 
-#: builtin/index-pack.c:327
+#: builtin/checkout.c:1369 builtin/checkout.c:1372 builtin/checkout.c:1375
+#: builtin/checkout.c:1380 builtin/checkout.c:1385
 #, c-format
-msgid "cannot open packfile '%s'"
-msgstr "impossible d'ouvrir le fichier paquet '%s'"
-
-#: builtin/index-pack.c:341
-msgid "pack signature mismatch"
-msgstr "la signature du paquet ne correspond pas"
+msgid "'%s' cannot be used with '%s'"
+msgstr "'%s' ne peut pas être utilisé avec '%s'"
 
-#: builtin/index-pack.c:343
+#: builtin/checkout.c:1382
 #, c-format
-msgid "pack version %<PRIu32> unsupported"
-msgstr "la version de paquet %<PRIu32> non supportée"
+msgid "'%s' cannot take <start-point>"
+msgstr "'%s' n'accepte pas <point-de-départ>"
 
-#: builtin/index-pack.c:361
+#: builtin/checkout.c:1390
 #, c-format
-msgid "pack has bad object at offset %<PRIuMAX>: %s"
-msgstr "le paquet a un mauvais objet à l'offset %<PRIuMAX> : %s"
+msgid "Cannot switch branch to a non-commit '%s'"
+msgstr "Impossible de basculer de branche vers '%s' qui n'est pas un commit"
 
-#: builtin/index-pack.c:482
-#, c-format
-msgid "inflate returned %d"
-msgstr "la décompression (inflate) a retourné %d"
+#: builtin/checkout.c:1397
+msgid "missing branch or commit argument"
+msgstr "argument de branche ou de commit manquant"
+
+#: builtin/checkout.c:1439 builtin/clone.c:91 builtin/commit-graph.c:52
+#: builtin/commit-graph.c:113 builtin/fetch.c:167 builtin/merge.c:285
+#: builtin/multi-pack-index.c:27 builtin/pull.c:138 builtin/push.c:563
+#: builtin/send-pack.c:174
+msgid "force progress reporting"
+msgstr "forcer l'affichage de l'état d'avancement"
 
-#: builtin/index-pack.c:531
-msgid "offset value overflow for delta base object"
-msgstr "dépassement de la valeur d'offset pour l'objet delta de base"
+#: builtin/checkout.c:1440
+msgid "perform a 3-way merge with the new branch"
+msgstr "effectuer une fusion à 3 points avec la nouvelle branche"
 
-#: builtin/index-pack.c:539
-msgid "delta base offset is out of bound"
-msgstr "l'objet delta de base est hors limite"
+#: builtin/checkout.c:1441 builtin/log.c:1690 parse-options.h:322
+msgid "style"
+msgstr "style"
 
-#: builtin/index-pack.c:547
-#, c-format
-msgid "unknown object type %d"
-msgstr "type d'objet inconnu %d"
+#: builtin/checkout.c:1442
+msgid "conflict style (merge or diff3)"
+msgstr "style de conflit (merge (fusion) ou diff3)"
 
-#: builtin/index-pack.c:578
-msgid "cannot pread pack file"
-msgstr "impossible de lire (pread) le fichier paquet"
+#: builtin/checkout.c:1454 builtin/worktree.c:503
+msgid "detach HEAD at named commit"
+msgstr "détacher la HEAD au commit nommé"
 
-#: builtin/index-pack.c:580
-#, c-format
-msgid "premature end of pack file, %<PRIuMAX> byte missing"
-msgid_plural "premature end of pack file, %<PRIuMAX> bytes missing"
-msgstr[0] "fin prématurée du fichier paquet, %<PRIuMAX> octet lu"
-msgstr[1] "fin prématurée du fichier paquet, %<PRIuMAX> octets lus"
+#: builtin/checkout.c:1455
+msgid "set upstream info for new branch"
+msgstr "paramétrer les coordonnées de branche amont pour une nouvelle branche"
 
-#: builtin/index-pack.c:606
-msgid "serious inflate inconsistency"
-msgstr "grave incohérence dans la décompression (inflate)"
+#: builtin/checkout.c:1457
+msgid "force checkout (throw away local modifications)"
+msgstr "forcer l'extraction (laisser tomber les modifications locales)"
 
-#: builtin/index-pack.c:751 builtin/index-pack.c:757 builtin/index-pack.c:780
-#: builtin/index-pack.c:819 builtin/index-pack.c:828
-#, c-format
-msgid "SHA1 COLLISION FOUND WITH %s !"
-msgstr "COLLISION SHA1 TROUVÉE AVEC %s !"
+#: builtin/checkout.c:1459
+msgid "new-branch"
+msgstr "nouvelle branche"
 
-#: builtin/index-pack.c:754 builtin/pack-objects.c:198
-#: builtin/pack-objects.c:292
-#, c-format
-msgid "unable to read %s"
-msgstr "impossible de lire %s"
+#: builtin/checkout.c:1459
+msgid "new unparented branch"
+msgstr "nouvelle branche sans parent"
 
-#: builtin/index-pack.c:817
-#, c-format
-msgid "cannot read existing object info %s"
-msgstr "impossible de lire l'information existante de l'objet %s"
+#: builtin/checkout.c:1461 builtin/merge.c:288
+msgid "update ignored files (default)"
+msgstr "mettre à jour les fichiers ignorés (par défaut)"
 
-#: builtin/index-pack.c:825
-#, c-format
-msgid "cannot read existing object %s"
-msgstr "impossible de lire l'objet existant %s"
+#: builtin/checkout.c:1464
+msgid "do not check if another worktree is holding the given ref"
+msgstr ""
+"ne pas vérifier si une autre copie de travail contient le référence fournie"
 
-#: builtin/index-pack.c:839
-#, c-format
-msgid "invalid blob object %s"
-msgstr "objet blob invalide %s"
+#: builtin/checkout.c:1477
+msgid "checkout our version for unmerged files"
+msgstr "extraire notre version pour les fichiers non fusionnés"
 
-#: builtin/index-pack.c:842 builtin/index-pack.c:860
-msgid "fsck error in packed object"
-msgstr "erreur de fsck dans l'objet empaqueté"
+#: builtin/checkout.c:1480
+msgid "checkout their version for unmerged files"
+msgstr "extraire leur version pour les fichiers non fusionnés"
 
-#: builtin/index-pack.c:857
-#, c-format
-msgid "invalid %s"
-msgstr "%s invalide"
+#: builtin/checkout.c:1484
+msgid "do not limit pathspecs to sparse entries only"
+msgstr "ne pas limiter les spécificateurs de chemins aux seuls éléments creux"
 
-#: builtin/index-pack.c:862
-#, c-format
-msgid "Not all child objects of %s are reachable"
-msgstr "Tous les objets enfants de %s ne sont pas accessibles"
+#: builtin/checkout.c:1537
+msgid "-b, -B and --orphan are mutually exclusive"
+msgstr "-b, -B et --orphan sont mutuellement exclusifs"
 
-#: builtin/index-pack.c:934 builtin/index-pack.c:965
-msgid "failed to apply delta"
-msgstr "échec d'application du delta"
+#: builtin/checkout.c:1540
+msgid "-p and --overlay are mutually exclusive"
+msgstr "-p et --overlay sont mutuellement exclusifs"
 
-#: builtin/index-pack.c:1135
-msgid "Receiving objects"
-msgstr "Réception d'objets"
+#: builtin/checkout.c:1577
+msgid "--track needs a branch name"
+msgstr "--track requiert un nom de branche"
 
-#: builtin/index-pack.c:1135
-msgid "Indexing objects"
-msgstr "Indexation d'objets"
+#: builtin/checkout.c:1582
+msgid "missing branch name; try -b"
+msgstr "nom de branche manquant ; essayez -b"
 
-#: builtin/index-pack.c:1169
-msgid "pack is corrupted (SHA1 mismatch)"
-msgstr "le paquet est corrompu (SHA1 ne correspond pas)"
+#: builtin/checkout.c:1615
+#, c-format
+msgid "could not resolve %s"
+msgstr "impossible de résoudre %s"
 
-#: builtin/index-pack.c:1174
-msgid "cannot fstat packfile"
-msgstr "impossible d'obtenir le statut (fstat) du fichier paquet"
+#: builtin/checkout.c:1631
+msgid "invalid path specification"
+msgstr "spécification de chemin invalide"
 
-#: builtin/index-pack.c:1177
-msgid "pack has junk at the end"
-msgstr "le paquet est invalide à la fin"
+#: builtin/checkout.c:1638
+#, c-format
+msgid "'%s' is not a commit and a branch '%s' cannot be created from it"
+msgstr ""
+"'%s' n'est pas un commit et une branche '%s' ne peut pas en être créée depuis"
 
-#: builtin/index-pack.c:1189
-msgid "confusion beyond insanity in parse_pack_objects()"
-msgstr "confusion extrême dans parse_pack_objects()"
-
-#: builtin/index-pack.c:1212
-msgid "Resolving deltas"
-msgstr "Résolution des deltas"
-
-#: builtin/index-pack.c:1223
+#: builtin/checkout.c:1642
 #, c-format
-msgid "unable to create thread: %s"
-msgstr "impossible de créer le fil : %s"
-
-#: builtin/index-pack.c:1265
-msgid "confusion beyond insanity"
-msgstr "confusion extrême"
+msgid "git checkout: --detach does not take a path argument '%s'"
+msgstr "git checkout: --detach n'accepte pas un argument de chemin '%s'"
 
-#: builtin/index-pack.c:1271
-#, c-format
-msgid "completed with %d local object"
-msgid_plural "completed with %d local objects"
-msgstr[0] "complété avec %d objet local"
-msgstr[1] "complété avec %d objets locaux"
+#: builtin/checkout.c:1651
+msgid "--pathspec-from-file is incompatible with --detach"
+msgstr "--pathspec-from-file est incompatible avec --detach"
+
+#: builtin/checkout.c:1654 builtin/reset.c:324
+msgid "--pathspec-from-file is incompatible with --patch"
+msgstr "--pathspec-from-file est incompatible avec --patch"
 
-#: builtin/index-pack.c:1283
-#, c-format
-msgid "Unexpected tail checksum for %s (disk corruption?)"
+#: builtin/checkout.c:1665
+msgid ""
+"git checkout: --ours/--theirs, --force and --merge are incompatible when\n"
+"checking out of the index."
 msgstr ""
-"Somme de contrôle de fin inattendue pour %s (corruption sur le disque ?)"
-
-#: builtin/index-pack.c:1287
-#, c-format
-msgid "pack has %d unresolved delta"
-msgid_plural "pack has %d unresolved deltas"
-msgstr[0] "le paquet a %d delta non résolu"
-msgstr[1] "le paquet a %d deltas non résolus"
-
-#: builtin/index-pack.c:1311
-#, c-format
-msgid "unable to deflate appended object (%d)"
-msgstr "impossible de compresser l'objet ajouté (%d)"
-
-#: builtin/index-pack.c:1388
-#, c-format
-msgid "local object %s is corrupt"
-msgstr "l'objet local %s est corrompu"
-
-#: builtin/index-pack.c:1402
-#, c-format
-msgid "packfile name '%s' does not end with '.pack'"
-msgstr "le nom de fichier paquet '%s' ne se termine pas par '.pack'"
+"git checkout: --ours/--theirs, --force et --merge sont incompatibles lors\n"
+"de l'extraction de l'index."
 
-#: builtin/index-pack.c:1427
-#, c-format
-msgid "cannot write %s file '%s'"
-msgstr "impossible d'écrire le fichier %s '%s'"
+#: builtin/checkout.c:1670
+msgid "you must specify path(s) to restore"
+msgstr "Vous devez spécifier un ou des chemins à restaurer"
 
-#: builtin/index-pack.c:1435
+#: builtin/checkout.c:1689
 #, c-format
-msgid "cannot close written %s file '%s'"
-msgstr "impossible de fermer le fichier %s écrit '%s'"
-
-#: builtin/index-pack.c:1459
-msgid "error while closing pack file"
-msgstr "erreur en fermeture du fichier paquet"
+msgid ""
+"'%s' matched more than one remote tracking branch.\n"
+"We found %d remotes with a reference that matched. So we fell back\n"
+"on trying to resolve the argument as a path, but failed there too!\n"
+"\n"
+"If you meant to check out a remote tracking branch on, e.g. 'origin',\n"
+"you can do so by fully qualifying the name with the --track option:\n"
+"\n"
+"    git checkout --track origin/<name>\n"
+"\n"
+"If you'd like to always have checkouts of an ambiguous <name> prefer\n"
+"one remote, e.g. the 'origin' remote, consider setting\n"
+"checkout.defaultRemote=origin in your config."
+msgstr ""
+"'%s' correspond à plusieurs branches de suivi distant. Nous avons\n"
+"trouvé %d distants avec une référence correspondante. Nous avons essayé\n"
+"de résoudre l'argument comme un chemin, sans plus de résultat !\n"
+"\n"
+"Si vous souhaitiez extraire une branche de suivi distant sur 'origin',\n"
+"par exemple, qualifiez-la complètement avec l'option --track :\n"
+"\n"
+"    git checkout --track origin/<nom>\n"
+"\n"
+"Si vous souhaitez privilégier un distant particulier lorsque <nom> est\n"
+"ambigu, vous pouvez positionner checkout.defaultRemote=origin dans\n"
+"votre config."
 
-#: builtin/index-pack.c:1473
-msgid "cannot store pack file"
-msgstr "impossible de stocker le fichier paquet"
+#: builtin/checkout.c:1714 builtin/checkout.c:1716 builtin/checkout.c:1765
+#: builtin/checkout.c:1767 builtin/clone.c:121 builtin/remote.c:169
+#: builtin/remote.c:171 builtin/worktree.c:499 builtin/worktree.c:501
+msgid "branch"
+msgstr "branche"
 
-#: builtin/index-pack.c:1481
-msgid "cannot store index file"
-msgstr "impossible de stocker le fichier d'index"
+#: builtin/checkout.c:1715
+msgid "create and checkout a new branch"
+msgstr "créer et extraire une nouvelle branche"
 
-#: builtin/index-pack.c:1525
-#, c-format
-msgid "bad pack.indexversion=%<PRIu32>"
-msgstr "mauvais pack.indexversion=%<PRIu32>"
+#: builtin/checkout.c:1717
+msgid "create/reset and checkout a branch"
+msgstr "créer/réinitialiser et extraire une branche"
 
-#: builtin/index-pack.c:1594
-#, c-format
-msgid "Cannot open existing pack file '%s'"
-msgstr "Impossible d'ouvrir le fichier paquet existant '%s'"
+#: builtin/checkout.c:1718
+msgid "create reflog for new branch"
+msgstr "créer un reflog pour une nouvelle branche"
 
-#: builtin/index-pack.c:1596
-#, c-format
-msgid "Cannot open existing pack idx file for '%s'"
-msgstr "Impossible d'ouvrir le fichier paquet d'index existant pour '%s'"
+#: builtin/checkout.c:1720
+msgid "second guess 'git checkout <no-such-branch>' (default)"
+msgstr ""
+"essayer d'interpréter 'git checkout <branche-inexistante>' (par défaut)"
 
-#: builtin/index-pack.c:1644
-#, c-format
-msgid "non delta: %d object"
-msgid_plural "non delta: %d objects"
-msgstr[0] "pas un delta : %d objet"
-msgstr[1] "pas un delta : %d objets"
+#: builtin/checkout.c:1721
+msgid "use overlay mode (default)"
+msgstr "utiliser le mode de superposition (défaut)"
 
-#: builtin/index-pack.c:1651
-#, c-format
-msgid "chain length = %d: %lu object"
-msgid_plural "chain length = %d: %lu objects"
-msgstr[0] "longueur chaînée = %d : %lu objet"
-msgstr[1] "longueur chaînée = %d : %lu objets"
+#: builtin/checkout.c:1766
+msgid "create and switch to a new branch"
+msgstr "créer et basculer sur une nouvelle branche"
 
-#: builtin/index-pack.c:1688
-msgid "Cannot come back to cwd"
-msgstr "Impossible de revenir au répertoire de travail courant"
+#: builtin/checkout.c:1768
+msgid "create/reset and switch to a branch"
+msgstr "créer/réinitialiser et basculer sur une branche"
 
-#: builtin/index-pack.c:1739 builtin/index-pack.c:1742
-#: builtin/index-pack.c:1758 builtin/index-pack.c:1762
-#, c-format
-msgid "bad %s"
-msgstr "mauvais %s"
+#: builtin/checkout.c:1770
+msgid "second guess 'git switch <no-such-branch>'"
+msgstr "interpréter 'git switch <branche-inexistante>'"
 
-#: builtin/index-pack.c:1778
-msgid "--fix-thin cannot be used without --stdin"
-msgstr "--fix-thin ne peut pas être utilisé sans --stdin"
+#: builtin/checkout.c:1772
+msgid "throw away local modifications"
+msgstr "laisser tomber les modifications locales"
 
-#: builtin/index-pack.c:1780
-msgid "--stdin requires a git repository"
-msgstr "--stdin requiert un dépôt git"
+#: builtin/checkout.c:1804
+msgid "which tree-ish to checkout from"
+msgstr "de quel <arbre-esque> faire l'extraction"
 
-#: builtin/index-pack.c:1786
-msgid "--verify with no packfile name given"
-msgstr "--verify sans nom de fichier paquet donné"
+#: builtin/checkout.c:1806
+msgid "restore the index"
+msgstr "restaurer l'index"
 
-#: builtin/index-pack.c:1836 builtin/unpack-objects.c:578
-msgid "fsck error in pack objects"
-msgstr "erreur de fsck dans les objets paquets"
+#: builtin/checkout.c:1808
+msgid "restore the working tree (default)"
+msgstr "restaurer l'arbre de travail (par défaut)"
 
-#: builtin/init-db.c:55
-#, c-format
-msgid "cannot stat '%s'"
-msgstr "impossible de faire un stat de '%s'"
+#: builtin/checkout.c:1810
+msgid "ignore unmerged entries"
+msgstr "ignorer les entrées non-fusionnées"
 
-#: builtin/init-db.c:61
-#, c-format
-msgid "cannot stat template '%s'"
-msgstr "impossible de faire un stat du modèle '%s'"
+#: builtin/checkout.c:1811
+msgid "use overlay mode"
+msgstr "utiliser le mode de superposition"
 
-#: builtin/init-db.c:66
-#, c-format
-msgid "cannot opendir '%s'"
-msgstr "impossible d'ouvrir (opendir) '%s'"
+#: builtin/clean.c:28
+msgid ""
+"git clean [-d] [-f] [-i] [-n] [-q] [-e <pattern>] [-x | -X] [--] <paths>..."
+msgstr ""
+"git clean [-d] [-f] [-i] [-n] [-q] [-e <motif>] [-x | -X] [--] <chemins>..."
 
-#: builtin/init-db.c:77
+#: builtin/clean.c:32
 #, c-format
-msgid "cannot readlink '%s'"
-msgstr "impossible de readlink '%s'"
+msgid "Removing %s\n"
+msgstr "Suppression de %s\n"
 
-#: builtin/init-db.c:79
+#: builtin/clean.c:33
 #, c-format
-msgid "cannot symlink '%s' '%s'"
-msgstr "impossible de créer un lien symbolique de '%s' '%s'"
+msgid "Would remove %s\n"
+msgstr "Supprimerait %s\n"
 
-#: builtin/init-db.c:85
+#: builtin/clean.c:34
 #, c-format
-msgid "cannot copy '%s' to '%s'"
-msgstr "impossible de copier '%s' vers '%s'"
+msgid "Skipping repository %s\n"
+msgstr "Ignore le dépôt %s\n"
 
-#: builtin/init-db.c:89
+#: builtin/clean.c:35
 #, c-format
-msgid "ignoring template %s"
-msgstr "modèle %s ignoré"
+msgid "Would skip repository %s\n"
+msgstr "Ignorerait le dépôt %s\n"
 
-#: builtin/init-db.c:120
+#: builtin/clean.c:36
 #, c-format
-msgid "templates not found in %s"
-msgstr "modèles non trouvés dans %s"
+msgid "failed to remove %s"
+msgstr "échec de la suppression de %s"
 
-#: builtin/init-db.c:135
+#: builtin/clean.c:37
 #, c-format
-msgid "not copying templates from '%s': %s"
-msgstr "pas de copie des modèles depuis '%s' : %s"
+msgid "could not lstat %s\n"
+msgstr "lstat de %s impossible\n"
 
-#: builtin/init-db.c:328
+#: builtin/clean.c:301 git-add--interactive.perl:595
 #, c-format
-msgid "unable to handle file type %d"
-msgstr "impossible de traiter le fichier de type %d"
+msgid ""
+"Prompt help:\n"
+"1          - select a numbered item\n"
+"foo        - select item based on unique prefix\n"
+"           - (empty) select nothing\n"
+msgstr ""
+"Aide en ligne :\n"
+"1           - sélectionner un élément numéroté\n"
+"foo         - sélectionner un élément par un préfixe unique\n"
+"            - (vide) ne rien sélectionner\n"
 
-#: builtin/init-db.c:331
+#: builtin/clean.c:305 git-add--interactive.perl:604
 #, c-format
-msgid "unable to move %s to %s"
-msgstr "impossible de déplacer %s vers %s"
+msgid ""
+"Prompt help:\n"
+"1          - select a single item\n"
+"3-5        - select a range of items\n"
+"2-3,6-9    - select multiple ranges\n"
+"foo        - select item based on unique prefix\n"
+"-...       - unselect specified items\n"
+"*          - choose all items\n"
+"           - (empty) finish selecting\n"
+msgstr ""
+"Aide en ligne :\n"
+"1          - sélectionner un seul élément\n"
+"3-5        - sélectionner une plage d'éléments\n"
+"2-3,6-9    - sélectionner plusieurs plages\n"
+"foo        - sélectionner un élément par un préfixe unique\n"
+"-...       - désélectionner les éléments spécifiés\n"
+"*          - choisir tous les éléments\n"
+"           - (vide) terminer la sélection\n"
 
-#: builtin/init-db.c:348 builtin/init-db.c:351
-#, c-format
-msgid "%s already exists"
-msgstr "%s existe déjà"
+#: builtin/clean.c:521 git-add--interactive.perl:570
+#: git-add--interactive.perl:575
+#, c-format, perl-format
+msgid "Huh (%s)?\n"
+msgstr "Hein (%s) ?\n"
 
-#: builtin/init-db.c:404
+#: builtin/clean.c:663
 #, c-format
-msgid "Reinitialized existing shared Git repository in %s%s\n"
-msgstr "Dépôt Git existant partagé réinitialisé dans %s%s\n"
+msgid "Input ignore patterns>> "
+msgstr "Entrez les motifs à ignorer>> "
 
-#: builtin/init-db.c:405
+#: builtin/clean.c:700
 #, c-format
-msgid "Reinitialized existing Git repository in %s%s\n"
-msgstr "Dépôt Git existant réinitialisé dans %s%s\n"
+msgid "WARNING: Cannot find items matched by: %s"
+msgstr "ATTENTION : Impossible de trouver les éléments correspondant à : %s"
 
-#: builtin/init-db.c:409
-#, c-format
-msgid "Initialized empty shared Git repository in %s%s\n"
-msgstr "Dépôt Git vide partagé initialisé dans %s%s\n"
+#: builtin/clean.c:721
+msgid "Select items to delete"
+msgstr "Sélectionner les éléments à supprimer"
 
-#: builtin/init-db.c:410
+#. TRANSLATORS: Make sure to keep [y/N] as is
+#: builtin/clean.c:762
 #, c-format
-msgid "Initialized empty Git repository in %s%s\n"
-msgstr "Dépôt Git vide initialisé dans %s%s\n"
+msgid "Remove %s [y/N]? "
+msgstr "Supprimer %s [y/N] ? "
 
-#: builtin/init-db.c:458
+#: builtin/clean.c:795
 msgid ""
-"git init [-q | --quiet] [--bare] [--template=<template-directory>] [--"
-"shared[=<permissions>]] [<directory>]"
+"clean               - start cleaning\n"
+"filter by pattern   - exclude items from deletion\n"
+"select by numbers   - select items to be deleted by numbers\n"
+"ask each            - confirm each deletion (like \"rm -i\")\n"
+"quit                - stop cleaning\n"
+"help                - this screen\n"
+"?                   - help for prompt selection"
 msgstr ""
-"git init [-q | --quiet] [--bare] [--template=<répertoire-modèle>] [--"
-"shared[=<permissions>]] [<répertoire>]"
+"clean               - démarrer le nettoyage\n"
+"filter by pattern   - exclure des éléments par motif\n"
+"select by numbers   - sélectionner les éléments à supprimer par numéros\n"
+"ask each            - confirmer chaque suppression (comme \"rm -i\")\n"
+"quit                - arrêter le nettoyage\n"
+"help                - cet écran\n"
+"?                   - aide pour la sélection en ligne"
 
-#: builtin/init-db.c:481
-msgid "permissions"
-msgstr "permissions"
+#: builtin/clean.c:831
+msgid "Would remove the following item:"
+msgid_plural "Would remove the following items:"
+msgstr[0] "Supprimerait l'élément suivant :"
+msgstr[1] "Supprimerait les éléments suivants :"
 
-#: builtin/init-db.c:482
-msgid "specify that the git repository is to be shared amongst several users"
-msgstr "spécifier que le dépôt git sera partagé entre plusieurs utilisateurs"
+#: builtin/clean.c:847
+msgid "No more files to clean, exiting."
+msgstr "Plus de fichier à nettoyer, sortie."
 
-#: builtin/init-db.c:525
-#, c-format
-msgid "cannot chdir to %s"
-msgstr "impossible de se déplacer vers le répertoire (chdir) %s"
+#: builtin/clean.c:909
+msgid "do not print names of files removed"
+msgstr "ne pas afficher les noms des fichiers supprimés"
 
-#: builtin/init-db.c:546
-#, c-format
-msgid ""
-"%s (or --work-tree=<directory>) not allowed without specifying %s (or --git-"
-"dir=<directory>)"
-msgstr ""
-"%s (ou --work-tree=<répertoire>) n'est pas autorisé sans spécifier %s (ou --"
-"git-dir=<répertoire>)"
+#: builtin/clean.c:911
+msgid "force"
+msgstr "forcer"
 
-#: builtin/init-db.c:574
-#, c-format
-msgid "Cannot access work tree '%s'"
-msgstr "Impossible d'accéder à l'arbre de travail '%s'"
+#: builtin/clean.c:912
+msgid "interactive cleaning"
+msgstr "nettoyage interactif"
 
-#: builtin/interpret-trailers.c:15
-msgid ""
-"git interpret-trailers [--in-place] [--trim-empty] [(--trailer "
-"<token>[(=|:)<value>])...] [<file>...]"
-msgstr ""
-"git interpret-trailers [--in-place] [--trim-empty] [(--trailer "
-"<symbole>[(=|:)<valeur>])...] [<fichier>...]"
+#: builtin/clean.c:914
+msgid "remove whole directories"
+msgstr "supprimer les répertoires entiers"
 
-#: builtin/interpret-trailers.c:92
-msgid "edit files in place"
-msgstr "éditer les fichiers sur place"
+#: builtin/clean.c:915 builtin/describe.c:548 builtin/describe.c:550
+#: builtin/grep.c:901 builtin/log.c:177 builtin/log.c:179
+#: builtin/ls-files.c:557 builtin/name-rev.c:464 builtin/name-rev.c:466
+#: builtin/show-ref.c:179
+msgid "pattern"
+msgstr "motif"
 
-#: builtin/interpret-trailers.c:93
-msgid "trim empty trailers"
-msgstr "éliminer les lignes de fin vides"
+#: builtin/clean.c:916
+msgid "add <pattern> to ignore rules"
+msgstr "ajouter <motif> aux règles ignore"
 
-#: builtin/interpret-trailers.c:96
-msgid "where to place the new trailer"
-msgstr "où placer les nouvelles lignes terminales"
+#: builtin/clean.c:917
+msgid "remove ignored files, too"
+msgstr "supprimer les fichiers ignorés, aussi"
 
-#: builtin/interpret-trailers.c:98
-msgid "action if trailer already exists"
-msgstr "action si les lignes terminales existent déjà"
+#: builtin/clean.c:919
+msgid "remove only ignored files"
+msgstr "supprimer seulement les fichiers ignorés"
 
-#: builtin/interpret-trailers.c:100
-msgid "action if trailer is missing"
-msgstr "action si les lignes terminales manquent"
+#: builtin/clean.c:937
+msgid "-x and -X cannot be used together"
+msgstr "-x et -X ne peuvent pas être utilisés ensemble"
 
-#: builtin/interpret-trailers.c:102
-msgid "output only the trailers"
-msgstr "éliminer les lignes terminales vides"
+#: builtin/clean.c:941
+msgid ""
+"clean.requireForce set to true and neither -i, -n, nor -f given; refusing to "
+"clean"
+msgstr ""
+"clean.requireForce positionné à true et ni -i, -n ou -f fourni ; refus de "
+"nettoyer"
 
-#: builtin/interpret-trailers.c:103
-msgid "do not apply config rules"
-msgstr "ne pas appliquer les règles de la configuration"
+#: builtin/clean.c:944
+msgid ""
+"clean.requireForce defaults to true and neither -i, -n, nor -f given; "
+"refusing to clean"
+msgstr ""
+"clean.requireForce à true par défaut et ni -i, -n ou -f fourni ; refus de "
+"nettoyer"
 
-#: builtin/interpret-trailers.c:104
-msgid "join whitespace-continued values"
-msgstr "joindre les valeurs continuées avec des caractères blancs"
+#: builtin/clone.c:45
+msgid "git clone [<options>] [--] <repo> [<dir>]"
+msgstr "git clone [<options>] [--] <dépôt> [<répertoire>]"
 
-#: builtin/interpret-trailers.c:105
-msgid "set parsing options"
-msgstr "paramètres d'analyse"
+#: builtin/clone.c:93
+msgid "don't create a checkout"
+msgstr "ne pas créer d'extraction"
 
-#: builtin/interpret-trailers.c:107
-msgid "trailer"
-msgstr "ligne de fin"
+#: builtin/clone.c:94 builtin/clone.c:96 builtin/init-db.c:489
+msgid "create a bare repository"
+msgstr "créer un dépôt nu"
 
-#: builtin/interpret-trailers.c:108
-msgid "trailer(s) to add"
-msgstr "ligne(s) de fin à ajouter"
+#: builtin/clone.c:98
+msgid "create a mirror repository (implies bare)"
+msgstr "créer un dépôt miroir (implique dépôt nu)"
 
-#: builtin/interpret-trailers.c:117
-msgid "--trailer with --only-input does not make sense"
-msgstr "--trailer n'a aucune signification avec --only-input"
+#: builtin/clone.c:100
+msgid "to clone from a local repository"
+msgstr "pour cloner depuis un dépôt local"
 
-#: builtin/interpret-trailers.c:127
-msgid "no input file given for in-place editing"
-msgstr "aucun fichier en entrée pour l'éditon sur place"
+#: builtin/clone.c:102
+msgid "don't use local hardlinks, always copy"
+msgstr "ne pas utiliser de liens durs locaux, toujours copier"
 
-#: builtin/log.c:48
-msgid "git log [<options>] [<revision-range>] [[--] <path>...]"
-msgstr "git log [<options>] [<plage de révisions>] [[--] <chemin>...]"
+#: builtin/clone.c:104
+msgid "setup as shared repository"
+msgstr "régler comme dépôt partagé"
 
-#: builtin/log.c:49
-msgid "git show [<options>] <object>..."
-msgstr "git show [<options>] <objet>..."
+#: builtin/clone.c:107
+msgid "pathspec"
+msgstr "spécificateur de chemin"
 
-#: builtin/log.c:93
-#, c-format
-msgid "invalid --decorate option: %s"
-msgstr "option --decorate invalide : %s"
+#: builtin/clone.c:107
+msgid "initialize submodules in the clone"
+msgstr "initialiser les sous-modules dans le clone"
 
-#: builtin/log.c:153
-msgid "suppress diff output"
-msgstr "supprimer la sortie des différences"
+#: builtin/clone.c:110
+msgid "number of submodules cloned in parallel"
+msgstr "nombre de sous-modules clonés en parallèle"
 
-#: builtin/log.c:154
-msgid "show source"
-msgstr "afficher la source"
+#: builtin/clone.c:111 builtin/init-db.c:486
+msgid "template-directory"
+msgstr "répertoire-modèle"
 
-#: builtin/log.c:155
-msgid "Use mail map file"
-msgstr "Utiliser le fichier de correspondance de mail"
+#: builtin/clone.c:112 builtin/init-db.c:487
+msgid "directory from which templates will be used"
+msgstr "répertoire depuis lequel les modèles vont être utilisés"
 
-#: builtin/log.c:157
-msgid "only decorate refs that match <pattern>"
-msgstr "décorer seulement les références correspondant à <motif>"
+#: builtin/clone.c:114 builtin/clone.c:116 builtin/submodule--helper.c:1392
+#: builtin/submodule--helper.c:1885
+msgid "reference repository"
+msgstr "dépôt de référence"
 
-#: builtin/log.c:159
-msgid "do not decorate refs that match <pattern>"
-msgstr "ne pas décorer les références correspondant à <motif>"
+#: builtin/clone.c:118 builtin/submodule--helper.c:1394
+#: builtin/submodule--helper.c:1887
+msgid "use --reference only while cloning"
+msgstr "utiliser seulement --reference pour cloner"
 
-#: builtin/log.c:160
-msgid "decorate options"
-msgstr "décorer les options"
+#: builtin/clone.c:119 builtin/column.c:27 builtin/merge-file.c:46
+#: builtin/pack-objects.c:3294 builtin/repack.c:327
+msgid "name"
+msgstr "nom"
 
-#: builtin/log.c:163
-msgid "Process line range n,m in file, counting from 1"
-msgstr ""
-"Traiter seulement l'intervalle de lignes n,m du fichier en commençant le "
-"compte à 1"
+#: builtin/clone.c:120
+msgid "use <name> instead of 'origin' to track upstream"
+msgstr "utiliser <nom> au lieu de 'origin' pour suivre la branche amont"
 
-#: builtin/log.c:259
-#, c-format
-msgid "Final output: %d %s\n"
-msgstr "Sortie finale : %d %s\n"
+#: builtin/clone.c:122
+msgid "checkout <branch> instead of the remote's HEAD"
+msgstr "extraire <branche> au lieu de la HEAD du répertoire distant"
 
-#: builtin/log.c:510
-#, c-format
-msgid "git show %s: bad file"
-msgstr "git show %s : fichier incorrect"
+#: builtin/clone.c:124
+msgid "path to git-upload-pack on the remote"
+msgstr "chemin vers git-upload-pack sur le serveur distant"
 
-#: builtin/log.c:525 builtin/log.c:619
-#, c-format
-msgid "Could not read object %s"
-msgstr "Impossible de lire l'objet %s"
+#: builtin/clone.c:125 builtin/fetch.c:168 builtin/grep.c:840
+#: builtin/pull.c:227
+msgid "depth"
+msgstr "profondeur"
 
-#: builtin/log.c:643
-#, c-format
-msgid "Unknown type: %d"
-msgstr "Type inconnu : %d"
+#: builtin/clone.c:126
+msgid "create a shallow clone of that depth"
+msgstr "créer un clone superficiel de cette profondeur"
 
-#: builtin/log.c:764
-msgid "format.headers without value"
-msgstr "format.headers sans valeur"
+#: builtin/clone.c:127 builtin/fetch.c:170 builtin/pack-objects.c:3283
+msgid "time"
+msgstr "heure"
 
-#: builtin/log.c:865
-msgid "name of output directory is too long"
-msgstr "le nom du répertoire de sortie est trop long"
+#: builtin/clone.c:128
+msgid "create a shallow clone since a specific time"
+msgstr "créer un clone superficiel depuis une date spécifique"
 
-#: builtin/log.c:881
-#, c-format
-msgid "Cannot open patch file %s"
-msgstr "Impossible d'ouvrir le fichier correctif %s"
+#: builtin/clone.c:129 builtin/fetch.c:172 builtin/fetch.c:195
+#: builtin/rebase.c:1445
+msgid "revision"
+msgstr "révision"
 
-#: builtin/log.c:898
-msgid "Need exactly one range."
-msgstr "Exactement une plage nécessaire."
+#: builtin/clone.c:130 builtin/fetch.c:173
+msgid "deepen history of shallow clone, excluding rev"
+msgstr ""
+"approfondir l'historique d'un clone superficiel en excluant une révision"
 
-#: builtin/log.c:908
-msgid "Not a range."
-msgstr "Ceci n'est pas une plage."
+#: builtin/clone.c:132
+msgid "clone only one branch, HEAD or --branch"
+msgstr "cloner seulement une branche, HEAD ou --branch"
 
-#: builtin/log.c:1014
-msgid "Cover letter needs email format"
-msgstr "La lettre de motivation doit être au format courriel"
+#: builtin/clone.c:134
+msgid "don't clone any tags, and make later fetches not to follow them"
+msgstr ""
+"ne pas cloner les tags et indiquer aux récupérations futures de ne pas le "
+"faire"
 
-#: builtin/log.c:1095
-#, c-format
-msgid "insane in-reply-to: %s"
-msgstr "in-reply-to aberrant : %s"
+#: builtin/clone.c:136
+msgid "any cloned submodules will be shallow"
+msgstr "tous les sous-modules clonés seront superficiels"
 
-#: builtin/log.c:1122
-msgid "git format-patch [<options>] [<since> | <revision-range>]"
-msgstr "git format-patch [<options>] [<depuis> | <plage de révisions>]"
+#: builtin/clone.c:137 builtin/init-db.c:495
+msgid "gitdir"
+msgstr "gitdir"
 
-#: builtin/log.c:1172
-msgid "Two output directories?"
-msgstr "Deux répertoires de sortie ?"
+#: builtin/clone.c:138 builtin/init-db.c:496
+msgid "separate git dir from working tree"
+msgstr "séparer le répertoire git de la copie de travail"
 
-#: builtin/log.c:1279 builtin/log.c:1932 builtin/log.c:1934 builtin/log.c:1946
-#, c-format
-msgid "Unknown commit %s"
-msgstr "Commit inconnu %s"
+#: builtin/clone.c:139
+msgid "key=value"
+msgstr "clé=valeur"
 
-#: builtin/log.c:1289 builtin/notes.c:887 builtin/tag.c:523
-#, c-format
-msgid "Failed to resolve '%s' as a valid ref."
-msgstr "Impossible de résoudre '%s' comme une référence valide."
+#: builtin/clone.c:140
+msgid "set config inside the new repository"
+msgstr "régler la configuration dans le nouveau dépôt"
+
+#: builtin/clone.c:142 builtin/fetch.c:190 builtin/ls-remote.c:76
+#: builtin/push.c:573 builtin/send-pack.c:172
+msgid "server-specific"
+msgstr "spécifique au serveur"
+
+#: builtin/clone.c:142 builtin/fetch.c:190 builtin/ls-remote.c:76
+#: builtin/push.c:573 builtin/send-pack.c:173
+msgid "option to transmit"
+msgstr "option à transmettre"
+
+#: builtin/clone.c:143 builtin/fetch.c:191 builtin/pull.c:240
+#: builtin/push.c:574
+msgid "use IPv4 addresses only"
+msgstr "n'utiliser que des adresses IPv4"
+
+#: builtin/clone.c:145 builtin/fetch.c:193 builtin/pull.c:243
+#: builtin/push.c:576
+msgid "use IPv6 addresses only"
+msgstr "n'utiliser que des adresses IPv6"
+
+#: builtin/clone.c:149
+msgid "any cloned submodules will use their remote-tracking branch"
+msgstr ""
+"tous les sous-modules clonés utiliseront leur branche de suivi à distance"
 
-#: builtin/log.c:1294
-msgid "Could not find exact merge base."
-msgstr "Impossible de trouver la base de fusion exacte."
+#: builtin/clone.c:151
+msgid "initialize sparse-checkout file to include only files at root"
+msgstr "initialiser le fichier d'extraction partielle pour n'inclure que les fichiers à la racine"
 
-#: builtin/log.c:1298
+#: builtin/clone.c:287
 msgid ""
-"Failed to get upstream, if you want to record base commit automatically,\n"
-"please use git branch --set-upstream-to to track a remote branch.\n"
-"Or you could specify base commit by --base=<base-commit-id> manually."
+"No directory name could be guessed.\n"
+"Please specify a directory on the command line"
 msgstr ""
-"Impossible de récupérer l'amont, si vous voulez enregistrer le commit de "
-"base automatiquement,\n"
-"veuillez utiliser git branch --set-upstream-to pour suivre une branche "
-"distante\n"
-"ou vous pouvez spécifier le commit de base par --base=<id-du-commit-de-base> "
-"manuellement."
-
-#: builtin/log.c:1318
-msgid "Failed to find exact merge base"
-msgstr "Impossible de trouver la base de fusion exacte"
+"Aucun nom de répertoire n'a pu être deviné\n"
+"Veuillez spécifier un répertoire dans la ligne de commande"
 
-#: builtin/log.c:1329
-msgid "base commit should be the ancestor of revision list"
-msgstr "le commit de base devrait être l'ancêtre de la liste de révisions"
+#: builtin/clone.c:340
+#, c-format
+msgid "info: Could not add alternate for '%s': %s\n"
+msgstr "info : impossible d'ajouter une alternative pour '%s' : %s\n"
 
-#: builtin/log.c:1333
-msgid "base commit shouldn't be in revision list"
-msgstr "le commit de base ne devrait pas faire partie de la liste de révisions"
+#: builtin/clone.c:413
+#, c-format
+msgid "%s exists and is not a directory"
+msgstr "%s existe et n'est pas un répertoire"
 
-#: builtin/log.c:1382
-msgid "cannot get patch id"
-msgstr "impossible d'obtenir l'id du patch"
+#: builtin/clone.c:430
+#, c-format
+msgid "failed to start iterator over '%s'"
+msgstr "échec du démarrage un itérateur sur '%s'"
 
-#: builtin/log.c:1441
-msgid "use [PATCH n/m] even with a single patch"
-msgstr "utiliser [PATCH n/m] même avec un patch unique"
+#: builtin/clone.c:460
+#, c-format
+msgid "failed to create link '%s'"
+msgstr "échec de la création du lien '%s'"
 
-#: builtin/log.c:1444
-msgid "use [PATCH] even with multiple patches"
-msgstr "utiliser [PATCH] même avec des patchs multiples"
+#: builtin/clone.c:464
+#, c-format
+msgid "failed to copy file to '%s'"
+msgstr "échec de la copie vers '%s'"
 
-#: builtin/log.c:1448
-msgid "print patches to standard out"
-msgstr "afficher les patchs sur la sortie standard"
+#: builtin/clone.c:469
+#, c-format
+msgid "failed to iterate over '%s'"
+msgstr "échec de l'itération sur '%s'"
 
-#: builtin/log.c:1450
-msgid "generate a cover letter"
-msgstr "générer une lettre de motivation"
+#: builtin/clone.c:494
+#, c-format
+msgid "done.\n"
+msgstr "fait.\n"
 
-#: builtin/log.c:1452
-msgid "use simple number sequence for output file names"
+#: builtin/clone.c:508
+msgid ""
+"Clone succeeded, but checkout failed.\n"
+"You can inspect what was checked out with 'git status'\n"
+"and retry with 'git restore --source=HEAD :/'\n"
 msgstr ""
-"utiliser une séquence simple de nombres pour les nom des fichiers de sortie"
+"Le clone a réussi, mais l'extraction a échoué.\n"
+"Vous pouvez inspecter ce qui a été extrait avec 'git status'\n"
+"et réessayer avec 'git restore --source=HEAD :/'\n"
 
-#: builtin/log.c:1453
-msgid "sfx"
-msgstr "sfx"
+#: builtin/clone.c:585
+#, c-format
+msgid "Could not find remote branch %s to clone."
+msgstr "Impossible de trouver la branche distante '%s' à cloner."
 
-#: builtin/log.c:1454
-msgid "use <sfx> instead of '.patch'"
-msgstr "utiliser <sfx> au lieu de '.patch'"
+#: builtin/clone.c:704
+#, c-format
+msgid "unable to update %s"
+msgstr "impossible de mettre à jour %s"
 
-#: builtin/log.c:1456
-msgid "start numbering patches at <n> instead of 1"
-msgstr "démarrer la numérotation des patchs à <n> au lieu de 1"
+#: builtin/clone.c:752
+msgid "failed to initialize sparse-checkout"
+msgstr "échec lors de l'initialisation l'extraction partielle"
 
-#: builtin/log.c:1458
-msgid "mark the series as Nth re-roll"
-msgstr "marquer la série comme une Nième réédition"
+#: builtin/clone.c:775
+msgid "remote HEAD refers to nonexistent ref, unable to checkout.\n"
+msgstr ""
+"la HEAD distante réfère à une référence non existante, impossible de "
+"l'extraire.\n"
 
-#: builtin/log.c:1460
-msgid "Use [RFC PATCH] instead of [PATCH]"
-msgstr "utiliser [RFC PATCH] au lieu de [PATCH]"
+#: builtin/clone.c:806
+msgid "unable to checkout working tree"
+msgstr "impossible d'extraire la copie de travail"
 
-#: builtin/log.c:1463
-msgid "Use [<prefix>] instead of [PATCH]"
-msgstr "utiliser [<préfixe>] au lieu de [PATCH]"
-
-#: builtin/log.c:1466
-msgid "store resulting files in <dir>"
-msgstr "stocker les fichiers résultats dans <répertoire>"
-
-#: builtin/log.c:1469
-msgid "don't strip/add [PATCH]"
-msgstr "ne pas retirer/ajouter [PATCH]"
+#: builtin/clone.c:856
+msgid "unable to write parameters to config file"
+msgstr "impossible d'écrire les paramètres dans le fichier de configuration"
 
-#: builtin/log.c:1472
-msgid "don't output binary diffs"
-msgstr "ne pas imprimer les diffs binaires"
+#: builtin/clone.c:919
+msgid "cannot repack to clean up"
+msgstr "impossible de remballer pour nettoyer"
 
-#: builtin/log.c:1474
-msgid "output all-zero hash in From header"
-msgstr "écrire une empreinte à zéro dans l'entête From"
+#: builtin/clone.c:921
+msgid "cannot unlink temporary alternates file"
+msgstr "impossible de délier le fichier temporaire alternates"
 
-#: builtin/log.c:1476
-msgid "don't include a patch matching a commit upstream"
-msgstr "ne pas inclure un patch correspondant à un commit amont"
+#: builtin/clone.c:959 builtin/receive-pack.c:1948
+msgid "Too many arguments."
+msgstr "Trop d'arguments."
 
-#: builtin/log.c:1478
-msgid "show patch format instead of default (patch + stat)"
-msgstr "afficher le format du patch au lieu du défaut (patch + stat)"
+#: builtin/clone.c:963
+msgid "You must specify a repository to clone."
+msgstr "Vous devez spécifier un dépôt à cloner."
 
-#: builtin/log.c:1480
-msgid "Messaging"
-msgstr "Communication"
+#: builtin/clone.c:976
+#, c-format
+msgid "--bare and --origin %s options are incompatible."
+msgstr "les options --bare et --origin %s sont incompatibles."
 
-#: builtin/log.c:1481
-msgid "header"
-msgstr "en-tête"
+#: builtin/clone.c:979
+msgid "--bare and --separate-git-dir are incompatible."
+msgstr "--bare et --separate-git-dir sont incompatibles."
 
-#: builtin/log.c:1482
-msgid "add email header"
-msgstr "ajouter l'en-tête de courriel"
+#: builtin/clone.c:992
+#, c-format
+msgid "repository '%s' does not exist"
+msgstr "le dépôt '%s' n'existe pas"
 
-#: builtin/log.c:1483 builtin/log.c:1485
-msgid "email"
-msgstr "courriel"
+#: builtin/clone.c:998 builtin/fetch.c:1787
+#, c-format
+msgid "depth %s is not a positive number"
+msgstr "la profondeur %s n'est pas un entier positif"
 
-#: builtin/log.c:1483
-msgid "add To: header"
-msgstr "ajouter l'en-tête \"To:\""
+#: builtin/clone.c:1008
+#, c-format
+msgid "destination path '%s' already exists and is not an empty directory."
+msgstr ""
+"le chemin de destination '%s' existe déjà et n'est pas un répertoire vide."
 
-#: builtin/log.c:1485
-msgid "add Cc: header"
-msgstr "ajouter l'en-tête \"Cc:\""
+#: builtin/clone.c:1018
+#, c-format
+msgid "working tree '%s' already exists."
+msgstr "la copie de travail '%s' existe déjà."
 
-#: builtin/log.c:1487
-msgid "ident"
-msgstr "ident"
+#: builtin/clone.c:1033 builtin/clone.c:1054 builtin/difftool.c:271
+#: builtin/log.c:1866 builtin/worktree.c:302 builtin/worktree.c:334
+#, c-format
+msgid "could not create leading directories of '%s'"
+msgstr "impossible de créer les répertoires de premier niveau dans '%s'"
 
-#: builtin/log.c:1488
-msgid "set From address to <ident> (or committer ident if absent)"
-msgstr ""
-"renseigner l'adresse From à <ident> (ou à l'ident du validateur si absent)"
+#: builtin/clone.c:1038
+#, c-format
+msgid "could not create work tree dir '%s'"
+msgstr "impossible de créer le répertoire de la copie de travail '%s'"
 
-#: builtin/log.c:1490
-msgid "message-id"
-msgstr "id-message"
+#: builtin/clone.c:1058
+#, c-format
+msgid "Cloning into bare repository '%s'...\n"
+msgstr "Clonage dans le dépôt nu '%s'\n"
 
-#: builtin/log.c:1491
-msgid "make first mail a reply to <message-id>"
-msgstr "répondre dans le premier message à <id-message>"
+#: builtin/clone.c:1060
+#, c-format
+msgid "Cloning into '%s'...\n"
+msgstr "Clonage dans '%s'...\n"
 
-#: builtin/log.c:1492 builtin/log.c:1495
-msgid "boundary"
-msgstr "limite"
+#: builtin/clone.c:1084
+msgid ""
+"clone --recursive is not compatible with both --reference and --reference-if-"
+"able"
+msgstr ""
+"clone --recursive n'est pas compatible avec à la fois --reference et --"
+"reference-if-able"
 
-#: builtin/log.c:1493
-msgid "attach the patch"
-msgstr "attacher le patch"
+#: builtin/clone.c:1148
+msgid "--depth is ignored in local clones; use file:// instead."
+msgstr ""
+"--depth est ignoré dans les clones locaux : utilisez plutôt \"file://\"."
 
-#: builtin/log.c:1496
-msgid "inline the patch"
-msgstr "patch à l'intérieur"
+#: builtin/clone.c:1150
+msgid "--shallow-since is ignored in local clones; use file:// instead."
+msgstr ""
+"--shallow-since est ignoré dans les clones locaux : utilisez plutôt \"file://"
+"\"."
 
-#: builtin/log.c:1500
-msgid "enable message threading, styles: shallow, deep"
+#: builtin/clone.c:1152
+msgid "--shallow-exclude is ignored in local clones; use file:// instead."
 msgstr ""
-"activer l'enfilage de message, styles : shallow (superficiel), deep (profond)"
+"--shallow-exclude est ignoré dans les clones locaux : utilisez plutôt "
+"\"file://\"."
 
-#: builtin/log.c:1502
-msgid "signature"
-msgstr "signature"
+#: builtin/clone.c:1154
+msgid "--filter is ignored in local clones; use file:// instead."
+msgstr "--filter est ignoré dans les clones locaux ; utilisez plutôt file:// ."
 
-#: builtin/log.c:1503
-msgid "add a signature"
-msgstr "ajouter une signature"
+#: builtin/clone.c:1157
+msgid "source repository is shallow, ignoring --local"
+msgstr "le dépôt source est superficiel, option --local ignorée"
 
-#: builtin/log.c:1504
-msgid "base-commit"
-msgstr "commit-de-base"
+#: builtin/clone.c:1162
+msgid "--local is ignored"
+msgstr "--local est ignoré"
 
-#: builtin/log.c:1505
-msgid "add prerequisite tree info to the patch series"
-msgstr "Ajouter un arbre prérequis à la série de patchs"
+#: builtin/clone.c:1237 builtin/clone.c:1245
+#, c-format
+msgid "Remote branch %s not found in upstream %s"
+msgstr "La branche distante %s n'a pas été trouvée dans le dépôt amont %s"
 
-#: builtin/log.c:1507
-msgid "add a signature from a file"
-msgstr "ajouter une signature depuis un fichier"
+#: builtin/clone.c:1248
+msgid "You appear to have cloned an empty repository."
+msgstr "Vous semblez avoir cloné un dépôt vide."
 
-#: builtin/log.c:1508
-msgid "don't print the patch filenames"
-msgstr "ne pas afficher les noms de fichiers des patchs"
+#: builtin/column.c:10
+msgid "git column [<options>]"
+msgstr "git column [<options>]"
 
-#: builtin/log.c:1510
-msgid "show progress while generating patches"
-msgstr ""
-"afficher la barre de progression durant la phase de génération des patchs"
+#: builtin/column.c:27
+msgid "lookup config vars"
+msgstr "rechercher les variables de configuration"
 
-#: builtin/log.c:1585
-#, c-format
-msgid "invalid ident line: %s"
-msgstr "ligne d'identification invalide : %s"
+#: builtin/column.c:28 builtin/column.c:29
+msgid "layout to use"
+msgstr "mise en page à utiliser"
 
-#: builtin/log.c:1600
-msgid "-n and -k are mutually exclusive."
-msgstr "-n et -k sont mutuellement exclusifs."
-
-#: builtin/log.c:1602
-msgid "--subject-prefix/--rfc and -k are mutually exclusive."
-msgstr "--subject-prefix/--rfc et -k sont mutuellement exclusifs."
+#: builtin/column.c:30
+msgid "Maximum width"
+msgstr "Largeur maximale"
 
-#: builtin/log.c:1610
-msgid "--name-only does not make sense"
-msgstr "--name-only n'a pas de sens"
+#: builtin/column.c:31
+msgid "Padding space on left border"
+msgstr "Remplissage d'espace sur la bordure gauche"
 
-#: builtin/log.c:1612
-msgid "--name-status does not make sense"
-msgstr "--name-status n'a pas de sens"
+#: builtin/column.c:32
+msgid "Padding space on right border"
+msgstr "Remplissage d'espace sur le côté droit"
 
-#: builtin/log.c:1614
-msgid "--check does not make sense"
-msgstr "--check n'a pas de sens"
+#: builtin/column.c:33
+msgid "Padding space between columns"
+msgstr "Remplissage d'espace entre les colonnes"
 
-#: builtin/log.c:1646
-msgid "standard output, or directory, which one?"
-msgstr "sortie standard, ou répertoire, lequel ?"
+#: builtin/column.c:51
+msgid "--command must be the first argument"
+msgstr "--command doit être le premier argument"
 
-#: builtin/log.c:1648
-#, c-format
-msgid "Could not create directory '%s'"
-msgstr "Impossible de créer le répertoire '%s'"
+#: builtin/commit-tree.c:18
+msgid ""
+"git commit-tree [(-p <parent>)...] [-S[<keyid>]] [(-m <message>)...] [(-F "
+"<file>)...] <tree>"
+msgstr ""
+"git commit-tree [(-p <parent>)...] [-S[<idclé>]] [(-m <message>)...] [(-F "
+"<fichier>)...] <arbre>"
 
-#: builtin/log.c:1741
+#: builtin/commit-tree.c:31
 #, c-format
-msgid "unable to read signature file '%s'"
-msgstr "lecture du fichier de signature '%s' impossible"
+msgid "duplicate parent %s ignored"
+msgstr "le parent dupliqué %s est ignoré"
 
-#: builtin/log.c:1773
-msgid "Generating patches"
-msgstr "Génération des patchs"
-
-#: builtin/log.c:1817
-msgid "Failed to create output files"
-msgstr "Échec de création des fichiers en sortie"
+#: builtin/commit-tree.c:56 builtin/commit-tree.c:136 builtin/log.c:526
+#, c-format
+msgid "not a valid object name %s"
+msgstr "nom d'objet invalide %s"
 
-#: builtin/log.c:1867
-msgid "git cherry [-v] [<upstream> [<head> [<limit>]]]"
-msgstr "git cherry [-v] [<branche_amont> [<head> [<limite>]]]"
+#: builtin/commit-tree.c:93
+#, c-format
+msgid "git commit-tree: failed to open '%s'"
+msgstr "git commit-tree : échec à l'ouverture de '%s'"
 
-#: builtin/log.c:1921
+#: builtin/commit-tree.c:96
 #, c-format
-msgid ""
-"Could not find a tracked remote branch, please specify <upstream> manually.\n"
-msgstr ""
-"Impossible de trouver une branche distante suivie, merci de spécifier "
-"<branche_amont> manuellement.\n"
+msgid "git commit-tree: failed to read '%s'"
+msgstr "git commit-tree : échec de la lecture de '%s'"
 
-#: builtin/ls-files.c:468
-msgid "git ls-files [<options>] [<file>...]"
-msgstr "git ls-files [<options>] [<fichier>...]"
+#: builtin/commit-tree.c:98
+#, c-format
+msgid "git commit-tree: failed to close '%s'"
+msgstr "git commit-tree : échec de la fermeture de '%s'"
 
-#: builtin/ls-files.c:517
-msgid "identify the file status with tags"
-msgstr "identifier l'état de fichier avec les étiquettes"
+#: builtin/commit-tree.c:111
+msgid "parent"
+msgstr "parent"
 
-#: builtin/ls-files.c:519
-msgid "use lowercase letters for 'assume unchanged' files"
-msgstr "utiliser des minuscules pour les fichiers 'assumés inchangés'"
+#: builtin/commit-tree.c:112
+msgid "id of a parent commit object"
+msgstr "id d'un objet commit parent"
 
-#: builtin/ls-files.c:521
-msgid "use lowercase letters for 'fsmonitor clean' files"
-msgstr "utiliser des minuscules pour les fichiers 'fsmonitor clean'"
+#: builtin/commit-tree.c:114 builtin/commit.c:1496 builtin/merge.c:270
+#: builtin/notes.c:409 builtin/notes.c:575 builtin/stash.c:1469
+#: builtin/tag.c:412
+msgid "message"
+msgstr "message"
 
-#: builtin/ls-files.c:523
-msgid "show cached files in the output (default)"
-msgstr "afficher les fichiers mis en cache dans la sortie (défaut)"
+#: builtin/commit-tree.c:115 builtin/commit.c:1496
+msgid "commit message"
+msgstr "message de validation"
 
-#: builtin/ls-files.c:525
-msgid "show deleted files in the output"
-msgstr "afficher les fichiers supprimés dans la sortie"
+#: builtin/commit-tree.c:118
+msgid "read commit log message from file"
+msgstr "lire le message de validation depuis un fichier"
 
-#: builtin/ls-files.c:527
-msgid "show modified files in the output"
-msgstr "afficher les fichiers modifiés dans la sortie"
+#: builtin/commit-tree.c:121 builtin/commit.c:1508 builtin/merge.c:287
+#: builtin/pull.c:195 builtin/revert.c:118
+msgid "GPG sign commit"
+msgstr "signer la validation avec GPG"
 
-#: builtin/ls-files.c:529
-msgid "show other files in the output"
-msgstr "afficher les autres fichiers dans la sortie"
+#: builtin/commit-tree.c:133
+msgid "must give exactly one tree"
+msgstr "exactement un arbre obligatoire"
+
+#: builtin/commit-tree.c:140
+msgid "git commit-tree: failed to read"
+msgstr "git commit-tree : échec de la lecture"
 
-#: builtin/ls-files.c:531
-msgid "show ignored files in the output"
-msgstr "afficher les fichiers ignorés dans la sortie"
+#: builtin/commit.c:41
+msgid "git commit [<options>] [--] <pathspec>..."
+msgstr "git commit [<options>] [--] <spécification-de-chemin>..."
 
-#: builtin/ls-files.c:534
-msgid "show staged contents' object name in the output"
-msgstr "afficher les nom des objets indexés dans la sortie"
+#: builtin/commit.c:46
+msgid "git status [<options>] [--] <pathspec>..."
+msgstr "git status [<options>] [--] <spécification-de-chemin>..."
 
-#: builtin/ls-files.c:536
-msgid "show files on the filesystem that need to be removed"
+#: builtin/commit.c:51
+msgid ""
+"You asked to amend the most recent commit, but doing so would make\n"
+"it empty. You can repeat your command with --allow-empty, or you can\n"
+"remove the commit entirely with \"git reset HEAD^\".\n"
 msgstr ""
-"afficher les fichiers du système de fichiers qui ont besoin d'être supprimés"
-
-#: builtin/ls-files.c:538
-msgid "show 'other' directories' names only"
-msgstr "afficher seulement les noms des répertoires 'other'"
-
-#: builtin/ls-files.c:540
-msgid "show line endings of files"
-msgstr "afficher les fins de lignes des fichiers"
+"Vous avez demandé de corriger le commit le plus récent, mais le faire le "
+"rendrait\n"
+"vide. Vous pouvez répéter votre commande avec --allow-empty, ou vous pouvez\n"
+"supprimer complètement le commit avec \"git reset HEAD^\".\n"
 
-#: builtin/ls-files.c:542
-msgid "don't show empty directories"
-msgstr "ne pas afficher les répertoires vides"
+#: builtin/commit.c:56
+msgid ""
+"The previous cherry-pick is now empty, possibly due to conflict resolution.\n"
+"If you wish to commit it anyway, use:\n"
+"\n"
+"    git commit --allow-empty\n"
+"\n"
+msgstr ""
+"Le picorage précédent est à présent vide, vraisemblablement dû à une "
+"résolution de conflit.\n"
+"Si vous souhaitez tout de même le valider, utilisez :\n"
+"\n"
+"    git commit --allow-empty\n"
+"\n"
 
-#: builtin/ls-files.c:545
-msgid "show unmerged files in the output"
-msgstr "afficher les fichiers non fusionnés dans la sortie"
+#: builtin/commit.c:63
+msgid "Otherwise, please use 'git cherry-pick --skip'\n"
+msgstr "Sinon, veuillez utiliser 'git cherry-pick --skip'\n"
 
-#: builtin/ls-files.c:547
-msgid "show resolve-undo information"
-msgstr "afficher l'information resolv-undo"
-
-#: builtin/ls-files.c:549
-msgid "skip files matching pattern"
-msgstr "sauter les fichiers correspondant au motif"
-
-#: builtin/ls-files.c:552
-msgid "exclude patterns are read from <file>"
-msgstr "les motifs d'exclusion sont lus depuis <fichier>"
-
-#: builtin/ls-files.c:555
-msgid "read additional per-directory exclude patterns in <file>"
-msgstr "lire des motifs d'exclusion additionnels par répertoire dans <fichier>"
+#: builtin/commit.c:66
+msgid ""
+"and then use:\n"
+"\n"
+"    git cherry-pick --continue\n"
+"\n"
+"to resume cherry-picking the remaining commits.\n"
+"If you wish to skip this commit, use:\n"
+"\n"
+"    git cherry-pick --skip\n"
+"\n"
+msgstr ""
+"utilisez ensuite :\n"
+"\n"
+"    git cherry-pick --continue\n"
+"\n"
+"pour continuer le picorage des commits restants.\n"
+"Si vous souhaitez sauter ce commit, utilisez :\n"
+"\n"
+"    git cherry-pick --skipped\n"
+"\n"
 
-#: builtin/ls-files.c:557
-msgid "add the standard git exclusions"
-msgstr "ajouter les exclusions git standard"
+#: builtin/commit.c:315
+msgid "failed to unpack HEAD tree object"
+msgstr "échec du dépaquetage de l'objet arbre HEAD"
 
-#: builtin/ls-files.c:560
-msgid "make the output relative to the project top directory"
-msgstr "afficher en relatif par rapport au répertoire racine du projet"
+#: builtin/commit.c:351
+msgid "--pathspec-from-file with -a does not make sense"
+msgstr "--pathspec-from-file avec l'option -a n'a pas de sens"
 
-#: builtin/ls-files.c:563
-msgid "recurse through submodules"
-msgstr "parcourir récursivement les sous-modules"
+#: builtin/commit.c:364
+msgid "No paths with --include/--only does not make sense."
+msgstr "Aucun chemin avec les options --include/--only n'a pas de sens."
 
-#: builtin/ls-files.c:565
-msgid "if any <file> is not in the index, treat this as an error"
-msgstr "si un <fichier> n'est pas dans l'index, traiter cela comme une erreur"
+#: builtin/commit.c:376
+msgid "unable to create temporary index"
+msgstr "impossible de créer l'index temporaire"
 
-#: builtin/ls-files.c:566
-msgid "tree-ish"
-msgstr "arbre ou apparenté"
+#: builtin/commit.c:382
+msgid "interactive add failed"
+msgstr "échec de l'ajout interactif"
 
-#: builtin/ls-files.c:567
-msgid "pretend that paths removed since <tree-ish> are still present"
-msgstr ""
-"considérer que les chemins supprimés depuis <arbre ou apparenté> sont "
-"toujours présents"
+#: builtin/commit.c:396
+msgid "unable to update temporary index"
+msgstr "impossible de mettre à jour l'index temporaire"
 
-#: builtin/ls-files.c:569
-msgid "show debugging data"
-msgstr "afficher les données de débogage"
+#: builtin/commit.c:398
+msgid "Failed to update main cache tree"
+msgstr "Impossible de mettre à jour l'arbre de cache principal"
 
-#: builtin/ls-remote.c:9
-msgid ""
-"git ls-remote [--heads] [--tags] [--refs] [--upload-pack=<exec>]\n"
-"                     [-q | --quiet] [--exit-code] [--get-url]\n"
-"                     [--symref] [<repository> [<refs>...]]"
-msgstr ""
-"git ls-remote [--heads] [--tags] [--refs] [--upload-pack=<exec>]\n"
-"                     [-q | --quiet] [--exit-code] [--get-url]\n"
-"                     [--symref] [<dépôt> [<références>...]]"
+#: builtin/commit.c:423 builtin/commit.c:446 builtin/commit.c:492
+msgid "unable to write new_index file"
+msgstr "impossible d'écrire le fichier new_index"
 
-#: builtin/ls-remote.c:59
-msgid "do not print remote URL"
-msgstr "ne pas afficher les URL distantes"
+#: builtin/commit.c:475
+msgid "cannot do a partial commit during a merge."
+msgstr "impossible de faire une validation partielle pendant une fusion."
 
-#: builtin/ls-remote.c:60 builtin/ls-remote.c:62
-msgid "exec"
-msgstr "exécutable"
+#: builtin/commit.c:477
+msgid "cannot do a partial commit during a cherry-pick."
+msgstr "impossible de faire une validation partielle pendant un picorage."
 
-#: builtin/ls-remote.c:61 builtin/ls-remote.c:63
-msgid "path of git-upload-pack on the remote host"
-msgstr "chemin vers git-upload-pack sur le serveur distant"
+#: builtin/commit.c:485
+msgid "cannot read the index"
+msgstr "impossible de lire l'index"
 
-#: builtin/ls-remote.c:65
-msgid "limit to tags"
-msgstr "limiter aux étiquettes"
+#: builtin/commit.c:504
+msgid "unable to write temporary index file"
+msgstr "impossible d'écrire le fichier d'index temporaire"
 
-#: builtin/ls-remote.c:66
-msgid "limit to heads"
-msgstr "limiter aux heads"
+#: builtin/commit.c:602
+#, c-format
+msgid "commit '%s' lacks author header"
+msgstr "entête d'auteur manquant dans le commit '%s'"
 
-#: builtin/ls-remote.c:67
-msgid "do not show peeled tags"
-msgstr "ne pas afficher les étiquettes pelées"
+#: builtin/commit.c:604
+#, c-format
+msgid "commit '%s' has malformed author line"
+msgstr "le commit '%s' a une ligne d'auteur malformée"
 
-#: builtin/ls-remote.c:69
-msgid "take url.<base>.insteadOf into account"
-msgstr "prendre en compte url.<base>.insteadOf"
+#: builtin/commit.c:623
+msgid "malformed --author parameter"
+msgstr "paramètre --author mal formé"
 
-#: builtin/ls-remote.c:73
-msgid "exit with exit code 2 if no matching refs are found"
+#: builtin/commit.c:676
+msgid ""
+"unable to select a comment character that is not used\n"
+"in the current commit message"
 msgstr ""
-"sortir avec un code d'erreur 2 si aucune correspondance de référence n'est "
-"trouvée"
+"impossible de sélectionner un caractère de commentaire\n"
+"qui n'est pas utilisé dans le message de validation actuel"
 
-#: builtin/ls-remote.c:76
-msgid "show underlying ref in addition to the object pointed by it"
-msgstr "afficher la réf sous-jacente en plus de l'objet pointé par elle"
+#: builtin/commit.c:714 builtin/commit.c:747 builtin/commit.c:1092
+#, c-format
+msgid "could not lookup commit %s"
+msgstr "impossible de rechercher le commit %s"
 
-#: builtin/ls-tree.c:29
-msgid "git ls-tree [<options>] <tree-ish> [<path>...]"
-msgstr "git ls-tree [<options>] <arbre ou apparenté> [<chemin>...]"
+#: builtin/commit.c:726 builtin/shortlog.c:319
+#, c-format
+msgid "(reading log message from standard input)\n"
+msgstr "(lecture du message de journal depuis l'entrée standard)\n"
 
-#: builtin/ls-tree.c:127
-msgid "only show trees"
-msgstr "afficher seulement les arbres"
+#: builtin/commit.c:728
+msgid "could not read log from standard input"
+msgstr "impossible de lire le journal depuis l'entrée standard"
 
-#: builtin/ls-tree.c:129
-msgid "recurse into subtrees"
-msgstr "parcourir les sous-arbres"
+#: builtin/commit.c:732
+#, c-format
+msgid "could not read log file '%s'"
+msgstr "impossible de lire le fichier de journal '%s'"
 
-#: builtin/ls-tree.c:131
-msgid "show trees when recursing"
-msgstr "afficher les arbres en les parcourant"
+#: builtin/commit.c:763 builtin/commit.c:779
+msgid "could not read SQUASH_MSG"
+msgstr "impossible de lire SQUASH_MSG"
 
-#: builtin/ls-tree.c:134
-msgid "terminate entries with NUL byte"
-msgstr "terminer les éléments avec un octet NUL"
+#: builtin/commit.c:770
+msgid "could not read MERGE_MSG"
+msgstr "impossible de lire MERGE_MSG"
 
-#: builtin/ls-tree.c:135
-msgid "include object size"
-msgstr "inclure la taille d'objet"
+#: builtin/commit.c:830
+msgid "could not write commit template"
+msgstr "impossible d'écrire le modèle de commit"
 
-#: builtin/ls-tree.c:137 builtin/ls-tree.c:139
-msgid "list only filenames"
-msgstr "afficher seulement les noms de fichiers"
+#: builtin/commit.c:849
+#, c-format
+msgid ""
+"\n"
+"It looks like you may be committing a merge.\n"
+"If this is not correct, please remove the file\n"
+"\t%s\n"
+"and try again.\n"
+msgstr ""
+"\n"
+"Il semble que vous validiez une fusion.\n"
+"Si ce n'est pas le cas, veuillez supprimer le fichier\n"
+"\t%s\n"
+"et essayez à nouveau.\n"
 
-#: builtin/ls-tree.c:142
-msgid "use full path names"
-msgstr "utiliser les noms de chemins complets"
+#: builtin/commit.c:854
+#, c-format
+msgid ""
+"\n"
+"It looks like you may be committing a cherry-pick.\n"
+"If this is not correct, please remove the file\n"
+"\t%s\n"
+"and try again.\n"
+msgstr ""
+"\n"
+"Il semble que vous validiez un picorage.\n"
+"Si ce n'est pas le cas, veuillez supprimer le fichier\n"
+"\t%s\n"
+"et essayez à nouveau.\n"
 
-#: builtin/ls-tree.c:144
-msgid "list entire tree; not just current directory (implies --full-name)"
+#: builtin/commit.c:867
+#, c-format
+msgid ""
+"Please enter the commit message for your changes. Lines starting\n"
+"with '%c' will be ignored, and an empty message aborts the commit.\n"
 msgstr ""
-"afficher l'arbre entier ; pas seulement le répertoire courant (implique --"
-"full-name)"
+"Veuillez saisir le message de validation pour vos modifications. Les lignes\n"
+"commençant par '%c' seront ignorées, et un message vide abandonne la "
+"validation.\n"
 
-#: builtin/mailsplit.c:241
+#: builtin/commit.c:875
 #, c-format
-msgid "empty mbox: '%s'"
-msgstr "mbox vide : '%s'"
+msgid ""
+"Please enter the commit message for your changes. Lines starting\n"
+"with '%c' will be kept; you may remove them yourself if you want to.\n"
+"An empty message aborts the commit.\n"
+msgstr ""
+"Veuillez saisir le message de validation pour vos modifications. Les lignes\n"
+"commençant par '%c' seront conservées ; vous pouvez les supprimer vous-même\n"
+"si vous le souhaitez. Un message vide abandonne la validation.\n"
 
-#: builtin/merge.c:51
-msgid "git merge [<options>] [<commit>...]"
-msgstr "git merge [<options>] [<commit>...]"
+#: builtin/commit.c:892
+#, c-format
+msgid "%sAuthor:    %.*s <%.*s>"
+msgstr "%sAuteur :     %.*s <%.*s>"
 
-#: builtin/merge.c:52
-msgid "git merge --abort"
-msgstr "git merge --abort"
+#: builtin/commit.c:900
+#, c-format
+msgid "%sDate:      %s"
+msgstr "%sDate :       %s"
 
-#: builtin/merge.c:53
-msgid "git merge --continue"
-msgstr "git merge --continue"
+#: builtin/commit.c:907
+#, c-format
+msgid "%sCommitter: %.*s <%.*s>"
+msgstr "%sValidateur : %.*s <%.*s>"
 
-#: builtin/merge.c:110
-msgid "switch `m' requires a value"
-msgstr "le commutateur `m' a besoin d'une valeur"
+#: builtin/commit.c:925
+msgid "Cannot read index"
+msgstr "Impossible de lire l'index"
+
+#: builtin/commit.c:992
+msgid "Error building trees"
+msgstr "Erreur lors de la construction des arbres"
 
-#: builtin/merge.c:147
+#: builtin/commit.c:1006 builtin/tag.c:275
 #, c-format
-msgid "Could not find merge strategy '%s'.\n"
-msgstr "Impossible de trouver la stratégie de fusion '%s'.\n"
+msgid "Please supply the message using either -m or -F option.\n"
+msgstr "Veuillez fournir le message en utilisant l'option -m ou -F.\n"
 
-#: builtin/merge.c:148
+#: builtin/commit.c:1050
 #, c-format
-msgid "Available strategies are:"
-msgstr "Les stratégies disponibles sont :"
+msgid "--author '%s' is not 'Name <email>' and matches no existing author"
+msgstr ""
+"--author '%s' n'est pas de la forme 'Nom <email>' ni ne correspond à aucun "
+"auteur existant"
 
-#: builtin/merge.c:153
+#: builtin/commit.c:1064
 #, c-format
-msgid "Available custom strategies are:"
-msgstr "Les stratégies personnalisées sont :"
+msgid "Invalid ignored mode '%s'"
+msgstr "Mode de fichier ignoré invalide '%s'"
 
-#: builtin/merge.c:203 builtin/pull.c:142
-msgid "do not show a diffstat at the end of the merge"
-msgstr "ne pas afficher un diffstat à la fin de la fusion"
+#: builtin/commit.c:1082 builtin/commit.c:1322
+#, c-format
+msgid "Invalid untracked files mode '%s'"
+msgstr "Mode de fichier non suivi invalide '%s'"
 
-#: builtin/merge.c:206 builtin/pull.c:145
-msgid "show a diffstat at the end of the merge"
-msgstr "afficher un diffstat à la fin de la fusion"
+#: builtin/commit.c:1122
+msgid "--long and -z are incompatible"
+msgstr "--long et -z sont incompatibles"
 
-#: builtin/merge.c:207 builtin/pull.c:148
-msgid "(synonym to --stat)"
-msgstr "(synonyme de --stat)"
+#: builtin/commit.c:1166
+msgid "Using both --reset-author and --author does not make sense"
+msgstr "L'utilisation simultanée de --reset-author et --author n'a pas de sens"
 
-#: builtin/merge.c:209 builtin/pull.c:151
-msgid "add (at most <n>) entries from shortlog to merge commit message"
-msgstr ""
-"ajouter (au plus <n>) éléments du journal court au message de validation de "
-"la fusion"
+#: builtin/commit.c:1175
+msgid "You have nothing to amend."
+msgstr "Il n'y a rien à corriger."
 
-#: builtin/merge.c:212 builtin/pull.c:157
-msgid "create a single commit instead of doing a merge"
-msgstr "créer une validation unique au lieu de faire une fusion"
+#: builtin/commit.c:1178
+msgid "You are in the middle of a merge -- cannot amend."
+msgstr "Vous êtes en pleine fusion -- impossible de corriger (amend)."
 
-#: builtin/merge.c:214 builtin/pull.c:160
-msgid "perform a commit if the merge succeeds (default)"
-msgstr "effectuer une validation si la fusion réussit (défaut)"
+#: builtin/commit.c:1180
+msgid "You are in the middle of a cherry-pick -- cannot amend."
+msgstr "Vous êtes en plein picorage -- impossible de corriger (amend)."
 
-#: builtin/merge.c:216 builtin/pull.c:163
-msgid "edit message before committing"
-msgstr "éditer le message avant la validation"
-
-#: builtin/merge.c:217
-msgid "allow fast-forward (default)"
-msgstr "autoriser l'avance rapide (défaut)"
-
-#: builtin/merge.c:219 builtin/pull.c:169
-msgid "abort if fast-forward is not possible"
-msgstr "abandonner si l'avance rapide n'est pas possible"
-
-#: builtin/merge.c:223 builtin/pull.c:172
-msgid "verify that the named commit has a valid GPG signature"
-msgstr "vérifier que le commit nommé a une signature GPG valide"
-
-#: builtin/merge.c:224 builtin/notes.c:777 builtin/pull.c:176
-#: builtin/revert.c:109
-msgid "strategy"
-msgstr "stratégie"
+#: builtin/commit.c:1183
+msgid "Options --squash and --fixup cannot be used together"
+msgstr "Les options --squash et --fixup ne peuvent pas être utilisées ensemble"
 
-#: builtin/merge.c:225 builtin/pull.c:177
-msgid "merge strategy to use"
-msgstr "stratégie de fusion à utiliser"
+#: builtin/commit.c:1193
+msgid "Only one of -c/-C/-F/--fixup can be used."
+msgstr "Une seule option parmi -c/-C/-F/--fixup peut être utilisée."
 
-#: builtin/merge.c:226 builtin/pull.c:180
-msgid "option=value"
-msgstr "option=valeur"
+#: builtin/commit.c:1195
+msgid "Option -m cannot be combined with -c/-C/-F."
+msgstr "L'option -m ne peut pas être combinée avec -c/-C/-F."
 
-#: builtin/merge.c:227 builtin/pull.c:181
-msgid "option for selected merge strategy"
-msgstr "option pour la stratégie de fusion sélectionnée"
+#: builtin/commit.c:1203
+msgid "--reset-author can be used only with -C, -c or --amend."
+msgstr "--reset-author ne peut être utilisé qu'avec -C, -c ou --amend."
 
-#: builtin/merge.c:229
-msgid "merge commit message (for a non-fast-forward merge)"
+#: builtin/commit.c:1220
+msgid "Only one of --include/--only/--all/--interactive/--patch can be used."
 msgstr ""
-"message de validation de la fusion (pour une fusion sans avance rapide)"
-
-#: builtin/merge.c:233
-msgid "abort the current in-progress merge"
-msgstr "abandonner la fusion en cours"
-
-#: builtin/merge.c:235
-msgid "continue the current in-progress merge"
-msgstr "continuer la fusion en cours"
-
-#: builtin/merge.c:237 builtin/pull.c:188
-msgid "allow merging unrelated histories"
-msgstr "permettre la fusion d'historiques sans rapport"
-
-#: builtin/merge.c:243
-msgid "verify commit-msg hook"
-msgstr "vérifier le crochet commit-msg"
-
-#: builtin/merge.c:268
-msgid "could not run stash."
-msgstr "impossible de lancer le remisage."
-
-#: builtin/merge.c:273
-msgid "stash failed"
-msgstr "échec du remisage"
+"Une seule option parmi --include/--only/--all/--interactive/--patch peut "
+"être utilisée."
 
-#: builtin/merge.c:278
+#: builtin/commit.c:1226
 #, c-format
-msgid "not a valid object: %s"
-msgstr "pas un objet valide : %s"
+msgid "paths '%s ...' with -a does not make sense"
+msgstr "des chemins '%s ...' avec l'option -a n'a pas de sens"
 
-#: builtin/merge.c:300 builtin/merge.c:317
-msgid "read-tree failed"
-msgstr "read-tree a échoué"
+#: builtin/commit.c:1357 builtin/commit.c:1519
+msgid "show status concisely"
+msgstr "afficher l'état avec concision"
 
-#: builtin/merge.c:347
-msgid " (nothing to squash)"
-msgstr " (rien à compresser)"
+#: builtin/commit.c:1359 builtin/commit.c:1521
+msgid "show branch information"
+msgstr "afficher l'information de branche"
 
-#: builtin/merge.c:358
-#, c-format
-msgid "Squash commit -- not updating HEAD\n"
-msgstr "Validation compressée -- HEAD non mise à jour\n"
+#: builtin/commit.c:1361
+msgid "show stash information"
+msgstr "afficher l'information de remisage"
 
-#: builtin/merge.c:408
-#, c-format
-msgid "No merge message -- not updating HEAD\n"
-msgstr "Pas de message de fusion -- pas de mise à jour de HEAD\n"
+#: builtin/commit.c:1363 builtin/commit.c:1523
+msgid "compute full ahead/behind values"
+msgstr "calcule les valeurs complètes en avance/en retard"
 
-#: builtin/merge.c:458
-#, c-format
-msgid "'%s' does not point to a commit"
-msgstr "'%s' ne pointe pas sur un commit"
+#: builtin/commit.c:1365
+msgid "version"
+msgstr "version"
 
-#: builtin/merge.c:548
-#, c-format
-msgid "Bad branch.%s.mergeoptions string: %s"
-msgstr "Mauvaise chaîne branch.%s.mergeoptions : %s"
+#: builtin/commit.c:1365 builtin/commit.c:1525 builtin/push.c:549
+#: builtin/worktree.c:650
+msgid "machine-readable output"
+msgstr "sortie pour traitement automatique"
 
-#: builtin/merge.c:669
-msgid "Not handling anything other than two heads merge."
-msgstr "Impossible de gérer autre chose que la fusion de deux têtes."
+#: builtin/commit.c:1368 builtin/commit.c:1527
+msgid "show status in long format (default)"
+msgstr "afficher l'état en format long (par défaut)"
 
-#: builtin/merge.c:683
-#, c-format
-msgid "Unknown option for merge-recursive: -X%s"
-msgstr "Options inconnue pour merge-recursive : -X%s"
+#: builtin/commit.c:1371 builtin/commit.c:1530
+msgid "terminate entries with NUL"
+msgstr "terminer les éléments par NUL"
 
-#: builtin/merge.c:698
-#, c-format
-msgid "unable to write %s"
-msgstr "impossible d'écrire %s"
+#: builtin/commit.c:1373 builtin/commit.c:1377 builtin/commit.c:1533
+#: builtin/fast-export.c:1153 builtin/fast-export.c:1156
+#: builtin/fast-export.c:1159 builtin/rebase.c:1525 parse-options.h:336
+msgid "mode"
+msgstr "mode"
 
-#: builtin/merge.c:749
-#, c-format
-msgid "Could not read from '%s'"
-msgstr "Impossible de lire depuis '%s'"
+#: builtin/commit.c:1374 builtin/commit.c:1533
+msgid "show untracked files, optional modes: all, normal, no. (Default: all)"
+msgstr ""
+"afficher les fichiers non suivis, \"mode\" facultatif : all (tous), normal, "
+"no. (Défaut : all)"
 
-#: builtin/merge.c:758
-#, c-format
-msgid "Not committing merge; use 'git commit' to complete the merge.\n"
+#: builtin/commit.c:1378
+msgid ""
+"show ignored files, optional modes: traditional, matching, no. (Default: "
+"traditional)"
 msgstr ""
-"Pas de validation de la fusion ; utilisez 'git commit' pour terminer la "
-"fusion.\n"
+"afficher les fichiers ignorés, \"mode\" facultatif : traditional "
+"(traditionnel), matching (correspondant), no. (Défaut : traditional)"
 
-#: builtin/merge.c:764
-#, c-format
+#: builtin/commit.c:1380 parse-options.h:192
+msgid "when"
+msgstr "quand"
+
+#: builtin/commit.c:1381
 msgid ""
-"Please enter a commit message to explain why this merge is necessary,\n"
-"especially if it merges an updated upstream into a topic branch.\n"
-"\n"
-"Lines starting with '%c' will be ignored, and an empty message aborts\n"
-"the commit.\n"
+"ignore changes to submodules, optional when: all, dirty, untracked. "
+"(Default: all)"
 msgstr ""
-"Veuillez entrer un message de validation pour expliquer en quoi cette fusion "
-"est\n"
-"nécessaire, surtout si cela fusionne une branche amont mise à jour dans une "
-"branche de sujet.\n"
-"\n"
-"Les lignes commençant par '%c' seront ignorées, et un message vide\n"
-"abandonne la validation.\n"
+"ignorer les modifications dans les sous-modules, \"quand\" facultatif : all "
+"(tous), dirty (sale), untracked (non suivi). (Défaut : all)"
 
-#: builtin/merge.c:800
-msgid "Empty commit message."
-msgstr "Message de validation vide."
+#: builtin/commit.c:1383
+msgid "list untracked files in columns"
+msgstr "afficher les fichiers non suivis en colonnes"
 
-#: builtin/merge.c:819
-#, c-format
-msgid "Wonderful.\n"
-msgstr "Merveilleux.\n"
+#: builtin/commit.c:1384
+msgid "do not detect renames"
+msgstr "ne pas détecter les renommages"
 
-#: builtin/merge.c:872
-#, c-format
-msgid "Automatic merge failed; fix conflicts and then commit the result.\n"
+#: builtin/commit.c:1386
+msgid "detect renames, optionally set similarity index"
 msgstr ""
-"La fusion automatique a échoué ; réglez les conflits et validez le "
-"résultat.\n"
+"détecter les renommages, en spécifiant optionnellement le facteur de "
+"similarité"
 
-#: builtin/merge.c:911
-msgid "No current branch."
-msgstr "Pas de branche courante."
+#: builtin/commit.c:1406
+msgid "Unsupported combination of ignored and untracked-files arguments"
+msgstr ""
+"Combinaison non supportée d'arguments sur les fichiers ignorés et non-suivis"
 
-#: builtin/merge.c:913
-msgid "No remote for the current branch."
-msgstr "Pas de branche distante pour la branche courante."
+#: builtin/commit.c:1489
+msgid "suppress summary after successful commit"
+msgstr "supprimer le résumé après une validation réussie"
 
-#: builtin/merge.c:915
-msgid "No default upstream defined for the current branch."
-msgstr "Pas de branche amont par défaut définie pour la branche courante."
+#: builtin/commit.c:1490
+msgid "show diff in commit message template"
+msgstr "afficher les diff dans le modèle de message de validation"
 
-#: builtin/merge.c:920
-#, c-format
-msgid "No remote-tracking branch for %s from %s"
-msgstr "Pas de branche de suivi pour %s depuis %s"
+#: builtin/commit.c:1492
+msgid "Commit message options"
+msgstr "Options du message de validation"
 
-#: builtin/merge.c:973
-#, c-format
-msgid "Bad value '%s' in environment '%s'"
-msgstr "Mauvaise valeur '%s' dans l'environnement '%s'"
+#: builtin/commit.c:1493 builtin/merge.c:274 builtin/tag.c:414
+msgid "read message from file"
+msgstr "lire le message depuis un fichier"
 
-#: builtin/merge.c:1075
-#, c-format
-msgid "not something we can merge in %s: %s"
-msgstr "pas possible de fusionner ceci dans %s : %s"
+#: builtin/commit.c:1494
+msgid "author"
+msgstr "auteur"
 
-#: builtin/merge.c:1109
-msgid "not something we can merge"
-msgstr "pas possible de fusionner ceci"
+#: builtin/commit.c:1494
+msgid "override author for commit"
+msgstr "remplacer l'auteur pour la validation"
 
-#: builtin/merge.c:1211
-msgid "--abort expects no arguments"
-msgstr "--abort n'accepte pas d'argument"
+#: builtin/commit.c:1495 builtin/gc.c:538
+msgid "date"
+msgstr "date"
 
-#: builtin/merge.c:1215
-msgid "There is no merge to abort (MERGE_HEAD missing)."
-msgstr "Il n'y a pas de fusion à abandonner (MERGE_HEAD manquant)."
+#: builtin/commit.c:1495
+msgid "override date for commit"
+msgstr "remplacer la date pour la validation"
 
-#: builtin/merge.c:1227
-msgid "--continue expects no arguments"
-msgstr "--continue ne supporte aucun argument"
+#: builtin/commit.c:1497 builtin/commit.c:1498 builtin/commit.c:1499
+#: builtin/commit.c:1500 parse-options.h:328 ref-filter.h:92
+msgid "commit"
+msgstr "commit"
 
-#: builtin/merge.c:1231
-msgid "There is no merge in progress (MERGE_HEAD missing)."
-msgstr "Il n'y a pas de fusion en cours (MERGE_HEAD manquant)."
+#: builtin/commit.c:1497
+msgid "reuse and edit message from specified commit"
+msgstr "réutiliser et éditer le message du commit spécifié"
 
-#: builtin/merge.c:1247
-msgid ""
-"You have not concluded your merge (MERGE_HEAD exists).\n"
-"Please, commit your changes before you merge."
-msgstr ""
-"Vous n'avez pas terminé votre fusion (MERGE_HEAD existe).\n"
-"Veuillez valider vos modifications avant de pouvoir fusionner."
+#: builtin/commit.c:1498
+msgid "reuse message from specified commit"
+msgstr "réutiliser le message du commit spécifié"
 
-#: builtin/merge.c:1254
-msgid ""
-"You have not concluded your cherry-pick (CHERRY_PICK_HEAD exists).\n"
-"Please, commit your changes before you merge."
+#: builtin/commit.c:1499
+msgid "use autosquash formatted message to fixup specified commit"
 msgstr ""
-"Vous n'avez pas terminé votre picorage (CHERRY_PICK_HEAD existe).\n"
-"Veuillez valider vos modifications avant de pouvoir fusionner."
-
-#: builtin/merge.c:1257
-msgid "You have not concluded your cherry-pick (CHERRY_PICK_HEAD exists)."
-msgstr "Vous n'avez pas terminé votre picorage (CHERRY_PICK_HEAD existe)."
+"utiliser un message au format autosquash pour corriger le commit spécifié"
 
-#: builtin/merge.c:1266
-msgid "You cannot combine --squash with --no-ff."
-msgstr "Vous ne pouvez pas combiner --squash avec --no-ff."
+#: builtin/commit.c:1500
+msgid "use autosquash formatted message to squash specified commit"
+msgstr ""
+"utiliser un message au format autosquash pour compresser le commit spécifié"
 
-#: builtin/merge.c:1274
-msgid "No commit specified and merge.defaultToUpstream not set."
+#: builtin/commit.c:1501
+msgid "the commit is authored by me now (used with -C/-c/--amend)"
 msgstr ""
-"Pas de validation spécifiée et merge.defaultToUpstream n'est pas défini."
+"à présent je suis l'auteur de la validation (utilisé avec -C/-c/--amend)"
 
-#: builtin/merge.c:1291
-msgid "Squash commit into empty head not supported yet"
-msgstr "La validation compressée vers une tête vide n'est pas encore supportée"
+#: builtin/commit.c:1502 builtin/log.c:1634 builtin/merge.c:289
+#: builtin/pull.c:164 builtin/revert.c:110
+msgid "add Signed-off-by:"
+msgstr "ajouter une entrée Signed-off-by :"
 
-#: builtin/merge.c:1293
-msgid "Non-fast-forward commit does not make sense into an empty head"
-msgstr "Une validation sans avance rapide n'a pas de sens dans une tête vide"
+#: builtin/commit.c:1503
+msgid "use specified template file"
+msgstr "utiliser le fichier de modèle spécifié"
 
-#: builtin/merge.c:1298
-#, c-format
-msgid "%s - not something we can merge"
-msgstr "%s - pas possible de fusionner ceci"
+#: builtin/commit.c:1504
+msgid "force edit of commit"
+msgstr "forcer l'édition du commit"
 
-#: builtin/merge.c:1300
-msgid "Can merge only exactly one commit into empty head"
-msgstr ""
-"Possible de fusionner exactement une seule validation dans une tête vide"
+#: builtin/commit.c:1506
+msgid "include status in commit message template"
+msgstr "inclure l'état dans le modèle de message de validation"
 
-#: builtin/merge.c:1334
-#, c-format
-msgid "Commit %s has an untrusted GPG signature, allegedly by %s."
-msgstr "La validation %s a une signature GPG non fiable, prétendument par %s."
+#: builtin/commit.c:1511
+msgid "Commit contents options"
+msgstr "Valider les options des contenus"
 
-#: builtin/merge.c:1337
-#, c-format
-msgid "Commit %s has a bad GPG signature allegedly by %s."
-msgstr "La validation %s a une mauvaise signature GPG prétendument par %s."
+#: builtin/commit.c:1512
+msgid "commit all changed files"
+msgstr "valider tous les fichiers modifiés"
 
-#: builtin/merge.c:1340
-#, c-format
-msgid "Commit %s does not have a GPG signature."
-msgstr "La validation %s n'a pas de signature GPG."
+#: builtin/commit.c:1513
+msgid "add specified files to index for commit"
+msgstr "ajouter les fichiers spécifiés à l'index pour la validation"
 
-#: builtin/merge.c:1343
-#, c-format
-msgid "Commit %s has a good GPG signature by %s\n"
-msgstr "La validation %s a une signature GPG correcte par %s\n"
+#: builtin/commit.c:1514
+msgid "interactively add files"
+msgstr "ajouter des fichiers en mode interactif"
 
-#: builtin/merge.c:1402
-msgid "refusing to merge unrelated histories"
-msgstr "refus de fusionner des historiques sans relation"
+#: builtin/commit.c:1515
+msgid "interactively add changes"
+msgstr "ajouter les modifications en mode interactif"
 
-#: builtin/merge.c:1411
-msgid "Already up to date."
-msgstr "Déjà à jour."
+#: builtin/commit.c:1516
+msgid "commit only specified files"
+msgstr "valider seulement les fichiers spécifiés"
 
-#: builtin/merge.c:1421
-#, c-format
-msgid "Updating %s..%s\n"
-msgstr "Mise à jour %s..%s\n"
+#: builtin/commit.c:1517
+msgid "bypass pre-commit and commit-msg hooks"
+msgstr "éviter d'utiliser les crochets pre-commit et commit-msg"
 
-#: builtin/merge.c:1462
-#, c-format
-msgid "Trying really trivial in-index merge...\n"
-msgstr "Essai de fusion vraiment triviale dans l'index...\n"
+#: builtin/commit.c:1518
+msgid "show what would be committed"
+msgstr "afficher ce qui serait validé"
 
-#: builtin/merge.c:1469
-#, c-format
-msgid "Nope.\n"
-msgstr "Non.\n"
+#: builtin/commit.c:1531
+msgid "amend previous commit"
+msgstr "corriger la validation précédente"
 
-#: builtin/merge.c:1494
-msgid "Already up to date. Yeeah!"
-msgstr "Déjà à jour. Ouais !"
+#: builtin/commit.c:1532
+msgid "bypass post-rewrite hook"
+msgstr "éviter d'utiliser le crochet post-rewrite"
 
-#: builtin/merge.c:1500
-msgid "Not possible to fast-forward, aborting."
-msgstr "Pas possible d'avancer rapidement, abandon."
+#: builtin/commit.c:1539
+msgid "ok to record an empty change"
+msgstr "accepter d'enregistrer une modification vide"
 
-#: builtin/merge.c:1523 builtin/merge.c:1602
-#, c-format
-msgid "Rewinding the tree to pristine...\n"
-msgstr "Retour de l'arbre à l'original...\n"
+#: builtin/commit.c:1541
+msgid "ok to record a change with an empty message"
+msgstr "accepter d'enregistrer une modification avec un message vide"
 
-#: builtin/merge.c:1527
+#: builtin/commit.c:1614
 #, c-format
-msgid "Trying merge strategy %s...\n"
-msgstr "Essai de la stratégie de fusion %s...\n"
+msgid "Corrupt MERGE_HEAD file (%s)"
+msgstr "Fichier MERGE_HEAD corrompu (%s)"
 
-#: builtin/merge.c:1593
-#, c-format
-msgid "No merge strategy handled the merge.\n"
-msgstr "Aucune stratégie de fusion n'a pris en charge la fusion.\n"
+#: builtin/commit.c:1621
+msgid "could not read MERGE_MODE"
+msgstr "impossible de lire MERGE_MODE"
 
-#: builtin/merge.c:1595
+#: builtin/commit.c:1640
 #, c-format
-msgid "Merge with strategy %s failed.\n"
-msgstr "La fusion avec la stratégie %s a échoué.\n"
+msgid "could not read commit message: %s"
+msgstr "impossible de lire le message de validation : %s"
 
-#: builtin/merge.c:1604
+#: builtin/commit.c:1647
 #, c-format
-msgid "Using the %s to prepare resolving by hand.\n"
-msgstr "Utilisation de %s pour préparer la résolution à la main.\n"
+msgid "Aborting commit due to empty commit message.\n"
+msgstr "Abandon de la validation dû à un message de validation vide.\n"
 
-#: builtin/merge.c:1616
+#: builtin/commit.c:1652
 #, c-format
-msgid "Automatic merge went well; stopped before committing as requested\n"
-msgstr ""
-"La fusion automatique a réussi ; stoppée avant la validation comme demandé\n"
+msgid "Aborting commit; you did not edit the message.\n"
+msgstr "Abandon de la validation ; vous n'avez pas édité le message\n"
 
-#: builtin/merge-base.c:30
-msgid "git merge-base [-a | --all] <commit> <commit>..."
-msgstr "git merge-base [-a | --all] <commit> <commit>..."
+#: builtin/commit.c:1686
+msgid ""
+"repository has been updated, but unable to write\n"
+"new_index file. Check that disk is not full and quota is\n"
+"not exceeded, and then \"git restore --staged :/\" to recover."
+msgstr ""
+"le dépôt a été mis à jour, mais impossible d'écrire le fichier\n"
+"new_index. Vérifiez que le disque n'est pas plein ou que le quota\n"
+"n'a pas été dépassé, puis lancez \"git restore --staged :/\" pour réparer."
 
-#: builtin/merge-base.c:31
-msgid "git merge-base [-a | --all] --octopus <commit>..."
-msgstr "git merge-base [-a | --all] --octopus <commit>..."
+#: builtin/commit-graph.c:11 builtin/commit-graph.c:17
+msgid ""
+"git commit-graph verify [--object-dir <objdir>] [--shallow] [--[no-]progress]"
+msgstr ""
+"git commit-graph verify [--object-dir <objdir>] [--shallow] [--[no-]progress]"
 
-#: builtin/merge-base.c:32
-msgid "git merge-base --independent <commit>..."
-msgstr "git merge-base --independent <validation>..."
+#: builtin/commit-graph.c:12 builtin/commit-graph.c:22
+msgid ""
+"git commit-graph write [--object-dir <objdir>] [--append|--split] [--"
+"reachable|--stdin-packs|--stdin-commits] [--[no-]progress] <split options>"
+msgstr ""
+"git commit-graph write [--object-dir <répertoire-d'objet>] [--append|--"
+"split] [--reachable|--stdin-packs|--stdin-commits] [--|no-]progress] "
+"<options de division>"
 
-#: builtin/merge-base.c:33
-msgid "git merge-base --is-ancestor <commit> <commit>"
-msgstr "git merge-base --is-ancestor <validation> <validation>"
+#: builtin/commit-graph.c:48 builtin/commit-graph.c:103
+#: builtin/commit-graph.c:187 builtin/fetch.c:179 builtin/log.c:1657
+msgid "dir"
+msgstr "répertoire"
 
-#: builtin/merge-base.c:34
-msgid "git merge-base --fork-point <ref> [<commit>]"
-msgstr "git merge-base --fork-point <référence> [<validation>]"
+#: builtin/commit-graph.c:49 builtin/commit-graph.c:104
+#: builtin/commit-graph.c:188
+msgid "The object directory to store the graph"
+msgstr "Le répertoire d'objet où stocker le graphe"
 
-#: builtin/merge-base.c:220
-msgid "output all common ancestors"
-msgstr "afficher tous les ancêtres communs"
+#: builtin/commit-graph.c:51
+msgid "if the commit-graph is split, only verify the tip file"
+msgstr ""
+"si le graphe de commit est divisé, vérifier seulement le fichier sommet"
 
-#: builtin/merge-base.c:222
-msgid "find ancestors for a single n-way merge"
-msgstr "trouver les ancêtres pour une fusion simple à n points"
+#: builtin/commit-graph.c:73 t/helper/test-read-graph.c:23
+#, c-format
+msgid "Could not open commit-graph '%s'"
+msgstr "impossible d'ouvrir le graphe de commit '%s'"
 
-#: builtin/merge-base.c:224
-msgid "list revs not reachable from others"
-msgstr "afficher les révisions inaccessibles depuis les autres"
+#: builtin/commit-graph.c:106
+msgid "start walk at all refs"
+msgstr "commencer le parcours à toutes les réfs"
 
-#: builtin/merge-base.c:226
-msgid "is the first one ancestor of the other?"
-msgstr "est le premier ancêtre de l'autre ?"
+#: builtin/commit-graph.c:108
+msgid "scan pack-indexes listed by stdin for commits"
+msgstr "scanner les index compactés listés sur stdin à la recherche de commits"
 
-#: builtin/merge-base.c:228
-msgid "find where <commit> forked from reflog of <ref>"
-msgstr "trouver où <validation> a divergé du reflog de <référence>"
+#: builtin/commit-graph.c:110
+msgid "start walk at commits listed by stdin"
+msgstr "commencer le parcours aux commits listés sur stdin"
 
-#: builtin/merge-file.c:9
-msgid ""
-"git merge-file [<options>] [-L <name1> [-L <orig> [-L <name2>]]] <file1> "
-"<orig-file> <file2>"
+#: builtin/commit-graph.c:112
+msgid "include all commits already in the commit-graph file"
 msgstr ""
-"git merge-file [<options>] [-L <nom1> [-L <orig> [-L <nom2>]]] <fichier1> "
-"<fichier-orig> <fichier2>"
+"inclure tous les commits déjà présents dans le fichier de graphe de commits"
 
-#: builtin/merge-file.c:33
-msgid "send results to standard output"
-msgstr "envoyer les résultats sur la sortie standard"
+#: builtin/commit-graph.c:115
+msgid "allow writing an incremental commit-graph file"
+msgstr "permettre d'écrire un fichier incrémental de graphe de commit"
 
-#: builtin/merge-file.c:34
-msgid "use a diff3 based merge"
-msgstr "utiliser une fusion basée sur diff3"
+#: builtin/commit-graph.c:117 builtin/commit-graph.c:121
+msgid "maximum number of commits in a non-base split commit-graph"
+msgstr ""
+"le nombre maximum de commits dans un graphe de commit divisé pas de base"
 
-#: builtin/merge-file.c:35
-msgid "for conflicts, use our version"
-msgstr "pour les conflits, utiliser notre version (our)"
+#: builtin/commit-graph.c:119
+msgid "maximum ratio between two levels of a split commit-graph"
+msgstr "rapport maximum entre deux niveaux d'un graphe de commit divisé"
 
-#: builtin/merge-file.c:37
-msgid "for conflicts, use their version"
-msgstr "pour les conflits, utiliser leur version (their)"
+#: builtin/commit-graph.c:137
+msgid "use at most one of --reachable, --stdin-commits, or --stdin-packs"
+msgstr "utilisez un seul parmi --reachable, --stdin-commits ou --stdin-packs"
 
-#: builtin/merge-file.c:39
-msgid "for conflicts, use a union version"
-msgstr "pour les conflits, utiliser l'ensemble des versions"
+#: builtin/config.c:11
+msgid "git config [<options>]"
+msgstr "git config [<options>]"
 
-#: builtin/merge-file.c:42
-msgid "for conflicts, use this marker size"
-msgstr "pour les conflits, utiliser cette taille de marqueur"
+#: builtin/config.c:103 builtin/env--helper.c:23
+#, c-format
+msgid "unrecognized --type argument, %s"
+msgstr "argument --type non reconnu, %s"
 
-#: builtin/merge-file.c:43
-msgid "do not warn about conflicts"
-msgstr "ne pas avertir à propos des conflits"
+#: builtin/config.c:115
+msgid "only one type at a time"
+msgstr "qu'un seul type à la fois"
 
-#: builtin/merge-file.c:45
-msgid "set labels for file1/orig-file/file2"
-msgstr "définir les labels pour fichier1/fichier-orig/fichier2"
+#: builtin/config.c:124
+msgid "Config file location"
+msgstr "Emplacement du fichier de configuration"
 
-#: builtin/merge-recursive.c:45
-#, c-format
-msgid "unknown option %s"
-msgstr "option inconnue %s"
+#: builtin/config.c:125
+msgid "use global config file"
+msgstr "utiliser les fichier de configuration global"
 
-#: builtin/merge-recursive.c:51
-#, c-format
-msgid "could not parse object '%s'"
-msgstr "Impossible d'analyser l'objet '%s'"
+#: builtin/config.c:126
+msgid "use system config file"
+msgstr "utiliser le fichier de configuration du système"
 
-#: builtin/merge-recursive.c:55
-#, c-format
-msgid "cannot handle more than %d base. Ignoring %s."
-msgid_plural "cannot handle more than %d bases. Ignoring %s."
-msgstr[0] "impossible de gérer plus de %d base. %s ignoré."
-msgstr[1] "impossible de gérer plus de %d bases. %s ignoré."
+#: builtin/config.c:127
+msgid "use repository config file"
+msgstr "utiliser le fichier de configuration du dépôt"
 
-#: builtin/merge-recursive.c:63
-msgid "not handling anything other than two heads merge."
-msgstr "impossible de gérer autre chose que la fusion de deux têtes."
+#: builtin/config.c:128
+msgid "use per-worktree config file"
+msgstr "utiliser un fichier de configuration par arbre de travail"
 
-#: builtin/merge-recursive.c:69 builtin/merge-recursive.c:71
-#, c-format
-msgid "could not resolve ref '%s'"
-msgstr "impossible de résoudre la référence '%s'"
+#: builtin/config.c:129
+msgid "use given config file"
+msgstr "utiliser le fichier de configuration spécifié"
 
-#: builtin/merge-recursive.c:77
-#, c-format
-msgid "Merging %s with %s\n"
-msgstr "Fusion de %s avec %s\n"
+#: builtin/config.c:130
+msgid "blob-id"
+msgstr "blob-id"
 
-#: builtin/mktree.c:65
-msgid "git mktree [-z] [--missing] [--batch]"
-msgstr "git mktree [-z] [--missing] [--batch]"
+#: builtin/config.c:130
+msgid "read config from given blob object"
+msgstr "lire la configuration depuis l'objet blob fourni"
 
-#: builtin/mktree.c:153
-msgid "input is NUL terminated"
-msgstr "l'entrée se termine par NUL"
+#: builtin/config.c:131
+msgid "Action"
+msgstr "Action"
 
-#: builtin/mktree.c:154 builtin/write-tree.c:25
-msgid "allow missing objects"
-msgstr "autoriser les objets manquants"
+#: builtin/config.c:132
+msgid "get value: name [value-regex]"
+msgstr "obtenir la valeur : nom [regex-de-valeur]"
 
-#: builtin/mktree.c:155
-msgid "allow creation of more than one tree"
-msgstr "autoriser la création de plus d'un arbre"
+#: builtin/config.c:133
+msgid "get all values: key [value-regex]"
+msgstr "obtenir toutes les valeurs : clé [regex-de-valeur]"
 
-#: builtin/mv.c:17
-msgid "git mv [<options>] <source>... <destination>"
-msgstr "git mv [<options>] <source>... <destination>"
+#: builtin/config.c:134
+msgid "get values for regexp: name-regex [value-regex]"
+msgstr "obtenir les valeur pour la regexp : regex-de-nom [regex-de-valeur]"
 
-#: builtin/mv.c:82
-#, c-format
-msgid "Directory %s is in index and no submodule?"
-msgstr "Le répertoire %s est dans l'index et pourtant aucun sous-module ?"
+#: builtin/config.c:135
+msgid "get value specific for the URL: section[.var] URL"
+msgstr "obtenir la valeur spécifique pour l'URL : section[.var] URL"
 
-#: builtin/mv.c:84 builtin/rm.c:288
-msgid "Please stage your changes to .gitmodules or stash them to proceed"
+#: builtin/config.c:136
+msgid "replace all matching variables: name value [value_regex]"
 msgstr ""
-"Veuillez indexer vos modifications de .gitmodules ou les remiser pour "
-"continuer"
+"remplacer toutes les variables correspondant : nom valeur [regex-de-valeur]"
 
-#: builtin/mv.c:102
-#, c-format
-msgid "%.*s is in index"
-msgstr "%.*s est dans l'index"
+#: builtin/config.c:137
+msgid "add a new variable: name value"
+msgstr "ajouter une nouvelle variable : nom valeur"
 
-#: builtin/mv.c:124
-msgid "force move/rename even if target exists"
-msgstr "forcer le déplacement/renommage même si la cible existe"
+#: builtin/config.c:138
+msgid "remove a variable: name [value-regex]"
+msgstr "supprimer une variable : nom [regex-de-valeur]"
 
-#: builtin/mv.c:126
-msgid "skip move/rename errors"
-msgstr "sauter les erreurs de déplacement/renommage"
+#: builtin/config.c:139
+msgid "remove all matches: name [value-regex]"
+msgstr "supprimer toutes les correspondances nom [regex-de-valeur]"
 
-#: builtin/mv.c:168
-#, c-format
-msgid "destination '%s' is not a directory"
-msgstr "la destination '%s' n'est pas un répertoire"
+#: builtin/config.c:140
+msgid "rename section: old-name new-name"
+msgstr "renommer une section : ancien-nom nouveau-nom"
 
-#: builtin/mv.c:179
-#, c-format
-msgid "Checking rename of '%s' to '%s'\n"
-msgstr "Vérification du renommage de '%s' en '%s'\n"
+#: builtin/config.c:141
+msgid "remove a section: name"
+msgstr "supprimer une section : nom"
 
-#: builtin/mv.c:183
-msgid "bad source"
-msgstr "mauvaise source"
+#: builtin/config.c:142
+msgid "list all"
+msgstr "afficher tout"
 
-#: builtin/mv.c:186
-msgid "can not move directory into itself"
-msgstr "impossible de déplacer un répertoire dans lui-même"
+#: builtin/config.c:143
+msgid "open an editor"
+msgstr "ouvrir un éditeur"
 
-#: builtin/mv.c:189
-msgid "cannot move directory over file"
-msgstr "impossible de déplacer un répertoire sur un fichier"
+#: builtin/config.c:144
+msgid "find the color configured: slot [default]"
+msgstr "trouver la couleur configurée : slot [par défaut]"
 
-#: builtin/mv.c:198
-msgid "source directory is empty"
-msgstr "le répertoire source est vide"
+#: builtin/config.c:145
+msgid "find the color setting: slot [stdout-is-tty]"
+msgstr "trouver le réglage de la couleur : slot [stdout-est-tty]"
 
-#: builtin/mv.c:223
-msgid "not under version control"
-msgstr "pas sous le contrôle de version"
+#: builtin/config.c:146
+msgid "Type"
+msgstr "Type"
 
-#: builtin/mv.c:226
-msgid "destination exists"
-msgstr "la destination existe"
+#: builtin/config.c:147 builtin/env--helper.c:38
+msgid "value is given this type"
+msgstr "ce type est assigné à la valeur"
 
-#: builtin/mv.c:234
-#, c-format
-msgid "overwriting '%s'"
-msgstr "écrasement de '%s'"
+#: builtin/config.c:148
+msgid "value is \"true\" or \"false\""
+msgstr "la valeur est \"true\" (vrai) ou \"false\" (faux)"
 
-#: builtin/mv.c:237
-msgid "Cannot overwrite"
-msgstr "Impossible d'écraser"
+#: builtin/config.c:149
+msgid "value is decimal number"
+msgstr "la valeur est un nombre décimal"
 
-#: builtin/mv.c:240
-msgid "multiple sources for the same target"
-msgstr "multiples sources pour la même destination"
+#: builtin/config.c:150
+msgid "value is --bool or --int"
+msgstr "la valeur est --bool ou --int"
 
-#: builtin/mv.c:242
-msgid "destination directory does not exist"
-msgstr "le répertoire de destination n'existe pas"
+#: builtin/config.c:151
+msgid "value is a path (file or directory name)"
+msgstr "la valeur est un chemin (vers un fichier ou un répertoire)"
 
-#: builtin/mv.c:249
-#, c-format
-msgid "%s, source=%s, destination=%s"
-msgstr "%s, source=%s, destination=%s"
+#: builtin/config.c:152
+msgid "value is an expiry date"
+msgstr "la valeur est une date d'expiration"
 
-#: builtin/mv.c:270
-#, c-format
-msgid "Renaming %s to %s\n"
-msgstr "Renommage de %s en %s\n"
+#: builtin/config.c:153
+msgid "Other"
+msgstr "Autre"
 
-#: builtin/mv.c:276 builtin/remote.c:715 builtin/repack.c:409
-#, c-format
-msgid "renaming '%s' failed"
-msgstr "le renommage de '%s' a échoué"
+#: builtin/config.c:154
+msgid "terminate values with NUL byte"
+msgstr "terminer les valeurs avec un caractère NUL"
 
-#: builtin/name-rev.c:338
-msgid "git name-rev [<options>] <commit>..."
-msgstr "git name-rev [<options>] <validation>..."
+#: builtin/config.c:155
+msgid "show variable names only"
+msgstr "n'afficher que les noms de variable"
 
-#: builtin/name-rev.c:339
-msgid "git name-rev [<options>] --all"
-msgstr "git name-rev [<options>] --all"
+#: builtin/config.c:156
+msgid "respect include directives on lookup"
+msgstr "respecter les directives d'inclusion lors de la recherche"
 
-#: builtin/name-rev.c:340
-msgid "git name-rev [<options>] --stdin"
-msgstr "git name-rev [<options>] --stdin"
+#: builtin/config.c:157
+msgid "show origin of config (file, standard input, blob, command line)"
+msgstr ""
+"afficher l'origine de la configuration (fichier, entrée standard, blob, "
+"ligne de commande)"
 
-#: builtin/name-rev.c:395
-msgid "print only names (no SHA-1)"
-msgstr "afficher seulement les noms (pas de SHA-1)"
+#: builtin/config.c:158 builtin/env--helper.c:40
+msgid "value"
+msgstr "valeur"
 
-#: builtin/name-rev.c:396
-msgid "only use tags to name the commits"
-msgstr "utiliser seulement les étiquettes pour nommer les validations"
+#: builtin/config.c:158
+msgid "with --get, use default value when missing entry"
+msgstr "avec --get, utiliser le valeur par défaut quand l'entrée n'existe pas"
 
-#: builtin/name-rev.c:398
-msgid "only use refs matching <pattern>"
-msgstr "utiliser seulement les références correspondant à <motif>"
+#: builtin/config.c:172
+#, c-format
+msgid "wrong number of arguments, should be %d"
+msgstr "mauvais nombre d'arguments, devrait être %d"
 
-#: builtin/name-rev.c:400
-msgid "ignore refs matching <pattern>"
-msgstr "ignorer les références correspondant à <motif>"
+#: builtin/config.c:174
+#, c-format
+msgid "wrong number of arguments, should be from %d to %d"
+msgstr "mauvais nombre d'arguments, devrait être entre %d et %d"
 
-#: builtin/name-rev.c:402
-msgid "list all commits reachable from all refs"
-msgstr ""
-"afficher toutes les validations accessibles depuis toutes les références"
+#: builtin/config.c:308
+#, c-format
+msgid "invalid key pattern: %s"
+msgstr "motif de clé invalide : %s"
 
-#: builtin/name-rev.c:403
-msgid "read from stdin"
-msgstr "lire depuis l'entrée standard"
+#: builtin/config.c:344
+#, c-format
+msgid "failed to format default config value: %s"
+msgstr "échec du formatage de la valeur de config par défaut : %s"
 
-#: builtin/name-rev.c:404
-msgid "allow to print `undefined` names (default)"
-msgstr "autoriser l'affichage des noms `non définis` (par défaut)"
+#: builtin/config.c:401
+#, c-format
+msgid "cannot parse color '%s'"
+msgstr "impossible d'analyser la couleur '%s'"
 
-#: builtin/name-rev.c:410
-msgid "dereference tags in the input (internal use)"
-msgstr "déréférencer les étiquettes en entrée (usage interne)"
+#: builtin/config.c:443
+msgid "unable to parse default color value"
+msgstr "impossible de lire la valeur de couleur par défaut"
 
-#: builtin/notes.c:26
-msgid "git notes [--ref <notes-ref>] [list [<object>]]"
-msgstr "git notes [--ref <références-notes>] [list [<object>]]"
+#: builtin/config.c:496 builtin/config.c:742
+msgid "not in a git directory"
+msgstr "pas dans un répertoire git"
+
+#: builtin/config.c:499
+msgid "writing to stdin is not supported"
+msgstr "l'écriture sur stdin n'est pas supportée"
+
+#: builtin/config.c:502
+msgid "writing config blobs is not supported"
+msgstr "l'écriture de blob de configuration n'est pas supportée<"
 
-#: builtin/notes.c:27
+#: builtin/config.c:587
+#, c-format
 msgid ""
-"git notes [--ref <notes-ref>] add [-f] [--allow-empty] [-m <msg> | -F <file> "
-"| (-c | -C) <object>] [<object>]"
+"# This is Git's per-user configuration file.\n"
+"[user]\n"
+"# Please adapt and uncomment the following lines:\n"
+"#\tname = %s\n"
+"#\temail = %s\n"
 msgstr ""
-"git notes [--ref <références-notes>] add [-f] [--allow-empty] [-m <message> "
-"| -F <fichier> | (-c | -C) <objet>] [<objet>]"
+"# Ceci est le fichier de configuration personnel de Git.\n"
+"[user]\n"
+"# Veuillez adapter et décommenter les lignes suivantes :\n"
+"#\tname = %s\n"
+"#\temail = %s\n"
 
-#: builtin/notes.c:28
-msgid "git notes [--ref <notes-ref>] copy [-f] <from-object> <to-object>"
-msgstr ""
-"git notes [--ref <références-notes>] copy [-f] <depuis-objet> <vers-objet>"
+#: builtin/config.c:611
+msgid "only one config file at a time"
+msgstr "un seul fichier de configuration à la fois"
 
-#: builtin/notes.c:29
-msgid ""
-"git notes [--ref <notes-ref>] append [--allow-empty] [-m <msg> | -F <file> | "
-"(-c | -C) <object>] [<object>]"
-msgstr ""
-"git notes [--ref <références-notes>] append [--allow-empty] [-m <message> | -"
-"F <fichier> | (-c | -C) <objet>] [<objet>]"
+#: builtin/config.c:616
+msgid "--local can only be used inside a git repository"
+msgstr "--local ne peut être utilisé qu'à l'intérieur d'un dépôt git"
 
-#: builtin/notes.c:30
-msgid "git notes [--ref <notes-ref>] edit [--allow-empty] [<object>]"
-msgstr "git notes [--ref <références-notes>] edit [--allow-empty] [<objet>]"
+#: builtin/config.c:619
+msgid "--blob can only be used inside a git repository"
+msgstr "--blob ne peut être utilisé qu'à l'intérieur d'un dépôt git"
 
-#: builtin/notes.c:31
-msgid "git notes [--ref <notes-ref>] show [<object>]"
-msgstr "git notes [--ref <références-notes>] show [<objet>]"
+#: builtin/config.c:638
+msgid "$HOME not set"
+msgstr "$HOME n'est pas défini"
 
-#: builtin/notes.c:32
+#: builtin/config.c:658
 msgid ""
-"git notes [--ref <notes-ref>] merge [-v | -q] [-s <strategy>] <notes-ref>"
+"--worktree cannot be used with multiple working trees unless the config\n"
+"extension worktreeConfig is enabled. Please read \"CONFIGURATION FILE\"\n"
+"section in \"git help worktree\" for details"
 msgstr ""
-"git notes [--ref <références-notes>] merge [-v | -q] [-s <stratégie> ] "
-"<références-notes>"
+"--worktree ne peut pas être utilisé avec des arbres de travail multiples\n"
+"à moins que l'extension worktreeConfig soit configuré. Veuillez lire\n"
+"la section \"CONFIGURATION FILE\" de \"git help worktree\" pour plus de "
+"détails"
 
-#: builtin/notes.c:33
-msgid "git notes merge --commit [-v | -q]"
-msgstr "git notes merge --commit [-v | -q]"
+#: builtin/config.c:688
+msgid "--get-color and variable type are incoherent"
+msgstr "--get-color et le type de la variable sont incohérents"
 
-#: builtin/notes.c:34
-msgid "git notes merge --abort [-v | -q]"
-msgstr "git notes merge --abort [-v | -q]"
+#: builtin/config.c:693
+msgid "only one action at a time"
+msgstr "une seule action à la fois"
 
-#: builtin/notes.c:35
-msgid "git notes [--ref <notes-ref>] remove [<object>...]"
-msgstr "git notes [--ref <références-notes>] remove [<objet>...]"
+#: builtin/config.c:706
+msgid "--name-only is only applicable to --list or --get-regexp"
+msgstr "--name-only n'est applicable qu'avec --list ou --get-regexp"
 
-#: builtin/notes.c:36
-msgid "git notes [--ref <notes-ref>] prune [-n] [-v]"
-msgstr "git notes [--ref <référence-notes>] prune [-n] [-v]"
+#: builtin/config.c:712
+msgid ""
+"--show-origin is only applicable to --get, --get-all, --get-regexp, and --"
+"list"
+msgstr ""
+"--show-origin n'est applicable qu'avec --get, --get-all, --get-regexp ou --"
+"list"
 
-#: builtin/notes.c:37
-msgid "git notes [--ref <notes-ref>] get-ref"
-msgstr "git notes [--ref <références-notes>] get-ref"
+#: builtin/config.c:718
+msgid "--default is only applicable to --get"
+msgstr "--default n'est applicable qu'avec --get"
 
-#: builtin/notes.c:42
-msgid "git notes [list [<object>]]"
-msgstr "git notes [list [<objet>]]"
+#: builtin/config.c:731
+#, c-format
+msgid "unable to read config file '%s'"
+msgstr "lecture du fichier de configuration '%s' impossible"
 
-#: builtin/notes.c:47
-msgid "git notes add [<options>] [<object>]"
-msgstr "git notes add [<options>] [<objet>]"
+#: builtin/config.c:734
+msgid "error processing config file(s)"
+msgstr "erreur lors du traitement de fichier(s) de configuration"
 
-#: builtin/notes.c:52
-msgid "git notes copy [<options>] <from-object> <to-object>"
-msgstr "git notes copy [<options>] <depuis-objet> <vers-objet>"
+#: builtin/config.c:744
+msgid "editing stdin is not supported"
+msgstr "l'édition de stdin n'est pas supportée"
 
-#: builtin/notes.c:53
-msgid "git notes copy --stdin [<from-object> <to-object>]..."
-msgstr "git notes copy --stdin [<depuis-objet> <vers-objet>]..."
+#: builtin/config.c:746
+msgid "editing blobs is not supported"
+msgstr "l'édition de blobs n'est pas supportée"
 
-#: builtin/notes.c:58
-msgid "git notes append [<options>] [<object>]"
-msgstr "git notes append [<options>] [<objet>]"
+#: builtin/config.c:760
+#, c-format
+msgid "cannot create configuration file %s"
+msgstr "création impossible du fichier de configuration '%s'"
 
-#: builtin/notes.c:63
-msgid "git notes edit [<object>]"
-msgstr "git notes edit [<objet>]"
+#: builtin/config.c:773
+#, c-format
+msgid ""
+"cannot overwrite multiple values with a single value\n"
+"       Use a regexp, --add or --replace-all to change %s."
+msgstr ""
+"impossible de surcharger des valeurs multiples avec une seule valeur\n"
+"       Utilisez une regexp, --add ou --replace-all pour modifier %s."
 
-#: builtin/notes.c:68
-msgid "git notes show [<object>]"
-msgstr "git notes show [<objet>]"
+#: builtin/config.c:847 builtin/config.c:858
+#, c-format
+msgid "no such section: %s"
+msgstr "section inexistante : %s"
 
-#: builtin/notes.c:73
-msgid "git notes merge [<options>] <notes-ref>"
-msgstr "git notes merge [<options>] <références-notes>"
+#: builtin/count-objects.c:90
+msgid "git count-objects [-v] [-H | --human-readable]"
+msgstr "git count-objects [-v] [-H | --human-readable]"
 
-#: builtin/notes.c:74
-msgid "git notes merge --commit [<options>]"
-msgstr "git notes merge --commit [<options>]"
+#: builtin/count-objects.c:100
+msgid "print sizes in human readable format"
+msgstr "affiche les tailles dans un format humainement lisible"
 
-#: builtin/notes.c:75
-msgid "git notes merge --abort [<options>]"
-msgstr "git notes merge --abort [<options>]"
+#: builtin/describe.c:26
+msgid "git describe [<options>] [<commit-ish>...]"
+msgstr "git describe [<options>] <commit ou apparenté>*"
 
-#: builtin/notes.c:80
-msgid "git notes remove [<object>]"
-msgstr "git notes remove [<objet>]"
+#: builtin/describe.c:27
+msgid "git describe [<options>] --dirty"
+msgstr "git describe [<options>] --dirty"
 
-#: builtin/notes.c:85
-msgid "git notes prune [<options>]"
-msgstr "git notes prune [<options>]"
+#: builtin/describe.c:62
+msgid "head"
+msgstr "tête"
 
-#: builtin/notes.c:90
-msgid "git notes get-ref"
-msgstr "git notes get-ref"
+#: builtin/describe.c:62
+msgid "lightweight"
+msgstr "léger"
 
-#: builtin/notes.c:95
-msgid "Write/edit the notes for the following object:"
-msgstr "Écrire/éditer les notes pour l'objet suivant :"
+#: builtin/describe.c:62
+msgid "annotated"
+msgstr "annoté"
 
-#: builtin/notes.c:148
+#: builtin/describe.c:275
 #, c-format
-msgid "unable to start 'show' for object '%s'"
-msgstr "impossible de démarrer 'show' pour l'objet '%s'"
-
-#: builtin/notes.c:152
-msgid "could not read 'show' output"
-msgstr "impossible de lire la sortie de 'show'"
+msgid "annotated tag %s not available"
+msgstr "l'étiquette annotée %s n'est pas disponible"
 
-#: builtin/notes.c:160
+#: builtin/describe.c:279
 #, c-format
-msgid "failed to finish 'show' for object '%s'"
-msgstr "impossible de finir 'show' pour l'objet '%s'"
-
-#: builtin/notes.c:195
-msgid "please supply the note contents using either -m or -F option"
-msgstr "veuillez fournir le contenu de la note en utilisant l'option -m ou -F"
-
-#: builtin/notes.c:204
-msgid "unable to write note object"
-msgstr "impossible d'écrire l'objet note"
+msgid "annotated tag %s has no embedded name"
+msgstr "l'étiquette annotée %s n'a pas de nom embarqué"
 
-#: builtin/notes.c:206
+#: builtin/describe.c:281
 #, c-format
-msgid "the note contents have been left in %s"
-msgstr "le contenu de la note a été laissé dans %s"
+msgid "tag '%s' is really '%s' here"
+msgstr "l'étiquette '%s' est en fait '%s'"
 
-#: builtin/notes.c:234 builtin/tag.c:507
+#: builtin/describe.c:325
 #, c-format
-msgid "cannot read '%s'"
-msgstr "impossible de lire '%s'"
+msgid "no tag exactly matches '%s'"
+msgstr "aucune étiquette ne correspond parfaitement à '%s'"
 
-#: builtin/notes.c:236 builtin/tag.c:510
+#: builtin/describe.c:327
 #, c-format
-msgid "could not open or read '%s'"
-msgstr "impossible d'ouvrir ou lire '%s'"
+msgid "No exact match on refs or tags, searching to describe\n"
+msgstr ""
+"Pas de correspondance exacte sur des réfs ou des étiquettes, recherche par "
+"describe\n"
 
-#: builtin/notes.c:255 builtin/notes.c:306 builtin/notes.c:308
-#: builtin/notes.c:376 builtin/notes.c:431 builtin/notes.c:517
-#: builtin/notes.c:522 builtin/notes.c:600 builtin/notes.c:662
+#: builtin/describe.c:381
 #, c-format
-msgid "failed to resolve '%s' as a valid ref."
-msgstr "impossible de résoudre '%s' comme une référence valide."
+msgid "finished search at %s\n"
+msgstr "recherche terminée à %s\n"
 
-#: builtin/notes.c:258
+#: builtin/describe.c:407
 #, c-format
-msgid "failed to read object '%s'."
-msgstr "impossible de lire l'objet '%s'."
-
-#: builtin/notes.c:262
+msgid ""
+"No annotated tags can describe '%s'.\n"
+"However, there were unannotated tags: try --tags."
+msgstr ""
+"Aucune étiquette annotée ne peut décrire '%s'.\n"
+"Cependant, il existe des étiquettes non-annotées : essayez avec --tags."
+
+#: builtin/describe.c:411
 #, c-format
-msgid "cannot read note data from non-blob object '%s'."
-msgstr "impossible de lire les informations de note d'un objet non-blob '%s'."
+msgid ""
+"No tags can describe '%s'.\n"
+"Try --always, or create some tags."
+msgstr ""
+"Aucune étiquette ne peut décrire '%s'.\n"
+"Essayez --always, ou créez des étiquettes."
 
-#: builtin/notes.c:302
+#: builtin/describe.c:441
 #, c-format
-msgid "malformed input line: '%s'."
-msgstr "ligne en entrée malformée : '%s'."
+msgid "traversed %lu commits\n"
+msgstr "%lu commits parcourus\n"
 
-#: builtin/notes.c:317
+#: builtin/describe.c:444
 #, c-format
-msgid "failed to copy notes from '%s' to '%s'"
-msgstr "impossible de copier les notes de '%s' vers '%s'"
+msgid ""
+"more than %i tags found; listed %i most recent\n"
+"gave up search at %s\n"
+msgstr ""
+"plus de %i étiquettes ont été trouvées; seules les %i plus récentes sont "
+"affichées\n"
+"abandon de la recherche à %s\n"
 
-#. TRANSLATORS: the first %s will be replaced by a git
-#. notes command: 'add', 'merge', 'remove', etc.
-#.
-#: builtin/notes.c:349
+#: builtin/describe.c:512
 #, c-format
-msgid "refusing to %s notes in %s (outside of refs/notes/)"
-msgstr "Refus de faire %s sur des notes dans %s (hors de refs/notes/)"
+msgid "describe %s\n"
+msgstr "décrire %s\n"
 
-#: builtin/notes.c:369 builtin/notes.c:424 builtin/notes.c:500
-#: builtin/notes.c:512 builtin/notes.c:588 builtin/notes.c:655
-#: builtin/notes.c:805 builtin/notes.c:952 builtin/notes.c:973
-msgid "too many parameters"
-msgstr "trop de paramètres"
+#: builtin/describe.c:515
+#, c-format
+msgid "Not a valid object name %s"
+msgstr "%s n'est pas un nom d'objet valide"
 
-#: builtin/notes.c:382 builtin/notes.c:668
+#: builtin/describe.c:523
 #, c-format
-msgid "no note found for object %s."
-msgstr "pas de note trouvée pour l'objet %s."
+msgid "%s is neither a commit nor blob"
+msgstr "%s n'est ni un commit ni un blob"
 
-#: builtin/notes.c:403 builtin/notes.c:566
-msgid "note contents as a string"
-msgstr "contenu de la note sous forme de chaîne"
+#: builtin/describe.c:537
+msgid "find the tag that comes after the commit"
+msgstr "rechercher l'étiquette qui suit le commit"
 
-#: builtin/notes.c:406 builtin/notes.c:569
-msgid "note contents in a file"
-msgstr "contenu de la note dans un fichier"
+#: builtin/describe.c:538
+msgid "debug search strategy on stderr"
+msgstr "déboguer la stratégie de recherche sur stderr"
 
-#: builtin/notes.c:409 builtin/notes.c:572
-msgid "reuse and edit specified note object"
-msgstr "réutiliser et éditer l'objet de note spécifié"
+#: builtin/describe.c:539
+msgid "use any ref"
+msgstr "utiliser n'importe quelle référence"
 
-#: builtin/notes.c:412 builtin/notes.c:575
-msgid "reuse specified note object"
-msgstr "réutiliser l'objet de note spécifié"
+#: builtin/describe.c:540
+msgid "use any tag, even unannotated"
+msgstr "utiliser n'importe quelle étiquette, même non-annotée"
 
-#: builtin/notes.c:415 builtin/notes.c:578
-msgid "allow storing empty note"
-msgstr "permettre de stocker une note vide"
+#: builtin/describe.c:541
+msgid "always use long format"
+msgstr "toujours utiliser le format long"
 
-#: builtin/notes.c:416 builtin/notes.c:487
-msgid "replace existing notes"
-msgstr "remplacer les notes existantes"
+#: builtin/describe.c:542
+msgid "only follow first parent"
+msgstr "ne suivre que le premier parent"
 
-#: builtin/notes.c:441
-#, c-format
-msgid ""
-"Cannot add notes. Found existing notes for object %s. Use '-f' to overwrite "
-"existing notes"
+#: builtin/describe.c:545
+msgid "only output exact matches"
+msgstr "n'afficher que les correspondances exactes"
+
+#: builtin/describe.c:547
+msgid "consider <n> most recent tags (default: 10)"
 msgstr ""
-"Impossible d'ajouter des notes. Des notes ont été trouvées pour l'objet %s. "
-"Utilisez '-f' pour écraser les notes existantes"
+"considérer uniquement les <n> étiquettes le plus récentes (défaut : 10)"
+
+#: builtin/describe.c:549
+msgid "only consider tags matching <pattern>"
+msgstr "ne considérer que les étiquettes correspondant à <motif>"
+
+#: builtin/describe.c:551
+msgid "do not consider tags matching <pattern>"
+msgstr "ne pas considérer les étiquettes correspondant à <motif>"
+
+#: builtin/describe.c:553 builtin/name-rev.c:473
+msgid "show abbreviated commit object as fallback"
+msgstr "afficher les objets commits abrégés en dernier recours"
+
+#: builtin/describe.c:554 builtin/describe.c:557
+msgid "mark"
+msgstr "marque"
+
+#: builtin/describe.c:555
+msgid "append <mark> on dirty working tree (default: \"-dirty\")"
+msgstr "ajouter <marque> si la copie de travail est sale (défaut : \"-dirty\")"
 
-#: builtin/notes.c:456 builtin/notes.c:535
+#: builtin/describe.c:558
+msgid "append <mark> on broken working tree (default: \"-broken\")"
+msgstr ""
+"ajouter <marque> si la copie de travail est cassée (défaut : \"-broken\")"
+
+#: builtin/describe.c:576
+msgid "--long is incompatible with --abbrev=0"
+msgstr "--long et --abbrev=0 sont incompatibles"
+
+#: builtin/describe.c:605
+msgid "No names found, cannot describe anything."
+msgstr "aucun nom trouvé, impossible de décrire quoi que ce soit."
+
+#: builtin/describe.c:656
+msgid "--dirty is incompatible with commit-ishes"
+msgstr "--dirty est incompatible avec la spécification de commits ou assimilés"
+
+#: builtin/describe.c:658
+msgid "--broken is incompatible with commit-ishes"
+msgstr "--broken est incompatible avec les commits ou assimilés"
+
+#: builtin/diff.c:84
 #, c-format
-msgid "Overwriting existing notes for object %s\n"
-msgstr "Écrasement des notes existantes pour l'objet %s\n"
+msgid "'%s': not a regular file or symlink"
+msgstr "'%s' : n'est pas un fichier régulier ni un lien symbolique"
 
-#: builtin/notes.c:467 builtin/notes.c:627 builtin/notes.c:892
+#: builtin/diff.c:235
 #, c-format
-msgid "Removing note for object %s\n"
-msgstr "Suppression de la note pour l'objet %s\n"
+msgid "invalid option: %s"
+msgstr "option invalide : %s"
 
-#: builtin/notes.c:488
-msgid "read objects from stdin"
-msgstr "lire les objets depuis l'entrée standard"
+#: builtin/diff.c:350
+msgid "Not a git repository"
+msgstr "Ce n'est pas un dépôt git !"
 
-#: builtin/notes.c:490
-msgid "load rewriting config for <command> (implies --stdin)"
-msgstr ""
-"charger la configuration de réécriture pour <commande> (implique --stdin)"
+#: builtin/diff.c:394
+#, c-format
+msgid "invalid object '%s' given."
+msgstr "objet spécifié '%s' invalide."
 
-#: builtin/notes.c:508
-msgid "too few parameters"
-msgstr "pas assez de paramètres"
+#: builtin/diff.c:403
+#, c-format
+msgid "more than two blobs given: '%s'"
+msgstr "plus de deux blobs spécifiés : '%s'"
 
-#: builtin/notes.c:529
+#: builtin/diff.c:408
 #, c-format
-msgid ""
-"Cannot copy notes. Found existing notes for object %s. Use '-f' to overwrite "
-"existing notes"
-msgstr ""
-"Impossible de copier des notes. Des notes ont été trouvées pour l'objet %s. "
-"Utilisez '-f' pour écraser les notes existantes"
+msgid "unhandled object '%s' given."
+msgstr "objet non géré '%s' spécifié."
 
-#: builtin/notes.c:541
+#: builtin/difftool.c:30
+msgid "git difftool [<options>] [<commit> [<commit>]] [--] [<path>...]"
+msgstr "git difftool [<options>] [<commit> [<commit>]] [--] [<chemin>...]"
+
+#: builtin/difftool.c:260
 #, c-format
-msgid "missing notes on source object %s. Cannot copy."
-msgstr "notes manquantes sur l'objet source %s. Impossible de copier."
+msgid "failed: %d"
+msgstr "échec : %d"
+
+#: builtin/difftool.c:302
+#, c-format
+msgid "could not read symlink %s"
+msgstr "lecture du lien symbolique %s impossible"
+
+#: builtin/difftool.c:304
+#, c-format
+msgid "could not read symlink file %s"
+msgstr "impossible de lire le fichier symlink %s"
 
-#: builtin/notes.c:593
+#: builtin/difftool.c:312
 #, c-format
+msgid "could not read object %s for symlink %s"
+msgstr "Impossible de lire l'objet %s pour le symlink %s"
+
+#: builtin/difftool.c:413
 msgid ""
-"The -m/-F/-c/-C options have been deprecated for the 'edit' subcommand.\n"
-"Please use 'git notes add -f -m/-F/-c/-C' instead.\n"
+"combined diff formats('-c' and '--cc') are not supported in\n"
+"directory diff mode('-d' and '--dir-diff')."
 msgstr ""
-"Les options -m/-F/-c/-C sont obsolètes pour la sous-commande 'edit'.\n"
-"Veuillez utiliser 'git notes add -f -m/-F/-c/-C' à la place.\n"
+"les formats de diff combinés ('-c' et '--cc') ne sont pas supportés\n"
+"dans le mode de diff de répertoire ('-d' et '--dir-diff')."
 
-#: builtin/notes.c:688
-msgid "failed to delete ref NOTES_MERGE_PARTIAL"
-msgstr "échec de la suppression de la référence NOTES_MERGE_PARTIAL"
+#: builtin/difftool.c:634
+#, c-format
+msgid "both files modified: '%s' and '%s'."
+msgstr "les deux fichiers sont modifiés : '%s' et '%s'."
 
-#: builtin/notes.c:690
-msgid "failed to delete ref NOTES_MERGE_REF"
-msgstr "échec de la suppression de la référence NOTES_MERGE_REF"
+#: builtin/difftool.c:636
+msgid "working tree file has been left."
+msgstr "le fichier dans l'arbre de travail a été laissé."
 
-#: builtin/notes.c:692
-msgid "failed to remove 'git notes merge' worktree"
-msgstr "échec de la suppression de la copie de travail 'git notes merge'"
+#: builtin/difftool.c:647
+#, c-format
+msgid "temporary files exist in '%s'."
+msgstr "des fichiers temporaires existent dans '%s'."
 
-#: builtin/notes.c:712
-msgid "failed to read ref NOTES_MERGE_PARTIAL"
-msgstr "échec de la lecture de la référence NOTES_MERGE_PARTIAL"
+#: builtin/difftool.c:648
+msgid "you may want to cleanup or recover these."
+msgstr "vous pourriez souhaiter les nettoyer ou les récupérer."
 
-#: builtin/notes.c:714
-msgid "could not find commit from NOTES_MERGE_PARTIAL."
-msgstr "impossible de trouver le commit de NOTES_MERGE_PARTIAL."
+#: builtin/difftool.c:697
+msgid "use `diff.guitool` instead of `diff.tool`"
+msgstr "utiliser `diff.guitool` au lieu de `diff.tool`"
 
-#: builtin/notes.c:716
-msgid "could not parse commit from NOTES_MERGE_PARTIAL."
-msgstr "impossible d'analyser le commit de NOTES_MERGE_PARTIAL."
+#: builtin/difftool.c:699
+msgid "perform a full-directory diff"
+msgstr "réalise un diff de répertoire complet"
 
-#: builtin/notes.c:729
-msgid "failed to resolve NOTES_MERGE_REF"
-msgstr "échec de la résolution de NOTES_MERGE_REF"
+#: builtin/difftool.c:701
+msgid "do not prompt before launching a diff tool"
+msgstr "ne pas confirmer avant de lancer l'outil de diff"
 
-#: builtin/notes.c:732
-msgid "failed to finalize notes merge"
-msgstr "impossible de finaliser la fusion de notes"
+#: builtin/difftool.c:706
+msgid "use symlinks in dir-diff mode"
+msgstr "utiliser les liens symboliques en mode de diff de répertoire"
 
-#: builtin/notes.c:758
-#, c-format
-msgid "unknown notes merge strategy %s"
-msgstr "stratégie de fusion de notes inconnue %s"
+#: builtin/difftool.c:707
+msgid "tool"
+msgstr "outil"
 
-#: builtin/notes.c:774
-msgid "General options"
-msgstr "Options générales"
+#: builtin/difftool.c:708
+msgid "use the specified diff tool"
+msgstr "utiliser l'outil de diff spécifié"
 
-#: builtin/notes.c:776
-msgid "Merge options"
-msgstr "Options de fusion"
+#: builtin/difftool.c:710
+msgid "print a list of diff tools that may be used with `--tool`"
+msgstr "afficher une liste des outils de diff utilisables avec `--tool`"
 
-#: builtin/notes.c:778
+#: builtin/difftool.c:713
 msgid ""
-"resolve notes conflicts using the given strategy (manual/ours/theirs/union/"
-"cat_sort_uniq)"
+"make 'git-difftool' exit when an invoked diff tool returns a non - zero exit "
+"code"
 msgstr ""
-"résoudre les conflits de notes en utilisant la stratégie donnée (manual/ours/"
-"theirs/union/cat_sort_uniq)"
+"provoque la fin de 'git-difftool' si l'outil de diff invoqué renvoie un code "
+"non-nul"
 
-#: builtin/notes.c:780
-msgid "Committing unmerged notes"
-msgstr "Validation des notes non fusionnées"
+#: builtin/difftool.c:716
+msgid "specify a custom command for viewing diffs"
+msgstr "spécifier une commande personnalisée pour visualiser les différences"
 
-#: builtin/notes.c:782
-msgid "finalize notes merge by committing unmerged notes"
-msgstr "finaliser la fusion de notes en validant les notes non fusionnées"
+#: builtin/difftool.c:717
+msgid "passed to `diff`"
+msgstr "passé à `diff`"
+
+#: builtin/difftool.c:732
+msgid "difftool requires worktree or --no-index"
+msgstr "difftool exige un arbre de travail ou --no-index"
+
+#: builtin/difftool.c:739
+msgid "--dir-diff is incompatible with --no-index"
+msgstr "--dir-diff est incompatible avec --no-index"
+
+#: builtin/difftool.c:742
+msgid "--gui, --tool and --extcmd are mutually exclusive"
+msgstr "--gui, --tool et --extcmd sont mutuellement exclusifs"
 
-#: builtin/notes.c:784
-msgid "Aborting notes merge resolution"
-msgstr "Abandon de la résolution de fusion des notes"
+#: builtin/difftool.c:750
+msgid "no <tool> given for --tool=<tool>"
+msgstr "pas d'<outil> spécifié pour --tool=<outil>"
 
-#: builtin/notes.c:786
-msgid "abort notes merge"
-msgstr "abandonner la fusion de notes"
+#: builtin/difftool.c:757
+msgid "no <cmd> given for --extcmd=<cmd>"
+msgstr "pas de <commande> spécifié pour --extcmd=<commande>"
 
-#: builtin/notes.c:797
-msgid "cannot mix --commit, --abort or -s/--strategy"
-msgstr "--commit, --abort et -s/--strategy sont mutuellement incompatibles"
+#: builtin/env--helper.c:6
+msgid "git env--helper --type=[bool|ulong] <options> <env-var>"
+msgstr "git env--helper --type=[bool|ulong] <options> <var d'env>"
 
-#: builtin/notes.c:802
-msgid "must specify a notes ref to merge"
-msgstr "vous devez spécifier une référence de notes à fusionner"
+#: builtin/env--helper.c:37 builtin/hash-object.c:98
+msgid "type"
+msgstr "type"
 
-#: builtin/notes.c:826
-#, c-format
-msgid "unknown -s/--strategy: %s"
-msgstr "-s/--strategy inconnu : %s"
+#: builtin/env--helper.c:41
+msgid "default for git_env_*(...) to fall back on"
+msgstr "valeur par défaut pour git_env_*(...) en cas d'absence"
+
+#: builtin/env--helper.c:43
+msgid "be quiet only use git_env_*() value as exit code"
+msgstr ""
+"mode silencieux n'utilisant la valeur de git_env_*() que pour le code de "
+"sortie"
 
-#: builtin/notes.c:863
+#: builtin/env--helper.c:62
 #, c-format
-msgid "a notes merge into %s is already in-progress at %s"
-msgstr "une fusion de notes dans %s est déjà en cours avec %s"
-
-#: builtin/notes.c:866
-#, c-format
-msgid "failed to store link to current notes ref (%s)"
+msgid "option `--default' expects a boolean value with `--type=bool`, not `%s`"
 msgstr ""
-"impossible de stocker le lien vers la référence actuelle aux notes (%s)"
+"l'option `--default` attend une valeur booléenne avec `--type=bool`, pas `%s`"
 
-#: builtin/notes.c:868
+#: builtin/env--helper.c:77
 #, c-format
 msgid ""
-"Automatic notes merge failed. Fix conflicts in %s and commit the result with "
-"'git notes merge --commit', or abort the merge with 'git notes merge --"
-"abort'.\n"
+"option `--default' expects an unsigned long value with `--type=ulong`, not `"
+"%s`"
 msgstr ""
-"La fusion automatique des notes a échoué. Corrigez les conflits dans %s et "
-"valide le résultat avec 'git notes merges --commit', ou abandonnez la fusion "
-"avec 'git notes merge --abort'.\n"
+"l'option `--default` attend une valeur entier long non signé avec `--"
+"type=ulong`, pas `%s`"
 
-#: builtin/notes.c:890
-#, c-format
-msgid "Object %s has no note\n"
-msgstr "L'objet %s n'a pas de note\n"
+#: builtin/fast-export.c:29
+msgid "git fast-export [rev-list-opts]"
+msgstr "git fast-export [options-de-liste-de-révisions]"
 
-#: builtin/notes.c:902
-msgid "attempt to remove non-existent note is not an error"
+#: builtin/fast-export.c:852
+msgid "Error: Cannot export nested tags unless --mark-tags is specified."
 msgstr ""
-"la tentative de suppression d'une note non existante n'est pas une erreur"
+"Erreur : impossible d'exporter des étiquettes imbriquées à moins que --mark-"
+"tags ne soit spécifié."
 
-#: builtin/notes.c:905
-msgid "read object names from the standard input"
-msgstr "lire les noms d'objet depuis l'entrée standard"
+#: builtin/fast-export.c:1152
+msgid "show progress after <n> objects"
+msgstr "afficher la progression après <n> objets"
 
-#: builtin/notes.c:943 builtin/prune.c:107 builtin/worktree.c:151
-msgid "do not remove, show only"
-msgstr "ne pas supprimer, afficher seulement"
+#: builtin/fast-export.c:1154
+msgid "select handling of signed tags"
+msgstr "sélectionner la gestion des étiquettes signées"
 
-#: builtin/notes.c:944
-msgid "report pruned notes"
-msgstr "afficher les notes éliminées"
+#: builtin/fast-export.c:1157
+msgid "select handling of tags that tag filtered objects"
+msgstr ""
+"sélectionner la gestion des étiquettes qui pointent sur des objets filtrés"
 
-#: builtin/notes.c:986
-msgid "notes-ref"
-msgstr "références-notes"
+#: builtin/fast-export.c:1160
+msgid "select handling of commit messages in an alternate encoding"
+msgstr ""
+"sélectionner la gestion des messages de validation dans un encodage "
+"alternatif"
 
-#: builtin/notes.c:987
-msgid "use notes from <notes-ref>"
-msgstr "utiliser les notes depuis <références-notes>"
+#: builtin/fast-export.c:1163
+msgid "Dump marks to this file"
+msgstr "Enregistrer les marques dans ce fichier"
 
-#: builtin/notes.c:1022
-#, c-format
-msgid "unknown subcommand: %s"
-msgstr "sous-commande inconnue : %s"
+#: builtin/fast-export.c:1165
+msgid "Import marks from this file"
+msgstr "importer les marques depuis ce fichier"
 
-#: builtin/pack-objects.c:48
-msgid ""
-"git pack-objects --stdout [<options>...] [< <ref-list> | < <object-list>]"
-msgstr ""
-"git pack-objects --stdout [options...] [< <liste-références> | < <liste-"
-"objets>]"
+#: builtin/fast-export.c:1169
+msgid "Import marks from this file if it exists"
+msgstr "importer les marques depuis ce fichier s'il existe"
 
-#: builtin/pack-objects.c:49
-msgid ""
-"git pack-objects [<options>...] <base-name> [< <ref-list> | < <object-list>]"
-msgstr ""
-"git pack-objects [options...] base-name [< <liste-références> | < <liste-"
-"objets>]"
+#: builtin/fast-export.c:1171
+msgid "Fake a tagger when tags lack one"
+msgstr "falsifier un auteur d'étiquette si l'étiquette n'en présente pas"
 
-#: builtin/pack-objects.c:211 builtin/pack-objects.c:214
-#, c-format
-msgid "deflate error (%d)"
-msgstr "erreur de compression (%d)"
+#: builtin/fast-export.c:1173
+msgid "Output full tree for each commit"
+msgstr "Afficher l'arbre complet pour chaque commit"
 
-#: builtin/pack-objects.c:810
-msgid "disabling bitmap writing, packs are split due to pack.packSizeLimit"
+#: builtin/fast-export.c:1175
+msgid "Use the done feature to terminate the stream"
+msgstr "Utiliser la fonction \"done\" pour terminer le flux"
+
+#: builtin/fast-export.c:1176
+msgid "Skip output of blob data"
+msgstr "Sauter l'affichage de données de blob"
+
+#: builtin/fast-export.c:1177 builtin/log.c:1705
+msgid "refspec"
+msgstr "spécificateur de référence"
+
+#: builtin/fast-export.c:1178
+msgid "Apply refspec to exported refs"
+msgstr "Appliquer le spécificateur de référence aux références exportées"
+
+#: builtin/fast-export.c:1179
+msgid "anonymize output"
+msgstr "anonymise la sortie"
+
+#: builtin/fast-export.c:1181
+msgid "Reference parents which are not in fast-export stream by object id"
 msgstr ""
-"désactivation de l'écriture en bitmap, les fichiers paquets sont scindés à "
-"cause de pack.packSizeLimit"
+"les parents références qui ne sont pas dans le flux d'export rapide par id "
+"d'objet"
 
-#: builtin/pack-objects.c:823
-msgid "Writing objects"
-msgstr "Écriture des objets"
+#: builtin/fast-export.c:1183
+msgid "Show original object ids of blobs/commits"
+msgstr "Afficher les ids d'objet originaux des blobs/commits"
 
-#: builtin/pack-objects.c:1106
-msgid "disabling bitmap writing, as some objects are not being packed"
+#: builtin/fast-export.c:1185
+msgid "Label tags with mark ids"
+msgstr "Marquer les étiquettes avec des ids de marque"
+
+#: builtin/fast-export.c:1220
+msgid "Cannot pass both --import-marks and --import-marks-if-exists"
 msgstr ""
-"désactivation de l'écriture en bitmap car certains objets ne sont pas "
-"compressés"
+"Impossible d'utiliser à la fois --import-marks et --import-marks-if-exists"
 
-#: builtin/pack-objects.c:1765
-msgid "Counting objects"
-msgstr "Décompte des objets"
+#: builtin/fetch.c:34
+msgid "git fetch [<options>] [<repository> [<refspec>...]]"
+msgstr "git fetch [<options>] [<dépôt> [<spécification-de-référence>...]]"
 
-#: builtin/pack-objects.c:1895
-#, c-format
-msgid "unable to get size of %s"
-msgstr "impossible de récupérer la taille de %s"
+#: builtin/fetch.c:35
+msgid "git fetch [<options>] <group>"
+msgstr "git fetch [<options>] <groupe>"
 
-#: builtin/pack-objects.c:1910
-#, c-format
-msgid "unable to parse object header of %s"
-msgstr "impossible d'analyser l'entête d'objet de %s"
+#: builtin/fetch.c:36
+msgid "git fetch --multiple [<options>] [(<repository> | <group>)...]"
+msgstr "git fetch --multiple [<options>] [(<dépôt> | <groupe>)...]"
 
-#: builtin/pack-objects.c:2564
-msgid "Compressing objects"
-msgstr "Compression des objets"
+#: builtin/fetch.c:37
+msgid "git fetch --all [<options>]"
+msgstr "git fetch --all [<options>]"
 
-#: builtin/pack-objects.c:2735
-msgid "invalid value for --missing"
-msgstr "valeur invalide pour --missing"
+#: builtin/fetch.c:116
+msgid "fetch.parallel cannot be negative"
+msgstr "fetch.parallel ne peut pas être négatif"
 
-#: builtin/pack-objects.c:3067
-#, c-format
-msgid "unsupported index version %s"
-msgstr "version d'index non supportée %s"
+#: builtin/fetch.c:139 builtin/pull.c:204
+msgid "fetch from all remotes"
+msgstr "récupérer depuis tous les dépôts distants"
 
-#: builtin/pack-objects.c:3071
-#, c-format
-msgid "bad index version '%s'"
-msgstr "mauvaise version d'index '%s'"
+#: builtin/fetch.c:141 builtin/pull.c:248
+msgid "set upstream for git pull/fetch"
+msgstr "définir la branche amont pour git pull/fetch"
 
-#: builtin/pack-objects.c:3102
-msgid "do not show progress meter"
-msgstr "ne pas afficher la barre de progression"
+#: builtin/fetch.c:143 builtin/pull.c:207
+msgid "append to .git/FETCH_HEAD instead of overwriting"
+msgstr "ajouter à .git/FETCH_HEAD au lieu de l'écraser"
 
-#: builtin/pack-objects.c:3104
-msgid "show progress meter"
-msgstr "afficher la barre de progression"
+#: builtin/fetch.c:145 builtin/pull.c:210
+msgid "path to upload pack on remote end"
+msgstr "chemin vers lequel télécharger le paquet sur le poste distant"
 
-#: builtin/pack-objects.c:3106
-msgid "show progress meter during object writing phase"
-msgstr "afficher la barre de progression durant la phase d'écrite des objets"
+#: builtin/fetch.c:146
+msgid "force overwrite of local reference"
+msgstr "forcer l'écrasement de la branche locale"
 
-#: builtin/pack-objects.c:3109
-msgid "similar to --all-progress when progress meter is shown"
-msgstr "similaire à --all-progress quand la barre de progression est affichée"
+#: builtin/fetch.c:148
+msgid "fetch from multiple remotes"
+msgstr "récupérer depuis plusieurs dépôts distants"
+
+#: builtin/fetch.c:150 builtin/pull.c:214
+msgid "fetch all tags and associated objects"
+msgstr "récupérer toutes les étiquettes et leurs objets associés"
+
+#: builtin/fetch.c:152
+msgid "do not fetch all tags (--no-tags)"
+msgstr "ne pas récupérer toutes les étiquettes (--no-tags)"
 
-#: builtin/pack-objects.c:3110
-msgid "version[,offset]"
-msgstr "version[,offset]"
+#: builtin/fetch.c:154
+msgid "number of submodules fetched in parallel"
+msgstr "nombre de sous-modules récupérés en parallèle"
 
-#: builtin/pack-objects.c:3111
-msgid "write the pack index file in the specified idx format version"
+#: builtin/fetch.c:156 builtin/pull.c:217
+msgid "prune remote-tracking branches no longer on remote"
 msgstr ""
-"écrire le fichier d'index du paquet dans le format d'index de version "
-"spécifié"
+"éliminer les branches de suivi distant si la branche n'existe plus dans le "
+"dépôt distant"
 
-#: builtin/pack-objects.c:3114
-msgid "maximum size of each output pack file"
-msgstr "taille maximum de chaque fichier paquet en sortie"
+#: builtin/fetch.c:158
+msgid "prune local tags no longer on remote and clobber changed tags"
+msgstr ""
+"éliminer les étiquettes locales qui ont disparu du dépôt distant et qui "
+"encombrent les étiquettes modifiées"
 
-#: builtin/pack-objects.c:3116
-msgid "ignore borrowed objects from alternate object store"
-msgstr "ignorer les objets empruntés à un autre magasin d'objets"
+#: builtin/fetch.c:159 builtin/fetch.c:182 builtin/pull.c:141
+msgid "on-demand"
+msgstr "à la demande"
 
-#: builtin/pack-objects.c:3118
-msgid "ignore packed objects"
-msgstr "ignorer les objets empaquetés"
+#: builtin/fetch.c:160
+msgid "control recursive fetching of submodules"
+msgstr "contrôler la récupération récursive dans les sous-modules"
 
-#: builtin/pack-objects.c:3120
-msgid "limit pack window by objects"
-msgstr "limiter la fenêtre d'empaquetage par objets"
+#: builtin/fetch.c:164 builtin/pull.c:225
+msgid "keep downloaded pack"
+msgstr "conserver le paquet téléchargé"
 
-#: builtin/pack-objects.c:3122
-msgid "limit pack window by memory in addition to object limit"
-msgstr ""
-"limiter la fenêtre d'empaquetage par mémoire en plus de la limite d'objets"
+#: builtin/fetch.c:166
+msgid "allow updating of HEAD ref"
+msgstr "permettre la mise à jour de la référence HEAD"
 
-#: builtin/pack-objects.c:3124
-msgid "maximum length of delta chain allowed in the resulting pack"
+#: builtin/fetch.c:169 builtin/fetch.c:175 builtin/pull.c:228
+msgid "deepen history of shallow clone"
+msgstr "approfondir l'historique d'un clone superficiel"
+
+#: builtin/fetch.c:171
+msgid "deepen history of shallow repository based on time"
+msgstr "approfondir l'historique d'un clone superficiel en fonction d'une date"
+
+#: builtin/fetch.c:177 builtin/pull.c:231
+msgid "convert to a complete repository"
+msgstr "convertir en un dépôt complet"
+
+#: builtin/fetch.c:180
+msgid "prepend this to submodule path output"
+msgstr "préfixer ceci à la sortie du chemin du sous-module"
+
+#: builtin/fetch.c:183
+msgid ""
+"default for recursive fetching of submodules (lower priority than config "
+"files)"
 msgstr ""
-"longueur maximum de la chaîne de delta autorisée dans le paquet résultant"
+"par défaut pour la récupération récursive de sous-modules (priorité plus "
+"basse que les fichiers de config)"
 
-#: builtin/pack-objects.c:3126
-msgid "reuse existing deltas"
-msgstr "réutiliser les deltas existants"
+#: builtin/fetch.c:187 builtin/pull.c:234
+msgid "accept refs that update .git/shallow"
+msgstr "accepter les références qui mettent à jour .git/shallow"
 
-#: builtin/pack-objects.c:3128
-msgid "reuse existing objects"
-msgstr "réutiliser les objets existants"
+#: builtin/fetch.c:188 builtin/pull.c:236
+msgid "refmap"
+msgstr "correspondance de référence"
 
-#: builtin/pack-objects.c:3130
-msgid "use OFS_DELTA objects"
-msgstr "utiliser les objets OFS_DELTA"
+#: builtin/fetch.c:189 builtin/pull.c:237
+msgid "specify fetch refmap"
+msgstr "spécifier une correspondance de référence pour la récupération"
 
-#: builtin/pack-objects.c:3132
-msgid "use threads when searching for best delta matches"
+#: builtin/fetch.c:196
+msgid "report that we have only objects reachable from this object"
+msgstr "rapporte que nous n'avons que des objets joignables depuis cet objet"
+
+#: builtin/fetch.c:199
+msgid "run 'gc --auto' after fetching"
+msgstr "lancer 'gc --auto' après la récupération"
+
+#: builtin/fetch.c:201 builtin/pull.c:246
+msgid "check for forced-updates on all updated branches"
+msgstr "vérifier les mises à jour forcées sur toutes les branches mises à jour"
+
+#: builtin/fetch.c:203
+msgid "write the commit-graph after fetching"
+msgstr "écrire le graphe de commits après le rapatriement"
+
+#: builtin/fetch.c:513
+msgid "Couldn't find remote ref HEAD"
+msgstr "impossible de trouver la référence HEAD distante"
+
+#: builtin/fetch.c:653
+#, c-format
+msgid "configuration fetch.output contains invalid value %s"
 msgstr ""
-"utiliser des fils lors de la recherche pour une meilleurs correspondance des "
-"deltas"
+"le paramètre de configuration fetch.output contient une valeur invalide %s"
 
-#: builtin/pack-objects.c:3134
-msgid "do not create an empty pack output"
-msgstr "ne pas créer un paquet vide"
+#: builtin/fetch.c:751
+#, c-format
+msgid "object %s not found"
+msgstr "objet %s non trouvé"
 
-#: builtin/pack-objects.c:3136
-msgid "read revision arguments from standard input"
-msgstr "lire les paramètres de révision depuis l'entrée standard"
+#: builtin/fetch.c:755
+msgid "[up to date]"
+msgstr "[à jour]"
 
-#: builtin/pack-objects.c:3138
-msgid "limit the objects to those that are not yet packed"
-msgstr "limiter les objets à ceux qui ne sont pas encore empaquetés"
+#: builtin/fetch.c:768 builtin/fetch.c:784 builtin/fetch.c:856
+msgid "[rejected]"
+msgstr "[rejeté]"
 
-#: builtin/pack-objects.c:3141
-msgid "include objects reachable from any reference"
-msgstr "inclure les objets accessibles depuis toute référence"
+#: builtin/fetch.c:769
+msgid "can't fetch in current branch"
+msgstr "impossible de récupérer dans la branche actuelle"
 
-#: builtin/pack-objects.c:3144
-msgid "include objects referred by reflog entries"
-msgstr "inclure les objets référencés par les éléments de reflog"
+#: builtin/fetch.c:779
+msgid "[tag update]"
+msgstr "[mise à jour de l'étiquette]"
 
-#: builtin/pack-objects.c:3147
-msgid "include objects referred to by the index"
-msgstr "inclure les objets référencés par l'index"
+#: builtin/fetch.c:780 builtin/fetch.c:817 builtin/fetch.c:839
+#: builtin/fetch.c:851
+msgid "unable to update local ref"
+msgstr "impossible de mettre à jour la référence locale"
 
-#: builtin/pack-objects.c:3150
-msgid "output pack to stdout"
-msgstr "afficher l'empaquetage sur la sortie standard"
+#: builtin/fetch.c:784
+msgid "would clobber existing tag"
+msgstr "écraserait l'étiquette existante"
 
-#: builtin/pack-objects.c:3152
-msgid "include tag objects that refer to objects to be packed"
-msgstr "inclure les objets d'étiquettes qui réfèrent à des objets à empaqueter"
+#: builtin/fetch.c:806
+msgid "[new tag]"
+msgstr "[nouvelle étiquette]"
 
-#: builtin/pack-objects.c:3154
-msgid "keep unreachable objects"
-msgstr "garder les objets inaccessibles"
+#: builtin/fetch.c:809
+msgid "[new branch]"
+msgstr "[nouvelle branche]"
 
-#: builtin/pack-objects.c:3156
-msgid "pack loose unreachable objects"
-msgstr "empaqueter les objets inaccessibles détachés"
+#: builtin/fetch.c:812
+msgid "[new ref]"
+msgstr "[nouvelle référence]"
 
-#: builtin/pack-objects.c:3158
-msgid "unpack unreachable objects newer than <time>"
-msgstr "dépaqueter les objets inaccessibles plus récents que <heure>"
+#: builtin/fetch.c:851
+msgid "forced update"
+msgstr "mise à jour forcée"
 
-#: builtin/pack-objects.c:3161
-msgid "create thin packs"
-msgstr "créer des paquets légers"
+#: builtin/fetch.c:856
+msgid "non-fast-forward"
+msgstr "pas en avance rapide"
 
-#: builtin/pack-objects.c:3163
-msgid "create packs suitable for shallow fetches"
-msgstr "créer des paquets permettant des récupérations superficielles"
+#: builtin/fetch.c:877
+msgid ""
+"Fetch normally indicates which branches had a forced update,\n"
+"but that check has been disabled. To re-enable, use '--show-forced-updates'\n"
+"flag or run 'git config fetch.showForcedUpdates true'."
+msgstr ""
+"Fetch indique normalement quelles branches ont subi une mise à jour forcée,\n"
+"mais ceci a été désactivé. Pour ré-activer, utilisez le drapeau\n"
+"'--show-forced-update' ou lancez 'git config fetch.showForcedUpdates true'."
+
+#: builtin/fetch.c:881
+#, c-format
+msgid ""
+"It took %.2f seconds to check forced updates. You can use\n"
+"'--no-show-forced-updates' or run 'git config fetch.showForcedUpdates "
+"false'\n"
+" to avoid this check.\n"
+msgstr ""
+"%.2f secondes ont été nécessaires pour vérifier les mises à jour forcées.\n"
+"Vous pouvez utiliser '--no-show-forced-update' ou lancer\n"
+"'git config fetch.showForcedUpdates false' pour éviter ceci.\n"
+
+#: builtin/fetch.c:911
+#, c-format
+msgid "%s did not send all necessary objects\n"
+msgstr "%s n'a pas envoyé tous les objets nécessaires\n"
+
+#: builtin/fetch.c:932
+#, c-format
+msgid "reject %s because shallow roots are not allowed to be updated"
+msgstr ""
+"%s rejeté parce que les racines superficielles ne sont pas mises à jour"
+
+#: builtin/fetch.c:1017 builtin/fetch.c:1155
+#, c-format
+msgid "From %.*s\n"
+msgstr "Depuis %.*s\n"
+
+#: builtin/fetch.c:1028
+#, c-format
+msgid ""
+"some local refs could not be updated; try running\n"
+" 'git remote prune %s' to remove any old, conflicting branches"
+msgstr ""
+"des références locales n'ont pas pu être mises à jour ; essayez de lancer\n"
+" 'git remote prune %s' pour supprimer des branches anciennes en conflit"
+
+#: builtin/fetch.c:1125
+#, c-format
+msgid "   (%s will become dangling)"
+msgstr "   (%s sera en suspens)"
+
+#: builtin/fetch.c:1126
+#, c-format
+msgid "   (%s has become dangling)"
+msgstr "   (%s est devenu en suspens)"
+
+#: builtin/fetch.c:1158
+msgid "[deleted]"
+msgstr "[supprimé]"
+
+#: builtin/fetch.c:1159 builtin/remote.c:1035
+msgid "(none)"
+msgstr "(aucun(e))"
+
+#: builtin/fetch.c:1182
+#, c-format
+msgid "Refusing to fetch into current branch %s of non-bare repository"
+msgstr "Refus de récupérer dans la branche courant %s d'un dépôt non nu"
+
+#: builtin/fetch.c:1201
+#, c-format
+msgid "Option \"%s\" value \"%s\" is not valid for %s"
+msgstr "La valeur \"%2$s\" de l'option \"%1$s\" est invalide pour %3$s"
+
+#: builtin/fetch.c:1204
+#, c-format
+msgid "Option \"%s\" is ignored for %s\n"
+msgstr "L'option \"%s\" est ignorée pour %s\n"
+
+#: builtin/fetch.c:1412
+msgid "multiple branches detected, incompatible with --set-upstream"
+msgstr "branches multiples détectées, imcompatible avec --set-upstream"
+
+#: builtin/fetch.c:1427
+msgid "not setting upstream for a remote remote-tracking branch"
+msgstr "dépôt amont non défini pour la branche de suivi à distance"
+
+#: builtin/fetch.c:1429
+msgid "not setting upstream for a remote tag"
+msgstr "dépôt amont non défini pour l'étiquette distante"
+
+#: builtin/fetch.c:1431
+msgid "unknown branch type"
+msgstr "type de branche inconnu"
+
+#: builtin/fetch.c:1433
+msgid ""
+"no source branch found.\n"
+"you need to specify exactly one branch with the --set-upstream option."
+msgstr ""
+"Aucune branche source trouvée.\n"
+"Vous devez spécifier exactement une branche avec l'option --set-upstream."
+
+#: builtin/fetch.c:1559 builtin/fetch.c:1622
+#, c-format
+msgid "Fetching %s\n"
+msgstr "Récupération de %s\n"
+
+#: builtin/fetch.c:1569 builtin/fetch.c:1624 builtin/remote.c:100
+#, c-format
+msgid "Could not fetch %s"
+msgstr "Impossible de récupérer %s"
+
+#: builtin/fetch.c:1581
+#, c-format
+msgid "could not fetch '%s' (exit code: %d)\n"
+msgstr "impossible de récupérer '%s' (code de sortie : %d)\n"
+
+#: builtin/fetch.c:1684
+msgid ""
+"No remote repository specified.  Please, specify either a URL or a\n"
+"remote name from which new revisions should be fetched."
+msgstr ""
+"Aucun dépôt distant spécifié. Veuillez spécifier une URL ou un nom\n"
+"distant depuis lesquels les nouvelles révisions devraient être récupérées."
+
+#: builtin/fetch.c:1721
+msgid "You need to specify a tag name."
+msgstr "Vous devez spécifier un nom d'étiquette."
+
+#: builtin/fetch.c:1771
+msgid "Negative depth in --deepen is not supported"
+msgstr "Une profondeur négative dans --deepen n'est pas supportée"
+
+#: builtin/fetch.c:1773
+msgid "--deepen and --depth are mutually exclusive"
+msgstr "--deepen et --depth sont mutuellement exclusifs"
+
+#: builtin/fetch.c:1778
+msgid "--depth and --unshallow cannot be used together"
+msgstr "--depth et --unshallow ne peuvent pas être utilisés ensemble"
+
+#: builtin/fetch.c:1780
+msgid "--unshallow on a complete repository does not make sense"
+msgstr "--unshallow sur un dépôt complet n'a pas de sens"
+
+#: builtin/fetch.c:1796
+msgid "fetch --all does not take a repository argument"
+msgstr "fetch --all n'accepte pas d'argument de dépôt"
+
+#: builtin/fetch.c:1798
+msgid "fetch --all does not make sense with refspecs"
+msgstr "fetch --all n'a pas de sens avec des spécifications de référence"
+
+#: builtin/fetch.c:1807
+#, c-format
+msgid "No such remote or remote group: %s"
+msgstr "distant ou groupe distant inexistant : %s"
+
+#: builtin/fetch.c:1814
+msgid "Fetching a group and specifying refspecs does not make sense"
+msgstr ""
+"La récupération d'un groupe et les spécifications de référence n'ont pas de "
+"sens"
+
+#: builtin/fetch.c:1832
+msgid ""
+"--filter can only be used with the remote configured in extensions."
+"partialclone"
+msgstr ""
+"--filter ne peut être utilisé qu'avec le dépôt distant configuré dans "
+"extensions.partialClone"
+
+#: builtin/fmt-merge-msg.c:18
+msgid ""
+"git fmt-merge-msg [-m <message>] [--log[=<n>] | --no-log] [--file <file>]"
+msgstr ""
+"git fmt-merge-msg [-m <message>] [--log[=<n>] | --no-log] [--file <fichier>]"
+
+#: builtin/fmt-merge-msg.c:674
+msgid "populate log with at most <n> entries from shortlog"
+msgstr "peupler le journal avec au plus <n> éléments depuis le journal court"
+
+#: builtin/fmt-merge-msg.c:677
+msgid "alias for --log (deprecated)"
+msgstr "alias pour --log (obsolète)"
+
+#: builtin/fmt-merge-msg.c:680
+msgid "text"
+msgstr "texte"
+
+#: builtin/fmt-merge-msg.c:681
+msgid "use <text> as start of message"
+msgstr "utiliser <texte> comme début de message"
+
+#: builtin/fmt-merge-msg.c:682
+msgid "file to read from"
+msgstr "fichier d'où lire"
+
+#: builtin/for-each-ref.c:10
+msgid "git for-each-ref [<options>] [<pattern>]"
+msgstr "git for-each-ref [<options>] [<motif>]"
+
+#: builtin/for-each-ref.c:11
+msgid "git for-each-ref [--points-at <object>]"
+msgstr "git for-each-ref [--points-at <objet>]"
+
+#: builtin/for-each-ref.c:12
+msgid "git for-each-ref [(--merged | --no-merged) [<commit>]]"
+msgstr "git for-each-ref [(--merged | --no-merged) [<commit>]]"
+
+#: builtin/for-each-ref.c:13
+msgid "git for-each-ref [--contains [<commit>]] [--no-contains [<commit>]]"
+msgstr "git for-each-ref [--contains [<commit>]] [--no-contains [<commit>]]"
+
+#: builtin/for-each-ref.c:28
+msgid "quote placeholders suitably for shells"
+msgstr "échapper les champs réservés pour les interpréteurs de commandes"
+
+#: builtin/for-each-ref.c:30
+msgid "quote placeholders suitably for perl"
+msgstr "échapper les champs réservés pour perl"
+
+#: builtin/for-each-ref.c:32
+msgid "quote placeholders suitably for python"
+msgstr "échapper les champs réservés pour python"
+
+#: builtin/for-each-ref.c:34
+msgid "quote placeholders suitably for Tcl"
+msgstr "échapper les champs réservés pour compatibilité avec Tcl"
+
+#: builtin/for-each-ref.c:37
+msgid "show only <n> matched refs"
+msgstr "n'afficher que <n> références correspondant"
+
+#: builtin/for-each-ref.c:39 builtin/tag.c:439
+msgid "respect format colors"
+msgstr "respecter les couleurs de formatage"
+
+#: builtin/for-each-ref.c:42
+msgid "print only refs which points at the given object"
+msgstr "afficher seulement les références pointant sur l'objet"
+
+#: builtin/for-each-ref.c:44
+msgid "print only refs that are merged"
+msgstr "afficher seulement les références qui sont fusionnées"
+
+#: builtin/for-each-ref.c:45
+msgid "print only refs that are not merged"
+msgstr "afficher seulement les références qui ne sont pas fusionnées"
+
+#: builtin/for-each-ref.c:46
+msgid "print only refs which contain the commit"
+msgstr "afficher seulement les références qui contiennent le commit"
+
+#: builtin/for-each-ref.c:47
+msgid "print only refs which don't contain the commit"
+msgstr "afficher seulement les références qui ne contiennent pas le commit"
+
+#: builtin/fsck.c:68 builtin/fsck.c:147 builtin/fsck.c:148
+msgid "unknown"
+msgstr "inconnu"
+
+#. TRANSLATORS: e.g. error in tree 01bfda: <more explanation>
+#: builtin/fsck.c:100 builtin/fsck.c:120
+#, c-format
+msgid "error in %s %s: %s"
+msgstr "erreur dans l'objet %s %s : %s"
+
+#. TRANSLATORS: e.g. warning in tree 01bfda: <more explanation>
+#: builtin/fsck.c:114
+#, c-format
+msgid "warning in %s %s: %s"
+msgstr "avertissement dans l'objet %s %s : %s"
+
+#: builtin/fsck.c:143 builtin/fsck.c:146
+#, c-format
+msgid "broken link from %7s %s"
+msgstr "lien cassé dans l'objet %7s %s"
+
+#: builtin/fsck.c:155
+msgid "wrong object type in link"
+msgstr "type d'objet inconnu dans le lien"
+
+#: builtin/fsck.c:171
+#, c-format
+msgid ""
+"broken link from %7s %s\n"
+"              to %7s %s"
+msgstr ""
+"lien cassé depuis %7s %s\n"
+"             vers %7s %s"
+
+#: builtin/fsck.c:282
+#, c-format
+msgid "missing %s %s"
+msgstr "objet %s manquant %s"
+
+#: builtin/fsck.c:309
+#, c-format
+msgid "unreachable %s %s"
+msgstr "objet %s inatteignable %s"
+
+#: builtin/fsck.c:329
+#, c-format
+msgid "dangling %s %s"
+msgstr "objet %s fantôme %s"
+
+#: builtin/fsck.c:339
+msgid "could not create lost-found"
+msgstr "impossible de créer le fichier lost-found"
+
+#: builtin/fsck.c:350
+#, c-format
+msgid "could not finish '%s'"
+msgstr "impossible de finir '%s'"
+
+#: builtin/fsck.c:367
+#, c-format
+msgid "Checking %s"
+msgstr "Vérification de l'objet %s"
+
+#: builtin/fsck.c:405
+#, c-format
+msgid "Checking connectivity (%d objects)"
+msgstr "Vérification de la connectivité (%d objets)"
+
+#: builtin/fsck.c:424
+#, c-format
+msgid "Checking %s %s"
+msgstr "Vérification de l'objet %s %s"
+
+#: builtin/fsck.c:429
+msgid "broken links"
+msgstr "liens cassés"
+
+#: builtin/fsck.c:438
+#, c-format
+msgid "root %s"
+msgstr "racine %s"
+
+#: builtin/fsck.c:446
+#, c-format
+msgid "tagged %s %s (%s) in %s"
+msgstr "étiquetage de l'objet %s %s (%s) dans %s"
+
+#: builtin/fsck.c:475
+#, c-format
+msgid "%s: object corrupt or missing"
+msgstr "%s : objet corrompu ou manquant"
+
+#: builtin/fsck.c:500
+#, c-format
+msgid "%s: invalid reflog entry %s"
+msgstr "%s : entrée %s de journal de références invalide"
+
+#: builtin/fsck.c:514
+#, c-format
+msgid "Checking reflog %s->%s"
+msgstr "Vérification du journal de réferences %s-> %s"
+
+#: builtin/fsck.c:548
+#, c-format
+msgid "%s: invalid sha1 pointer %s"
+msgstr "%s : pointeur de sha1 invalide %s"
+
+#: builtin/fsck.c:555
+#, c-format
+msgid "%s: not a commit"
+msgstr "l'objet %s n'est pas un commit"
+
+#: builtin/fsck.c:609
+msgid "notice: No default references"
+msgstr "Note : pas de référence par défaut"
+
+#: builtin/fsck.c:624
+#, c-format
+msgid "%s: object corrupt or missing: %s"
+msgstr "%s : objet corrompu ou manquant : %s"
+
+#: builtin/fsck.c:637
+#, c-format
+msgid "%s: object could not be parsed: %s"
+msgstr "%s : impossible d'analyser : %s"
+
+#: builtin/fsck.c:657
+#, c-format
+msgid "bad sha1 file: %s"
+msgstr "mauvais fichier de sha1 : %s"
+
+#: builtin/fsck.c:672
+msgid "Checking object directory"
+msgstr "Vérification du répertoire d'objet"
+
+#: builtin/fsck.c:675
+msgid "Checking object directories"
+msgstr "Vérification des répertoires d'objet"
+
+#: builtin/fsck.c:690
+#, c-format
+msgid "Checking %s link"
+msgstr "Vérification du lien %s"
+
+#: builtin/fsck.c:695 builtin/index-pack.c:842
+#, c-format
+msgid "invalid %s"
+msgstr "%s invalide"
+
+#: builtin/fsck.c:702
+#, c-format
+msgid "%s points to something strange (%s)"
+msgstr "%s pointe sur quelque chose bizarre (%s)"
+
+#: builtin/fsck.c:708
+#, c-format
+msgid "%s: detached HEAD points at nothing"
+msgstr "%s : la HEAD détachée ne pointe sur rien"
+
+#: builtin/fsck.c:712
+#, c-format
+msgid "notice: %s points to an unborn branch (%s)"
+msgstr "note : %s pointe sur une branche non-née (%s)"
+
+#: builtin/fsck.c:724
+msgid "Checking cache tree"
+msgstr "Vérification de l'arbre cache"
+
+#: builtin/fsck.c:729
+#, c-format
+msgid "%s: invalid sha1 pointer in cache-tree"
+msgstr "%s : pointer sha1 invalide dans l'arbre de cache"
+
+#: builtin/fsck.c:738
+msgid "non-tree in cache-tree"
+msgstr "non-arbre dans l'arbre de cache"
+
+#: builtin/fsck.c:769
+msgid "git fsck [<options>] [<object>...]"
+msgstr "git fsck [<options>] [<objet>...]"
+
+#: builtin/fsck.c:775
+msgid "show unreachable objects"
+msgstr "afficher les objets inaccessibles"
+
+#: builtin/fsck.c:776
+msgid "show dangling objects"
+msgstr "afficher les objets en suspens"
+
+#: builtin/fsck.c:777
+msgid "report tags"
+msgstr "afficher les étiquettes"
+
+#: builtin/fsck.c:778
+msgid "report root nodes"
+msgstr "signaler les nœuds racines"
+
+#: builtin/fsck.c:779
+msgid "make index objects head nodes"
+msgstr "considérer les objets de l'index comme nœuds tête"
+
+# translated from man page
+#: builtin/fsck.c:780
+msgid "make reflogs head nodes (default)"
+msgstr "considérer les reflogs comme nœuds tête (par défaut)"
+
+#: builtin/fsck.c:781
+msgid "also consider packs and alternate objects"
+msgstr "inspecter aussi les objets pack et alternatifs"
+
+#: builtin/fsck.c:782
+msgid "check only connectivity"
+msgstr "ne vérifier que la connectivité"
+
+#: builtin/fsck.c:783
+msgid "enable more strict checking"
+msgstr "activer une vérification plus strict"
+
+#: builtin/fsck.c:785
+msgid "write dangling objects in .git/lost-found"
+msgstr "écrire les objets en suspens dans .git/lost-found"
+
+#: builtin/fsck.c:786 builtin/prune.c:132
+msgid "show progress"
+msgstr "afficher la progression"
+
+#: builtin/fsck.c:787
+msgid "show verbose names for reachable objects"
+msgstr "afficher les noms étendus pour les objets inaccessibles"
+
+#: builtin/fsck.c:846 builtin/index-pack.c:225
+msgid "Checking objects"
+msgstr "Vérification des objets"
+
+#: builtin/fsck.c:874
+#, c-format
+msgid "%s: object missing"
+msgstr "%s : objet manquant"
+
+#: builtin/fsck.c:885
+#, c-format
+msgid "invalid parameter: expected sha1, got '%s'"
+msgstr "paramètre invalide : sha-1 attendu, '%s' trouvé"
+
+#: builtin/gc.c:35
+msgid "git gc [<options>]"
+msgstr "git gc [<options>]"
+
+#: builtin/gc.c:90
+#, c-format
+msgid "Failed to fstat %s: %s"
+msgstr "Échec du stat de %s : %s"
+
+#: builtin/gc.c:126
+#, c-format
+msgid "failed to parse '%s' value '%s'"
+msgstr "échec de l'analyse de '%s' valeur '%s'"
+
+#: builtin/gc.c:475 builtin/init-db.c:55
+#, c-format
+msgid "cannot stat '%s'"
+msgstr "impossible de faire un stat de '%s'"
+
+#: builtin/gc.c:484 builtin/notes.c:240 builtin/tag.c:529
+#, c-format
+msgid "cannot read '%s'"
+msgstr "impossible de lire '%s'"
+
+#: builtin/gc.c:491
+#, c-format
+msgid ""
+"The last gc run reported the following. Please correct the root cause\n"
+"and remove %s.\n"
+"Automatic cleanup will not be performed until the file is removed.\n"
+"\n"
+"%s"
+msgstr ""
+"Le dernier lancement de gc a rapporté l'erreur suivante. Veuillez corriger\n"
+"la cause et supprimer %s.\n"
+"Le nettoyage automatique n'aura pas lieu jusqu'à ce que le fichier soit "
+"supprimé.\n"
+"\n"
+"%s"
+
+#: builtin/gc.c:539
+msgid "prune unreferenced objects"
+msgstr "éliminer les objets non référencés"
+
+#: builtin/gc.c:541
+msgid "be more thorough (increased runtime)"
+msgstr "être plus consciencieux (durée de traitement allongée)"
+
+#: builtin/gc.c:542
+msgid "enable auto-gc mode"
+msgstr "activer le mode auto-gc"
+
+#: builtin/gc.c:545
+msgid "force running gc even if there may be another gc running"
+msgstr ""
+"forcer le lancement du ramasse-miettes même si un autre ramasse-miettes "
+"tourne déjà"
+
+#: builtin/gc.c:548
+msgid "repack all other packs except the largest pack"
+msgstr "recompacter tous les autres paquets excepté le plus gros paquet"
+
+#: builtin/gc.c:565
+#, c-format
+msgid "failed to parse gc.logexpiry value %s"
+msgstr "impossible d'analyser gc.logexpiry %s"
+
+#: builtin/gc.c:576
+#, c-format
+msgid "failed to parse prune expiry value %s"
+msgstr "impossible d'analyser la valeur d'expiration d'élagage %s"
+
+#: builtin/gc.c:596
+#, c-format
+msgid "Auto packing the repository in background for optimum performance.\n"
+msgstr ""
+"Compression automatique du dépôt en tâche de fond pour optimiser les "
+"performances.\n"
+
+#: builtin/gc.c:598
+#, c-format
+msgid "Auto packing the repository for optimum performance.\n"
+msgstr "Compression du dépôt pour optimiser les performances.\n"
+
+#: builtin/gc.c:599
+#, c-format
+msgid "See \"git help gc\" for manual housekeeping.\n"
+msgstr "Voir \"git help gc\" pour toute information sur le nettoyage manuel.\n"
+
+#: builtin/gc.c:639
+#, c-format
+msgid ""
+"gc is already running on machine '%s' pid %<PRIuMAX> (use --force if not)"
+msgstr ""
+"un ramasse-miettes est déjà en cours sur la machine '%s' pid %<PRIuMAX> "
+"(utilisez --force si ce n'est pas le cas)"
+
+#: builtin/gc.c:694
+msgid ""
+"There are too many unreachable loose objects; run 'git prune' to remove them."
+msgstr ""
+"Il y a trop d'objets seuls inaccessibles ; lancez 'git prune' pour les "
+"supprimer."
+
+#: builtin/grep.c:29
+msgid "git grep [<options>] [-e] <pattern> [<rev>...] [[--] <path>...]"
+msgstr "git grep [<options>] [-e] <motif> [<révision>...] [[--] <chemin>...]"
+
+#: builtin/grep.c:225
+#, c-format
+msgid "grep: failed to create thread: %s"
+msgstr "grep : échec de création du fil: %s"
+
+#: builtin/grep.c:279
+#, c-format
+msgid "invalid number of threads specified (%d) for %s"
+msgstr "nombre de fils spécifié invalide (%d) pour %s"
+
+#. TRANSLATORS: %s is the configuration
+#. variable for tweaking threads, currently
+#. grep.threads
+#.
+#: builtin/grep.c:287 builtin/index-pack.c:1534 builtin/index-pack.c:1727
+#: builtin/pack-objects.c:2708
+#, c-format
+msgid "no threads support, ignoring %s"
+msgstr "pas de support des fils, ignore %s"
+
+#: builtin/grep.c:467 builtin/grep.c:592 builtin/grep.c:635
+#, c-format
+msgid "unable to read tree (%s)"
+msgstr "impossible de lire l'arbre (%s)"
+
+#: builtin/grep.c:650
+#, c-format
+msgid "unable to grep from object of type %s"
+msgstr "impossible de faire un grep sur un objet de type %s"
+
+#: builtin/grep.c:716
+#, c-format
+msgid "switch `%c' expects a numerical value"
+msgstr "l'option '%c' attend une valeur numérique"
+
+#: builtin/grep.c:815
+msgid "search in index instead of in the work tree"
+msgstr "rechercher dans l'index plutôt que dans la copie de travail"
+
+#: builtin/grep.c:817
+msgid "find in contents not managed by git"
+msgstr "rechercher dans les contenus non gérés par git"
+
+#: builtin/grep.c:819
+msgid "search in both tracked and untracked files"
+msgstr "rechercher dans les fichiers suivis et non-suivis"
+
+#: builtin/grep.c:821
+msgid "ignore files specified via '.gitignore'"
+msgstr "ignorer les fichiers spécifiés via '.gitignore'"
+
+#: builtin/grep.c:823
+msgid "recursively search in each submodule"
+msgstr "rechercher récursivement dans chaque sous-module"
+
+#: builtin/grep.c:826
+msgid "show non-matching lines"
+msgstr "afficher les lignes qui ne correspondent pas"
+
+#: builtin/grep.c:828
+msgid "case insensitive matching"
+msgstr "correspondance insensible à la casse"
+
+#: builtin/grep.c:830
+msgid "match patterns only at word boundaries"
+msgstr "rechercher les motifs aux séparateurs de mots"
+
+#: builtin/grep.c:832
+msgid "process binary files as text"
+msgstr "traiter les fichiers binaires comme texte"
+
+#: builtin/grep.c:834
+msgid "don't match patterns in binary files"
+msgstr "ne pas chercher les motifs dans les fichiers binaires"
+
+#: builtin/grep.c:837
+msgid "process binary files with textconv filters"
+msgstr "traiter les fichiers binaires avec les filtres textconv"
+
+#: builtin/grep.c:839
+msgid "search in subdirectories (default)"
+msgstr "rechercher dans les sous-répertoires (défaut)"
+
+#: builtin/grep.c:841
+msgid "descend at most <depth> levels"
+msgstr "descendre au plus de <profondeur> dans l'arborescence"
+
+#: builtin/grep.c:845
+msgid "use extended POSIX regular expressions"
+msgstr "utiliser des expressions régulières étendues POSIX"
+
+#: builtin/grep.c:848
+msgid "use basic POSIX regular expressions (default)"
+msgstr "utiliser des expressions régulières basiques POSIX (par défaut)"
+
+#: builtin/grep.c:851
+msgid "interpret patterns as fixed strings"
+msgstr "interpréter les motifs comme de chaînes fixes"
+
+#: builtin/grep.c:854
+msgid "use Perl-compatible regular expressions"
+msgstr "utiliser des expressions régulières compatibles avec Perl"
+
+#: builtin/grep.c:857
+msgid "show line numbers"
+msgstr "afficher les numéros de ligne"
+
+#: builtin/grep.c:858
+msgid "show column number of first match"
+msgstr "afficher le numéro de colonne de la première correspondance"
+
+#: builtin/grep.c:859
+msgid "don't show filenames"
+msgstr "ne pas pas afficher les noms de fichier"
+
+#: builtin/grep.c:860
+msgid "show filenames"
+msgstr "afficher les noms de fichier"
+
+#: builtin/grep.c:862
+msgid "show filenames relative to top directory"
+msgstr "afficher les noms de fichiers relativement au répertoire de base"
+
+#: builtin/grep.c:864
+msgid "show only filenames instead of matching lines"
+msgstr "n'afficher que les noms de fichiers au lieu des lignes correspondant"
+
+#: builtin/grep.c:866
+msgid "synonym for --files-with-matches"
+msgstr "synonyme pour --files-with-matches"
+
+#: builtin/grep.c:869
+msgid "show only the names of files without match"
+msgstr "n'afficher que les noms des fichiers sans correspondance"
+
+#: builtin/grep.c:871
+msgid "print NUL after filenames"
+msgstr "imprimer une caractère NUL après le noms de fichier"
+
+#: builtin/grep.c:874
+msgid "show only matching parts of a line"
+msgstr "n'afficher que les parties correspondantes d'une ligne"
+
+#: builtin/grep.c:876
+msgid "show the number of matches instead of matching lines"
+msgstr "afficher le nombre de correspondances au lieu des lignes correspondant"
+
+#: builtin/grep.c:877
+msgid "highlight matches"
+msgstr "mettre en évidence les correspondances"
+
+#: builtin/grep.c:879
+msgid "print empty line between matches from different files"
+msgstr ""
+"imprimer une ligne vide entre les correspondances de fichiers différents"
+
+#: builtin/grep.c:881
+msgid "show filename only once above matches from same file"
+msgstr ""
+"afficher le nom de fichier une fois au dessus des correspondances du même "
+"fichier"
+
+#: builtin/grep.c:884
+msgid "show <n> context lines before and after matches"
+msgstr "afficher <n> lignes de contexte avant et après les correspondances"
+
+#: builtin/grep.c:887
+msgid "show <n> context lines before matches"
+msgstr "afficher <n> lignes de contexte avant les correspondances"
+
+#: builtin/grep.c:889
+msgid "show <n> context lines after matches"
+msgstr "afficher <n> lignes de contexte après les correspondances"
+
+#: builtin/grep.c:891
+msgid "use <n> worker threads"
+msgstr "utiliser <n> fils de travail"
+
+#: builtin/grep.c:892
+msgid "shortcut for -C NUM"
+msgstr "raccourci pour -C NUM"
+
+#: builtin/grep.c:895
+msgid "show a line with the function name before matches"
+msgstr ""
+"afficher une ligne avec le nom de la fonction avant les correspondances"
+
+#: builtin/grep.c:897
+msgid "show the surrounding function"
+msgstr "afficher la fonction contenante"
+
+#: builtin/grep.c:900
+msgid "read patterns from file"
+msgstr "lire les motifs depuis fichier"
+
+#: builtin/grep.c:902
+msgid "match <pattern>"
+msgstr "rechercher <motif>"
+
+#: builtin/grep.c:904
+msgid "combine patterns specified with -e"
+msgstr "combiner les motifs spécifiés par -e"
+
+#: builtin/grep.c:916
+msgid "indicate hit with exit status without output"
+msgstr ""
+"indiquer des correspondances avec le code de sortie mais sans rien afficher"
+
+#: builtin/grep.c:918
+msgid "show only matches from files that match all patterns"
+msgstr ""
+"n'afficher que les correspondances de fichiers qui correspondent à tous les "
+"motifs"
+
+#: builtin/grep.c:920
+msgid "show parse tree for grep expression"
+msgstr "afficher l'arbre d'analyse pour le motif grep"
+
+#: builtin/grep.c:924
+msgid "pager"
+msgstr "pagineur"
+
+#: builtin/grep.c:924
+msgid "show matching files in the pager"
+msgstr "afficher les fichiers correspondant dans le pagineur"
+
+#: builtin/grep.c:928
+msgid "allow calling of grep(1) (ignored by this build)"
+msgstr "permettre l'appel de grep(1) (ignoré par ce build)"
+
+#: builtin/grep.c:992
+msgid "no pattern given"
+msgstr "aucun motif fourni"
+
+#: builtin/grep.c:1028
+msgid "--no-index or --untracked cannot be used with revs"
+msgstr ""
+"--no-index ou --untracked ne peuvent pas être utilisés avec des révisions"
+
+#: builtin/grep.c:1036
+#, c-format
+msgid "unable to resolve revision: %s"
+msgstr "impossible de résoudre la révision : %s"
+
+#: builtin/grep.c:1067
+msgid "invalid option combination, ignoring --threads"
+msgstr "option de combinaison invalide, ignore --threads"
+
+#: builtin/grep.c:1070 builtin/pack-objects.c:3400
+msgid "no threads support, ignoring --threads"
+msgstr "pas de support des fils, ignore --threads"
+
+#: builtin/grep.c:1073 builtin/index-pack.c:1531 builtin/pack-objects.c:2705
+#, c-format
+msgid "invalid number of threads specified (%d)"
+msgstr "nombre de fils spécifié invalide (%d)"
+
+#: builtin/grep.c:1096
+msgid "--open-files-in-pager only works on the worktree"
+msgstr "--open-files-in-pager ne fonctionne que sur la copie de travail"
+
+#: builtin/grep.c:1119
+msgid "option not supported with --recurse-submodules"
+msgstr "option non supportée avec --recurse-submodules"
+
+#: builtin/grep.c:1125
+msgid "--cached or --untracked cannot be used with --no-index"
+msgstr "--cached ou --untracked ne peuvent pas être utilisés avec --no-index"
+
+#: builtin/grep.c:1131
+msgid "--[no-]exclude-standard cannot be used for tracked contents"
+msgstr "--[no-]exclude-standard ne peut pas être utilisé avec du contenu suivi"
+
+#: builtin/grep.c:1139
+msgid "both --cached and trees are given"
+msgstr "--cached et des arbres sont fournis en même temps"
+
+#: builtin/hash-object.c:85
+msgid ""
+"git hash-object [-t <type>] [-w] [--path=<file> | --no-filters] [--stdin] "
+"[--] <file>..."
+msgstr ""
+"git hash-object [-t <type>] [-w] [--path=<fichier> | --no-filters] [--stdin] "
+"[--] <fichier>..."
+
+#: builtin/hash-object.c:86
+msgid "git hash-object  --stdin-paths"
+msgstr "git hash-object  --stdin-paths"
+
+#: builtin/hash-object.c:98
+msgid "object type"
+msgstr "type d'objet"
+
+#: builtin/hash-object.c:99
+msgid "write the object into the object database"
+msgstr "écrire l'objet dans la base de donnée d'objets"
+
+#: builtin/hash-object.c:101
+msgid "read the object from stdin"
+msgstr "lire l'objet depuis l'entrée standard"
+
+#: builtin/hash-object.c:103
+msgid "store file as is without filters"
+msgstr "stocker le fichier tel quel sans filtrage"
+
+#: builtin/hash-object.c:104
+msgid ""
+"just hash any random garbage to create corrupt objects for debugging Git"
+msgstr ""
+"juste hasher n'importe quel contenu pour créer des objets corrompus pour "
+"debugger Git"
+
+#: builtin/hash-object.c:105
+msgid "process file as it were from this path"
+msgstr "traiter le fichier comme s'il venait de ce chemin"
+
+#: builtin/help.c:46
+msgid "print all available commands"
+msgstr "afficher toutes les commandes disponibles"
+
+#: builtin/help.c:47
+msgid "exclude guides"
+msgstr "exclure les guides"
+
+#: builtin/help.c:48
+msgid "print list of useful guides"
+msgstr "afficher une liste de guides utiles"
+
+#: builtin/help.c:49
+msgid "print all configuration variable names"
+msgstr "afficher tous les noms de variables de configuration"
+
+#: builtin/help.c:51
+msgid "show man page"
+msgstr "afficher la page de manuel"
+
+#: builtin/help.c:52
+msgid "show manual in web browser"
+msgstr "afficher le manuel dans un navigateur web"
+
+#: builtin/help.c:54
+msgid "show info page"
+msgstr "afficher la page info"
+
+#: builtin/help.c:56
+msgid "print command description"
+msgstr "afficher la description de la commande"
+
+#: builtin/help.c:61
+msgid "git help [--all] [--guides] [--man | --web | --info] [<command>]"
+msgstr "git help [--all] [--guides] [--man | --web | --info] [<commande>]"
+
+#: builtin/help.c:77
+#, c-format
+msgid "unrecognized help format '%s'"
+msgstr "format d'aide non reconnu '%s'"
+
+#: builtin/help.c:104
+msgid "Failed to start emacsclient."
+msgstr "échec de démarrage d'emacsclient."
+
+#: builtin/help.c:117
+msgid "Failed to parse emacsclient version."
+msgstr "échec d'analyse de la version d'emacsclient."
+
+#: builtin/help.c:125
+#, c-format
+msgid "emacsclient version '%d' too old (< 22)."
+msgstr "la version d'emacsclient '%d' est trop ancienne (<22)."
+
+#: builtin/help.c:143 builtin/help.c:165 builtin/help.c:175 builtin/help.c:183
+#, c-format
+msgid "failed to exec '%s'"
+msgstr "échec de l'exécution de '%s'"
+
+#: builtin/help.c:221
+#, c-format
+msgid ""
+"'%s': path for unsupported man viewer.\n"
+"Please consider using 'man.<tool>.cmd' instead."
+msgstr ""
+"'%s' : chemin pour l'utilitaire de visualisation de manuel non supporté.\n"
+"Veuillez utiliser plutôt 'man.<outil>.cmd'."
+
+#: builtin/help.c:233
+#, c-format
+msgid ""
+"'%s': cmd for supported man viewer.\n"
+"Please consider using 'man.<tool>.path' instead."
+msgstr ""
+"'%s' : chemin pour l'utilitaire de visualisation de manuel supporté.\n"
+"Veuillez utiliser plutôt 'man.<outil>.cmd'."
+
+#: builtin/help.c:350
+#, c-format
+msgid "'%s': unknown man viewer."
+msgstr "'%s' : visualiseur de manuel inconnu."
+
+#: builtin/help.c:367
+msgid "no man viewer handled the request"
+msgstr "aucun visualiseur de manuel n'a pris en charge la demande"
+
+#: builtin/help.c:375
+msgid "no info viewer handled the request"
+msgstr "aucun visualiseur de 'info' n'a pris en charge la demande"
+
+#: builtin/help.c:434 builtin/help.c:445 git.c:336
+#, c-format
+msgid "'%s' is aliased to '%s'"
+msgstr "'%s' est un alias de '%s'"
+
+#: builtin/help.c:448 git.c:365
+#, c-format
+msgid "bad alias.%s string: %s"
+msgstr "Mauvais chaîne alias.%s : %s"
+
+#: builtin/help.c:477 builtin/help.c:507
+#, c-format
+msgid "usage: %s%s"
+msgstr "usage : %s%s"
+
+#: builtin/help.c:491
+msgid "'git help config' for more information"
+msgstr "'git help config' pour plus d'information"
+
+#: builtin/index-pack.c:185
+#, c-format
+msgid "object type mismatch at %s"
+msgstr "type d'objet non correspondant à %s"
+
+#: builtin/index-pack.c:205
+#, c-format
+msgid "did not receive expected object %s"
+msgstr "objet attendu non reçu %s"
+
+#: builtin/index-pack.c:208
+#, c-format
+msgid "object %s: expected type %s, found %s"
+msgstr "objet %s : type attendu %s, reçu %s"
+
+#: builtin/index-pack.c:258
+#, c-format
+msgid "cannot fill %d byte"
+msgid_plural "cannot fill %d bytes"
+msgstr[0] "impossible de remplir %d octet"
+msgstr[1] "impossible de remplir %d octets"
+
+#: builtin/index-pack.c:268
+msgid "early EOF"
+msgstr "fin de fichier prématurée"
+
+#: builtin/index-pack.c:269
+msgid "read error on input"
+msgstr "erreur de lecture sur l'entrée"
+
+#: builtin/index-pack.c:281
+msgid "used more bytes than were available"
+msgstr "plus d'octets utilisés que disponibles"
+
+#: builtin/index-pack.c:288 builtin/pack-objects.c:604
+msgid "pack too large for current definition of off_t"
+msgstr "le paquet est trop grand pour la définition actuelle de off_t"
+
+#: builtin/index-pack.c:291 builtin/unpack-objects.c:95
+msgid "pack exceeds maximum allowed size"
+msgstr "le paquet dépasse la taille maximale permise"
+
+#: builtin/index-pack.c:312
+#, c-format
+msgid "cannot open packfile '%s'"
+msgstr "impossible d'ouvrir le fichier paquet '%s'"
+
+#: builtin/index-pack.c:326
+msgid "pack signature mismatch"
+msgstr "la signature du paquet ne correspond pas"
+
+#: builtin/index-pack.c:328
+#, c-format
+msgid "pack version %<PRIu32> unsupported"
+msgstr "la version de paquet %<PRIu32> non supportée"
+
+#: builtin/index-pack.c:346
+#, c-format
+msgid "pack has bad object at offset %<PRIuMAX>: %s"
+msgstr "le paquet a un mauvais objet à l'offset %<PRIuMAX> : %s"
+
+#: builtin/index-pack.c:466
+#, c-format
+msgid "inflate returned %d"
+msgstr "la décompression (inflate) a retourné %d"
+
+#: builtin/index-pack.c:515
+msgid "offset value overflow for delta base object"
+msgstr "dépassement de la valeur d'offset pour l'objet delta de base"
+
+#: builtin/index-pack.c:523
+msgid "delta base offset is out of bound"
+msgstr "l'objet delta de base est hors limite"
+
+#: builtin/index-pack.c:531
+#, c-format
+msgid "unknown object type %d"
+msgstr "type d'objet inconnu %d"
+
+#: builtin/index-pack.c:562
+msgid "cannot pread pack file"
+msgstr "impossible de lire (pread) le fichier paquet"
+
+#: builtin/index-pack.c:564
+#, c-format
+msgid "premature end of pack file, %<PRIuMAX> byte missing"
+msgid_plural "premature end of pack file, %<PRIuMAX> bytes missing"
+msgstr[0] "fin prématurée du fichier paquet, %<PRIuMAX> octet lu"
+msgstr[1] "fin prématurée du fichier paquet, %<PRIuMAX> octets lus"
+
+#: builtin/index-pack.c:590
+msgid "serious inflate inconsistency"
+msgstr "grave incohérence dans la décompression (inflate)"
+
+#: builtin/index-pack.c:735 builtin/index-pack.c:741 builtin/index-pack.c:764
+#: builtin/index-pack.c:803 builtin/index-pack.c:812
+#, c-format
+msgid "SHA1 COLLISION FOUND WITH %s !"
+msgstr "COLLISION SHA1 TROUVÉE AVEC %s !"
+
+#: builtin/index-pack.c:738 builtin/pack-objects.c:157
+#: builtin/pack-objects.c:217 builtin/pack-objects.c:311
+#, c-format
+msgid "unable to read %s"
+msgstr "impossible de lire %s"
+
+#: builtin/index-pack.c:801
+#, c-format
+msgid "cannot read existing object info %s"
+msgstr "impossible de lire l'information existante de l'objet %s"
+
+#: builtin/index-pack.c:809
+#, c-format
+msgid "cannot read existing object %s"
+msgstr "impossible de lire l'objet existant %s"
+
+#: builtin/index-pack.c:823
+#, c-format
+msgid "invalid blob object %s"
+msgstr "objet blob invalide %s"
+
+#: builtin/index-pack.c:826 builtin/index-pack.c:845
+msgid "fsck error in packed object"
+msgstr "erreur de fsck dans l'objet empaqueté"
+
+#: builtin/index-pack.c:847
+#, c-format
+msgid "Not all child objects of %s are reachable"
+msgstr "Tous les objets enfants de %s ne sont pas accessibles"
+
+#: builtin/index-pack.c:919 builtin/index-pack.c:950
+msgid "failed to apply delta"
+msgstr "échec d'application du delta"
+
+#: builtin/index-pack.c:1118
+msgid "Receiving objects"
+msgstr "Réception d'objets"
+
+#: builtin/index-pack.c:1118
+msgid "Indexing objects"
+msgstr "Indexation d'objets"
+
+#: builtin/index-pack.c:1152
+msgid "pack is corrupted (SHA1 mismatch)"
+msgstr "le paquet est corrompu (SHA1 ne correspond pas)"
+
+#: builtin/index-pack.c:1157
+msgid "cannot fstat packfile"
+msgstr "impossible d'obtenir le statut (fstat) du fichier paquet"
+
+#: builtin/index-pack.c:1160
+msgid "pack has junk at the end"
+msgstr "le paquet est invalide à la fin"
+
+#: builtin/index-pack.c:1172
+msgid "confusion beyond insanity in parse_pack_objects()"
+msgstr "confusion extrême dans parse_pack_objects()"
+
+#: builtin/index-pack.c:1195
+msgid "Resolving deltas"
+msgstr "Résolution des deltas"
+
+#: builtin/index-pack.c:1205 builtin/pack-objects.c:2481
+#, c-format
+msgid "unable to create thread: %s"
+msgstr "impossible de créer le fil : %s"
+
+#: builtin/index-pack.c:1246
+msgid "confusion beyond insanity"
+msgstr "confusion extrême"
+
+#: builtin/index-pack.c:1252
+#, c-format
+msgid "completed with %d local object"
+msgid_plural "completed with %d local objects"
+msgstr[0] "complété avec %d objet local"
+msgstr[1] "complété avec %d objets locaux"
+
+#: builtin/index-pack.c:1264
+#, c-format
+msgid "Unexpected tail checksum for %s (disk corruption?)"
+msgstr ""
+"Somme de contrôle de fin inattendue pour %s (corruption sur le disque ?)"
+
+#: builtin/index-pack.c:1268
+#, c-format
+msgid "pack has %d unresolved delta"
+msgid_plural "pack has %d unresolved deltas"
+msgstr[0] "le paquet a %d delta non résolu"
+msgstr[1] "le paquet a %d deltas non résolus"
+
+#: builtin/index-pack.c:1292
+#, c-format
+msgid "unable to deflate appended object (%d)"
+msgstr "impossible de compresser l'objet ajouté (%d)"
+
+#: builtin/index-pack.c:1388
+#, c-format
+msgid "local object %s is corrupt"
+msgstr "l'objet local %s est corrompu"
+
+#: builtin/index-pack.c:1402
+#, c-format
+msgid "packfile name '%s' does not end with '.pack'"
+msgstr "le nom de fichier paquet '%s' ne se termine pas par '.pack'"
+
+#: builtin/index-pack.c:1427
+#, c-format
+msgid "cannot write %s file '%s'"
+msgstr "impossible d'écrire le fichier %s '%s'"
+
+#: builtin/index-pack.c:1435
+#, c-format
+msgid "cannot close written %s file '%s'"
+msgstr "impossible de fermer le fichier %s écrit '%s'"
+
+#: builtin/index-pack.c:1459
+msgid "error while closing pack file"
+msgstr "erreur en fermeture du fichier paquet"
+
+#: builtin/index-pack.c:1473
+msgid "cannot store pack file"
+msgstr "impossible de stocker le fichier paquet"
+
+#: builtin/index-pack.c:1481
+msgid "cannot store index file"
+msgstr "impossible de stocker le fichier d'index"
+
+#: builtin/index-pack.c:1525 builtin/pack-objects.c:2716
+#, c-format
+msgid "bad pack.indexversion=%<PRIu32>"
+msgstr "mauvais pack.indexversion=%<PRIu32>"
+
+#: builtin/index-pack.c:1593
+#, c-format
+msgid "Cannot open existing pack file '%s'"
+msgstr "Impossible d'ouvrir le fichier paquet existant '%s'"
+
+#: builtin/index-pack.c:1595
+#, c-format
+msgid "Cannot open existing pack idx file for '%s'"
+msgstr "Impossible d'ouvrir le fichier paquet d'index existant pour '%s'"
+
+#: builtin/index-pack.c:1643
+#, c-format
+msgid "non delta: %d object"
+msgid_plural "non delta: %d objects"
+msgstr[0] "pas un delta : %d objet"
+msgstr[1] "pas un delta : %d objets"
+
+#: builtin/index-pack.c:1650
+#, c-format
+msgid "chain length = %d: %lu object"
+msgid_plural "chain length = %d: %lu objects"
+msgstr[0] "longueur chaînée = %d : %lu objet"
+msgstr[1] "longueur chaînée = %d : %lu objets"
+
+#: builtin/index-pack.c:1689
+msgid "Cannot come back to cwd"
+msgstr "Impossible de revenir au répertoire de travail courant"
+
+#: builtin/index-pack.c:1738 builtin/index-pack.c:1741
+#: builtin/index-pack.c:1757 builtin/index-pack.c:1761
+#, c-format
+msgid "bad %s"
+msgstr "mauvais %s"
+
+#: builtin/index-pack.c:1777
+msgid "--fix-thin cannot be used without --stdin"
+msgstr "--fix-thin ne peut pas être utilisé sans --stdin"
+
+#: builtin/index-pack.c:1779
+msgid "--stdin requires a git repository"
+msgstr "--stdin requiert un dépôt git"
+
+#: builtin/index-pack.c:1785
+msgid "--verify with no packfile name given"
+msgstr "--verify sans nom de fichier paquet donné"
+
+#: builtin/index-pack.c:1833 builtin/unpack-objects.c:581
+msgid "fsck error in pack objects"
+msgstr "erreur de fsck dans les objets paquets"
+
+#: builtin/init-db.c:61
+#, c-format
+msgid "cannot stat template '%s'"
+msgstr "impossible de faire un stat du modèle '%s'"
+
+#: builtin/init-db.c:66
+#, c-format
+msgid "cannot opendir '%s'"
+msgstr "impossible d'ouvrir le répertoire '%s'"
+
+#: builtin/init-db.c:78
+#, c-format
+msgid "cannot readlink '%s'"
+msgstr "impossible de lire le lien '%s'"
+
+#: builtin/init-db.c:80
+#, c-format
+msgid "cannot symlink '%s' '%s'"
+msgstr "impossible de créer un lien symbolique de '%s' '%s'"
+
+#: builtin/init-db.c:86
+#, c-format
+msgid "cannot copy '%s' to '%s'"
+msgstr "impossible de copier '%s' vers '%s'"
+
+#: builtin/init-db.c:90
+#, c-format
+msgid "ignoring template %s"
+msgstr "modèle %s ignoré"
+
+#: builtin/init-db.c:121
+#, c-format
+msgid "templates not found in %s"
+msgstr "modèles non trouvés dans %s"
+
+#: builtin/init-db.c:136
+#, c-format
+msgid "not copying templates from '%s': %s"
+msgstr "pas de copie des modèles depuis '%s' : %s"
+
+#: builtin/init-db.c:334
+#, c-format
+msgid "unable to handle file type %d"
+msgstr "impossible de traiter le fichier de type %d"
+
+#: builtin/init-db.c:337
+#, c-format
+msgid "unable to move %s to %s"
+msgstr "impossible de déplacer %s vers %s"
+
+#: builtin/init-db.c:354 builtin/init-db.c:357
+#, c-format
+msgid "%s already exists"
+msgstr "%s existe déjà"
+
+#: builtin/init-db.c:413
+#, c-format
+msgid "Reinitialized existing shared Git repository in %s%s\n"
+msgstr "Dépôt Git existant partagé réinitialisé dans %s%s\n"
+
+#: builtin/init-db.c:414
+#, c-format
+msgid "Reinitialized existing Git repository in %s%s\n"
+msgstr "Dépôt Git existant réinitialisé dans %s%s\n"
+
+#: builtin/init-db.c:418
+#, c-format
+msgid "Initialized empty shared Git repository in %s%s\n"
+msgstr "Dépôt Git vide partagé initialisé dans %s%s\n"
+
+#: builtin/init-db.c:419
+#, c-format
+msgid "Initialized empty Git repository in %s%s\n"
+msgstr "Dépôt Git vide initialisé dans %s%s\n"
+
+#: builtin/init-db.c:468
+msgid ""
+"git init [-q | --quiet] [--bare] [--template=<template-directory>] [--"
+"shared[=<permissions>]] [<directory>]"
+msgstr ""
+"git init [-q | --quiet] [--bare] [--template=<répertoire-modèle>] [--"
+"shared[=<permissions>]] [<répertoire>]"
+
+#: builtin/init-db.c:491
+msgid "permissions"
+msgstr "permissions"
+
+#: builtin/init-db.c:492
+msgid "specify that the git repository is to be shared amongst several users"
+msgstr "spécifier que le dépôt git sera partagé entre plusieurs utilisateurs"
+
+#: builtin/init-db.c:529 builtin/init-db.c:534
+#, c-format
+msgid "cannot mkdir %s"
+msgstr "impossible de créer le répertoire (mkdir) %s"
+
+#: builtin/init-db.c:538
+#, c-format
+msgid "cannot chdir to %s"
+msgstr "impossible de se déplacer vers le répertoire (chdir) %s"
+
+#: builtin/init-db.c:559
+#, c-format
+msgid ""
+"%s (or --work-tree=<directory>) not allowed without specifying %s (or --git-"
+"dir=<directory>)"
+msgstr ""
+"%s (ou --work-tree=<répertoire>) n'est pas autorisé sans spécifier %s (ou --"
+"git-dir=<répertoire>)"
+
+#: builtin/init-db.c:587
+#, c-format
+msgid "Cannot access work tree '%s'"
+msgstr "Impossible d'accéder à l'arbre de travail '%s'"
+
+#: builtin/interpret-trailers.c:16
+msgid ""
+"git interpret-trailers [--in-place] [--trim-empty] [(--trailer "
+"<token>[(=|:)<value>])...] [<file>...]"
+msgstr ""
+"git interpret-trailers [--in-place] [--trim-empty] [(--trailer "
+"<symbole>[(=|:)<valeur>])...] [<fichier>...]"
+
+#: builtin/interpret-trailers.c:95
+msgid "edit files in place"
+msgstr "éditer les fichiers sur place"
+
+#: builtin/interpret-trailers.c:96
+msgid "trim empty trailers"
+msgstr "éliminer les lignes de fin vides"
+
+#: builtin/interpret-trailers.c:99
+msgid "where to place the new trailer"
+msgstr "où placer les nouvelles lignes terminales"
+
+#: builtin/interpret-trailers.c:101
+msgid "action if trailer already exists"
+msgstr "action si les lignes terminales existent déjà"
+
+#: builtin/interpret-trailers.c:103
+msgid "action if trailer is missing"
+msgstr "action si les lignes terminales manquent"
+
+#: builtin/interpret-trailers.c:105
+msgid "output only the trailers"
+msgstr "éliminer les lignes terminales vides"
+
+#: builtin/interpret-trailers.c:106
+msgid "do not apply config rules"
+msgstr "ne pas appliquer les règles de la configuration"
+
+#: builtin/interpret-trailers.c:107
+msgid "join whitespace-continued values"
+msgstr "joindre les valeurs continuées avec des caractères blancs"
+
+#: builtin/interpret-trailers.c:108
+msgid "set parsing options"
+msgstr "paramètres d'analyse"
+
+#: builtin/interpret-trailers.c:110
+msgid "do not treat --- specially"
+msgstr "ne pas traiter spécialement ---"
+
+#: builtin/interpret-trailers.c:111
+msgid "trailer"
+msgstr "ligne de fin"
+
+#: builtin/interpret-trailers.c:112
+msgid "trailer(s) to add"
+msgstr "ligne(s) de fin à ajouter"
+
+#: builtin/interpret-trailers.c:123
+msgid "--trailer with --only-input does not make sense"
+msgstr "--trailer n'a aucune signification avec --only-input"
+
+#: builtin/interpret-trailers.c:133
+msgid "no input file given for in-place editing"
+msgstr "aucun fichier en entrée pour l'éditon sur place"
+
+#: builtin/log.c:56
+msgid "git log [<options>] [<revision-range>] [[--] <path>...]"
+msgstr "git log [<options>] [<plage de révisions>] [[--] <chemin>...]"
+
+#: builtin/log.c:57
+msgid "git show [<options>] <object>..."
+msgstr "git show [<options>] <objet>..."
+
+#: builtin/log.c:110
+#, c-format
+msgid "invalid --decorate option: %s"
+msgstr "option --decorate invalide : %s"
+
+#: builtin/log.c:174
+msgid "show source"
+msgstr "afficher la source"
+
+#: builtin/log.c:175
+msgid "Use mail map file"
+msgstr "Utiliser le fichier de correspondance de mail"
+
+#: builtin/log.c:177
+msgid "only decorate refs that match <pattern>"
+msgstr "décorer seulement les références correspondant à <motif>"
+
+#: builtin/log.c:179
+msgid "do not decorate refs that match <pattern>"
+msgstr "ne pas décorer les références correspondant à <motif>"
+
+#: builtin/log.c:180
+msgid "decorate options"
+msgstr "décorer les options"
+
+#: builtin/log.c:183
+msgid "Process line range n,m in file, counting from 1"
+msgstr ""
+"Traiter seulement l'intervalle de lignes n,m du fichier en commençant le "
+"compte à 1"
+
+#: builtin/log.c:281
+#, c-format
+msgid "Final output: %d %s\n"
+msgstr "Sortie finale : %d %s\n"
+
+#: builtin/log.c:535
+#, c-format
+msgid "git show %s: bad file"
+msgstr "git show %s : fichier incorrect"
+
+#: builtin/log.c:550 builtin/log.c:645
+#, c-format
+msgid "could not read object %s"
+msgstr "impossible de lire l'objet %s"
+
+#: builtin/log.c:670
+#, c-format
+msgid "unknown type: %d"
+msgstr "type inconnu : %d"
+
+#: builtin/log.c:814
+#, c-format
+msgid "%s: invalid cover from description mode"
+msgstr "%s : couverture invalide pour le mode de description"
+
+#: builtin/log.c:821
+msgid "format.headers without value"
+msgstr "format.headers sans valeur"
+
+#: builtin/log.c:936
+msgid "name of output directory is too long"
+msgstr "le nom du répertoire de sortie est trop long"
+
+#: builtin/log.c:952
+#, c-format
+msgid "cannot open patch file %s"
+msgstr "impossible d'ouvrir le fichier correctif %s"
+
+#: builtin/log.c:969
+msgid "need exactly one range"
+msgstr "exactement une plage nécessaire"
+
+#: builtin/log.c:979
+msgid "not a range"
+msgstr "ceci n'est pas une plage"
+
+#: builtin/log.c:1143
+msgid "cover letter needs email format"
+msgstr "la lettre de motivation doit être au format courriel"
+
+#: builtin/log.c:1149
+msgid "failed to create cover-letter file"
+msgstr "échec de création du fichier de lettre de motivation"
+
+#: builtin/log.c:1228
+#, c-format
+msgid "insane in-reply-to: %s"
+msgstr "in-reply-to aberrant : %s"
+
+#: builtin/log.c:1255
+msgid "git format-patch [<options>] [<since> | <revision-range>]"
+msgstr "git format-patch [<options>] [<depuis> | <plage de révisions>]"
+
+#: builtin/log.c:1313
+msgid "two output directories?"
+msgstr "deux répertoires de sortie ?"
+
+#: builtin/log.c:1424 builtin/log.c:2197 builtin/log.c:2199 builtin/log.c:2211
+#, c-format
+msgid "unknown commit %s"
+msgstr "commit inconnu %s"
+
+#: builtin/log.c:1434 builtin/replace.c:58 builtin/replace.c:207
+#: builtin/replace.c:210
+#, c-format
+msgid "failed to resolve '%s' as a valid ref"
+msgstr "échec à résoudre '%s' comme une référence valide"
+
+#: builtin/log.c:1439
+msgid "could not find exact merge base"
+msgstr "impossible de trouver la base de fusion exacte"
+
+#: builtin/log.c:1443
+msgid ""
+"failed to get upstream, if you want to record base commit automatically,\n"
+"please use git branch --set-upstream-to to track a remote branch.\n"
+"Or you could specify base commit by --base=<base-commit-id> manually"
+msgstr ""
+"impossible de récupérer l'amont, si vous voulez enregistrer le commit de "
+"base automatiquement,\n"
+"veuillez utiliser git branch --set-upstream-to pour suivre une branche "
+"distante.\n"
+"Ou vous pouvez spécifier le commit de base par --base=<id-du-commit-de-base> "
+"manuellement"
+
+#: builtin/log.c:1463
+msgid "failed to find exact merge base"
+msgstr "échec à trouver la base de fusion exacte"
+
+#: builtin/log.c:1474
+msgid "base commit should be the ancestor of revision list"
+msgstr "le commit de base devrait être l'ancêtre de la liste de révisions"
+
+#: builtin/log.c:1478
+msgid "base commit shouldn't be in revision list"
+msgstr "le commit de base ne devrait pas faire partie de la liste de révisions"
+
+#: builtin/log.c:1531
+msgid "cannot get patch id"
+msgstr "impossible d'obtenir l'id du patch"
+
+#: builtin/log.c:1583
+msgid "failed to infer range-diff ranges"
+msgstr "échec d'inférence d'intervalles de différence d'intervalles"
+
+#: builtin/log.c:1629
+msgid "use [PATCH n/m] even with a single patch"
+msgstr "utiliser [PATCH n/m] même avec un patch unique"
+
+#: builtin/log.c:1632
+msgid "use [PATCH] even with multiple patches"
+msgstr "utiliser [PATCH] même avec des patchs multiples"
+
+#: builtin/log.c:1636
+msgid "print patches to standard out"
+msgstr "afficher les patchs sur la sortie standard"
+
+#: builtin/log.c:1638
+msgid "generate a cover letter"
+msgstr "générer une lettre de motivation"
+
+#: builtin/log.c:1640
+msgid "use simple number sequence for output file names"
+msgstr ""
+"utiliser une séquence simple de nombres pour les nom des fichiers de sortie"
+
+#: builtin/log.c:1641
+msgid "sfx"
+msgstr "sfx"
+
+#: builtin/log.c:1642
+msgid "use <sfx> instead of '.patch'"
+msgstr "utiliser <sfx> au lieu de '.patch'"
+
+#: builtin/log.c:1644
+msgid "start numbering patches at <n> instead of 1"
+msgstr "démarrer la numérotation des patchs à <n> au lieu de 1"
+
+#: builtin/log.c:1646
+msgid "mark the series as Nth re-roll"
+msgstr "marquer la série comme une Nième réédition"
+
+#: builtin/log.c:1648
+msgid "Use [RFC PATCH] instead of [PATCH]"
+msgstr "utiliser [RFC PATCH] au lieu de [PATCH]"
+
+#: builtin/log.c:1651
+msgid "cover-from-description-mode"
+msgstr "cover-from-description-mode"
+
+#: builtin/log.c:1652
+msgid "generate parts of a cover letter based on a branch's description"
+msgstr "générer des parties de la lettre d'introduction à partir de la description de la branche"
+
+#: builtin/log.c:1654
+msgid "Use [<prefix>] instead of [PATCH]"
+msgstr "utiliser [<préfixe>] au lieu de [PATCH]"
+
+#: builtin/log.c:1657
+msgid "store resulting files in <dir>"
+msgstr "stocker les fichiers résultats dans <répertoire>"
+
+#: builtin/log.c:1660
+msgid "don't strip/add [PATCH]"
+msgstr "ne pas retirer/ajouter [PATCH]"
+
+#: builtin/log.c:1663
+msgid "don't output binary diffs"
+msgstr "ne pas imprimer les diffs binaires"
+
+#: builtin/log.c:1665
+msgid "output all-zero hash in From header"
+msgstr "écrire une empreinte à zéro dans l'entête From"
+
+#: builtin/log.c:1667
+msgid "don't include a patch matching a commit upstream"
+msgstr "ne pas inclure un patch correspondant à un commit amont"
+
+#: builtin/log.c:1669
+msgid "show patch format instead of default (patch + stat)"
+msgstr "afficher le format du patch au lieu du défaut (patch + stat)"
+
+#: builtin/log.c:1671
+msgid "Messaging"
+msgstr "Communication"
+
+#: builtin/log.c:1672
+msgid "header"
+msgstr "en-tête"
+
+#: builtin/log.c:1673
+msgid "add email header"
+msgstr "ajouter l'en-tête de courriel"
+
+#: builtin/log.c:1674 builtin/log.c:1676
+msgid "email"
+msgstr "courriel"
+
+#: builtin/log.c:1674
+msgid "add To: header"
+msgstr "ajouter l'en-tête \"To:\""
+
+#: builtin/log.c:1676
+msgid "add Cc: header"
+msgstr "ajouter l'en-tête \"Cc:\""
+
+#: builtin/log.c:1678
+msgid "ident"
+msgstr "ident"
+
+#: builtin/log.c:1679
+msgid "set From address to <ident> (or committer ident if absent)"
+msgstr ""
+"renseigner l'adresse From à <ident> (ou à l'ident du validateur si absent)"
+
+#: builtin/log.c:1681
+msgid "message-id"
+msgstr "id-message"
+
+#: builtin/log.c:1682
+msgid "make first mail a reply to <message-id>"
+msgstr "répondre dans le premier message à <id-message>"
+
+#: builtin/log.c:1683 builtin/log.c:1686
+msgid "boundary"
+msgstr "limite"
+
+#: builtin/log.c:1684
+msgid "attach the patch"
+msgstr "attacher le patch"
+
+#: builtin/log.c:1687
+msgid "inline the patch"
+msgstr "patch à l'intérieur"
+
+#: builtin/log.c:1691
+msgid "enable message threading, styles: shallow, deep"
+msgstr ""
+"activer l'enfilage de message, styles : shallow (superficiel), deep (profond)"
+
+#: builtin/log.c:1693
+msgid "signature"
+msgstr "signature"
+
+#: builtin/log.c:1694
+msgid "add a signature"
+msgstr "ajouter une signature"
+
+#: builtin/log.c:1695
+msgid "base-commit"
+msgstr "commit-de-base"
+
+#: builtin/log.c:1696
+msgid "add prerequisite tree info to the patch series"
+msgstr "Ajouter un arbre prérequis à la série de patchs"
+
+#: builtin/log.c:1698
+msgid "add a signature from a file"
+msgstr "ajouter une signature depuis un fichier"
+
+#: builtin/log.c:1699
+msgid "don't print the patch filenames"
+msgstr "ne pas afficher les noms de fichiers des patchs"
+
+#: builtin/log.c:1701
+msgid "show progress while generating patches"
+msgstr ""
+"afficher la barre de progression durant la phase de génération des patchs"
+
+#: builtin/log.c:1703
+msgid "show changes against <rev> in cover letter or single patch"
+msgstr ""
+"afficher les modifications par rapport à <rév> dans la première page ou une "
+"rustine"
+
+#: builtin/log.c:1706
+msgid "show changes against <refspec> in cover letter or single patch"
+msgstr ""
+"afficher les modifications par rapport à <refspec> dans la première page ou "
+"une rustine"
+
+#: builtin/log.c:1708
+msgid "percentage by which creation is weighted"
+msgstr "pourcentage par lequel la création est pondérée"
+
+#: builtin/log.c:1792
+#, c-format
+msgid "invalid ident line: %s"
+msgstr "ligne d'identification invalide : %s"
+
+#: builtin/log.c:1807
+msgid "-n and -k are mutually exclusive"
+msgstr "-n et -k sont mutuellement exclusifs"
+
+#: builtin/log.c:1809
+msgid "--subject-prefix/--rfc and -k are mutually exclusive"
+msgstr "--subject-prefix/--rfc et -k sont mutuellement exclusifs"
+
+#: builtin/log.c:1817
+msgid "--name-only does not make sense"
+msgstr "--name-only n'a pas de sens"
+
+#: builtin/log.c:1819
+msgid "--name-status does not make sense"
+msgstr "--name-status n'a pas de sens"
+
+#: builtin/log.c:1821
+msgid "--check does not make sense"
+msgstr "--check n'a pas de sens"
+
+#: builtin/log.c:1854
+msgid "standard output, or directory, which one?"
+msgstr "sortie standard, ou répertoire, lequel ?"
+
+#: builtin/log.c:1958
+msgid "--interdiff requires --cover-letter or single patch"
+msgstr "--interdiff requiert --cover-letter ou une rustine unique"
+
+#: builtin/log.c:1962
+msgid "Interdiff:"
+msgstr "Interdiff :"
+
+#: builtin/log.c:1963
+#, c-format
+msgid "Interdiff against v%d:"
+msgstr "Interdiff contre v%d :"
+
+#: builtin/log.c:1969
+msgid "--creation-factor requires --range-diff"
+msgstr "--creation-factor requiert --range-diff"
+
+#: builtin/log.c:1973
+msgid "--range-diff requires --cover-letter or single patch"
+msgstr "--range-diff requiert --cover-letter ou une rustine unique"
+
+#: builtin/log.c:1981
+msgid "Range-diff:"
+msgstr "Diff-intervalle :"
+
+#: builtin/log.c:1982
+#, c-format
+msgid "Range-diff against v%d:"
+msgstr "Diff-intervalle contre v%d :"
+
+#: builtin/log.c:1993
+#, c-format
+msgid "unable to read signature file '%s'"
+msgstr "lecture du fichier de signature '%s' impossible"
+
+#: builtin/log.c:2029
+msgid "Generating patches"
+msgstr "Génération des patchs"
+
+#: builtin/log.c:2073
+msgid "failed to create output files"
+msgstr "échec de création des fichiers en sortie"
+
+#: builtin/log.c:2132
+msgid "git cherry [-v] [<upstream> [<head> [<limit>]]]"
+msgstr "git cherry [-v] [<branche_amont> [<head> [<limite>]]]"
+
+#: builtin/log.c:2186
+#, c-format
+msgid ""
+"Could not find a tracked remote branch, please specify <upstream> manually.\n"
+msgstr ""
+"Impossible de trouver une branche distante suivie, merci de spécifier "
+"<branche_amont> manuellement.\n"
+
+#: builtin/ls-files.c:470
+msgid "git ls-files [<options>] [<file>...]"
+msgstr "git ls-files [<options>] [<fichier>...]"
+
+#: builtin/ls-files.c:526
+msgid "identify the file status with tags"
+msgstr "identifier l'état de fichier avec les étiquettes"
+
+#: builtin/ls-files.c:528
+msgid "use lowercase letters for 'assume unchanged' files"
+msgstr "utiliser des minuscules pour les fichiers 'assumés inchangés'"
+
+#: builtin/ls-files.c:530
+msgid "use lowercase letters for 'fsmonitor clean' files"
+msgstr "utiliser des minuscules pour les fichiers 'fsmonitor clean'"
+
+#: builtin/ls-files.c:532
+msgid "show cached files in the output (default)"
+msgstr "afficher les fichiers mis en cache dans la sortie (défaut)"
+
+#: builtin/ls-files.c:534
+msgid "show deleted files in the output"
+msgstr "afficher les fichiers supprimés dans la sortie"
+
+#: builtin/ls-files.c:536
+msgid "show modified files in the output"
+msgstr "afficher les fichiers modifiés dans la sortie"
+
+#: builtin/ls-files.c:538
+msgid "show other files in the output"
+msgstr "afficher les autres fichiers dans la sortie"
+
+#: builtin/ls-files.c:540
+msgid "show ignored files in the output"
+msgstr "afficher les fichiers ignorés dans la sortie"
+
+#: builtin/ls-files.c:543
+msgid "show staged contents' object name in the output"
+msgstr "afficher les nom des objets indexés dans la sortie"
+
+#: builtin/ls-files.c:545
+msgid "show files on the filesystem that need to be removed"
+msgstr ""
+"afficher les fichiers du système de fichiers qui ont besoin d'être supprimés"
+
+#: builtin/ls-files.c:547
+msgid "show 'other' directories' names only"
+msgstr "afficher seulement les noms des répertoires 'other'"
+
+#: builtin/ls-files.c:549
+msgid "show line endings of files"
+msgstr "afficher les fins de lignes des fichiers"
+
+#: builtin/ls-files.c:551
+msgid "don't show empty directories"
+msgstr "ne pas afficher les répertoires vides"
+
+#: builtin/ls-files.c:554
+msgid "show unmerged files in the output"
+msgstr "afficher les fichiers non fusionnés dans la sortie"
+
+#: builtin/ls-files.c:556
+msgid "show resolve-undo information"
+msgstr "afficher l'information resolv-undo"
+
+#: builtin/ls-files.c:558
+msgid "skip files matching pattern"
+msgstr "sauter les fichiers correspondant au motif"
+
+#: builtin/ls-files.c:561
+msgid "exclude patterns are read from <file>"
+msgstr "les motifs d'exclusion sont lus depuis <fichier>"
+
+#: builtin/ls-files.c:564
+msgid "read additional per-directory exclude patterns in <file>"
+msgstr "lire des motifs d'exclusion additionnels par répertoire dans <fichier>"
+
+#: builtin/ls-files.c:566
+msgid "add the standard git exclusions"
+msgstr "ajouter les exclusions git standard"
+
+#: builtin/ls-files.c:570
+msgid "make the output relative to the project top directory"
+msgstr "afficher en relatif par rapport au répertoire racine du projet"
+
+#: builtin/ls-files.c:573
+msgid "recurse through submodules"
+msgstr "parcourir récursivement les sous-modules"
+
+#: builtin/ls-files.c:575
+msgid "if any <file> is not in the index, treat this as an error"
+msgstr "si un <fichier> n'est pas dans l'index, traiter cela comme une erreur"
+
+#: builtin/ls-files.c:576
+msgid "tree-ish"
+msgstr "arbre ou apparenté"
+
+#: builtin/ls-files.c:577
+msgid "pretend that paths removed since <tree-ish> are still present"
+msgstr ""
+"considérer que les chemins supprimés depuis <arbre ou apparenté> sont "
+"toujours présents"
+
+#: builtin/ls-files.c:579
+msgid "show debugging data"
+msgstr "afficher les données de débogage"
+
+#: builtin/ls-remote.c:9
+msgid ""
+"git ls-remote [--heads] [--tags] [--refs] [--upload-pack=<exec>]\n"
+"                     [-q | --quiet] [--exit-code] [--get-url]\n"
+"                     [--symref] [<repository> [<refs>...]]"
+msgstr ""
+"git ls-remote [--heads] [--tags] [--refs] [--upload-pack=<exec>]\n"
+"                     [-q | --quiet] [--exit-code] [--get-url]\n"
+"                     [--symref] [<dépôt> [<références>...]]"
+
+#: builtin/ls-remote.c:59
+msgid "do not print remote URL"
+msgstr "ne pas afficher les URL distantes"
+
+#: builtin/ls-remote.c:60 builtin/ls-remote.c:62 builtin/rebase.c:1518
+msgid "exec"
+msgstr "exécutable"
+
+#: builtin/ls-remote.c:61 builtin/ls-remote.c:63
+msgid "path of git-upload-pack on the remote host"
+msgstr "chemin vers git-upload-pack sur le serveur distant"
+
+#: builtin/ls-remote.c:65
+msgid "limit to tags"
+msgstr "limiter aux étiquettes"
+
+#: builtin/ls-remote.c:66
+msgid "limit to heads"
+msgstr "limiter aux heads"
+
+#: builtin/ls-remote.c:67
+msgid "do not show peeled tags"
+msgstr "ne pas afficher les étiquettes pelées"
+
+#: builtin/ls-remote.c:69
+msgid "take url.<base>.insteadOf into account"
+msgstr "prendre en compte url.<base>.insteadOf"
+
+#: builtin/ls-remote.c:72
+msgid "exit with exit code 2 if no matching refs are found"
+msgstr ""
+"sortir avec un code d'erreur 2 si aucune correspondance de référence n'est "
+"trouvée"
+
+#: builtin/ls-remote.c:75
+msgid "show underlying ref in addition to the object pointed by it"
+msgstr "afficher la réf sous-jacente en plus de l'objet pointé par elle"
+
+#: builtin/ls-tree.c:30
+msgid "git ls-tree [<options>] <tree-ish> [<path>...]"
+msgstr "git ls-tree [<options>] <arbre ou apparenté> [<chemin>...]"
+
+#: builtin/ls-tree.c:128
+msgid "only show trees"
+msgstr "afficher seulement les arbres"
+
+#: builtin/ls-tree.c:130
+msgid "recurse into subtrees"
+msgstr "parcourir les sous-arbres"
+
+#: builtin/ls-tree.c:132
+msgid "show trees when recursing"
+msgstr "afficher les arbres en les parcourant"
+
+#: builtin/ls-tree.c:135
+msgid "terminate entries with NUL byte"
+msgstr "terminer les éléments avec un octet NUL"
+
+#: builtin/ls-tree.c:136
+msgid "include object size"
+msgstr "inclure la taille d'objet"
+
+#: builtin/ls-tree.c:138 builtin/ls-tree.c:140
+msgid "list only filenames"
+msgstr "afficher seulement les noms de fichiers"
+
+#: builtin/ls-tree.c:143
+msgid "use full path names"
+msgstr "utiliser les noms de chemins complets"
+
+#: builtin/ls-tree.c:145
+msgid "list entire tree; not just current directory (implies --full-name)"
+msgstr ""
+"afficher l'arbre entier ; pas seulement le répertoire courant (implique --"
+"full-name)"
+
+#: builtin/mailsplit.c:241
+#, c-format
+msgid "empty mbox: '%s'"
+msgstr "mbox vide : '%s'"
+
+#: builtin/merge.c:55
+msgid "git merge [<options>] [<commit>...]"
+msgstr "git merge [<options>] [<commit>...]"
+
+#: builtin/merge.c:56
+msgid "git merge --abort"
+msgstr "git merge --abort"
+
+#: builtin/merge.c:57
+msgid "git merge --continue"
+msgstr "git merge --continue"
+
+#: builtin/merge.c:118
+msgid "switch `m' requires a value"
+msgstr "le commutateur `m' a besoin d'une valeur"
+
+#: builtin/merge.c:141
+#, c-format
+msgid "option `%s' requires a value"
+msgstr "le commutateur '%s' a besoin d'une valeur"
+
+#: builtin/merge.c:187
+#, c-format
+msgid "Could not find merge strategy '%s'.\n"
+msgstr "Impossible de trouver la stratégie de fusion '%s'.\n"
+
+#: builtin/merge.c:188
+#, c-format
+msgid "Available strategies are:"
+msgstr "Les stratégies disponibles sont :"
+
+#: builtin/merge.c:193
+#, c-format
+msgid "Available custom strategies are:"
+msgstr "Les stratégies personnalisées sont :"
+
+#: builtin/merge.c:244 builtin/pull.c:152
+msgid "do not show a diffstat at the end of the merge"
+msgstr "ne pas afficher un diffstat à la fin de la fusion"
+
+#: builtin/merge.c:247 builtin/pull.c:155
+msgid "show a diffstat at the end of the merge"
+msgstr "afficher un diffstat à la fin de la fusion"
+
+#: builtin/merge.c:248 builtin/pull.c:158
+msgid "(synonym to --stat)"
+msgstr "(synonyme de --stat)"
+
+#: builtin/merge.c:250 builtin/pull.c:161
+msgid "add (at most <n>) entries from shortlog to merge commit message"
+msgstr ""
+"ajouter (au plus <n>) éléments du journal court au message de validation de "
+"la fusion"
+
+#: builtin/merge.c:253 builtin/pull.c:167
+msgid "create a single commit instead of doing a merge"
+msgstr "créer une validation unique au lieu de faire une fusion"
+
+#: builtin/merge.c:255 builtin/pull.c:170
+msgid "perform a commit if the merge succeeds (default)"
+msgstr "effectuer une validation si la fusion réussit (défaut)"
+
+#: builtin/merge.c:257 builtin/pull.c:173
+msgid "edit message before committing"
+msgstr "éditer le message avant la validation"
+
+#: builtin/merge.c:259
+msgid "allow fast-forward (default)"
+msgstr "autoriser l'avance rapide (défaut)"
+
+#: builtin/merge.c:261 builtin/pull.c:180
+msgid "abort if fast-forward is not possible"
+msgstr "abandonner si l'avance rapide n'est pas possible"
+
+#: builtin/merge.c:265 builtin/pull.c:183
+msgid "verify that the named commit has a valid GPG signature"
+msgstr "vérifier que le commit nommé a une signature GPG valide"
+
+#: builtin/merge.c:266 builtin/notes.c:787 builtin/pull.c:187
+#: builtin/rebase.c:512 builtin/rebase.c:1531 builtin/revert.c:114
+msgid "strategy"
+msgstr "stratégie"
+
+#: builtin/merge.c:267 builtin/pull.c:188
+msgid "merge strategy to use"
+msgstr "stratégie de fusion à utiliser"
+
+#: builtin/merge.c:268 builtin/pull.c:191
+msgid "option=value"
+msgstr "option=valeur"
+
+#: builtin/merge.c:269 builtin/pull.c:192
+msgid "option for selected merge strategy"
+msgstr "option pour la stratégie de fusion sélectionnée"
+
+#: builtin/merge.c:271
+msgid "merge commit message (for a non-fast-forward merge)"
+msgstr ""
+"message de validation de la fusion (pour une fusion sans avance rapide)"
+
+#: builtin/merge.c:278
+msgid "abort the current in-progress merge"
+msgstr "abandonner la fusion en cours"
+
+#: builtin/merge.c:280
+msgid "--abort but leave index and working tree alone"
+msgstr "--abort mais laisser l'index et l'arbre de travail inchangés"
+
+#: builtin/merge.c:282
+msgid "continue the current in-progress merge"
+msgstr "continuer la fusion en cours"
+
+#: builtin/merge.c:284 builtin/pull.c:199
+msgid "allow merging unrelated histories"
+msgstr "permettre la fusion d'historiques sans rapport"
+
+#: builtin/merge.c:290
+msgid "bypass pre-merge-commit and commit-msg hooks"
+msgstr "ne pas utiliser les crochets pre-merge-commit et commit-msg"
+
+#: builtin/merge.c:307
+msgid "could not run stash."
+msgstr "impossible de lancer le remisage."
+
+#: builtin/merge.c:312
+msgid "stash failed"
+msgstr "échec du remisage"
+
+#: builtin/merge.c:317
+#, c-format
+msgid "not a valid object: %s"
+msgstr "pas un objet valide : %s"
+
+#: builtin/merge.c:339 builtin/merge.c:356
+msgid "read-tree failed"
+msgstr "read-tree a échoué"
+
+#: builtin/merge.c:386
+msgid " (nothing to squash)"
+msgstr " (rien à compresser)"
+
+#: builtin/merge.c:397
+#, c-format
+msgid "Squash commit -- not updating HEAD\n"
+msgstr "Validation compressée -- HEAD non mise à jour\n"
+
+#: builtin/merge.c:447
+#, c-format
+msgid "No merge message -- not updating HEAD\n"
+msgstr "Pas de message de fusion -- pas de mise à jour de HEAD\n"
+
+#: builtin/merge.c:498
+#, c-format
+msgid "'%s' does not point to a commit"
+msgstr "'%s' ne pointe pas sur un commit"
+
+#: builtin/merge.c:585
+#, c-format
+msgid "Bad branch.%s.mergeoptions string: %s"
+msgstr "Mauvaise chaîne branch.%s.mergeoptions : %s"
+
+#: builtin/merge.c:705
+msgid "Not handling anything other than two heads merge."
+msgstr "Impossible de gérer autre chose que la fusion de deux têtes."
+
+#: builtin/merge.c:719
+#, c-format
+msgid "Unknown option for merge-recursive: -X%s"
+msgstr "Options inconnue pour merge-recursive : -X%s"
+
+#: builtin/merge.c:734
+#, c-format
+msgid "unable to write %s"
+msgstr "impossible d'écrire %s"
+
+#: builtin/merge.c:786
+#, c-format
+msgid "Could not read from '%s'"
+msgstr "Impossible de lire depuis '%s'"
+
+#: builtin/merge.c:795
+#, c-format
+msgid "Not committing merge; use 'git commit' to complete the merge.\n"
+msgstr ""
+"Pas de validation de la fusion ; utilisez 'git commit' pour terminer la "
+"fusion.\n"
+
+#: builtin/merge.c:801
+msgid ""
+"Please enter a commit message to explain why this merge is necessary,\n"
+"especially if it merges an updated upstream into a topic branch.\n"
+"\n"
+msgstr ""
+"Veuillez entrer un message de validation pour expliquer en quoi cette fusion "
+"est\n"
+"nécessaire, surtout si cela fusionne une branche amont mise à jour dans une "
+"branche de sujet.\n"
+"\n"
+
+#: builtin/merge.c:806
+msgid "An empty message aborts the commit.\n"
+msgstr "Un message vide abandonne la validation.\n"
+
+#: builtin/merge.c:809
+#, c-format
+msgid ""
+"Lines starting with '%c' will be ignored, and an empty message aborts\n"
+"the commit.\n"
+msgstr ""
+"Les lignes commençant par '%c' seront ignorées, et un message vide\n"
+"abandonne la validation.\n"
+
+#: builtin/merge.c:862
+msgid "Empty commit message."
+msgstr "Message de validation vide."
+
+#: builtin/merge.c:877
+#, c-format
+msgid "Wonderful.\n"
+msgstr "Merveilleux.\n"
+
+#: builtin/merge.c:938
+#, c-format
+msgid "Automatic merge failed; fix conflicts and then commit the result.\n"
+msgstr ""
+"La fusion automatique a échoué ; réglez les conflits et validez le "
+"résultat.\n"
+
+#: builtin/merge.c:977
+msgid "No current branch."
+msgstr "Pas de branche courante."
+
+#: builtin/merge.c:979
+msgid "No remote for the current branch."
+msgstr "Pas de branche distante pour la branche courante."
+
+#: builtin/merge.c:981
+msgid "No default upstream defined for the current branch."
+msgstr "Pas de branche amont par défaut définie pour la branche courante."
+
+#: builtin/merge.c:986
+#, c-format
+msgid "No remote-tracking branch for %s from %s"
+msgstr "Pas de branche de suivi pour %s depuis %s"
+
+#: builtin/merge.c:1043
+#, c-format
+msgid "Bad value '%s' in environment '%s'"
+msgstr "Mauvaise valeur '%s' dans l'environnement '%s'"
+
+#: builtin/merge.c:1146
+#, c-format
+msgid "not something we can merge in %s: %s"
+msgstr "pas possible de fusionner ceci dans %s : %s"
+
+#: builtin/merge.c:1180
+msgid "not something we can merge"
+msgstr "pas possible de fusionner ceci"
+
+#: builtin/merge.c:1283
+msgid "--abort expects no arguments"
+msgstr "--abort n'accepte pas d'argument"
+
+#: builtin/merge.c:1287
+msgid "There is no merge to abort (MERGE_HEAD missing)."
+msgstr "Il n'y a pas de fusion à abandonner (MERGE_HEAD manquant)."
+
+#: builtin/merge.c:1296
+msgid "--quit expects no arguments"
+msgstr "--quit n'accepte pas d'argument"
+
+#: builtin/merge.c:1309
+msgid "--continue expects no arguments"
+msgstr "--continue ne supporte aucun argument"
+
+#: builtin/merge.c:1313
+msgid "There is no merge in progress (MERGE_HEAD missing)."
+msgstr "Il n'y a pas de fusion en cours (MERGE_HEAD manquant)."
+
+#: builtin/merge.c:1329
+msgid ""
+"You have not concluded your merge (MERGE_HEAD exists).\n"
+"Please, commit your changes before you merge."
+msgstr ""
+"Vous n'avez pas terminé votre fusion (MERGE_HEAD existe).\n"
+"Veuillez valider vos modifications avant de pouvoir fusionner."
+
+#: builtin/merge.c:1336
+msgid ""
+"You have not concluded your cherry-pick (CHERRY_PICK_HEAD exists).\n"
+"Please, commit your changes before you merge."
+msgstr ""
+"Vous n'avez pas terminé votre picorage (CHERRY_PICK_HEAD existe).\n"
+"Veuillez valider vos modifications avant de pouvoir fusionner."
+
+#: builtin/merge.c:1339
+msgid "You have not concluded your cherry-pick (CHERRY_PICK_HEAD exists)."
+msgstr "Vous n'avez pas terminé votre picorage (CHERRY_PICK_HEAD existe)."
+
+#: builtin/merge.c:1353
+msgid "You cannot combine --squash with --no-ff."
+msgstr "Vous ne pouvez pas combiner --squash avec --no-ff."
+
+#: builtin/merge.c:1355
+msgid "You cannot combine --squash with --commit."
+msgstr "Vous ne pouvez pas combiner --squash avec --commit."
+
+#: builtin/merge.c:1371
+msgid "No commit specified and merge.defaultToUpstream not set."
+msgstr ""
+"Pas de validation spécifiée et merge.defaultToUpstream n'est pas défini."
+
+#: builtin/merge.c:1388
+msgid "Squash commit into empty head not supported yet"
+msgstr "La validation compressée vers une tête vide n'est pas encore supportée"
+
+#: builtin/merge.c:1390
+msgid "Non-fast-forward commit does not make sense into an empty head"
+msgstr "Une validation sans avance rapide n'a pas de sens dans une tête vide"
+
+#: builtin/merge.c:1395
+#, c-format
+msgid "%s - not something we can merge"
+msgstr "%s - pas possible de fusionner ceci"
+
+#: builtin/merge.c:1397
+msgid "Can merge only exactly one commit into empty head"
+msgstr ""
+"Possible de fusionner exactement une seule validation dans une tête vide"
+
+#: builtin/merge.c:1476
+msgid "refusing to merge unrelated histories"
+msgstr "refus de fusionner des historiques sans relation"
+
+#: builtin/merge.c:1485
+msgid "Already up to date."
+msgstr "Déjà à jour."
+
+#: builtin/merge.c:1495
+#, c-format
+msgid "Updating %s..%s\n"
+msgstr "Mise à jour %s..%s\n"
+
+#: builtin/merge.c:1537
+#, c-format
+msgid "Trying really trivial in-index merge...\n"
+msgstr "Essai de fusion vraiment triviale dans l'index...\n"
+
+#: builtin/merge.c:1544
+#, c-format
+msgid "Nope.\n"
+msgstr "Non.\n"
+
+#: builtin/merge.c:1569
+msgid "Already up to date. Yeeah!"
+msgstr "Déjà à jour. Ouais !"
+
+#: builtin/merge.c:1575
+msgid "Not possible to fast-forward, aborting."
+msgstr "Pas possible d'avancer rapidement, abandon."
+
+#: builtin/merge.c:1598 builtin/merge.c:1663
+#, c-format
+msgid "Rewinding the tree to pristine...\n"
+msgstr "Retour de l'arbre à l'original...\n"
+
+#: builtin/merge.c:1602
+#, c-format
+msgid "Trying merge strategy %s...\n"
+msgstr "Essai de la stratégie de fusion %s...\n"
+
+#: builtin/merge.c:1654
+#, c-format
+msgid "No merge strategy handled the merge.\n"
+msgstr "Aucune stratégie de fusion n'a pris en charge la fusion.\n"
+
+#: builtin/merge.c:1656
+#, c-format
+msgid "Merge with strategy %s failed.\n"
+msgstr "La fusion avec la stratégie %s a échoué.\n"
+
+#: builtin/merge.c:1665
+#, c-format
+msgid "Using the %s to prepare resolving by hand.\n"
+msgstr "Utilisation de %s pour préparer la résolution à la main.\n"
+
+#: builtin/merge.c:1677
+#, c-format
+msgid "Automatic merge went well; stopped before committing as requested\n"
+msgstr ""
+"La fusion automatique a réussi ; stoppée avant la validation comme demandé\n"
+
+#: builtin/merge-base.c:32
+msgid "git merge-base [-a | --all] <commit> <commit>..."
+msgstr "git merge-base [-a | --all] <commit> <commit>..."
+
+#: builtin/merge-base.c:33
+msgid "git merge-base [-a | --all] --octopus <commit>..."
+msgstr "git merge-base [-a | --all] --octopus <commit>..."
+
+#: builtin/merge-base.c:34
+msgid "git merge-base --independent <commit>..."
+msgstr "git merge-base --independent <validation>..."
+
+#: builtin/merge-base.c:35
+msgid "git merge-base --is-ancestor <commit> <commit>"
+msgstr "git merge-base --is-ancestor <validation> <validation>"
+
+#: builtin/merge-base.c:36
+msgid "git merge-base --fork-point <ref> [<commit>]"
+msgstr "git merge-base --fork-point <référence> [<validation>]"
+
+#: builtin/merge-base.c:153
+msgid "output all common ancestors"
+msgstr "afficher tous les ancêtres communs"
+
+#: builtin/merge-base.c:155
+msgid "find ancestors for a single n-way merge"
+msgstr "trouver les ancêtres pour une fusion simple à n points"
+
+#: builtin/merge-base.c:157
+msgid "list revs not reachable from others"
+msgstr "afficher les révisions inaccessibles depuis les autres"
+
+#: builtin/merge-base.c:159
+msgid "is the first one ancestor of the other?"
+msgstr "est le premier ancêtre de l'autre ?"
+
+#: builtin/merge-base.c:161
+msgid "find where <commit> forked from reflog of <ref>"
+msgstr "trouver où <validation> a divergé du reflog de <référence>"
+
+#: builtin/merge-file.c:9
+msgid ""
+"git merge-file [<options>] [-L <name1> [-L <orig> [-L <name2>]]] <file1> "
+"<orig-file> <file2>"
+msgstr ""
+"git merge-file [<options>] [-L <nom1> [-L <orig> [-L <nom2>]]] <fichier1> "
+"<fichier-orig> <fichier2>"
+
+#: builtin/merge-file.c:35
+msgid "send results to standard output"
+msgstr "envoyer les résultats sur la sortie standard"
+
+#: builtin/merge-file.c:36
+msgid "use a diff3 based merge"
+msgstr "utiliser une fusion basée sur diff3"
+
+#: builtin/merge-file.c:37
+msgid "for conflicts, use our version"
+msgstr "pour les conflits, utiliser notre version (our)"
+
+#: builtin/merge-file.c:39
+msgid "for conflicts, use their version"
+msgstr "pour les conflits, utiliser leur version (their)"
+
+#: builtin/merge-file.c:41
+msgid "for conflicts, use a union version"
+msgstr "pour les conflits, utiliser l'ensemble des versions"
+
+#: builtin/merge-file.c:44
+msgid "for conflicts, use this marker size"
+msgstr "pour les conflits, utiliser cette taille de marqueur"
+
+#: builtin/merge-file.c:45
+msgid "do not warn about conflicts"
+msgstr "ne pas avertir à propos des conflits"
+
+#: builtin/merge-file.c:47
+msgid "set labels for file1/orig-file/file2"
+msgstr "définir les labels pour fichier1/fichier-orig/fichier2"
+
+#: builtin/merge-recursive.c:47
+#, c-format
+msgid "unknown option %s"
+msgstr "option inconnue %s"
+
+#: builtin/merge-recursive.c:53
+#, c-format
+msgid "could not parse object '%s'"
+msgstr "Impossible d'analyser l'objet '%s'"
+
+#: builtin/merge-recursive.c:57
+#, c-format
+msgid "cannot handle more than %d base. Ignoring %s."
+msgid_plural "cannot handle more than %d bases. Ignoring %s."
+msgstr[0] "impossible de gérer plus de %d base. %s ignoré."
+msgstr[1] "impossible de gérer plus de %d bases. %s ignoré."
+
+#: builtin/merge-recursive.c:65
+msgid "not handling anything other than two heads merge."
+msgstr "impossible de gérer autre chose que la fusion de deux têtes."
+
+#: builtin/merge-recursive.c:74 builtin/merge-recursive.c:76
+#, c-format
+msgid "could not resolve ref '%s'"
+msgstr "impossible de résoudre la référence '%s'"
+
+#: builtin/merge-recursive.c:82
+#, c-format
+msgid "Merging %s with %s\n"
+msgstr "Fusion de %s avec %s\n"
+
+#: builtin/mktree.c:66
+msgid "git mktree [-z] [--missing] [--batch]"
+msgstr "git mktree [-z] [--missing] [--batch]"
+
+#: builtin/mktree.c:154
+msgid "input is NUL terminated"
+msgstr "l'entrée se termine par NUL"
+
+#: builtin/mktree.c:155 builtin/write-tree.c:26
+msgid "allow missing objects"
+msgstr "autoriser les objets manquants"
+
+#: builtin/mktree.c:156
+msgid "allow creation of more than one tree"
+msgstr "autoriser la création de plus d'un arbre"
+
+#: builtin/multi-pack-index.c:9
+msgid ""
+"git multi-pack-index [<options>] (write|verify|expire|repack --batch-"
+"size=<size>)"
+msgstr "git multi-pack-index [<options>] (write|verify|expire|repack --batch-size=<taille>)"
+
+#: builtin/multi-pack-index.c:26
+msgid "object directory containing set of packfile and pack-index pairs"
+msgstr ""
+"répertoire objet contenant un ensemble de paires de fichiers paquet et "
+"d'index de paquet"
+
+#: builtin/multi-pack-index.c:29
+msgid ""
+"during repack, collect pack-files of smaller size into a batch that is "
+"larger than this size"
+msgstr ""
+"pendant le repaquetage, collecter les fichiers paquet de plus petite taille "
+"dans un lot plus grand que cette taille"
+
+#: builtin/multi-pack-index.c:50 builtin/prune-packed.c:67
+msgid "too many arguments"
+msgstr "trop d'arguments"
+
+#: builtin/multi-pack-index.c:60
+msgid "--batch-size option is only for 'repack' subcommand"
+msgstr "l'option --batch-size ne sert que pour la sous-commande 'repack'"
+
+#: builtin/multi-pack-index.c:69
+#, c-format
+msgid "unrecognized subcommand: %s"
+msgstr "sous-commande non reconnue : %s"
+
+#: builtin/mv.c:18
+msgid "git mv [<options>] <source>... <destination>"
+msgstr "git mv [<options>] <source>... <destination>"
+
+#: builtin/mv.c:83
+#, c-format
+msgid "Directory %s is in index and no submodule?"
+msgstr "Le répertoire %s est dans l'index et pourtant aucun sous-module ?"
+
+#: builtin/mv.c:85
+msgid "Please stage your changes to .gitmodules or stash them to proceed"
+msgstr ""
+"Veuillez indexer vos modifications de .gitmodules ou les remiser pour "
+"continuer"
+
+#: builtin/mv.c:103
+#, c-format
+msgid "%.*s is in index"
+msgstr "%.*s est dans l'index"
+
+#: builtin/mv.c:125
+msgid "force move/rename even if target exists"
+msgstr "forcer le déplacement/renommage même si la cible existe"
+
+#: builtin/mv.c:127
+msgid "skip move/rename errors"
+msgstr "sauter les erreurs de déplacement/renommage"
+
+#: builtin/mv.c:169
+#, c-format
+msgid "destination '%s' is not a directory"
+msgstr "la destination '%s' n'est pas un répertoire"
+
+#: builtin/mv.c:180
+#, c-format
+msgid "Checking rename of '%s' to '%s'\n"
+msgstr "Vérification du renommage de '%s' en '%s'\n"
+
+#: builtin/mv.c:184
+msgid "bad source"
+msgstr "mauvaise source"
+
+#: builtin/mv.c:187
+msgid "can not move directory into itself"
+msgstr "impossible de déplacer un répertoire dans lui-même"
+
+#: builtin/mv.c:190
+msgid "cannot move directory over file"
+msgstr "impossible de déplacer un répertoire sur un fichier"
+
+#: builtin/mv.c:199
+msgid "source directory is empty"
+msgstr "le répertoire source est vide"
+
+#: builtin/mv.c:224
+msgid "not under version control"
+msgstr "pas sous le contrôle de version"
+
+#: builtin/mv.c:227
+msgid "destination exists"
+msgstr "la destination existe"
+
+#: builtin/mv.c:235
+#, c-format
+msgid "overwriting '%s'"
+msgstr "écrasement de '%s'"
+
+#: builtin/mv.c:238
+msgid "Cannot overwrite"
+msgstr "Impossible d'écraser"
+
+#: builtin/mv.c:241
+msgid "multiple sources for the same target"
+msgstr "multiples sources pour la même destination"
+
+#: builtin/mv.c:243
+msgid "destination directory does not exist"
+msgstr "le répertoire de destination n'existe pas"
+
+#: builtin/mv.c:250
+#, c-format
+msgid "%s, source=%s, destination=%s"
+msgstr "%s, source=%s, destination=%s"
+
+#: builtin/mv.c:271
+#, c-format
+msgid "Renaming %s to %s\n"
+msgstr "Renommage de %s en %s\n"
+
+#: builtin/mv.c:277 builtin/remote.c:716 builtin/repack.c:518
+#, c-format
+msgid "renaming '%s' failed"
+msgstr "le renommage de '%s' a échoué"
+
+#: builtin/name-rev.c:403
+msgid "git name-rev [<options>] <commit>..."
+msgstr "git name-rev [<options>] <validation>..."
+
+#: builtin/name-rev.c:404
+msgid "git name-rev [<options>] --all"
+msgstr "git name-rev [<options>] --all"
+
+#: builtin/name-rev.c:405
+msgid "git name-rev [<options>] --stdin"
+msgstr "git name-rev [<options>] --stdin"
+
+#: builtin/name-rev.c:462
+msgid "print only names (no SHA-1)"
+msgstr "afficher seulement les noms (pas de SHA-1)"
+
+#: builtin/name-rev.c:463
+msgid "only use tags to name the commits"
+msgstr "utiliser seulement les étiquettes pour nommer les validations"
+
+#: builtin/name-rev.c:465
+msgid "only use refs matching <pattern>"
+msgstr "utiliser seulement les références correspondant à <motif>"
+
+#: builtin/name-rev.c:467
+msgid "ignore refs matching <pattern>"
+msgstr "ignorer les références correspondant à <motif>"
+
+#: builtin/name-rev.c:469
+msgid "list all commits reachable from all refs"
+msgstr ""
+"afficher toutes les validations accessibles depuis toutes les références"
+
+#: builtin/name-rev.c:470
+msgid "read from stdin"
+msgstr "lire depuis l'entrée standard"
+
+#: builtin/name-rev.c:471
+msgid "allow to print `undefined` names (default)"
+msgstr "autoriser l'affichage des noms `non définis` (par défaut)"
+
+#: builtin/name-rev.c:477
+msgid "dereference tags in the input (internal use)"
+msgstr "déréférencer les étiquettes en entrée (usage interne)"
+
+#: builtin/notes.c:28
+msgid "git notes [--ref <notes-ref>] [list [<object>]]"
+msgstr "git notes [--ref <références-notes>] [list [<object>]]"
+
+#: builtin/notes.c:29
+msgid ""
+"git notes [--ref <notes-ref>] add [-f] [--allow-empty] [-m <msg> | -F <file> "
+"| (-c | -C) <object>] [<object>]"
+msgstr ""
+"git notes [--ref <références-notes>] add [-f] [--allow-empty] [-m <message> "
+"| -F <fichier> | (-c | -C) <objet>] [<objet>]"
+
+#: builtin/notes.c:30
+msgid "git notes [--ref <notes-ref>] copy [-f] <from-object> <to-object>"
+msgstr ""
+"git notes [--ref <références-notes>] copy [-f] <depuis-objet> <vers-objet>"
+
+#: builtin/notes.c:31
+msgid ""
+"git notes [--ref <notes-ref>] append [--allow-empty] [-m <msg> | -F <file> | "
+"(-c | -C) <object>] [<object>]"
+msgstr ""
+"git notes [--ref <références-notes>] append [--allow-empty] [-m <message> | -"
+"F <fichier> | (-c | -C) <objet>] [<objet>]"
+
+#: builtin/notes.c:32
+msgid "git notes [--ref <notes-ref>] edit [--allow-empty] [<object>]"
+msgstr "git notes [--ref <références-notes>] edit [--allow-empty] [<objet>]"
+
+#: builtin/notes.c:33
+msgid "git notes [--ref <notes-ref>] show [<object>]"
+msgstr "git notes [--ref <références-notes>] show [<objet>]"
+
+#: builtin/notes.c:34
+msgid ""
+"git notes [--ref <notes-ref>] merge [-v | -q] [-s <strategy>] <notes-ref>"
+msgstr ""
+"git notes [--ref <références-notes>] merge [-v | -q] [-s <stratégie> ] "
+"<références-notes>"
+
+#: builtin/notes.c:35
+msgid "git notes merge --commit [-v | -q]"
+msgstr "git notes merge --commit [-v | -q]"
+
+#: builtin/notes.c:36
+msgid "git notes merge --abort [-v | -q]"
+msgstr "git notes merge --abort [-v | -q]"
+
+#: builtin/notes.c:37
+msgid "git notes [--ref <notes-ref>] remove [<object>...]"
+msgstr "git notes [--ref <références-notes>] remove [<objet>...]"
+
+#: builtin/notes.c:38
+msgid "git notes [--ref <notes-ref>] prune [-n] [-v]"
+msgstr "git notes [--ref <référence-notes>] prune [-n] [-v]"
+
+#: builtin/notes.c:39
+msgid "git notes [--ref <notes-ref>] get-ref"
+msgstr "git notes [--ref <références-notes>] get-ref"
+
+#: builtin/notes.c:44
+msgid "git notes [list [<object>]]"
+msgstr "git notes [list [<objet>]]"
+
+#: builtin/notes.c:49
+msgid "git notes add [<options>] [<object>]"
+msgstr "git notes add [<options>] [<objet>]"
+
+#: builtin/notes.c:54
+msgid "git notes copy [<options>] <from-object> <to-object>"
+msgstr "git notes copy [<options>] <depuis-objet> <vers-objet>"
+
+#: builtin/notes.c:55
+msgid "git notes copy --stdin [<from-object> <to-object>]..."
+msgstr "git notes copy --stdin [<depuis-objet> <vers-objet>]..."
+
+#: builtin/notes.c:60
+msgid "git notes append [<options>] [<object>]"
+msgstr "git notes append [<options>] [<objet>]"
+
+#: builtin/notes.c:65
+msgid "git notes edit [<object>]"
+msgstr "git notes edit [<objet>]"
+
+#: builtin/notes.c:70
+msgid "git notes show [<object>]"
+msgstr "git notes show [<objet>]"
+
+#: builtin/notes.c:75
+msgid "git notes merge [<options>] <notes-ref>"
+msgstr "git notes merge [<options>] <références-notes>"
+
+#: builtin/notes.c:76
+msgid "git notes merge --commit [<options>]"
+msgstr "git notes merge --commit [<options>]"
+
+#: builtin/notes.c:77
+msgid "git notes merge --abort [<options>]"
+msgstr "git notes merge --abort [<options>]"
+
+#: builtin/notes.c:82
+msgid "git notes remove [<object>]"
+msgstr "git notes remove [<objet>]"
+
+#: builtin/notes.c:87
+msgid "git notes prune [<options>]"
+msgstr "git notes prune [<options>]"
+
+#: builtin/notes.c:92
+msgid "git notes get-ref"
+msgstr "git notes get-ref"
+
+#: builtin/notes.c:97
+msgid "Write/edit the notes for the following object:"
+msgstr "Écrire/éditer les notes pour l'objet suivant :"
+
+#: builtin/notes.c:150
+#, c-format
+msgid "unable to start 'show' for object '%s'"
+msgstr "impossible de démarrer 'show' pour l'objet '%s'"
+
+#: builtin/notes.c:154
+msgid "could not read 'show' output"
+msgstr "impossible de lire la sortie de 'show'"
+
+#: builtin/notes.c:162
+#, c-format
+msgid "failed to finish 'show' for object '%s'"
+msgstr "impossible de finir 'show' pour l'objet '%s'"
+
+#: builtin/notes.c:197
+msgid "please supply the note contents using either -m or -F option"
+msgstr "veuillez fournir le contenu de la note en utilisant l'option -m ou -F"
+
+#: builtin/notes.c:206
+msgid "unable to write note object"
+msgstr "impossible d'écrire l'objet note"
+
+#: builtin/notes.c:208
+#, c-format
+msgid "the note contents have been left in %s"
+msgstr "le contenu de la note a été laissé dans %s"
+
+#: builtin/notes.c:242 builtin/tag.c:532
+#, c-format
+msgid "could not open or read '%s'"
+msgstr "impossible d'ouvrir ou lire '%s'"
+
+#: builtin/notes.c:263 builtin/notes.c:313 builtin/notes.c:315
+#: builtin/notes.c:383 builtin/notes.c:438 builtin/notes.c:526
+#: builtin/notes.c:531 builtin/notes.c:610 builtin/notes.c:672
+#, c-format
+msgid "failed to resolve '%s' as a valid ref."
+msgstr "impossible de résoudre '%s' comme une référence valide."
+
+#: builtin/notes.c:265
+#, c-format
+msgid "failed to read object '%s'."
+msgstr "impossible de lire l'objet '%s'."
+
+#: builtin/notes.c:268
+#, c-format
+msgid "cannot read note data from non-blob object '%s'."
+msgstr "impossible de lire les informations de note d'un objet non-blob '%s'."
+
+#: builtin/notes.c:309
+#, c-format
+msgid "malformed input line: '%s'."
+msgstr "ligne en entrée malformée : '%s'."
+
+#: builtin/notes.c:324
+#, c-format
+msgid "failed to copy notes from '%s' to '%s'"
+msgstr "impossible de copier les notes de '%s' vers '%s'"
+
+#. TRANSLATORS: the first %s will be replaced by a git
+#. notes command: 'add', 'merge', 'remove', etc.
+#.
+#: builtin/notes.c:356
+#, c-format
+msgid "refusing to %s notes in %s (outside of refs/notes/)"
+msgstr "Refus de faire %s sur des notes dans %s (hors de refs/notes/)"
+
+#: builtin/notes.c:376 builtin/notes.c:431 builtin/notes.c:509
+#: builtin/notes.c:521 builtin/notes.c:598 builtin/notes.c:665
+#: builtin/notes.c:815 builtin/notes.c:963 builtin/notes.c:985
+msgid "too many parameters"
+msgstr "trop de paramètres"
+
+#: builtin/notes.c:389 builtin/notes.c:678
+#, c-format
+msgid "no note found for object %s."
+msgstr "pas de note trouvée pour l'objet %s."
+
+#: builtin/notes.c:410 builtin/notes.c:576
+msgid "note contents as a string"
+msgstr "contenu de la note sous forme de chaîne"
+
+#: builtin/notes.c:413 builtin/notes.c:579
+msgid "note contents in a file"
+msgstr "contenu de la note dans un fichier"
+
+#: builtin/notes.c:416 builtin/notes.c:582
+msgid "reuse and edit specified note object"
+msgstr "réutiliser et éditer l'objet de note spécifié"
+
+#: builtin/notes.c:419 builtin/notes.c:585
+msgid "reuse specified note object"
+msgstr "réutiliser l'objet de note spécifié"
+
+#: builtin/notes.c:422 builtin/notes.c:588
+msgid "allow storing empty note"
+msgstr "permettre de stocker une note vide"
+
+#: builtin/notes.c:423 builtin/notes.c:496
+msgid "replace existing notes"
+msgstr "remplacer les notes existantes"
+
+#: builtin/notes.c:448
+#, c-format
+msgid ""
+"Cannot add notes. Found existing notes for object %s. Use '-f' to overwrite "
+"existing notes"
+msgstr ""
+"Impossible d'ajouter des notes. Des notes ont été trouvées pour l'objet %s. "
+"Utilisez '-f' pour écraser les notes existantes"
+
+#: builtin/notes.c:463 builtin/notes.c:544
+#, c-format
+msgid "Overwriting existing notes for object %s\n"
+msgstr "Écrasement des notes existantes pour l'objet %s\n"
+
+#: builtin/notes.c:475 builtin/notes.c:637 builtin/notes.c:902
+#, c-format
+msgid "Removing note for object %s\n"
+msgstr "Suppression de la note pour l'objet %s\n"
+
+#: builtin/notes.c:497
+msgid "read objects from stdin"
+msgstr "lire les objets depuis l'entrée standard"
+
+#: builtin/notes.c:499
+msgid "load rewriting config for <command> (implies --stdin)"
+msgstr ""
+"charger la configuration de réécriture pour <commande> (implique --stdin)"
+
+#: builtin/notes.c:517
+msgid "too few parameters"
+msgstr "pas assez de paramètres"
+
+#: builtin/notes.c:538
+#, c-format
+msgid ""
+"Cannot copy notes. Found existing notes for object %s. Use '-f' to overwrite "
+"existing notes"
+msgstr ""
+"Impossible de copier des notes. Des notes ont été trouvées pour l'objet %s. "
+"Utilisez '-f' pour écraser les notes existantes"
+
+#: builtin/notes.c:550
+#, c-format
+msgid "missing notes on source object %s. Cannot copy."
+msgstr "notes manquantes sur l'objet source %s. Impossible de copier."
+
+#: builtin/notes.c:603
+#, c-format
+msgid ""
+"The -m/-F/-c/-C options have been deprecated for the 'edit' subcommand.\n"
+"Please use 'git notes add -f -m/-F/-c/-C' instead.\n"
+msgstr ""
+"Les options -m/-F/-c/-C sont obsolètes pour la sous-commande 'edit'.\n"
+"Veuillez utiliser 'git notes add -f -m/-F/-c/-C' à la place.\n"
+
+#: builtin/notes.c:698
+msgid "failed to delete ref NOTES_MERGE_PARTIAL"
+msgstr "échec de la suppression de la référence NOTES_MERGE_PARTIAL"
+
+#: builtin/notes.c:700
+msgid "failed to delete ref NOTES_MERGE_REF"
+msgstr "échec de la suppression de la référence NOTES_MERGE_REF"
+
+#: builtin/notes.c:702
+msgid "failed to remove 'git notes merge' worktree"
+msgstr "échec de la suppression de la copie de travail 'git notes merge'"
+
+#: builtin/notes.c:722
+msgid "failed to read ref NOTES_MERGE_PARTIAL"
+msgstr "échec de la lecture de la référence NOTES_MERGE_PARTIAL"
+
+#: builtin/notes.c:724
+msgid "could not find commit from NOTES_MERGE_PARTIAL."
+msgstr "impossible de trouver le commit de NOTES_MERGE_PARTIAL."
+
+#: builtin/notes.c:726
+msgid "could not parse commit from NOTES_MERGE_PARTIAL."
+msgstr "impossible d'analyser le commit de NOTES_MERGE_PARTIAL."
+
+#: builtin/notes.c:739
+msgid "failed to resolve NOTES_MERGE_REF"
+msgstr "échec de la résolution de NOTES_MERGE_REF"
+
+#: builtin/notes.c:742
+msgid "failed to finalize notes merge"
+msgstr "impossible de finaliser la fusion de notes"
+
+#: builtin/notes.c:768
+#, c-format
+msgid "unknown notes merge strategy %s"
+msgstr "stratégie de fusion de notes inconnue %s"
+
+#: builtin/notes.c:784
+msgid "General options"
+msgstr "Options générales"
+
+#: builtin/notes.c:786
+msgid "Merge options"
+msgstr "Options de fusion"
+
+#: builtin/notes.c:788
+msgid ""
+"resolve notes conflicts using the given strategy (manual/ours/theirs/union/"
+"cat_sort_uniq)"
+msgstr ""
+"résoudre les conflits de notes en utilisant la stratégie donnée (manual/ours/"
+"theirs/union/cat_sort_uniq)"
+
+#: builtin/notes.c:790
+msgid "Committing unmerged notes"
+msgstr "Validation des notes non fusionnées"
+
+#: builtin/notes.c:792
+msgid "finalize notes merge by committing unmerged notes"
+msgstr "finaliser la fusion de notes en validant les notes non fusionnées"
+
+#: builtin/notes.c:794
+msgid "Aborting notes merge resolution"
+msgstr "Abandon de la résolution de fusion des notes"
+
+#: builtin/notes.c:796
+msgid "abort notes merge"
+msgstr "abandonner la fusion de notes"
+
+#: builtin/notes.c:807
+msgid "cannot mix --commit, --abort or -s/--strategy"
+msgstr "--commit, --abort et -s/--strategy sont mutuellement incompatibles"
+
+#: builtin/notes.c:812
+msgid "must specify a notes ref to merge"
+msgstr "vous devez spécifier une référence de notes à fusionner"
+
+#: builtin/notes.c:836
+#, c-format
+msgid "unknown -s/--strategy: %s"
+msgstr "-s/--strategy inconnu : %s"
+
+#: builtin/notes.c:873
+#, c-format
+msgid "a notes merge into %s is already in-progress at %s"
+msgstr "une fusion de notes dans %s est déjà en cours avec %s"
+
+#: builtin/notes.c:876
+#, c-format
+msgid "failed to store link to current notes ref (%s)"
+msgstr ""
+"impossible de stocker le lien vers la référence actuelle aux notes (%s)"
+
+#: builtin/notes.c:878
+#, c-format
+msgid ""
+"Automatic notes merge failed. Fix conflicts in %s and commit the result with "
+"'git notes merge --commit', or abort the merge with 'git notes merge --"
+"abort'.\n"
+msgstr ""
+"La fusion automatique des notes a échoué. Corrigez les conflits dans %s et "
+"validez le résultat avec 'git notes merges --commit', ou abandonnez la "
+"fusion avec 'git notes merge --abort'.\n"
+
+#: builtin/notes.c:897 builtin/tag.c:545
+#, c-format
+msgid "Failed to resolve '%s' as a valid ref."
+msgstr "Impossible de résoudre '%s' comme une référence valide."
+
+#: builtin/notes.c:900
+#, c-format
+msgid "Object %s has no note\n"
+msgstr "L'objet %s n'a pas de note\n"
+
+#: builtin/notes.c:912
+msgid "attempt to remove non-existent note is not an error"
+msgstr ""
+"la tentative de suppression d'une note non existante n'est pas une erreur"
+
+#: builtin/notes.c:915
+msgid "read object names from the standard input"
+msgstr "lire les noms d'objet depuis l'entrée standard"
+
+#: builtin/notes.c:954 builtin/prune.c:130 builtin/worktree.c:164
+msgid "do not remove, show only"
+msgstr "ne pas supprimer, afficher seulement"
+
+#: builtin/notes.c:955
+msgid "report pruned notes"
+msgstr "afficher les notes éliminées"
+
+#: builtin/notes.c:998
+msgid "notes-ref"
+msgstr "références-notes"
+
+#: builtin/notes.c:999
+msgid "use notes from <notes-ref>"
+msgstr "utiliser les notes depuis <références-notes>"
+
+#: builtin/notes.c:1034 builtin/stash.c:1607
+#, c-format
+msgid "unknown subcommand: %s"
+msgstr "sous-commande inconnue : %s"
+
+#: builtin/pack-objects.c:52
+msgid ""
+"git pack-objects --stdout [<options>...] [< <ref-list> | < <object-list>]"
+msgstr ""
+"git pack-objects --stdout [options...] [< <liste-références> | < <liste-"
+"objets>]"
+
+#: builtin/pack-objects.c:53
+msgid ""
+"git pack-objects [<options>...] <base-name> [< <ref-list> | < <object-list>]"
+msgstr ""
+"git pack-objects [options...] base-name [< <liste-références> | < <liste-"
+"objets>]"
+
+#: builtin/pack-objects.c:428
+#, c-format
+msgid "bad packed object CRC for %s"
+msgstr "mauvais CRC d'objet empaqueté pour %s"
+
+#: builtin/pack-objects.c:439
+#, c-format
+msgid "corrupt packed object for %s"
+msgstr "objet empaqueté corrompu pour %s"
+
+#: builtin/pack-objects.c:570
+#, c-format
+msgid "recursive delta detected for object %s"
+msgstr "delta récursif détecté pour l'objet %s"
+
+#: builtin/pack-objects.c:781
+#, c-format
+msgid "ordered %u objects, expected %<PRIu32>"
+msgstr "%u objets commandés, %<PRIu32> attendus"
+
+#: builtin/pack-objects.c:794
+#, c-format
+msgid "packfile is invalid: %s"
+msgstr "le fichier packet est invalide : %s"
+
+#: builtin/pack-objects.c:798
+#, c-format
+msgid "unable to open packfile for reuse: %s"
+msgstr "ouverture du fichier paquet pour réutilisation impossible : %s"
+
+#: builtin/pack-objects.c:802
+msgid "unable to seek in reused packfile"
+msgstr "impossible de rechercher (seek) dans le fichier paquet réutilisé"
+
+#: builtin/pack-objects.c:813
+msgid "unable to read from reused packfile"
+msgstr "lecture du fichier de paquet réutilisé impossible"
+
+#: builtin/pack-objects.c:841
+msgid "disabling bitmap writing, packs are split due to pack.packSizeLimit"
+msgstr ""
+"désactivation de l'écriture en bitmap, les fichiers paquets sont scindés à "
+"cause de pack.packSizeLimit"
+
+#: builtin/pack-objects.c:854
+msgid "Writing objects"
+msgstr "Écriture des objets"
+
+#: builtin/pack-objects.c:917 builtin/update-index.c:90
+#, c-format
+msgid "failed to stat %s"
+msgstr "échec du stat de %s"
+
+#: builtin/pack-objects.c:970
+#, c-format
+msgid "wrote %<PRIu32> objects while expecting %<PRIu32>"
+msgstr "%<PRIu32> objets écrits, %<PRIu32> attendus"
+
+#: builtin/pack-objects.c:1164
+msgid "disabling bitmap writing, as some objects are not being packed"
+msgstr ""
+"désactivation de l'écriture en bitmap car certains objets ne sont pas "
+"compressés"
+
+#: builtin/pack-objects.c:1592
+#, c-format
+msgid "delta base offset overflow in pack for %s"
+msgstr "dépassement de décalage de base de delta pour %s"
+
+#: builtin/pack-objects.c:1601
+#, c-format
+msgid "delta base offset out of bound for %s"
+msgstr "décalage de base de delta est hors limite pour %s"
+
+#: builtin/pack-objects.c:1870
+msgid "Counting objects"
+msgstr "Décompte des objets"
+
+#: builtin/pack-objects.c:2000
+#, c-format
+msgid "unable to get size of %s"
+msgstr "impossible de récupérer la taille de %s"
+
+#: builtin/pack-objects.c:2015
+#, c-format
+msgid "unable to parse object header of %s"
+msgstr "impossible d'analyser l'entête d'objet de %s"
+
+#: builtin/pack-objects.c:2085 builtin/pack-objects.c:2101
+#: builtin/pack-objects.c:2111
+#, c-format
+msgid "object %s cannot be read"
+msgstr "l'objet %s ne peut être lu"
+
+#: builtin/pack-objects.c:2088 builtin/pack-objects.c:2115
+#, c-format
+msgid "object %s inconsistent object length (%<PRIuMAX> vs %<PRIuMAX>)"
+msgstr ""
+"objet %s longueur de l'objet inconsistante (%<PRIuMAX> contre %<PRIuMAX>)"
+
+#: builtin/pack-objects.c:2125
+msgid "suboptimal pack - out of memory"
+msgstr "paquet sous-optimal - mémoire insuffisante"
+
+#: builtin/pack-objects.c:2440
+#, c-format
+msgid "Delta compression using up to %d threads"
+msgstr "Compression par delta en utilisant jusqu'à %d fils d'exécution"
+
+#: builtin/pack-objects.c:2572
+#, c-format
+msgid "unable to pack objects reachable from tag %s"
+msgstr "impossible d'empaqueter les objets joignables depuis l'étiquette %s"
+
+#: builtin/pack-objects.c:2659
+msgid "Compressing objects"
+msgstr "Compression des objets"
+
+#: builtin/pack-objects.c:2665
+msgid "inconsistency with delta count"
+msgstr "inconsistance dans le compte de delta"
+
+#: builtin/pack-objects.c:2742
+#, c-format
+msgid ""
+"expected edge object ID, got garbage:\n"
+" %s"
+msgstr ""
+"ID d'objet de bord attendu, reçu des données illisibles :\n"
+"%s"
+
+#: builtin/pack-objects.c:2748
+#, c-format
+msgid ""
+"expected object ID, got garbage:\n"
+" %s"
+msgstr ""
+"ID d'objet attendu, reçu des données illisibles :\n"
+"%s"
+
+#: builtin/pack-objects.c:2846
+msgid "invalid value for --missing"
+msgstr "valeur invalide pour --missing"
+
+#: builtin/pack-objects.c:2905 builtin/pack-objects.c:3013
+msgid "cannot open pack index"
+msgstr "impossible d'ouvrir l'index de paquet"
+
+#: builtin/pack-objects.c:2936
+#, c-format
+msgid "loose object at %s could not be examined"
+msgstr "l'objet libre à %s n'a pas pu être examiné"
+
+#: builtin/pack-objects.c:3021
+msgid "unable to force loose object"
+msgstr "impossible de forcer l'objet libre"
+
+#: builtin/pack-objects.c:3113
+#, c-format
+msgid "not a rev '%s'"
+msgstr "'%s' n'est pas une révision"
+
+#: builtin/pack-objects.c:3116
+#, c-format
+msgid "bad revision '%s'"
+msgstr "mauvaise révision '%s'"
+
+#: builtin/pack-objects.c:3141
+msgid "unable to add recent objects"
+msgstr "impossible d'ajouter les objets récents"
+
+#: builtin/pack-objects.c:3194
+#, c-format
+msgid "unsupported index version %s"
+msgstr "version d'index non supportée %s"
+
+#: builtin/pack-objects.c:3198
+#, c-format
+msgid "bad index version '%s'"
+msgstr "mauvaise version d'index '%s'"
+
+#: builtin/pack-objects.c:3236
+msgid "<version>[,<offset>]"
+msgstr "<version>[,<décalage>]"
+
+#: builtin/pack-objects.c:3237
+msgid "write the pack index file in the specified idx format version"
+msgstr ""
+"écrire le fichier d'index du paquet dans le format d'index de version "
+"spécifié"
+
+#: builtin/pack-objects.c:3240
+msgid "maximum size of each output pack file"
+msgstr "taille maximum de chaque fichier paquet en sortie"
+
+#: builtin/pack-objects.c:3242
+msgid "ignore borrowed objects from alternate object store"
+msgstr "ignorer les objets empruntés à un autre magasin d'objets"
+
+#: builtin/pack-objects.c:3244
+msgid "ignore packed objects"
+msgstr "ignorer les objets empaquetés"
+
+#: builtin/pack-objects.c:3246
+msgid "limit pack window by objects"
+msgstr "limiter la fenêtre d'empaquetage par objets"
+
+#: builtin/pack-objects.c:3248
+msgid "limit pack window by memory in addition to object limit"
+msgstr ""
+"limiter la fenêtre d'empaquetage par mémoire en plus de la limite d'objets"
+
+#: builtin/pack-objects.c:3250
+msgid "maximum length of delta chain allowed in the resulting pack"
+msgstr ""
+"longueur maximum de la chaîne de delta autorisée dans le paquet résultant"
+
+#: builtin/pack-objects.c:3252
+msgid "reuse existing deltas"
+msgstr "réutiliser les deltas existants"
+
+#: builtin/pack-objects.c:3254
+msgid "reuse existing objects"
+msgstr "réutiliser les objets existants"
+
+#: builtin/pack-objects.c:3256
+msgid "use OFS_DELTA objects"
+msgstr "utiliser les objets OFS_DELTA"
+
+#: builtin/pack-objects.c:3258
+msgid "use threads when searching for best delta matches"
+msgstr ""
+"utiliser des fils lors de la recherche pour une meilleure correspondance des "
+"deltas"
+
+#: builtin/pack-objects.c:3260
+msgid "do not create an empty pack output"
+msgstr "ne pas créer un paquet vide"
+
+#: builtin/pack-objects.c:3262
+msgid "read revision arguments from standard input"
+msgstr "lire les paramètres de révision depuis l'entrée standard"
+
+#: builtin/pack-objects.c:3264
+msgid "limit the objects to those that are not yet packed"
+msgstr "limiter les objets à ceux qui ne sont pas encore empaquetés"
+
+#: builtin/pack-objects.c:3267
+msgid "include objects reachable from any reference"
+msgstr "inclure les objets accessibles depuis toute référence"
+
+#: builtin/pack-objects.c:3270
+msgid "include objects referred by reflog entries"
+msgstr "inclure les objets référencés par les éléments de reflog"
+
+#: builtin/pack-objects.c:3273
+msgid "include objects referred to by the index"
+msgstr "inclure les objets référencés par l'index"
+
+#: builtin/pack-objects.c:3276
+msgid "output pack to stdout"
+msgstr "afficher l'empaquetage sur la sortie standard"
+
+#: builtin/pack-objects.c:3278
+msgid "include tag objects that refer to objects to be packed"
+msgstr "inclure les objets d'étiquettes qui réfèrent à des objets à empaqueter"
+
+#: builtin/pack-objects.c:3280
+msgid "keep unreachable objects"
+msgstr "garder les objets inaccessibles"
+
+#: builtin/pack-objects.c:3282
+msgid "pack loose unreachable objects"
+msgstr "empaqueter les objets inaccessibles détachés"
+
+#: builtin/pack-objects.c:3284
+msgid "unpack unreachable objects newer than <time>"
+msgstr "dépaqueter les objets inaccessibles plus récents que <heure>"
+
+#: builtin/pack-objects.c:3287
+msgid "use the sparse reachability algorithm"
+msgstr "utiliser l'algorithme de joignabilité creuse"
+
+#: builtin/pack-objects.c:3289
+msgid "create thin packs"
+msgstr "créer des paquets légers"
+
+#: builtin/pack-objects.c:3291
+msgid "create packs suitable for shallow fetches"
+msgstr "créer des paquets permettant des récupérations superficielles"
+
+#: builtin/pack-objects.c:3293
+msgid "ignore packs that have companion .keep file"
+msgstr "ignorer les paquets qui ont un fichier .keep"
+
+#: builtin/pack-objects.c:3295
+msgid "ignore this pack"
+msgstr "ignorer ce paquet"
+
+#: builtin/pack-objects.c:3297
+msgid "pack compression level"
+msgstr "niveau de compression du paquet"
+
+#: builtin/pack-objects.c:3299
+msgid "do not hide commits by grafts"
+msgstr "ne pas cacher les validations par greffes"
+
+#: builtin/pack-objects.c:3301
+msgid "use a bitmap index if available to speed up counting objects"
+msgstr ""
+"utiliser un index en bitmap si disponible pour accélerer le décompte des "
+"objets"
+
+#: builtin/pack-objects.c:3303
+msgid "write a bitmap index together with the pack index"
+msgstr "écrire un index en bitmap associé à l'index de paquet"
+
+#: builtin/pack-objects.c:3307
+msgid "write a bitmap index if possible"
+msgstr "écrire un index de bitmap si possible"
+
+#: builtin/pack-objects.c:3311
+msgid "handling for missing objects"
+msgstr "gestion des objets manquants"
+
+#: builtin/pack-objects.c:3314
+msgid "do not pack objects in promisor packfiles"
+msgstr "ne pas empaqueter les objets dans les fichiers paquets prometteurs"
+
+#: builtin/pack-objects.c:3316
+msgid "respect islands during delta compression"
+msgstr "respecter les îlots pendant la compression des deltas"
+
+#: builtin/pack-objects.c:3345
+#, c-format
+msgid "delta chain depth %d is too deep, forcing %d"
+msgstr "la profondeur %d de chaîne de delta est trop grande, forcée à %d"
+
+#: builtin/pack-objects.c:3350
+#, c-format
+msgid "pack.deltaCacheLimit is too high, forcing %d"
+msgstr "pack.deltaCacheLimit est trop grand, forcé à %d"
+
+#: builtin/pack-objects.c:3404
+msgid "--max-pack-size cannot be used to build a pack for transfer"
+msgstr ""
+"--max-pack-size ne peut pas être utilisé pour construire un paquet à "
+"transférer"
+
+#: builtin/pack-objects.c:3406
+msgid "minimum pack size limit is 1 MiB"
+msgstr "la taille limite minimale d'un paquet est 1 MiB"
+
+#: builtin/pack-objects.c:3411
+msgid "--thin cannot be used to build an indexable pack"
+msgstr "--thin ne peut pas être utilisé pour construire un paquet indexable"
+
+#: builtin/pack-objects.c:3414
+msgid "--keep-unreachable and --unpack-unreachable are incompatible"
+msgstr "--keep-unreachable et --unpack-unreachable sont incompatibles"
+
+#: builtin/pack-objects.c:3420
+msgid "cannot use --filter without --stdout"
+msgstr "impossible d'utiliser --filter sans --stdout"
+
+#: builtin/pack-objects.c:3481
+msgid "Enumerating objects"
+msgstr "Énumération des objets"
+
+#: builtin/pack-objects.c:3511
+#, c-format
+msgid "Total %<PRIu32> (delta %<PRIu32>), reused %<PRIu32> (delta %<PRIu32>)"
+msgstr ""
+"Total %<PRIu32> (delta %<PRIu32>), réutilisés %<PRIu32> (delta %<PRIu32>)"
+
+#: builtin/pack-refs.c:8
+msgid "git pack-refs [<options>]"
+msgstr "git pack-refs [<options>]"
+
+#: builtin/pack-refs.c:16
+msgid "pack everything"
+msgstr "empaqueter tout"
+
+#: builtin/pack-refs.c:17
+msgid "prune loose refs (default)"
+msgstr "éliminer les références perdues (défaut)"
+
+#: builtin/prune-packed.c:9
+msgid "git prune-packed [-n | --dry-run] [-q | --quiet]"
+msgstr "git prune-packed [-n | --dry-run] [-q | --quiet]"
+
+#: builtin/prune-packed.c:42
+msgid "Removing duplicate objects"
+msgstr "Suppression des objets dupliqués"
+
+#: builtin/prune.c:12
+msgid "git prune [-n] [-v] [--progress] [--expire <time>] [--] [<head>...]"
+msgstr "git prune [-n] [-v] [--progress] [--expire <heure>] [--] [<head>…]"
+
+#: builtin/prune.c:131
+msgid "report pruned objects"
+msgstr "afficher les objets éliminés"
+
+#: builtin/prune.c:134
+msgid "expire objects older than <time>"
+msgstr "faire expirer les objets plus vieux que <heure>"
+
+#: builtin/prune.c:136
+msgid "limit traversal to objects outside promisor packfiles"
+msgstr "limiter la traversée aux objets hors des fichiers paquets prometteurs"
+
+#: builtin/prune.c:150
+msgid "cannot prune in a precious-objects repo"
+msgstr "impossible de nettoyer dans un dépôt d'objets précieux"
+
+#: builtin/pull.c:66 builtin/pull.c:68
+#, c-format
+msgid "Invalid value for %s: %s"
+msgstr "Valeur invalide pour %s : %s"
+
+#: builtin/pull.c:88
+msgid "git pull [<options>] [<repository> [<refspec>...]]"
+msgstr "git pull [<options>] [<dépôt> [<spécification-de-référence>...]]"
+
+#: builtin/pull.c:142
+msgid "control for recursive fetching of submodules"
+msgstr "contrôler la récupération récursive dans les sous-modules"
+
+#: builtin/pull.c:146
+msgid "Options related to merging"
+msgstr "Options relatives à la fusion"
+
+#: builtin/pull.c:149
+msgid "incorporate changes by rebasing rather than merging"
+msgstr "incorporer les modifications en rebasant plutôt qu'en fusionnant"
+
+#: builtin/pull.c:177 builtin/rebase.c:467 builtin/revert.c:126
+msgid "allow fast-forward"
+msgstr "autoriser l'avance rapide"
+
+#: builtin/pull.c:186
+msgid "automatically stash/stash pop before and after rebase"
+msgstr "remiser avant et réappliquer après le rebasage automatiquement"
+
+#: builtin/pull.c:202
+msgid "Options related to fetching"
+msgstr "Options relatives au rapatriement"
+
+#: builtin/pull.c:212
+msgid "force overwrite of local branch"
+msgstr "forcer l'écrasement de la branche locale"
+
+#: builtin/pull.c:220
+msgid "number of submodules pulled in parallel"
+msgstr "nombre de sous-modules tirés en parallèle"
+
+#: builtin/pull.c:320
+#, c-format
+msgid "Invalid value for pull.ff: %s"
+msgstr "Valeur invalide pour pull.ff : %s"
+
+#: builtin/pull.c:437
+msgid ""
+"There is no candidate for rebasing against among the refs that you just "
+"fetched."
+msgstr ""
+"Il n'y a pas de candidate sur laquelle rebaser parmi les références que vous "
+"venez de récupérer."
+
+#: builtin/pull.c:439
+msgid ""
+"There are no candidates for merging among the refs that you just fetched."
+msgstr ""
+"Il n'y a pas de candidate avec laquelle fusionner parmi les références que "
+"vous venez de récupérer."
+
+#: builtin/pull.c:440
+msgid ""
+"Generally this means that you provided a wildcard refspec which had no\n"
+"matches on the remote end."
+msgstr ""
+"Généralement, cela signifie que vous avez indiqué un spécificateur\n"
+"de référence joker qui n'a pas eu de correspondance sur le serveur distant."
+
+#: builtin/pull.c:443
+#, c-format
+msgid ""
+"You asked to pull from the remote '%s', but did not specify\n"
+"a branch. Because this is not the default configured remote\n"
+"for your current branch, you must specify a branch on the command line."
+msgstr ""
+"Vous avez demandé de tirer depuis le dépôt distant '%s', mais sans indiquer\n"
+"la branche. Comme ce n'est pas le dépôt distant par défaut dans la "
+"configuration\n"
+"pour la branche actuelle, vous devez spécifier la branche avec la commande."
+
+#: builtin/pull.c:448 builtin/rebase.c:1375 git-parse-remote.sh:73
+msgid "You are not currently on a branch."
+msgstr "Vous n'êtes actuellement sur aucune branche."
+
+#: builtin/pull.c:450 builtin/pull.c:465 git-parse-remote.sh:79
+msgid "Please specify which branch you want to rebase against."
+msgstr "Veuillez spécifier sur quelle branche vous souhaiter rebaser."
+
+#: builtin/pull.c:452 builtin/pull.c:467 git-parse-remote.sh:82
+msgid "Please specify which branch you want to merge with."
+msgstr "Veuillez spécifier une branche avec laquelle fusionner."
+
+#: builtin/pull.c:453 builtin/pull.c:468
+msgid "See git-pull(1) for details."
+msgstr "Référez-vous à git-pull(1) pour de plus amples détails."
+
+#: builtin/pull.c:455 builtin/pull.c:461 builtin/pull.c:470
+#: builtin/rebase.c:1381 git-parse-remote.sh:64
+msgid "<remote>"
+msgstr "<distant>"
+
+#: builtin/pull.c:455 builtin/pull.c:470 builtin/pull.c:475
+#: git-parse-remote.sh:65
+msgid "<branch>"
+msgstr "<branche>"
+
+#: builtin/pull.c:463 builtin/rebase.c:1373 git-parse-remote.sh:75
+msgid "There is no tracking information for the current branch."
+msgstr "Pas d'information de suivi distant pour la branche actuelle."
+
+#: builtin/pull.c:472 git-parse-remote.sh:95
+msgid ""
+"If you wish to set tracking information for this branch you can do so with:"
+msgstr ""
+"Si vous souhaitez indiquer l'information de suivi distant pour cette "
+"branche, vous pouvez le faire avec :"
+
+#: builtin/pull.c:477
+#, c-format
+msgid ""
+"Your configuration specifies to merge with the ref '%s'\n"
+"from the remote, but no such ref was fetched."
+msgstr ""
+"Votre information de configuration indique de fusionner avec la référence "
+"'%s'\n"
+"du serveur distant, mais cette référence n'a pas été récupérée."
+
+#: builtin/pull.c:587
+#, c-format
+msgid "unable to access commit %s"
+msgstr "impossible d'accéder le commit %s"
+
+#: builtin/pull.c:867
+msgid "ignoring --verify-signatures for rebase"
+msgstr "--verify-signatures est ignoré pour un rebasage"
+
+#: builtin/pull.c:922
+msgid "--[no-]autostash option is only valid with --rebase."
+msgstr "l'option --[no-]autostash n'est valide qu'avec --rebase."
+
+#: builtin/pull.c:930
+msgid "Updating an unborn branch with changes added to the index."
+msgstr ""
+"Mise à jour d'une branche non encore créée avec les changements ajoutés dans "
+"l'index."
+
+#: builtin/pull.c:934
+msgid "pull with rebase"
+msgstr "tirer avec un rebasage"
+
+#: builtin/pull.c:935
+msgid "please commit or stash them."
+msgstr "veuillez les valider ou les remiser."
+
+#: builtin/pull.c:960
+#, c-format
+msgid ""
+"fetch updated the current branch head.\n"
+"fast-forwarding your working tree from\n"
+"commit %s."
+msgstr ""
+"la récupération a mis à jour la tête de la branche actuelle.\n"
+"avance rapide de votre copie de travail\n"
+"depuis le commit %s."
+
+#: builtin/pull.c:966
+#, c-format
+msgid ""
+"Cannot fast-forward your working tree.\n"
+"After making sure that you saved anything precious from\n"
+"$ git diff %s\n"
+"output, run\n"
+"$ git reset --hard\n"
+"to recover."
+msgstr ""
+"Avance rapide de votre arbre de travail impossible.\n"
+"Après avoir vérifié que toute modification précieuse a été sauvegardée avec\n"
+"$ git diff %s\n"
+"lancez\n"
+"$ git reset --hard\n"
+"pour régénérer."
+
+#: builtin/pull.c:981
+msgid "Cannot merge multiple branches into empty head."
+msgstr "Impossible de fusionner de multiples branches sur une tête vide."
+
+#: builtin/pull.c:985
+msgid "Cannot rebase onto multiple branches."
+msgstr "Impossible de rebaser sur de multiples branches."
+
+#: builtin/pull.c:992
+msgid "cannot rebase with locally recorded submodule modifications"
+msgstr ""
+"impossible de rebaser avec des modifications de sous-modules enregistrées "
+"localement"
+
+#: builtin/push.c:19
+msgid "git push [<options>] [<repository> [<refspec>...]]"
+msgstr "git push [<options>] [<dépôt> [<spécification-de-référence>...]]"
+
+#: builtin/push.c:112
+msgid "tag shorthand without <tag>"
+msgstr "raccourci d'étiquette sans <étiquette>"
+
+#: builtin/push.c:122
+msgid "--delete only accepts plain target ref names"
+msgstr "--delete accepte seulement des noms entiers de références cibles"
+
+#: builtin/push.c:168
+msgid ""
+"\n"
+"To choose either option permanently, see push.default in 'git help config'."
+msgstr ""
+"\n"
+"Pour choisir l'option de manière permanente, voir push.default dans 'git "
+"help config'."
+
+#: builtin/push.c:171
+#, c-format
+msgid ""
+"The upstream branch of your current branch does not match\n"
+"the name of your current branch.  To push to the upstream branch\n"
+"on the remote, use\n"
+"\n"
+"    git push %s HEAD:%s\n"
+"\n"
+"To push to the branch of the same name on the remote, use\n"
+"\n"
+"    git push %s HEAD\n"
+"%s"
+msgstr ""
+"La branche amont de votre branche courante ne correspond pas\n"
+"au nom de votre branche courante.  Pour pousser vers la branche amont\n"
+"sur le serveur distant, utilisez\n"
+"\n"
+"    git push %s HEAD:%s\n"
+"\n"
+"Pour pousser vers la branche du même nom sur le serveur distant, utilisez\n"
+"\n"
+"    git push %s HEAD\n"
+"%s"
+
+#: builtin/push.c:186
+#, c-format
+msgid ""
+"You are not currently on a branch.\n"
+"To push the history leading to the current (detached HEAD)\n"
+"state now, use\n"
+"\n"
+"    git push %s HEAD:<name-of-remote-branch>\n"
+msgstr ""
+"Vous n'êtes actuellement sur aucune branche.\n"
+"Pour pousser l'historique menant à l'état actuel (HEAD détachée),\n"
+"utilisez\n"
+"\n"
+"    git push %s HEAD:<nom-de-la-branche-amont>\n"
+
+#: builtin/push.c:200
+#, c-format
+msgid ""
+"The current branch %s has no upstream branch.\n"
+"To push the current branch and set the remote as upstream, use\n"
+"\n"
+"    git push --set-upstream %s %s\n"
+msgstr ""
+"La branche courante %s n'a pas de branche amont.\n"
+"Pour pousser la branche courante et définir la distante comme amont, "
+"utilisez\n"
+"\n"
+"    git push --set-upstream %s %s\n"
+
+#: builtin/push.c:208
+#, c-format
+msgid "The current branch %s has multiple upstream branches, refusing to push."
+msgstr ""
+"La branche courante %s a de multiples branches amont, impossible de pousser."
+
+#: builtin/push.c:211
+#, c-format
+msgid ""
+"You are pushing to remote '%s', which is not the upstream of\n"
+"your current branch '%s', without telling me what to push\n"
+"to update which remote branch."
+msgstr ""
+"Vous êtes en train de pousser vers la branche distante '%s', qui n'est\n"
+"pas une branche amont de votre branche courante '%s', sans me dire\n"
+"quoi pousser pour mettre à jour quelle branche amont."
+
+#: builtin/push.c:270
+msgid ""
+"You didn't specify any refspecs to push, and push.default is \"nothing\"."
+msgstr ""
+"Vous n'avez pas spécifié de spécifications de référence à pousser, et push."
+"default est \"nothing\"."
+
+#: builtin/push.c:277
+msgid ""
+"Updates were rejected because the tip of your current branch is behind\n"
+"its remote counterpart. Integrate the remote changes (e.g.\n"
+"'git pull ...') before pushing again.\n"
+"See the 'Note about fast-forwards' in 'git push --help' for details."
+msgstr ""
+"Les mises à jour ont été rejetées car la pointe de la branche courante est "
+"derrière\n"
+"son homologue distant. Intégrez les changements distants (par exemple 'git "
+"pull ...')\n"
+"avant de pousser à nouveau.\n"
+"Voir la 'Note à propos des avances rapides' dans 'git push --help' pour plus "
+"d'information."
+
+#: builtin/push.c:283
+msgid ""
+"Updates were rejected because a pushed branch tip is behind its remote\n"
+"counterpart. Check out this branch and integrate the remote changes\n"
+"(e.g. 'git pull ...') before pushing again.\n"
+"See the 'Note about fast-forwards' in 'git push --help' for details."
+msgstr ""
+"Les mises à jour ont été rejetées car la pointe de la branche courante est "
+"derrière\n"
+"son homologue distant. Extrayez cette branche et intégrez les changements "
+"distants\n"
+"(par exemple 'git pull ...') avant de pousser à nouveau.\n"
+"Voir la 'Note à propos des avances rapides' dans 'git push --help' pour plus "
+"d'information."
+
+#: builtin/push.c:289
+msgid ""
+"Updates were rejected because the remote contains work that you do\n"
+"not have locally. This is usually caused by another repository pushing\n"
+"to the same ref. You may want to first integrate the remote changes\n"
+"(e.g., 'git pull ...') before pushing again.\n"
+"See the 'Note about fast-forwards' in 'git push --help' for details."
+msgstr ""
+"Les mises à jour ont été rejetées car la branche distante contient du "
+"travail que\n"
+"vous n'avez pas en local. Ceci est généralement causé par un autre dépôt "
+"poussé\n"
+"vers la même référence. Vous pourriez intégrer d'abord les changements "
+"distants\n"
+"(par exemple 'git pull ...') avant de pousser à nouveau.\n"
+"Voir la 'Note à propos des avances rapides' dans 'git push --help' pour plus "
+"d'information."
+
+#: builtin/push.c:296
+msgid "Updates were rejected because the tag already exists in the remote."
+msgstr ""
+"Les mises à jour ont été rejetées car l'étiquette existe déjà dans la "
+"branche distante."
+
+#: builtin/push.c:299
+msgid ""
+"You cannot update a remote ref that points at a non-commit object,\n"
+"or update a remote ref to make it point at a non-commit object,\n"
+"without using the '--force' option.\n"
+msgstr ""
+"Vous ne pouvez pas mettre à jour une référence distante qui pointe sur un "
+"objet qui\n"
+"n'est pas un commit, ou mettre à jour une référence distante pour la faire "
+"pointer\n"
+"vers un objet qui n'est pas un commit, sans utiliser l'option '--force'.\n"
+
+#: builtin/push.c:360
+#, c-format
+msgid "Pushing to %s\n"
+msgstr "Poussée vers %s\n"
+
+#: builtin/push.c:367
+#, c-format
+msgid "failed to push some refs to '%s'"
+msgstr "impossible de pousser des références vers '%s'"
+
+#: builtin/push.c:542
+msgid "repository"
+msgstr "dépôt"
+
+#: builtin/push.c:543 builtin/send-pack.c:164
+msgid "push all refs"
+msgstr "pousser toutes les références"
+
+#: builtin/push.c:544 builtin/send-pack.c:166
+msgid "mirror all refs"
+msgstr "refléter toutes les références"
+
+#: builtin/push.c:546
+msgid "delete refs"
+msgstr "supprimer les références"
+
+#: builtin/push.c:547
+msgid "push tags (can't be used with --all or --mirror)"
+msgstr ""
+"pousser les étiquettes (ne peut pas être utilisé avec --all ou --mirror)"
+
+#: builtin/push.c:550 builtin/send-pack.c:167
+msgid "force updates"
+msgstr "forcer les mises à jour"
+
+#: builtin/push.c:552 builtin/send-pack.c:181
+msgid "<refname>:<expect>"
+msgstr "<nom-de-ref>:<attendu>"
+
+#: builtin/push.c:553 builtin/send-pack.c:182
+msgid "require old value of ref to be at this value"
+msgstr "exiger que l'ancienne valeur de la référence soit à cette valeur"
+
+#: builtin/push.c:556
+msgid "control recursive pushing of submodules"
+msgstr "contrôler la poussée récursive des sous-modules"
+
+#: builtin/push.c:558 builtin/send-pack.c:175
+msgid "use thin pack"
+msgstr "utiliser un empaquetage léger"
+
+#: builtin/push.c:559 builtin/push.c:560 builtin/send-pack.c:161
+#: builtin/send-pack.c:162
+msgid "receive pack program"
+msgstr "recevoir le programme d'empaquetage"
+
+#: builtin/push.c:561
+msgid "set upstream for git pull/status"
+msgstr "définir la branche amont pour git pull/status"
+
+#: builtin/push.c:564
+msgid "prune locally removed refs"
+msgstr "éliminer les références locales supprimées"
+
+#: builtin/push.c:566
+msgid "bypass pre-push hook"
+msgstr "éviter d'utiliser le crochet pre-push"
+
+#: builtin/push.c:567
+msgid "push missing but relevant tags"
+msgstr "pousser les étiquettes manquantes mais pertinentes"
+
+#: builtin/push.c:570 builtin/send-pack.c:169
+msgid "GPG sign the push"
+msgstr "signer la poussée avec GPG"
+
+#: builtin/push.c:572 builtin/send-pack.c:176
+msgid "request atomic transaction on remote side"
+msgstr "demande une transaction atomique sur le serveur distant"
+
+#: builtin/push.c:590
+msgid "--delete is incompatible with --all, --mirror and --tags"
+msgstr "--delete est incompatible avec --all, --mirror et --tags"
+
+#: builtin/push.c:592
+msgid "--delete doesn't make sense without any refs"
+msgstr "--delete n'a pas de sens sans aucune référence"
+
+#: builtin/push.c:612
+#, c-format
+msgid "bad repository '%s'"
+msgstr "mauvais dépôt '%s'"
+
+#: builtin/push.c:613
+msgid ""
+"No configured push destination.\n"
+"Either specify the URL from the command-line or configure a remote "
+"repository using\n"
+"\n"
+"    git remote add <name> <url>\n"
+"\n"
+"and then push using the remote name\n"
+"\n"
+"    git push <name>\n"
+msgstr ""
+"Pas de destination pour pousser.\n"
+"Spécifiez une URL depuis la ligne de commande ou configurez un dépôt distant "
+"en utilisant\n"
+"\n"
+"    git remote add <nom> <url>\n"
+"\n"
+"et poussez alors en utilisant le dépôt distant\n"
+"\n"
+"    git push <nom>\n"
+
+#: builtin/push.c:628
+msgid "--all and --tags are incompatible"
+msgstr "--all et --tags sont incompatibles"
 
-#: builtin/pack-objects.c:3165
-msgid "ignore packs that have companion .keep file"
-msgstr "ignorer les paquets qui ont un fichier .keep"
+#: builtin/push.c:630
+msgid "--all can't be combined with refspecs"
+msgstr "--all ne peut pas être combiné avec des spécifications de référence"
 
-#: builtin/pack-objects.c:3167
-msgid "ignore this pack"
-msgstr "ignorer ce paquet"
+#: builtin/push.c:634
+msgid "--mirror and --tags are incompatible"
+msgstr "--mirror et --tags sont incompatibles"
 
-#: builtin/pack-objects.c:3169
-msgid "pack compression level"
-msgstr "niveau de compression du paquet"
+#: builtin/push.c:636
+msgid "--mirror can't be combined with refspecs"
+msgstr "--mirror ne peut pas être combiné avec des spécifications de référence"
 
-#: builtin/pack-objects.c:3171
-msgid "do not hide commits by grafts"
-msgstr "ne pas cacher les validations par greffes"
+#: builtin/push.c:639
+msgid "--all and --mirror are incompatible"
+msgstr "--all et --mirror sont incompatibles"
 
-#: builtin/pack-objects.c:3173
-msgid "use a bitmap index if available to speed up counting objects"
+#: builtin/push.c:643
+msgid "push options must not have new line characters"
 msgstr ""
-"utiliser un index en bitmap si disponible pour accélerer le décompte des "
-"objets"
+"les options de poussée ne peuvent pas contenir de caractères de nouvelle "
+"ligne"
 
-#: builtin/pack-objects.c:3175
-msgid "write a bitmap index together with the pack index"
-msgstr "écrire un index en bitmap associé à l'index de paquet"
+#: builtin/range-diff.c:8
+msgid "git range-diff [<options>] <old-base>..<old-tip> <new-base>..<new-tip>"
+msgstr ""
+"git range-diff [<options>] <ancienne-base>..<ancien-sommet> <nouvelle-base>.."
+"<nouveau-sommet>"
 
-#: builtin/pack-objects.c:3178
-msgid "handling for missing objects"
-msgstr "gestion des objets manquants"
+#: builtin/range-diff.c:9
+msgid "git range-diff [<options>] <old-tip>...<new-tip>"
+msgstr "git range-diff [<options>] <ancien-sommet>...<nouveau-sommet>"
 
-#: builtin/pack-objects.c:3181
-msgid "do not pack objects in promisor packfiles"
-msgstr "ne pas empaqueter les objets dans les fichiers paquets prometteurs"
+#: builtin/range-diff.c:10
+msgid "git range-diff [<options>] <base> <old-tip> <new-tip>"
+msgstr "git range-diff [<options>] <base> <ancien-sommet> <nouveau-sommet>"
 
-#: builtin/pack-objects.c:3205
-#, c-format
-msgid "delta chain depth %d is too deep, forcing %d"
-msgstr "la profondeur %d de chaîne de delta est trop grande, forcée à %d"
+#: builtin/range-diff.c:22
+msgid "Percentage by which creation is weighted"
+msgstr "Pourcentage par lequel la création est pondérée"
+
+#: builtin/range-diff.c:24
+msgid "use simple diff colors"
+msgstr "utiliser des couleurs de diff simples"
+
+#: builtin/range-diff.c:26
+msgid "notes"
+msgstr "notes"
+
+#: builtin/range-diff.c:26
+msgid "passed to 'git log'"
+msgstr "passé à 'git log'"
 
-#: builtin/pack-objects.c:3210
+#: builtin/range-diff.c:50 builtin/range-diff.c:54
 #, c-format
-msgid "pack.deltaCacheLimit is too high, forcing %d"
-msgstr "pack.deltaCacheLimit est trop grand, forcé à %d"
+msgid "no .. in range: '%s'"
+msgstr "pas de .. dans la plage : '%s'"
 
-#: builtin/pack-objects.c:3338
-msgid "Enumerating objects"
-msgstr "Énumération des objets"
+#: builtin/range-diff.c:64
+msgid "single arg format must be symmetric range"
+msgstr "un format d'argument unique doit être une plage symétrique"
 
-#: builtin/pack-refs.c:7
-msgid "git pack-refs [<options>]"
-msgstr "git pack-refs [<options>]"
+#: builtin/range-diff.c:79
+msgid "need two commit ranges"
+msgstr "plage entre deux commits requise"
 
-#: builtin/pack-refs.c:15
-msgid "pack everything"
-msgstr "empaqueter tout"
+#: builtin/read-tree.c:41
+msgid ""
+"git read-tree [(-m [--trivial] [--aggressive] | --reset | --prefix=<prefix>) "
+"[-u [--exclude-per-directory=<gitignore>] | -i]] [--no-sparse-checkout] [--"
+"index-output=<file>] (--empty | <tree-ish1> [<tree-ish2> [<tree-ish3>]])"
+msgstr ""
+"git read-tree [(-m [--trivial] [--aggressive] | --reset | --"
+"prefix=<préfixe>) [-u [--exclude-per-directory=<gitignore>] | -i]] [--no-"
+"sparse-checkout] [--index-output=<fichier>] (--empty | <arbre ou apparenté "
+"1> [<arbre ou apparenté 2> [<arbre ou apparenté 3>]])"
 
-#: builtin/pack-refs.c:16
-msgid "prune loose refs (default)"
-msgstr "éliminer les références perdues (défaut)"
+#: builtin/read-tree.c:124
+msgid "write resulting index to <file>"
+msgstr "écrire l'index résultant dans <fichier>"
 
-#: builtin/prune-packed.c:8
-msgid "git prune-packed [-n | --dry-run] [-q | --quiet]"
-msgstr "git prune-packed [-n | --dry-run] [-q | --quiet]"
+#: builtin/read-tree.c:127
+msgid "only empty the index"
+msgstr "juste vider l'index"
 
-#: builtin/prune-packed.c:41
-msgid "Removing duplicate objects"
-msgstr "Suppression des objets dupliqués"
+#: builtin/read-tree.c:129
+msgid "Merging"
+msgstr "Fusion"
 
-#: builtin/prune.c:11
-msgid "git prune [-n] [-v] [--progress] [--expire <time>] [--] [<head>...]"
-msgstr "git prune [-n] [-v] [--progress] [--expire <heure>] [--] [<head>…]"
+#: builtin/read-tree.c:131
+msgid "perform a merge in addition to a read"
+msgstr "effectuer une fusion en plus d'une lecture"
 
-#: builtin/prune.c:108
-msgid "report pruned objects"
-msgstr "afficher les objets éliminés"
+#: builtin/read-tree.c:133
+msgid "3-way merge if no file level merging required"
+msgstr "fusion à 3 points si aucune fusion de niveau fichier n'est requise"
 
-#: builtin/prune.c:111
-msgid "expire objects older than <time>"
-msgstr "faire expirer les objets plus vieux que <heure>"
+#: builtin/read-tree.c:135
+msgid "3-way merge in presence of adds and removes"
+msgstr "fusion à 3 points en présence d'ajouts et suppressions"
 
-#: builtin/prune.c:113
-msgid "limit traversal to objects outside promisor packfiles"
-msgstr "limiter la traversée aux objets hors des fichiers paquets prometteurs"
+#: builtin/read-tree.c:137
+msgid "same as -m, but discard unmerged entries"
+msgstr "comme -m, mais annule les éléments non fusionnés"
 
-#: builtin/prune.c:127
-msgid "cannot prune in a precious-objects repo"
-msgstr "impossible de nettoyer dans un dépôt d'objets précieux"
+#: builtin/read-tree.c:138
+msgid "<subdirectory>/"
+msgstr "<sous-répertoire>/"
 
-#: builtin/pull.c:59 builtin/pull.c:61
-#, c-format
-msgid "Invalid value for %s: %s"
-msgstr "Valeur invalide pour %s : %s"
+#: builtin/read-tree.c:139
+msgid "read the tree into the index under <subdirectory>/"
+msgstr "lire l'arbre dans l'index dans <sous-répertoire>/"
 
-#: builtin/pull.c:81
-msgid "git pull [<options>] [<repository> [<refspec>...]]"
-msgstr "git pull [<options>] [<dépôt> [<spécification-de-référence>...]]"
+#: builtin/read-tree.c:142
+msgid "update working tree with merge result"
+msgstr "mettre à jour la copie de travail avec le résultat de la fusion"
 
-#: builtin/pull.c:132
-msgid "control for recursive fetching of submodules"
-msgstr "contrôler la récupération récursive dans les sous-modules"
+#: builtin/read-tree.c:144
+msgid "gitignore"
+msgstr "gitignore"
 
-#: builtin/pull.c:136
-msgid "Options related to merging"
-msgstr "Options relatives à la fusion"
+#: builtin/read-tree.c:145
+msgid "allow explicitly ignored files to be overwritten"
+msgstr "autoriser explicitement les fichiers ignorés à être écrasés"
 
-#: builtin/pull.c:139
-msgid "incorporate changes by rebasing rather than merging"
-msgstr "incorporer les modifications en rebasant plutôt qu'en fusionnant"
+#: builtin/read-tree.c:148
+msgid "don't check the working tree after merging"
+msgstr "ne pas vérifier la copie de travail après la fusion"
 
-#: builtin/pull.c:166 builtin/rebase--helper.c:23 builtin/revert.c:121
-msgid "allow fast-forward"
-msgstr "autoriser l'avance rapide"
+#: builtin/read-tree.c:149
+msgid "don't update the index or the work tree"
+msgstr "ne pas mettre à jour l'index ou la copie de travail"
 
-#: builtin/pull.c:175
-msgid "automatically stash/stash pop before and after rebase"
-msgstr "remiser avant et réappliquer après le rebasage automatiquement"
+#: builtin/read-tree.c:151
+msgid "skip applying sparse checkout filter"
+msgstr "sauter l'application du filtre d'extraction creuse"
 
-#: builtin/pull.c:191
-msgid "Options related to fetching"
-msgstr "Options relatives au rapatriement"
+#: builtin/read-tree.c:153
+msgid "debug unpack-trees"
+msgstr "déboguer unpack-trees"
 
-#: builtin/pull.c:209
-msgid "number of submodules pulled in parallel"
-msgstr "nombre de sous-modules tirés en parallèle"
+#: builtin/read-tree.c:157
+msgid "suppress feedback messages"
+msgstr "supprimer les messages d'information de suivi"
 
-#: builtin/pull.c:304
-#, c-format
-msgid "Invalid value for pull.ff: %s"
-msgstr "Valeur invalide pour pull.ff : %s"
+#: builtin/read-tree.c:188
+msgid "You need to resolve your current index first"
+msgstr "Vous devez d'abord résoudre votre index courant"
 
-#: builtin/pull.c:420
+#: builtin/rebase.c:32
 msgid ""
-"There is no candidate for rebasing against among the refs that you just "
-"fetched."
+"git rebase [-i] [options] [--exec <cmd>] [--onto <newbase> | --keep-base] "
+"[<upstream> [<branch>]]"
 msgstr ""
-"Il n'y a pas de candidate sur laquelle rebaser parmi les références que vous "
-"venez de récupérer."
+"git rebase [-i] [options] [--exec <cmd>] [--onto <nouvelle-base> | --keep-"
+"base] [<amont> [<branche>]]"
 
-#: builtin/pull.c:422
+#: builtin/rebase.c:34
 msgid ""
-"There are no candidates for merging among the refs that you just fetched."
+"git rebase [-i] [options] [--exec <cmd>] [--onto <newbase>] --root [<branch>]"
 msgstr ""
-"Il n'y a pas de candidate avec laquelle fusionner parmi les références que "
-"vous venez de récupérer."
+"git rebase [-i] [options] [--exec <cmd>] [--onto <nouvelle-base>] --root "
+"[<branche>]"
 
-#: builtin/pull.c:423
-msgid ""
-"Generally this means that you provided a wildcard refspec which had no\n"
-"matches on the remote end."
-msgstr ""
-"Généralement, cela signifie que vous avez indiqué un spécificateur\n"
-"de référence joker qui n'a pas eu de correspondance sur le serveur distant."
+#: builtin/rebase.c:36
+msgid "git rebase --continue | --abort | --skip | --edit-todo"
+msgstr "git rebase --continue | --abort | --skip | --edit-todo"
 
-#: builtin/pull.c:426
+#: builtin/rebase.c:177 builtin/rebase.c:201 builtin/rebase.c:228
 #, c-format
-msgid ""
-"You asked to pull from the remote '%s', but did not specify\n"
-"a branch. Because this is not the default configured remote\n"
-"for your current branch, you must specify a branch on the command line."
-msgstr ""
-"Vous avez demandé de tirer depuis le dépôt distant '%s', mais sans indiquer\n"
-"la branche. Comme ce n'est pas le dépôt distant par défaut dans la "
-"configuration\n"
-"pour la branche actuelle, vous devez spécifier la branche avec la commande."
+msgid "unusable todo list: '%s'"
+msgstr "liste à faire inutilisable : '%s'"
 
-#: builtin/pull.c:431 git-parse-remote.sh:73
-msgid "You are not currently on a branch."
-msgstr "Vous n'êtes actuellement sur aucune branche."
+#: builtin/rebase.c:186 builtin/rebase.c:212 builtin/rebase.c:236
+#, c-format
+msgid "could not write '%s'."
+msgstr "impossible d'écrire '%s'."
 
-#: builtin/pull.c:433 builtin/pull.c:448 git-parse-remote.sh:79
-msgid "Please specify which branch you want to rebase against."
-msgstr "Veuillez spécifier sur quelle branche vous souhaiter rebaser."
+#: builtin/rebase.c:271
+msgid "no HEAD?"
+msgstr "pas de HEAD ?"
 
-#: builtin/pull.c:435 builtin/pull.c:450 git-parse-remote.sh:82
-msgid "Please specify which branch you want to merge with."
-msgstr "Veuillez spécifier une branche avec laquelle fusionner."
+#: builtin/rebase.c:298
+#, c-format
+msgid "could not create temporary %s"
+msgstr "impossible de créer un fichier temporaire %s"
 
-#: builtin/pull.c:436 builtin/pull.c:451
-msgid "See git-pull(1) for details."
-msgstr "Référez-vous à git-pull(1) pour de plus amples détails."
+#: builtin/rebase.c:304
+msgid "could not mark as interactive"
+msgstr "impossible de marquer comme interactif"
 
-#: builtin/pull.c:438 builtin/pull.c:444 builtin/pull.c:453
-#: git-parse-remote.sh:64
-msgid "<remote>"
-msgstr "<distant>"
+#: builtin/rebase.c:362
+msgid "could not generate todo list"
+msgstr "impossible de générer la liste à-faire"
 
-#: builtin/pull.c:438 builtin/pull.c:453 builtin/pull.c:458 git-rebase.sh:523
-#: git-parse-remote.sh:65
-msgid "<branch>"
-msgstr "<branche>"
+#: builtin/rebase.c:402
+msgid "a base commit must be provided with --upstream or --onto"
+msgstr "un commit de base doit être fourni avec --upstream ou --onto"
 
-#: builtin/pull.c:446 git-parse-remote.sh:75
-msgid "There is no tracking information for the current branch."
-msgstr "Pas d'information de suivi distant pour la branche actuelle."
+#: builtin/rebase.c:457
+msgid "git rebase--interactive [<options>]"
+msgstr "git rebase--interactive [<options>]"
 
-#: builtin/pull.c:455 git-parse-remote.sh:95
-msgid ""
-"If you wish to set tracking information for this branch you can do so with:"
-msgstr ""
-"Si vous souhaitez indiquer l'information de suivi distant pour cette "
-"branche, vous pouvez le faire avec :"
+#: builtin/rebase.c:469
+msgid "keep empty commits"
+msgstr "garder les validations vides"
 
-#: builtin/pull.c:460
-#, c-format
-msgid ""
-"Your configuration specifies to merge with the ref '%s'\n"
-"from the remote, but no such ref was fetched."
-msgstr ""
-"Votre information de configuration indique de fusionner avec la référence "
-"'%s'\n"
-"du serveur distant, mais cette référence n'a pas été récupérée."
+#: builtin/rebase.c:471 builtin/revert.c:128
+msgid "allow commits with empty messages"
+msgstr "autoriser les validations avec des messages vides"
 
-#: builtin/pull.c:826
-msgid "ignoring --verify-signatures for rebase"
-msgstr "--verify-signatures est ignoré pour un rebasage"
+#: builtin/rebase.c:472
+msgid "rebase merge commits"
+msgstr "rebaser les commits de fusion"
 
-#: builtin/pull.c:874
-msgid "--[no-]autostash option is only valid with --rebase."
-msgstr "l'option --[no-]autostash n'est valide qu'avec --rebase."
+#: builtin/rebase.c:474
+msgid "keep original branch points of cousins"
+msgstr "conserver les points de branchement de cousins originaux"
 
-#: builtin/pull.c:882
-msgid "Updating an unborn branch with changes added to the index."
-msgstr ""
-"Mise à jour d'une branche non encore créée avec les changements ajoutés dans "
-"l'index."
+#: builtin/rebase.c:476
+msgid "move commits that begin with squash!/fixup!"
+msgstr "déplacer les commits qui commencent par squash!/fixup!"
+
+#: builtin/rebase.c:477
+msgid "sign commits"
+msgstr "signer les commits"
+
+#: builtin/rebase.c:479 builtin/rebase.c:1455
+msgid "display a diffstat of what changed upstream"
+msgstr "afficher un diffstat de ce qui a changé en amont"
 
-#: builtin/pull.c:885
-msgid "pull with rebase"
-msgstr "tirer avec un rebasage"
+#: builtin/rebase.c:481
+msgid "continue rebase"
+msgstr "continuer le rebasage"
 
-#: builtin/pull.c:886
-msgid "please commit or stash them."
-msgstr "veuillez les valider ou les remiser."
+#: builtin/rebase.c:483
+msgid "skip commit"
+msgstr "sauter le commit"
+
+#: builtin/rebase.c:484
+msgid "edit the todo list"
+msgstr "éditer la liste à-faire"
+
+#: builtin/rebase.c:486
+msgid "show the current patch"
+msgstr "afficher le patch courant"
 
-#: builtin/pull.c:911
-#, c-format
-msgid ""
-"fetch updated the current branch head.\n"
-"fast-forwarding your working tree from\n"
-"commit %s."
-msgstr ""
-"la récupération a mis à jour la tête de la branche actuelle.\n"
-"avance rapide de votre copie de travail\n"
-"depuis le commit %s."
+#: builtin/rebase.c:489
+msgid "shorten commit ids in the todo list"
+msgstr "raccourcir les identifiants de commits dans la liste à-faire"
+
+#: builtin/rebase.c:491
+msgid "expand commit ids in the todo list"
+msgstr "étendre les identifiants de commit dans la liste à-faire"
+
+#: builtin/rebase.c:493
+msgid "check the todo list"
+msgstr "vérifier la liste à-faire"
+
+#: builtin/rebase.c:495
+msgid "rearrange fixup/squash lines"
+msgstr "réarranger les lignes fixup/squash"
+
+#: builtin/rebase.c:497
+msgid "insert exec commands in todo list"
+msgstr "insérer les commandes exec dans la liste à-faire"
 
-#: builtin/pull.c:916
+#: builtin/rebase.c:498
+msgid "onto"
+msgstr "sur"
+
+#: builtin/rebase.c:501
+msgid "restrict-revision"
+msgstr "restrict-revision"
+
+#: builtin/rebase.c:501
+msgid "restrict revision"
+msgstr "restreindre la révision"
+
+#: builtin/rebase.c:503
+msgid "squash-onto"
+msgstr "écraser-sur"
+
+#: builtin/rebase.c:504
+msgid "squash onto"
+msgstr "écraser sur"
+
+#: builtin/rebase.c:506
+msgid "the upstream commit"
+msgstr "le commit amont"
+
+#: builtin/rebase.c:508
+msgid "head-name"
+msgstr "nom du head"
+
+#: builtin/rebase.c:508
+msgid "head name"
+msgstr "nom du head"
+
+#: builtin/rebase.c:513
+msgid "rebase strategy"
+msgstr "stratégie de rebasage"
+
+#: builtin/rebase.c:514
+msgid "strategy-opts"
+msgstr "options de stratégie"
+
+#: builtin/rebase.c:515
+msgid "strategy options"
+msgstr "options de stratégie"
+
+#: builtin/rebase.c:516
+msgid "switch-to"
+msgstr "switch-to"
+
+#: builtin/rebase.c:517
+msgid "the branch or commit to checkout"
+msgstr "la branche ou le commit à extraire"
+
+#: builtin/rebase.c:518
+msgid "onto-name"
+msgstr "sur-le-nom"
+
+#: builtin/rebase.c:518
+msgid "onto name"
+msgstr "sur le nom"
+
+#: builtin/rebase.c:519
+msgid "cmd"
+msgstr "cmd"
+
+#: builtin/rebase.c:519
+msgid "the command to run"
+msgstr "la commande à lancer"
+
+#: builtin/rebase.c:522 builtin/rebase.c:1540
+msgid "automatically re-schedule any `exec` that fails"
+msgstr "re-planifier automatiquement tout `exec` qui échoue"
+
+#: builtin/rebase.c:540
+msgid "--[no-]rebase-cousins has no effect without --rebase-merges"
+msgstr "--[no-]rebase-cousins n'a aucun effet sans --rebase-merges"
+
+#: builtin/rebase.c:556
 #, c-format
-msgid ""
-"Cannot fast-forward your working tree.\n"
-"After making sure that you saved anything precious from\n"
-"$ git diff %s\n"
-"output, run\n"
-"$ git reset --hard\n"
-"to recover."
-msgstr ""
-"Avance rapide de votre arbre de travail impossible.\n"
-"Après avoir vérifié que toute modification précieuse a été sauvegardée avec\n"
-"$ git diff %s\n"
-"lancez\n"
-"$ git reset --hard\n"
-"pour régénérer."
+msgid "%s requires an interactive rebase"
+msgstr "%s requiert un rebasage interactif"
 
-#: builtin/pull.c:931
-msgid "Cannot merge multiple branches into empty head."
-msgstr "Impossible de fusionner de multiples branches sur une tête vide."
+#: builtin/rebase.c:608
+#, c-format
+msgid "could not get 'onto': '%s'"
+msgstr "impossible d'accéder 'onto' : '%s'"
 
-#: builtin/pull.c:935
-msgid "Cannot rebase onto multiple branches."
-msgstr "Impossible de rebaser sur de multiples branches."
+#: builtin/rebase.c:623
+#, c-format
+msgid "invalid orig-head: '%s'"
+msgstr "orig-head invalide : '%s'"
 
-#: builtin/pull.c:942
-msgid "cannot rebase with locally recorded submodule modifications"
-msgstr ""
-"impossible de rebaser avec des modifications de sous-modules enregistrées "
-"localement"
+#: builtin/rebase.c:648
+#, c-format
+msgid "ignoring invalid allow_rerere_autoupdate: '%s'"
+msgstr "allow_rerere_autoupdate invalide ignoré : '%s'"
 
-#: builtin/push.c:19
-msgid "git push [<options>] [<repository> [<refspec>...]]"
-msgstr "git push [<options>] [<dépôt> [<spécification-de-référence>...]]"
+#: builtin/rebase.c:724
+#, c-format
+msgid "Could not read '%s'"
+msgstr "Impossible de lire '%s'"
 
-#: builtin/push.c:111
-msgid "tag shorthand without <tag>"
-msgstr "raccourci d'étiquette sans <étiquette>"
+#: builtin/rebase.c:742
+#, c-format
+msgid "Cannot store %s"
+msgstr "Impossible de stocker %s"
 
-#: builtin/push.c:121
-msgid "--delete only accepts plain target ref names"
-msgstr "--delete accepte seulement des noms entiers de références cibles"
+#: builtin/rebase.c:849
+msgid "could not determine HEAD revision"
+msgstr "impossible de déterminer la révision HEAD"
 
-#: builtin/push.c:165
+#: builtin/rebase.c:972 git-rebase--preserve-merges.sh:81
 msgid ""
-"\n"
-"To choose either option permanently, see push.default in 'git help config'."
+"Resolve all conflicts manually, mark them as resolved with\n"
+"\"git add/rm <conflicted_files>\", then run \"git rebase --continue\".\n"
+"You can instead skip this commit: run \"git rebase --skip\".\n"
+"To abort and get back to the state before \"git rebase\", run \"git rebase --"
+"abort\"."
 msgstr ""
-"\n"
-"Pour choisir l'option de manière permanente, voir push.default dans 'git "
-"help config'."
+"Résolvez tous les conflits manuellement, marquez-les comme résolus avec\n"
+"\"git add/rm <fichier en conflit>\", puis lancez \"git rebase --continue\".\n"
+"Si vous préférez sauter ce commit, lancez \"git rebase --skip\". Pour "
+"arrêter\n"
+"et revenir à l'état antérieur à la commande, lancez \"git rebase --abort\"."
 
-#: builtin/push.c:168
+#: builtin/rebase.c:1060
 #, c-format
 msgid ""
-"The upstream branch of your current branch does not match\n"
-"the name of your current branch.  To push to the upstream branch\n"
-"on the remote, use\n"
 "\n"
-"    git push %s HEAD:%s\n"
+"git encountered an error while preparing the patches to replay\n"
+"these revisions:\n"
 "\n"
-"To push to the branch of the same name on the remote, use\n"
+"    %s\n"
 "\n"
-"    git push %s %s\n"
-"%s"
+"As a result, git cannot rebase them."
 msgstr ""
-"La branche amont de votre branche courante ne correspond pas\n"
-"au nom de votre branche courante.  Pour pousser vers la branche amont\n"
-"sur le serveur distant, utilisez\n"
 "\n"
-"    git push %s HEAD:%s\n"
+"git a rencontré une erreur lors de la préparation des correctifs\n"
+"pour rejouer ces révisions : \n"
 "\n"
-"Pour pousser vers la branche du même nom sur le serveur distant, utilisez\n"
+"    %s\n"
 "\n"
-"    git push %s %s\n"
-"%s"
+"Résultat, git ne peut pas les rebaser."
 
-#: builtin/push.c:183
+#: builtin/rebase.c:1367
 #, c-format
 msgid ""
-"You are not currently on a branch.\n"
-"To push the history leading to the current (detached HEAD)\n"
-"state now, use\n"
+"%s\n"
+"Please specify which branch you want to rebase against.\n"
+"See git-rebase(1) for details.\n"
+"\n"
+"    git rebase '<branch>'\n"
 "\n"
-"    git push %s HEAD:<name-of-remote-branch>\n"
 msgstr ""
-"Vous n'êtes actuellement sur aucune branche.\n"
-"Pour pousser l'historique menant à l'état actuel (HEAD détachée),\n"
-"utilisez\n"
+"%s\n"
+"Veuillez spécifier sur quelle branche vous souhaiter rebaser.\n"
+"Voir git-rebase(1) pour plus de détails.\n"
+"\n"
+"    git rebase '<branche>'\n"
 "\n"
-"    git push %s HEAD:<nom-de-la-branche-amont>\n"
 
-#: builtin/push.c:197
+#: builtin/rebase.c:1383
 #, c-format
 msgid ""
-"The current branch %s has no upstream branch.\n"
-"To push the current branch and set the remote as upstream, use\n"
+"If you wish to set tracking information for this branch you can do so with:\n"
+"\n"
+"    git branch --set-upstream-to=%s/<branch> %s\n"
 "\n"
-"    git push --set-upstream %s %s\n"
 msgstr ""
-"La branche courante %s n'a pas de branche amont.\n"
-"Pour pousser la branche courante et définir la distante comme amont, "
-"utilisez\n"
+"Si vous souhaitez indiquer l'information de suivi distant pour cette "
+"branche, vous pouvez le faire avec :\n"
+"\n"
+"    git branch --set-upstream-to=%s/<branche> %s\n"
 "\n"
-"    git push --set-upstream %s %s\n"
 
-#: builtin/push.c:205
-#, c-format
-msgid "The current branch %s has multiple upstream branches, refusing to push."
-msgstr ""
-"La branche courante %s a de multiples branches amont, impossible de pousser."
+#: builtin/rebase.c:1413
+msgid "exec commands cannot contain newlines"
+msgstr "les commandes exec ne peut pas contenir de retour à la ligne"
 
-#: builtin/push.c:208
-#, c-format
-msgid ""
-"You are pushing to remote '%s', which is not the upstream of\n"
-"your current branch '%s', without telling me what to push\n"
-"to update which remote branch."
-msgstr ""
-"Vous êtes en train de pousser vers la branche distante '%s', qui n'est\n"
-"pas une branche amont de votre branche courante '%s', sans me dire\n"
-"quoi pousser pour mettre à jour quelle branche amont."
+#: builtin/rebase.c:1417
+msgid "empty exec command"
+msgstr "commande exec vide"
 
-#: builtin/push.c:267
-msgid ""
-"You didn't specify any refspecs to push, and push.default is \"nothing\"."
-msgstr ""
-"Vous n'avez pas spécifié de spécifications de référence à pousser, et push."
-"default est \"nothing\"."
+#: builtin/rebase.c:1446
+msgid "rebase onto given branch instead of upstream"
+msgstr "rebaser sur la branche %s au lieu de la branche amont"
 
-#: builtin/push.c:274
-msgid ""
-"Updates were rejected because the tip of your current branch is behind\n"
-"its remote counterpart. Integrate the remote changes (e.g.\n"
-"'git pull ...') before pushing again.\n"
-"See the 'Note about fast-forwards' in 'git push --help' for details."
+#: builtin/rebase.c:1448
+msgid "use the merge-base of upstream and branch as the current base"
 msgstr ""
-"Les mises à jour ont été rejetées car la pointe de la branche courante est "
-"derrière\n"
-"son homologue distant. Intégrez les changements distants (par exemple 'git "
-"pull ...')\n"
-"avant de pousser à nouveau.\n"
-"Voir la 'Note à propos des avances rapides' dans 'git push --help' pour plus "
-"d'information."
+"utiliser la base de fusion de l'amont et la branche comme base actuelle"
 
-#: builtin/push.c:280
-msgid ""
-"Updates were rejected because a pushed branch tip is behind its remote\n"
-"counterpart. Check out this branch and integrate the remote changes\n"
-"(e.g. 'git pull ...') before pushing again.\n"
-"See the 'Note about fast-forwards' in 'git push --help' for details."
-msgstr ""
-"Les mises à jour ont été rejetées car la pointe de la branche courante est "
-"derrière\n"
-"son homologue distant. Extrayez cette branche et intégrez les changements "
-"distants\n"
-"(par exemple 'git pull ...') avant de pousser à nouveau.\n"
-"Voir la 'Note à propos des avances rapides' dans 'git push --help' pour plus "
-"d'information."
+#: builtin/rebase.c:1450
+msgid "allow pre-rebase hook to run"
+msgstr "permettre le lancement du crochet pre-rebase"
 
-#: builtin/push.c:286
-msgid ""
-"Updates were rejected because the remote contains work that you do\n"
-"not have locally. This is usually caused by another repository pushing\n"
-"to the same ref. You may want to first integrate the remote changes\n"
-"(e.g., 'git pull ...') before pushing again.\n"
-"See the 'Note about fast-forwards' in 'git push --help' for details."
-msgstr ""
-"Les mises à jour ont été rejetées car la branche distante contient du "
-"travail que\n"
-"vous n'avez pas en local. Ceci est généralement causé par un autre dépôt "
-"poussé\n"
-"vers la même référence. Vous pourriez intégrer d'abord les changements "
-"distants\n"
-"(par exemple 'git pull ...') avant de pousser à nouveau.\n"
-"Voir la 'Note à propos des avances rapides' dans 'git push --help' pour plus "
-"d'information."
+#: builtin/rebase.c:1452
+msgid "be quiet. implies --no-stat"
+msgstr "être silencieux. implique --no-stat"
 
-#: builtin/push.c:293
-msgid "Updates were rejected because the tag already exists in the remote."
-msgstr ""
-"Les mises à jour ont été rejetées car l'étiquette existe déjà dans la "
-"branche distante."
+#: builtin/rebase.c:1458
+msgid "do not show diffstat of what changed upstream"
+msgstr "ne pas afficher un diffstat de ce qui a changé en amont"
 
-#: builtin/push.c:296
-msgid ""
-"You cannot update a remote ref that points at a non-commit object,\n"
-"or update a remote ref to make it point at a non-commit object,\n"
-"without using the '--force' option.\n"
-msgstr ""
-"Vous ne pouvez pas mettre à jour une référence distante qui pointe sur un "
-"objet qui\n"
-"n'est pas un commit, ou mettre à jour une référence distante pour la faire "
-"pointer\n"
-"vers un objet qui n'est pas un commit, sans utiliser l'option '--force'.\n"
+#: builtin/rebase.c:1461
+msgid "add a Signed-off-by: line to each commit"
+msgstr "ajouter une ligne Signed-off-by à chaque message de validation"
 
-#: builtin/push.c:357
-#, c-format
-msgid "Pushing to %s\n"
-msgstr "Poussée vers %s\n"
+#: builtin/rebase.c:1464
+msgid "make committer date match author date"
+msgstr "aligner la date de validateur sur la date d'auteur"
 
-#: builtin/push.c:361
-#, c-format
-msgid "failed to push some refs to '%s'"
-msgstr "impossible de pousser des références vers '%s'"
+#: builtin/rebase.c:1466
+msgid "ignore author date and use current date"
+msgstr "ignorer la date d'auteur et utiliser la date actuelle"
 
-#: builtin/push.c:395
-#, c-format
-msgid "bad repository '%s'"
-msgstr "mauvais dépôt '%s'"
+#: builtin/rebase.c:1468
+msgid "synonym of --reset-author-date"
+msgstr "synonyme pour --reset-author-date"
 
-#: builtin/push.c:396
-msgid ""
-"No configured push destination.\n"
-"Either specify the URL from the command-line or configure a remote "
-"repository using\n"
-"\n"
-"    git remote add <name> <url>\n"
-"\n"
-"and then push using the remote name\n"
-"\n"
-"    git push <name>\n"
-msgstr ""
-"Pas de destination pour pousser.\n"
-"Spécifiez une URL depuis la ligne de commande ou configurez un dépôt distant "
-"en utilisant\n"
-"\n"
-"    git remote add <nom> <url>\n"
-"\n"
-"et poussez alors en utilisant le dépôt distant\n"
-"\n"
-"    git push <nom>\n"
+#: builtin/rebase.c:1470 builtin/rebase.c:1474
+msgid "passed to 'git apply'"
+msgstr "passé jusqu'à git-apply"
 
-#: builtin/push.c:551
-msgid "repository"
-msgstr "dépôt"
+#: builtin/rebase.c:1472
+msgid "ignore changes in whitespace"
+msgstr "ignorer des modifications d'espace"
 
-#: builtin/push.c:552 builtin/send-pack.c:164
-msgid "push all refs"
-msgstr "pousser toutes les références"
+#: builtin/rebase.c:1476 builtin/rebase.c:1479
+msgid "cherry-pick all commits, even if unchanged"
+msgstr "picorer tous les commits, même sans modifiant"
 
-#: builtin/push.c:553 builtin/send-pack.c:166
-msgid "mirror all refs"
-msgstr "refléter toutes les références"
+#: builtin/rebase.c:1481
+msgid "continue"
+msgstr "continuer"
 
-#: builtin/push.c:555
-msgid "delete refs"
-msgstr "supprimer les références"
+#: builtin/rebase.c:1484
+msgid "skip current patch and continue"
+msgstr "sauter le patch courant et continuer"
 
-#: builtin/push.c:556
-msgid "push tags (can't be used with --all or --mirror)"
-msgstr ""
-"pousser les étiquettes (ne peut pas être utilisé avec --all ou --mirror)"
+#: builtin/rebase.c:1486
+msgid "abort and check out the original branch"
+msgstr "abandonner et extraire la branche d'origine"
 
-#: builtin/push.c:559 builtin/send-pack.c:167
-msgid "force updates"
-msgstr "forcer les mises à jour"
+#: builtin/rebase.c:1489
+msgid "abort but keep HEAD where it is"
+msgstr "abandonne mais garde HEAD où il est"
 
-#: builtin/push.c:561 builtin/send-pack.c:181
-msgid "refname>:<expect"
-msgstr "nom de référence>:<attendu"
+#: builtin/rebase.c:1490
+msgid "edit the todo list during an interactive rebase"
+msgstr "éditer la liste à faire lors d'un rebasage interactif"
 
-#: builtin/push.c:562 builtin/send-pack.c:182
-msgid "require old value of ref to be at this value"
-msgstr "exiger que l'ancienne valeur de la référence soit à cette valeur"
+#: builtin/rebase.c:1493
+msgid "show the patch file being applied or merged"
+msgstr "afficher le patch en cours d'application ou de fusion"
 
-#: builtin/push.c:565
-msgid "control recursive pushing of submodules"
-msgstr "contrôler la poussée récursive des sous-modules"
+#: builtin/rebase.c:1496
+msgid "use merging strategies to rebase"
+msgstr "utiliser des stratégies de fusion pour rebaser"
 
-#: builtin/push.c:567 builtin/send-pack.c:175
-msgid "use thin pack"
-msgstr "utiliser un empaquetage léger"
+#: builtin/rebase.c:1500
+msgid "let the user edit the list of commits to rebase"
+msgstr "laisser l'utilisateur éditer la liste des commits à rebaser"
 
-#: builtin/push.c:568 builtin/push.c:569 builtin/send-pack.c:161
-#: builtin/send-pack.c:162
-msgid "receive pack program"
-msgstr "recevoir le programme d'empaquetage"
+#: builtin/rebase.c:1504
+msgid "(DEPRECATED) try to recreate merges instead of ignoring them"
+msgstr "(DÉCONSEILLÉ) essayer de recréer les fusions au lieu de les ignorer"
 
-#: builtin/push.c:570
-msgid "set upstream for git pull/status"
-msgstr "définir la branche amont pour git pull/status"
+#: builtin/rebase.c:1509
+msgid "preserve empty commits during rebase"
+msgstr "préserver les validations vides pendant le rebasage"
 
-#: builtin/push.c:573
-msgid "prune locally removed refs"
-msgstr "éliminer les références locales supprimées"
+#: builtin/rebase.c:1511
+msgid "move commits that begin with squash!/fixup! under -i"
+msgstr "déplace les commits qui commencent par squash!/fixup! sous -i"
 
-#: builtin/push.c:575
-msgid "bypass pre-push hook"
-msgstr "éviter d'utiliser le crochet pre-push"
+#: builtin/rebase.c:1517
+msgid "automatically stash/stash pop before and after"
+msgstr "remiser et réappliquer automatiquement avant et après"
 
-#: builtin/push.c:576
-msgid "push missing but relevant tags"
-msgstr "pousser les étiquettes manquantes mais pertinentes"
+#: builtin/rebase.c:1519
+msgid "add exec lines after each commit of the editable list"
+msgstr "ajouter les lignes exec après chaque commit de la liste éditable"
 
-#: builtin/push.c:579 builtin/send-pack.c:169
-msgid "GPG sign the push"
-msgstr "signer la poussée avec GPG"
+#: builtin/rebase.c:1523
+msgid "allow rebasing commits with empty messages"
+msgstr "autoriser les commits de rebasage avec des messages vides"
 
-#: builtin/push.c:581 builtin/send-pack.c:176
-msgid "request atomic transaction on remote side"
-msgstr "demande une transaction atomique sur le serveur distant"
+#: builtin/rebase.c:1526
+msgid "try to rebase merges instead of skipping them"
+msgstr "essayer de rebaser les fusions au lieu de les garder"
 
-#: builtin/push.c:599
-msgid "--delete is incompatible with --all, --mirror and --tags"
-msgstr "--delete est incompatible avec --all, --mirror et --tags"
+#: builtin/rebase.c:1529
+msgid "use 'merge-base --fork-point' to refine upstream"
+msgstr "utiliser 'merge-base --fork-point' pour raffiner l'amont"
 
-#: builtin/push.c:601
-msgid "--delete doesn't make sense without any refs"
-msgstr "--delete n'a pas de sens sans aucune référence"
+#: builtin/rebase.c:1531
+msgid "use the given merge strategy"
+msgstr "utiliser la stratégie de fusion indiquée"
 
-#: builtin/push.c:604
-msgid "--all and --tags are incompatible"
-msgstr "--all et --tags sont incompatibles"
+#: builtin/rebase.c:1533 builtin/revert.c:115
+msgid "option"
+msgstr "option"
+
+#: builtin/rebase.c:1534
+msgid "pass the argument through to the merge strategy"
+msgstr "passer les arguments jusqu'à la stratégie de fusion"
+
+#: builtin/rebase.c:1537
+msgid "rebase all reachable commits up to the root(s)"
+msgstr "rebaser tous les objets inatteignables depuis les racines"
+
+#: builtin/rebase.c:1554
+msgid ""
+"the rebase.useBuiltin support has been removed!\n"
+"See its entry in 'git help config' for details."
+msgstr ""
+"les support de rebase.useBuiltin a été supprimé !\n"
+"Voir son entrée dans 'git help config' pour plus de détails."
+
+#: builtin/rebase.c:1560
+msgid "It looks like 'git am' is in progress. Cannot rebase."
+msgstr "Il semble que 'git-am' soit en cours. Impossible de rebaser."
+
+#: builtin/rebase.c:1601
+msgid ""
+"git rebase --preserve-merges is deprecated. Use --rebase-merges instead."
+msgstr ""
+"git rebase --preserve-merges est déconseillé. Utilisez --rebase-merges à la "
+"place."
+
+#: builtin/rebase.c:1606
+msgid "cannot combine '--keep-base' with '--onto'"
+msgstr "impossible de combiner '--keep-base' avec '--onto'"
+
+#: builtin/rebase.c:1608
+msgid "cannot combine '--keep-base' with '--root'"
+msgstr "impossible de combiner '--keep-base' avec '--root'"
+
+#: builtin/rebase.c:1612
+msgid "No rebase in progress?"
+msgstr "Pas de rebasage en cours ?"
+
+#: builtin/rebase.c:1616
+msgid "The --edit-todo action can only be used during interactive rebase."
+msgstr ""
+"L'action --edit-todo peut seulement être utilisée lors d'un rebasage "
+"interactif."
+
+#: builtin/rebase.c:1639
+msgid "Cannot read HEAD"
+msgstr "Impossible de lire HEAD"
+
+#: builtin/rebase.c:1651
+msgid ""
+"You must edit all merge conflicts and then\n"
+"mark them as resolved using git add"
+msgstr ""
+"Vous devez éditer tous les conflits de fusion et\n"
+"les marquer comme résolus avec git add"
+
+#: builtin/rebase.c:1670
+msgid "could not discard worktree changes"
+msgstr "Impossible de supprimer les changements de l'arbre de travail"
+
+#: builtin/rebase.c:1689
+#, c-format
+msgid "could not move back to %s"
+msgstr "Impossible de revenir à %s"
+
+#: builtin/rebase.c:1734
+#, c-format
+msgid ""
+"It seems that there is already a %s directory, and\n"
+"I wonder if you are in the middle of another rebase.  If that is the\n"
+"case, please try\n"
+"\t%s\n"
+"If that is not the case, please\n"
+"\t%s\n"
+"and run me again.  I am stopping in case you still have something\n"
+"valuable there.\n"
+msgstr ""
+"Il semble qu'il y ait déjà un répertoire %s, et je me demande\n"
+"si un autre rebasage n'est pas déjà en cours. Si c'est le cas,\n"
+"essayez\n"
+"\t%s\n"
+"Sinon, essayez\n"
+"\t%s\n"
+"puis relancez-moi à nouveau.  Je m'arrête au cas où vous auriez quelque "
+"chose\n"
+"d'important ici.\n"
 
-#: builtin/push.c:606
-msgid "--all can't be combined with refspecs"
-msgstr "--all ne peut pas être combiné avec des spécifications de référence"
+#: builtin/rebase.c:1757
+msgid "switch `C' expects a numerical value"
+msgstr "l'option `C' attend un valeur numérique"
 
-#: builtin/push.c:610
-msgid "--mirror and --tags are incompatible"
-msgstr "--mirror et --tags sont incompatibles"
+#: builtin/rebase.c:1798
+#, c-format
+msgid "Unknown mode: %s"
+msgstr "mode inconnu : %s"
 
-#: builtin/push.c:612
-msgid "--mirror can't be combined with refspecs"
-msgstr "--mirror ne peut pas être combiné avec des spécifications de référence"
+#: builtin/rebase.c:1820
+msgid "--strategy requires --merge or --interactive"
+msgstr "--strategy requiert --merge ou --interactive"
 
-#: builtin/push.c:615
-msgid "--all and --mirror are incompatible"
-msgstr "--all et --mirror sont incompatibles"
+#: builtin/rebase.c:1860
+msgid "--reschedule-failed-exec requires --exec or --interactive"
+msgstr "--reschedule-failed-exec requiert --exec ou --interactive"
 
-#: builtin/push.c:634
-msgid "push options must not have new line characters"
+#: builtin/rebase.c:1872
+msgid "cannot combine am options with either interactive or merge options"
 msgstr ""
-"les options de poussée ne peuvent pas contenir de caractères de nouvelle "
-"ligne"
+"impossible de combiner les options am avec l'options interactive ou merge"
 
-#: builtin/read-tree.c:40
+#: builtin/rebase.c:1891
+msgid "cannot combine '--preserve-merges' with '--rebase-merges'"
+msgstr "impossible de combiner '--preserve-merges' avec '--rebase-merges'"
+
+#: builtin/rebase.c:1895
 msgid ""
-"git read-tree [(-m [--trivial] [--aggressive] | --reset | --prefix=<prefix>) "
-"[-u [--exclude-per-directory=<gitignore>] | -i]] [--no-sparse-checkout] [--"
-"index-output=<file>] (--empty | <tree-ish1> [<tree-ish2> [<tree-ish3>]])"
+"error: cannot combine '--preserve-merges' with '--reschedule-failed-exec'"
 msgstr ""
-"git read-tree [(-m [--trivial] [--aggressive] | --reset | --"
-"prefix=<préfixe>) [-u [--exclude-per-directory=<gitignore>] | -i]] [--no-"
-"sparse-checkout] [--index-output=<fichier>] (--empty | <arbre ou apparenté "
-"1> [<arbre ou apparenté 2> [<arbre ou apparenté 3>]])"
-
-#: builtin/read-tree.c:120
-msgid "write resulting index to <file>"
-msgstr "écrire l'index résultant dans <fichier>"
-
-#: builtin/read-tree.c:123
-msgid "only empty the index"
-msgstr "juste vider l'index"
-
-#: builtin/read-tree.c:125
-msgid "Merging"
-msgstr "Fusion"
-
-#: builtin/read-tree.c:127
-msgid "perform a merge in addition to a read"
-msgstr "effectuer une fusion en plus d'une lecture"
+"erreur : impossible de combiner '--preserve-merges' avec '--reschedule-"
+"failed-exec'"
 
-#: builtin/read-tree.c:129
-msgid "3-way merge if no file level merging required"
-msgstr "fusion à 3 points si aucune fusion de niveau fichier n'est requise"
+#: builtin/rebase.c:1919
+#, c-format
+msgid "invalid upstream '%s'"
+msgstr "amont invalide '%s'"
 
-#: builtin/read-tree.c:131
-msgid "3-way merge in presence of adds and removes"
-msgstr "fusion à 3 points en présence d'ajouts et suppressions"
+#: builtin/rebase.c:1925
+msgid "Could not create new root commit"
+msgstr "Impossible de créer un nouveau commit racine"
 
-#: builtin/read-tree.c:133
-msgid "same as -m, but discard unmerged entries"
-msgstr "comme -m, mais annule les éléments non fusionnés"
+#: builtin/rebase.c:1951
+#, c-format
+msgid "'%s': need exactly one merge base with branch"
+msgstr "'%s': exactement une base de fusion nécessaire avec une branche"
 
-#: builtin/read-tree.c:134
-msgid "<subdirectory>/"
-msgstr "<sous-répertoire>/"
+#: builtin/rebase.c:1954
+#, c-format
+msgid "'%s': need exactly one merge base"
+msgstr "'%s': exactement une base de fusion nécessaire"
 
-#: builtin/read-tree.c:135
-msgid "read the tree into the index under <subdirectory>/"
-msgstr "lire l'arbre dans l'index dans <sous-répertoire>/"
+#: builtin/rebase.c:1962
+#, c-format
+msgid "Does not point to a valid commit '%s'"
+msgstr "ne pointe pas sur une validation valide : '%s'"
 
-#: builtin/read-tree.c:138
-msgid "update working tree with merge result"
-msgstr "mettre à jour la copie de travail avec le résultat de la fusion"
+#: builtin/rebase.c:1987
+#, c-format
+msgid "fatal: no such branch/commit '%s'"
+msgstr "fatal : pas de branche ou commit '%s'"
 
-#: builtin/read-tree.c:140
-msgid "gitignore"
-msgstr "gitignore"
+#: builtin/rebase.c:1995 builtin/submodule--helper.c:40
+#: builtin/submodule--helper.c:1961
+#, c-format
+msgid "No such ref: %s"
+msgstr "Référence inexistante : %s"
 
-#: builtin/read-tree.c:141
-msgid "allow explicitly ignored files to be overwritten"
-msgstr "autoriser explicitement les fichiers ignorés à être écrasés"
+#: builtin/rebase.c:2006
+msgid "Could not resolve HEAD to a revision"
+msgstr "Impossible de résoudre le commit HEAD vers un révision"
 
-#: builtin/read-tree.c:144
-msgid "don't check the working tree after merging"
-msgstr "ne pas vérifier la copie de travail après la fusion"
+#: builtin/rebase.c:2044
+msgid "Cannot autostash"
+msgstr "Autoremisage impossible"
 
-#: builtin/read-tree.c:145
-msgid "don't update the index or the work tree"
-msgstr "ne pas mettre à jour l'index ou la copie de travail"
+#: builtin/rebase.c:2047
+#, c-format
+msgid "Unexpected stash response: '%s'"
+msgstr "réponse de remisage inattendue : '%s'"
 
-#: builtin/read-tree.c:147
-msgid "skip applying sparse checkout filter"
-msgstr "sauter l'application du filtre d'extraction creuse"
+#: builtin/rebase.c:2053
+#, c-format
+msgid "Could not create directory for '%s'"
+msgstr "Impossible de créer le répertoire pour '%s'"
 
-#: builtin/read-tree.c:149
-msgid "debug unpack-trees"
-msgstr "déboguer unpack-trees"
+#: builtin/rebase.c:2056
+#, c-format
+msgid "Created autostash: %s\n"
+msgstr "Autoremisage créé : %s\n"
 
-#: builtin/rebase--helper.c:8
-msgid "git rebase--helper [<options>]"
-msgstr "git rebase-helper [<options>]"
+#: builtin/rebase.c:2059
+msgid "could not reset --hard"
+msgstr "impossible de réinitialiser --hard"
 
-#: builtin/rebase--helper.c:24
-msgid "keep empty commits"
-msgstr "garder les validations vides"
+#: builtin/rebase.c:2068
+msgid "Please commit or stash them."
+msgstr "Veuillez les valider ou les remiser."
 
-#: builtin/rebase--helper.c:26 builtin/revert.c:123
-msgid "allow commits with empty messages"
-msgstr "autoriser les validations avec des messages vides"
+#: builtin/rebase.c:2095
+#, c-format
+msgid "could not parse '%s'"
+msgstr "impossible d'analyser '%s'"
 
-#: builtin/rebase--helper.c:27
-msgid "rebase merge commits"
-msgstr "rebaser les commits de fusion"
+#: builtin/rebase.c:2108
+#, c-format
+msgid "could not switch to %s"
+msgstr "Impossible de basculer vers %s"
 
-#: builtin/rebase--helper.c:29
-msgid "keep original branch points of cousins"
-msgstr "conserver les points de branchement de cousins originaux"
+#: builtin/rebase.c:2119
+msgid "HEAD is up to date."
+msgstr "HEAD est à jour."
 
-#: builtin/rebase--helper.c:30
-msgid "continue rebase"
-msgstr "continuer le rebasage"
+#: builtin/rebase.c:2121
+#, c-format
+msgid "Current branch %s is up to date.\n"
+msgstr "La branche courante %s est à jour.\n"
 
-#: builtin/rebase--helper.c:32
-msgid "abort rebase"
-msgstr "abandonner le rebasage"
-
-#: builtin/rebase--helper.c:35
-msgid "make rebase script"
-msgstr "créer les script de rebasage"
+#: builtin/rebase.c:2129
+msgid "HEAD is up to date, rebase forced."
+msgstr "HEAD est à jour, rebasage forcé."
 
-#: builtin/rebase--helper.c:37
-msgid "shorten commit ids in the todo list"
-msgstr "raccourcir les identifiants de commits dans la liste à-faire"
+#: builtin/rebase.c:2131
+#, c-format
+msgid "Current branch %s is up to date, rebase forced.\n"
+msgstr "La branche courante %s est à jour, rebasage forcé.\n"
 
-#: builtin/rebase--helper.c:39
-msgid "expand commit ids in the todo list"
-msgstr "étendre les identifiants de commit dans la liste à-faire"
+#: builtin/rebase.c:2139
+msgid "The pre-rebase hook refused to rebase."
+msgstr "Le crochet pre-rebase a refusé de rebaser."
 
-#: builtin/rebase--helper.c:41
-msgid "check the todo list"
-msgstr "vérifier la liste à-faire"
+#: builtin/rebase.c:2146
+#, c-format
+msgid "Changes to %s:\n"
+msgstr "Changements vers %s :\n"
 
-#: builtin/rebase--helper.c:43
-msgid "skip unnecessary picks"
-msgstr "éviter les commandes de picorage non nécessaires"
+#: builtin/rebase.c:2149
+#, c-format
+msgid "Changes from %s to %s:\n"
+msgstr "Changements de %s sur %s :\n"
 
-#: builtin/rebase--helper.c:45
-msgid "rearrange fixup/squash lines"
-msgstr "réarranger les lignes fixup/squash"
+#: builtin/rebase.c:2174
+#, c-format
+msgid "First, rewinding head to replay your work on top of it...\n"
+msgstr ""
+"Rembobinage préalable de head pour pouvoir rejouer votre travail par-"
+"dessus...\n"
 
-#: builtin/rebase--helper.c:47
-msgid "insert exec commands in todo list"
-msgstr "insérer les commandes exec dans la liste à-faire"
+#: builtin/rebase.c:2183
+msgid "Could not detach HEAD"
+msgstr "Impossible de détacher HEAD"
 
-#: builtin/rebase--helper.c:68
-msgid "--[no-]rebase-cousins has no effect without --rebase-merges"
-msgstr "--[no-]rebase-cousins n'a aucun effet sans --rebase-merges"
+#: builtin/rebase.c:2192
+#, c-format
+msgid "Fast-forwarded %s to %s.\n"
+msgstr "Avance rapide de %s sur %s.\n"
 
-#: builtin/receive-pack.c:31
+#: builtin/receive-pack.c:32
 msgid "git receive-pack <git-dir>"
 msgstr "git receive-pack <répertoire-git>"
 
-#: builtin/receive-pack.c:842
+#: builtin/receive-pack.c:830
 msgid ""
 "By default, updating the current branch in a non-bare repository\n"
 "is denied, because it will make the index and work tree inconsistent\n"
@@ -13030,7 +18665,7 @@ msgstr ""
 "Pour éliminer ce message et conserver le comportement par défaut,\n"
 "réglez « receive.denyCurrentBranch » à 'refuse'."
 
-#: builtin/receive-pack.c:862
+#: builtin/receive-pack.c:850
 msgid ""
 "By default, deleting the current branch is denied, because the next\n"
 "'git clone' won't result in any file checked out, causing confusion.\n"
@@ -13050,24 +18685,79 @@ msgstr ""
 "\n"
 "Pour éliminer ce message, réglez-le à 'refuse'."
 
-#: builtin/receive-pack.c:1935
+#: builtin/receive-pack.c:1936
 msgid "quiet"
 msgstr "quiet"
 
-#: builtin/receive-pack.c:1949
+#: builtin/receive-pack.c:1950
 msgid "You must specify a directory."
 msgstr "Vous devez spécifier un répertoire."
 
-#: builtin/reflog.c:532 builtin/reflog.c:537
+#: builtin/reflog.c:17
+msgid ""
+"git reflog expire [--expire=<time>] [--expire-unreachable=<time>] [--"
+"rewrite] [--updateref] [--stale-fix] [--dry-run | -n] [--verbose] [--all] "
+"<refs>..."
+msgstr ""
+"git reflog expire [--expire=<date>] [--expire-unreachable=<date>] [--"
+"rewrite] [--updateref] [--stale-fix] [--dry-run | -n] [--verbose] [--all] "
+"<réferences>..."
+
+#: builtin/reflog.c:22
+msgid ""
+"git reflog delete [--rewrite] [--updateref] [--dry-run | -n] [--verbose] "
+"<refs>..."
+msgstr ""
+"git reflog delete [--rewrite] [--updateref] [--dry-run | -n] [--verbose] "
+"<références>..."
+
+#: builtin/reflog.c:25
+msgid "git reflog exists <ref>"
+msgstr "git reflog exists <référence>"
+
+#: builtin/reflog.c:567 builtin/reflog.c:572
 #, c-format
 msgid "'%s' is not a valid timestamp"
 msgstr "'%s' n'est pas un horodatage valide"
 
-#: builtin/remote.c:14
+#: builtin/reflog.c:605
+#, c-format
+msgid "Marking reachable objects..."
+msgstr "Marquage des objets inaccessibles..."
+
+#: builtin/reflog.c:643
+#, c-format
+msgid "%s points nowhere!"
+msgstr "%s ne pointe nulle part !"
+
+#: builtin/reflog.c:695
+msgid "no reflog specified to delete"
+msgstr "pas de journal de références à supprimer spécifié"
+
+#: builtin/reflog.c:704
+#, c-format
+msgid "not a reflog: %s"
+msgstr "'%s' n'est pas un journal de références"
+
+#: builtin/reflog.c:709
+#, c-format
+msgid "no reflog for '%s'"
+msgstr "pas de journal de références pour '%s'"
+
+#: builtin/reflog.c:755
+#, c-format
+msgid "invalid ref format: %s"
+msgstr "format de référence invalide : %s"
+
+#: builtin/reflog.c:764
+msgid "git reflog [ show | expire | delete | exists ]"
+msgstr "git reflog [ show | expire | delete | exists ]"
+
+#: builtin/remote.c:16
 msgid "git remote [-v | --verbose]"
 msgstr "git remote [-v | --verbose]"
 
-#: builtin/remote.c:15
+#: builtin/remote.c:17
 msgid ""
 "git remote add [-t <branch>] [-m <master>] [-f] [--tags | --no-tags] [--"
 "mirror=<fetch|push>] <name> <url>"
@@ -13075,83 +18765,83 @@ msgstr ""
 "git remote add [-t <branche>] [-m <master>] [-f] [--tags | --no-tags] [--"
 "mirror=<fetch|push>] <nom> <url>"
 
-#: builtin/remote.c:16 builtin/remote.c:36
+#: builtin/remote.c:18 builtin/remote.c:38
 msgid "git remote rename <old> <new>"
 msgstr "git remote rename <ancienne> <nouvelle>"
 
-#: builtin/remote.c:17 builtin/remote.c:41
+#: builtin/remote.c:19 builtin/remote.c:43
 msgid "git remote remove <name>"
 msgstr "git remote remove <nom>"
 
-#: builtin/remote.c:18 builtin/remote.c:46
+#: builtin/remote.c:20 builtin/remote.c:48
 msgid "git remote set-head <name> (-a | --auto | -d | --delete | <branch>)"
 msgstr "git remote set-head <nom> (-a | --auto | -d | --delete | <branche>)"
 
-#: builtin/remote.c:19
+#: builtin/remote.c:21
 msgid "git remote [-v | --verbose] show [-n] <name>"
 msgstr "git remote [-v | --verbose] show [-n] <nom>"
 
-#: builtin/remote.c:20
+#: builtin/remote.c:22
 msgid "git remote prune [-n | --dry-run] <name>"
 msgstr "git remote prune [-n | --dry-run] <nom>"
 
-#: builtin/remote.c:21
+#: builtin/remote.c:23
 msgid ""
 "git remote [-v | --verbose] update [-p | --prune] [(<group> | <remote>)...]"
 msgstr ""
 "git remote [-v | --verbose] update [-p | --prune] [(<groupe> | "
 "<distante>)...]"
 
-#: builtin/remote.c:22
+#: builtin/remote.c:24
 msgid "git remote set-branches [--add] <name> <branch>..."
 msgstr "git remote set-branches [--add] <nom> <branche>..."
 
-#: builtin/remote.c:23 builtin/remote.c:72
+#: builtin/remote.c:25 builtin/remote.c:74
 msgid "git remote get-url [--push] [--all] <name>"
 msgstr "git remote get-url [--push] [--all] <nom>"
 
-#: builtin/remote.c:24 builtin/remote.c:77
+#: builtin/remote.c:26 builtin/remote.c:79
 msgid "git remote set-url [--push] <name> <newurl> [<oldurl>]"
 msgstr "git remote set-url [--push] <nom> <nouvelle-URL> [<ancienne-URL>]"
 
-#: builtin/remote.c:25 builtin/remote.c:78
+#: builtin/remote.c:27 builtin/remote.c:80
 msgid "git remote set-url --add <name> <newurl>"
 msgstr "git remote set-url --add <nom> <nouvelle-URL>"
 
-#: builtin/remote.c:26 builtin/remote.c:79
+#: builtin/remote.c:28 builtin/remote.c:81
 msgid "git remote set-url --delete <name> <url>"
-msgstr "git remote set-url --delete <nom> <URL>"
+msgstr "git remote set-url --delete <nom> <url>"
 
-#: builtin/remote.c:31
+#: builtin/remote.c:33
 msgid "git remote add [<options>] <name> <url>"
 msgstr "git remote add [<options>] <nom> <URL>"
 
-#: builtin/remote.c:51
+#: builtin/remote.c:53
 msgid "git remote set-branches <name> <branch>..."
 msgstr "git remote set-branches <nom> <branche>..."
 
-#: builtin/remote.c:52
+#: builtin/remote.c:54
 msgid "git remote set-branches --add <name> <branch>..."
 msgstr "git remote set-branches --add <nom> <branche>..."
 
-#: builtin/remote.c:57
+#: builtin/remote.c:59
 msgid "git remote show [<options>] <name>"
 msgstr "git remote show [<options>] <nom>"
 
-#: builtin/remote.c:62
+#: builtin/remote.c:64
 msgid "git remote prune [<options>] <name>"
 msgstr "git remote prune [<options>] <nom>"
 
-#: builtin/remote.c:67
+#: builtin/remote.c:69
 msgid "git remote update [<options>] [<group> | <remote>]..."
 msgstr "git remote update [<options>] [<groupe> | <distante>]..."
 
-#: builtin/remote.c:96
+#: builtin/remote.c:98
 #, c-format
 msgid "Updating %s"
 msgstr "Mise à jour de %s"
 
-#: builtin/remote.c:128
+#: builtin/remote.c:130
 msgid ""
 "--mirror is dangerous and deprecated; please\n"
 "\t use --mirror=fetch or --mirror=push instead"
@@ -13159,92 +18849,88 @@ msgstr ""
 "--mirror est dangereux et obsolète ; merci\n"
 "\t d'utiliser --mirror=fetch ou --mirror=push à la place"
 
-#: builtin/remote.c:145
+#: builtin/remote.c:147
 #, c-format
 msgid "unknown mirror argument: %s"
 msgstr "argument miroir inconnu : %s"
 
-#: builtin/remote.c:161
+#: builtin/remote.c:163
 msgid "fetch the remote branches"
 msgstr "rapatrier les branches distantes"
 
-#: builtin/remote.c:163
+#: builtin/remote.c:165
 msgid "import all tags and associated objects when fetching"
 msgstr ""
 "importer toutes les étiquettes et les objets associés lors du rapatriement"
 
-#: builtin/remote.c:166
+#: builtin/remote.c:168
 msgid "or do not fetch any tag at all (--no-tags)"
 msgstr "ou ne rapatrier aucune étiquette (--no-tags)"
 
-#: builtin/remote.c:168
+#: builtin/remote.c:170
 msgid "branch(es) to track"
 msgstr "branche(s) à suivre"
 
-#: builtin/remote.c:169
+#: builtin/remote.c:171
 msgid "master branch"
 msgstr "branche maîtresse"
 
-#: builtin/remote.c:170
-msgid "push|fetch"
-msgstr "push|fetch"
-
-#: builtin/remote.c:171
+#: builtin/remote.c:173
 msgid "set up remote as a mirror to push to or fetch from"
 msgstr ""
 "paramétrer la distante comme miroir pour pousser ou pour rapatrier depuis"
 
-#: builtin/remote.c:183
+#: builtin/remote.c:185
 msgid "specifying a master branch makes no sense with --mirror"
 msgstr "spécifier une branche maîtresse n'a pas de sens avec --mirror"
 
-#: builtin/remote.c:185
+#: builtin/remote.c:187
 msgid "specifying branches to track makes sense only with fetch mirrors"
 msgstr ""
 "spécifier les branches à suivre n'a de sens qu'avec des miroirs de "
 "rapatriement"
 
-#: builtin/remote.c:192 builtin/remote.c:634
+#: builtin/remote.c:194 builtin/remote.c:636
 #, c-format
 msgid "remote %s already exists."
 msgstr "la distante %s existe déjà."
 
-#: builtin/remote.c:196 builtin/remote.c:638
+#: builtin/remote.c:198 builtin/remote.c:640
 #, c-format
 msgid "'%s' is not a valid remote name"
 msgstr "'%s' n'est pas un nom valide de distante"
 
-#: builtin/remote.c:236
+#: builtin/remote.c:238
 #, c-format
 msgid "Could not setup master '%s'"
 msgstr "Impossible de paramétrer la maîtresse '%s'"
 
-#: builtin/remote.c:342
+#: builtin/remote.c:344
 #, c-format
 msgid "Could not get fetch map for refspec %s"
 msgstr ""
 "Impossible d'obtenir une correspondance distante pour la spécification de "
 "référence %s"
 
-#: builtin/remote.c:441 builtin/remote.c:449
+#: builtin/remote.c:443 builtin/remote.c:451
 msgid "(matching)"
 msgstr "(correspond)"
 
-#: builtin/remote.c:453
+#: builtin/remote.c:455
 msgid "(delete)"
 msgstr "(supprimer)"
 
-#: builtin/remote.c:627 builtin/remote.c:762 builtin/remote.c:861
+#: builtin/remote.c:629 builtin/remote.c:764 builtin/remote.c:863
 #, c-format
-msgid "No such remote: %s"
-msgstr "Distante inconnue : %s"
+msgid "No such remote: '%s'"
+msgstr "Pas de serveur remote : '%s'"
 
-#: builtin/remote.c:644
+#: builtin/remote.c:646
 #, c-format
 msgid "Could not rename config section '%s' to '%s'"
 msgstr "Impossible de renommer la section de configuration '%s' en '%s'"
 
-#: builtin/remote.c:664
+#: builtin/remote.c:666
 #, c-format
 msgid ""
 "Not updating non-default fetch refspec\n"
@@ -13255,17 +18941,17 @@ msgstr ""
 "\t%s\n"
 "\tVeuillez mettre à jour la configuration manuellement si nécessaire."
 
-#: builtin/remote.c:700
+#: builtin/remote.c:701
 #, c-format
 msgid "deleting '%s' failed"
 msgstr "échec de suppression de '%s'"
 
-#: builtin/remote.c:734
+#: builtin/remote.c:735
 #, c-format
 msgid "creating '%s' failed"
 msgstr "échec de création de '%s'"
 
-#: builtin/remote.c:799
+#: builtin/remote.c:801
 msgid ""
 "Note: A branch outside the refs/remotes/ hierarchy was not removed;\n"
 "to delete it, use:"
@@ -13280,118 +18966,118 @@ msgstr[1] ""
 "supprimées ;\n"
 "pour les supprimer, utilisez :"
 
-#: builtin/remote.c:813
+#: builtin/remote.c:815
 #, c-format
 msgid "Could not remove config section '%s'"
 msgstr "Impossible de supprimer la section de configuration '%s'"
 
-#: builtin/remote.c:914
+#: builtin/remote.c:916
 #, c-format
 msgid " new (next fetch will store in remotes/%s)"
 msgstr " nouveau (le prochain rapatriement (fetch) stockera dans remotes/%s)"
 
-#: builtin/remote.c:917
+#: builtin/remote.c:919
 msgid " tracked"
 msgstr " suivi"
 
-#: builtin/remote.c:919
+#: builtin/remote.c:921
 msgid " stale (use 'git remote prune' to remove)"
 msgstr " dépassé (utilisez 'git remote prune' pour supprimer)"
 
-#: builtin/remote.c:921
+#: builtin/remote.c:923
 msgid " ???"
 msgstr " ???"
 
-#: builtin/remote.c:962
+#: builtin/remote.c:964
 #, c-format
 msgid "invalid branch.%s.merge; cannot rebase onto > 1 branch"
 msgstr "branch.%s.merge invalide ; ne peut pas rebaser sur plus d'une branche"
 
-#: builtin/remote.c:971
+#: builtin/remote.c:973
 #, c-format
 msgid "rebases interactively onto remote %s"
 msgstr "rebase de manière interactive sur la distante %s"
 
-#: builtin/remote.c:973
+#: builtin/remote.c:975
 #, c-format
 msgid "rebases interactively (with merges) onto remote %s"
 msgstr "rebase de manière interactive (avec fusions) sur la distante %s"
 
-#: builtin/remote.c:976
+#: builtin/remote.c:978
 #, c-format
 msgid "rebases onto remote %s"
 msgstr "rebase sur la distante %s"
 
-#: builtin/remote.c:980
+#: builtin/remote.c:982
 #, c-format
 msgid " merges with remote %s"
 msgstr " fusionne avec la distante %s"
 
-#: builtin/remote.c:983
+#: builtin/remote.c:985
 #, c-format
 msgid "merges with remote %s"
 msgstr "fusionne avec la distante %s"
 
-#: builtin/remote.c:986
+#: builtin/remote.c:988
 #, c-format
 msgid "%-*s    and with remote %s\n"
 msgstr "%-*s    et avec la distante %s\n"
 
-#: builtin/remote.c:1029
+#: builtin/remote.c:1031
 msgid "create"
 msgstr "créer"
 
-#: builtin/remote.c:1032
+#: builtin/remote.c:1034
 msgid "delete"
 msgstr "supprimer"
 
-#: builtin/remote.c:1036
+#: builtin/remote.c:1038
 msgid "up to date"
 msgstr "à jour"
 
-#: builtin/remote.c:1039
+#: builtin/remote.c:1041
 msgid "fast-forwardable"
 msgstr "peut être mis à jour en avance rapide"
 
-#: builtin/remote.c:1042
+#: builtin/remote.c:1044
 msgid "local out of date"
 msgstr "le local n'est pas à jour"
 
-#: builtin/remote.c:1049
+#: builtin/remote.c:1051
 #, c-format
 msgid "    %-*s forces to %-*s (%s)"
 msgstr "    %-*s force vers %-*s (%s)"
 
-#: builtin/remote.c:1052
+#: builtin/remote.c:1054
 #, c-format
 msgid "    %-*s pushes to %-*s (%s)"
 msgstr "    %-*s pousse vers %-*s (%s)"
 
-#: builtin/remote.c:1056
+#: builtin/remote.c:1058
 #, c-format
 msgid "    %-*s forces to %s"
 msgstr "    %-*s force vers %s"
 
-#: builtin/remote.c:1059
+#: builtin/remote.c:1061
 #, c-format
 msgid "    %-*s pushes to %s"
 msgstr "    %-*s pousse vers %s"
 
-#: builtin/remote.c:1127
+#: builtin/remote.c:1129
 msgid "do not query remotes"
 msgstr "ne pas interroger les distantes"
 
-#: builtin/remote.c:1154
+#: builtin/remote.c:1156
 #, c-format
 msgid "* remote %s"
 msgstr "* distante %s"
 
-#: builtin/remote.c:1155
+#: builtin/remote.c:1157
 #, c-format
 msgid "  Fetch URL: %s"
 msgstr "  URL de rapatriement : %s"
 
-#: builtin/remote.c:1156 builtin/remote.c:1172 builtin/remote.c:1311
+#: builtin/remote.c:1158 builtin/remote.c:1174 builtin/remote.c:1313
 msgid "(no URL)"
 msgstr "(pas d'URL)"
 
@@ -13399,25 +19085,25 @@ msgstr "(pas d'URL)"
 #. with the one in " Fetch URL: %s"
 #. translation.
 #.
-#: builtin/remote.c:1170 builtin/remote.c:1172
+#: builtin/remote.c:1172 builtin/remote.c:1174
 #, c-format
 msgid "  Push  URL: %s"
 msgstr "  URL push : %s"
 
-#: builtin/remote.c:1174 builtin/remote.c:1176 builtin/remote.c:1178
+#: builtin/remote.c:1176 builtin/remote.c:1178 builtin/remote.c:1180
 #, c-format
 msgid "  HEAD branch: %s"
 msgstr "  Branche HEAD : %s"
 
-#: builtin/remote.c:1174
+#: builtin/remote.c:1176
 msgid "(not queried)"
 msgstr "(non demandé)"
 
-#: builtin/remote.c:1176
+#: builtin/remote.c:1178
 msgid "(unknown)"
 msgstr "(inconnu)"
 
-#: builtin/remote.c:1180
+#: builtin/remote.c:1182
 #, c-format
 msgid ""
 "  HEAD branch (remote HEAD is ambiguous, may be one of the following):\n"
@@ -13425,171 +19111,162 @@ msgstr ""
 "  Branche HEAD (la HEAD distante est ambiguë, peut être l'une des "
 "suivantes) :\n"
 
-#: builtin/remote.c:1192
+#: builtin/remote.c:1194
 #, c-format
 msgid "  Remote branch:%s"
 msgid_plural "  Remote branches:%s"
 msgstr[0] "  Branche distante :%s"
 msgstr[1] "  Branches distantes :%s"
 
-#: builtin/remote.c:1195 builtin/remote.c:1221
+#: builtin/remote.c:1197 builtin/remote.c:1223
 msgid " (status not queried)"
 msgstr " (état non demandé)"
 
-#: builtin/remote.c:1204
+#: builtin/remote.c:1206
 msgid "  Local branch configured for 'git pull':"
 msgid_plural "  Local branches configured for 'git pull':"
 msgstr[0] "  Branche locale configurée pour 'git pull' :"
 msgstr[1] "  Branches locales configurées pour 'git pull' :"
 
-#: builtin/remote.c:1212
+#: builtin/remote.c:1214
 msgid "  Local refs will be mirrored by 'git push'"
 msgstr "  Les références locales seront reflétées par 'git push'"
 
-#: builtin/remote.c:1218
+#: builtin/remote.c:1220
 #, c-format
 msgid "  Local ref configured for 'git push'%s:"
 msgid_plural "  Local refs configured for 'git push'%s:"
 msgstr[0] "  Référence locale configurée pour 'git push'%s :"
 msgstr[1] "  Références locales configurées pour 'git push'%s :"
 
-#: builtin/remote.c:1239
+#: builtin/remote.c:1241
 msgid "set refs/remotes/<name>/HEAD according to remote"
 msgstr "définir refs/remotes/<nom>/HEAD selon la distante"
 
-#: builtin/remote.c:1241
+#: builtin/remote.c:1243
 msgid "delete refs/remotes/<name>/HEAD"
 msgstr "supprimer refs/remotes/<nom>/HEAD"
 
-#: builtin/remote.c:1256
+#: builtin/remote.c:1258
 msgid "Cannot determine remote HEAD"
 msgstr "Impossible de déterminer la HEAD distante"
 
-#: builtin/remote.c:1258
+#: builtin/remote.c:1260
 msgid "Multiple remote HEAD branches. Please choose one explicitly with:"
 msgstr ""
 "Il y a de multiples branches HEAD distantes. Veuillez en choisir une "
 "explicitement avec :"
 
-#: builtin/remote.c:1268
+#: builtin/remote.c:1270
 #, c-format
 msgid "Could not delete %s"
 msgstr "Impossible de supprimer %s"
 
-#: builtin/remote.c:1276
+#: builtin/remote.c:1278
 #, c-format
 msgid "Not a valid ref: %s"
 msgstr "Référence non valide : %s"
 
-#: builtin/remote.c:1278
+#: builtin/remote.c:1280
 #, c-format
 msgid "Could not setup %s"
 msgstr "Impossible de paramétrer %s"
 
-#: builtin/remote.c:1296
+#: builtin/remote.c:1298
 #, c-format
 msgid " %s will become dangling!"
 msgstr " %s se retrouvera en suspens !"
 
-#: builtin/remote.c:1297
+#: builtin/remote.c:1299
 #, c-format
 msgid " %s has become dangling!"
 msgstr " %s se retrouve en suspens !"
 
-#: builtin/remote.c:1307
+#: builtin/remote.c:1309
 #, c-format
 msgid "Pruning %s"
 msgstr "Élimination de %s"
 
-#: builtin/remote.c:1308
+#: builtin/remote.c:1310
 #, c-format
 msgid "URL: %s"
 msgstr "URL : %s"
 
-#: builtin/remote.c:1324
+#: builtin/remote.c:1326
 #, c-format
 msgid " * [would prune] %s"
 msgstr " * [serait éliminé] %s"
 
-#: builtin/remote.c:1327
+#: builtin/remote.c:1329
 #, c-format
 msgid " * [pruned] %s"
 msgstr " * [éliminé] %s"
 
-#: builtin/remote.c:1372
+#: builtin/remote.c:1374
 msgid "prune remotes after fetching"
 msgstr "éliminer les distants après le rapatriement"
 
-#: builtin/remote.c:1435 builtin/remote.c:1489 builtin/remote.c:1557
+#: builtin/remote.c:1437 builtin/remote.c:1491 builtin/remote.c:1559
 #, c-format
 msgid "No such remote '%s'"
 msgstr "Pas de serveur remote '%s'"
 
-#: builtin/remote.c:1451
+#: builtin/remote.c:1453
 msgid "add branch"
 msgstr "ajouter une branche"
 
-#: builtin/remote.c:1458
+#: builtin/remote.c:1460
 msgid "no remote specified"
 msgstr "pas de serveur distant spécifié"
 
-#: builtin/remote.c:1475
+#: builtin/remote.c:1477
 msgid "query push URLs rather than fetch URLs"
 msgstr "interroger les URLs de poussée plutôt que les URLs de récupération"
 
-#: builtin/remote.c:1477
+#: builtin/remote.c:1479
 msgid "return all URLs"
 msgstr "retourner toutes les URLs"
 
-#: builtin/remote.c:1505
+#: builtin/remote.c:1507
 #, c-format
 msgid "no URLs configured for remote '%s'"
 msgstr "aucune URL configurée pour le dépôt distant '%s'"
 
-#: builtin/remote.c:1531
+#: builtin/remote.c:1533
 msgid "manipulate push URLs"
 msgstr "manipuler les URLs push"
 
-#: builtin/remote.c:1533
+#: builtin/remote.c:1535
 msgid "add URL"
 msgstr "ajouter une URL"
 
-#: builtin/remote.c:1535
+#: builtin/remote.c:1537
 msgid "delete URLs"
 msgstr "supprimer des URLs"
 
-#: builtin/remote.c:1542
+#: builtin/remote.c:1544
 msgid "--add --delete doesn't make sense"
 msgstr "--add --delete n'a aucun sens"
 
-#: builtin/remote.c:1581
+#: builtin/remote.c:1583
 #, c-format
 msgid "Invalid old URL pattern: %s"
 msgstr "Motif d'URL ancien invalide : %s"
 
-#: builtin/remote.c:1589
+#: builtin/remote.c:1591
 #, c-format
 msgid "No such URL found: %s"
 msgstr "Pas d'URL trouvée : %s"
 
-#: builtin/remote.c:1591
+#: builtin/remote.c:1593
 msgid "Will not delete all non-push URLs"
 msgstr "Pas de suppression de toutes les URLs non-push"
 
-#: builtin/remote.c:1607
-msgid "be verbose; must be placed before a subcommand"
-msgstr "être verbeux : doit être placé avant une sous-commande"
-
-#: builtin/remote.c:1638
-#, c-format
-msgid "Unknown subcommand: %s"
-msgstr "Sous-commande inconnue : %s"
-
-#: builtin/repack.c:18
+#: builtin/repack.c:23
 msgid "git repack [<options>]"
 msgstr "git repack [<options>]"
 
-#: builtin/repack.c:23
+#: builtin/repack.c:28
 msgid ""
 "Incremental repacks are incompatible with bitmap indexes.  Use\n"
 "--no-write-bitmap-index or disable the pack.writebitmaps configuration."
@@ -13598,136 +19275,279 @@ msgstr ""
 "Utilisez\n"
 "--no-write-bitmap-index ou désactivez le paramètre pack.writebitmaps."
 
-#: builtin/repack.c:180
+#: builtin/repack.c:191
+msgid "could not start pack-objects to repack promisor objects"
+msgstr ""
+"ne pas démarrer pack-objects pour ré-empaqueter les objects de prometteur"
+
+#: builtin/repack.c:230 builtin/repack.c:416
+msgid "repack: Expecting full hex object ID lines only from pack-objects."
+msgstr ""
+"repack : attente de lignes d'Id d'objets en hexa complet seulement depuis "
+"les objects de paquet."
+
+#: builtin/repack.c:254
+msgid "could not finish pack-objects to repack promisor objects"
+msgstr ""
+"impossible de terminer pack-objects  pour ré-empaqueter les objets de "
+"prometteur"
+
+#: builtin/repack.c:292
 msgid "pack everything in a single pack"
 msgstr "empaqueter tout dans un seul paquet"
 
-#: builtin/repack.c:182
+#: builtin/repack.c:294
 msgid "same as -a, and turn unreachable objects loose"
 msgstr "identique à -a et transformer les objets inaccessibles en suspens"
 
-#: builtin/repack.c:185
+#: builtin/repack.c:297
 msgid "remove redundant packs, and run git-prune-packed"
 msgstr "supprimer les paquets redondants et lancer git-prune-packed"
 
-#: builtin/repack.c:187
+#: builtin/repack.c:299
 msgid "pass --no-reuse-delta to git-pack-objects"
 msgstr "passer --no-reuse-delta à git-pack-objects"
 
-#: builtin/repack.c:189
+#: builtin/repack.c:301
 msgid "pass --no-reuse-object to git-pack-objects"
 msgstr "passer --no-reuse-object à git-pack-objects"
 
-#: builtin/repack.c:191
+#: builtin/repack.c:303
 msgid "do not run git-update-server-info"
 msgstr "ne pas lancer git update-server-info"
 
-#: builtin/repack.c:194
+#: builtin/repack.c:306
 msgid "pass --local to git-pack-objects"
 msgstr "passer --local à git-pack-objects"
 
-#: builtin/repack.c:196
+#: builtin/repack.c:308
 msgid "write bitmap index"
 msgstr "écrire un index en bitmap"
 
-#: builtin/repack.c:197
+#: builtin/repack.c:310
+msgid "pass --delta-islands to git-pack-objects"
+msgstr "passer --delta-islands à git-pack-objects"
+
+#: builtin/repack.c:311
 msgid "approxidate"
 msgstr "date approximative"
 
-#: builtin/repack.c:198
+#: builtin/repack.c:312
 msgid "with -A, do not loosen objects older than this"
 msgstr "avec -A, ne pas suspendre les objets plus vieux que celui-ci"
 
-#: builtin/repack.c:200
+#: builtin/repack.c:314
 msgid "with -a, repack unreachable objects"
 msgstr "avec -a, repaquétiser les objets inaccessibles"
 
-#: builtin/repack.c:202
+#: builtin/repack.c:316
 msgid "size of the window used for delta compression"
 msgstr "taille de la fenêtre utilisée pour la compression des deltas"
 
-#: builtin/repack.c:203 builtin/repack.c:209
+#: builtin/repack.c:317 builtin/repack.c:323
 msgid "bytes"
 msgstr "octets"
 
-#: builtin/repack.c:204
+#: builtin/repack.c:318
 msgid "same as the above, but limit memory size instead of entries count"
 msgstr ""
 "idem ci-dessus, mais limiter la taille mémoire au lieu du nombre d'éléments"
 
-#: builtin/repack.c:206
+#: builtin/repack.c:320
 msgid "limits the maximum delta depth"
 msgstr "limite la profondeur maximale des deltas"
 
-#: builtin/repack.c:208
+#: builtin/repack.c:322
 msgid "limits the maximum number of threads"
 msgstr "limite le nombre maximal de fils"
 
-#: builtin/repack.c:210
+#: builtin/repack.c:324
 msgid "maximum size of each packfile"
 msgstr "taille maximum de chaque fichier paquet"
 
-#: builtin/repack.c:212
+#: builtin/repack.c:326
 msgid "repack objects in packs marked with .keep"
 msgstr "réempaqueter les objets dans des paquets marqués avec .keep"
 
-#: builtin/repack.c:214
+#: builtin/repack.c:328
 msgid "do not repack this pack"
 msgstr "ne pas rempaqueter ce paquet"
 
-#: builtin/repack.c:224
+#: builtin/repack.c:338
 msgid "cannot delete packs in a precious-objects repo"
 msgstr "impossible de supprimer les paquets dans un dépôt d'objets précieux"
 
-#: builtin/repack.c:228
+#: builtin/repack.c:342
 msgid "--keep-unreachable and -A are incompatible"
 msgstr "--keep-unreachable et -A sont incompatibles"
 
-#: builtin/repack.c:425 builtin/worktree.c:139
+#: builtin/repack.c:425
+msgid "Nothing new to pack."
+msgstr "Rien de neuf à empaqueter."
+
+#: builtin/repack.c:486
+#, c-format
+msgid ""
+"WARNING: Some packs in use have been renamed by\n"
+"WARNING: prefixing old- to their name, in order to\n"
+"WARNING: replace them with the new version of the\n"
+"WARNING: file.  But the operation failed, and the\n"
+"WARNING: attempt to rename them back to their\n"
+"WARNING: original names also failed.\n"
+"WARNING: Please rename them in %s manually:\n"
+msgstr ""
+"ALERTE : certains paquets utilisés ont été renommés\n"
+"ALERTE : en les préfixant par old-, de manière à\n"
+"ALERTE : les remplacer par une nouvelle version de\n"
+"ALERTE : fichier. Mais l'opération a échoué et la\n"
+"ALERTE : tentative de renommage en sens inverse a\n"
+"ALERTE : aussi échoué.\n"
+"ALERTE : Veuillez les renommer manuellement dans %s :\n"
+
+#: builtin/repack.c:534
 #, c-format
 msgid "failed to remove '%s'"
 msgstr "échec de la suppression de '%s'"
 
-#: builtin/replace.c:22
-msgid "git replace [-f] <object> <replacement>"
-msgstr "git replace [-f] <objet> <remplacement>"
+#: builtin/replace.c:22
+msgid "git replace [-f] <object> <replacement>"
+msgstr "git replace [-f] <objet> <remplacement>"
+
+#: builtin/replace.c:23
+msgid "git replace [-f] --edit <object>"
+msgstr "git replace [-f] --edit <objet>"
+
+#: builtin/replace.c:24
+msgid "git replace [-f] --graft <commit> [<parent>...]"
+msgstr "git replace [-f] --graft <commit> [<parent>...]"
+
+#: builtin/replace.c:25
+msgid "git replace [-f] --convert-graft-file"
+msgstr "git replace [-f] --convert-graft-file"
+
+#: builtin/replace.c:26
+msgid "git replace -d <object>..."
+msgstr "git replace -d <objet>..."
+
+#: builtin/replace.c:27
+msgid "git replace [--format=<format>] [-l [<pattern>]]"
+msgstr "git replace [--format=<format>] [-l [<motif>]]"
+
+#: builtin/replace.c:90
+#, c-format
+msgid ""
+"invalid replace format '%s'\n"
+"valid formats are 'short', 'medium' and 'long'"
+msgstr ""
+"format de remplacement invalide '%s'\n"
+"les formats valides sont 'short', 'medium' et 'long'"
+
+#: builtin/replace.c:125
+#, c-format
+msgid "replace ref '%s' not found"
+msgstr "réf de remplacement '%s' non trouvée"
+
+#: builtin/replace.c:141
+#, c-format
+msgid "Deleted replace ref '%s'"
+msgstr "Référence de remplacement '%s' supprimée"
+
+#: builtin/replace.c:153
+#, c-format
+msgid "'%s' is not a valid ref name"
+msgstr "'%s' n'est pas un nom valide de référence"
+
+#: builtin/replace.c:158
+#, c-format
+msgid "replace ref '%s' already exists"
+msgstr "la référence de remplacement '%s' existe déjà"
+
+#: builtin/replace.c:178
+#, c-format
+msgid ""
+"Objects must be of the same type.\n"
+"'%s' points to a replaced object of type '%s'\n"
+"while '%s' points to a replacement object of type '%s'."
+msgstr ""
+"Les objets doivent être du même type.\n"
+"'%s' pointe sur un objet remplacé de type '%s' tandis que\n"
+"'%s' pointe sur un objet remplaçant de type '%s'."
+
+#: builtin/replace.c:229
+#, c-format
+msgid "unable to open %s for writing"
+msgstr "impossible d'ouvrir %s en écriture"
+
+#: builtin/replace.c:242
+msgid "cat-file reported failure"
+msgstr "cat-file a retourné un échec"
+
+#: builtin/replace.c:258
+#, c-format
+msgid "unable to open %s for reading"
+msgstr "impossible d'ouvrir %s en écriture"
+
+#: builtin/replace.c:272
+msgid "unable to spawn mktree"
+msgstr "impossible de lire l'arbre (%s)"
+
+#: builtin/replace.c:276
+msgid "unable to read from mktree"
+msgstr "impossible de lire depui mktree"
+
+#: builtin/replace.c:285
+msgid "mktree reported failure"
+msgstr "mktree a échoué"
+
+#: builtin/replace.c:289
+msgid "mktree did not return an object name"
+msgstr "mktree n'a pas retourné de nom d'objet"
+
+#: builtin/replace.c:298
+#, c-format
+msgid "unable to fstat %s"
+msgstr "fstat de %s impossible"
 
-#: builtin/replace.c:23
-msgid "git replace [-f] --edit <object>"
-msgstr "git replace [-f] --edit <objet>"
+#: builtin/replace.c:303
+msgid "unable to write object to database"
+msgstr "impossible d'écrire l'objet dans la base de données"
 
-#: builtin/replace.c:24
-msgid "git replace [-f] --graft <commit> [<parent>...]"
-msgstr "git replace [-f] --graft <commit> [<parent>...]"
+#: builtin/replace.c:322 builtin/replace.c:378 builtin/replace.c:423
+#: builtin/replace.c:453
+#, c-format
+msgid "not a valid object name: '%s'"
+msgstr "nom d'objet invalide : '%s'"
 
-#: builtin/replace.c:25
-msgid "git replace [-f] --convert-graft-file"
-msgstr "git replace [-f] --convert-graft-file"
+#: builtin/replace.c:326
+#, c-format
+msgid "unable to get object type for %s"
+msgstr "impossible d'obtenir le type de l'objet pour %s"
 
-#: builtin/replace.c:26
-msgid "git replace -d <object>..."
-msgstr "git replace -d <objet>..."
+#: builtin/replace.c:342
+msgid "editing object file failed"
+msgstr "échec de l'édition du fichier d'objet"
 
-#: builtin/replace.c:27
-msgid "git replace [--format=<format>] [-l [<pattern>]]"
-msgstr "git replace [--format=<format>] [-l [<motif>]]"
+#: builtin/replace.c:351
+#, c-format
+msgid "new object is the same as the old one: '%s'"
+msgstr "le nouvel objet est identique à l'ancien : '%s'"
 
-#: builtin/replace.c:371 builtin/replace.c:415 builtin/replace.c:445
+#: builtin/replace.c:384
 #, c-format
-msgid "Not a valid object name: '%s'"
-msgstr "Nom d'objet invalide : '%s'"
+msgid "could not parse %s as a commit"
+msgstr "impossible d'analyser %s comme commit"
 
-#: builtin/replace.c:407
+#: builtin/replace.c:415
 #, c-format
 msgid "bad mergetag in commit '%s'"
 msgstr "mauvaise étiquette de fusion dans le commit '%s'"
 
-#: builtin/replace.c:409
+#: builtin/replace.c:417
 #, c-format
 msgid "malformed mergetag in commit '%s'"
 msgstr "étiquette de fusion malformée dans le commit '%s'"
 
-#: builtin/replace.c:421
+#: builtin/replace.c:429
 #, c-format
 msgid ""
 "original commit '%s' contains mergetag '%s' that is discarded; use --edit "
@@ -13736,21 +19556,31 @@ msgstr ""
 "le commit original '%s' contient l'étiquette de fusion '%s' qui a disparu ; "
 "utilisez --edit au lieu de --graft"
 
-#: builtin/replace.c:460
+#: builtin/replace.c:468
 #, c-format
-msgid "the original commit '%s' has a gpg signature."
-msgstr "le commit original '%s' contient une signature GPG."
+msgid "the original commit '%s' has a gpg signature"
+msgstr "le commit original '%s' contient une signature GPG"
 
-#: builtin/replace.c:461
+#: builtin/replace.c:469
 msgid "the signature will be removed in the replacement commit!"
 msgstr "la signature sera éliminée dans la validation de remplacement !"
 
-#: builtin/replace.c:471
+#: builtin/replace.c:479
 #, c-format
 msgid "could not write replacement commit for: '%s'"
 msgstr "Impossible d'écrire le commit de remplacement pour '%s'"
 
-#: builtin/replace.c:514
+#: builtin/replace.c:487
+#, c-format
+msgid "graft for '%s' unnecessary"
+msgstr "graft pour '%s' non nécessaire"
+
+#: builtin/replace.c:491
+#, c-format
+msgid "new commit is the same as the old one: '%s'"
+msgstr "le nouveau commit est identique à l'ancien : '%s'"
+
+#: builtin/replace.c:526
 #, c-format
 msgid ""
 "could not convert the following graft(s):\n"
@@ -13759,215 +19589,276 @@ msgstr ""
 "impossible de convertir la(les) greffe(s) suivante(s) :\n"
 "%s"
 
-#: builtin/replace.c:535
+#: builtin/replace.c:547
 msgid "list replace refs"
 msgstr "afficher les références de remplacement"
 
-#: builtin/replace.c:536
+#: builtin/replace.c:548
 msgid "delete replace refs"
 msgstr "supprimer les références de remplacement"
 
-#: builtin/replace.c:537
+#: builtin/replace.c:549
 msgid "edit existing object"
 msgstr "éditer l'objet existant"
 
-#: builtin/replace.c:538
+#: builtin/replace.c:550
 msgid "change a commit's parents"
 msgstr "Modifier les parents d'un commit"
 
-#: builtin/replace.c:539
+#: builtin/replace.c:551
 msgid "convert existing graft file"
 msgstr "convertir le fichier de greffe existant"
 
-#: builtin/replace.c:540
+#: builtin/replace.c:552
 msgid "replace the ref if it exists"
 msgstr "remplacer la référence si elle existe"
 
-#: builtin/replace.c:542
+#: builtin/replace.c:554
 msgid "do not pretty-print contents for --edit"
 msgstr "afficher sans mise en forme pour --edit"
 
-#: builtin/replace.c:543
+#: builtin/replace.c:555
 msgid "use this format"
 msgstr "utiliser ce format"
 
+#: builtin/replace.c:568
+msgid "--format cannot be used when not listing"
+msgstr "--format ne peut pas être utilisé sans lister"
+
+#: builtin/replace.c:576
+msgid "-f only makes sense when writing a replacement"
+msgstr "-f n'a de sens qu'en écrivant un remplacement"
+
+#: builtin/replace.c:580
+msgid "--raw only makes sense with --edit"
+msgstr "--raw n'a de sens qu'avec l'option --edit"
+
+#: builtin/replace.c:586
+msgid "-d needs at least one argument"
+msgstr "-d requiert au moins un argument"
+
+#: builtin/replace.c:592
+msgid "bad number of arguments"
+msgstr "mauvais nombre d'arguments"
+
+#: builtin/replace.c:598
+msgid "-e needs exactly one argument"
+msgstr "-e requiert un seul argument"
+
+#: builtin/replace.c:604
+msgid "-g needs at least one argument"
+msgstr "-g requiert au moins un argument"
+
+#: builtin/replace.c:610
+msgid "--convert-graft-file takes no argument"
+msgstr "--convert-graft-file ne supporte aucun argument"
+
+#: builtin/replace.c:616
+msgid "only one pattern can be given with -l"
+msgstr "-l n'accepte qu'un motifs"
+
 #: builtin/rerere.c:13
 msgid "git rerere [clear | forget <path>... | status | remaining | diff | gc]"
 msgstr ""
 "git rerere [clear | forget <chemin>... | status | remaining | diff | gc]"
 
-#: builtin/rerere.c:59
+#: builtin/rerere.c:60
 msgid "register clean resolutions in index"
 msgstr "enregistrer des résolutions propres dans l'index"
 
-#: builtin/reset.c:29
+#: builtin/rerere.c:79
+msgid "'git rerere forget' without paths is deprecated"
+msgstr "'git rerere forget' sans chemin est obsolète"
+
+#: builtin/rerere.c:113
+#, c-format
+msgid "unable to generate diff for '%s'"
+msgstr "échec de la génération de diff pour '%s'"
+
+#: builtin/reset.c:32
 msgid ""
 "git reset [--mixed | --soft | --hard | --merge | --keep] [-q] [<commit>]"
 msgstr ""
 "git reset [--mixed | --soft | --hard | --merge | --keep] [-q] [<commit>]"
 
-#: builtin/reset.c:30
-msgid "git reset [-q] [<tree-ish>] [--] <paths>..."
-msgstr "git reset [-q] [<arbre ou apparenté>] [--] <chemins>..."
-
-#: builtin/reset.c:31
-msgid "git reset --patch [<tree-ish>] [--] [<paths>...]"
-msgstr "git reset --patch [<arbre ou apparenté>] [--] [<chemins>...]"
+#: builtin/reset.c:33
+msgid "git reset [-q] [<tree-ish>] [--] <pathspec>..."
+msgstr "git reset [-q] [<arbre ou apparenté>] [--] <spécificateur-de-chemin>..."
+
+#: builtin/reset.c:34
+msgid ""
+"git reset [-q] [--pathspec-from-file [--pathspec-file-nul]] [<tree-ish>]"
+msgstr "git reset [-q] [--pathspec-from-file [--pathspec-file-nul]] [<arbre-esque>]"
+
+#: builtin/reset.c:35
+msgid "git reset --patch [<tree-ish>] [--] [<pathspec>...]"
+msgstr "git reset --patch [<arbre-esque>] [--] [<spéc.-de-chemin>...]"
 
-#: builtin/reset.c:37
+#: builtin/reset.c:41
 msgid "mixed"
 msgstr "mixed"
 
-#: builtin/reset.c:37
+#: builtin/reset.c:41
 msgid "soft"
 msgstr "soft"
 
-#: builtin/reset.c:37
+#: builtin/reset.c:41
 msgid "hard"
 msgstr "hard"
 
-#: builtin/reset.c:37
+#: builtin/reset.c:41
 msgid "merge"
 msgstr "merge"
 
-#: builtin/reset.c:37
+#: builtin/reset.c:41
 msgid "keep"
 msgstr "keep"
 
-#: builtin/reset.c:78
+#: builtin/reset.c:82
 msgid "You do not have a valid HEAD."
 msgstr "Vous n'avez pas une HEAD valide."
 
-#: builtin/reset.c:80
+#: builtin/reset.c:84
 msgid "Failed to find tree of HEAD."
 msgstr "Impossible de trouver l'arbre pour HEAD."
 
-#: builtin/reset.c:86
+#: builtin/reset.c:90
 #, c-format
 msgid "Failed to find tree of %s."
 msgstr "Impossible de trouver l'arbre pour %s."
 
-#: builtin/reset.c:111
+#: builtin/reset.c:115
 #, c-format
 msgid "HEAD is now at %s"
 msgstr "HEAD est maintenant à %s"
 
-#: builtin/reset.c:189
+#: builtin/reset.c:194
 #, c-format
 msgid "Cannot do a %s reset in the middle of a merge."
 msgstr "Impossible de faire un \"reset %s\" au milieu d'une fusion."
 
-#: builtin/reset.c:289
+#: builtin/reset.c:294 builtin/stash.c:519 builtin/stash.c:594
+#: builtin/stash.c:618
 msgid "be quiet, only report errors"
 msgstr "être silencieux, afficher seulement les erreurs"
 
-#: builtin/reset.c:291
+#: builtin/reset.c:296
 msgid "reset HEAD and index"
 msgstr "réinitialiser HEAD et l'index"
 
-#: builtin/reset.c:292
+#: builtin/reset.c:297
 msgid "reset only HEAD"
 msgstr "réinitialiser seulement HEAD"
 
-#: builtin/reset.c:294 builtin/reset.c:296
+#: builtin/reset.c:299 builtin/reset.c:301
 msgid "reset HEAD, index and working tree"
 msgstr "réinitialiser HEAD, l'index et la copie de travail"
 
-#: builtin/reset.c:298
+#: builtin/reset.c:303
 msgid "reset HEAD but keep local changes"
 msgstr "réinitialiser HEAD mais garder les changements locaux"
 
-#: builtin/reset.c:304
+#: builtin/reset.c:309
 msgid "record only the fact that removed paths will be added later"
 msgstr ""
 "enregistrer seulement le fait que les chemins effacés seront ajoutés plus "
 "tard"
 
-#: builtin/reset.c:321
+#: builtin/reset.c:343
 #, c-format
 msgid "Failed to resolve '%s' as a valid revision."
 msgstr "Échec de résolution de '%s' comme une révision valide."
 
-#: builtin/reset.c:329
+#: builtin/reset.c:351
 #, c-format
 msgid "Failed to resolve '%s' as a valid tree."
 msgstr "Échec de résolution de '%s' comme un arbre valide."
 
-#: builtin/reset.c:338
+#: builtin/reset.c:360
 msgid "--patch is incompatible with --{hard,mixed,soft}"
 msgstr "--patch est incompatible avec --{hard,mixed,soft}"
 
-#: builtin/reset.c:347
+#: builtin/reset.c:370
 msgid "--mixed with paths is deprecated; use 'git reset -- <paths>' instead."
 msgstr ""
 "--mixed avec des chemins est obsolète ; utilisez 'git reset -- <paths>' à la "
 "place."
 
-#: builtin/reset.c:349
+#: builtin/reset.c:372
 #, c-format
 msgid "Cannot do %s reset with paths."
 msgstr "Impossible de faire un \"%s reset\" avec des chemins."
 
-#: builtin/reset.c:359
+#: builtin/reset.c:387
 #, c-format
 msgid "%s reset is not allowed in a bare repository"
 msgstr "Le \"%s reset\" n'est pas permis dans un dépôt nu"
 
-#: builtin/reset.c:363
+#: builtin/reset.c:391
 msgid "-N can only be used with --mixed"
 msgstr "-N ne peut être utilisé qu'avec --mixed"
 
-#: builtin/reset.c:380
+#: builtin/reset.c:412
 msgid "Unstaged changes after reset:"
 msgstr "Modifications non indexées après reset :"
 
-#: builtin/reset.c:386
+#: builtin/reset.c:415
+#, c-format
+msgid ""
+"\n"
+"It took %.2f seconds to enumerate unstaged changes after reset.  You can\n"
+"use '--quiet' to avoid this.  Set the config setting reset.quiet to true\n"
+"to make this the default.\n"
+msgstr ""
+"\n"
+"Les modifications non-indexées ont pris %.2f secondes à énumérer après "
+"reset.\n"
+"Vous pouvez utiliser '--quiet' pour éviter ce message. Réglez le paramètre "
+"de\n"
+"config reset.quiet à true pour avoir ce comportement en permanence.\n"
+
+#: builtin/reset.c:425
 #, c-format
 msgid "Could not reset index file to revision '%s'."
 msgstr "Impossible de réinitialiser le fichier d'index à la révision '%s'."
 
-#: builtin/reset.c:390
+#: builtin/reset.c:429
 msgid "Could not write new index file."
 msgstr "Impossible d'écrire le nouveau fichier d'index."
 
-#: builtin/rev-list.c:397
+#: builtin/rev-list.c:411
 msgid "cannot combine --exclude-promisor-objects and --missing"
 msgstr "impossible de combiner --exclude-promisor-objects et --missing"
 
-#: builtin/rev-list.c:455
+#: builtin/rev-list.c:472
 msgid "object filtering requires --objects"
 msgstr "le filtrage d'objet exige --objects"
 
-#: builtin/rev-list.c:458
-#, c-format
-msgid "invalid sparse value '%s'"
-msgstr "valeur invalide de 'sparse' '%s'"
-
-#: builtin/rev-list.c:499
+#: builtin/rev-list.c:522
 msgid "rev-list does not support display of notes"
 msgstr "rev-list ne supporte l'affichage des notes"
 
-#: builtin/rev-list.c:502
+#: builtin/rev-list.c:525
 msgid "cannot combine --use-bitmap-index with object filtering"
 msgstr "impossible de combiner --use-bitmap-index avec le filtrage d'objet"
 
-#: builtin/rev-parse.c:406
+#: builtin/rev-parse.c:408
 msgid "git rev-parse --parseopt [<options>] -- [<args>...]"
 msgstr "git rev-parse --parseopt [<options>] -- [<arguments>...]"
 
-#: builtin/rev-parse.c:411
+#: builtin/rev-parse.c:413
 msgid "keep the `--` passed as an arg"
 msgstr "garder le `--` passé en argument"
 
-#: builtin/rev-parse.c:413
+#: builtin/rev-parse.c:415
 msgid "stop parsing after the first non-option argument"
 msgstr "arrêt de l'analyse après le premier argument qui n'est pas une option"
 
-#: builtin/rev-parse.c:416
+#: builtin/rev-parse.c:418
 msgid "output in stuck long form"
 msgstr "sortie en forme longue fixée"
 
-#: builtin/rev-parse.c:549
+#: builtin/rev-parse.c:551
 msgid ""
 "git rev-parse --parseopt [<options>] -- [<args>...]\n"
 "   or: git rev-parse --sq-quote [<arg>...]\n"
@@ -13982,92 +19873,97 @@ msgstr ""
 "Lancez \"git rev-parse --parseopt -h\" pour plus d'information sur "
 "l'utilisation principale."
 
-#: builtin/revert.c:23
+#: builtin/revert.c:24
 msgid "git revert [<options>] <commit-ish>..."
 msgstr "git revert [<options>] <commit ou apparenté>..."
 
-#: builtin/revert.c:24
+#: builtin/revert.c:25
 msgid "git revert <subcommand>"
 msgstr "git revert <sous-commande>"
 
-#: builtin/revert.c:29
+#: builtin/revert.c:30
 msgid "git cherry-pick [<options>] <commit-ish>..."
 msgstr "git cherry-pick [<options>] <commit ou apparenté>..."
 
-#: builtin/revert.c:30
+#: builtin/revert.c:31
 msgid "git cherry-pick <subcommand>"
 msgstr "git cherry-pick <sous-commande>"
 
-#: builtin/revert.c:90
+#: builtin/revert.c:72
+#, c-format
+msgid "option `%s' expects a number greater than zero"
+msgstr "l'option '%s' attend un nombre supérieur à zéro"
+
+#: builtin/revert.c:92
 #, c-format
 msgid "%s: %s cannot be used with %s"
 msgstr "%s : %s ne peut pas être utilisé avec %s"
 
-#: builtin/revert.c:99
+#: builtin/revert.c:102
 msgid "end revert or cherry-pick sequence"
 msgstr "mettre fin au retour ou picorage"
 
-#: builtin/revert.c:100
+#: builtin/revert.c:103
 msgid "resume revert or cherry-pick sequence"
 msgstr "reprendre le retour ou picorage"
 
-#: builtin/revert.c:101
+#: builtin/revert.c:104
 msgid "cancel revert or cherry-pick sequence"
 msgstr "annuler le retour ou picorage"
 
-#: builtin/revert.c:102
+#: builtin/revert.c:105
+msgid "skip current commit and continue"
+msgstr "sauter le commit courant et continuer"
+
+#: builtin/revert.c:107
 msgid "don't automatically commit"
 msgstr "ne pas valider automatiquement"
 
-#: builtin/revert.c:103
+#: builtin/revert.c:108
 msgid "edit the commit message"
 msgstr "éditer le message de validation"
 
-#: builtin/revert.c:106
+#: builtin/revert.c:111
 msgid "parent-number"
 msgstr "numéro-de-parent"
 
-#: builtin/revert.c:107
+#: builtin/revert.c:112
 msgid "select mainline parent"
 msgstr "sélectionner le parent principal"
 
-#: builtin/revert.c:109
+#: builtin/revert.c:114
 msgid "merge strategy"
 msgstr "stratégie de fusion"
 
-#: builtin/revert.c:110
-msgid "option"
-msgstr "option"
-
-#: builtin/revert.c:111
+#: builtin/revert.c:116
 msgid "option for merge strategy"
 msgstr "option pour la stratégie de fusion"
 
-#: builtin/revert.c:120
+#: builtin/revert.c:125
 msgid "append commit name"
 msgstr "ajouter le nom de validation"
 
-#: builtin/revert.c:122
+#: builtin/revert.c:127
 msgid "preserve initially empty commits"
 msgstr "préserver les validations vides initialement"
 
-#: builtin/revert.c:124
+#: builtin/revert.c:129
 msgid "keep redundant, empty commits"
 msgstr "garder les validations redondantes, vides"
 
-#: builtin/revert.c:214
+#: builtin/revert.c:232
 msgid "revert failed"
 msgstr "revert a échoué"
 
-#: builtin/revert.c:227
+#: builtin/revert.c:245
 msgid "cherry-pick failed"
 msgstr "le picorage a échoué"
 
-#: builtin/rm.c:18
+#: builtin/rm.c:19
 msgid "git rm [<options>] [--] <file>..."
 msgstr "git rm [<options>] [--] <fichier>..."
 
-#: builtin/rm.c:206
+#: builtin/rm.c:207
 msgid ""
 "the following file has staged content different from both the\n"
 "file and the HEAD:"
@@ -14081,7 +19977,7 @@ msgstr[1] ""
 "les fichiers suivants ont du contenu indexé différent\n"
 "du fichier et de HEAD :"
 
-#: builtin/rm.c:211
+#: builtin/rm.c:212
 msgid ""
 "\n"
 "(use -f to force removal)"
@@ -14089,13 +19985,13 @@ msgstr ""
 "\n"
 "(utilisez -f pour forcer la suppression)"
 
-#: builtin/rm.c:215
+#: builtin/rm.c:216
 msgid "the following file has changes staged in the index:"
 msgid_plural "the following files have changes staged in the index:"
 msgstr[0] "le fichier suivant a des changements indexés :"
 msgstr[1] "les fichiers suivants ont des changements indexés :"
 
-#: builtin/rm.c:219 builtin/rm.c:228
+#: builtin/rm.c:220 builtin/rm.c:229
 msgid ""
 "\n"
 "(use --cached to keep the file, or -f to force removal)"
@@ -14103,47 +19999,48 @@ msgstr ""
 "\n"
 "(utilisez --cached pour garder le fichier, ou -f pour forcer la suppression)"
 
-#: builtin/rm.c:225
+#: builtin/rm.c:226
 msgid "the following file has local modifications:"
 msgid_plural "the following files have local modifications:"
 msgstr[0] "le fichier suivant a des modifications locales :"
 msgstr[1] "les fichiers suivants ont des modifications locales :"
 
-#: builtin/rm.c:241
+#: builtin/rm.c:242
 msgid "do not list removed files"
 msgstr "ne pas afficher les fichiers supprimés"
 
-#: builtin/rm.c:242
+#: builtin/rm.c:243
 msgid "only remove from the index"
 msgstr "supprimer seulement de l'index"
 
-#: builtin/rm.c:243
+#: builtin/rm.c:244
 msgid "override the up-to-date check"
 msgstr "outrepasser la vérification des fichiers à jour"
 
-#: builtin/rm.c:244
+#: builtin/rm.c:245
 msgid "allow recursive removal"
 msgstr "autoriser la suppression récursive"
 
-#: builtin/rm.c:246
+#: builtin/rm.c:247
 msgid "exit with a zero status even if nothing matched"
 msgstr "sortir avec un état zéro même si rien ne correspondait"
 
-#: builtin/rm.c:306
+#: builtin/rm.c:289
+msgid "please stage your changes to .gitmodules or stash them to proceed"
+msgstr ""
+"veuillez indexer vos modifications de .gitmodules ou les remiser pour "
+"continuer"
+
+#: builtin/rm.c:307
 #, c-format
 msgid "not removing '%s' recursively without -r"
 msgstr "pas de suppression récursive de '%s' sans -r"
 
-#: builtin/rm.c:345
+#: builtin/rm.c:346
 #, c-format
 msgid "git rm: unable to remove %s"
 msgstr "git rm : impossible de supprimer %s"
 
-#: builtin/rm.c:368
-#, c-format
-msgid "could not remove '%s'"
-msgstr "impossible de supprimer '%s'"
-
 #: builtin/send-pack.c:20
 msgid ""
 "git send-pack [--all | --mirror] [--dry-run] [--force] [--receive-pack=<git-"
@@ -14173,18 +20070,6 @@ msgstr "lire les références depuis l'e
 msgid "print status from remote helper"
 msgstr "afficher les messages du greffon de protocole distant"
 
-#: builtin/serve.c:7
-msgid "git serve [<options>]"
-msgstr "git serve [<options>]"
-
-#: builtin/serve.c:17 builtin/upload-pack.c:23
-msgid "quit after a single request/response exchange"
-msgstr "quitter après un unique échange requête/réponse"
-
-#: builtin/serve.c:19
-msgid "exit immediately after advertising capabilities"
-msgstr "sortir immédiatement après l'annonce des capacités"
-
 #: builtin/shortlog.c:14
 msgid "git shortlog [<options>] [<revision-range>] [[--] <path>...]"
 msgstr "git shortlog [<options>] [<intervalle-révisions>] [[--] <chemin>...]"
@@ -14212,18 +20097,18 @@ msgid "Show the email address of each au
 msgstr "Afficher l'adresse courriel de chaque auteur"
 
 #: builtin/shortlog.c:271
-msgid "w[,i1[,i2]]"
-msgstr "w[,i1[,i2]]"
+msgid "<w>[,<i1>[,<i2>]]"
+msgstr "<w>[,<i1>[,<i2>]]"
 
 #: builtin/shortlog.c:272
 msgid "Linewrap output"
 msgstr "Couper les lignes"
 
-#: builtin/shortlog.c:298
+#: builtin/shortlog.c:301
 msgid "too many arguments given outside repository"
 msgstr "trop d'arguments fournis hors d'un dépôt"
 
-#: builtin/show-branch.c:12
+#: builtin/show-branch.c:13
 msgid ""
 "git show-branch [-a | --all] [-r | --remotes] [--topo-order | --date-order]\n"
 "\t\t[--current] [--color[=<when>] | --no-color] [--sparse]\n"
@@ -14235,133 +20120,133 @@ msgstr ""
 "\t\t[--more=<n> | --list | --independent | --merge-base]\n"
 "\t\t[--no-name | --sha1-name] [--topics] [(<rév> | <glob>)...]"
 
-#: builtin/show-branch.c:16
+#: builtin/show-branch.c:17
 msgid "git show-branch (-g | --reflog)[=<n>[,<base>]] [--list] [<ref>]"
 msgstr "git show-branch (-g | --reflog)[=<n>[,<base>]] [--list] [<référence>]"
 
-#: builtin/show-branch.c:376
+#: builtin/show-branch.c:395
 #, c-format
 msgid "ignoring %s; cannot handle more than %d ref"
 msgid_plural "ignoring %s; cannot handle more than %d refs"
 msgstr[0] "%s ignoré; impossible de gérer plus de %d référence"
 msgstr[1] "%s ignoré; impossible de gérer plus de %d références"
 
-#: builtin/show-branch.c:530
+#: builtin/show-branch.c:548
 #, c-format
 msgid "no matching refs with %s"
 msgstr "aucune référence correspond à %s"
 
-#: builtin/show-branch.c:626
+#: builtin/show-branch.c:645
 msgid "show remote-tracking and local branches"
 msgstr "afficher les branches de suivi distantes et les branches locales"
 
-#: builtin/show-branch.c:628
+#: builtin/show-branch.c:647
 msgid "show remote-tracking branches"
 msgstr "afficher les branches de suivi distantes"
 
-#: builtin/show-branch.c:630
+#: builtin/show-branch.c:649
 msgid "color '*!+-' corresponding to the branch"
 msgstr "couleur '*!+-' correspondant à la branche"
 
-#: builtin/show-branch.c:632
+#: builtin/show-branch.c:651
 msgid "show <n> more commits after the common ancestor"
 msgstr "afficher <n> validations de plus après l'ancêtre commun"
 
-#: builtin/show-branch.c:634
+#: builtin/show-branch.c:653
 msgid "synonym to more=-1"
 msgstr "synonyme de more=-1"
 
-#: builtin/show-branch.c:635
+#: builtin/show-branch.c:654
 msgid "suppress naming strings"
 msgstr "supprimer les chaînes de nommage"
 
-#: builtin/show-branch.c:637
+#: builtin/show-branch.c:656
 msgid "include the current branch"
 msgstr "inclure la branche courante"
 
-#: builtin/show-branch.c:639
+#: builtin/show-branch.c:658
 msgid "name commits with their object names"
 msgstr "nommer les validations avec leurs noms d'objet"
 
-#: builtin/show-branch.c:641
+#: builtin/show-branch.c:660
 msgid "show possible merge bases"
 msgstr "afficher les bases possibles de fusion"
 
-#: builtin/show-branch.c:643
+#: builtin/show-branch.c:662
 msgid "show refs unreachable from any other ref"
 msgstr "afficher les références inaccessibles depuis toute autre référence"
 
-#: builtin/show-branch.c:645
+#: builtin/show-branch.c:664
 msgid "show commits in topological order"
 msgstr "afficher les validations dans l'ordre topologique"
 
-#: builtin/show-branch.c:648
+#: builtin/show-branch.c:667
 msgid "show only commits not on the first branch"
 msgstr ""
 "afficher seulement les validations qui ne sont pas sur la première branche"
 
-#: builtin/show-branch.c:650
+#: builtin/show-branch.c:669
 msgid "show merges reachable from only one tip"
 msgstr "afficher les fusions accessibles depuis une seule pointe"
 
-#: builtin/show-branch.c:652
+#: builtin/show-branch.c:671
 msgid "topologically sort, maintaining date order where possible"
 msgstr "tri topologique, maintenant l'ordre par date si possible"
 
-#: builtin/show-branch.c:655
+#: builtin/show-branch.c:674
 msgid "<n>[,<base>]"
 msgstr "<n>[,<base>]"
 
-#: builtin/show-branch.c:656
+#: builtin/show-branch.c:675
 msgid "show <n> most recent ref-log entries starting at base"
 msgstr ""
 "afficher les <n> plus récents éléments de ref-log en commençant à la base"
 
-#: builtin/show-branch.c:690
+#: builtin/show-branch.c:711
 msgid ""
 "--reflog is incompatible with --all, --remotes, --independent or --merge-base"
 msgstr ""
 "--reflog est incompatible avec --all, --remotes, --independant et --merge-"
 "base"
 
-#: builtin/show-branch.c:714
+#: builtin/show-branch.c:735
 msgid "no branches given, and HEAD is not valid"
 msgstr "aucune branche spécifiée, et HEAD est invalide"
 
-#: builtin/show-branch.c:717
+#: builtin/show-branch.c:738
 msgid "--reflog option needs one branch name"
 msgstr "--reflog requiert un nom de branche"
 
-#: builtin/show-branch.c:720
+#: builtin/show-branch.c:741
 #, c-format
 msgid "only %d entry can be shown at one time."
 msgid_plural "only %d entries can be shown at one time."
 msgstr[0] "%d entrée seulement ne peut être montrée en même temps."
 msgstr[1] "%d entrées seulement ne peuvent être montrée en même temps."
 
-#: builtin/show-branch.c:724
+#: builtin/show-branch.c:745
 #, c-format
 msgid "no such ref %s"
 msgstr "référence inexistante %s"
 
-#: builtin/show-branch.c:808
+#: builtin/show-branch.c:831
 #, c-format
 msgid "cannot handle more than %d rev."
 msgid_plural "cannot handle more than %d revs."
 msgstr[0] "impossible de gérer plus de %d révision."
 msgstr[1] "impossible de gérer plus de %d révisions."
 
-#: builtin/show-branch.c:812
+#: builtin/show-branch.c:835
 #, c-format
 msgid "'%s' is not a valid ref."
 msgstr "'%s' n'est pas une référence valide."
 
-#: builtin/show-branch.c:815
+#: builtin/show-branch.c:838
 #, c-format
 msgid "cannot find commit %s (%s)"
 msgstr "impossible de trouver le commit %s (%s)"
 
-#: builtin/show-ref.c:10
+#: builtin/show-ref.c:12
 msgid ""
 "git show-ref [-q | --quiet] [--verify] [--head] [-d | --dereference] [-s | --"
 "hash[=<n>]] [--abbrev[=<n>]] [--tags] [--heads] [--] [<pattern>...]"
@@ -14369,47 +20254,324 @@ msgstr ""
 "git show-ref [-q | --quiet] [--verify] [--head] [-d | --dereference] [-s | --"
 "hash[=<n>]] [--abbrev[=<n>]] [--tags] [--heads] [--] [<motif>...]"
 
-#: builtin/show-ref.c:11
+#: builtin/show-ref.c:13
 msgid "git show-ref --exclude-existing[=<pattern>]"
 msgstr "git show-ref --exclude-existing[=<motif>]"
 
-#: builtin/show-ref.c:159
+#: builtin/show-ref.c:162
 msgid "only show tags (can be combined with heads)"
 msgstr "afficher seulement les étiquettes (peut être combiné avec heads)"
 
-#: builtin/show-ref.c:160
+#: builtin/show-ref.c:163
 msgid "only show heads (can be combined with tags)"
 msgstr "afficher seulement les têtes (peut être combiné avec tags)"
 
-#: builtin/show-ref.c:161
+#: builtin/show-ref.c:164
 msgid "stricter reference checking, requires exact ref path"
 msgstr ""
 "vérification de référence plus stricte, nécessite un chemin de référence "
 "exact"
 
-#: builtin/show-ref.c:164 builtin/show-ref.c:166
+#: builtin/show-ref.c:167 builtin/show-ref.c:169
 msgid "show the HEAD reference, even if it would be filtered out"
 msgstr "afficher la référence HEAD, même si elle serait filtrée"
 
-#: builtin/show-ref.c:168
+#: builtin/show-ref.c:171
 msgid "dereference tags into object IDs"
 msgstr "déréférencer les étiquettes en IDs d'objet"
 
-#: builtin/show-ref.c:170
+#: builtin/show-ref.c:173
 msgid "only show SHA1 hash using <n> digits"
 msgstr "afficher seulement le hachage SHA1 en utilisant <n> chiffres"
 
-#: builtin/show-ref.c:174
+#: builtin/show-ref.c:177
 msgid "do not print results to stdout (useful with --verify)"
 msgstr ""
 "ne pas afficher les résultats sur la sortie standard (pratique avec --verify)"
 
-#: builtin/show-ref.c:176
+#: builtin/show-ref.c:179
 msgid "show refs from stdin that aren't in local repository"
 msgstr ""
 "afficher les références de l'entrée standard qui ne sont pas dans le dépôt "
 "local"
 
+#: builtin/sparse-checkout.c:20
+msgid "git sparse-checkout (init|list|set|disable) <options>"
+msgstr "git sparse-checkout (init|list|set|disable) <options>"
+
+#: builtin/sparse-checkout.c:61
+msgid "this worktree is not sparse (sparse-checkout file may not exist)"
+msgstr "cet arbre de travail n'est pas partiel (le fichier sparse-checkout pourrait ne pas exister)"
+
+#: builtin/sparse-checkout.c:220
+msgid "failed to set extensions.worktreeConfig setting"
+msgstr "échec de paramétrage extensions.worktreeConfig"
+
+#: builtin/sparse-checkout.c:237
+msgid "git sparse-checkout init [--cone]"
+msgstr "git sparse-checkout init [--cone]"
+
+#: builtin/sparse-checkout.c:256
+msgid "initialize the sparse-checkout in cone mode"
+msgstr "initialiser l'extraction partielle en mode cone"
+
+#: builtin/sparse-checkout.c:262
+msgid "initialize sparse-checkout"
+msgstr "initialiser l'extraction partielle"
+
+#: builtin/sparse-checkout.c:295
+#, c-format
+msgid "failed to open '%s'"
+msgstr "échec à l'ouverture de '%s'"
+
+#: builtin/sparse-checkout.c:361
+msgid "git sparse-checkout set (--stdin | <patterns>)"
+msgstr "git sparse-checkout set (--stdin | <motifs>)"
+
+#: builtin/sparse-checkout.c:378
+msgid "read patterns from standard in"
+msgstr "lire les motifs depuis l'entrée standard"
+
+#: builtin/sparse-checkout.c:384
+msgid "set sparse-checkout patterns"
+msgstr "indiquer les motifs de l'extraction partielle"
+
+#: builtin/sparse-checkout.c:447
+msgid "disable sparse-checkout"
+msgstr "désactiver d'extraction partielle"
+
+#: builtin/sparse-checkout.c:459
+msgid "error while refreshing working directory"
+msgstr "erreur lors du rafraîchissement du répertoire de travail"
+
+#: builtin/stash.c:22 builtin/stash.c:37
+msgid "git stash list [<options>]"
+msgstr "git stash list [<options>]"
+
+#: builtin/stash.c:23 builtin/stash.c:42
+msgid "git stash show [<options>] [<stash>]"
+msgstr "git stash show [<options>] [<remise>]"
+
+#: builtin/stash.c:24 builtin/stash.c:47
+msgid "git stash drop [-q|--quiet] [<stash>]"
+msgstr "git stash drop [-q|--quiet] [<remise>]"
+
+#: builtin/stash.c:25
+msgid "git stash ( pop | apply ) [--index] [-q|--quiet] [<stash>]"
+msgstr "git stash ( pop | apply ) [--index] [-q|--quiet] [<remise>]"
+
+#: builtin/stash.c:26 builtin/stash.c:62
+msgid "git stash branch <branchname> [<stash>]"
+msgstr "git stash branch <nom-de-branche> [<remise>]"
+
+#: builtin/stash.c:27 builtin/stash.c:67
+msgid "git stash clear"
+msgstr "git stash clear"
+
+#: builtin/stash.c:28 builtin/stash.c:77
+msgid ""
+"git stash [push [-p|--patch] [-k|--[no-]keep-index] [-q|--quiet]\n"
+"          [-u|--include-untracked] [-a|--all] [-m|--message <message>]\n"
+"          [--] [<pathspec>...]]"
+msgstr ""
+"git stash [push [-p|--patch] [-k|--[no-]keep-index] [-q|--quiet]\n"
+"          [-u|--include-untracked] [-a|--all] [-m|--message <message>]\n"
+"          [--] [<spécificateur-de-chemin>...]]"
+
+#: builtin/stash.c:31 builtin/stash.c:84
+msgid ""
+"git stash save [-p|--patch] [-k|--[no-]keep-index] [-q|--quiet]\n"
+"          [-u|--include-untracked] [-a|--all] [<message>]"
+msgstr ""
+"git stash save [-p|--patch] [-k|--[no-]keep-index] [-q|--quiet]\n"
+"          [-u|--include-untracked] [-a|--all] [<message>]"
+
+#: builtin/stash.c:52
+msgid "git stash pop [--index] [-q|--quiet] [<stash>]"
+msgstr "git stash pop [--index] [-q|--quiet] [<remise>]"
+
+#: builtin/stash.c:57
+msgid "git stash apply [--index] [-q|--quiet] [<stash>]"
+msgstr "git stash apply [--index] [-q|--quiet] [<remise>]"
+
+#: builtin/stash.c:72
+msgid "git stash store [-m|--message <message>] [-q|--quiet] <commit>"
+msgstr "git stash store [-m|--message <message>] [-q|--quiet] <remise>"
+
+#: builtin/stash.c:127
+#, c-format
+msgid "'%s' is not a stash-like commit"
+msgstr "'%s' n'est pas une validation de type remisage"
+
+#: builtin/stash.c:147
+#, c-format
+msgid "Too many revisions specified:%s"
+msgstr "Trop de révisions spécifiées : %s"
+
+#: builtin/stash.c:161 git-legacy-stash.sh:549
+msgid "No stash entries found."
+msgstr "Aucune entrée de remisage trouvée."
+
+#: builtin/stash.c:175
+#, c-format
+msgid "%s is not a valid reference"
+msgstr "%s n'est pas une référence valide"
+
+#: builtin/stash.c:224 git-legacy-stash.sh:75
+msgid "git stash clear with parameters is unimplemented"
+msgstr "git stash clear avec des paramètres n'est pas implémenté"
+
+#: builtin/stash.c:403
+msgid "cannot apply a stash in the middle of a merge"
+msgstr "impossible d'appliquer un remisage en cours de fusion"
+
+#: builtin/stash.c:414
+#, c-format
+msgid "could not generate diff %s^!."
+msgstr "impossible de générer %s^!."
+
+#: builtin/stash.c:421
+msgid "conflicts in index.Try without --index."
+msgstr "conflits dans l'index. Essayez sans --index."
+
+#: builtin/stash.c:427
+msgid "could not save index tree"
+msgstr "impossible de sauvegarder l'arbre d'index"
+
+#: builtin/stash.c:436
+msgid "could not restore untracked files from stash"
+msgstr "impossible de restaurer les fichiers non-suivis depuis le remisage"
+
+#: builtin/stash.c:450
+#, c-format
+msgid "Merging %s with %s"
+msgstr "Fusion de %s avec %s"
+
+#: builtin/stash.c:460 git-legacy-stash.sh:681
+msgid "Index was not unstashed."
+msgstr "L'index n'a pas été sorti de remise."
+
+#: builtin/stash.c:521 builtin/stash.c:620
+msgid "attempt to recreate the index"
+msgstr "tentative de recréer l'index"
+
+#: builtin/stash.c:554
+#, c-format
+msgid "Dropped %s (%s)"
+msgstr "%s supprimé (%s)"
+
+#: builtin/stash.c:557
+#, c-format
+msgid "%s: Could not drop stash entry"
+msgstr "%s : Impossible de supprimer l'élément de stash"
+
+#: builtin/stash.c:582
+#, c-format
+msgid "'%s' is not a stash reference"
+msgstr "'%s' n'est pas une référence de remisage"
+
+#: builtin/stash.c:632 git-legacy-stash.sh:695
+msgid "The stash entry is kept in case you need it again."
+msgstr ""
+"L'entrée de remisage est conservée au cas où vous en auriez encore besoin."
+
+#: builtin/stash.c:655 git-legacy-stash.sh:713
+msgid "No branch name specified"
+msgstr "Aucune branche spécifiée"
+
+#: builtin/stash.c:795 builtin/stash.c:832
+#, c-format
+msgid "Cannot update %s with %s"
+msgstr "Impossible de mettre à jour %s avec %s"
+
+#: builtin/stash.c:813 builtin/stash.c:1470 builtin/stash.c:1506
+msgid "stash message"
+msgstr "message pour le remisage"
+
+#: builtin/stash.c:823
+msgid "\"git stash store\" requires one <commit> argument"
+msgstr "\"git stash store\" exige un argument <commit>"
+
+#: builtin/stash.c:1045 git-legacy-stash.sh:218
+msgid "No changes selected"
+msgstr "Aucun changement sélectionné"
+
+#: builtin/stash.c:1145 git-legacy-stash.sh:150
+msgid "You do not have the initial commit yet"
+msgstr "Vous n'avez pas encore la validation initiale"
+
+#: builtin/stash.c:1172 git-legacy-stash.sh:165
+msgid "Cannot save the current index state"
+msgstr "Impossible de sauver l'état courant de l'index"
+
+#: builtin/stash.c:1181 git-legacy-stash.sh:180
+msgid "Cannot save the untracked files"
+msgstr "Impossible de sauver les fichiers non-suivis"
+
+#: builtin/stash.c:1192 builtin/stash.c:1201 git-legacy-stash.sh:201
+#: git-legacy-stash.sh:214
+msgid "Cannot save the current worktree state"
+msgstr "Impossible de sauver l'état courant de la copie de travail"
+
+#: builtin/stash.c:1229 git-legacy-stash.sh:234
+msgid "Cannot record working tree state"
+msgstr "Impossible d'enregistrer l'état de la copie de travail"
+
+#: builtin/stash.c:1278 git-legacy-stash.sh:338
+msgid "Can't use --patch and --include-untracked or --all at the same time"
+msgstr ""
+"Impossible d'utiliser --patch et --include-untracked ou --all en même temps"
+
+#: builtin/stash.c:1294
+msgid "Did you forget to 'git add'?"
+msgstr "Vous avez sûrement oublié 'git add' ?"
+
+#: builtin/stash.c:1309 git-legacy-stash.sh:346
+msgid "No local changes to save"
+msgstr "Pas de modifications locales à sauver"
+
+#: builtin/stash.c:1316 git-legacy-stash.sh:351
+msgid "Cannot initialize stash"
+msgstr "Impossible d'initialiser le remisage"
+
+#: builtin/stash.c:1331 git-legacy-stash.sh:355
+msgid "Cannot save the current status"
+msgstr "Impossible de sauver l'état courant"
+
+#: builtin/stash.c:1336
+#, c-format
+msgid "Saved working directory and index state %s"
+msgstr "Arbre de travail et état de l'index sauvegardés dans %s"
+
+#: builtin/stash.c:1426 git-legacy-stash.sh:385
+msgid "Cannot remove worktree changes"
+msgstr "Impossible de supprimer les changements de la copie de travail"
+
+#: builtin/stash.c:1461 builtin/stash.c:1497
+msgid "keep index"
+msgstr "conserver l'index"
+
+#: builtin/stash.c:1463 builtin/stash.c:1499
+msgid "stash in patch mode"
+msgstr "remiser une mode rustine"
+
+#: builtin/stash.c:1464 builtin/stash.c:1500
+msgid "quiet mode"
+msgstr "mode silencieux"
+
+#: builtin/stash.c:1466 builtin/stash.c:1502
+msgid "include untracked files in stash"
+msgstr "inclure les fichiers non suivis dans la remise"
+
+#: builtin/stash.c:1468 builtin/stash.c:1504
+msgid "include ignore files"
+msgstr "inclure les fichiers ignorés"
+
+#: builtin/stash.c:1564
+#, c-format
+msgid "could not exec %s"
+msgstr "impossible d'exécuter %s"
+
 #: builtin/stripspace.c:18
 msgid "git stripspace [-s | --strip-comments]"
 msgstr "git stripspace [-s | --strip-comments]"
@@ -14418,111 +20580,145 @@ msgstr "git stripspace [-s | --strip-com
 msgid "git stripspace [-c | --comment-lines]"
 msgstr "git stripspace [-c | --comment-lines]"
 
-#: builtin/stripspace.c:36
+#: builtin/stripspace.c:37
 msgid "skip and remove all lines starting with comment character"
 msgstr ""
 "sauter et supprimer toutes les lignes commençant par le caractère de "
 "commentaire"
 
-#: builtin/stripspace.c:39
+#: builtin/stripspace.c:40
 msgid "prepend comment character and space to each line"
 msgstr "ajouter devant chaque ligne le caractère de commentaire et un espace"
 
-#: builtin/submodule--helper.c:37 builtin/submodule--helper.c:1688
-#, c-format
-msgid "No such ref: %s"
-msgstr "Référence inexistante : %s"
-
-#: builtin/submodule--helper.c:44 builtin/submodule--helper.c:1697
+#: builtin/submodule--helper.c:47 builtin/submodule--helper.c:1970
 #, c-format
 msgid "Expecting a full ref name, got %s"
 msgstr "Nom de référence complet attendu, %s obtenu"
 
-#: builtin/submodule--helper.c:61
+#: builtin/submodule--helper.c:64
 msgid "submodule--helper print-default-remote takes no arguments"
 msgstr "submodule--helper  print-default-remote n'accepte aucun argument"
 
-#: builtin/submodule--helper.c:98
+#: builtin/submodule--helper.c:102
 #, c-format
 msgid "cannot strip one component off url '%s'"
 msgstr "impossible de supprimer un composant de l'URL '%s'"
 
-#: builtin/submodule--helper.c:406 builtin/submodule--helper.c:1211
+#: builtin/submodule--helper.c:410 builtin/submodule--helper.c:1380
 msgid "alternative anchor for relative paths"
 msgstr "ancre alternative pour les chemins relatifs"
 
-#: builtin/submodule--helper.c:411
+#: builtin/submodule--helper.c:415
 msgid "git submodule--helper list [--prefix=<path>] [<path>...]"
 msgstr "git submodule--helper list [--prefix=<chemin>] [<chemin>...]"
 
-#: builtin/submodule--helper.c:462 builtin/submodule--helper.c:485
+#: builtin/submodule--helper.c:472 builtin/submodule--helper.c:630
+#: builtin/submodule--helper.c:653
 #, c-format
 msgid "No url found for submodule path '%s' in .gitmodules"
 msgstr "URL non trouvée pour le chemin de sous-module '%s' dans .gitmodules"
 
-#: builtin/submodule--helper.c:500
+#: builtin/submodule--helper.c:524
+#, c-format
+msgid "Entering '%s'\n"
+msgstr "Entrée dans '%s'\n"
+
+#: builtin/submodule--helper.c:527
+#, c-format
+msgid ""
+"run_command returned non-zero status for %s\n"
+"."
+msgstr ""
+"run_command a retourné un statut non-nul pour %s\n"
+"."
+
+#: builtin/submodule--helper.c:549
+#, c-format
+msgid ""
+"run_command returned non-zero status while recursing in the nested "
+"submodules of %s\n"
+"."
+msgstr ""
+"run_command a retourné un statut non-nul pendant la récursion dans les sous-"
+"modules inclus de %s\n"
+"."
+
+#: builtin/submodule--helper.c:565
+msgid "Suppress output of entering each submodule command"
+msgstr ""
+"Supprimer la sortie lors de l'entrée dans chaque commande de sous-module"
+
+#: builtin/submodule--helper.c:567 builtin/submodule--helper.c:1053
+msgid "Recurse into nested submodules"
+msgstr "Parcourir récursivement les sous-modules"
+
+#: builtin/submodule--helper.c:572
+msgid "git submodule--helper foreach [--quiet] [--recursive] [--] <command>"
+msgstr "git submodule--helper foreach [--quiet] [--recursive] [--] <commande>"
+
+#: builtin/submodule--helper.c:599
 #, c-format
 msgid ""
-"could not lookup configuration '%s'. Assuming this repository is its own "
+"could not look up configuration '%s'. Assuming this repository is its own "
 "authoritative upstream."
 msgstr ""
 "impossible de trouver la configuration '%s'. Ce dépôt est considéré comme "
 "son propre amont d'autorité."
 
-#: builtin/submodule--helper.c:511
+#: builtin/submodule--helper.c:667
 #, c-format
 msgid "Failed to register url for submodule path '%s'"
 msgstr "Échec d'enregistrement de l'URL pour le chemin de sous-module '%s'"
 
-#: builtin/submodule--helper.c:515
+#: builtin/submodule--helper.c:671
 #, c-format
 msgid "Submodule '%s' (%s) registered for path '%s'\n"
 msgstr "Sous-module '%s' (%s) enregistré pour le chemin '%s'\n"
 
-#: builtin/submodule--helper.c:525
+#: builtin/submodule--helper.c:681
 #, c-format
 msgid "warning: command update mode suggested for submodule '%s'\n"
 msgstr ""
 "attention : nous vous suggérons de spécifier une commande de mode de mise à "
 "jour pour le sous-module '%s'\n"
 
-#: builtin/submodule--helper.c:532
+#: builtin/submodule--helper.c:688
 #, c-format
 msgid "Failed to register update mode for submodule path '%s'"
 msgstr ""
 "Échec d'enregistrement du mode de mise à jour pour le chemin de sous-module "
 "'%s'"
 
-#: builtin/submodule--helper.c:554
+#: builtin/submodule--helper.c:710
 msgid "Suppress output for initializing a submodule"
 msgstr "Supprimer la sortie lors de l'initialisation d'un sous-module"
 
-#: builtin/submodule--helper.c:559
-msgid "git submodule--helper init [<path>]"
-msgstr "git submodule--helper init [<chemin>]"
+#: builtin/submodule--helper.c:715
+msgid "git submodule--helper init [<options>] [<path>]"
+msgstr "git submodule--helper init [<options>] [<chemin>]"
 
-#: builtin/submodule--helper.c:631 builtin/submodule--helper.c:757
+#: builtin/submodule--helper.c:787 builtin/submodule--helper.c:914
 #, c-format
 msgid "no submodule mapping found in .gitmodules for path '%s'"
 msgstr ""
 "Pas de mise en correspondance du sous-module trouvé dans .gitmodules pour le "
 "chemin '%s'"
 
-#: builtin/submodule--helper.c:670
+#: builtin/submodule--helper.c:827
 #, c-format
 msgid "could not resolve HEAD ref inside the submodule '%s'"
 msgstr "impossible de résoudre HEAD dans le sous-module '%s'"
 
-#: builtin/submodule--helper.c:697 builtin/submodule--helper.c:866
+#: builtin/submodule--helper.c:854 builtin/submodule--helper.c:1023
 #, c-format
 msgid "failed to recurse into submodule '%s'"
 msgstr "récursion impossible dans le sous-module '%s'"
 
-#: builtin/submodule--helper.c:721 builtin/submodule--helper.c:1031
+#: builtin/submodule--helper.c:878 builtin/submodule--helper.c:1189
 msgid "Suppress submodule status output"
 msgstr "supprimer la sortie d'état du sous-module"
 
-#: builtin/submodule--helper.c:722
+#: builtin/submodule--helper.c:879
 msgid ""
 "Use commit stored in the index instead of the one stored in the submodule "
 "HEAD"
@@ -14530,52 +20726,48 @@ msgstr ""
 "Utiliser le commit stocké dans l'index au lieu de celui stocké dans la HEAD "
 "du sous-module"
 
-#: builtin/submodule--helper.c:723
+#: builtin/submodule--helper.c:880
 msgid "recurse into nested submodules"
 msgstr "parcourir récursivement les sous-modules"
 
-#: builtin/submodule--helper.c:728
+#: builtin/submodule--helper.c:885
 msgid "git submodule status [--quiet] [--cached] [--recursive] [<path>...]"
 msgstr "git submodule status [--quiet] [--cached] [--recursive] [<chemin>...]"
 
-#: builtin/submodule--helper.c:752
+#: builtin/submodule--helper.c:909
 msgid "git submodule--helper name <path>"
 msgstr "git submodule--helper <nom> <chemin>"
 
-#: builtin/submodule--helper.c:816
+#: builtin/submodule--helper.c:973
 #, c-format
 msgid "Synchronizing submodule url for '%s'\n"
 msgstr "Synchronisation de l'URL sous-module pour '%s'\n"
 
-#: builtin/submodule--helper.c:822
+#: builtin/submodule--helper.c:979
 #, c-format
 msgid "failed to register url for submodule path '%s'"
 msgstr "échec d'enregistrement de l'URL pour le chemin de sous-module '%s'"
 
-#: builtin/submodule--helper.c:836
+#: builtin/submodule--helper.c:993
 #, c-format
 msgid "failed to get the default remote for submodule '%s'"
 msgstr "échec d'obtention du dépôt distant par défaut pour le sous-module '%s'"
 
-#: builtin/submodule--helper.c:847
+#: builtin/submodule--helper.c:1004
 #, c-format
 msgid "failed to update remote for submodule '%s'"
 msgstr "échec de mise à jour du dépôt distant pour le sous-module '%s'"
 
-#: builtin/submodule--helper.c:895
+#: builtin/submodule--helper.c:1051
 msgid "Suppress output of synchronizing submodule url"
 msgstr ""
 "Supprimer la sortie lors de la synchronisation de l'URL d'un sous-module"
 
-#: builtin/submodule--helper.c:897
-msgid "Recurse into nested submodules"
-msgstr "Parcourir récursivement les sous-modules"
-
-#: builtin/submodule--helper.c:902
+#: builtin/submodule--helper.c:1058
 msgid "git submodule--helper sync [--quiet] [--recursive] [<path>]"
 msgstr "git submodule--helper sync [--quiet] [--recursive] [<chemin>]"
 
-#: builtin/submodule--helper.c:956
+#: builtin/submodule--helper.c:1112
 #, c-format
 msgid ""
 "Submodule work tree '%s' contains a .git directory (use 'rm -rf' if you "
@@ -14585,7 +20777,7 @@ msgstr ""
 "'rm -rf' si vous voulez vraiment le supprimer en incluant tout son "
 "historique)"
 
-#: builtin/submodule--helper.c:968
+#: builtin/submodule--helper.c:1124
 #, c-format
 msgid ""
 "Submodule work tree '%s' contains local modifications; use '-f' to discard "
@@ -14594,84 +20786,100 @@ msgstr ""
 "L'arbre de travail du sous-module '%s' contient des modifications locales ; "
 "utilisez '-f' pour les annuler"
 
-#: builtin/submodule--helper.c:976
+#: builtin/submodule--helper.c:1132
 #, c-format
 msgid "Cleared directory '%s'\n"
 msgstr "Répertoire '%s' nettoyé\n"
 
-#: builtin/submodule--helper.c:978
+#: builtin/submodule--helper.c:1134
 #, c-format
 msgid "Could not remove submodule work tree '%s'\n"
 msgstr "Impossible de supprimer l'arbre de travail du sous-module '%s'\n"
 
-#: builtin/submodule--helper.c:987
+#: builtin/submodule--helper.c:1145
 #, c-format
 msgid "could not create empty submodule directory %s"
 msgstr "impossible de créer le répertoire vide du sous-module %s"
 
-#: builtin/submodule--helper.c:1003
+#: builtin/submodule--helper.c:1161
 #, c-format
 msgid "Submodule '%s' (%s) unregistered for path '%s'\n"
 msgstr "Sous-module '%s' (%s) non enregistré pour le chemin '%s'\n"
 
-#: builtin/submodule--helper.c:1032
+#: builtin/submodule--helper.c:1190
 msgid "Remove submodule working trees even if they contain local changes"
 msgstr ""
 "Éliminer les arbres de travail des sous-modules même s'ils contiennent des "
 "modifications locales"
 
-#: builtin/submodule--helper.c:1033
+#: builtin/submodule--helper.c:1191
 msgid "Unregister all submodules"
 msgstr "Désenregistrer tous les sous-modules"
 
-#: builtin/submodule--helper.c:1038
+#: builtin/submodule--helper.c:1196
 msgid ""
 "git submodule deinit [--quiet] [-f | --force] [--all | [--] [<path>...]]"
 msgstr ""
 "git submodule deinit [--quiet] [-f | --force] [--all | [--] [<chemin>...]]"
 
-#: builtin/submodule--helper.c:1052
+#: builtin/submodule--helper.c:1210
 msgid "Use '--all' if you really want to deinitialize all submodules"
 msgstr ""
 "Utilisez '--all' si vous voulez vraiment réinitialiser tous les sous-modules"
 
-#: builtin/submodule--helper.c:1145 builtin/submodule--helper.c:1148
+#: builtin/submodule--helper.c:1275
+msgid ""
+"An alternate computed from a superproject's alternate is invalid.\n"
+"To allow Git to clone without an alternate in such a case, set\n"
+"submodule.alternateErrorStrategy to 'info' or, equivalently, clone with\n"
+"'--reference-if-able' instead of '--reference'."
+msgstr ""
+"Une alternative calculée depuis l'alternative du super-projet est invalide.\n"
+"Pour permettre à Git de cloner sans alternative dans un tel cas, réglez\n"
+"submodule.alternateErrorStrategy à 'info', ou de manière équivalente,\n"
+"clonez avec '--reference-if-able' au lieu de '--reference'."
+
+#: builtin/submodule--helper.c:1314 builtin/submodule--helper.c:1317
 #, c-format
 msgid "submodule '%s' cannot add alternate: %s"
 msgstr "le sous-module '%s' ne peut pas ajouter d'alternative : %s"
 
-#: builtin/submodule--helper.c:1184
+#: builtin/submodule--helper.c:1353
 #, c-format
 msgid "Value '%s' for submodule.alternateErrorStrategy is not recognized"
 msgstr ""
 "La valeur '%s' pour submodule.alternateErrorStrategy n'est pas reconnue"
 
-#: builtin/submodule--helper.c:1191
+#: builtin/submodule--helper.c:1360
 #, c-format
 msgid "Value '%s' for submodule.alternateLocation is not recognized"
 msgstr "La valeur '%s' pour submodule.alternateLocation n'est pas reconnue"
 
-#: builtin/submodule--helper.c:1214
+#: builtin/submodule--helper.c:1383
 msgid "where the new submodule will be cloned to"
 msgstr "emplacement où le sous-module sera cloné"
 
-#: builtin/submodule--helper.c:1217
+#: builtin/submodule--helper.c:1386
 msgid "name of the new submodule"
 msgstr "nom du nouveau sous-module"
 
-#: builtin/submodule--helper.c:1220
+#: builtin/submodule--helper.c:1389
 msgid "url where to clone the submodule from"
 msgstr "URL depuis laquelle cloner le sous-module"
 
-#: builtin/submodule--helper.c:1228
+#: builtin/submodule--helper.c:1397
 msgid "depth for shallow clones"
 msgstr "profondeur de l'historique des clones superficiels"
 
-#: builtin/submodule--helper.c:1231 builtin/submodule--helper.c:1606
+#: builtin/submodule--helper.c:1400 builtin/submodule--helper.c:1897
 msgid "force cloning progress"
 msgstr "forcer l'affichage de la progression du clonage"
 
-#: builtin/submodule--helper.c:1236
+#: builtin/submodule--helper.c:1402 builtin/submodule--helper.c:1899
+msgid "disallow cloning into non-empty directory"
+msgstr "interdire de cloner dans un répertoire non-vide"
+
+#: builtin/submodule--helper.c:1407
 msgid ""
 "git submodule--helper clone [--prefix=<path>] [--quiet] [--reference "
 "<repository>] [--name <name>] [--depth <depth>] --url <url> --path <path>"
@@ -14679,83 +20887,104 @@ msgstr ""
 "git submodule--helper clone [--prefix=<chemin>] [--quiet] [--reference "
 "<dépôt>] [--name <nom>] [--depth <profondeur>]  --url <url> --path <chemin>"
 
-#: builtin/submodule--helper.c:1267
+#: builtin/submodule--helper.c:1431
+#, c-format
+msgid "refusing to create/use '%s' in another submodule's git dir"
+msgstr "refus de créer/utiliser '%s' dans un répertoire git d'un autre sous-module"
+
+#: builtin/submodule--helper.c:1442
 #, c-format
 msgid "clone of '%s' into submodule path '%s' failed"
 msgstr "Le clonage de '%s' dans le chemin de sous-module '%s' a échoué"
 
-#: builtin/submodule--helper.c:1281
+#: builtin/submodule--helper.c:1446
+#, c-format
+msgid "directory not empty: '%s'"
+msgstr "le répertoire n'est pas vide : '%s'"
+
+#: builtin/submodule--helper.c:1458
 #, c-format
 msgid "could not get submodule directory for '%s'"
 msgstr "impossible de créer le répertoire de sous-module pour '%s'"
 
-#: builtin/submodule--helper.c:1347
+#: builtin/submodule--helper.c:1494
+#, c-format
+msgid "Invalid update mode '%s' for submodule path '%s'"
+msgstr "mode de mise à jour '%s' invalide pour le chemin de sous-module '%s'"
+
+#: builtin/submodule--helper.c:1498
+#, c-format
+msgid "Invalid update mode '%s' configured for submodule path '%s'"
+msgstr ""
+"Mode de mise à jour '%s'invalide configuré pour le chemin de sous-module '%s'"
+
+#: builtin/submodule--helper.c:1594
 #, c-format
 msgid "Submodule path '%s' not initialized"
 msgstr "Le chemin de sous-module '%s' n'est pas initialisé"
 
-#: builtin/submodule--helper.c:1351
+#: builtin/submodule--helper.c:1598
 msgid "Maybe you want to use 'update --init'?"
 msgstr "Vous voudriez sûrement utiliser 'update --init' ?"
 
-#: builtin/submodule--helper.c:1380
+#: builtin/submodule--helper.c:1628
 #, c-format
 msgid "Skipping unmerged submodule %s"
 msgstr "Sous-module non fusionné %s non traité"
 
-#: builtin/submodule--helper.c:1409
+#: builtin/submodule--helper.c:1657
 #, c-format
 msgid "Skipping submodule '%s'"
 msgstr "Sous-module '%s' non traité"
 
-#: builtin/submodule--helper.c:1544
+#: builtin/submodule--helper.c:1803
 #, c-format
 msgid "Failed to clone '%s'. Retry scheduled"
 msgstr "Impossible de cloner '%s'. Réessai prévu"
 
-#: builtin/submodule--helper.c:1555
+#: builtin/submodule--helper.c:1814
 #, c-format
 msgid "Failed to clone '%s' a second time, aborting"
 msgstr "Impossible de cloner '%s' pour la seconde fois, abandon"
 
-#: builtin/submodule--helper.c:1585 builtin/submodule--helper.c:1808
+#: builtin/submodule--helper.c:1876 builtin/submodule--helper.c:2120
 msgid "path into the working tree"
 msgstr "chemin dans la copie de travail"
 
-#: builtin/submodule--helper.c:1588
+#: builtin/submodule--helper.c:1879
 msgid "path into the working tree, across nested submodule boundaries"
 msgstr ""
 "chemin dans la copie de travail, traversant les frontières de sous-modules"
 
-#: builtin/submodule--helper.c:1592
+#: builtin/submodule--helper.c:1883
 msgid "rebase, merge, checkout or none"
 msgstr "valeurs possibles : rebase, merge, checkout ou none"
 
-#: builtin/submodule--helper.c:1598
+#: builtin/submodule--helper.c:1889
 msgid "Create a shallow clone truncated to the specified number of revisions"
 msgstr "Créer un clone superficiel tronqué au nombre de révisions spécifié"
 
-#: builtin/submodule--helper.c:1601
+#: builtin/submodule--helper.c:1892
 msgid "parallel jobs"
 msgstr "jobs parallèles"
 
-#: builtin/submodule--helper.c:1603
+#: builtin/submodule--helper.c:1894
 msgid "whether the initial clone should follow the shallow recommendation"
 msgstr "spécifie si le clonage initial doit être aussi superficiel"
 
-#: builtin/submodule--helper.c:1604
+#: builtin/submodule--helper.c:1895
 msgid "don't print cloning progress"
 msgstr "ne pas afficher la progression du clonage"
 
-#: builtin/submodule--helper.c:1611
-msgid "git submodule--helper update_clone [--prefix=<path>] [<path>...]"
-msgstr "git submodule--helper update_clone [--prefix=<chemin>] [<chemin>...]"
+#: builtin/submodule--helper.c:1904
+msgid "git submodule--helper update-clone [--prefix=<path>] [<path>...]"
+msgstr "git submodule--helper update-clone [--prefix=<chemin>] [<chemin>...]"
 
-#: builtin/submodule--helper.c:1624
+#: builtin/submodule--helper.c:1917
 msgid "bad value for update parameter"
 msgstr "valeur invalide pour la mise à jour du paramètre"
 
-#: builtin/submodule--helper.c:1692
+#: builtin/submodule--helper.c:1965
 #, c-format
 msgid ""
 "Submodule (%s) branch configured to inherit branch from superproject, but "
@@ -14764,20 +20993,51 @@ msgstr ""
 "la branche du sous-module %s est configurée pour hériter de la branche du "
 "superprojet, mais le superprojet n'est sur aucune branche"
 
-#: builtin/submodule--helper.c:1809
+#: builtin/submodule--helper.c:2088
+#, c-format
+msgid "could not get a repository handle for submodule '%s'"
+msgstr "impossible de trouver une poignée de dépôt pour le sous-module '%s'"
+
+#: builtin/submodule--helper.c:2121
 msgid "recurse into submodules"
 msgstr "parcourir récursivement les sous-modules"
 
-#: builtin/submodule--helper.c:1815
-msgid "git submodule--helper embed-git-dir [<path>...]"
-msgstr "git submodule--helper embed-git-dir [<chemin>...]"
+#: builtin/submodule--helper.c:2127
+msgid "git submodule--helper absorb-git-dirs [<options>] [<path>...]"
+msgstr "git submodule--helper embed-git-dir [<options>] [<chemin>...]"
+
+#: builtin/submodule--helper.c:2183
+msgid "check if it is safe to write to the .gitmodules file"
+msgstr "vérifier si écrire dans le fichier .gitmodules est sur"
+
+#: builtin/submodule--helper.c:2186
+msgid "unset the config in the .gitmodules file"
+msgstr "désactiver la configuration dans le fichier .gitmodules"
+
+#: builtin/submodule--helper.c:2191
+msgid "git submodule--helper config <name> [<value>]"
+msgstr "git submodule--helper config name [<valeur>]"
+
+#: builtin/submodule--helper.c:2192
+msgid "git submodule--helper config --unset <name>"
+msgstr "git submodule--helper config --unset <nom>"
+
+#: builtin/submodule--helper.c:2193
+msgid "git submodule--helper config --check-writeable"
+msgstr "git submodule--helper config --check-writeable"
+
+#: builtin/submodule--helper.c:2212 git-submodule.sh:173
+#, sh-format
+msgid "please make sure that the .gitmodules file is in the working tree"
+msgstr ""
+"veuillez vous assurer que le fichier .gitmodules est dans l'arbre de travail"
 
-#: builtin/submodule--helper.c:1901
+#: builtin/submodule--helper.c:2262 git.c:433 git.c:684
 #, c-format
 msgid "%s doesn't support --super-prefix"
 msgstr "%s ne gère pas --super-prefix"
 
-#: builtin/submodule--helper.c:1907
+#: builtin/submodule--helper.c:2268
 #, c-format
 msgid "'%s' is not a valid submodule--helper subcommand"
 msgstr "'%s' n'est pas une sous-commande valide de submodule--helper"
@@ -14803,27 +21063,27 @@ msgstr "supprimer la référence symboli
 msgid "shorten ref output"
 msgstr "raccourcir l'affichage de la référence"
 
-#: builtin/symbolic-ref.c:43 builtin/update-ref.c:362
+#: builtin/symbolic-ref.c:43 builtin/update-ref.c:363
 msgid "reason"
 msgstr "raison"
 
-#: builtin/symbolic-ref.c:43 builtin/update-ref.c:362
+#: builtin/symbolic-ref.c:43 builtin/update-ref.c:363
 msgid "reason of the update"
 msgstr "raison de la mise à jour"
 
-#: builtin/tag.c:24
+#: builtin/tag.c:25
 msgid ""
-"git tag [-a | -s | -u <key-id>] [-f] [-m <msg> | -F <file>] <tagname> "
-"[<head>]"
+"git tag [-a | -s | -u <key-id>] [-f] [-m <msg> | -F <file>]\n"
+"\t\t<tagname> [<head>]"
 msgstr ""
-"git tag [-a | -s | -u <id-clé>] [-f] [-m <message> | -F <file>] <nom-"
-"étiquette> [<head>]"
+"git tag [-a | -s | -u <id-clé>] [-f] [-m <message> | -F <fichier>]\n"
+"\t\t<nom-étiquette> [<head>]"
 
-#: builtin/tag.c:25
+#: builtin/tag.c:27
 msgid "git tag -d <tagname>..."
 msgstr "git tag -d <nométiquette>..."
 
-#: builtin/tag.c:26
+#: builtin/tag.c:28
 msgid ""
 "git tag -l [-n[<num>]] [--contains <commit>] [--no-contains <commit>] [--"
 "points-at <object>]\n"
@@ -14833,21 +21093,21 @@ msgstr ""
 "points-at <objet>]\n"
 "\t\t[--format=<format>] [--[no-]merged [<commit>]] [<motif>...]"
 
-#: builtin/tag.c:28
+#: builtin/tag.c:30
 msgid "git tag -v [--format=<format>] <tagname>..."
 msgstr "git tag -v [--format=<format>] <nométiquette>..."
 
-#: builtin/tag.c:86
+#: builtin/tag.c:89
 #, c-format
 msgid "tag '%s' not found."
 msgstr "étiquette '%s' non trouvée."
 
-#: builtin/tag.c:102
+#: builtin/tag.c:105
 #, c-format
 msgid "Deleted tag '%s' (was %s)\n"
 msgstr "Étiquette '%s' supprimée (elle était sur %s)\n"
 
-#: builtin/tag.c:132
+#: builtin/tag.c:135
 #, c-format
 msgid ""
 "\n"
@@ -14860,7 +21120,7 @@ msgstr ""
 "  %s\n"
 "Les lignes commençant par '%c' seront ignorées.\n"
 
-#: builtin/tag.c:136
+#: builtin/tag.c:139
 #, c-format
 msgid ""
 "\n"
@@ -14875,364 +21135,378 @@ msgstr ""
 "Les lignes commençant par '%c' seront gardées ; vous pouvez les retirer vous-"
 "même si vous le souhaitez.\n"
 
-#: builtin/tag.c:190
+#: builtin/tag.c:198
 msgid "unable to sign the tag"
 msgstr "impossible de signer l'étiquette"
 
-#: builtin/tag.c:192
+#: builtin/tag.c:200
 msgid "unable to write tag file"
 msgstr "impossible d'écrire le fichier d'étiquettes"
 
-#: builtin/tag.c:217
+#: builtin/tag.c:216
+#, c-format
+msgid ""
+"You have created a nested tag. The object referred to by your new tag is\n"
+"already a tag. If you meant to tag the object that it points to, use:\n"
+"\n"
+"\tgit tag -f %s %s^{}"
+msgstr ""
+"Vous avez créé une étiquette nichée. L'objet pointé par votre nouvelle "
+"étiquette\n"
+"est déjà une étiquette. Si vous vouliez étiqueter l'objet pointé, "
+"utilisez :\n"
+"\n"
+"\tgit tag -f %s %s^{}"
+
+#: builtin/tag.c:232
 msgid "bad object type."
 msgstr "mauvais type d'objet."
 
-#: builtin/tag.c:266
+#: builtin/tag.c:284
 msgid "no tag message?"
 msgstr "pas de message pour l'étiquette ?"
 
-#: builtin/tag.c:273
+#: builtin/tag.c:291
 #, c-format
 msgid "The tag message has been left in %s\n"
 msgstr "Le message pour l'étiquette a été laissé dans %s\n"
 
-#: builtin/tag.c:382
+#: builtin/tag.c:402
 msgid "list tag names"
 msgstr "afficher les noms des étiquettes"
 
-#: builtin/tag.c:384
+#: builtin/tag.c:404
 msgid "print <n> lines of each tag message"
 msgstr "affiche <n> lignes de chaque message d'étiquette"
 
-#: builtin/tag.c:386
+#: builtin/tag.c:406
 msgid "delete tags"
 msgstr "supprimer des étiquettes"
 
-#: builtin/tag.c:387
+#: builtin/tag.c:407
 msgid "verify tags"
 msgstr "vérifier des étiquettes"
 
-#: builtin/tag.c:389
+#: builtin/tag.c:409
 msgid "Tag creation options"
 msgstr "Options de création de l'étiquette"
 
-#: builtin/tag.c:391
+#: builtin/tag.c:411
 msgid "annotated tag, needs a message"
 msgstr "étiquette annotée, nécessite un message"
 
-#: builtin/tag.c:393
+#: builtin/tag.c:413
 msgid "tag message"
 msgstr "message pour l'étiquette"
 
-#: builtin/tag.c:395
+#: builtin/tag.c:415
 msgid "force edit of tag message"
 msgstr "forcer l'édition du message d'étiquetage"
 
-#: builtin/tag.c:396
+#: builtin/tag.c:416
 msgid "annotated and GPG-signed tag"
 msgstr "étiquette annotée et signée avec GPG"
 
-#: builtin/tag.c:400
+#: builtin/tag.c:419
 msgid "use another key to sign the tag"
 msgstr "utiliser une autre clé pour signer l'étiquette"
 
-#: builtin/tag.c:401
+#: builtin/tag.c:420
 msgid "replace the tag if exists"
 msgstr "remplacer l'étiquette si elle existe"
 
-#: builtin/tag.c:402 builtin/update-ref.c:368
+#: builtin/tag.c:421 builtin/update-ref.c:369
 msgid "create a reflog"
 msgstr "créer un reflog"
 
-#: builtin/tag.c:404
+#: builtin/tag.c:423
 msgid "Tag listing options"
 msgstr "Options d'affichage des étiquettes"
 
-#: builtin/tag.c:405
+#: builtin/tag.c:424
 msgid "show tag list in columns"
 msgstr "afficher la liste des étiquettes sous forme de colonnes"
 
-#: builtin/tag.c:406 builtin/tag.c:408
+#: builtin/tag.c:425 builtin/tag.c:427
 msgid "print only tags that contain the commit"
 msgstr "afficher seulement les étiquettes qui contiennent la validation"
 
-#: builtin/tag.c:407 builtin/tag.c:409
+#: builtin/tag.c:426 builtin/tag.c:428
 msgid "print only tags that don't contain the commit"
 msgstr "afficher seulement les étiquettes qui ne contiennent pas la validation"
 
-#: builtin/tag.c:410
+#: builtin/tag.c:429
 msgid "print only tags that are merged"
 msgstr "afficher seulement les étiquettes qui sont fusionnées"
 
-#: builtin/tag.c:411
+#: builtin/tag.c:430
 msgid "print only tags that are not merged"
 msgstr "afficher seulement les étiquettes qui ne sont pas fusionnées"
 
-#: builtin/tag.c:416
+#: builtin/tag.c:434
 msgid "print only tags of the object"
 msgstr "afficher seulement les étiquettes de l'objet"
 
-#: builtin/tag.c:460
+#: builtin/tag.c:482
 msgid "--column and -n are incompatible"
 msgstr "--column et -n sont incompatibles"
 
-#: builtin/tag.c:482
+#: builtin/tag.c:504
 msgid "-n option is only allowed in list mode"
 msgstr "l'option -n est autorisée seulement en mode de liste"
 
-#: builtin/tag.c:484
+#: builtin/tag.c:506
 msgid "--contains option is only allowed in list mode"
 msgstr "l'option --contains est autorisée seulement en mode de liste"
 
-#: builtin/tag.c:486
+#: builtin/tag.c:508
 msgid "--no-contains option is only allowed in list mode"
 msgstr "l'option --contains est autorisée seulement en mode liste"
 
-#: builtin/tag.c:488
+#: builtin/tag.c:510
 msgid "--points-at option is only allowed in list mode"
 msgstr "l'option --points-at est autorisée seulement en mode liste"
 
-#: builtin/tag.c:490
+#: builtin/tag.c:512
 msgid "--merged and --no-merged options are only allowed in list mode"
 msgstr ""
 "les options --merged et --no-merged ne sont autorisées qu'en mode liste"
 
-#: builtin/tag.c:501
+#: builtin/tag.c:523
 msgid "only one -F or -m option is allowed."
 msgstr "une seule option -F ou -m est autorisée."
 
-#: builtin/tag.c:520
+#: builtin/tag.c:542
 msgid "too many params"
 msgstr "trop de paramètres"
 
-#: builtin/tag.c:526
+#: builtin/tag.c:548
 #, c-format
 msgid "'%s' is not a valid tag name."
 msgstr "'%s' n'est pas un nom d'étiquette valide."
 
-#: builtin/tag.c:531
+#: builtin/tag.c:553
 #, c-format
 msgid "tag '%s' already exists"
 msgstr "l'étiquette '%s' existe déjà"
 
-#: builtin/tag.c:562
+#: builtin/tag.c:584
 #, c-format
 msgid "Updated tag '%s' (was %s)\n"
 msgstr "Étiquette '%s' mise à jour (elle était sur %s)\n"
 
-#: builtin/unpack-objects.c:498
+#: builtin/unpack-objects.c:501
 msgid "Unpacking objects"
 msgstr "Dépaquetage des objets"
 
-#: builtin/update-index.c:82
+#: builtin/update-index.c:84
 #, c-format
 msgid "failed to create directory %s"
 msgstr "échec de la création du répertoire %s"
 
-#: builtin/update-index.c:88
-#, c-format
-msgid "failed to stat %s"
-msgstr "échec du stat de %s"
-
-#: builtin/update-index.c:98
+#: builtin/update-index.c:100
 #, c-format
 msgid "failed to create file %s"
 msgstr "échec de la création du fichier %s"
 
-#: builtin/update-index.c:106
+#: builtin/update-index.c:108
 #, c-format
 msgid "failed to delete file %s"
 msgstr "échec de la suppression du fichier %s"
 
-#: builtin/update-index.c:113 builtin/update-index.c:219
+#: builtin/update-index.c:115 builtin/update-index.c:221
 #, c-format
 msgid "failed to delete directory %s"
 msgstr "échec de la suppression du répertoire %s"
 
-#: builtin/update-index.c:138
+#: builtin/update-index.c:140
 #, c-format
 msgid "Testing mtime in '%s' "
 msgstr "Test du mtime dans '%s' "
 
-#: builtin/update-index.c:152
+#: builtin/update-index.c:154
 msgid "directory stat info does not change after adding a new file"
 msgstr ""
 "l'information de stat du répertoire ne change pas après ajout d'un fichier"
 
-#: builtin/update-index.c:165
+#: builtin/update-index.c:167
 msgid "directory stat info does not change after adding a new directory"
 msgstr ""
 "l'information de stat du répertoire ne change pas après ajout d'un répertoire"
 
-#: builtin/update-index.c:178
+#: builtin/update-index.c:180
 msgid "directory stat info changes after updating a file"
 msgstr ""
 "l'information de stat du répertoire change après mise à jour d'un fichier"
 
-#: builtin/update-index.c:189
+#: builtin/update-index.c:191
 msgid "directory stat info changes after adding a file inside subdirectory"
 msgstr ""
 "l'information de stat du répertoire change après l'ajout d'un fichier dans "
 "un sous-répertoire"
 
-#: builtin/update-index.c:200
+#: builtin/update-index.c:202
 msgid "directory stat info does not change after deleting a file"
 msgstr ""
 "l'information de stat du répertoire ne change pas après la suppression d'un "
 "fichier<"
 
-#: builtin/update-index.c:213
+#: builtin/update-index.c:215
 msgid "directory stat info does not change after deleting a directory"
 msgstr ""
 "l'information de stat du répertoire ne change pas après la suppression d'un "
 "répertoire"
 
-#: builtin/update-index.c:220
+#: builtin/update-index.c:222
 msgid " OK"
 msgstr " OK"
 
-#: builtin/update-index.c:589
+#: builtin/update-index.c:591
 msgid "git update-index [<options>] [--] [<file>...]"
 msgstr "git update-index [<options>] [--] [<fichier>...]"
 
-#: builtin/update-index.c:946
+#: builtin/update-index.c:974
 msgid "continue refresh even when index needs update"
 msgstr "continuer de rafraîchir même si l'index a besoin d'une mise à jour"
 
-#: builtin/update-index.c:949
+#: builtin/update-index.c:977
 msgid "refresh: ignore submodules"
 msgstr "rafraîchir : ignorer les sous-modules"
 
-#: builtin/update-index.c:952
+#: builtin/update-index.c:980
 msgid "do not ignore new files"
 msgstr "ne pas ignorer les nouveaux fichiers"
 
-#: builtin/update-index.c:954
+#: builtin/update-index.c:982
 msgid "let files replace directories and vice-versa"
 msgstr "laisser les fichiers remplacer des répertoires et vice-versa"
 
-#: builtin/update-index.c:956
+#: builtin/update-index.c:984
 msgid "notice files missing from worktree"
 msgstr "aviser des fichiers manquants dans la copie de travail"
 
-#: builtin/update-index.c:958
+#: builtin/update-index.c:986
 msgid "refresh even if index contains unmerged entries"
 msgstr "rafraîchir même si l'index contient des éléments non fusionnés"
 
-#: builtin/update-index.c:961
+#: builtin/update-index.c:989
 msgid "refresh stat information"
 msgstr "rafraîchir l'information de stat"
 
-#: builtin/update-index.c:965
+#: builtin/update-index.c:993
 msgid "like --refresh, but ignore assume-unchanged setting"
 msgstr "comme --refresh, mais en ignorant l'option assume-unchanged"
 
-#: builtin/update-index.c:969
+#: builtin/update-index.c:997
 msgid "<mode>,<object>,<path>"
 msgstr "<mode>, <objet>, <chemin>"
 
-#: builtin/update-index.c:970
+#: builtin/update-index.c:998
 msgid "add the specified entry to the index"
 msgstr "ajouter l'élément spécifié dans l'index"
 
-#: builtin/update-index.c:979
+#: builtin/update-index.c:1008
 msgid "mark files as \"not changing\""
 msgstr "marquer les fichiers comme \"non changeants\""
 
-#: builtin/update-index.c:982
+#: builtin/update-index.c:1011
 msgid "clear assumed-unchanged bit"
 msgstr "mettre à zéro le bit supposé-non-modifié"
 
-#: builtin/update-index.c:985
+#: builtin/update-index.c:1014
 msgid "mark files as \"index-only\""
 msgstr "marquer les fichiers comme \"index seulement\""
 
-#: builtin/update-index.c:988
+#: builtin/update-index.c:1017
 msgid "clear skip-worktree bit"
 msgstr "mettre à zéro le bit sauter-la-copie-de travail"
 
-#: builtin/update-index.c:991
+#: builtin/update-index.c:1020
+msgid "do not touch index-only entries"
+msgstr "ne pas toucher aux entrées restreintes à l'index"
+
+#: builtin/update-index.c:1022
 msgid "add to index only; do not add content to object database"
 msgstr ""
 "ajouter seulement à l'index ; ne pas ajouter le contenu dans la base de "
 "données des objets"
 
-#: builtin/update-index.c:993
+#: builtin/update-index.c:1024
 msgid "remove named paths even if present in worktree"
 msgstr ""
 "supprimer les chemins nommés même s'ils sont présents dans la copie de "
 "travail"
 
-#: builtin/update-index.c:995
+#: builtin/update-index.c:1026
 msgid "with --stdin: input lines are terminated by null bytes"
 msgstr "avec --stdin : les lignes en entrée sont terminées par des octets nuls"
 
-#: builtin/update-index.c:997
+#: builtin/update-index.c:1028
 msgid "read list of paths to be updated from standard input"
 msgstr "lire la liste des chemins à mettre à jour depuis l'entrée standard"
 
-#: builtin/update-index.c:1001
+#: builtin/update-index.c:1032
 msgid "add entries from standard input to the index"
 msgstr "ajouter les éléments depuis l'entrée standard à l'index"
 
-#: builtin/update-index.c:1005
+#: builtin/update-index.c:1036
 msgid "repopulate stages #2 and #3 for the listed paths"
 msgstr "repeupler les étapes n°2 et n°3 pour les chemins listés"
 
-#: builtin/update-index.c:1009
+#: builtin/update-index.c:1040
 msgid "only update entries that differ from HEAD"
 msgstr "mettre à jour seulement les éléments qui diffèrent de HEAD"
 
-#: builtin/update-index.c:1013
+#: builtin/update-index.c:1044
 msgid "ignore files missing from worktree"
 msgstr "ignorer les fichiers manquants dans la copie de travail"
 
-#: builtin/update-index.c:1016
+#: builtin/update-index.c:1047
 msgid "report actions to standard output"
 msgstr "afficher les actions sur la sortie standard"
 
-#: builtin/update-index.c:1018
+#: builtin/update-index.c:1049
 msgid "(for porcelains) forget saved unresolved conflicts"
 msgstr "(pour porcelaines) oublier les conflits sauvés et non résolus"
 
-#: builtin/update-index.c:1022
+#: builtin/update-index.c:1053
 msgid "write index in this format"
 msgstr "écrire l'index dans ce format"
 
-#: builtin/update-index.c:1024
+#: builtin/update-index.c:1055
 msgid "enable or disable split index"
 msgstr "activer ou désactiver l'index divisé"
 
-#: builtin/update-index.c:1026
+#: builtin/update-index.c:1057
 msgid "enable/disable untracked cache"
 msgstr "activer ou désactiver le cache de non-suivis"
 
-#: builtin/update-index.c:1028
+#: builtin/update-index.c:1059
 msgid "test if the filesystem supports untracked cache"
 msgstr "tester si le système de fichier supporte le cache de non-suivis"
 
-#: builtin/update-index.c:1030
+#: builtin/update-index.c:1061
 msgid "enable untracked cache without testing the filesystem"
 msgstr "activer le cache de non-suivis sans tester le système de fichier"
 
-#: builtin/update-index.c:1032
+#: builtin/update-index.c:1063
 msgid "write out the index even if is not flagged as changed"
 msgstr "écrire l'index même s'il n'est pas marqué comme modifié"
 
-#: builtin/update-index.c:1034
+#: builtin/update-index.c:1065
 msgid "enable or disable file system monitor"
 msgstr ""
 "activer ou désactiver la surveillance du système de fichier (fsmonitor)"
 
-#: builtin/update-index.c:1036
+#: builtin/update-index.c:1067
 msgid "mark files as fsmonitor valid"
 msgstr "marquer les fichiers comme valides pour fsmonitor"
 
-#: builtin/update-index.c:1039
+#: builtin/update-index.c:1070
 msgid "clear fsmonitor valid bit"
 msgstr "effacer le bit de validité fsmonitor"
 
-#: builtin/update-index.c:1138
+#: builtin/update-index.c:1173
 msgid ""
 "core.splitIndex is set to false; remove or change it, if you really want to "
 "enable split index"
@@ -15240,7 +21514,7 @@ msgstr ""
 "core.splitIndex est réglé à false ; supprimez-le ou changez-le si vous "
 "souhaitez vraiment activer l'index coupé"
 
-#: builtin/update-index.c:1147
+#: builtin/update-index.c:1182
 msgid ""
 "core.splitIndex is set to true; remove or change it, if you really want to "
 "disable split index"
@@ -15248,7 +21522,7 @@ msgstr ""
 "core.splitIndex est réglé à vrai ; supprimez-le ou changez-le si vous "
 "souhaitez vraiment désactiver l'index coupé"
 
-#: builtin/update-index.c:1158
+#: builtin/update-index.c:1194
 msgid ""
 "core.untrackedCache is set to true; remove or change it, if you really want "
 "to disable the untracked cache"
@@ -15256,11 +21530,11 @@ msgstr ""
 "core.untrackedCache est réglé à true ; supprimez-le ou changez-le si vous "
 "souhaitez vraiment désactiver le cache des fichiers non-suivis"
 
-#: builtin/update-index.c:1162
+#: builtin/update-index.c:1198
 msgid "Untracked cache disabled"
 msgstr "Le cache non suivi est désactivé"
 
-#: builtin/update-index.c:1170
+#: builtin/update-index.c:1206
 msgid ""
 "core.untrackedCache is set to false; remove or change it, if you really want "
 "to enable the untracked cache"
@@ -15268,29 +21542,29 @@ msgstr ""
 "core.untrackedCache est réglé à false ; supprimez-le ou changez-le si vous "
 "souhaitez vraiment activer le cache des fichiers non-suivis"
 
-#: builtin/update-index.c:1174
+#: builtin/update-index.c:1210
 #, c-format
 msgid "Untracked cache enabled for '%s'"
 msgstr "Le cache non suivi est activé pour '%s'"
 
-#: builtin/update-index.c:1182
+#: builtin/update-index.c:1218
 msgid "core.fsmonitor is unset; set it if you really want to enable fsmonitor"
 msgstr ""
 "core.fsmonitor est réglé à false ; changez-le si vous souhaitez vraiment "
 "activer la surveillance du système de fichiers"
 
-#: builtin/update-index.c:1186
+#: builtin/update-index.c:1222
 msgid "fsmonitor enabled"
 msgstr "fsmonitor activé"
 
-#: builtin/update-index.c:1189
+#: builtin/update-index.c:1225
 msgid ""
 "core.fsmonitor is set; remove it if you really want to disable fsmonitor"
 msgstr ""
 "core.fsmonitor est réglé à true ; supprimez-le ou changez-le si vous "
 "souhaitez vraiment désactiver la surveillance du système de fichiers"
 
-#: builtin/update-index.c:1193
+#: builtin/update-index.c:1229
 msgid "fsmonitor disabled"
 msgstr "fsmonitor désactivé"
 
@@ -15308,19 +21582,19 @@ msgstr ""
 msgid "git update-ref [<options>] --stdin [-z]"
 msgstr "git update-ref [<options>] --stdin [-z]"
 
-#: builtin/update-ref.c:363
+#: builtin/update-ref.c:364
 msgid "delete the reference"
 msgstr "supprimer la référence"
 
-#: builtin/update-ref.c:365
+#: builtin/update-ref.c:366
 msgid "update <refname> not the one it points to"
 msgstr "mettre à jour <nomréférence> et non la référence pointée par lui"
 
-#: builtin/update-ref.c:366
+#: builtin/update-ref.c:367
 msgid "stdin has NUL-terminated arguments"
 msgstr "l'entrée standard a des arguments qui se terminent par NUL"
 
-#: builtin/update-ref.c:367
+#: builtin/update-ref.c:368
 msgid "read updates from stdin"
 msgstr "lire les mises à jour depuis l'entrée standard"
 
@@ -15336,6 +21610,10 @@ msgstr "mettre à jour les fichiers d'in
 msgid "git upload-pack [<options>] <dir>"
 msgstr "git upload-pack [<options>] <répertoire>"
 
+#: builtin/upload-pack.c:23 t/helper/test-serve-v2.c:17
+msgid "quit after a single request/response exchange"
+msgstr "quitter après un unique échange requête/réponse"
+
 #: builtin/upload-pack.c:25
 msgid "exit immediately after initial ref advertisement"
 msgstr "Sortir immédiatement après l'annonce initiale des références"
@@ -15350,15 +21628,15 @@ msgstr ""
 msgid "interrupt transfer after <n> seconds of inactivity"
 msgstr "interrompre le transfert après <n> secondes d'inactivité"
 
-#: builtin/verify-commit.c:18
+#: builtin/verify-commit.c:19
 msgid "git verify-commit [-v | --verbose] <commit>..."
 msgstr "git verify-commit [-v | --verbose] <commit>..."
 
-#: builtin/verify-commit.c:73
+#: builtin/verify-commit.c:68
 msgid "print commit contents"
 msgstr "afficher le contenu du commit"
 
-#: builtin/verify-commit.c:74 builtin/verify-tag.c:38
+#: builtin/verify-commit.c:69 builtin/verify-tag.c:37
 msgid "print raw gpg status output"
 msgstr "afficher les messages bruts de gpg"
 
@@ -15374,11 +21652,11 @@ msgstr "verbeux"
 msgid "show statistics only"
 msgstr "afficher seulement les statistiques"
 
-#: builtin/verify-tag.c:19
+#: builtin/verify-tag.c:18
 msgid "git verify-tag [-v | --verbose] [--format=<format>] <tag>..."
 msgstr "git verify-tag [-v | --verbose] [--format=<format>] <étiquette>..."
 
-#: builtin/verify-tag.c:37
+#: builtin/verify-tag.c:36
 msgid "print tag contents"
 msgstr "afficher le contenu de l'étiquette"
 
@@ -15410,23 +21688,28 @@ msgstr "git worktree remove [<options>]
 msgid "git worktree unlock <path>"
 msgstr "git worktree unlock <chemin>"
 
-#: builtin/worktree.c:58
+#: builtin/worktree.c:60 builtin/worktree.c:898
+#, c-format
+msgid "failed to delete '%s'"
+msgstr "échec de la suppression de '%s'"
+
+#: builtin/worktree.c:79
 #, c-format
 msgid "Removing worktrees/%s: not a valid directory"
 msgstr "Suppression de worktrees/%s : répertoire invalide"
 
-#: builtin/worktree.c:64
+#: builtin/worktree.c:85
 #, c-format
 msgid "Removing worktrees/%s: gitdir file does not exist"
 msgstr "Suppression de worktrees/%s : le fichier gitdir n'existe pas"
 
-#: builtin/worktree.c:69 builtin/worktree.c:78
+#: builtin/worktree.c:90 builtin/worktree.c:99
 #, c-format
 msgid "Removing worktrees/%s: unable to read gitdir file (%s)"
 msgstr ""
-"Suppression de worktrees/%s : echec de la lecture du fichier gitdir (%s)"
+"Suppression de worktrees/%s : échec de la lecture du fichier gitdir (%s)"
 
-#: builtin/worktree.c:88
+#: builtin/worktree.c:109
 #, c-format
 msgid ""
 "Removing worktrees/%s: short read (expected %<PRIuMAX> bytes, read "
@@ -15435,219 +21718,260 @@ msgstr ""
 "Suppression de worktrees/%s: lecture trop courte ( %<PRIuMAX> octets "
 "attendus, %<PRIuMAX> octets lus)"
 
-#: builtin/worktree.c:96
+#: builtin/worktree.c:117
 #, c-format
 msgid "Removing worktrees/%s: invalid gitdir file"
 msgstr "Suppression de worktrees/%s : fichier gitdir invalide"
 
-#: builtin/worktree.c:105
+#: builtin/worktree.c:126
 #, c-format
 msgid "Removing worktrees/%s: gitdir file points to non-existent location"
 msgstr ""
 "Suppression de worktrees/%s : le fichier gitdir point sur un endroit "
 "inexistant"
 
-#: builtin/worktree.c:152
+#: builtin/worktree.c:165
 msgid "report pruned working trees"
 msgstr "afficher les arbres de travail éliminés"
 
-#: builtin/worktree.c:154
+#: builtin/worktree.c:167
 msgid "expire working trees older than <time>"
 msgstr "faire expirer les arbres de travail plus vieux que <temps>"
 
-#: builtin/worktree.c:229
+#: builtin/worktree.c:234
 #, c-format
 msgid "'%s' already exists"
 msgstr "'%s' existe déjà"
 
-#: builtin/worktree.c:260
+#: builtin/worktree.c:251
+#, c-format
+msgid "unable to re-add worktree '%s'"
+msgstr "impossible de ré-ajouter l'arbre de travail '%s'"
+
+#: builtin/worktree.c:256
+#, c-format
+msgid ""
+"'%s' is a missing but locked worktree;\n"
+"use 'add -f -f' to override, or 'unlock' and 'prune' or 'remove' to clear"
+msgstr ""
+"'%s' est un arbre de travail manquant mais verrouillé ;\n"
+"utilisez 'add -f -f' pour passer outre, ou 'unlock' et 'prune' ou 'remove' "
+"pour corriger"
+
+#: builtin/worktree.c:258
+#, c-format
+msgid ""
+"'%s' is a missing but already registered worktree;\n"
+"use 'add -f' to override, or 'prune' or 'remove' to clear"
+msgstr ""
+"'%s' est un arbre de travail manquant mais déjà enregistré ;\n"
+"utilisez 'add -f' pour passer outre, ou 'prune' ou 'remove' pour corriger"
+
+#: builtin/worktree.c:308
 #, c-format
 msgid "could not create directory of '%s'"
 msgstr "impossible de créer le répertoire de '%s'"
 
-#: builtin/worktree.c:373 builtin/worktree.c:379
+#: builtin/worktree.c:439 builtin/worktree.c:445
 #, c-format
 msgid "Preparing worktree (new branch '%s')"
 msgstr "Préparation de l'arbre de travail (nouvelle branche '%s')"
 
-#: builtin/worktree.c:375
+#: builtin/worktree.c:441
 #, c-format
 msgid "Preparing worktree (resetting branch '%s'; was at %s)"
 msgstr ""
 "Préparation de l'arbre de travail (réinitialisation de la branche '%s' ; "
 "précédemment sur %s)"
 
-#: builtin/worktree.c:384
+#: builtin/worktree.c:450
 #, c-format
 msgid "Preparing worktree (checking out '%s')"
 msgstr "Préparation de l'arbre de travail (extraction de '%s')"
 
-#: builtin/worktree.c:390
+#: builtin/worktree.c:456
 #, c-format
 msgid "Preparing worktree (detached HEAD %s)"
 msgstr "Préparation de l'arbre de travail (HEAD détachée %s)"
 
-#: builtin/worktree.c:431
+#: builtin/worktree.c:497
 msgid "checkout <branch> even if already checked out in other worktree"
 msgstr ""
 "extraire la <branche> même si elle est déjà extraite dans une autre copie de "
 "travail"
 
-#: builtin/worktree.c:434
+#: builtin/worktree.c:500
 msgid "create a new branch"
 msgstr "créer une nouvelle branche"
 
-#: builtin/worktree.c:436
+#: builtin/worktree.c:502
 msgid "create or reset a branch"
 msgstr "créer ou réinitialiser une branche"
 
-#: builtin/worktree.c:438
+#: builtin/worktree.c:504
 msgid "populate the new working tree"
 msgstr "remplissage de la nouvelle copie de travail"
 
-#: builtin/worktree.c:439
+#: builtin/worktree.c:505
 msgid "keep the new working tree locked"
 msgstr "conserver le verrou sur le nouvel arbre de travail"
 
-#: builtin/worktree.c:441
+#: builtin/worktree.c:508
 msgid "set up tracking mode (see git-branch(1))"
 msgstr "régler le mode de suivi (voir git-branch(1))"
 
-#: builtin/worktree.c:444
+#: builtin/worktree.c:511
 msgid "try to match the new branch name with a remote-tracking branch"
 msgstr "essayer de nommer la nouvelle branche comme la branche amont"
 
-#: builtin/worktree.c:452
+#: builtin/worktree.c:519
 msgid "-b, -B, and --detach are mutually exclusive"
 msgstr "-b, -B et --detach sont mutuellement exclusifs"
 
-#: builtin/worktree.c:511
+#: builtin/worktree.c:580
 msgid "--[no-]track can only be used if a new branch is created"
 msgstr ""
 "--[no-]track ne peut être utilisé qu'à la création d'une nouvelle branche"
 
-#: builtin/worktree.c:611
+#: builtin/worktree.c:680
 msgid "reason for locking"
 msgstr "raison du verrouillage"
 
-#: builtin/worktree.c:623 builtin/worktree.c:656 builtin/worktree.c:710
-#: builtin/worktree.c:850
+#: builtin/worktree.c:692 builtin/worktree.c:725 builtin/worktree.c:799
+#: builtin/worktree.c:926
 #, c-format
 msgid "'%s' is not a working tree"
 msgstr "'%s' n'est pas une copie de travail"
 
-#: builtin/worktree.c:625 builtin/worktree.c:658
+#: builtin/worktree.c:694 builtin/worktree.c:727
 msgid "The main working tree cannot be locked or unlocked"
 msgstr ""
 "La copie de travail principale ne peut pas être verrouillée ou déverrouillée"
 
-#: builtin/worktree.c:630
+#: builtin/worktree.c:699
 #, c-format
 msgid "'%s' is already locked, reason: %s"
 msgstr "'%s' est déjà verrouillé, car '%s'"
 
-#: builtin/worktree.c:632
+#: builtin/worktree.c:701
 #, c-format
 msgid "'%s' is already locked"
 msgstr "'%s' est déjà verrouillé"
 
-#: builtin/worktree.c:660
+#: builtin/worktree.c:729
 #, c-format
 msgid "'%s' is not locked"
 msgstr "'%s' n'est pas verrouillé"
 
-#: builtin/worktree.c:685
+#: builtin/worktree.c:770
 msgid "working trees containing submodules cannot be moved or removed"
 msgstr ""
 "les arbres de travail contenant des sous-modules ne peuvent pas être "
 "déplacés ou supprimés"
 
-#: builtin/worktree.c:712 builtin/worktree.c:852
+#: builtin/worktree.c:778
+msgid "force move even if worktree is dirty or locked"
+msgstr ""
+"forcer le déplacement même si l'arbre de travail est sale ou verrouillé"
+
+#: builtin/worktree.c:801 builtin/worktree.c:928
 #, c-format
 msgid "'%s' is a main working tree"
 msgstr "'%s' est un arbre de travail principal"
 
-#: builtin/worktree.c:717
+#: builtin/worktree.c:806
 #, c-format
 msgid "could not figure out destination name from '%s'"
 msgstr "impossible de trouver le nom de la destination à partir de '%s'"
 
-#: builtin/worktree.c:723
+#: builtin/worktree.c:812
 #, c-format
 msgid "target '%s' already exists"
 msgstr "la cible '%s' existe déjà"
 
-#: builtin/worktree.c:730
+#: builtin/worktree.c:820
 #, c-format
-msgid "cannot move a locked working tree, lock reason: %s"
+msgid ""
+"cannot move a locked working tree, lock reason: %s\n"
+"use 'move -f -f' to override or unlock first"
 msgstr ""
 "impossible de déplacer un arbre de travail verrouillé, raison du "
-"verrouillage : %s"
+"verrouillage : %s\n"
+"utilisez 'move -f -f' pour outrepasser ou déverrouiller avant"
 
-#: builtin/worktree.c:732
-msgid "cannot move a locked working tree"
-msgstr "impossible de déplacer un arbre de travail verrouillé"
+#: builtin/worktree.c:822
+msgid ""
+"cannot move a locked working tree;\n"
+"use 'move -f -f' to override or unlock first"
+msgstr ""
+"impossible de déplacer un arbre de travail verrouillé;\n"
+"utilisez 'move -f -f' pour outrepasser ou déverrouiller avant"
 
-#: builtin/worktree.c:735
+#: builtin/worktree.c:825
 #, c-format
 msgid "validation failed, cannot move working tree: %s"
 msgstr "la validation a échoué, impossible de déplacer l'arbre de travail : %s"
 
-#: builtin/worktree.c:740
+#: builtin/worktree.c:830
 #, c-format
 msgid "failed to move '%s' to '%s'"
 msgstr "échec au déplacement de '%s' vers '%s'"
 
-#: builtin/worktree.c:788
+#: builtin/worktree.c:878
 #, c-format
 msgid "failed to run 'git status' on '%s'"
 msgstr "échec du lancement de 'git status' sur '%s'"
 
-#: builtin/worktree.c:792
+#: builtin/worktree.c:882
 #, c-format
-msgid "'%s' is dirty, use --force to delete it"
-msgstr "'%s' est sale, utilisez --force pour le supprimer"
+msgid "'%s' contains modified or untracked files, use --force to delete it"
+msgstr ""
+"'%s' contient des fichiers modifiés ou non-suivis, utilisez --force pour le "
+"supprimer"
 
-#: builtin/worktree.c:797
+#: builtin/worktree.c:887
 #, c-format
 msgid "failed to run 'git status' on '%s', code %d"
 msgstr "impossible de lancer 'git status' sur '%s', code %d"
 
-#: builtin/worktree.c:808 builtin/worktree.c:822
-#, c-format
-msgid "failed to delete '%s'"
-msgstr "échec de la suppression de '%s'"
-
-#: builtin/worktree.c:834
-msgid "force removing even if the worktree is dirty"
-msgstr "forcer la suppression même si l'arbre de travail est sale"
+#: builtin/worktree.c:910
+msgid "force removal even if worktree is dirty or locked"
+msgstr ""
+"forcer la suppression même si l'arbre de travail est sale ou verrouillé"
 
-#: builtin/worktree.c:856
+#: builtin/worktree.c:933
 #, c-format
-msgid "cannot remove a locked working tree, lock reason: %s"
+msgid ""
+"cannot remove a locked working tree, lock reason: %s\n"
+"use 'remove -f -f' to override or unlock first"
 msgstr ""
 "impossible de supprimer un arbre de travail verrouillé, raison du "
-"verrouillage : %s"
+"verrouillage : %s\n"
+"utilisez 'move -f -f' pour outrepasser ou déverrouiller avant"
 
-#: builtin/worktree.c:858
-msgid "cannot remove a locked working tree"
-msgstr "impossible de supprimer un arbre de travail verrouillé"
+#: builtin/worktree.c:935
+msgid ""
+"cannot remove a locked working tree;\n"
+"use 'remove -f -f' to override or unlock first"
+msgstr ""
+"impossible de supprimer un arbre de travail verrouillé;\n"
+"utilisez 'move -f -f' pour outrepasser ou déverrouiller avant"
 
-#: builtin/worktree.c:861
+#: builtin/worktree.c:938
 #, c-format
 msgid "validation failed, cannot remove working tree: %s"
 msgstr ""
 "la validation a échoué, impossible de supprimer l'arbre de travail : %s"
 
-#: builtin/write-tree.c:14
+#: builtin/write-tree.c:15
 msgid "git write-tree [--missing-ok] [--prefix=<prefix>/]"
 msgstr "git write-tree [--missing-ok] [--prefix=<préfixe>/]"
 
-#: builtin/write-tree.c:27
+#: builtin/write-tree.c:28
 msgid "<prefix>/"
 msgstr "<préfixe>/"
 
-#: builtin/write-tree.c:28
+#: builtin/write-tree.c:29
 msgid "write tree object for a subdirectory <prefix>"
 msgstr "écrire l'objet arbre pour un sous-répertoire <préfixe>"
 
@@ -15655,7 +21979,22 @@ msgstr "écrire l'objet arbre pour un so
 msgid "only useful for debugging"
 msgstr "seulement utile pour le débogage"
 
-#: credential-cache--daemon.c:222
+#: fast-import.c:3125
+#, c-format
+msgid "Expected 'mark' command, got %s"
+msgstr "commande 'mark' attendue, %s trouvé"
+
+#: fast-import.c:3130
+#, c-format
+msgid "Expected 'to' command, got %s"
+msgstr "commande 'to' attendue, %s trouvé"
+
+#: fast-import.c:3254
+#, c-format
+msgid "feature '%s' forbidden in input without --allow-unsafe-features"
+msgstr "la fonctionnalité '%s' est interdite en entrée sans --allow-unsafe-features"
+
+#: credential-cache--daemon.c:223
 #, c-format
 msgid ""
 "The permissions on your socket directory are too loose; other\n"
@@ -15668,10 +22007,27 @@ msgstr ""
 "\n"
 "    chmod 0700 %s"
 
-#: credential-cache--daemon.c:271
+#: credential-cache--daemon.c:272
 msgid "print debugging messages to stderr"
 msgstr "afficher les messages de debug sur stderr"
 
+#: t/helper/test-reach.c:152
+#, c-format
+msgid "commit %s is not marked reachable"
+msgstr "le commit %s n'est pas marqué joignable"
+
+#: t/helper/test-reach.c:162
+msgid "too many commits marked reachable"
+msgstr "trop de commits marqués joignables"
+
+#: t/helper/test-serve-v2.c:7
+msgid "test-tool serve-v2 [<options>]"
+msgstr "test-tool serve-v2 [<options>]"
+
+#: t/helper/test-serve-v2.c:19
+msgid "exit immediately after advertising capabilities"
+msgstr "sortir immédiatement après l'annonce des capacités"
+
 #: git.c:27
 msgid ""
 "git [--version] [--help] [-C <path>] [-c <name>=<value>]\n"
@@ -15693,73 +22049,155 @@ msgstr ""
 msgid ""
 "'git help -a' and 'git help -g' list available subcommands and some\n"
 "concept guides. See 'git help <command>' or 'git help <concept>'\n"
-"to read about a specific subcommand or concept."
+"to read about a specific subcommand or concept.\n"
+"See 'git help git' for an overview of the system."
 msgstr ""
 "'git help -a' et 'git help -g' listent les sous-commandes disponibles et\n"
 "quelques concepts. Voir 'git help <commande>' ou 'git help <concept>'\n"
-"pour en lire plus à propos d'une commande spécifique ou d'un concept."
+"pour en lire plus à propos d'une commande spécifique ou d'un concept.\n"
+"Voir 'git help git' pour un survol du système."
 
-#: git.c:173
+#: git.c:186
 #, c-format
 msgid "no directory given for --git-dir\n"
 msgstr "aucun répertoire fourni pour --git-dir\n"
 
-#: git.c:187
+#: git.c:200
 #, c-format
 msgid "no namespace given for --namespace\n"
 msgstr "aucun espace de nom fournit pour --namespace\n"
 
-#: git.c:201
+#: git.c:214
 #, c-format
 msgid "no directory given for --work-tree\n"
 msgstr "aucun répertoire fourni pour --work-tree\n"
 
-#: git.c:215
+#: git.c:228
 #, c-format
 msgid "no prefix given for --super-prefix\n"
 msgstr "aucun préfixe fourni pour --super-prefix\n"
 
-#: git.c:237
+#: git.c:250
 #, c-format
 msgid "-c expects a configuration string\n"
 msgstr "-c requiert une chaîne de configuration\n"
 
-#: git.c:275
+#: git.c:288
 #, c-format
 msgid "no directory given for -C\n"
 msgstr "aucun répertoire fourni pour -C\n"
 
-#: git.c:300
+#: git.c:314
 #, c-format
 msgid "unknown option: %s\n"
 msgstr "option inconnue : %s\n"
 
-#: git.c:765
+#: git.c:360
+#, c-format
+msgid "while expanding alias '%s': '%s'"
+msgstr "lors de l'expansion de l'alias '%s' : '%s'"
+
+#: git.c:369
+#, c-format
+msgid ""
+"alias '%s' changes environment variables.\n"
+"You can use '!git' in the alias to do this"
+msgstr ""
+"l'alias '%s' modifie les variables d'environnement.\n"
+"Vous pouvez utiliser '!git' dans l'alias pour le faire"
+
+#: git.c:376
+#, c-format
+msgid "empty alias for %s"
+msgstr "alias vide pour %s"
+
+#: git.c:379
+#, c-format
+msgid "recursive alias: %s"
+msgstr "alias recursif : %s"
+
+#: git.c:459
+msgid "write failure on standard output"
+msgstr "échec d'écriture sur la sortie standard"
+
+#: git.c:461
+msgid "unknown write failure on standard output"
+msgstr "échec inconnu d'écriture sur la sortie standard"
+
+#: git.c:463
+msgid "close failed on standard output"
+msgstr "échec de fermeture de la sortie standard"
+
+#: git.c:793
+#, c-format
+msgid "alias loop detected: expansion of '%s' does not terminate:%s"
+msgstr "boucle d'alias détectée : l'expansion de '%s' ne finit jamais : %s"
+
+#: git.c:843
+#, c-format
+msgid "cannot handle %s as a builtin"
+msgstr "impossible d'utiliser %s comme une fonction intégrée"
+
+#: git.c:856
+#, c-format
+msgid ""
+"usage: %s\n"
+"\n"
+msgstr ""
+"usage : %s\n"
+"\n"
+
+#: git.c:876
 #, c-format
 msgid "expansion of alias '%s' failed; '%s' is not a git command\n"
 msgstr ""
 "l'expansion de l'alias '%s' a échoué : '%s' n'est pas une commande git\n"
 
-#: git.c:777
+#: git.c:888
 #, c-format
 msgid "failed to run command '%s': %s\n"
 msgstr "échec au lancement de la commande '%s' : %s\n"
 
-#: http.c:348
+#: http.c:378
 #, c-format
 msgid "negative value for http.postbuffer; defaulting to %d"
 msgstr ""
 "valeur négative pour http.postbuffer ; utilisation de la valeur par défaut %d"
 
-#: http.c:369
+#: http.c:399
 msgid "Delegation control is not supported with cURL < 7.22.0"
 msgstr "La délégation de commande n'est pas supporté avec cuRL < 7.22.0"
 
-#: http.c:378
+#: http.c:408
 msgid "Public key pinning not supported with cURL < 7.44.0"
 msgstr "L'épinglage de clé publique n'est pas supporté avec cuRL < 7.44.0"
 
-#: http.c:1854
+#: http.c:876
+msgid "CURLSSLOPT_NO_REVOKE not supported with cURL < 7.44.0"
+msgstr "CURLSSLOPT_NO_REMOVE n'est pas supporté avec cuRL < 7.44.0"
+
+#: http.c:949
+msgid "Protocol restrictions not supported with cURL < 7.19.4"
+msgstr "Les restrictions de protocole ne sont pas supportés avec cuRL < 7.19.4"
+
+#: http.c:1086
+#, c-format
+msgid "Unsupported SSL backend '%s'. Supported SSL backends:"
+msgstr "Dorsale SSL '%s' non supportée. Dorsales SSL supportées :"
+
+#: http.c:1093
+#, c-format
+msgid "Could not set SSL backend to '%s': cURL was built without SSL backends"
+msgstr ""
+"Impossible de régler la dorsale SSL à '%s' : cURL a été construit sans "
+"dorsale SSL"
+
+#: http.c:1097
+#, c-format
+msgid "Could not set SSL backend to '%s': already set"
+msgstr "Impossible de spécifier le dorsal SSL à '%s' : déjà spécifié"
+
+#: http.c:1966
 #, c-format
 msgid ""
 "unable to update url base from redirection:\n"
@@ -15770,39 +22208,179 @@ msgstr ""
 "      demandé : %s\n"
 "  redirection : %s"
 
-#: remote-curl.c:401
+#: remote-curl.c:166
+#, c-format
+msgid "invalid quoting in push-option value: '%s'"
+msgstr "citation invalide dans la valeur push-option : '%s'"
+
+#: remote-curl.c:263
+#, c-format
+msgid "%sinfo/refs not valid: is this a git repository?"
+msgstr "%sinfo/refs n'est pas valide : est-ce bien un dépôt git ?"
+
+#: remote-curl.c:364
+msgid "invalid server response; expected service, got flush packet"
+msgstr "réponse du serveur invalide ; service attendu, paquet de vidage reçu"
+
+#: remote-curl.c:395
+#, c-format
+msgid "invalid server response; got '%s'"
+msgstr "réponse du serveur invalide ; '%s' reçu"
+
+#: remote-curl.c:455
+#, c-format
+msgid "repository '%s' not found"
+msgstr "dépôt '%s' non trouvé"
+
+#: remote-curl.c:459
+#, c-format
+msgid "Authentication failed for '%s'"
+msgstr "Échec d'authentification pour '%s'"
+
+#: remote-curl.c:463
+#, c-format
+msgid "unable to access '%s': %s"
+msgstr "impossible d'accéder à '%s' : %s"
+
+#: remote-curl.c:469
 #, c-format
 msgid "redirecting to %s"
 msgstr "redirection vers %s"
 
-#: list-objects-filter-options.h:59
+#: remote-curl.c:593
+msgid "shouldn't have EOF when not gentle on EOF"
+msgstr "ne devrait pas recevoir OEF quand on n'est pas gentil sur EOF"
+
+#: remote-curl.c:673
+msgid "unable to rewind rpc post data - try increasing http.postBuffer"
+msgstr ""
+"impossible de rembobiner le données post rpc - essayer d'augmenter http."
+"postBuffer"
+
+#: remote-curl.c:733
+#, c-format
+msgid "RPC failed; %s"
+msgstr "échec RPC ; %s"
+
+#: remote-curl.c:773
+msgid "cannot handle pushes this big"
+msgstr "impossible de gérer des poussées aussi grosses"
+
+#: remote-curl.c:888
+#, c-format
+msgid "cannot deflate request; zlib deflate error %d"
+msgstr "impossible de compresser la requête ; erreur de compression zlib %d"
+
+#: remote-curl.c:892
+#, c-format
+msgid "cannot deflate request; zlib end error %d"
+msgstr "impossible de compresser la requête ; erreur de fin zlib %d"
+
+#: remote-curl.c:1023
+msgid "dumb http transport does not support shallow capabilities"
+msgstr "le protocole http idiot ne supporte la capacité superficielle"
+
+#: remote-curl.c:1037
+msgid "fetch failed."
+msgstr "échec du récupération."
+
+#: remote-curl.c:1085
+msgid "cannot fetch by sha1 over smart http"
+msgstr "impossible de récupérer par sha1 sur http intelligent"
+
+#: remote-curl.c:1129 remote-curl.c:1135
+#, c-format
+msgid "protocol error: expected sha/ref, got '%s'"
+msgstr "erreur de protocole : sha/ref attendu, '%s' trouvé"
+
+#: remote-curl.c:1147 remote-curl.c:1261
+#, c-format
+msgid "http transport does not support %s"
+msgstr "le transport http ne supporte pas %s"
+
+#: remote-curl.c:1183
+msgid "git-http-push failed"
+msgstr "échec de git-http-push"
+
+#: remote-curl.c:1367
+msgid "remote-curl: usage: git remote-curl <remote> [<url>]"
+msgstr "remote-curl: usage: git remote-curl <distant> [<url>]"
+
+#: remote-curl.c:1399
+msgid "remote-curl: error reading command stream from git"
+msgstr "remote-curl : erreur de lecture du flux de commande depuis git"
+
+#: remote-curl.c:1406
+msgid "remote-curl: fetch attempted without a local repo"
+msgstr "remote-curl : récupération tentée sans dépôt local"
+
+#: remote-curl.c:1446
+#, c-format
+msgid "remote-curl: unknown command '%s' from git"
+msgstr "remote-curl : commande inconnue '%s' depuis git"
+
+#: list-objects-filter-options.h:85
 msgid "args"
 msgstr "args"
 
-#: list-objects-filter-options.h:60
+#: list-objects-filter-options.h:86
 msgid "object filtering"
 msgstr "filtrage d'objet"
 
-#: parse-options.h:157
+#: parse-options.h:183
 msgid "expiry-date"
 msgstr "date-d'expiration"
 
-#: parse-options.h:172
+#: parse-options.h:197
 msgid "no-op (backward compatibility)"
 msgstr "sans action (rétrocompatibilité)"
 
-#: parse-options.h:251
+#: parse-options.h:309
 msgid "be more verbose"
 msgstr "être plus verbeux"
 
-#: parse-options.h:253
+#: parse-options.h:311
 msgid "be more quiet"
 msgstr "être plus silencieux"
 
-#: parse-options.h:259
+#: parse-options.h:317
 msgid "use <n> digits to display SHA-1s"
 msgstr "utiliser <n> chiffres pour afficher les SHA-1s"
 
+#: parse-options.h:336
+msgid "how to strip spaces and #comments from message"
+msgstr "comment éliminer les espaces et les commentaires # du message"
+
+#: parse-options.h:337
+msgid "read pathspec from file"
+msgstr "lire les spécificateurs de fichier depuis fichier"
+
+#: parse-options.h:338
+msgid ""
+"with --pathspec-from-file, pathspec elements are separated with NUL character"
+msgstr "avec --pathspec-from-file, les spécificateurs de chemin sont séparés par un caractère NUL"
+
+#: ref-filter.h:101
+msgid "key"
+msgstr "clé"
+
+#: ref-filter.h:101
+msgid "field name to sort on"
+msgstr "nom du champ servant à trier"
+
+#: rerere.h:44
+msgid "update the index with reused conflict resolution if possible"
+msgstr ""
+"met à jour l'index avec les résolutions de conflit réutilisées si possible"
+
+#: wt-status.h:67
+msgid "HEAD detached at "
+msgstr "HEAD détachée sur "
+
+#: wt-status.h:68
+msgid "HEAD detached from "
+msgstr "HEAD détachée depuis "
+
 #: command-list.h:50
 msgid "Add file contents to the index"
 msgstr "Ajouter le contenu de fichiers dans l'index"
@@ -15820,8 +22398,8 @@ msgid "Apply a patch to files and/or to
 msgstr "Appliquer une patch à des fichiers ou à l'index"
 
 #: command-list.h:54
-msgid "Import an Arch repository into Git"
-msgstr "Importer dans Git un dépôt Arch"
+msgid "Import a GNU Arch repository into Git"
+msgstr "Importer dans Git un dépôt GNU Arch"
 
 #: command-list.h:55
 msgid "Create an archive of files from a named tree"
@@ -15904,7 +22482,7 @@ msgid "Record changes to the repository"
 msgstr "Enregistrer les modifications dans le dépôt"
 
 #: command-list.h:74
-msgid "Write and verify Git commit graph files"
+msgid "Write and verify Git commit-graph files"
 msgstr "Écrire et vérifier les fichiers de graphe de commit Git"
 
 #: command-list.h:75
@@ -16068,9 +22646,9 @@ msgid "Instantly browse your working rep
 msgstr "Naviguer instantanément votre dépôt de travail dans gitweb"
 
 #: command-list.h:113
-msgid "add or parse structured information in commit messages"
+msgid "Add or parse structured information in commit messages"
 msgstr ""
-"ajouter ou analyser l'information structurée dans les messages de validation"
+"Ajouter ou analyser l'information structurée dans les messages de validation"
 
 #: command-list.h:114
 msgid "The Git repository browser"
@@ -16135,332 +22713,352 @@ msgid "Show three-way merge without touc
 msgstr "Afficher la fusion à trois points sans modifier l'index"
 
 #: command-list.h:128
+msgid "Write and verify multi-pack-indexes"
+msgstr "Écrire et vérifier les index multi-paquet"
+
+#: command-list.h:129
 msgid "Creates a tag object"
 msgstr "Créer un objet étiquette"
 
-#: command-list.h:129
+#: command-list.h:130
 msgid "Build a tree-object from ls-tree formatted text"
 msgstr "Construire un objet arbre depuis une texte formaté comme ls-tree"
 
-#: command-list.h:130
+#: command-list.h:131
 msgid "Move or rename a file, a directory, or a symlink"
 msgstr "Déplacer ou renommer un fichier, un répertoire, ou un lien symbolique"
 
-#: command-list.h:131
+#: command-list.h:132
 msgid "Find symbolic names for given revs"
 msgstr "Trouver les noms symboliques pour des révisions données"
 
-#: command-list.h:132
+#: command-list.h:133
 msgid "Add or inspect object notes"
 msgstr "Ajouter ou inspecter les notes d'un objets"
 
-#: command-list.h:133
+#: command-list.h:134
 msgid "Import from and submit to Perforce repositories"
 msgstr "Importer et soumettre à des dépôt Perforce"
 
-#: command-list.h:134
+#: command-list.h:135
 msgid "Create a packed archive of objects"
 msgstr "Créer une archive compactée d'objets"
 
-#: command-list.h:135
+#: command-list.h:136
 msgid "Find redundant pack files"
 msgstr "Trouver les fichiers pack redondants"
 
-#: command-list.h:136
+#: command-list.h:137
 msgid "Pack heads and tags for efficient repository access"
 msgstr "Empaqueter les têtes et les étiquettes pour un accès efficace au dépôt"
 
-#: command-list.h:137
+#: command-list.h:138
 msgid "Routines to help parsing remote repository access parameters"
 msgstr ""
 "Routines pour aider à analyser les paramètres d'accès aux dépôts distants"
 
-#: command-list.h:138
+#: command-list.h:139
 msgid "Compute unique ID for a patch"
 msgstr "Calculer l'ID unique d'un patch"
 
-#: command-list.h:139
+#: command-list.h:140
 msgid "Prune all unreachable objects from the object database"
 msgstr ""
 "Éliminer les objets inatteignables depuis la base de données des objets"
 
-#: command-list.h:140
+#: command-list.h:141
 msgid "Remove extra objects that are already in pack files"
 msgstr "Éliminer les objets qui sont déjà présents dans les fichiers pack"
 
-#: command-list.h:141
+#: command-list.h:142
 msgid "Fetch from and integrate with another repository or a local branch"
 msgstr "Rapatrier et intégrer un autre dépôt ou une branche locale"
 
-#: command-list.h:142
+#: command-list.h:143
 msgid "Update remote refs along with associated objects"
 msgstr "Mettre à jour les références distantes ainsi que les objets associés"
 
-#: command-list.h:143
+#: command-list.h:144
 msgid "Applies a quilt patchset onto the current branch"
 msgstr "Appliquer un patchset quilt sur la branche courante"
 
-#: command-list.h:144
+#: command-list.h:145
+msgid "Compare two commit ranges (e.g. two versions of a branch)"
+msgstr ""
+"Comparer deux plages de commits (par exemple deux versions d'une branche)"
+
+#: command-list.h:146
 msgid "Reads tree information into the index"
 msgstr "Lire l'information d'arbre dans l'index"
 
-#: command-list.h:145
+#: command-list.h:147
 msgid "Reapply commits on top of another base tip"
 msgstr "Réapplication des commits sur le sommet de l'autre base"
 
-#: command-list.h:146
+#: command-list.h:148
 msgid "Receive what is pushed into the repository"
 msgstr "Recevoir ce qui est poussé dans le dépôt"
 
-#: command-list.h:147
+#: command-list.h:149
 msgid "Manage reflog information"
 msgstr "Gérer l'information de reflog"
 
-#: command-list.h:148
+#: command-list.h:150
 msgid "Manage set of tracked repositories"
 msgstr "Gérer un ensemble de dépôts suivis"
 
-#: command-list.h:149
+#: command-list.h:151
 msgid "Pack unpacked objects in a repository"
 msgstr "Empaqueter les objets non-empaquetés d'un dépôt"
 
-#: command-list.h:150
+#: command-list.h:152
 msgid "Create, list, delete refs to replace objects"
 msgstr "Créer, lister, supprimer des référence pour remplacer des objets"
 
-#: command-list.h:151
+#: command-list.h:153
 msgid "Generates a summary of pending changes"
 msgstr "Générer une résumé des modifications en attentes"
 
-#: command-list.h:152
+#: command-list.h:154
 msgid "Reuse recorded resolution of conflicted merges"
 msgstr "Réutiliser une résolution enregistrée de fusions conflictuelles"
 
-#: command-list.h:153
+#: command-list.h:155
 msgid "Reset current HEAD to the specified state"
 msgstr "Réinitialiser la HEAD courante à l'état spécifié"
 
-#: command-list.h:154
+#: command-list.h:156
+msgid "Restore working tree files"
+msgstr "restaurer les fichiers l'arbre de travail"
+
+#: command-list.h:157
 msgid "Revert some existing commits"
 msgstr "Inverser des commits existants"
 
-#: command-list.h:155
+#: command-list.h:158
 msgid "Lists commit objects in reverse chronological order"
 msgstr "Afficher les objets commit dans l'ordre chronologique inverse"
 
-#: command-list.h:156
+#: command-list.h:159
 msgid "Pick out and massage parameters"
 msgstr "Analyser et préparer les paramètres"
 
-#: command-list.h:157
+#: command-list.h:160
 msgid "Remove files from the working tree and from the index"
 msgstr "Supprimer des fichiers de la copie de travail et de l'index"
 
-#: command-list.h:158
+#: command-list.h:161
 msgid "Send a collection of patches as emails"
 msgstr "Envoyer un ensemble de patchs comme courriels"
 
-#: command-list.h:159
+#: command-list.h:162
 msgid "Push objects over Git protocol to another repository"
 msgstr "Pousser les objets sur un autre dépôt via le protocole Git"
 
-#: command-list.h:160
+#: command-list.h:163
 msgid "Restricted login shell for Git-only SSH access"
 msgstr "shell de login restreint pour un accès SSH vers Git seulement"
 
-#: command-list.h:161
+#: command-list.h:164
 msgid "Summarize 'git log' output"
 msgstr "Résumer la sortie de 'git log'"
 
-#: command-list.h:162
+#: command-list.h:165
 msgid "Show various types of objects"
 msgstr "Afficher différents types d'objets"
 
-#: command-list.h:163
+#: command-list.h:166
 msgid "Show branches and their commits"
 msgstr "Afficher les branches et leurs commits"
 
-#: command-list.h:164
+#: command-list.h:167
 msgid "Show packed archive index"
 msgstr "Afficher l'index de l'archive empaquetée"
 
-#: command-list.h:165
+#: command-list.h:168
 msgid "List references in a local repository"
 msgstr "Lister les références du dépôt local"
 
-#: command-list.h:166
+#: command-list.h:169
 msgid "Git's i18n setup code for shell scripts"
 msgstr "Le code d'initialisation i18n pour les scripts shell"
 
-#: command-list.h:167
+#: command-list.h:170
 msgid "Common Git shell script setup code"
 msgstr "Le code d'initialisation commun aux scripts shell Git"
 
-#: command-list.h:168
+#: command-list.h:171
+msgid "Initialize and modify the sparse-checkout"
+msgstr "Initialiser et modifier l'extraction partielle"
+
+#: command-list.h:172
 msgid "Stash the changes in a dirty working directory away"
 msgstr "Remiser les modifications d'un répertoire de travail sale"
 
-#: command-list.h:169
+#: command-list.h:173
 msgid "Add file contents to the staging area"
 msgstr "Ajouter le contenu de fichiers à l'index"
 
-#: command-list.h:170
+#: command-list.h:174
 msgid "Show the working tree status"
 msgstr "Afficher l'état de la copie de travail"
 
-#: command-list.h:171
+#: command-list.h:175
 msgid "Remove unnecessary whitespace"
 msgstr "Retirer les espaces inutiles"
 
-#: command-list.h:172
+#: command-list.h:176
 msgid "Initialize, update or inspect submodules"
 msgstr "Initialiser, mettre à jour et inspecter les sous-modules"
 
-#: command-list.h:173
+#: command-list.h:177
 msgid "Bidirectional operation between a Subversion repository and Git"
 msgstr "Opération Bidirectionnelles entre un dépôt Subversion et Git"
 
-#: command-list.h:174
+#: command-list.h:178
+msgid "Switch branches"
+msgstr "Basculer de branche"
+
+#: command-list.h:179
 msgid "Read, modify and delete symbolic refs"
 msgstr "Lire, modifier et supprimer les références symboliques"
 
-#: command-list.h:175
+#: command-list.h:180
 msgid "Create, list, delete or verify a tag object signed with GPG"
 msgstr ""
 "Créer, lister, supprimer ou vérifier un objet d'étiquette signé avec GPG"
 
-#: command-list.h:176
+#: command-list.h:181
 msgid "Creates a temporary file with a blob's contents"
 msgstr "Créer un fichier temporaire avec le contenu d'un blob"
 
-#: command-list.h:177
+#: command-list.h:182
 msgid "Unpack objects from a packed archive"
 msgstr "Dépaqueter les objets depuis une archive empaquetée"
 
-#: command-list.h:178
+#: command-list.h:183
 msgid "Register file contents in the working tree to the index"
 msgstr "Enregistrer le contenu d'un fichier de l'arbre de travail dans l'index"
 
-#: command-list.h:179
+#: command-list.h:184
 msgid "Update the object name stored in a ref safely"
 msgstr ""
 "Mettre à jour le nom d'objet stocké dans une référence en toute sécurité"
 
-#: command-list.h:180
+#: command-list.h:185
 msgid "Update auxiliary info file to help dumb servers"
 msgstr ""
 "Mettre à jour le fichier d'informations auxiliaires pour aider les serveurs "
 "idiots"
 
-#: command-list.h:181
+#: command-list.h:186
 msgid "Send archive back to git-archive"
 msgstr "Renvoyer une archive dans git-archive"
 
-#: command-list.h:182
+#: command-list.h:187
 msgid "Send objects packed back to git-fetch-pack"
 msgstr "Renvoyer des objets empaquetés dans git-fetch-pack"
 
-#: command-list.h:183
+#: command-list.h:188
 msgid "Show a Git logical variable"
 msgstr "Afficher un variable logique de Git"
 
-#: command-list.h:184
+#: command-list.h:189
 msgid "Check the GPG signature of commits"
 msgstr "Vérifier la signature GPG de commits"
 
-#: command-list.h:185
+#: command-list.h:190
 msgid "Validate packed Git archive files"
 msgstr "Valider des fichiers d'archive Git empaquetés"
 
-#: command-list.h:186
+#: command-list.h:191
 msgid "Check the GPG signature of tags"
 msgstr "Vérifier la signature GPG d'étiquettes"
 
-#: command-list.h:187
+#: command-list.h:192
 msgid "Git web interface (web frontend to Git repositories)"
 msgstr "Interface web de Git"
 
-#: command-list.h:188
+#: command-list.h:193
 msgid "Show logs with difference each commit introduces"
 msgstr "Afficher les journaux avec la différence que chaque commit introduit"
 
-#: command-list.h:189
+#: command-list.h:194
 msgid "Manage multiple working trees"
 msgstr "Gère de arbres de travail multiples"
 
-#: command-list.h:190
+#: command-list.h:195
 msgid "Create a tree object from the current index"
 msgstr "Créer un objet arbre depuis l'index courant"
 
-#: command-list.h:191
+#: command-list.h:196
 msgid "Defining attributes per path"
 msgstr "Définition des attributs par chemin"
 
-#: command-list.h:192
+#: command-list.h:197
 msgid "Git command-line interface and conventions"
 msgstr "interface en ligne de commande et conventions de Git"
 
-#: command-list.h:193
+#: command-list.h:198
 msgid "A Git core tutorial for developers"
 msgstr "Tutoriel du cœur de Git pour les développeurs"
 
-#: command-list.h:194
+#: command-list.h:199
 msgid "Git for CVS users"
 msgstr "Git pour les utilisateurs de CVS"
 
-#: command-list.h:195
+#: command-list.h:200
 msgid "Tweaking diff output"
 msgstr "Bidouillage de la sortie diff"
 
-#: command-list.h:196
+#: command-list.h:201
 msgid "A useful minimum set of commands for Everyday Git"
 msgstr "Un ensemble minimal utile des commandes de Git pour tous les jours"
 
-#: command-list.h:197
+#: command-list.h:202
 msgid "A Git Glossary"
 msgstr "Un glossaire Git"
 
-#: command-list.h:198
+#: command-list.h:203
 msgid "Hooks used by Git"
 msgstr "Crochets utilisés par Git"
 
-#: command-list.h:199
+#: command-list.h:204
 msgid "Specifies intentionally untracked files to ignore"
 msgstr "Spécifie les fichiers non-suivis à ignorer intentionnellement"
 
-#: command-list.h:200
+#: command-list.h:205
 msgid "Defining submodule properties"
 msgstr "Définition des propriétés de sous-module"
 
-#: command-list.h:201
+#: command-list.h:206
 msgid "Git namespaces"
 msgstr "Espaces de nom de Git"
 
-#: command-list.h:202
+#: command-list.h:207
 msgid "Git Repository Layout"
 msgstr "Disposition d'un dépôt Git"
 
-#: command-list.h:203
+#: command-list.h:208
 msgid "Specifying revisions and ranges for Git"
 msgstr "Spécification des révisions et portées pour Git"
 
-#: command-list.h:204
+#: command-list.h:209
+msgid "Mounting one repository inside another"
+msgstr "Montage d'un dépôt dans un autre dépôt"
+
+#: command-list.h:210
 msgid "A tutorial introduction to Git: part two"
 msgstr "Une introduction pratique à Git : deuxième partie"
 
-#: command-list.h:205
+#: command-list.h:211
 msgid "A tutorial introduction to Git"
 msgstr "Une introduction pratique à Git"
 
-#: command-list.h:206
+#: command-list.h:212
 msgid "An overview of recommended workflows with Git"
 msgstr "Un aperçu des flux de travail recommandés avec Git"
 
-#: rerere.h:40
-msgid "update the index with reused conflict resolution if possible"
-msgstr ""
-"met à jour l'index avec les résolutions de conflit réutilisées si possible"
-
 #: git-bisect.sh:54
 msgid "You need to start by \"git bisect start\""
 msgstr "Vous devez démarrer avec \"git bisect start\""
@@ -16472,138 +23070,49 @@ msgstr "Vous devez démarrer avec \"git
 msgid "Do you want me to do it for you [Y/n]? "
 msgstr "Souhaitez-vous que je le fasse pour vous [Y/n] ? "
 
-#: git-bisect.sh:121
-#, sh-format
-msgid "unrecognised option: '$arg'"
-msgstr "option inconnue : '$arg'"
-
-#: git-bisect.sh:125
-#, sh-format
-msgid "'$arg' does not appear to be a valid revision"
-msgstr "'$arg' ne semble être une révision valide"
-
-#: git-bisect.sh:154
-msgid "Bad HEAD - I need a HEAD"
-msgstr "Mauvaise HEAD - j'ai besoin d'une HEAD"
-
-#: git-bisect.sh:167
-#, sh-format
-msgid ""
-"Checking out '$start_head' failed. Try 'git bisect reset <valid-branch>'."
-msgstr ""
-"L'extraction de '$start_head' a échoué. Essayez 'git bisect reset <branche-"
-"valide>'."
-
-#: git-bisect.sh:177
-msgid "won't bisect on cg-seek'ed tree"
-msgstr "refus de bissecter sur un arbre 'cg-seeked'"
-
-#: git-bisect.sh:181
-msgid "Bad HEAD - strange symbolic ref"
-msgstr "Mauvaise HEAD - référence symbolique douteuse"
-
-#: git-bisect.sh:233
-#, sh-format
-msgid "Bad bisect_write argument: $state"
-msgstr "Mauvais argument pour bisect_write : $state"
-
-#: git-bisect.sh:246
+#: git-bisect.sh:101
 #, sh-format
 msgid "Bad rev input: $arg"
 msgstr "Mauvaise révision en entrée : $arg"
 
-#: git-bisect.sh:265
+#: git-bisect.sh:121
 #, sh-format
 msgid "Bad rev input: $bisected_head"
 msgstr "Mauvaise révision en entrée : $bisected_head"
 
-#: git-bisect.sh:274
+#: git-bisect.sh:130
 #, sh-format
 msgid "Bad rev input: $rev"
 msgstr "Mauvaise révision en entrée : $rev"
 
-#: git-bisect.sh:283
+#: git-bisect.sh:139
 #, sh-format
 msgid "'git bisect $TERM_BAD' can take only one argument."
 msgstr "'git bisect $TERM_BAD' n'accepte qu'un seul argument."
 
-#: git-bisect.sh:306
-#, sh-format
-msgid "Warning: bisecting only with a $TERM_BAD commit."
-msgstr "Attention : bissection avec seulement une validation $TERM_BAD."
-
-#. TRANSLATORS: Make sure to include [Y] and [n] in your
-#. translation. The program will only accept English input
-#. at this point.
-#: git-bisect.sh:312
-msgid "Are you sure [Y/n]? "
-msgstr "Confirmez-vous [Y/n] ? "
-
-#: git-bisect.sh:324
-#, sh-format
-msgid ""
-"You need to give me at least one $bad_syn and one $good_syn revision.\n"
-"(You can use \"git bisect $bad_syn\" and \"git bisect $good_syn\" for that.)"
-msgstr ""
-"Vous devez me donner au moins une révision $bad_syn et une révision "
-"$good_syn.\n"
-"(Vous pouvez utiliser \"git bisect $bad_syn\" et \"git bisect $good_syn\" "
-"pour cela.)"
-
-#: git-bisect.sh:327
-#, sh-format
-msgid ""
-"You need to start by \"git bisect start\".\n"
-"You then need to give me at least one $good_syn and one $bad_syn revision.\n"
-"(You can use \"git bisect $bad_syn\" and \"git bisect $good_syn\" for that.)"
-msgstr ""
-"Vous devez démarrer avec \"git bisect start\".\n"
-"Puis vous devez me donner au moins une révision $good_syn et une révision "
-"$bad_syn.\n"
-"(Vous pouvez utiliser \"git bisect $bad_syn\" et \"git bisect $good_syn\" "
-"pour cela.)"
-
-#: git-bisect.sh:398 git-bisect.sh:512
-msgid "We are not bisecting."
-msgstr "Pas de bissection en cours."
-
-#: git-bisect.sh:405
-#, sh-format
-msgid "'$invalid' is not a valid commit"
-msgstr "'$invalid' n'est pas une validation valide"
-
-#: git-bisect.sh:414
-#, sh-format
-msgid ""
-"Could not check out original HEAD '$branch'.\n"
-"Try 'git bisect reset <commit>'."
-msgstr ""
-"Échec d'extraction de la HEAD d'origine '$branch'.\n"
-"Essayez 'git bisect reset <commit>'."
-
-#: git-bisect.sh:422
+#: git-bisect.sh:209
 msgid "No logfile given"
 msgstr "Pas de fichier de log donné"
 
-#: git-bisect.sh:423
+#: git-bisect.sh:210
 #, sh-format
 msgid "cannot read $file for replaying"
 msgstr "impossible de lire $file pour rejouer"
 
-#: git-bisect.sh:444
+#: git-bisect.sh:232
 msgid "?? what are you talking about?"
 msgstr "?? de quoi parlez-vous ?"
 
-#: git-bisect.sh:453
+#: git-bisect.sh:241
 msgid "bisect run failed: no command provided."
 msgstr "la bissection a échoué : aucune commande fournie."
 
-#: git-bisect.sh:458
+#: git-bisect.sh:246
 #, sh-format
 msgid "running $command"
 msgstr "lancement de $command"
 
-#: git-bisect.sh:465
+#: git-bisect.sh:253
 #, sh-format
 msgid ""
 "bisect run failed:\n"
@@ -16612,11 +23121,11 @@ msgstr ""
 "la bissection a échoué :\n"
 "le code retour $res de '$command' est < 0 ou >= 128"
 
-#: git-bisect.sh:491
+#: git-bisect.sh:279
 msgid "bisect run cannot continue any more"
 msgstr "la bissection ne peut plus continuer"
 
-#: git-bisect.sh:497
+#: git-bisect.sh:285
 #, sh-format
 msgid ""
 "bisect run failed:\n"
@@ -16625,30 +23134,13 @@ msgstr ""
 "la bissection a échoué :\n"
 "'bisect_state $state' a retourné le code erreur $res"
 
-#: git-bisect.sh:504
+#: git-bisect.sh:292
 msgid "bisect run success"
 msgstr "succès de la bissection"
 
-#: git-bisect.sh:533
-#, sh-format
-msgid "Invalid command: you're currently in a $TERM_BAD/$TERM_GOOD bisect."
-msgstr ""
-"Commande invalide : vous êtes actuellement dans une bissection $TERM_BAD/"
-"$TERM_GOOD."
-
-#: git-bisect.sh:567
-msgid "no terms defined"
-msgstr "aucun terme défini"
-
-#: git-bisect.sh:584
-#, sh-format
-msgid ""
-"invalid argument $arg for 'git bisect terms'.\n"
-"Supported options are: --term-good|--term-old and --term-bad|--term-new."
-msgstr ""
-"argument invalide $arg pour 'git bisect terms'.\n"
-"Les options supportées sont : --term-good|--term-old et --term-bad|--term-"
-"new."
+#: git-bisect.sh:300
+msgid "We are not bisecting."
+msgstr "Pas de bissection en cours."
 
 #: git-merge-octopus.sh:46
 msgid ""
@@ -16664,361 +23156,142 @@ msgstr "La fusion automatique a échoué
 
 #: git-merge-octopus.sh:62
 msgid "Should not be doing an octopus."
-msgstr "L'Octopus ne devrait pas arriver."
-
-#: git-merge-octopus.sh:73
-#, sh-format
-msgid "Unable to find common commit with $pretty_name"
-msgstr "Impossible de trouver un commit commun avec $pretty_name"
-
-#: git-merge-octopus.sh:77
-#, sh-format
-msgid "Already up to date with $pretty_name"
-msgstr "Déjà à jour avec $pretty_name"
-
-#: git-merge-octopus.sh:89
-#, sh-format
-msgid "Fast-forwarding to: $pretty_name"
-msgstr "Mise à jour en avance rapide sur $pretty_name"
-
-#: git-merge-octopus.sh:97
-#, sh-format
-msgid "Trying simple merge with $pretty_name"
-msgstr "Essai de fusion simple avec $pretty_name"
-
-#: git-merge-octopus.sh:102
-msgid "Simple merge did not work, trying automatic merge."
-msgstr "La fusion simple a échoué, essai avec la fusion automatique."
-
-#: git-rebase.sh:61
-msgid ""
-"Resolve all conflicts manually, mark them as resolved with\n"
-"\"git add/rm <conflicted_files>\", then run \"git rebase --continue\".\n"
-"You can instead skip this commit: run \"git rebase --skip\".\n"
-"To abort and get back to the state before \"git rebase\", run \"git rebase --"
-"abort\"."
-msgstr ""
-"Résolvez tous les conflits manuellement, marquez-les comme résolus avec\n"
-"\"git add/rm <fichier en conflit>\", puis lancez \"git rebase --continue\".\n"
-"Si vous préférez sauter ce commit, lancez \"git rebase --skip\". Pour "
-"arrêter\n"
-"et revenir à l'état antérieur à la commande, lancez \"git rebase --abort\"."
-
-#: git-rebase.sh:173 git-rebase.sh:442
-#, sh-format
-msgid "Could not move back to $head_name"
-msgstr "Impossible de revenir à $head_name"
-
-#: git-rebase.sh:184
-msgid "Applied autostash."
-msgstr "Autoremisage appliqué."
-
-#: git-rebase.sh:187
-#, sh-format
-msgid "Cannot store $stash_sha1"
-msgstr "Impossible de stocker $stash_sha1"
-
-#: git-rebase.sh:229
-msgid "The pre-rebase hook refused to rebase."
-msgstr "Le crochet pre-rebase a refusé de rebaser."
-
-#: git-rebase.sh:234
-msgid "It looks like 'git am' is in progress. Cannot rebase."
-msgstr "Il semble que 'git-am' soit en cours. Impossible de rebaser."
-
-#: git-rebase.sh:403
-msgid "No rebase in progress?"
-msgstr "Pas de rebasage en cours ?"
-
-#: git-rebase.sh:414
-msgid "The --edit-todo action can only be used during interactive rebase."
-msgstr ""
-"L'action --edit-todo peut seulement être utilisée lors d'un rebasage "
-"interactif."
-
-#: git-rebase.sh:421
-msgid "Cannot read HEAD"
-msgstr "Impossible de lire HEAD"
-
-#: git-rebase.sh:424
-msgid ""
-"You must edit all merge conflicts and then\n"
-"mark them as resolved using git add"
-msgstr ""
-"Vous devez éditer tous les conflits de fusion et\n"
-"les marquer comme résolus avec git add"
-
-#: git-rebase.sh:468
-#, sh-format
-msgid ""
-"It seems that there is already a $state_dir_base directory, and\n"
-"I wonder if you are in the middle of another rebase.  If that is the\n"
-"case, please try\n"
-"\t$cmd_live_rebase\n"
-"If that is not the case, please\n"
-"\t$cmd_clear_stale_rebase\n"
-"and run me again.  I am stopping in case you still have something\n"
-"valuable there."
-msgstr ""
-"Il semble qu'il y ait déjà un répertoire $state_dir_base, et je me demande\n"
-"si un autre rebasage n'est pas déjà en cours. Si c'est le cas,\n"
-"essayez\n"
-"\t$cmd_live_rebase\n"
-"Sinon, essayez\n"
-"\t$cmd_clear_stale_rebase\n"
-"puis relancez-moi à nouveau.  Je m'arrête au cas où vous auriez quelque "
-"chose\n"
-"d'important ici."
-
-#: git-rebase.sh:509
-msgid "error: cannot combine '--signoff' with '--preserve-merges'"
-msgstr "erreur : '--signoff' et '--preserve-merges' sont incompatibles"
-
-#: git-rebase.sh:537
-#, sh-format
-msgid "invalid upstream '$upstream_name'"
-msgstr "invalide '$upstream_name' en amont"
-
-#: git-rebase.sh:561
-#, sh-format
-msgid "$onto_name: there are more than one merge bases"
-msgstr "$onto_name : il y a plus d'une base de fusion"
-
-#: git-rebase.sh:564 git-rebase.sh:568
-#, sh-format
-msgid "$onto_name: there is no merge base"
-msgstr "$onto_name : il n'y a pas de base de fusion"
-
-#: git-rebase.sh:573
-#, sh-format
-msgid "Does not point to a valid commit: $onto_name"
-msgstr "Ne pointe pas sur une validation valide : $onto_name"
-
-#: git-rebase.sh:599
-#, sh-format
-msgid "fatal: no such branch/commit '$branch_name'"
-msgstr "fatal : pas de branche ou commit '$branch_name'"
-
-#: git-rebase.sh:632
-msgid "Cannot autostash"
-msgstr "Autoremisage impossible"
-
-#: git-rebase.sh:637
-#, sh-format
-msgid "Created autostash: $stash_abbrev"
-msgstr "Autoremisage créé : $stash_abbrev"
-
-#: git-rebase.sh:641
-msgid "Please commit or stash them."
-msgstr "Veuillez les valider ou les remiser."
-
-#: git-rebase.sh:664
-#, sh-format
-msgid "HEAD is up to date."
-msgstr "HEAD est à jour."
-
-#: git-rebase.sh:666
-#, sh-format
-msgid "Current branch $branch_name is up to date."
-msgstr "La branche courante $branch_name est à jour."
+msgstr "L'Octopus ne devrait pas arriver."
 
-#: git-rebase.sh:674
+#: git-merge-octopus.sh:73
 #, sh-format
-msgid "HEAD is up to date, rebase forced."
-msgstr "HEAD est à jour, rebasage forcé."
+msgid "Unable to find common commit with $pretty_name"
+msgstr "Impossible de trouver un commit commun avec $pretty_name"
 
-#: git-rebase.sh:676
+#: git-merge-octopus.sh:77
 #, sh-format
-msgid "Current branch $branch_name is up to date, rebase forced."
-msgstr "La branche courante $branch_name est à jour, rebasage forcé."
+msgid "Already up to date with $pretty_name"
+msgstr "Déjà à jour avec $pretty_name"
 
-#: git-rebase.sh:688
+#: git-merge-octopus.sh:89
 #, sh-format
-msgid "Changes from $mb to $onto:"
-msgstr "Changements de $mb sur $onto :"
-
-#: git-rebase.sh:697
-msgid "First, rewinding head to replay your work on top of it..."
-msgstr ""
-"Rembobinage préalable de head pour pouvoir rejouer votre travail par-"
-"dessus..."
+msgid "Fast-forwarding to: $pretty_name"
+msgstr "Mise à jour en avance rapide sur $pretty_name"
 
-#: git-rebase.sh:707
+#: git-merge-octopus.sh:97
 #, sh-format
-msgid "Fast-forwarded $branch_name to $onto_name."
-msgstr "$branch_name mise à jour en avance rapide sur $onto_name."
-
-#: git-stash.sh:61
-msgid "git stash clear with parameters is unimplemented"
-msgstr "git stash clear avec des paramètres n'est pas implémenté"
-
-#: git-stash.sh:108
-msgid "You do not have the initial commit yet"
-msgstr "Vous n'avez pas encore la validation initiale"
-
-#: git-stash.sh:123
-msgid "Cannot save the current index state"
-msgstr "Impossible de sauver l'état courant de l'index"
-
-#: git-stash.sh:138
-msgid "Cannot save the untracked files"
-msgstr "Impossible de sauver les fichiers non-suivis"
-
-#: git-stash.sh:158 git-stash.sh:171
-msgid "Cannot save the current worktree state"
-msgstr "Impossible de sauver l'état courant de la copie de travail"
+msgid "Trying simple merge with $pretty_name"
+msgstr "Essai de fusion simple avec $pretty_name"
 
-#: git-stash.sh:175
-msgid "No changes selected"
-msgstr "Aucun changement sélectionné"
+#: git-merge-octopus.sh:102
+msgid "Simple merge did not work, trying automatic merge."
+msgstr "La fusion simple a échoué, essai avec la fusion automatique."
 
-#: git-stash.sh:178
+#: git-legacy-stash.sh:221
 msgid "Cannot remove temporary index (can't happen)"
 msgstr "Impossible de supprimer l'index temporaire (ne peut pas se produire)"
 
-#: git-stash.sh:191
-msgid "Cannot record working tree state"
-msgstr "Impossible d'enregistrer l'état de la copie de travail"
-
-#: git-stash.sh:229
+#: git-legacy-stash.sh:272
 #, sh-format
 msgid "Cannot update $ref_stash with $w_commit"
 msgstr "Impossible de mettre à jour $ref_stash avec $w_commit"
 
-#: git-stash.sh:281
+#: git-legacy-stash.sh:324
 #, sh-format
 msgid "error: unknown option for 'stash push': $option"
 msgstr "erreur : option inconnue pour 'stash push' : $option"
 
-#: git-stash.sh:295
-msgid "Can't use --patch and --include-untracked or --all at the same time"
-msgstr ""
-"Impossible d'utiliser --patch et --include-untracked ou --all en même temps"
-
-#: git-stash.sh:303
-msgid "No local changes to save"
-msgstr "Pas de modifications locales à sauver"
-
-#: git-stash.sh:308
-msgid "Cannot initialize stash"
-msgstr "Impossible d'initialiser le remisage"
-
-#: git-stash.sh:312
-msgid "Cannot save the current status"
-msgstr "Impossible de sauver l'état courant"
-
-#: git-stash.sh:313
+#: git-legacy-stash.sh:356
 #, sh-format
 msgid "Saved working directory and index state $stash_msg"
 msgstr "Copie de travail et état de l'index sauvegardés dans $stash_msg"
 
-#: git-stash.sh:342
-msgid "Cannot remove worktree changes"
-msgstr "Impossible de supprimer les changements de la copie de travail"
-
-#: git-stash.sh:490
+#: git-legacy-stash.sh:536
 #, sh-format
 msgid "unknown option: $opt"
 msgstr "option inconnue : $opt"
 
-#: git-stash.sh:503
-msgid "No stash entries found."
-msgstr "Aucune entrée de remisage trouvée."
-
-#: git-stash.sh:510
+#: git-legacy-stash.sh:556
 #, sh-format
 msgid "Too many revisions specified: $REV"
 msgstr "Trop de révisions spécifiées : $REV"
 
-#: git-stash.sh:525
+#: git-legacy-stash.sh:571
 #, sh-format
 msgid "$reference is not a valid reference"
 msgstr "$reference n'est pas une référence valide"
 
-#: git-stash.sh:553
+#: git-legacy-stash.sh:599
 #, sh-format
 msgid "'$args' is not a stash-like commit"
 msgstr "'$args' n'est pas une validation de type remisage"
 
-#: git-stash.sh:564
+#: git-legacy-stash.sh:610
 #, sh-format
 msgid "'$args' is not a stash reference"
 msgstr "'$args' n'est pas une référence de remisage"
 
-#: git-stash.sh:572
+#: git-legacy-stash.sh:618
 msgid "unable to refresh index"
 msgstr "impossible de rafraîchir l'index"
 
-#: git-stash.sh:576
+#: git-legacy-stash.sh:622
 msgid "Cannot apply a stash in the middle of a merge"
 msgstr "Impossible d'appliquer un remisage en cours de fusion"
 
-#: git-stash.sh:584
+#: git-legacy-stash.sh:630
 msgid "Conflicts in index. Try without --index."
 msgstr "Conflits dans l'index. Essayez sans --index."
 
-#: git-stash.sh:586
+#: git-legacy-stash.sh:632
 msgid "Could not save index tree"
 msgstr "Impossible de sauvegarder l'arbre d'index"
 
-#: git-stash.sh:595
+#: git-legacy-stash.sh:641
 msgid "Could not restore untracked files from stash entry"
 msgstr ""
 "Impossible de restaurer les fichiers non-suivis depuis l'entrée de remisage"
 
-#: git-stash.sh:620
+#: git-legacy-stash.sh:666
 msgid "Cannot unstage modified files"
 msgstr "Impossible de désindexer les fichiers modifiés"
 
-#: git-stash.sh:635
-msgid "Index was not unstashed."
-msgstr "L'index n'a pas été sorti de remise."
-
-#: git-stash.sh:649
-msgid "The stash entry is kept in case you need it again."
-msgstr ""
-"L'entrée de remisage est conservée au cas où vous en auriez encore besoin."
-
-#: git-stash.sh:658
+#: git-legacy-stash.sh:704
 #, sh-format
 msgid "Dropped ${REV} ($s)"
 msgstr "${REV} supprimé ($s)"
 
-#: git-stash.sh:659
+#: git-legacy-stash.sh:705
 #, sh-format
 msgid "${REV}: Could not drop stash entry"
-msgstr "${REV}: Impossible de supprimer l'élément de stash"
-
-#: git-stash.sh:667
-msgid "No branch name specified"
-msgstr "Aucune branche spécifiée"
+msgstr "${REV}: Impossible de supprimer l'entrée de stash"
 
-#: git-stash.sh:746
+#: git-legacy-stash.sh:792
 msgid "(To restore them type \"git stash apply\")"
 msgstr "(Pour les restaurer tapez \"git stash apply\")"
 
-#: git-submodule.sh:188
+#: git-submodule.sh:202
 msgid "Relative path can only be used from the toplevel of the working tree"
 msgstr ""
 "Un chemin relatif ne peut être utilisé que depuis la racine de la copie de "
 "travail"
 
-#: git-submodule.sh:198
+#: git-submodule.sh:212
 #, sh-format
 msgid "repo URL: '$repo' must be absolute or begin with ./|../"
 msgstr "L'URL de dépôt '$repo' doit être absolu ou commencer par ./|../"
 
-#: git-submodule.sh:217
+#: git-submodule.sh:231
 #, sh-format
 msgid "'$sm_path' already exists in the index"
 msgstr "'$sm_path' existe déjà dans l'index"
 
-#: git-submodule.sh:220
+#: git-submodule.sh:234
 #, sh-format
 msgid "'$sm_path' already exists in the index and is not a submodule"
 msgstr "'$sm_path' existe déjà dans l'index et n'est pas un sous-module"
 
-#: git-submodule.sh:226
+#: git-submodule.sh:241
+#, sh-format
+msgid "'$sm_path' does not have a commit checked out"
+msgstr "'$sm_path' n'a pas de commit extrait"
+
+#: git-submodule.sh:247
 #, sh-format
 msgid ""
 "The following path is ignored by one of your .gitignore files:\n"
@@ -17029,24 +23302,24 @@ msgstr ""
 "$sm_path\n"
 "Utilisez -f si vous voulez vraiment l'ajouter."
 
-#: git-submodule.sh:249
+#: git-submodule.sh:270
 #, sh-format
 msgid "Adding existing repo at '$sm_path' to the index"
 msgstr "Ajout du dépôt existant à '$sm_path' dans l'index"
 
-#: git-submodule.sh:251
+#: git-submodule.sh:272
 #, sh-format
 msgid "'$sm_path' already exists and is not a valid git repo"
 msgstr "'$sm_path' existe déjà et n'est pas un dépôt git valide"
 
-#: git-submodule.sh:259
+#: git-submodule.sh:280
 #, sh-format
 msgid "A git directory for '$sm_name' is found locally with remote(s):"
 msgstr ""
 "Un répertoire git pour '$sm_name' est trouvé en local avec le(s) serveur(s) "
 "distant(s) :"
 
-#: git-submodule.sh:261
+#: git-submodule.sh:282
 #, sh-format
 msgid ""
 "If you want to reuse this local git directory instead of cloning again from\n"
@@ -17063,49 +23336,39 @@ msgstr ""
 "correct\n"
 "ou si ceci n'est pas clair, choisissez un autre nom avec l'option '--name'."
 
-#: git-submodule.sh:267
+#: git-submodule.sh:288
 #, sh-format
 msgid "Reactivating local git directory for submodule '$sm_name'."
 msgstr "Réactivation du répertoire git local pour le sous-module '$sm_name'."
 
-#: git-submodule.sh:279
+#: git-submodule.sh:300
 #, sh-format
 msgid "Unable to checkout submodule '$sm_path'"
 msgstr "Impossible d'extraire le sous-module '$sm_path'"
 
-#: git-submodule.sh:284
+#: git-submodule.sh:305
 #, sh-format
 msgid "Failed to add submodule '$sm_path'"
 msgstr "Échec d'ajout du sous-module '$sm_path'"
 
-#: git-submodule.sh:293
+#: git-submodule.sh:314
 #, sh-format
 msgid "Failed to register submodule '$sm_path'"
 msgstr "Échec d'enregistrement du sous-module '$sm_path'"
 
-#: git-submodule.sh:354
-#, sh-format
-msgid "Entering '$displaypath'"
-msgstr "Entrée dans '$displaypath'"
-
-#: git-submodule.sh:374
-#, sh-format
-msgid "Stopping at '$displaypath'; script returned non-zero status."
-msgstr "Arrêt sur '$displaypath' ; le script a retourné un état non nul."
-
-#: git-submodule.sh:600
+#: git-submodule.sh:580
 #, sh-format
 msgid "Unable to find current revision in submodule path '$displaypath'"
 msgstr ""
 "Impossible de trouver la révision courante dans le chemin de sous-module "
 "'$displaypath'"
 
-#: git-submodule.sh:610
+#: git-submodule.sh:590
 #, sh-format
 msgid "Unable to fetch in submodule path '$sm_path'"
 msgstr "Impossible de rapatrier dans le chemin de sous-module '$sm_path'"
 
-#: git-submodule.sh:615
+#: git-submodule.sh:595
 #, sh-format
 msgid ""
 "Unable to find current ${remote_name}/${branch} revision in submodule path "
@@ -17114,12 +23377,16 @@ msgstr ""
 "Impossible de trouver la révision courante ${remote_name}/${branch} dans le "
 "chemin de sous-module '$sm_path'"
 
-#: git-submodule.sh:633
+#: git-submodule.sh:613
 #, sh-format
-msgid "Unable to fetch in submodule path '$displaypath'"
-msgstr "Impossible de rapatrier dans le chemin de sous-module '$displaypath'"
+msgid ""
+"Unable to fetch in submodule path '$displaypath'; trying to directly fetch "
+"$sha1:"
+msgstr ""
+"Impossible de rapatrier dans le chemin de sous-module '$displaypath' ; essai "
+"de rapatriement direct de $sha1 :"
 
-#: git-submodule.sh:639
+#: git-submodule.sh:619
 #, sh-format
 msgid ""
 "Fetched in submodule path '$displaypath', but it did not contain $sha1. "
@@ -17128,76 +23395,76 @@ msgstr ""
 "Chemin de sous-module '$displaypath' récupéré, mais il ne contenait pas "
 "$sha1. La récupération directe de ce commit a échoué."
 
-#: git-submodule.sh:646
+#: git-submodule.sh:626
 #, sh-format
 msgid "Unable to checkout '$sha1' in submodule path '$displaypath'"
 msgstr ""
 "Impossible d'extraire '$sha1' dans le chemin de sous-module '$displaypath'"
 
-#: git-submodule.sh:647
+#: git-submodule.sh:627
 #, sh-format
 msgid "Submodule path '$displaypath': checked out '$sha1'"
 msgstr "Chemin de sous-module '$displaypath' : '$sha1' extrait"
 
-#: git-submodule.sh:651
+#: git-submodule.sh:631
 #, sh-format
 msgid "Unable to rebase '$sha1' in submodule path '$displaypath'"
 msgstr ""
 "Impossible de rebaser '$sha1' dans le chemin de sous-module '$displaypath'"
 
-#: git-submodule.sh:652
+#: git-submodule.sh:632
 #, sh-format
 msgid "Submodule path '$displaypath': rebased into '$sha1'"
 msgstr "Chemin de sous-module '$displaypath' : rebasé dans '$sha1'"
 
-#: git-submodule.sh:657
+#: git-submodule.sh:637
 #, sh-format
 msgid "Unable to merge '$sha1' in submodule path '$displaypath'"
 msgstr ""
 "Impossible de fusionner '$sha1' dans le chemin de sous-module '$displaypath'"
 
-#: git-submodule.sh:658
+#: git-submodule.sh:638
 #, sh-format
 msgid "Submodule path '$displaypath': merged in '$sha1'"
 msgstr "Chemin de sous-module '$displaypath' : fusionné dans '$sha1'"
 
-#: git-submodule.sh:663
+#: git-submodule.sh:643
 #, sh-format
 msgid "Execution of '$command $sha1' failed in submodule path '$displaypath'"
 msgstr ""
 "L'exécution de '$command $sha1' a échoué dans le chemin de sous-module "
 "'$displaypath'"
 
-#: git-submodule.sh:664
+#: git-submodule.sh:644
 #, sh-format
 msgid "Submodule path '$displaypath': '$command $sha1'"
 msgstr "Chemin de sous-module '$displaypath' : '$command $sha1'"
 
-#: git-submodule.sh:695
+#: git-submodule.sh:675
 #, sh-format
 msgid "Failed to recurse into submodule path '$displaypath'"
 msgstr "Échec de parcours dans le chemin du sous-module '$displaypath'"
 
-#: git-submodule.sh:791
+#: git-submodule.sh:886
 msgid "The --cached option cannot be used with the --files option"
 msgstr "L'option --cached ne peut pas être utilisée avec l'option --files"
 
-#: git-submodule.sh:843
+#: git-submodule.sh:938
 #, sh-format
 msgid "unexpected mode $mod_dst"
 msgstr "mode $mod_dst inattendu"
 
-#: git-submodule.sh:863
+#: git-submodule.sh:958
 #, sh-format
 msgid "  Warn: $display_name doesn't contain commit $sha1_src"
 msgstr "  Attention : $display_name ne contient pas la validation $sha1_src"
 
-#: git-submodule.sh:866
+#: git-submodule.sh:961
 #, sh-format
 msgid "  Warn: $display_name doesn't contain commit $sha1_dst"
 msgstr "  Attention : $display_name ne contient pas la validation $sha1_dst"
 
-#: git-submodule.sh:869
+#: git-submodule.sh:964
 #, sh-format
 msgid "  Warn: $display_name doesn't contain commits $sha1_src and $sha1_dst"
 msgstr ""
@@ -17209,12 +23476,21 @@ msgstr ""
 msgid "See git-${cmd}(1) for details."
 msgstr "Référez-vous à git-${cmd}(1) pour de plus amples détails."
 
-#: git-rebase--interactive.sh:142
+#: git-rebase--preserve-merges.sh:109
+msgid "Applied autostash."
+msgstr "Autoremisage appliqué."
+
+#: git-rebase--preserve-merges.sh:112
+#, sh-format
+msgid "Cannot store $stash_sha1"
+msgstr "Impossible de stocker $stash_sha1"
+
+#: git-rebase--preserve-merges.sh:191
 #, sh-format
 msgid "Rebasing ($new_count/$total)"
 msgstr "Rebasage ($new_count/$total)"
 
-#: git-rebase--interactive.sh:158
+#: git-rebase--preserve-merges.sh:207
 msgid ""
 "\n"
 "Commands:\n"
@@ -17223,7 +23499,7 @@ msgid ""
 "e, edit <commit> = use commit, but stop for amending\n"
 "s, squash <commit> = use commit, but meld into previous commit\n"
 "f, fixup <commit> = like \"squash\", but discard this commit's log message\n"
-"x, exec <command> = run command (the rest of the line) using shell\n"
+"x, exec <commit> = run command (the rest of the line) using shell\n"
 "d, drop <commit> = remove commit\n"
 "l, label <label> = label current HEAD with a name\n"
 "t, reset <label> = reset HEAD to a label\n"
@@ -17253,24 +23529,7 @@ msgstr ""
 "\n"
 "Vous pouvez réordonner ces lignes ; elles sont exécutées de haut en bas.\n"
 
-#: git-rebase--interactive.sh:179
-msgid ""
-"\n"
-"Do not remove any line. Use 'drop' explicitly to remove a commit.\n"
-msgstr ""
-"\n"
-"Ne supprimez aucune ligne. Utilisez 'drop' explicitement pour supprimer un "
-"commit.\n"
-
-#: git-rebase--interactive.sh:183
-msgid ""
-"\n"
-"If you remove a line here THAT COMMIT WILL BE LOST.\n"
-msgstr ""
-"\n"
-"Si vous éliminez une ligne ici, LE COMMIT CORRESPONDANT SERA PERDU.\n"
-
-#: git-rebase--interactive.sh:221
+#: git-rebase--preserve-merges.sh:270
 #, sh-format
 msgid ""
 "You can amend the commit now, with\n"
@@ -17289,83 +23548,83 @@ msgstr ""
 "\n"
 "\tgit rebase --continue"
 
-#: git-rebase--interactive.sh:246
+#: git-rebase--preserve-merges.sh:295
 #, sh-format
 msgid "$sha1: not a commit that can be picked"
 msgstr "$sha1 n'est pas un commit qui peut être picorer"
 
-#: git-rebase--interactive.sh:285
+#: git-rebase--preserve-merges.sh:334
 #, sh-format
 msgid "Invalid commit name: $sha1"
 msgstr "Nom de commit invalide : $sha1"
 
-#: git-rebase--interactive.sh:325
+#: git-rebase--preserve-merges.sh:364
 msgid "Cannot write current commit's replacement sha1"
 msgstr "Impossible de sauver le sha1 du remplaçant du commit en cours"
 
-#: git-rebase--interactive.sh:376
+#: git-rebase--preserve-merges.sh:415
 #, sh-format
 msgid "Fast-forward to $sha1"
 msgstr "Avance rapide sur $sha1"
 
-#: git-rebase--interactive.sh:378
+#: git-rebase--preserve-merges.sh:417
 #, sh-format
 msgid "Cannot fast-forward to $sha1"
 msgstr "Avance rapide impossible sur $sha1"
 
-#: git-rebase--interactive.sh:387
+#: git-rebase--preserve-merges.sh:426
 #, sh-format
 msgid "Cannot move HEAD to $first_parent"
 msgstr "Impossible de déplacer HEAD sur $first_parent"
 
-#: git-rebase--interactive.sh:392
+#: git-rebase--preserve-merges.sh:431
 #, sh-format
 msgid "Refusing to squash a merge: $sha1"
 msgstr "Refus d'écraser un commit de fusion: $sha1"
 
-#: git-rebase--interactive.sh:410
+#: git-rebase--preserve-merges.sh:449
 #, sh-format
 msgid "Error redoing merge $sha1"
 msgstr "Erreur lors de la réapplication de la fusion $sha1"
 
-#: git-rebase--interactive.sh:419
+#: git-rebase--preserve-merges.sh:458
 #, sh-format
 msgid "Could not pick $sha1"
 msgstr "Impossible de picorer $sha1"
 
-#: git-rebase--interactive.sh:428
+#: git-rebase--preserve-merges.sh:467
 #, sh-format
 msgid "This is the commit message #${n}:"
 msgstr "Ceci est le ${n}ième message de validation :"
 
-#: git-rebase--interactive.sh:433
+#: git-rebase--preserve-merges.sh:472
 #, sh-format
 msgid "The commit message #${n} will be skipped:"
 msgstr "Le message de validation ${n} sera ignoré :"
 
-#: git-rebase--interactive.sh:444
+#: git-rebase--preserve-merges.sh:483
 #, sh-format
 msgid "This is a combination of $count commit."
 msgid_plural "This is a combination of $count commits."
 msgstr[0] "Ceci est la combinaison de $count commit."
 msgstr[1] "Ceci est la combinaison de $count commits."
 
-#: git-rebase--interactive.sh:453
+#: git-rebase--preserve-merges.sh:492
 #, sh-format
 msgid "Cannot write $fixup_msg"
 msgstr "Impossible d'écrire $fixup_msg"
 
-#: git-rebase--interactive.sh:456
+#: git-rebase--preserve-merges.sh:495
 msgid "This is a combination of 2 commits."
 msgstr "Ceci est la combinaison de 2 commits."
 
-#: git-rebase--interactive.sh:497 git-rebase--interactive.sh:540
-#: git-rebase--interactive.sh:543
+#: git-rebase--preserve-merges.sh:536 git-rebase--preserve-merges.sh:579
+#: git-rebase--preserve-merges.sh:582
 #, sh-format
 msgid "Could not apply $sha1... $rest"
 msgstr "Impossible d'appliquer $sha1... $rest"
 
-#: git-rebase--interactive.sh:572
+#: git-rebase--preserve-merges.sh:611
 #, sh-format
 msgid ""
 "Could not amend commit after successfully picking $sha1... $rest\n"
@@ -17382,31 +23641,31 @@ msgstr ""
 "le\n"
 "problème avant de pouvoir reformuler le message du commit."
 
-#: git-rebase--interactive.sh:587
+#: git-rebase--preserve-merges.sh:626
 #, sh-format
 msgid "Stopped at $sha1_abbrev... $rest"
 msgstr "Arrêté à $sha1_abbrev... $rest"
 
-#: git-rebase--interactive.sh:602
+#: git-rebase--preserve-merges.sh:641
 #, sh-format
 msgid "Cannot '$squash_style' without a previous commit"
 msgstr "'$squash_style' impossible avec le commit précédent"
 
-#: git-rebase--interactive.sh:644
+#: git-rebase--preserve-merges.sh:683
 #, sh-format
 msgid "Executing: $rest"
 msgstr "Exécution : $rest"
 
-#: git-rebase--interactive.sh:652
+#: git-rebase--preserve-merges.sh:691
 #, sh-format
 msgid "Execution failed: $rest"
 msgstr "L'exécution a échoué : $rest"
 
-#: git-rebase--interactive.sh:654
+#: git-rebase--preserve-merges.sh:693
 msgid "and made changes to the index and/or the working tree"
 msgstr "et a mis à jour l'index ou la copie de travail"
 
-#: git-rebase--interactive.sh:656
+#: git-rebase--preserve-merges.sh:695
 msgid ""
 "You can fix the problem, and then run\n"
 "\n"
@@ -17417,7 +23676,7 @@ msgstr ""
 "git rebase --continue"
 
 #. TRANSLATORS: after these lines is a command to be issued by the user
-#: git-rebase--interactive.sh:669
+#: git-rebase--preserve-merges.sh:708
 #, sh-format
 msgid ""
 "Execution succeeded: $rest\n"
@@ -17432,29 +23691,25 @@ msgstr ""
 "\n"
 "\tgit rebase --continue"
 
-#: git-rebase--interactive.sh:680
+#: git-rebase--preserve-merges.sh:719
 #, sh-format
 msgid "Unknown command: $command $sha1 $rest"
 msgstr "Commande inconnue : $command $sha1 $rest"
 
-#: git-rebase--interactive.sh:681
+#: git-rebase--preserve-merges.sh:720
 msgid "Please fix this using 'git rebase --edit-todo'."
 msgstr "Veuillez corriger ceci en utilisant 'git rebase --edit-todo'."
 
-#: git-rebase--interactive.sh:716
+#: git-rebase--preserve-merges.sh:755
 #, sh-format
 msgid "Successfully rebased and updated $head_name."
 msgstr "Rebasage et mise à jour de $head_name avec succès."
 
-#: git-rebase--interactive.sh:740
-msgid "could not detach HEAD"
-msgstr "Impossible de détacher HEAD"
-
-#: git-rebase--interactive.sh:778
+#: git-rebase--preserve-merges.sh:812
 msgid "Could not remove CHERRY_PICK_HEAD"
 msgstr "Impossible de supprimer CHERRY_PICK_HEAD"
 
-#: git-rebase--interactive.sh:783
+#: git-rebase--preserve-merges.sh:817
 #, sh-format
 msgid ""
 "You have staged changes in your working tree.\n"
@@ -17485,12 +23740,12 @@ msgstr ""
 "\n"
 "  git rebase --continue\n"
 
-#: git-rebase--interactive.sh:800
+#: git-rebase--preserve-merges.sh:834
 msgid "Error trying to find the author identity to amend commit"
 msgstr ""
 "Erreur lors de la recherche de l'identité de l'auteur pour corriger le commit"
 
-#: git-rebase--interactive.sh:805
+#: git-rebase--preserve-merges.sh:839
 msgid ""
 "You have uncommitted changes in your working tree. Please commit them\n"
 "first and then run 'git rebase --continue' again."
@@ -17498,75 +23753,40 @@ msgstr ""
 "Vous avez des modifications non validées dans votre copie de travail.\n"
 "Veuillez les valider d'abord, puis relancer 'git rebase --continue'."
 
-#: git-rebase--interactive.sh:810 git-rebase--interactive.sh:814
+#: git-rebase--preserve-merges.sh:844 git-rebase--preserve-merges.sh:848
 msgid "Could not commit staged changes."
 msgstr "impossible de valider les modifications indexées."
 
-#: git-rebase--interactive.sh:843
-msgid ""
-"\n"
-"You are editing the todo file of an ongoing interactive rebase.\n"
-"To continue rebase after editing, run:\n"
-"    git rebase --continue\n"
-"\n"
-msgstr ""
-"\n"
-"Vous êtes en train d'éditer le fichier todo d'un rebasage interactif en "
-"cours.\n"
-"Pour continuer le rebasage après édition, lancez :\n"
-"    git rebase --continue\n"
-"\n"
-
-#: git-rebase--interactive.sh:851 git-rebase--interactive.sh:937
+#: git-rebase--preserve-merges.sh:879 git-rebase--preserve-merges.sh:965
 msgid "Could not execute editor"
 msgstr "Impossible de lancer l'éditeur"
 
-#: git-rebase--interactive.sh:872
+#: git-rebase--preserve-merges.sh:900
 #, sh-format
 msgid "Could not checkout $switch_to"
 msgstr "Impossible d'extraire $switch_to"
 
-#: git-rebase--interactive.sh:879
+#: git-rebase--preserve-merges.sh:907
 msgid "No HEAD?"
 msgstr "Pas de HEAD ?"
 
-#: git-rebase--interactive.sh:880
+#: git-rebase--preserve-merges.sh:908
 #, sh-format
 msgid "Could not create temporary $state_dir"
 msgstr "Impossible de créer un répertoire temporaire $state_dir"
 
-#: git-rebase--interactive.sh:883
+#: git-rebase--preserve-merges.sh:911
 msgid "Could not mark as interactive"
 msgstr "Impossible de marquer comme interactif"
 
-#: git-rebase--interactive.sh:915
+#: git-rebase--preserve-merges.sh:943
 #, sh-format
 msgid "Rebase $shortrevisions onto $shortonto ($todocount command)"
 msgid_plural "Rebase $shortrevisions onto $shortonto ($todocount commands)"
 msgstr[0] "Rebasage de $shortrevisions sur $shortonto ($todocount commande)"
 msgstr[1] "Rebasage de $shortrevisions sur $shortonto ($todocount commandes)"
 
-#: git-rebase--interactive.sh:920
-msgid ""
-"\n"
-"\tHowever, if you remove everything, the rebase will be aborted.\n"
-"\n"
-"\t"
-msgstr ""
-"\n"
-"Cependant, si vous effacez tout, le rebasage sera annulé.\n"
-"\n"
-"\t"
-
-#: git-rebase--interactive.sh:927
-msgid "Note that empty commits are commented out"
-msgstr "Veuillez noter que les commits vides sont en commentaire"
-
-#: git-rebase--interactive.sh:980
-msgid "Could not generate todo list"
-msgstr "Impossible de générer la liste à-faire"
-
-#: git-rebase--interactive.sh:1001 git-rebase--interactive.sh:1006
+#: git-rebase--preserve-merges.sh:997 git-rebase--preserve-merges.sh:1002
 msgid "Could not init rewritten commits"
 msgstr "Impossible d'initialiser les commits réécrits"
 
@@ -17575,144 +23795,82 @@ msgstr "Impossible d'initialiser les com
 msgid "usage: $dashless $USAGE"
 msgstr "usage : $dashless $USAGE"
 
-#: git-sh-setup.sh:190
+#: git-sh-setup.sh:191
 #, sh-format
 msgid "Cannot chdir to $cdup, the toplevel of the working tree"
 msgstr ""
 "Impossible de se placer dans le répertoire $cdup, la racine de la copie de "
 "travail"
 
-#: git-sh-setup.sh:199 git-sh-setup.sh:206
+#: git-sh-setup.sh:200 git-sh-setup.sh:207
 #, sh-format
 msgid "fatal: $program_name cannot be used without a working tree."
 msgstr "fatal : $program_name ne peut pas être utilisé sans copie de travail."
 
-#: git-sh-setup.sh:220
+#: git-sh-setup.sh:221
 msgid "Cannot rebase: You have unstaged changes."
 msgstr "Impossible de rebaser : vous avez des modifications non indexées."
 
-#: git-sh-setup.sh:223
+#: git-sh-setup.sh:224
 msgid "Cannot rewrite branches: You have unstaged changes."
 msgstr ""
 "Impossible de réécrire les branches : vous avez des modifications non "
 "indexées."
 
-#: git-sh-setup.sh:226
+#: git-sh-setup.sh:227
 msgid "Cannot pull with rebase: You have unstaged changes."
 msgstr ""
 "impossible de tirer avec rebasage. Vous avez des modifications non indexées."
 
-#: git-sh-setup.sh:229
+#: git-sh-setup.sh:230
 #, sh-format
 msgid "Cannot $action: You have unstaged changes."
 msgstr "$action est impossible : vous avez des modifications non indexées."
 
-#: git-sh-setup.sh:242
+#: git-sh-setup.sh:243
 msgid "Cannot rebase: Your index contains uncommitted changes."
 msgstr ""
 "Impossible de rebaser : votre index contient des modifications non validées."
 
-#: git-sh-setup.sh:245
+#: git-sh-setup.sh:246
 msgid "Cannot pull with rebase: Your index contains uncommitted changes."
 msgstr ""
 "impossible de tirer avec rebasage : votre index contient des modifications "
 "non validées."
 
-#: git-sh-setup.sh:248
+#: git-sh-setup.sh:249
 #, sh-format
 msgid "Cannot $action: Your index contains uncommitted changes."
 msgstr ""
 "$action est impossible : votre index contient des modifications non validées."
 
-#: git-sh-setup.sh:252
+#: git-sh-setup.sh:253
 msgid "Additionally, your index contains uncommitted changes."
 msgstr "De plus, votre index contient des modifications non validées."
 
-#: git-sh-setup.sh:372
+#: git-sh-setup.sh:373
 msgid "You need to run this command from the toplevel of the working tree."
 msgstr ""
 "Vous devez lancer cette commande depuis la racine de votre copie de travail."
 
-#: git-sh-setup.sh:377
+#: git-sh-setup.sh:378
 msgid "Unable to determine absolute path of git directory"
 msgstr "Impossible de déterminer le chemin absolu du répertoire git"
 
 #. TRANSLATORS: you can adjust this to align "git add -i" status menu
-#: git-add--interactive.perl:196
+#: git-add--interactive.perl:212
 #, perl-format
 msgid "%12s %12s %s"
 msgstr "%12s %s12s %s"
 
-#: git-add--interactive.perl:197
-msgid "staged"
-msgstr "indexé"
-
-#: git-add--interactive.perl:197
-msgid "unstaged"
-msgstr "non-indexé"
-
-#: git-add--interactive.perl:253 git-add--interactive.perl:278
-msgid "binary"
-msgstr "binaire"
-
-#: git-add--interactive.perl:262 git-add--interactive.perl:316
-msgid "nothing"
-msgstr "rien"
-
-#: git-add--interactive.perl:298 git-add--interactive.perl:313
-msgid "unchanged"
-msgstr "inchangé"
-
-#: git-add--interactive.perl:609
-#, perl-format
-msgid "added %d path\n"
-msgid_plural "added %d paths\n"
-msgstr[0] "%d chemin ajouté\n"
-msgstr[1] "%d chemins ajoutés\n"
-
-#: git-add--interactive.perl:612
-#, perl-format
-msgid "updated %d path\n"
-msgid_plural "updated %d paths\n"
-msgstr[0] "%d chemin mis à jour\n"
-msgstr[1] "%d chemins mis à jour\n"
-
-#: git-add--interactive.perl:615
-#, perl-format
-msgid "reverted %d path\n"
-msgid_plural "reverted %d paths\n"
-msgstr[0] "%d chemin inversé\n"
-msgstr[1] "%d chemins inversés\n"
-
-#: git-add--interactive.perl:618
+#: git-add--interactive.perl:634
 #, perl-format
 msgid "touched %d path\n"
 msgid_plural "touched %d paths\n"
 msgstr[0] "%d chemin touché\n"
 msgstr[1] "%d chemins touchés\n"
 
-#: git-add--interactive.perl:627
-msgid "Update"
-msgstr "Mise à jour"
-
-#: git-add--interactive.perl:639
-msgid "Revert"
-msgstr "Inverser"
-
-#: git-add--interactive.perl:662
-#, perl-format
-msgid "note: %s is untracked now.\n"
-msgstr "note : %s n'est plus suivi à présent.\n"
-
-#: git-add--interactive.perl:673
-msgid "Add untracked"
-msgstr "Ajouter un fichier non-suivi"
-
-#: git-add--interactive.perl:679
-msgid "No untracked files.\n"
-msgstr "Aucun Fichier non suivi.\n"
-
-#: git-add--interactive.perl:1033
+#: git-add--interactive.perl:1053
 msgid ""
 "If the patch applies cleanly, the edited hunk will immediately be\n"
 "marked for staging."
@@ -17720,7 +23878,7 @@ msgstr ""
 "Si le patch s'applique proprement, la section éditée sera\n"
 "immédiatement marquée comme indexée."
 
-#: git-add--interactive.perl:1036
+#: git-add--interactive.perl:1056
 msgid ""
 "If the patch applies cleanly, the edited hunk will immediately be\n"
 "marked for stashing."
@@ -17728,7 +23886,7 @@ msgstr ""
 "Si le patch s'applique proprement, la section éditée sera\n"
 "immédiatement marquée comme remisée."
 
-#: git-add--interactive.perl:1039
+#: git-add--interactive.perl:1059
 msgid ""
 "If the patch applies cleanly, the edited hunk will immediately be\n"
 "marked for unstaging."
@@ -17736,7 +23894,8 @@ msgstr ""
 "Si le patch s'applique proprement, la section éditée sera\n"
 "immédiatement marquée comme desindexée."
 
-#: git-add--interactive.perl:1042 git-add--interactive.perl:1051
+#: git-add--interactive.perl:1062 git-add--interactive.perl:1071
+#: git-add--interactive.perl:1077
 msgid ""
 "If the patch applies cleanly, the edited hunk will immediately be\n"
 "marked for applying."
@@ -17744,7 +23903,8 @@ msgstr ""
 "Si le patch s'applique proprement, la section éditée sera\n"
 "immédiatement marquée comme appliquée."
 
-#: git-add--interactive.perl:1045 git-add--interactive.perl:1048
+#: git-add--interactive.perl:1065 git-add--interactive.perl:1068
+#: git-add--interactive.perl:1074
 msgid ""
 "If the patch applies cleanly, the edited hunk will immediately be\n"
 "marked for discarding."
@@ -17752,17 +23912,12 @@ msgstr ""
 "Si le patch s'applique proprement, la section éditée sera\n"
 "immédiatement marquée comme éliminée."
 
-#: git-add--interactive.perl:1085
+#: git-add--interactive.perl:1111
 #, perl-format
 msgid "failed to open hunk edit file for writing: %s"
 msgstr "impossible d'ouvrir le fichier d'édition de section en écriture : %s"
 
-#: git-add--interactive.perl:1086
-msgid "Manual hunk edit mode -- see bottom for a quick guide.\n"
-msgstr ""
-"Mode d'édition manuelle de section -- voir ci-dessous pour un guide rapide.\n"
-
-#: git-add--interactive.perl:1092
+#: git-add--interactive.perl:1118
 #, perl-format
 msgid ""
 "---\n"
@@ -17775,36 +23930,12 @@ msgstr ""
 "Pour éliminer les lignes '%s', effacez-les.\n"
 "Les lignes commençant par %s seront éliminées.\n"
 
-#. TRANSLATORS: 'it' refers to the patch mentioned in the previous messages.
-#: git-add--interactive.perl:1100
-msgid ""
-"If it does not apply cleanly, you will be given an opportunity to\n"
-"edit again.  If all lines of the hunk are removed, then the edit is\n"
-"aborted and the hunk is left unchanged.\n"
-msgstr ""
-"Si ça ne s'applique pas proprement, vous aurez la possibilité de\n"
-"l'éditer à nouveau. Si toutes les lignes de la section sont supprimées,\n"
-"alors l'édition sera abandonnée et la section conservée.\n"
-
-#: git-add--interactive.perl:1114
+#: git-add--interactive.perl:1140
 #, perl-format
 msgid "failed to open hunk edit file for reading: %s"
 msgstr "échec de l'ouverture du fichier d'édition de section en lecture : %s"
 
-#. TRANSLATORS: do not translate [y/n]
-#. The program will only accept that input
-#. at this point.
-#. Consider translating (saying "no" discards!) as
-#. (saying "n" for "no" discards!) if the translation
-#. of the word "no" does not start with n.
-#: git-add--interactive.perl:1213
-msgid ""
-"Your edited hunk does not apply. Edit again (saying \"no\" discards!) [y/n]? "
-msgstr ""
-"Votre section éditée ne s'applique pas. L'éditer à nouveau (\"no\" "
-"l'élimine !) [y|n] ? "
-
-#: git-add--interactive.perl:1222
+#: git-add--interactive.perl:1248
 msgid ""
 "y - stage this hunk\n"
 "n - do not stage this hunk\n"
@@ -17818,7 +23949,7 @@ msgstr ""
 "a - indexer cette section et toutes les suivantes de ce fichier\n"
 "d - ne pas indexer cette section ni les suivantes de ce fichier"
 
-#: git-add--interactive.perl:1228
+#: git-add--interactive.perl:1254
 msgid ""
 "y - stash this hunk\n"
 "n - do not stash this hunk\n"
@@ -17832,7 +23963,7 @@ msgstr ""
 "a - remiser cette section et toutes les suivantes de ce fichier\n"
 "d - ne pas remiser cette section ni les suivantes de ce fichier"
 
-#: git-add--interactive.perl:1234
+#: git-add--interactive.perl:1260
 msgid ""
 "y - unstage this hunk\n"
 "n - do not unstage this hunk\n"
@@ -17846,7 +23977,7 @@ msgstr ""
 "a - désindexer cette section et toutes les suivantes de ce fichier\n"
 "d - ne pas désindexer cette section ni les suivantes de ce fichier"
 
-#: git-add--interactive.perl:1240
+#: git-add--interactive.perl:1266
 msgid ""
 "y - apply this hunk to index\n"
 "n - do not apply this hunk to index\n"
@@ -17860,7 +23991,7 @@ msgstr ""
 "a - appliquer cette section et toutes les suivantes de ce fichier\n"
 "d - ne pas appliquer cette section ni les suivantes de ce fichier"
 
-#: git-add--interactive.perl:1246
+#: git-add--interactive.perl:1272 git-add--interactive.perl:1290
 msgid ""
 "y - discard this hunk from worktree\n"
 "n - do not discard this hunk from worktree\n"
@@ -17874,7 +24005,7 @@ msgstr ""
 "a - supprimer cette section et toutes les suivantes de ce fichier\n"
 "d - ne pas supprimer cette section ni les suivantes de ce fichier"
 
-#: git-add--interactive.perl:1252
+#: git-add--interactive.perl:1278
 msgid ""
 "y - discard this hunk from index and worktree\n"
 "n - do not discard this hunk from index and worktree\n"
@@ -17888,7 +24019,7 @@ msgstr ""
 "a - éliminer cette section et toutes les suivantes de ce fichier\n"
 "d - ne pas éliminer cette section ni les suivantes de ce fichier"
 
-#: git-add--interactive.perl:1258
+#: git-add--interactive.perl:1284
 msgid ""
 "y - apply this hunk to index and worktree\n"
 "n - do not apply this hunk to index and worktree\n"
@@ -17902,7 +24033,21 @@ msgstr ""
 "a - appliquer cette section et toutes les suivantes de ce fichier\n"
 "d - ne pas appliquer cette section ni les suivantes de ce fichier"
 
-#: git-add--interactive.perl:1273
+#: git-add--interactive.perl:1296
+msgid ""
+"y - apply this hunk to worktree\n"
+"n - do not apply this hunk to worktree\n"
+"q - quit; do not apply this hunk or any of the remaining ones\n"
+"a - apply this hunk and all later hunks in the file\n"
+"d - do not apply this hunk or any of the later hunks in the file"
+msgstr ""
+"y - appliquer cette section à l'arbre de travail\n"
+"n - ne pas appliquer cette section\n"
+"q - quitter ; ne pas appliquer cette section ni les autres restantes\n"
+"a - appliquer cette section et toutes les suivantes de ce fichier\n"
+"d - ne pas appliquer cette section ni les suivantes de ce fichier"
+
+#: git-add--interactive.perl:1311
 msgid ""
 "g - select a hunk to go to\n"
 "/ - search for a hunk matching the given regex\n"
@@ -17924,218 +24069,206 @@ msgstr ""
 "e - éditer manuellement la section actuelle\n"
 "? - afficher l'aide\n"
 
-#: git-add--interactive.perl:1304
+#: git-add--interactive.perl:1342
 msgid "The selected hunks do not apply to the index!\n"
 msgstr "Les sections sélectionnées ne s'applique pas à l'index !\n"
 
-#: git-add--interactive.perl:1305
+#: git-add--interactive.perl:1343
 msgid "Apply them to the worktree anyway? "
 msgstr "Les appliquer quand même à l'arbre de travail ? "
 
-#: git-add--interactive.perl:1308
+#: git-add--interactive.perl:1346
 msgid "Nothing was applied.\n"
 msgstr "Rien n'a été appliqué.\n"
 
-#: git-add--interactive.perl:1319
+#: git-add--interactive.perl:1357
 #, perl-format
 msgid "ignoring unmerged: %s\n"
 msgstr "fichier non-fusionné ignoré : %s\n"
 
-#: git-add--interactive.perl:1328
-msgid "Only binary files changed.\n"
-msgstr "Seuls des fichiers binaires ont changé.\n"
-
-#: git-add--interactive.perl:1330
-msgid "No changes.\n"
-msgstr "Aucune modification.\n"
-
-#: git-add--interactive.perl:1338
-msgid "Patch update"
-msgstr "Mise à jour par patch"
-
-#: git-add--interactive.perl:1390
+#: git-add--interactive.perl:1428
 #, perl-format
 msgid "Stage mode change [y,n,q,a,d%s,?]? "
 msgstr "Indexer le changement de mode [y,n,q,a,d%s,?] ? "
 
-#: git-add--interactive.perl:1391
+#: git-add--interactive.perl:1429
 #, perl-format
 msgid "Stage deletion [y,n,q,a,d%s,?]? "
 msgstr "Indexer la suppression [y,n,q,a,d%s,?] ? "
 
-#: git-add--interactive.perl:1392
+#: git-add--interactive.perl:1430
 #, perl-format
 msgid "Stage this hunk [y,n,q,a,d%s,?]? "
 msgstr "Indexer cette section [y,n,q,a,d%s,?] ? "
 
-#: git-add--interactive.perl:1395
+#: git-add--interactive.perl:1433
 #, perl-format
 msgid "Stash mode change [y,n,q,a,d%s,?]? "
 msgstr "Remiser le changement de mode [y,n,q,a,d%s,?] ? "
 
-#: git-add--interactive.perl:1396
+#: git-add--interactive.perl:1434
 #, perl-format
 msgid "Stash deletion [y,n,q,a,d%s,?]? "
 msgstr "Remiser la suppression [y,n,q,a,d%s,?] ? "
 
-#: git-add--interactive.perl:1397
+#: git-add--interactive.perl:1435
 #, perl-format
 msgid "Stash this hunk [y,n,q,a,d%s,?]? "
 msgstr "Remiser cette section [y,n,q,a,d%s,?] ? "
 
-#: git-add--interactive.perl:1400
+#: git-add--interactive.perl:1438
 #, perl-format
 msgid "Unstage mode change [y,n,q,a,d%s,?]? "
 msgstr "Désindexer le changement de mode [y,n,q,a,d%s,?] ? "
 
-#: git-add--interactive.perl:1401
+#: git-add--interactive.perl:1439
 #, perl-format
 msgid "Unstage deletion [y,n,q,a,d%s,?]? "
 msgstr "Désindexer la suppression [y,n,q,a,d%s,?] ? "
 
-#: git-add--interactive.perl:1402
+#: git-add--interactive.perl:1440
 #, perl-format
 msgid "Unstage this hunk [y,n,q,a,d%s,?]? "
 msgstr "Désindexer cette section [y,n,q,a,d%s,?] ? "
 
-#: git-add--interactive.perl:1405
+#: git-add--interactive.perl:1443
 #, perl-format
 msgid "Apply mode change to index [y,n,q,a,d%s,?]? "
 msgstr "Appliquer le changement de mode à l'index [y,n,q,a,d%s,?] ? "
 
-#: git-add--interactive.perl:1406
+#: git-add--interactive.perl:1444
 #, perl-format
 msgid "Apply deletion to index [y,n,q,a,d%s,?]? "
 msgstr "Appliquer la suppression à l'index [y,n,q,a,d%s,?] ? "
 
-#: git-add--interactive.perl:1407
+#: git-add--interactive.perl:1445
 #, perl-format
 msgid "Apply this hunk to index [y,n,q,a,d%s,?]? "
 msgstr "Appliquer cette section à l'index [y,n,q,a,d%s,?] ? "
 
-#: git-add--interactive.perl:1410
+#: git-add--interactive.perl:1448 git-add--interactive.perl:1463
 #, perl-format
 msgid "Discard mode change from worktree [y,n,q,a,d%s,?]? "
 msgstr "Abandonner le changement de mode dans l'arbre [y,n,q,a,d%s,?] ? "
 
-#: git-add--interactive.perl:1411
+#: git-add--interactive.perl:1449 git-add--interactive.perl:1464
 #, perl-format
 msgid "Discard deletion from worktree [y,n,q,a,d%s,?]? "
 msgstr "Abandonner la suppression dans l'arbre [y,n,q,a,d%s,?] ? "
 
-#: git-add--interactive.perl:1412
+#: git-add--interactive.perl:1450 git-add--interactive.perl:1465
 #, perl-format
 msgid "Discard this hunk from worktree [y,n,q,a,d%s,?]? "
 msgstr "Abandonner cette section dans l'arbre [y,n,q,a,d%s,?] ? "
 
-#: git-add--interactive.perl:1415
+#: git-add--interactive.perl:1453
 #, perl-format
 msgid "Discard mode change from index and worktree [y,n,q,a,d%s,?]? "
 msgstr ""
 "Abandonner le changement de mode dans l'index et l'arbre [y,n,q,a,d%s,?] ? "
 
-#: git-add--interactive.perl:1416
+#: git-add--interactive.perl:1454
 #, perl-format
 msgid "Discard deletion from index and worktree [y,n,q,a,d%s,?]? "
 msgstr "Abandonner la suppression de l'index et de l'arbre [y,n,q,a,d%s,?] ? "
 
-#: git-add--interactive.perl:1417
+#: git-add--interactive.perl:1455
 #, perl-format
 msgid "Discard this hunk from index and worktree [y,n,q,a,d%s,?]? "
 msgstr ""
 "Supprimer la section dans l'index et l'arbre de travail [y,n,q,a,d%s,?] ? "
 
-#: git-add--interactive.perl:1420
+#: git-add--interactive.perl:1458
 #, perl-format
 msgid "Apply mode change to index and worktree [y,n,q,a,d%s,?]? "
 msgstr ""
 "Appliquer le changement de mode dans l'index et l'arbre de travail [y,n,q,a,d"
 "%s,?] ? "
 
-#: git-add--interactive.perl:1421
+#: git-add--interactive.perl:1459
 #, perl-format
 msgid "Apply deletion to index and worktree [y,n,q,a,d%s,?]? "
 msgstr ""
 "Appliquer la suppression dans l'index et l'arbre de travail [y,n,q,a,d"
 "%s,?] ? "
 
-#: git-add--interactive.perl:1422
+#: git-add--interactive.perl:1460
 #, perl-format
 msgid "Apply this hunk to index and worktree [y,n,q,a,d%s,?]? "
 msgstr ""
 "Appliquer la section à l'index et l'arbre de travail [y,n,q,a,d%s,?] ? "
 
-#: git-add--interactive.perl:1522
-msgid "No other hunks to goto\n"
-msgstr "Aucune autre section à atteindre\n"
+#: git-add--interactive.perl:1468
+#, perl-format
+msgid "Apply mode change to worktree [y,n,q,a,d%s,?]? "
+msgstr ""
+"Appliquer le changement de mode dans l'arbre de travail [y,n,q,a,d%s,?] ? "
 
-#: git-add--interactive.perl:1529
-msgid "go to which hunk (<ret> to see more)? "
-msgstr "aller à quelle section (<ret> pour voir plus) ? "
+#: git-add--interactive.perl:1469
+#, perl-format
+msgid "Apply deletion to worktree [y,n,q,a,d%s,?]? "
+msgstr "Appliquer la suppression dans l'arbre de travail [y,n,q,a,d%s,?] ? "
 
-#: git-add--interactive.perl:1531
-msgid "go to which hunk? "
-msgstr "aller à quelle section ? "
+#: git-add--interactive.perl:1470
+#, perl-format
+msgid "Apply this hunk to worktree [y,n,q,a,d%s,?]? "
+msgstr "Appliquer la section à l'arbre de travail [y,n,q,a,d%s,?] ? "
+
+#: git-add--interactive.perl:1570
+msgid "No other hunks to goto\n"
+msgstr "Aucune autre section à atteindre\n"
 
-#: git-add--interactive.perl:1540
+#: git-add--interactive.perl:1588
 #, perl-format
 msgid "Invalid number: '%s'\n"
 msgstr "Nombre invalide : '%s'\n"
 
-#: git-add--interactive.perl:1545
+#: git-add--interactive.perl:1593
 #, perl-format
 msgid "Sorry, only %d hunk available.\n"
 msgid_plural "Sorry, only %d hunks available.\n"
 msgstr[0] "Désolé, %d seule section disponible.\n"
 msgstr[1] "Désolé, Seulement %d sections disponibles.\n"
 
-#: git-add--interactive.perl:1571
+#: git-add--interactive.perl:1619
 msgid "No other hunks to search\n"
 msgstr "aucune autre section à rechercher\n"
 
-#: git-add--interactive.perl:1575
-msgid "search for regex? "
-msgstr "rechercher la regex ? "
-
-#: git-add--interactive.perl:1588
+#: git-add--interactive.perl:1636
 #, perl-format
 msgid "Malformed search regexp %s: %s\n"
 msgstr "Regex de recherche malformée %s : %s\n"
 
-#: git-add--interactive.perl:1598
+#: git-add--interactive.perl:1646
 msgid "No hunk matches the given pattern\n"
 msgstr "Aucune section ne correspond au motif donné\n"
 
-#: git-add--interactive.perl:1610 git-add--interactive.perl:1632
+#: git-add--interactive.perl:1658 git-add--interactive.perl:1680
 msgid "No previous hunk\n"
 msgstr "Pas de section précédente\n"
 
-#: git-add--interactive.perl:1619 git-add--interactive.perl:1638
+#: git-add--interactive.perl:1667 git-add--interactive.perl:1686
 msgid "No next hunk\n"
 msgstr "Pas de section suivante\n"
 
-#: git-add--interactive.perl:1644
+#: git-add--interactive.perl:1692
 msgid "Sorry, cannot split this hunk\n"
 msgstr "Désolé, impossible de découper cette section\n"
 
-#: git-add--interactive.perl:1650
+#: git-add--interactive.perl:1698
 #, perl-format
 msgid "Split into %d hunk.\n"
 msgid_plural "Split into %d hunks.\n"
 msgstr[0] "Découpée en %d section.\n"
 msgstr[1] "Découpée en %d sections.\n"
 
-#: git-add--interactive.perl:1660
+#: git-add--interactive.perl:1708
 msgid "Sorry, cannot edit this hunk\n"
 msgstr "Désolé, impossible d'éditer cette section\n"
 
-#: git-add--interactive.perl:1706
-msgid "Review diff"
-msgstr "Réviser la différence"
-
 #. TRANSLATORS: please do not translate the command names
 #. 'status', 'update', 'revert', etc.
-#: git-add--interactive.perl:1725
+#: git-add--interactive.perl:1773
 msgid ""
 "status        - show paths with changes\n"
 "update        - add working tree state to the staged set of changes\n"
@@ -18153,56 +24286,57 @@ msgstr ""
 "diff          - visualiser les diff entre HEAD et l'index\n"
 "add untracked - ajouter les fichiers non-suivis aux modifications à indexer\n"
 
-#: git-add--interactive.perl:1742 git-add--interactive.perl:1747
-#: git-add--interactive.perl:1750 git-add--interactive.perl:1757
-#: git-add--interactive.perl:1761 git-add--interactive.perl:1767
+#: git-add--interactive.perl:1790 git-add--interactive.perl:1795
+#: git-add--interactive.perl:1798 git-add--interactive.perl:1805
+#: git-add--interactive.perl:1808 git-add--interactive.perl:1815
+#: git-add--interactive.perl:1819 git-add--interactive.perl:1825
 msgid "missing --"
 msgstr "-- manquant"
 
-#: git-add--interactive.perl:1763
+#: git-add--interactive.perl:1821
 #, perl-format
 msgid "unknown --patch mode: %s"
 msgstr "mode de --patch inconnu : %s"
 
-#: git-add--interactive.perl:1769 git-add--interactive.perl:1775
+#: git-add--interactive.perl:1827 git-add--interactive.perl:1833
 #, perl-format
 msgid "invalid argument %s, expecting --"
 msgstr "argument invalide %s, -- attendu"
 
-#: git-send-email.perl:130
+#: git-send-email.perl:138
 msgid "local zone differs from GMT by a non-minute interval\n"
 msgstr ""
 "la zone locale diffère du GMT par un intervalle supérieur à une minute\n"
 
-#: git-send-email.perl:137 git-send-email.perl:143
+#: git-send-email.perl:145 git-send-email.perl:151
 msgid "local time offset greater than or equal to 24 hours\n"
 msgstr "le décalage de temps local est plus grand ou égal à 24 heures\n"
 
-#: git-send-email.perl:211 git-send-email.perl:217
+#: git-send-email.perl:223 git-send-email.perl:229
 msgid "the editor exited uncleanly, aborting everything"
 msgstr "l'éditeur est sorti en erreur, abandon total"
 
-#: git-send-email.perl:294
+#: git-send-email.perl:310
 #, perl-format
 msgid ""
 "'%s' contains an intermediate version of the email you were composing.\n"
 msgstr ""
 "'%s' contient une version intermédiaire du courriel que vous composiez.\n"
 
-#: git-send-email.perl:299
+#: git-send-email.perl:315
 #, perl-format
 msgid "'%s.final' contains the composed email.\n"
 msgstr "'%s.final' contient le courriel composé.\n"
 
-#: git-send-email.perl:317
+#: git-send-email.perl:408
 msgid "--dump-aliases incompatible with other options\n"
 msgstr "--dump-aliases est incompatible avec d'autres options\n"
 
-#: git-send-email.perl:383 git-send-email.perl:638
+#: git-send-email.perl:481 git-send-email.perl:683
 msgid "Cannot run git format-patch from outside a repository\n"
 msgstr "Lancement de git format-patch impossible à l'extérieur d'un dépôt\n"
 
-#: git-send-email.perl:386
+#: git-send-email.perl:484
 msgid ""
 "`batch-size` and `relogin` must be specified together (via command-line or "
 "configuration option)\n"
@@ -18210,39 +24344,39 @@ msgstr ""
 "`batch-size` et `relogin` doivent être spécifiés ensembles (via la ligne de "
 "commande ou des options de configuration)\n"
 
-#: git-send-email.perl:456
+#: git-send-email.perl:497
 #, perl-format
 msgid "Unknown --suppress-cc field: '%s'\n"
 msgstr "Champ de --suppress-cc inconnu : '%s'\n"
 
-#: git-send-email.perl:485
+#: git-send-email.perl:528
 #, perl-format
 msgid "Unknown --confirm setting: '%s'\n"
 msgstr "Paramètre de --confirm inconnu : '%s'\n"
 
-#: git-send-email.perl:513
+#: git-send-email.perl:556
 #, perl-format
 msgid "warning: sendmail alias with quotes is not supported: %s\n"
 msgstr ""
 "attention : les guillemets ne sont pas supportés dans alias sendmail : %s\n"
 
-#: git-send-email.perl:515
+#: git-send-email.perl:558
 #, perl-format
 msgid "warning: `:include:` not supported: %s\n"
 msgstr "attention : `:include:` n'est pas supporté : %s\n"
 
-#: git-send-email.perl:517
+#: git-send-email.perl:560
 #, perl-format
 msgid "warning: `/file` or `|pipe` redirection not supported: %s\n"
 msgstr ""
 "attention : les redirections `/file` ou `|pipe` ne sont pas supportées : %s\n"
 
-#: git-send-email.perl:522
+#: git-send-email.perl:565
 #, perl-format
 msgid "warning: sendmail line is not recognized: %s\n"
 msgstr "attention : ligne sendmail non reconnue : %s\n"
 
-#: git-send-email.perl:604
+#: git-send-email.perl:649
 #, perl-format
 msgid ""
 "File '%s' exists but it could also be the range of commits\n"
@@ -18257,12 +24391,12 @@ msgstr ""
 "    * en indiquant \"./%s\" si vous désignez un fichier, ou\n"
 "    * en fournissant l'option --format-patch pour une plage.\n"
 
-#: git-send-email.perl:625
+#: git-send-email.perl:670
 #, perl-format
 msgid "Failed to opendir %s: %s"
 msgstr "Échec à l'ouverture du répertoire %s : %s"
 
-#: git-send-email.perl:649
+#: git-send-email.perl:694
 #, perl-format
 msgid ""
 "fatal: %s: %s\n"
@@ -18271,7 +24405,7 @@ msgstr ""
 "fatal : %s : %s\n"
 "attention : aucun patch envoyé\n"
 
-#: git-send-email.perl:660
+#: git-send-email.perl:705
 msgid ""
 "\n"
 "No patch files specified!\n"
@@ -18281,17 +24415,17 @@ msgstr ""
 "Aucun fichier patch spécifié !\n"
 "\n"
 
-#: git-send-email.perl:673
+#: git-send-email.perl:718
 #, perl-format
 msgid "No subject line in %s?"
 msgstr "Ligne de sujet non trouvée dans %s ?"
 
-#: git-send-email.perl:683
+#: git-send-email.perl:728
 #, perl-format
 msgid "Failed to open for writing %s: %s"
 msgstr "Impossible d'ouvrir %s en écriture : %s"
 
-#: git-send-email.perl:694
+#: git-send-email.perl:739
 msgid ""
 "Lines beginning in \"GIT:\" will be removed.\n"
 "Consider including an overall diffstat or table of contents\n"
@@ -18305,27 +24439,27 @@ msgstr ""
 "\n"
 "Effacez le corps si vous ne souhaitez pas envoyer un résumé.\n"
 
-#: git-send-email.perl:718
+#: git-send-email.perl:763
 #, perl-format
 msgid "Failed to open %s: %s"
 msgstr "Échec à l'ouverture de %s : %s"
 
-#: git-send-email.perl:735
+#: git-send-email.perl:780
 #, perl-format
 msgid "Failed to open %s.final: %s"
 msgstr "Échec à l'ouverture de %s.final : %s"
 
-#: git-send-email.perl:778
+#: git-send-email.perl:823
 msgid "Summary email is empty, skipping it\n"
-msgstr "Le courriel de résumé etant vide, il a été ignoré\n"
+msgstr "Le courriel de résumé étant vide, il a été ignoré\n"
 
 #. TRANSLATORS: please keep [y/N] as is.
-#: git-send-email.perl:813
+#: git-send-email.perl:858
 #, perl-format
 msgid "Are you sure you want to use <%s> [y/N]? "
 msgstr "Êtes-vous sur de vouloir utiliser <%s> [y/N] ? "
 
-#: git-send-email.perl:868
+#: git-send-email.perl:913
 msgid ""
 "The following files are 8bit, but do not declare a Content-Transfer-"
 "Encoding.\n"
@@ -18333,11 +24467,11 @@ msgstr ""
 "Les fichiers suivants sont 8bit mais ne déclarent pas de champs Content-"
 "Transfer-Encoding.\n"
 
-#: git-send-email.perl:873
+#: git-send-email.perl:918
 msgid "Which 8bit encoding should I declare [UTF-8]? "
 msgstr "Quel encodage 8bit doit être déclaré [UTF8] ? "
 
-#: git-send-email.perl:881
+#: git-send-email.perl:926
 #, perl-format
 msgid ""
 "Refusing to send because the patch\n"
@@ -18350,22 +24484,22 @@ msgstr ""
 "a un sujet modèle '*** SUBJECT HERE ***'. Passez --force is vous souhaitez "
 "vraiment envoyer.\n"
 
-#: git-send-email.perl:900
+#: git-send-email.perl:945
 msgid "To whom should the emails be sent (if anyone)?"
 msgstr "À qui les courriels doivent-ils être envoyés (s'il y en a) ?"
 
-#: git-send-email.perl:918
+#: git-send-email.perl:963
 #, perl-format
 msgid "fatal: alias '%s' expands to itself\n"
 msgstr "fatal : l'alias '%s' se développe en lui-même\n"
 
-#: git-send-email.perl:930
+#: git-send-email.perl:975
 msgid "Message-ID to be used as In-Reply-To for the first email (if any)? "
 msgstr ""
 "Message-ID à utiliser comme In-Reply-To pour le premier courriel (s'il y en "
 "a) ? "
 
-#: git-send-email.perl:988 git-send-email.perl:996
+#: git-send-email.perl:1033 git-send-email.perl:1041
 #, perl-format
 msgid "error: unable to extract a valid address from: %s\n"
 msgstr "erreur : impossible d'extraire une adresse valide depuis : %s\n"
@@ -18373,16 +24507,16 @@ msgstr "erreur : impossible d'extraire
 #. TRANSLATORS: Make sure to include [q] [d] [e] in your
 #. translation. The program will only accept English input
 #. at this point.
-#: git-send-email.perl:1000
+#: git-send-email.perl:1045
 msgid "What to do with this address? ([q]uit|[d]rop|[e]dit): "
 msgstr "Que faire de cette adresse ? ([q]uitter|[d]élaisser|[e]diter): "
 
-#: git-send-email.perl:1317
+#: git-send-email.perl:1362
 #, perl-format
 msgid "CA path \"%s\" does not exist"
 msgstr "le chemin vers la CA \"%s\" n'existe pas"
 
-#: git-send-email.perl:1400
+#: git-send-email.perl:1445
 msgid ""
 "    The Cc list above has been expanded by additional\n"
 "    addresses found in the patch commit message. By default\n"
@@ -18409,1082 +24543,130 @@ msgstr ""
 #. TRANSLATORS: Make sure to include [y] [n] [e] [q] [a] in your
 #. translation. The program will only accept English input
 #. at this point.
-#: git-send-email.perl:1415
+#: git-send-email.perl:1460
 msgid "Send this email? ([y]es|[n]o|[e]dit|[q]uit|[a]ll): "
 msgstr "Envoyer ce courriel ? ([y]es|[n]o|[e]dit|[q]uit|[a]ll) : "
 
-#: git-send-email.perl:1418
+#: git-send-email.perl:1463
 msgid "Send this email reply required"
 msgstr "Une réponse est nécessaire"
 
-#: git-send-email.perl:1446
+#: git-send-email.perl:1491
 msgid "The required SMTP server is not properly defined."
 msgstr "Le serveur SMTP nécessaire n'est pas défini correctement."
 
-#: git-send-email.perl:1493
+#: git-send-email.perl:1538
 #, perl-format
 msgid "Server does not support STARTTLS! %s"
 msgstr "Le serveur ne supporte pas STARTTLS ! %s"
 
-#: git-send-email.perl:1498 git-send-email.perl:1502
+#: git-send-email.perl:1543 git-send-email.perl:1547
 #, perl-format
 msgid "STARTTLS failed! %s"
-msgstr "echec de STARTTLS ! %s"
+msgstr "échec de STARTTLS ! %s"
 
-#: git-send-email.perl:1512
+#: git-send-email.perl:1556
 msgid "Unable to initialize SMTP properly. Check config and use --smtp-debug."
 msgstr ""
 "Impossible d'initialiser SMTP. Vérifiez la configuration et utilisez --smtp-"
 "debug."
 
-#: git-send-email.perl:1530
+#: git-send-email.perl:1574
 #, perl-format
 msgid "Failed to send %s\n"
 msgstr "échec de l'envoi de %s\n"
 
-#: git-send-email.perl:1533
+#: git-send-email.perl:1577
 #, perl-format
 msgid "Dry-Sent %s\n"
 msgstr "Envoi simulé de %s\n"
 
-#: git-send-email.perl:1533
+#: git-send-email.perl:1577
 #, perl-format
 msgid "Sent %s\n"
 msgstr "%s envoyé\n"
 
-#: git-send-email.perl:1535
+#: git-send-email.perl:1579
 msgid "Dry-OK. Log says:\n"
 msgstr "Simulation OK. Le journal indique :\n"
 
-#: git-send-email.perl:1535
+#: git-send-email.perl:1579
 msgid "OK. Log says:\n"
 msgstr "OK. Le journal indique :\n"
 
-#: git-send-email.perl:1547
+#: git-send-email.perl:1591
 msgid "Result: "
 msgstr "Résultat : "
 
-#: git-send-email.perl:1550
+#: git-send-email.perl:1594
 msgid "Result: OK\n"
 msgstr "Résultat : OK\n"
 
-#: git-send-email.perl:1568
+#: git-send-email.perl:1612
 #, perl-format
 msgid "can't open file %s"
 msgstr "impossible d'ouvrir le fichier %s"
 
-#: git-send-email.perl:1615 git-send-email.perl:1635
+#: git-send-email.perl:1659 git-send-email.perl:1679
 #, perl-format
 msgid "(mbox) Adding cc: %s from line '%s'\n"
 msgstr "(mbox) Ajout de cc: %s depuis la ligne '%s'\n"
 
-#: git-send-email.perl:1621
+#: git-send-email.perl:1665
 #, perl-format
 msgid "(mbox) Adding to: %s from line '%s'\n"
 msgstr "(mbox) Ajout de to: %s depuis la ligne '%s'\n"
 
-#: git-send-email.perl:1674
+#: git-send-email.perl:1718
 #, perl-format
 msgid "(non-mbox) Adding cc: %s from line '%s'\n"
 msgstr "(non-mbox) Ajout de cc: %s depuis la ligne '%s'\n"
 
-#: git-send-email.perl:1699
+#: git-send-email.perl:1753
 #, perl-format
 msgid "(body) Adding cc: %s from line '%s'\n"
 msgstr "(corps) Ajout de cc: %s depuis la ligne '%s'\n"
 
-#: git-send-email.perl:1817
+#: git-send-email.perl:1864
 #, perl-format
 msgid "(%s) Could not execute '%s'"
 msgstr "(%s) Impossible d'exécuter '%s'"
 
-#: git-send-email.perl:1824
+#: git-send-email.perl:1871
 #, perl-format
 msgid "(%s) Adding %s: %s from: '%s'\n"
 msgstr "(%s) Ajout de %s : %s depuis : '%s'\n"
 
-#: git-send-email.perl:1828
+#: git-send-email.perl:1875
 #, perl-format
 msgid "(%s) failed to close pipe to '%s'"
 msgstr "(%s) échec de la fermeture du pipe vers '%s'"
 
-#: git-send-email.perl:1855
+#: git-send-email.perl:1905
 msgid "cannot send message as 7bit"
 msgstr "impossible d'envoyer un message comme 7bit"
 
-#: git-send-email.perl:1863
+#: git-send-email.perl:1913
 msgid "invalid transfer encoding"
 msgstr "codage de transfert invalide"
 
-#: git-send-email.perl:1901 git-send-email.perl:1952 git-send-email.perl:1962
+#: git-send-email.perl:1954 git-send-email.perl:2006 git-send-email.perl:2016
 #, perl-format
 msgid "unable to open %s: %s\n"
 msgstr "impossible d'ouvrir %s :%s\n"
 
-#: git-send-email.perl:1904
+#: git-send-email.perl:1957
 #, perl-format
 msgid "%s: patch contains a line longer than 998 characters"
 msgstr "%s : le patch contient une ligne plus longue que 998 caractères"
 
-#: git-send-email.perl:1920
+#: git-send-email.perl:1974
 #, perl-format
 msgid "Skipping %s with backup suffix '%s'.\n"
 msgstr "%s sauté avec un suffix de sauvegarde '%s'.\n"
 
 #. TRANSLATORS: please keep "[y|N]" as is.
-#: git-send-email.perl:1924
+#: git-send-email.perl:1978
 #, perl-format
 msgid "Do you really want to send %s? [y|N]: "
 msgstr "Souhaitez-vous réellement envoyer %s ?[y|N] : "
-
-#~ msgid "Everyday Git With 20 Commands Or So"
-#~ msgstr "Git de tous les jours avec à peu près 20 commandes"
-
-#~ msgid "Could not open '%s' for writing"
-#~ msgstr "Impossible d'ouvrir '%s' en écriture"
-
-#~ msgid ""
-#~ "unexpected 1st line of squash message:\n"
-#~ "\n"
-#~ "\t%.*s"
-#~ msgstr ""
-#~ "première ligne de message de compression inattendue :\n"
-#~ "\n"
-#~ "\t%.*s"
-
-#~ msgid ""
-#~ "invalid 1st line of squash message:\n"
-#~ "\n"
-#~ "\t%.*s"
-#~ msgstr ""
-#~ "première ligne de message de compression invalide :\n"
-#~ "\n"
-#~ "\t%.*s"
-
-#~ msgid "BUG: returned path string doesn't match cwd?"
-#~ msgstr "BUG : le chemin renvoyé ne correspond pas à cwd ?"
-
-#~ msgid "Error in object"
-#~ msgstr "Erreur dans l'objet"
-
-#~ msgid "git fetch-pack: expected ACK/NAK, got EOF"
-#~ msgstr "git fetch-pack : ACK/NACK attendu, EOF reçu"
-
-#~ msgid "invalid filter-spec expression '%s'"
-#~ msgstr "expression de filtre invalide : '%s'"
-
-#~ msgid "The copy of the patch that failed is found in: %s"
-#~ msgstr "La copie du patch qui a échoué se trouve dans : %s"
-
-#~ msgid "pathspec and --all are incompatible"
-#~ msgstr "un spécificateur de chemin et --all sont incompatibles"
-
-#~ msgid "Submodule '$name' ($url) unregistered for path '$displaypath'"
-#~ msgstr ""
-#~ "Le sous-module '$name' ($url) n'est pas enregistré pour le chemin "
-#~ "'$displaypath'"
-
-#~ msgid "To/Cc/Bcc fields are not interpreted yet, they have been ignored\n"
-#~ msgstr ""
-#~ "Les champs To/CC/Bcc ne sont pas encore interprétés, ils ont été ignorés\n"
-
-#~ msgid ""
-#~ "empty strings as pathspecs will be made invalid in upcoming releases. "
-#~ "please use . instead if you meant to match all paths"
-#~ msgstr ""
-#~ "les chaines de caractères vides comme spécificateurs de chemin seront "
-#~ "invalides dans les prochaines versions. Veuillez utiliser . à la place "
-#~ "pour correspondre à tous le chemins"
-
-#~ msgid "unable to open '%s' for writing"
-#~ msgstr "impossible d'ouvrir '%s' en écriture"
-
-#~ msgid "could not truncate '%s'"
-#~ msgstr "impossible de tronquer '%s'"
-
-#~ msgid "could not finish '%s'"
-#~ msgstr "impossible de finir '%s'"
-
-#~ msgid "could not write to %s"
-#~ msgstr "Impossible d'écrire dans %s"
-
-#~ msgid "could not close %s"
-#~ msgstr "impossible de fermer %s"
-
-#~ msgid "Copied a misnamed branch '%s' away"
-#~ msgstr "Copie d'une branche mal nommée '%s'"
-
-#~ msgid "it does not make sense to create 'HEAD' manually"
-#~ msgstr "créer manuellement 'HEAD' n'a pas de sens"
-
-#~ msgid "Don't know how to clone %s"
-#~ msgstr "Je ne sais pas cloner %s"
-
-#~ msgid "show ignored files"
-#~ msgstr "afficher les fichiers ignorés"
-
-#~ msgid "%s is not a valid '%s' object"
-#~ msgstr "%s n'est pas un objet '%s' valide"
-
-#~ msgid "Don't know how to fetch from %s"
-#~ msgstr "Je ne sais pas récupérer depuis %s"
-
-#~ msgid "'$term' is not a valid term"
-#~ msgstr "'$term' n'est pas un terme valide"
-
-#~ msgid ""
-#~ "error: unknown option for 'stash save': $option\n"
-#~ "       To provide a message, use git stash save -- '$option'"
-#~ msgstr ""
-#~ "erreur: option inconnue pour 'stash save': $option\n"
-#~ "        Pour fournir un message, utilisez git stash save -- '$option'"
-
-#~ msgid "Failed to recurse into submodule path '$sm_path'"
-#~ msgstr "Échec de parcours dans le chemin du sous-module '$sm_path'"
-
-#~ msgid "%%(trailers) does not take arguments"
-#~ msgstr "%%(trailers) n'accepte pas d'argument"
-
-#~ msgid "submodule update strategy not supported for submodule '%s'"
-#~ msgstr ""
-#~ "stratégie de mise à jour de sous-module non supportée pour le sous-module "
-#~ "'%s'"
-
-#~ msgid "change upstream info"
-#~ msgstr "modifier l'information amont"
-
-#~ msgid ""
-#~ "\n"
-#~ "If you wanted to make '%s' track '%s', do this:\n"
-#~ "\n"
-#~ msgstr ""
-#~ "\n"
-#~ "Si vous vouliez que '%s' suive '%s', faites ceci :\n"
-#~ "\n"
-
-#~ msgid "basename"
-#~ msgstr "nom de base"
-
-#~ msgid "prepend parent project's basename to output"
-#~ msgstr "préfixer le nom de base du projet parent à la sortie"
-
-#~ msgid ""
-#~ "Warning: the SHA-1 is missing or isn't a commit in the following line:\n"
-#~ " - $line"
-#~ msgstr ""
-#~ "Attention : le SHA-1 manque ou n'est pas un commit dans la ligne "
-#~ "suivante :\n"
-#~ " - $line"
-
-#~ msgid ""
-#~ "Warning: the command isn't recognized in the following line:\n"
-#~ " - $line"
-#~ msgstr ""
-#~ "Attention : la commande n'est pas reconnue dans le ligne suivante :\n"
-#~ " - $line"
-
-#~ msgid "Or you can abort the rebase with 'git rebase --abort'."
-#~ msgstr ""
-#~ "Ou bien vous pouvez abandonner le rebasage avec 'git rebase --abort'."
-
-#~ msgid "Could not open file '%s'"
-#~ msgstr "impossible d'ouvrir le fichier '%s'"
-
-#~ msgid "in %0.1f seconds automatically..."
-#~ msgstr "dans %0.1f secondes automatiquement..."
-
-#~ msgid "dup2(%d,%d) failed"
-#~ msgstr "échec de dup2(%d,%d)"
-
-#~ msgid "Initial commit on "
-#~ msgstr "Validation initiale sur "
-
-#~ msgid "Patch is empty. Was it split wrong?"
-#~ msgstr "Le patch est vide. Le découpage était-il bon ?"
-
-#~ msgid ""
-#~ "You still have unmerged paths in your index.\n"
-#~ "Did you forget to use 'git add'?"
-#~ msgstr ""
-#~ "Vous avez toujours des chemins non fusionnés dans votre index\n"
-#~ "Auriez-vous oublié de faire 'git add' ?"
-
-#~ msgid ""
-#~ "Cannot update paths and switch to branch '%s' at the same time.\n"
-#~ "Did you intend to checkout '%s' which can not be resolved as commit?"
-#~ msgstr ""
-#~ "Impossible de mettre à jour les chemins et de basculer sur la branche "
-#~ "'%s' en même temps.\n"
-#~ "Souhaitiez-vous extraire '%s' qui ne peut être résolu comme commit ?"
-
-#~ msgid "Explicit paths specified without -i or -o; assuming --only paths..."
-#~ msgstr "Chemins explicites spécifiés sans -i ni -o ; --only supposé..."
-
-#~ msgid "default mode for recursion"
-#~ msgstr "mode par défaut pour la récursion"
-
-#~ msgid "submodule--helper subcommand must be called with a subcommand"
-#~ msgstr ""
-#~ "la sous-commande submodule--helper doit être appelée avec une sous-"
-#~ "commande"
-
-#~ msgid "could not stat '%s"
-#~ msgstr "stat impossible de '%s'"
-
-#~ msgid "tag: tagging "
-#~ msgstr "étiquette: étiquetage de "
-
-#~ msgid "object of unknown type"
-#~ msgstr "objet de type inconnu"
-
-#~ msgid "commit object"
-#~ msgstr "objet commit"
-
-#~ msgid "tree object"
-#~ msgstr "objet arbre"
-
-#~ msgid "blob object"
-#~ msgstr "objet blob"
-
-#~ msgid ""
-#~ "There is nothing to exclude from by :(exclude) patterns.\n"
-#~ "Perhaps you forgot to add either ':/' or '.' ?"
-#~ msgstr ""
-#~ "Il n'y a rien dont il faut exclure par des motifs :(exclure).\n"
-#~ "Peut-être avez-vous oublié d'ajouter ':/' ou '.' ?"
-
-#~ msgid "unrecognized format: %%(%s)"
-#~ msgstr "format non reconnu %%(%s)"
-
-#~ msgid ":strip= requires a positive integer argument"
-#~ msgstr ":strip= requiert un argument entier positif"
-
-#~ msgid "ref '%s' does not have %ld components to :strip"
-#~ msgstr "la réf '%s' n'a pas %ld composants à :strip"
-
-#~ msgid "unknown %.*s format %s"
-#~ msgstr "format de %.*s inconnu %s"
-
-# féminin pour une branche
-#~ msgid "[%s: gone]"
-#~ msgstr "[%s: disparue]"
-
-#~ msgid "[%s]"
-#~ msgstr "[%s]"
-
-#~ msgid "[%s: behind %d]"
-#~ msgstr "[%s: en retard de %d]"
-
-#~ msgid "[%s: ahead %d]"
-#~ msgstr "[%s : en avance de %d]"
-
-#~ msgid "[%s: ahead %d, behind %d]"
-#~ msgstr "[%s : en avance de %d, en retard de %d]"
-
-#~ msgid " **** invalid ref ****"
-#~ msgstr " **** référence invalide ****"
-
-#~ msgid "insanely long object directory %.*s"
-#~ msgstr "objet répertoire démentiellement long %.*s"
-
-#~ msgid "git merge [<options>] <msg> HEAD <commit>"
-#~ msgstr "git merge [<options>] <message> HEAD <commit>"
-
-#~ msgid "cannot open file '%s'"
-#~ msgstr "impossible d'ouvrir le fichier '%s'"
-
-#~ msgid "could not close file %s"
-#~ msgstr "impossible de fermer le fichier %s"
-
-#~ msgid "tag name too long: %.*s..."
-#~ msgstr "nom d'étiquette trop long : %.*s..."
-
-#~ msgid "tag header too big."
-#~ msgstr "en-tête d'étiquette trop gros."
-
-#~ msgid ""
-#~ "If the patch applies cleanly, the edited hunk will immediately be\n"
-#~ "marked for discarding"
-#~ msgstr ""
-#~ "Si le patch s'applique proprement, la section éditée sera\n"
-#~ "immediatement marquée comme éliminée"
-
-#~ msgid "Use an experimental blank-line-based heuristic to improve diffs"
-#~ msgstr ""
-#~ "Utiliser une heuristique expérimentale reposant sur les lignes vides pour "
-#~ "améliorer le diffs"
-
-#~ msgid "Clever... amending the last one with dirty index."
-#~ msgstr "Malin... correction du dernier avec un index sale."
-
-#~ msgid ""
-#~ "the following submodule (or one of its nested submodules)\n"
-#~ "uses a .git directory:"
-#~ msgid_plural ""
-#~ "the following submodules (or one of their nested submodules)\n"
-#~ "use a .git directory:"
-#~ msgstr[0] ""
-#~ "le sous-module suivant (ou un de ses sous-modules imbriqués)\n"
-#~ "utilise un répertoire .git :"
-#~ msgstr[1] ""
-#~ "les sous-modules suivants (ou un de leurs sous-modules imbriqués)\n"
-#~ "utilisent un répertoire .git :"
-
-#~ msgid ""
-#~ "\n"
-#~ "(use 'rm -rf' if you really want to remove it including all of its "
-#~ "history)"
-#~ msgstr ""
-#~ "\n"
-#~ "(utilisez 'rm -rf' si vous voulez vraiment le supprimer en incluant tout "
-#~ "son historique)"
-
-#~ msgid "Error wrapping up %s."
-#~ msgstr "Erreur lors de l'emballage de %s."
-
-#~ msgid "Your local changes would be overwritten by cherry-pick."
-#~ msgstr "Vos modifications locales seraient écrasées par cherry-pick."
-
-#~ msgid "Cannot revert during another revert."
-#~ msgstr "Impossible d'annuler un commit pendant l'annulation d'un commit."
-
-#~ msgid "Cannot cherry-pick during another cherry-pick."
-#~ msgstr "Impossible de picorer pendant un autre picorage."
-
-#~ msgid "Could not parse line %d."
-#~ msgstr "Impossible d'analyser la ligne %d."
-
-#~ msgid "Could not open %s"
-#~ msgstr "Impossible d'ouvrir %s"
-
-#~ msgid "Could not read %s."
-#~ msgstr "Impossible de lire %s."
-
-#~ msgid "Could not format %s."
-#~ msgstr "Impossible de formater %s."
-
-#~ msgid "%s: %s"
-#~ msgstr "%s : %s"
-
-#~ msgid "cannot open %s: %s"
-#~ msgstr "impossible d'ouvrir %s : %s"
-
-#~ msgid "You need to set your committer info first"
-#~ msgstr "Vous devez d'abord définir vos informations de validateur"
-
-#~ msgid "This is the 2nd commit message:"
-#~ msgstr "Ceci est le deuxième message de validation :"
-
-#~ msgid "This is the 3rd commit message:"
-#~ msgstr "Ceci est le troisième message de validation :"
-
-#~ msgid "This is the 4th commit message:"
-#~ msgstr "Ceci est le quatrième message de validation :"
-
-#~ msgid "This is the 5th commit message:"
-#~ msgstr "Ceci est le cinquième message de validation :"
-
-#~ msgid "This is the 6th commit message:"
-#~ msgstr "Ceci est le sixième message de validation :"
-
-#~ msgid "This is the 7th commit message:"
-#~ msgstr "Ceci est le septième message de validation :"
-
-#~ msgid "This is the 8th commit message:"
-#~ msgstr "Ceci est le huitième message de validation :"
-
-#~ msgid "This is the 9th commit message:"
-#~ msgstr "Ceci est le neuvième message de validation :"
-
-#~ msgid "This is the 10th commit message:"
-#~ msgstr "Ceci est le dixième message de validation :"
-
-#~ msgid "This is the ${n}th commit message:"
-#~ msgstr "Ceci est le ${n}ième message de validation :"
-
-#~ msgid "This is the ${n}st commit message:"
-#~ msgstr "Ceci est le ${n}ième message de validation :"
-
-#~ msgid "This is the ${n}nd commit message:"
-#~ msgstr "Ceci est le ${n}ième message de validation :"
-
-#~ msgid "This is the ${n}rd commit message:"
-#~ msgstr "Ceci est le ${n}ième message de validation :"
-
-#~ msgid "The 1st commit message will be skipped:"
-#~ msgstr "Le premier message de validation sera ignoré :"
-
-#~ msgid "The 2nd commit message will be skipped:"
-#~ msgstr "Le deuxième message de validation sera ignoré :"
-
-#~ msgid "The 3rd commit message will be skipped:"
-#~ msgstr "Le troisième message de validation sera ignoré :"
-
-#~ msgid "The 4th commit message will be skipped:"
-#~ msgstr "Le quatrième message de validation sera ignoré :"
-
-#~ msgid "The 5th commit message will be skipped:"
-#~ msgstr "Le cinquième message de validation sera ignoré :"
-
-#~ msgid "The 6th commit message will be skipped:"
-#~ msgstr "Le sixième message de validation sera ignoré :"
-
-#~ msgid "The 7th commit message will be skipped:"
-#~ msgstr "Le septième message de validation sera ignoré :"
-
-#~ msgid "The 8th commit message will be skipped:"
-#~ msgstr "Le huitième message de validation sera ignoré :"
-
-#~ msgid "The 9th commit message will be skipped:"
-#~ msgstr "Le neuvième message de validation sera ignoré :"
-
-#~ msgid "The 10th commit message will be skipped:"
-#~ msgstr "Le dixième message de validation sera ignoré :"
-
-#~ msgid "The ${n}th commit message will be skipped:"
-#~ msgstr "le ${n}ième message de validation sera ignoré :"
-
-#~ msgid "The ${n}st commit message will be skipped:"
-#~ msgstr "Le message de validation ${n} sera ignoré :"
-
-#~ msgid "The ${n}nd commit message will be skipped:"
-#~ msgstr "Le message de validation ${n} sera ignoré :"
-
-#~ msgid "The ${n}rd commit message will be skipped:"
-#~ msgstr "Le message de validation ${n} sera ignoré :"
-
-#~ msgid "could not run gpg."
-#~ msgstr "impossible de lancer gpg."
-
-#~ msgid "gpg did not accept the data"
-#~ msgstr "gpg n'a pas accepté les données"
-
-#~ msgid "unsupported object type in the tree"
-#~ msgstr "type d'objet non supporté dans l'arbre"
-
-#~ msgid "Fatal merge failure, shouldn't happen."
-#~ msgstr "Échec fatal de fusion, qui ne devrait jamais arriver."
-
-#~ msgid "Unprocessed path??? %s"
-#~ msgstr "Chemin non traité ??? %s"
-
-#~ msgid "Cannot %s during a %s"
-#~ msgstr "Impossible de %s pendant un %s"
-
-#~ msgid "Can't cherry-pick into empty head"
-#~ msgstr "Impossible de picorer vers une HEAD vide"
-
-#~ msgid "could not open %s for writing"
-#~ msgstr "Impossible d'ouvrir '%s' en écriture"
-
-#~ msgid "bug: unhandled unmerged status %x"
-#~ msgstr "bogue : état de non-fusion non géré %x"
-
-#~ msgid "bug: unhandled diff status %c"
-#~ msgstr "bogue : état de diff non géré %c"
-
-#~ msgid "could not write branch description template"
-#~ msgstr "impossible d'écrire le modèle de description de branche"
-
-#~ msgid "corrupt index file"
-#~ msgstr "fichier d'index corrompu"
-
-#~ msgid "detach the HEAD at named commit"
-#~ msgstr "détacher la HEAD à la validation nommée"
-
-#~ msgid "Checking connectivity... "
-#~ msgstr "Vérification de la connectivité... "
-
-#~ msgid "  (unable to update local ref)"
-#~ msgstr "  (impossible de mettre à jour la référence locale)"
-
-#~ msgid "Reinitialized existing"
-#~ msgstr "existant réinitialisé"
-
-#~ msgid "Initialized empty"
-#~ msgstr "vide initialisé"
-
-#~ msgid " shared"
-#~ msgstr " partagé"
-
-#~ msgid "Verify that the named commit has a valid GPG signature"
-#~ msgstr "Vérifier que la validation a une signature GPG valide"
-
-#~ msgid "Writing SQUASH_MSG"
-#~ msgstr "Écriture de SQUASH_MSG"
-
-#~ msgid "Finishing SQUASH_MSG"
-#~ msgstr "Finition de SQUASH_MSG"
-
-#~ msgid "   and with remote"
-#~ msgstr "   et avec la distante"
-
-#~ msgid "removing '%s' failed"
-#~ msgstr "la suppression de '%s' a échoué"
-
-#~ msgid "program error"
-#~ msgstr "erreur du programme"
-
-#~ msgid "Please call 'bisect_state' with at least one argument."
-#~ msgstr "Veuillez appeler 'bisect_state' avec au moins un argument."
-
-#~ msgid ""
-#~ "If you want to reuse this local git directory instead of cloning again "
-#~ "from"
-#~ msgstr ""
-#~ "Si vous voulez réutiliser ce répertoire git local au lieu de cloner à "
-#~ "nouveau depuis"
-
-#~ msgid ""
-#~ "use the '--force' option. If the local git directory is not the correct "
-#~ "repo"
-#~ msgstr ""
-#~ "utilisez l'option '--force'. Si le répertoire local git n'est pas le "
-#~ "dépôt correct"
-
-#~ msgid ""
-#~ "or you are unsure what this means choose another name with the '--name' "
-#~ "option."
-#~ msgstr ""
-#~ "ou si vous ne savez pas ce que cela signifie, choisissez un autre nom "
-#~ "avec l'option '--name'."
-
-#~ msgid "Submodule work tree '$displaypath' contains a .git directory"
-#~ msgstr ""
-#~ "La copie de travail du sous-module '$displaypath' contient un répertoire ."
-#~ "git"
-
-#~ msgid ""
-#~ "(use 'rm -rf' if you really want to remove it including all of its "
-#~ "history)"
-#~ msgstr ""
-#~ "(utilisez 'rm -rf' si vous voulez vraiment le supprimer en incluant tout "
-#~ "son historique)"
-
-#~ msgid "'%s': %s"
-#~ msgstr "'%s' : %s"
-
-#~ msgid "unable to access '%s': %s"
-#~ msgstr "impossible d'accéder à '%s' : %s"
-
-#~ msgid "    git branch -d %s\n"
-#~ msgstr "    git branch -d %s\n"
-
-#~ msgid "    git branch --set-upstream-to %s\n"
-#~ msgstr "    git branch --set-upstream-to %s\n"
-
-#~ msgid "cannot open %s: %s\n"
-#~ msgstr "impossible d'ouvrir %s : %s\n"
-
-#~ msgid "Please, stage your changes to .gitmodules or stash them to proceed"
-#~ msgstr ""
-#~ "Veuillez indexer vos modifications de .gitmodules ou remisez-les pour "
-#~ "continuer"
-
-#~ msgid "failed to remove: %s"
-#~ msgstr "échec de la suppression de %s"
-
-#~ msgid "The --exec option must be used with the --interactive option"
-#~ msgstr "L'option --exec doit être utilisée avec l'option --interactive"
-
-#~ msgid ""
-#~ "Submodule path '$displaypath' not initialized\n"
-#~ "Maybe you want to use 'update --init'?"
-#~ msgstr ""
-#~ "Chemin de sous-module '$displaypath' non initialisé\n"
-#~ "Peut-être souhaitez-vous utiliser 'update --init' ?"
-
-#~ msgid "Forward-port local commits to the updated upstream head"
-#~ msgstr ""
-#~ "Reporter les validations locales sur le sommet mis à jour d'une branche "
-#~ "amont"
-
-#~ msgid "improper format entered align:%s"
-#~ msgstr "format non convenable align:%s"
-
-#~ msgid "Could not set core.worktree in %s"
-#~ msgstr "Impossible de paramétrer core.worktree dans %s"
-
-#~ msgid ""
-#~ "push.default is unset; its implicit value has changed in\n"
-#~ "Git 2.0 from 'matching' to 'simple'. To squelch this message\n"
-#~ "and maintain the traditional behavior, use:\n"
-#~ "\n"
-#~ "  git config --global push.default matching\n"
-#~ "\n"
-#~ "To squelch this message and adopt the new behavior now, use:\n"
-#~ "\n"
-#~ "  git config --global push.default simple\n"
-#~ "\n"
-#~ "When push.default is set to 'matching', git will push local branches\n"
-#~ "to the remote branches that already exist with the same name.\n"
-#~ "\n"
-#~ "Since Git 2.0, Git defaults to the more conservative 'simple'\n"
-#~ "behavior, which only pushes the current branch to the corresponding\n"
-#~ "remote branch that 'git pull' uses to update the current branch.\n"
-#~ "\n"
-#~ "See 'git help config' and search for 'push.default' for further "
-#~ "information.\n"
-#~ "(the 'simple' mode was introduced in Git 1.7.11. Use the similar mode\n"
-#~ "'current' instead of 'simple' if you sometimes use older versions of Git)"
-#~ msgstr ""
-#~ "push.default n'est pas défini ; sa valeur implicite a changé dans Git "
-#~ "2.0\n"
-#~ "de 'matching' vers 'simple'. Pour supprimer ce message et maintenir\n"
-#~ "le comportement actuel après la modification de la valeur de défaut, "
-#~ "utilisez :\n"
-#~ "\n"
-#~ "  git config --global push.default matching\n"
-#~ "\n"
-#~ "Pour supprimer ce message et adopter le nouveau comportement maintenant, "
-#~ "utilisez :\n"
-#~ "\n"
-#~ "  git config --global push.default simple\n"
-#~ "\n"
-#~ "Quand push.default vaudra 'matching', git poussera les branches locales\n"
-#~ "sur les branches distantes qui existent déjà avec le même nom.\n"
-#~ "\n"
-#~ "Depuis Git 2.0, Git utilise par défaut le comportement plus conservatif "
-#~ "'simple'\n"
-#~ "qui ne pousse la branche courante que vers la branche distante "
-#~ "correspondante\n"
-#~ "que 'git pull' utilise pour mettre à jour la branche courante.\n"
-#~ " \n"
-#~ "Voir 'git help config' et chercher 'push.default' pour plus "
-#~ "d'information.\n"
-#~ "(le mode 'simple' a été introduit dans Git 1.7.11. Utilisez le mode "
-#~ "similaire\n"
-#~ "'current' au lieu de 'simple' si vous utilisez de temps en temps "
-#~ "d'anciennes versions de Git)"
-
-#~ msgid "check|on-demand|no"
-#~ msgstr "check|on-demand|no"
-
-#~ msgid "Could not append '%s'"
-#~ msgstr "Impossible d'ajouter '%s'"
-
-#~ msgid "Missing author: %s"
-#~ msgstr "Auteur manquant : %s"
-
-#~ msgid "Testing "
-#~ msgstr "Test en cours "
-
-#~ msgid "unable to look up current user in the passwd file: %s"
-#~ msgstr ""
-#~ "impossible de rechercher l'utilisateur actuel dans le fichier de mots de "
-#~ "passe : %s"
-
-#~ msgid "no such user"
-#~ msgstr "utilisateur inconnu"
-
-#~ msgid "branch '%s' does not point at a commit"
-#~ msgstr "la branche '%s' ne pointe pas sur un commit"
-
-#~ msgid "object '%s' does not point to a commit"
-#~ msgstr "l'objet '%s' ne pointe pas sur un commit"
-
-#~ msgid "some refs could not be read"
-#~ msgstr "des références n'ont pas pu être lues"
-
-#~ msgid "print only merged branches"
-#~ msgstr "afficher seulement les branches fusionnées"
-
-#~ msgid "--dissociate given, but there is no --reference"
-#~ msgstr "--dissociate est spécifié, mais --reference est absent"
-
-#~ msgid "show usage"
-#~ msgstr "afficher l'usage"
-
-#~ msgid "insanely long template name %s"
-#~ msgstr "nom de modèle démentiellement long %s"
-
-#~ msgid "insanely long symlink %s"
-#~ msgstr "lien symbolique démentiellement long %s"
-
-#~ msgid "insanely long template path %s"
-#~ msgstr "chemin de modèle %s démentiellement long"
-
-#~ msgid "insane git directory %s"
-#~ msgstr "répertoire git démentiel %s"
-
-#~ msgid "unsupported sort specification '%s'"
-#~ msgstr "spécification de tri non supportée '%s'"
-
-#~ msgid "unsupported sort specification '%s' in variable '%s'"
-#~ msgstr "spécification de tri non supportée '%s' dans le variable '%s'"
-
-#~ msgid "switch 'points-at' requires an object"
-#~ msgstr "le commutateur 'points-at' a besoin d'un objet"
-
-#~ msgid "sort tags"
-#~ msgstr "trier les étiquettes"
-
-#~ msgid "--sort and -n are incompatible"
-#~ msgstr "--sort et -n sont incompatibles"
-
-#~ msgid "Gitdir '$a' is part of the submodule path '$b' or vice versa"
-#~ msgstr ""
-#~ "Le répertoire Git '$a' fait partie du chemin de sous-module '$b' ou vice-"
-#~ "versa"
-
-#~ msgid "false|true|preserve"
-#~ msgstr "false|true|preserve"
-
-#~ msgid "BUG: reopen a lockfile that is still open"
-#~ msgstr "BUG: réouverture d'un fichier verrou déjà ouvert"
-
-#~ msgid "BUG: reopen a lockfile that has been committed"
-#~ msgstr "BUG: réouverture d'un fichier verrou validé"
-
-#~ msgid "option %s does not accept negative form"
-#~ msgstr "l'option %s n'accepte pas de valeur négative"
-
-#~ msgid "unable to parse value '%s' for option %s"
-#~ msgstr "impossible d'analyser la valeur '%s' pour l'option %s"
-
-#~ msgid "-b and -B are mutually exclusive"
-#~ msgstr "-b et -B sont mutuellement exclusifs"
-
-#~ msgid ""
-#~ "When you have resolved this problem, run \"$cmdline --continue\".\n"
-#~ "If you prefer to skip this patch, run \"$cmdline --skip\" instead.\n"
-#~ "To restore the original branch and stop patching, run \"$cmdline --abort"
-#~ "\"."
-#~ msgstr ""
-#~ "Lorsque vous aurez résolu ce problème, lancez \"$cmdline --continue\".\n"
-#~ "Si vous préférez sauter ce patch, lancez \"$cmdline --skip\" à la place.\n"
-#~ "Pour restaurer la branche d'origine et stopper le patchage, lancez "
-#~ "\"$cmdline --abort\"."
-
-#~ msgid "Patch format $patch_format is not supported."
-#~ msgstr "Le format de patch $patch_format n'est pas supporté."
-
-#~ msgid "Please make up your mind. --skip or --abort?"
-#~ msgstr "Décidez-vous. --skip ou --abort ?"
-
-#~ msgid ""
-#~ "Patch is empty.  Was it split wrong?\n"
-#~ "If you would prefer to skip this patch, instead run \"$cmdline --skip\".\n"
-#~ "To restore the original branch and stop patching run \"$cmdline --abort\"."
-#~ msgstr ""
-#~ "Le patch est vide.  Était-il mal découpé ?\n"
-#~ "Si vous préférez sauter ce patch, lancez plutôt \"$cmdline --skip\".\n"
-#~ "Pour restaurer la branche d'origine et stopper le patchage, lancez "
-#~ "\"$cmdline --abort\"."
-
-#~ msgid "Patch does not have a valid courriel address."
-#~ msgstr "Le patch n'a pas d'adresse courriel valide."
-
-#~ msgid "Applying: $FIRSTLINE"
-#~ msgstr "Application : $FIRSTLINE"
-
-#~ msgid "Patch failed at $msgnum $FIRSTLINE"
-#~ msgstr "Le patch a échoué à $msgnum $FIRSTLINE"
-
-#~ msgid ""
-#~ "Pull is not possible because you have unmerged files.\n"
-#~ "Please, fix them up in the work tree, and then use 'git add/rm <file>'\n"
-#~ "as appropriate to mark resolution and make a commit."
-#~ msgstr ""
-#~ "Le tirage n'est pas possible car vous avez des fichiers non fusionnés.\n"
-#~ "Veuillez les corriger dans votre copie de travail, utiliser alors 'git "
-#~ "add/rm <fichier>'\n"
-#~ "si nécessaire pour marquer comme résolu et valider."
-
-#~ msgid "no branch specified"
-#~ msgstr "aucune branche spécifiée"
-
-#~ msgid "prune .git/worktrees"
-#~ msgstr "éliminer .git/worktrees"
-
-#~ msgid "The most commonly used git commands are:"
-#~ msgstr "Les commandes git les plus utilisées sont :"
-
-#~ msgid "No such branch: '%s'"
-#~ msgstr "Branche inconnue : '%s'"
-
-#~ msgid "Could not create git link %s"
-#~ msgstr "Impossible de créer le lien git %s"
-
-#~ msgid "Invalid gc.pruneexpire: '%s'"
-#~ msgstr "gc.pruneexpire invalide : '%s'"
-
-#~ msgid "(detached from %s)"
-#~ msgstr "(détaché de %s)"
-
-#~ msgid "No existing author found with '%s'"
-#~ msgstr "Aucun auteur existant trouvé avec '%s'"
-
-#~ msgid "search also in ignored files"
-#~ msgstr "rechercher aussi dans les fichiers ignorés"
-
-#~ msgid "git remote set-head <name> (-a | --auto | -d | --delete |<branch>)"
-#~ msgstr "git remote set-head <nom> (-a | --auto | -d | --delete |<branche>)"
-
-#~ msgid "no files added"
-#~ msgstr "aucun fichier ajouté"
-
-#~ msgid "slot"
-#~ msgstr "emplacement"
-
-#~ msgid "Failed to lock ref for update"
-#~ msgstr "Échec du verrouillage de la référence pour mise à jour"
-
-#~ msgid "Failed to write ref"
-#~ msgstr "Échec de l'écriture de la référence"
-
-#~ msgid "Failed to lock HEAD during fast_forward_to"
-#~ msgstr "Échec du verrouillage de HEAD pendant l'avance rapide"
-
-#~ msgid "cannot lock HEAD ref"
-#~ msgstr "impossible de verrouiller la référence HEAD"
-
-#~ msgid "cannot update HEAD ref"
-#~ msgstr "impossible de mettre à jour la référence HEAD"
-
-#~ msgid "%s: cannot lock the ref"
-#~ msgstr "%s : impossible de verrouiller la référence"
-
-#~ msgid "%s: cannot update the ref"
-#~ msgstr "%s : impossible de mettre à jour la référence"
-
-#~ msgid "commit has empty message"
-#~ msgstr "le commit a un message vide"
-
-#~ msgid "Failed to chdir: %s"
-#~ msgstr "Échec de chdir: %s"
-
-#~ msgid "Tracking not set up: name too long: %s"
-#~ msgstr "Suivi de branche non paramétré : le nom est trop long : %s"
-
-#~ msgid "could not find .gitmodules in index"
-#~ msgstr "impossible de trouver .gitmodules dans l'index"
-
-#~ msgid "reading updated .gitmodules failed"
-#~ msgstr "échec de la lecture du .gitmodules mis à jour"
-
-#~ msgid "unable to stat updated .gitmodules"
-#~ msgstr "échec de stat du .gitmodules mis à jour"
-
-#~ msgid "unable to remove .gitmodules from index"
-#~ msgstr "suppression du .gitmodules dans l'index impossible"
-
-#~ msgid "adding updated .gitmodules failed"
-#~ msgstr "échec de l'ajout du .gitmodules mis à jour"
-
-#~ msgid "bug"
-#~ msgstr "bogue"
-
-#~ msgid ", behind "
-#~ msgstr ", derrière "
-
-#~ msgid ""
-#~ "The behavior of 'git add %s (or %s)' with no path argument from a\n"
-#~ "subdirectory of the tree will change in Git 2.0 and should not be used "
-#~ "anymore.\n"
-#~ "To add content for the whole tree, run:\n"
-#~ "\n"
-#~ "  git add %s :/\n"
-#~ "  (or git add %s :/)\n"
-#~ "\n"
-#~ "To restrict the command to the current directory, run:\n"
-#~ "\n"
-#~ "  git add %s .\n"
-#~ "  (or git add %s .)\n"
-#~ "\n"
-#~ "With the current Git version, the command is restricted to the current "
-#~ "directory.\n"
-#~ msgstr ""
-#~ "Le comportement de 'git add %s (ou %s)' sans argument de chemin depuis "
-#~ "un\n"
-#~ "sous-répertoire du projet va changer dans Git 2.0 et ne doit plus être "
-#~ "utilisé.\n"
-#~ "Pour ajouter le contenu de toute l'arborescence, lancez :\n"
-#~ "\n"
-#~ "  git add %s :/\n"
-#~ "  (ou git add %s :/)\n"
-#~ "\n"
-#~ "Pour restreindre la commande au répertoire courant, lancez :\n"
-#~ "\n"
-#~ "  git add %s .\n"
-#~ "  (ou git add %s .)\n"
-#~ "\n"
-#~ "Avec la version actuelle de Git, la commande est restreinte au répertoire "
-#~ "courant.\n"
-
-#~ msgid ""
-#~ "You ran 'git add' with neither '-A (--all)' or '--ignore-removal',\n"
-#~ "whose behaviour will change in Git 2.0 with respect to paths you "
-#~ "removed.\n"
-#~ "Paths like '%s' that are\n"
-#~ "removed from your working tree are ignored with this version of Git.\n"
-#~ "\n"
-#~ "* 'git add --ignore-removal <pathspec>', which is the current default,\n"
-#~ "  ignores paths you removed from your working tree.\n"
-#~ "\n"
-#~ "* 'git add --all <pathspec>' will let you also record the removals.\n"
-#~ "\n"
-#~ "Run 'git status' to check the paths you removed from your working tree.\n"
-#~ msgstr ""
-#~ "Vous avez lancé 'git add' sans '-A (--all)' ni '--ignore-removal',\n"
-#~ "dont le comportement va changer dans Git 2.0 avec le respect des chemins "
-#~ "que vous supprimez.\n"
-#~ "Les chemins tels que '%s' qui ont été\n"
-#~ "retirés de votre copie de travail sont ignorés avec cette version de "
-#~ "Git.\n"
-#~ "\n"
-#~ "* 'git add --ignore-removal <chemin>', qui est l'option par défaut "
-#~ "actuelle,\n"
-#~ "  ignore les chemins que vous avez supprimés de votre copie de travail.\n"
-#~ "\n"
-#~ "* 'git add --all <chemin>' permet d'enregistrer aussi les suppressions.\n"
-#~ "\n"
-#~ "Lancez 'git status' pour vérifier les chemins que vous avez supprimés de "
-#~ "votre copie de travail.\n"
-
-#~ msgid "key id"
-#~ msgstr "identifiant de clé"
-
-#~ msgid ""
-#~ "Auto packing the repository for optimum performance. You may also\n"
-#~ "run \"git gc\" manually. See \"git help gc\" for more information.\n"
-#~ msgstr ""
-#~ "Compression automatique du dépôt pour une performance optimum. Vous "
-#~ "pouvez aussi\n"
-#~ "lancer \"git gc\" manuellement. Voir \"git help gc\" pour plus "
-#~ "d'information.\n"
-
-#~ msgid ""
-#~ "Updates were rejected because a pushed branch tip is behind its remote\n"
-#~ "counterpart. If you did not intend to push that branch, you may want to\n"
-#~ "specify branches to push or set the 'push.default' configuration "
-#~ "variable\n"
-#~ "to 'simple', 'current' or 'upstream' to push only the current branch."
-#~ msgstr ""
-#~ "Les mises à jour ont été rejetées car la pointe de la branche poussée est "
-#~ "derrière\n"
-#~ "son homologue distant. Si vous ne vouliez pas pousser cette branche, vous "
-#~ "pourriez\n"
-#~ "vouloir spécifier les branches à pousser ou définir la variable de "
-#~ "configuration\n"
-#~ "'push.default' à 'simple', 'current' ou 'upstream' pour pousser seulement "
-#~ "la branche courante."
-
-#~ msgid "deleted:    %s"
-#~ msgstr "supprimé :  %s"
-
-#~ msgid "modified:   %s"
-#~ msgstr "modifié :   %s"
-
-#~ msgid "renamed:    %s -> %s"
-#~ msgstr "renommé :   %s -> %s"
-
-#~ msgid "unmerged:   %s"
-#~ msgstr "non fus. :  %s"
-
-#~ msgid "input paths are terminated by a null character"
-#~ msgstr "les chemins en entrée sont terminés par le caractère nul"
-
-#~ msgid ""
-#~ "Aborting. Consider using either the --force or --include-untracked option."
-#~ msgstr "Abandon. Utilisez l'option --force ou --include-untracked."
diff -pruN 1.2.1+git2.18.0-1/git/po/git.pot 1.2.3+git2.25.1-1/git/po/git.pot
--- 1.2.1+git2.18.0-1/git/po/git.pot	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/po/git.pot	2020-02-17 04:47:35.000000000 +0000
@@ -8,7 +8,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: PACKAGE VERSION\n"
 "Report-Msgid-Bugs-To: Git Mailing List <git@vger.kernel.org>\n"
-"POT-Creation-Date: 2018-06-16 22:06+0800\n"
+"POT-Creation-Date: 2019-12-30 08:48+0800\n"
 "PO-Revision-Date: YEAR-MO-DA HO:MI+ZONE\n"
 "Last-Translator: FULL NAME <EMAIL@ADDRESS>\n"
 "Language-Team: LANGUAGE <LL@li.org>\n"
@@ -18,15675 +18,21501 @@ msgstr ""
 "Content-Transfer-Encoding: 8bit\n"
 "Plural-Forms: nplurals=INTEGER; plural=EXPRESSION;\n"
 
-#: advice.c:92
+#: add-interactive.c:347
 #, c-format
-msgid "%shint: %.*s%s\n"
+msgid "Huh (%s)?"
 msgstr ""
 
-#: advice.c:137
-msgid "Cherry-picking is not possible because you have unmerged files."
+#: add-interactive.c:500 add-interactive.c:801 sequencer.c:3216
+#: sequencer.c:3656 builtin/rebase.c:871 builtin/rebase.c:1643
+#: builtin/rebase.c:2019 builtin/rebase.c:2063
+msgid "could not read index"
 msgstr ""
 
-#: advice.c:139
-msgid "Committing is not possible because you have unmerged files."
+#: add-interactive.c:555 git-add--interactive.perl:269
+#: git-add--interactive.perl:294
+msgid "binary"
 msgstr ""
 
-#: advice.c:141
-msgid "Merging is not possible because you have unmerged files."
+#: add-interactive.c:613 git-add--interactive.perl:278
+#: git-add--interactive.perl:332
+msgid "nothing"
 msgstr ""
 
-#: advice.c:143
-msgid "Pulling is not possible because you have unmerged files."
+#: add-interactive.c:614 git-add--interactive.perl:314
+#: git-add--interactive.perl:329
+msgid "unchanged"
 msgstr ""
 
-#: advice.c:145
-msgid "Reverting is not possible because you have unmerged files."
+#: add-interactive.c:651 git-add--interactive.perl:643
+msgid "Update"
 msgstr ""
 
-#: advice.c:147
+#: add-interactive.c:668 add-interactive.c:856
 #, c-format
-msgid "It is not possible to %s because you have unmerged files."
+msgid "could not stage '%s'"
 msgstr ""
 
-#: advice.c:155
-msgid ""
-"Fix them up in the work tree, and then use 'git add/rm <file>'\n"
-"as appropriate to mark resolution and make a commit."
+#: add-interactive.c:674 add-interactive.c:863 sequencer.c:3409
+#: builtin/rebase.c:895
+msgid "could not write index"
 msgstr ""
 
-#: advice.c:163
-msgid "Exiting because of an unresolved conflict."
+#: add-interactive.c:677 git-add--interactive.perl:628
+#, c-format, perl-format
+msgid "updated %d path\n"
+msgid_plural "updated %d paths\n"
+msgstr[0] ""
+msgstr[1] ""
+
+#: add-interactive.c:695 git-add--interactive.perl:678
+#, c-format, perl-format
+msgid "note: %s is untracked now.\n"
 msgstr ""
 
-#: advice.c:168 builtin/merge.c:1250
-msgid "You have not concluded your merge (MERGE_HEAD exists)."
+#: add-interactive.c:700 apply.c:4108 builtin/checkout.c:281
+#: builtin/reset.c:144
+#, c-format
+msgid "make_cache_entry failed for path '%s'"
 msgstr ""
 
-#: advice.c:170
-msgid "Please, commit your changes before merging."
+#: add-interactive.c:730 git-add--interactive.perl:655
+msgid "Revert"
 msgstr ""
 
-#: advice.c:171
-msgid "Exiting because of unfinished merge."
+#: add-interactive.c:746
+msgid "Could not parse HEAD^{tree}"
 msgstr ""
 
-#: advice.c:177
+#: add-interactive.c:784 git-add--interactive.perl:631
+#, c-format, perl-format
+msgid "reverted %d path\n"
+msgid_plural "reverted %d paths\n"
+msgstr[0] ""
+msgstr[1] ""
+
+#: add-interactive.c:835 git-add--interactive.perl:695
 #, c-format
-msgid ""
-"Note: checking out '%s'.\n"
-"\n"
-"You are in 'detached HEAD' state. You can look around, make experimental\n"
-"changes and commit them, and you can discard any commits you make in this\n"
-"state without impacting any branches by performing another checkout.\n"
-"\n"
-"If you want to create a new branch to retain commits you create, you may\n"
-"do so (now or later) by using -b with the checkout command again. Example:\n"
-"\n"
-"  git checkout -b <new-branch-name>\n"
-"\n"
+msgid "No untracked files.\n"
+msgstr ""
+
+#: add-interactive.c:839 git-add--interactive.perl:689
+msgid "Add untracked"
 msgstr ""
 
-#: apply.c:58
+#: add-interactive.c:866 git-add--interactive.perl:625
+#, c-format, perl-format
+msgid "added %d path\n"
+msgid_plural "added %d paths\n"
+msgstr[0] ""
+msgstr[1] ""
+
+#: add-interactive.c:896
 #, c-format
-msgid "unrecognized whitespace option '%s'"
+msgid "ignoring unmerged: %s"
 msgstr ""
 
-#: apply.c:74
+#: add-interactive.c:908 add-patch.c:1331 git-add--interactive.perl:1366
 #, c-format
-msgid "unrecognized whitespace ignore option '%s'"
+msgid "Only binary files changed.\n"
 msgstr ""
 
-#: apply.c:122
-msgid "--reject and --3way cannot be used together."
+#: add-interactive.c:910 add-patch.c:1329 git-add--interactive.perl:1368
+#, c-format
+msgid "No changes.\n"
 msgstr ""
 
-#: apply.c:124
-msgid "--cached and --3way cannot be used together."
+#: add-interactive.c:914 git-add--interactive.perl:1376
+msgid "Patch update"
 msgstr ""
 
-#: apply.c:127
-msgid "--3way outside a repository"
+#: add-interactive.c:953 git-add--interactive.perl:1754
+msgid "Review diff"
 msgstr ""
 
-#: apply.c:138
-msgid "--index outside a repository"
+#: add-interactive.c:981
+msgid "show paths with changes"
 msgstr ""
 
-#: apply.c:141
-msgid "--cached outside a repository"
+#: add-interactive.c:983
+msgid "add working tree state to the staged set of changes"
 msgstr ""
 
-#: apply.c:821
-#, c-format
-msgid "Cannot prepare timestamp regexp %s"
+#: add-interactive.c:985
+msgid "revert staged set of changes back to the HEAD version"
 msgstr ""
 
-#: apply.c:830
-#, c-format
-msgid "regexec returned %d for input: %s"
+#: add-interactive.c:987
+msgid "pick hunks and update selectively"
 msgstr ""
 
-#: apply.c:904
-#, c-format
-msgid "unable to find filename in patch at line %d"
+#: add-interactive.c:989
+msgid "view diff between HEAD and index"
 msgstr ""
 
-#: apply.c:942
-#, c-format
-msgid "git apply: bad git-diff - expected /dev/null, got %s on line %d"
+#: add-interactive.c:991
+msgid "add contents of untracked files to the staged set of changes"
 msgstr ""
 
-#: apply.c:948
-#, c-format
-msgid "git apply: bad git-diff - inconsistent new filename on line %d"
+#: add-interactive.c:999 add-interactive.c:1048
+msgid "Prompt help:"
 msgstr ""
 
-#: apply.c:949
-#, c-format
-msgid "git apply: bad git-diff - inconsistent old filename on line %d"
+#: add-interactive.c:1001
+msgid "select a single item"
 msgstr ""
 
-#: apply.c:954
-#, c-format
-msgid "git apply: bad git-diff - expected /dev/null on line %d"
+#: add-interactive.c:1003
+msgid "select a range of items"
 msgstr ""
 
-#: apply.c:983
-#, c-format
-msgid "invalid mode on line %d: %s"
+#: add-interactive.c:1005
+msgid "select multiple ranges"
 msgstr ""
 
-#: apply.c:1301
-#, c-format
-msgid "inconsistent header lines %d and %d"
+#: add-interactive.c:1007 add-interactive.c:1052
+msgid "select item based on unique prefix"
 msgstr ""
 
-#: apply.c:1473
-#, c-format
-msgid "recount: unexpected line: %.*s"
+#: add-interactive.c:1009
+msgid "unselect specified items"
 msgstr ""
 
-#: apply.c:1542
-#, c-format
-msgid "patch fragment without header at line %d: %.*s"
+#: add-interactive.c:1011
+msgid "choose all items"
 msgstr ""
 
-#: apply.c:1562
-#, c-format
-msgid ""
-"git diff header lacks filename information when removing %d leading pathname "
-"component (line %d)"
-msgid_plural ""
-"git diff header lacks filename information when removing %d leading pathname "
-"components (line %d)"
-msgstr[0] ""
-msgstr[1] ""
+#: add-interactive.c:1013
+msgid "(empty) finish selecting"
+msgstr ""
 
-#: apply.c:1575
-#, c-format
-msgid "git diff header lacks filename information (line %d)"
+#: add-interactive.c:1050
+msgid "select a numbered item"
 msgstr ""
 
-#: apply.c:1763
-msgid "new file depends on old contents"
+#: add-interactive.c:1054
+msgid "(empty) select nothing"
 msgstr ""
 
-#: apply.c:1765
-msgid "deleted file still has contents"
+#: add-interactive.c:1062 builtin/clean.c:822 git-add--interactive.perl:1851
+msgid "*** Commands ***"
 msgstr ""
 
-#: apply.c:1799
-#, c-format
-msgid "corrupt patch at line %d"
+#: add-interactive.c:1063 builtin/clean.c:823 git-add--interactive.perl:1848
+msgid "What now"
 msgstr ""
 
-#: apply.c:1836
-#, c-format
-msgid "new file %s depends on old contents"
+#: add-interactive.c:1115 git-add--interactive.perl:213
+msgid "staged"
 msgstr ""
 
-#: apply.c:1838
-#, c-format
-msgid "deleted file %s still has contents"
+#: add-interactive.c:1115 git-add--interactive.perl:213
+msgid "unstaged"
 msgstr ""
 
-#: apply.c:1841
-#, c-format
-msgid "** warning: file %s becomes empty but is not deleted"
+#: add-interactive.c:1115 apply.c:4965 apply.c:4968 builtin/am.c:2197
+#: builtin/am.c:2200 builtin/clone.c:123 builtin/fetch.c:144
+#: builtin/merge.c:273 builtin/pull.c:209 builtin/submodule--helper.c:409
+#: builtin/submodule--helper.c:1379 builtin/submodule--helper.c:1382
+#: builtin/submodule--helper.c:1875 builtin/submodule--helper.c:1878
+#: builtin/submodule--helper.c:2119 git-add--interactive.perl:213
+msgid "path"
 msgstr ""
 
-#: apply.c:1988
-#, c-format
-msgid "corrupt binary patch at line %d: %.*s"
+#: add-interactive.c:1122
+msgid "could not refresh index"
 msgstr ""
 
-#: apply.c:2025
+#: add-interactive.c:1136 builtin/clean.c:787 git-add--interactive.perl:1765
 #, c-format
-msgid "unrecognized binary patch at line %d"
+msgid "Bye.\n"
 msgstr ""
 
-#: apply.c:2185
+#: add-patch.c:15
 #, c-format
-msgid "patch with only garbage at line %d"
+msgid "Stage mode change [y,n,a,q,d%s,?]? "
 msgstr ""
 
-#: apply.c:2271
+#: add-patch.c:16
 #, c-format
-msgid "unable to read symlink %s"
+msgid "Stage deletion [y,n,a,q,d%s,?]? "
 msgstr ""
 
-#: apply.c:2275
+#: add-patch.c:17
 #, c-format
-msgid "unable to open or read %s"
+msgid "Stage this hunk [y,n,a,q,d%s,?]? "
 msgstr ""
 
-#: apply.c:2934
+#: add-patch.c:111
 #, c-format
-msgid "invalid start of line: '%c'"
+msgid "could not parse hunk header '%.*s'"
 msgstr ""
 
-#: apply.c:3055
+#: add-patch.c:130 add-patch.c:134
 #, c-format
-msgid "Hunk #%d succeeded at %d (offset %d line)."
-msgid_plural "Hunk #%d succeeded at %d (offset %d lines)."
-msgstr[0] ""
-msgstr[1] ""
+msgid "could not parse colored hunk header '%.*s'"
+msgstr ""
 
-#: apply.c:3067
-#, c-format
-msgid "Context reduced to (%ld/%ld) to apply fragment at %d"
+#: add-patch.c:176
+msgid "could not parse diff"
 msgstr ""
 
-#: apply.c:3073
-#, c-format
-msgid ""
-"while searching for:\n"
-"%.*s"
+#: add-patch.c:194
+msgid "could not parse colored diff"
 msgstr ""
 
-#: apply.c:3095
+#: add-patch.c:508
 #, c-format
-msgid "missing binary patch data for '%s'"
+msgid ""
+"expected context line #%d in\n"
+"%.*s"
 msgstr ""
 
-#: apply.c:3103
+#: add-patch.c:523
 #, c-format
-msgid "cannot reverse-apply a binary patch without the reverse hunk to '%s'"
+msgid ""
+"hunks do not overlap:\n"
+"%.*s\n"
+"\tdoes not end with:\n"
+"%.*s"
 msgstr ""
 
-#: apply.c:3149
-#, c-format
-msgid "cannot apply binary patch to '%s' without full index line"
+#: add-patch.c:799 git-add--interactive.perl:1112
+msgid "Manual hunk edit mode -- see bottom for a quick guide.\n"
 msgstr ""
 
-#: apply.c:3159
+#: add-patch.c:803
 #, c-format
 msgid ""
-"the patch applies to '%s' (%s), which does not match the current contents."
+"---\n"
+"To remove '%c' lines, make them ' ' lines (context).\n"
+"To remove '%c' lines, delete them.\n"
+"Lines starting with %c will be removed.\n"
 msgstr ""
 
-#: apply.c:3167
-#, c-format
-msgid "the patch applies to an empty '%s' but it is not empty"
+#: add-patch.c:810
+msgid ""
+"If the patch applies cleanly, the edited hunk will immediately be\n"
+"marked for staging.\n"
 msgstr ""
 
-#: apply.c:3185
-#, c-format
-msgid "the necessary postimage %s for '%s' cannot be read"
+#. TRANSLATORS: 'it' refers to the patch mentioned in the previous messages.
+#: add-patch.c:818 git-add--interactive.perl:1126
+msgid ""
+"If it does not apply cleanly, you will be given an opportunity to\n"
+"edit again.  If all lines of the hunk are removed, then the edit is\n"
+"aborted and the hunk is left unchanged.\n"
 msgstr ""
 
-#: apply.c:3198
-#, c-format
-msgid "binary patch does not apply to '%s'"
+#: add-patch.c:851
+msgid "could not parse hunk header"
 msgstr ""
 
-#: apply.c:3204
-#, c-format
-msgid "binary patch to '%s' creates incorrect result (expecting %s, got %s)"
+#: add-patch.c:895 add-patch.c:1294
+msgid "'git apply --cached' failed"
 msgstr ""
 
-#: apply.c:3225
-#, c-format
-msgid "patch failed: %s:%ld"
+#. TRANSLATORS: do not translate [y/n]
+#. The program will only accept that input at this point.
+#. Consider translating (saying "no" discards!) as
+#. (saying "n" for "no" discards!) if the translation
+#. of the word "no" does not start with n.
+#.
+#. TRANSLATORS: do not translate [y/n]
+#. The program will only accept that input
+#. at this point.
+#. Consider translating (saying "no" discards!) as
+#. (saying "n" for "no" discards!) if the translation
+#. of the word "no" does not start with n.
+#: add-patch.c:952 git-add--interactive.perl:1239
+msgid ""
+"Your edited hunk does not apply. Edit again (saying \"no\" discards!) [y/n]? "
 msgstr ""
 
-#: apply.c:3347
-#, c-format
-msgid "cannot checkout %s"
+#: add-patch.c:1009
+msgid ""
+"y - stage this hunk\n"
+"n - do not stage this hunk\n"
+"q - quit; do not stage this hunk or any of the remaining ones\n"
+"a - stage this and all the remaining hunks\n"
+"d - do not stage this hunk nor any of the remaining hunks\n"
 msgstr ""
 
-#: apply.c:3396 apply.c:3407 apply.c:3453 setup.c:278
-#, c-format
-msgid "failed to read %s"
+#: add-patch.c:1016
+msgid ""
+"j - leave this hunk undecided, see next undecided hunk\n"
+"J - leave this hunk undecided, see next hunk\n"
+"k - leave this hunk undecided, see previous undecided hunk\n"
+"K - leave this hunk undecided, see previous hunk\n"
+"g - select a hunk to go to\n"
+"/ - search for a hunk matching the given regex\n"
+"s - split the current hunk into smaller hunks\n"
+"e - manually edit the current hunk\n"
+"? - print help\n"
 msgstr ""
 
-#: apply.c:3404
-#, c-format
-msgid "reading from '%s' beyond a symbolic link"
+#: add-patch.c:1137 add-patch.c:1147
+msgid "No previous hunk"
 msgstr ""
 
-#: apply.c:3433 apply.c:3673
-#, c-format
-msgid "path %s has been renamed/deleted"
+#: add-patch.c:1142 add-patch.c:1152
+msgid "No next hunk"
 msgstr ""
 
-#: apply.c:3516 apply.c:3687
-#, c-format
-msgid "%s: does not exist in index"
+#: add-patch.c:1158
+msgid "No other hunks to goto"
 msgstr ""
 
-#: apply.c:3525 apply.c:3695
-#, c-format
-msgid "%s: does not match index"
+#: add-patch.c:1169 git-add--interactive.perl:1577
+msgid "go to which hunk (<ret> to see more)? "
 msgstr ""
 
-#: apply.c:3560
-msgid "repository lacks the necessary blob to fall back on 3-way merge."
+#: add-patch.c:1170 git-add--interactive.perl:1579
+msgid "go to which hunk? "
 msgstr ""
 
-#: apply.c:3563
+#: add-patch.c:1181
 #, c-format
-msgid "Falling back to three-way merge...\n"
+msgid "Invalid number: '%s'"
 msgstr ""
 
-#: apply.c:3579 apply.c:3583
+#: add-patch.c:1186
 #, c-format
-msgid "cannot read the current contents of '%s'"
+msgid "Sorry, only %d hunk available."
+msgid_plural "Sorry, only %d hunks available."
+msgstr[0] ""
+msgstr[1] ""
+
+#: add-patch.c:1195
+msgid "No other hunks to search"
 msgstr ""
 
-#: apply.c:3595
-#, c-format
-msgid "Failed to fall back on three-way merge...\n"
+#: add-patch.c:1201 git-add--interactive.perl:1623
+msgid "search for regex? "
 msgstr ""
 
-#: apply.c:3609
+#: add-patch.c:1216
 #, c-format
-msgid "Applied patch to '%s' with conflicts.\n"
+msgid "Malformed search regexp %s: %s"
 msgstr ""
 
-#: apply.c:3614
-#, c-format
-msgid "Applied patch to '%s' cleanly.\n"
+#: add-patch.c:1233
+msgid "No hunk matches the given pattern"
 msgstr ""
 
-#: apply.c:3640
-msgid "removal patch leaves file contents"
+#: add-patch.c:1240
+msgid "Sorry, cannot split this hunk"
 msgstr ""
 
-#: apply.c:3712
+#: add-patch.c:1244
 #, c-format
-msgid "%s: wrong type"
+msgid "Split into %d hunks."
 msgstr ""
 
-#: apply.c:3714
-#, c-format
-msgid "%s has type %o, expected %o"
+#: add-patch.c:1248
+msgid "Sorry, cannot edit this hunk"
 msgstr ""
 
-#: apply.c:3864 apply.c:3866
+#: advice.c:111
 #, c-format
-msgid "invalid path '%s'"
+msgid "%shint: %.*s%s\n"
 msgstr ""
 
-#: apply.c:3922
-#, c-format
-msgid "%s: already exists in index"
+#: advice.c:164
+msgid "Cherry-picking is not possible because you have unmerged files."
 msgstr ""
 
-#: apply.c:3925
-#, c-format
-msgid "%s: already exists in working directory"
+#: advice.c:166
+msgid "Committing is not possible because you have unmerged files."
 msgstr ""
 
-#: apply.c:3945
-#, c-format
-msgid "new mode (%o) of %s does not match old mode (%o)"
+#: advice.c:168
+msgid "Merging is not possible because you have unmerged files."
 msgstr ""
 
-#: apply.c:3950
-#, c-format
-msgid "new mode (%o) of %s does not match old mode (%o) of %s"
+#: advice.c:170
+msgid "Pulling is not possible because you have unmerged files."
 msgstr ""
 
-#: apply.c:3970
-#, c-format
-msgid "affected file '%s' is beyond a symbolic link"
+#: advice.c:172
+msgid "Reverting is not possible because you have unmerged files."
 msgstr ""
 
-#: apply.c:3974
+#: advice.c:174
 #, c-format
-msgid "%s: patch does not apply"
+msgid "It is not possible to %s because you have unmerged files."
 msgstr ""
 
-#: apply.c:3989
-#, c-format
-msgid "Checking patch %s..."
+#: advice.c:182
+msgid ""
+"Fix them up in the work tree, and then use 'git add/rm <file>'\n"
+"as appropriate to mark resolution and make a commit."
 msgstr ""
 
-#: apply.c:4080
-#, c-format
-msgid "sha1 information is lacking or useless for submodule %s"
+#: advice.c:190
+msgid "Exiting because of an unresolved conflict."
 msgstr ""
 
-#: apply.c:4087
-#, c-format
-msgid "mode change for %s, which is not in current HEAD"
+#: advice.c:195 builtin/merge.c:1332
+msgid "You have not concluded your merge (MERGE_HEAD exists)."
 msgstr ""
 
-#: apply.c:4090
-#, c-format
-msgid "sha1 information is lacking or useless (%s)."
+#: advice.c:197
+msgid "Please, commit your changes before merging."
 msgstr ""
 
-#: apply.c:4095 builtin/checkout.c:235 builtin/reset.c:140
-#, c-format
-msgid "make_cache_entry failed for path '%s'"
+#: advice.c:198
+msgid "Exiting because of unfinished merge."
 msgstr ""
 
-#: apply.c:4099
+#: advice.c:204
 #, c-format
-msgid "could not add %s to temporary index"
+msgid ""
+"Note: switching to '%s'.\n"
+"\n"
+"You are in 'detached HEAD' state. You can look around, make experimental\n"
+"changes and commit them, and you can discard any commits you make in this\n"
+"state without impacting any branches by switching back to a branch.\n"
+"\n"
+"If you want to create a new branch to retain commits you create, you may\n"
+"do so (now or later) by using -c with the switch command. Example:\n"
+"\n"
+"  git switch -c <new-branch-name>\n"
+"\n"
+"Or undo this operation with:\n"
+"\n"
+"  git switch -\n"
+"\n"
+"Turn off this advice by setting config variable advice.detachedHead to "
+"false\n"
+"\n"
 msgstr ""
 
-#: apply.c:4109
-#, c-format
-msgid "could not write temporary index to %s"
+#: alias.c:50
+msgid "cmdline ends with \\"
 msgstr ""
 
-#: apply.c:4247
-#, c-format
-msgid "unable to remove %s from index"
+#: alias.c:51
+msgid "unclosed quote"
 msgstr ""
 
-#: apply.c:4282
+#: apply.c:69
 #, c-format
-msgid "corrupt patch for submodule %s"
+msgid "unrecognized whitespace option '%s'"
 msgstr ""
 
-#: apply.c:4288
+#: apply.c:85
 #, c-format
-msgid "unable to stat newly created file '%s'"
+msgid "unrecognized whitespace ignore option '%s'"
 msgstr ""
 
-#: apply.c:4296
-#, c-format
-msgid "unable to create backing store for newly created file %s"
+#: apply.c:135
+msgid "--reject and --3way cannot be used together."
 msgstr ""
 
-#: apply.c:4302 apply.c:4446
-#, c-format
-msgid "unable to add cache entry for %s"
+#: apply.c:137
+msgid "--cached and --3way cannot be used together."
 msgstr ""
 
-#: apply.c:4343
-#, c-format
-msgid "failed to write to '%s'"
+#: apply.c:140
+msgid "--3way outside a repository"
 msgstr ""
 
-#: apply.c:4347
-#, c-format
-msgid "closing file '%s'"
+#: apply.c:151
+msgid "--index outside a repository"
 msgstr ""
 
-#: apply.c:4417
-#, c-format
-msgid "unable to write file '%s' mode %o"
+#: apply.c:154
+msgid "--cached outside a repository"
 msgstr ""
 
-#: apply.c:4515
+#: apply.c:801
 #, c-format
-msgid "Applied patch %s cleanly."
-msgstr ""
-
-#: apply.c:4523
-msgid "internal error"
+msgid "Cannot prepare timestamp regexp %s"
 msgstr ""
 
-#: apply.c:4526
-#, c-format
-msgid "Applying patch %%s with %d reject..."
-msgid_plural "Applying patch %%s with %d rejects..."
-msgstr[0] ""
-msgstr[1] ""
-
-#: apply.c:4537
+#: apply.c:810
 #, c-format
-msgid "truncating .rej filename to %.*s.rej"
+msgid "regexec returned %d for input: %s"
 msgstr ""
 
-#: apply.c:4545 builtin/fetch.c:786 builtin/fetch.c:1036
+#: apply.c:884
 #, c-format
-msgid "cannot open %s"
+msgid "unable to find filename in patch at line %d"
 msgstr ""
 
-#: apply.c:4559
+#: apply.c:922
 #, c-format
-msgid "Hunk #%d applied cleanly."
+msgid "git apply: bad git-diff - expected /dev/null, got %s on line %d"
 msgstr ""
 
-#: apply.c:4563
+#: apply.c:928
 #, c-format
-msgid "Rejected hunk #%d."
+msgid "git apply: bad git-diff - inconsistent new filename on line %d"
 msgstr ""
 
-#: apply.c:4673
+#: apply.c:929
 #, c-format
-msgid "Skipped patch '%s'."
+msgid "git apply: bad git-diff - inconsistent old filename on line %d"
 msgstr ""
 
-#: apply.c:4681
-msgid "unrecognized input"
+#: apply.c:934
+#, c-format
+msgid "git apply: bad git-diff - expected /dev/null on line %d"
 msgstr ""
 
-#: apply.c:4700
-msgid "unable to read index file"
+#: apply.c:963
+#, c-format
+msgid "invalid mode on line %d: %s"
 msgstr ""
 
-#: apply.c:4837
+#: apply.c:1282
 #, c-format
-msgid "can't open patch '%s': %s"
+msgid "inconsistent header lines %d and %d"
 msgstr ""
 
-#: apply.c:4864
+#: apply.c:1372
 #, c-format
-msgid "squelched %d whitespace error"
-msgid_plural "squelched %d whitespace errors"
+msgid ""
+"git diff header lacks filename information when removing %d leading pathname "
+"component (line %d)"
+msgid_plural ""
+"git diff header lacks filename information when removing %d leading pathname "
+"components (line %d)"
 msgstr[0] ""
 msgstr[1] ""
 
-#: apply.c:4870 apply.c:4885
+#: apply.c:1385
 #, c-format
-msgid "%d line adds whitespace errors."
-msgid_plural "%d lines add whitespace errors."
-msgstr[0] ""
-msgstr[1] ""
+msgid "git diff header lacks filename information (line %d)"
+msgstr ""
 
-#: apply.c:4878
+#: apply.c:1481
 #, c-format
-msgid "%d line applied after fixing whitespace errors."
-msgid_plural "%d lines applied after fixing whitespace errors."
-msgstr[0] ""
-msgstr[1] ""
-
-#: apply.c:4894 builtin/add.c:538 builtin/mv.c:300 builtin/rm.c:389
-msgid "Unable to write new index file"
+msgid "recount: unexpected line: %.*s"
 msgstr ""
 
-#: apply.c:4921 apply.c:4924 builtin/am.c:2254 builtin/am.c:2257
-#: builtin/clone.c:120 builtin/fetch.c:126 builtin/pull.c:198
-#: builtin/submodule--helper.c:405 builtin/submodule--helper.c:1210
-#: builtin/submodule--helper.c:1213 builtin/submodule--helper.c:1584
-#: builtin/submodule--helper.c:1587 builtin/submodule--helper.c:1807
-#: git-add--interactive.perl:197
-msgid "path"
+#: apply.c:1550
+#, c-format
+msgid "patch fragment without header at line %d: %.*s"
 msgstr ""
 
-#: apply.c:4922
-msgid "don't apply changes matching the given path"
+#: apply.c:1753
+msgid "new file depends on old contents"
 msgstr ""
 
-#: apply.c:4925
-msgid "apply changes matching the given path"
+#: apply.c:1755
+msgid "deleted file still has contents"
 msgstr ""
 
-#: apply.c:4927 builtin/am.c:2263
-msgid "num"
+#: apply.c:1789
+#, c-format
+msgid "corrupt patch at line %d"
 msgstr ""
 
-#: apply.c:4928
-msgid "remove <num> leading slashes from traditional diff paths"
+#: apply.c:1826
+#, c-format
+msgid "new file %s depends on old contents"
 msgstr ""
 
-#: apply.c:4931
-msgid "ignore additions made by the patch"
+#: apply.c:1828
+#, c-format
+msgid "deleted file %s still has contents"
 msgstr ""
 
-#: apply.c:4933
-msgid "instead of applying the patch, output diffstat for the input"
+#: apply.c:1831
+#, c-format
+msgid "** warning: file %s becomes empty but is not deleted"
 msgstr ""
 
-#: apply.c:4937
-msgid "show number of added and deleted lines in decimal notation"
+#: apply.c:1978
+#, c-format
+msgid "corrupt binary patch at line %d: %.*s"
 msgstr ""
 
-#: apply.c:4939
-msgid "instead of applying the patch, output a summary for the input"
+#: apply.c:2015
+#, c-format
+msgid "unrecognized binary patch at line %d"
 msgstr ""
 
-#: apply.c:4941
-msgid "instead of applying the patch, see if the patch is applicable"
+#: apply.c:2177
+#, c-format
+msgid "patch with only garbage at line %d"
 msgstr ""
 
-#: apply.c:4943
-msgid "make sure the patch is applicable to the current index"
+#: apply.c:2263
+#, c-format
+msgid "unable to read symlink %s"
 msgstr ""
 
-#: apply.c:4945
-msgid "apply a patch without touching the working tree"
+#: apply.c:2267
+#, c-format
+msgid "unable to open or read %s"
 msgstr ""
 
-#: apply.c:4947
-msgid "accept a patch that touches outside the working area"
+#: apply.c:2936
+#, c-format
+msgid "invalid start of line: '%c'"
 msgstr ""
 
-#: apply.c:4950
-msgid "also apply the patch (use with --stat/--summary/--check)"
+#: apply.c:3057
+#, c-format
+msgid "Hunk #%d succeeded at %d (offset %d line)."
+msgid_plural "Hunk #%d succeeded at %d (offset %d lines)."
+msgstr[0] ""
+msgstr[1] ""
+
+#: apply.c:3069
+#, c-format
+msgid "Context reduced to (%ld/%ld) to apply fragment at %d"
 msgstr ""
 
-#: apply.c:4952
-msgid "attempt three-way merge if a patch does not apply"
+#: apply.c:3075
+#, c-format
+msgid ""
+"while searching for:\n"
+"%.*s"
 msgstr ""
 
-#: apply.c:4954
-msgid "build a temporary index based on embedded index information"
+#: apply.c:3097
+#, c-format
+msgid "missing binary patch data for '%s'"
 msgstr ""
 
-#: apply.c:4957 builtin/checkout-index.c:168 builtin/ls-files.c:515
-msgid "paths are separated with NUL character"
+#: apply.c:3105
+#, c-format
+msgid "cannot reverse-apply a binary patch without the reverse hunk to '%s'"
 msgstr ""
 
-#: apply.c:4959
-msgid "ensure at least <n> lines of context match"
+#: apply.c:3152
+#, c-format
+msgid "cannot apply binary patch to '%s' without full index line"
 msgstr ""
 
-#: apply.c:4960 builtin/am.c:2242 builtin/interpret-trailers.c:95
-#: builtin/interpret-trailers.c:97 builtin/interpret-trailers.c:99
-#: builtin/pack-objects.c:3177
-msgid "action"
+#: apply.c:3162
+#, c-format
+msgid ""
+"the patch applies to '%s' (%s), which does not match the current contents."
 msgstr ""
 
-#: apply.c:4961
-msgid "detect new or modified lines that have whitespace errors"
+#: apply.c:3170
+#, c-format
+msgid "the patch applies to an empty '%s' but it is not empty"
 msgstr ""
 
-#: apply.c:4964 apply.c:4967
-msgid "ignore changes in whitespace when finding context"
+#: apply.c:3188
+#, c-format
+msgid "the necessary postimage %s for '%s' cannot be read"
 msgstr ""
 
-#: apply.c:4970
-msgid "apply the patch in reverse"
+#: apply.c:3201
+#, c-format
+msgid "binary patch does not apply to '%s'"
 msgstr ""
 
-#: apply.c:4972
-msgid "don't expect at least one line of context"
+#: apply.c:3207
+#, c-format
+msgid "binary patch to '%s' creates incorrect result (expecting %s, got %s)"
 msgstr ""
 
-#: apply.c:4974
-msgid "leave the rejected hunks in corresponding *.rej files"
+#: apply.c:3228
+#, c-format
+msgid "patch failed: %s:%ld"
 msgstr ""
 
-#: apply.c:4976
-msgid "allow overlapping hunks"
+#: apply.c:3351
+#, c-format
+msgid "cannot checkout %s"
 msgstr ""
 
-#: apply.c:4977 builtin/add.c:290 builtin/check-ignore.c:21
-#: builtin/commit.c:1301 builtin/count-objects.c:98 builtin/fsck.c:666
-#: builtin/log.c:1901 builtin/mv.c:122 builtin/read-tree.c:124
-msgid "be verbose"
+#: apply.c:3403 apply.c:3414 apply.c:3460 midx.c:61 setup.c:280
+#, c-format
+msgid "failed to read %s"
 msgstr ""
 
-#: apply.c:4979
-msgid "tolerate incorrectly detected missing new-line at the end of file"
+#: apply.c:3411
+#, c-format
+msgid "reading from '%s' beyond a symbolic link"
 msgstr ""
 
-#: apply.c:4982
-msgid "do not trust the line counts in the hunk headers"
+#: apply.c:3440 apply.c:3683
+#, c-format
+msgid "path %s has been renamed/deleted"
 msgstr ""
 
-#: apply.c:4984 builtin/am.c:2251
-msgid "root"
+#: apply.c:3526 apply.c:3698
+#, c-format
+msgid "%s: does not exist in index"
 msgstr ""
 
-#: apply.c:4985
-msgid "prepend <root> to all filenames"
+#: apply.c:3535 apply.c:3706
+#, c-format
+msgid "%s: does not match index"
 msgstr ""
 
-#: archive.c:13
-msgid "git archive [<options>] <tree-ish> [<path>...]"
+#: apply.c:3570
+msgid "repository lacks the necessary blob to fall back on 3-way merge."
 msgstr ""
 
-#: archive.c:14
-msgid "git archive --list"
+#: apply.c:3573
+#, c-format
+msgid "Falling back to three-way merge...\n"
 msgstr ""
 
-#: archive.c:15
-msgid ""
-"git archive --remote <repo> [--exec <cmd>] [<options>] <tree-ish> [<path>...]"
+#: apply.c:3589 apply.c:3593
+#, c-format
+msgid "cannot read the current contents of '%s'"
 msgstr ""
 
-#: archive.c:16
-msgid "git archive --remote <repo> [--exec <cmd>] --list"
+#: apply.c:3605
+#, c-format
+msgid "Failed to fall back on three-way merge...\n"
 msgstr ""
 
-#: archive.c:351 builtin/add.c:176 builtin/add.c:514 builtin/rm.c:298
+#: apply.c:3619
 #, c-format
-msgid "pathspec '%s' did not match any files"
+msgid "Applied patch to '%s' with conflicts.\n"
 msgstr ""
 
-#: archive.c:434
-msgid "fmt"
+#: apply.c:3624
+#, c-format
+msgid "Applied patch to '%s' cleanly.\n"
 msgstr ""
 
-#: archive.c:434
-msgid "archive format"
+#: apply.c:3650
+msgid "removal patch leaves file contents"
 msgstr ""
 
-#: archive.c:435 builtin/log.c:1462
-msgid "prefix"
+#: apply.c:3723
+#, c-format
+msgid "%s: wrong type"
 msgstr ""
 
-#: archive.c:436
-msgid "prepend prefix to each pathname in the archive"
+#: apply.c:3725
+#, c-format
+msgid "%s has type %o, expected %o"
 msgstr ""
 
-#: archive.c:437 builtin/blame.c:813 builtin/blame.c:814 builtin/config.c:127
-#: builtin/fast-export.c:1007 builtin/fast-export.c:1009 builtin/grep.c:869
-#: builtin/hash-object.c:103 builtin/ls-files.c:551 builtin/ls-files.c:554
-#: builtin/notes.c:405 builtin/notes.c:568 builtin/read-tree.c:119
-#: parse-options.h:165
-msgid "file"
+#: apply.c:3876 apply.c:3878 read-cache.c:830 read-cache.c:856
+#: read-cache.c:1320
+#, c-format
+msgid "invalid path '%s'"
 msgstr ""
 
-#: archive.c:438 builtin/archive.c:89
-msgid "write the archive to this file"
+#: apply.c:3934
+#, c-format
+msgid "%s: already exists in index"
 msgstr ""
 
-#: archive.c:440
-msgid "read .gitattributes in working directory"
+#: apply.c:3937
+#, c-format
+msgid "%s: already exists in working directory"
 msgstr ""
 
-#: archive.c:441
-msgid "report archived files on stderr"
+#: apply.c:3957
+#, c-format
+msgid "new mode (%o) of %s does not match old mode (%o)"
 msgstr ""
 
-#: archive.c:442
-msgid "store only"
+#: apply.c:3962
+#, c-format
+msgid "new mode (%o) of %s does not match old mode (%o) of %s"
 msgstr ""
 
-#: archive.c:443
-msgid "compress faster"
+#: apply.c:3982
+#, c-format
+msgid "affected file '%s' is beyond a symbolic link"
 msgstr ""
 
-#: archive.c:451
-msgid "compress better"
+#: apply.c:3986
+#, c-format
+msgid "%s: patch does not apply"
 msgstr ""
 
-#: archive.c:454
-msgid "list supported archive formats"
+#: apply.c:4001
+#, c-format
+msgid "Checking patch %s..."
 msgstr ""
 
-#: archive.c:456 builtin/archive.c:90 builtin/clone.c:110 builtin/clone.c:113
-#: builtin/submodule--helper.c:1222 builtin/submodule--helper.c:1593
-msgid "repo"
+#: apply.c:4093
+#, c-format
+msgid "sha1 information is lacking or useless for submodule %s"
 msgstr ""
 
-#: archive.c:457 builtin/archive.c:91
-msgid "retrieve the archive from remote repository <repo>"
+#: apply.c:4100
+#, c-format
+msgid "mode change for %s, which is not in current HEAD"
 msgstr ""
 
-#: archive.c:458 builtin/archive.c:92 builtin/notes.c:489
-msgid "command"
+#: apply.c:4103
+#, c-format
+msgid "sha1 information is lacking or useless (%s)."
 msgstr ""
 
-#: archive.c:459 builtin/archive.c:93
-msgid "path to the remote git-upload-archive command"
+#: apply.c:4112
+#, c-format
+msgid "could not add %s to temporary index"
 msgstr ""
 
-#: archive.c:466
-msgid "Unexpected option --remote"
+#: apply.c:4122
+#, c-format
+msgid "could not write temporary index to %s"
 msgstr ""
 
-#: archive.c:468
-msgid "Option --exec can only be used together with --remote"
-msgstr ""
-
-#: archive.c:470
-msgid "Unexpected option --output"
+#: apply.c:4260
+#, c-format
+msgid "unable to remove %s from index"
 msgstr ""
 
-#: archive.c:492
+#: apply.c:4294
 #, c-format
-msgid "Unknown archive format '%s'"
+msgid "corrupt patch for submodule %s"
 msgstr ""
 
-#: archive.c:499
+#: apply.c:4300
 #, c-format
-msgid "Argument not supported for format '%s': -%d"
+msgid "unable to stat newly created file '%s'"
 msgstr ""
 
-#: attr.c:218
+#: apply.c:4308
 #, c-format
-msgid "%.*s is not a valid attribute name"
+msgid "unable to create backing store for newly created file %s"
 msgstr ""
 
-#: attr.c:415
-msgid ""
-"Negative patterns are ignored in git attributes\n"
-"Use '\\!' for literal leading exclamation."
+#: apply.c:4314 apply.c:4459
+#, c-format
+msgid "unable to add cache entry for %s"
 msgstr ""
 
-#: bisect.c:461
+#: apply.c:4357
 #, c-format
-msgid "Badly quoted content in file '%s': %s"
+msgid "failed to write to '%s'"
 msgstr ""
 
-#: bisect.c:669
+#: apply.c:4361
 #, c-format
-msgid "We cannot bisect more!\n"
+msgid "closing file '%s'"
 msgstr ""
 
-#: bisect.c:723
+#: apply.c:4431
 #, c-format
-msgid "Not a valid commit name %s"
+msgid "unable to write file '%s' mode %o"
 msgstr ""
 
-#: bisect.c:747
+#: apply.c:4529
 #, c-format
-msgid ""
-"The merge base %s is bad.\n"
-"This means the bug has been fixed between %s and [%s].\n"
+msgid "Applied patch %s cleanly."
 msgstr ""
 
-#: bisect.c:752
-#, c-format
-msgid ""
-"The merge base %s is new.\n"
-"The property has changed between %s and [%s].\n"
+#: apply.c:4537
+msgid "internal error"
 msgstr ""
 
-#: bisect.c:757
+#: apply.c:4540
 #, c-format
-msgid ""
-"The merge base %s is %s.\n"
-"This means the first '%s' commit is between %s and [%s].\n"
-msgstr ""
+msgid "Applying patch %%s with %d reject..."
+msgid_plural "Applying patch %%s with %d rejects..."
+msgstr[0] ""
+msgstr[1] ""
 
-#: bisect.c:765
+#: apply.c:4551
 #, c-format
-msgid ""
-"Some %s revs are not ancestors of the %s rev.\n"
-"git bisect cannot work properly in this case.\n"
-"Maybe you mistook %s and %s revs?\n"
+msgid "truncating .rej filename to %.*s.rej"
 msgstr ""
 
-#: bisect.c:778
+#: apply.c:4559 builtin/fetch.c:901 builtin/fetch.c:1192
 #, c-format
-msgid ""
-"the merge base between %s and [%s] must be skipped.\n"
-"So we cannot be sure the first %s commit is between %s and %s.\n"
-"We continue anyway."
+msgid "cannot open %s"
 msgstr ""
 
-#: bisect.c:811
+#: apply.c:4573
 #, c-format
-msgid "Bisecting: a merge base must be tested\n"
+msgid "Hunk #%d applied cleanly."
 msgstr ""
 
-#: bisect.c:851
+#: apply.c:4577
 #, c-format
-msgid "a %s revision is needed"
+msgid "Rejected hunk #%d."
 msgstr ""
 
-#: bisect.c:870 builtin/notes.c:175 builtin/tag.c:236
+#: apply.c:4696
 #, c-format
-msgid "could not create file '%s'"
+msgid "Skipped patch '%s'."
 msgstr ""
 
-#: bisect.c:921
-#, c-format
-msgid "could not read file '%s'"
+#: apply.c:4704
+msgid "unrecognized input"
 msgstr ""
 
-#: bisect.c:951
-msgid "reading bisect refs failed"
+#: apply.c:4724
+msgid "unable to read index file"
 msgstr ""
 
-#: bisect.c:970
+#: apply.c:4881
 #, c-format
-msgid "%s was both %s and %s\n"
+msgid "can't open patch '%s': %s"
 msgstr ""
 
-#: bisect.c:978
+#: apply.c:4908
 #, c-format
-msgid ""
-"No testable commit found.\n"
-"Maybe you started with bad path parameters?\n"
-msgstr ""
+msgid "squelched %d whitespace error"
+msgid_plural "squelched %d whitespace errors"
+msgstr[0] ""
+msgstr[1] ""
 
-#: bisect.c:997
+#: apply.c:4914 apply.c:4929
 #, c-format
-msgid "(roughly %d step)"
-msgid_plural "(roughly %d steps)"
+msgid "%d line adds whitespace errors."
+msgid_plural "%d lines add whitespace errors."
 msgstr[0] ""
 msgstr[1] ""
 
-#. TRANSLATORS: the last %s will be replaced with "(roughly %d
-#. steps)" translation.
-#.
-#: bisect.c:1003
+#: apply.c:4922
 #, c-format
-msgid "Bisecting: %d revision left to test after this %s\n"
-msgid_plural "Bisecting: %d revisions left to test after this %s\n"
+msgid "%d line applied after fixing whitespace errors."
+msgid_plural "%d lines applied after fixing whitespace errors."
 msgstr[0] ""
 msgstr[1] ""
 
-#: blame.c:1756
-msgid "--contents and --reverse do not blend well."
+#: apply.c:4938 builtin/add.c:579 builtin/mv.c:301 builtin/rm.c:390
+msgid "Unable to write new index file"
 msgstr ""
 
-#: blame.c:1767
-msgid "cannot use --contents with final commit object name"
+#: apply.c:4966
+msgid "don't apply changes matching the given path"
 msgstr ""
 
-#: blame.c:1787
-msgid "--reverse and --first-parent together require specified latest commit"
+#: apply.c:4969
+msgid "apply changes matching the given path"
 msgstr ""
 
-#: blame.c:1796 bundle.c:160 ref-filter.c:2075 sequencer.c:1861
-#: sequencer.c:3632 builtin/commit.c:981 builtin/log.c:366 builtin/log.c:920
-#: builtin/log.c:1371 builtin/log.c:1702 builtin/log.c:1950 builtin/merge.c:372
-#: builtin/shortlog.c:192
-msgid "revision walk setup failed"
+#: apply.c:4971 builtin/am.c:2206
+msgid "num"
 msgstr ""
 
-#: blame.c:1814
-msgid ""
-"--reverse --first-parent together require range along first-parent chain"
+#: apply.c:4972
+msgid "remove <num> leading slashes from traditional diff paths"
 msgstr ""
 
-#: blame.c:1825
-#, c-format
-msgid "no such path %s in %s"
+#: apply.c:4975
+msgid "ignore additions made by the patch"
 msgstr ""
 
-#: blame.c:1836
-#, c-format
-msgid "cannot read blob %s for path %s"
+#: apply.c:4977
+msgid "instead of applying the patch, output diffstat for the input"
 msgstr ""
 
-#: branch.c:54
-#, c-format
-msgid ""
-"\n"
-"After fixing the error cause you may try to fix up\n"
-"the remote tracking information by invoking\n"
-"\"git branch --set-upstream-to=%s%s%s\"."
+#: apply.c:4981
+msgid "show number of added and deleted lines in decimal notation"
 msgstr ""
 
-#: branch.c:68
-#, c-format
-msgid "Not setting branch %s as its own upstream."
+#: apply.c:4983
+msgid "instead of applying the patch, output a summary for the input"
 msgstr ""
 
-#: branch.c:94
-#, c-format
-msgid "Branch '%s' set up to track remote branch '%s' from '%s' by rebasing."
+#: apply.c:4985
+msgid "instead of applying the patch, see if the patch is applicable"
 msgstr ""
 
-#: branch.c:95
-#, c-format
-msgid "Branch '%s' set up to track remote branch '%s' from '%s'."
+#: apply.c:4987
+msgid "make sure the patch is applicable to the current index"
 msgstr ""
 
-#: branch.c:99
-#, c-format
-msgid "Branch '%s' set up to track local branch '%s' by rebasing."
+#: apply.c:4989
+msgid "mark new files with `git add --intent-to-add`"
 msgstr ""
 
-#: branch.c:100
-#, c-format
-msgid "Branch '%s' set up to track local branch '%s'."
+#: apply.c:4991
+msgid "apply a patch without touching the working tree"
 msgstr ""
 
-#: branch.c:105
-#, c-format
-msgid "Branch '%s' set up to track remote ref '%s' by rebasing."
+#: apply.c:4993
+msgid "accept a patch that touches outside the working area"
 msgstr ""
 
-#: branch.c:106
-#, c-format
-msgid "Branch '%s' set up to track remote ref '%s'."
+#: apply.c:4996
+msgid "also apply the patch (use with --stat/--summary/--check)"
 msgstr ""
 
-#: branch.c:110
-#, c-format
-msgid "Branch '%s' set up to track local ref '%s' by rebasing."
+#: apply.c:4998
+msgid "attempt three-way merge if a patch does not apply"
 msgstr ""
 
-#: branch.c:111
-#, c-format
-msgid "Branch '%s' set up to track local ref '%s'."
+#: apply.c:5000
+msgid "build a temporary index based on embedded index information"
 msgstr ""
 
-#: branch.c:120
-msgid "Unable to write upstream branch configuration"
+#: apply.c:5003 builtin/checkout-index.c:173 builtin/ls-files.c:524
+msgid "paths are separated with NUL character"
 msgstr ""
 
-#: branch.c:157
-#, c-format
-msgid "Not tracking: ambiguous information for ref %s"
+#: apply.c:5005
+msgid "ensure at least <n> lines of context match"
 msgstr ""
 
-#: branch.c:190
-#, c-format
-msgid "'%s' is not a valid branch name."
+#: apply.c:5006 builtin/am.c:2185 builtin/interpret-trailers.c:98
+#: builtin/interpret-trailers.c:100 builtin/interpret-trailers.c:102
+#: builtin/pack-objects.c:3310 builtin/rebase.c:1474
+msgid "action"
 msgstr ""
 
-#: branch.c:209
-#, c-format
-msgid "A branch named '%s' already exists."
+#: apply.c:5007
+msgid "detect new or modified lines that have whitespace errors"
 msgstr ""
 
-#: branch.c:214
-msgid "Cannot force update the current branch."
+#: apply.c:5010 apply.c:5013
+msgid "ignore changes in whitespace when finding context"
 msgstr ""
 
-#: branch.c:234
-#, c-format
-msgid "Cannot setup tracking information; starting point '%s' is not a branch."
+#: apply.c:5016
+msgid "apply the patch in reverse"
 msgstr ""
 
-#: branch.c:236
-#, c-format
-msgid "the requested upstream branch '%s' does not exist"
+#: apply.c:5018
+msgid "don't expect at least one line of context"
 msgstr ""
 
-#: branch.c:238
-msgid ""
-"\n"
-"If you are planning on basing your work on an upstream\n"
-"branch that already exists at the remote, you may need to\n"
-"run \"git fetch\" to retrieve it.\n"
-"\n"
-"If you are planning to push out a new local branch that\n"
-"will track its remote counterpart, you may want to use\n"
-"\"git push -u\" to set the upstream config as you push."
+#: apply.c:5020
+msgid "leave the rejected hunks in corresponding *.rej files"
 msgstr ""
 
-#: branch.c:281
-#, c-format
-msgid "Not a valid object name: '%s'."
+#: apply.c:5022
+msgid "allow overlapping hunks"
 msgstr ""
 
-#: branch.c:301
-#, c-format
-msgid "Ambiguous object name: '%s'."
+#: apply.c:5023 builtin/add.c:309 builtin/check-ignore.c:22
+#: builtin/commit.c:1355 builtin/count-objects.c:98 builtin/fsck.c:774
+#: builtin/log.c:2166 builtin/mv.c:123 builtin/read-tree.c:128
+msgid "be verbose"
 msgstr ""
 
-#: branch.c:306
-#, c-format
-msgid "Not a valid branch point: '%s'."
+#: apply.c:5025
+msgid "tolerate incorrectly detected missing new-line at the end of file"
 msgstr ""
 
-#: branch.c:360
-#, c-format
-msgid "'%s' is already checked out at '%s'"
+#: apply.c:5028
+msgid "do not trust the line counts in the hunk headers"
 msgstr ""
 
-#: branch.c:383
-#, c-format
-msgid "HEAD of working tree %s is not updated"
+#: apply.c:5030 builtin/am.c:2194
+msgid "root"
 msgstr ""
 
-#: bundle.c:34
-#, c-format
-msgid "'%s' does not look like a v2 bundle file"
+#: apply.c:5031
+msgid "prepend <root> to all filenames"
+msgstr ""
+
+#: archive.c:14
+msgid "git archive [<options>] <tree-ish> [<path>...]"
+msgstr ""
+
+#: archive.c:15
+msgid "git archive --list"
+msgstr ""
+
+#: archive.c:16
+msgid ""
+"git archive --remote <repo> [--exec <cmd>] [<options>] <tree-ish> [<path>...]"
 msgstr ""
 
-#: bundle.c:62
+#: archive.c:17
+msgid "git archive --remote <repo> [--exec <cmd>] --list"
+msgstr ""
+
+#: archive.c:372 builtin/add.c:180 builtin/add.c:555 builtin/rm.c:299
 #, c-format
-msgid "unrecognized header: %s%s (%d)"
+msgid "pathspec '%s' did not match any files"
 msgstr ""
 
-#: bundle.c:88 sequencer.c:2081 sequencer.c:2558 builtin/commit.c:755
+#: archive.c:396
 #, c-format
-msgid "could not open '%s'"
+msgid "no such ref: %.*s"
 msgstr ""
 
-#: bundle.c:139
-msgid "Repository lacks these prerequisite commits:"
+#: archive.c:401
+#, c-format
+msgid "not a valid object name: %s"
 msgstr ""
 
-#: bundle.c:190
+#: archive.c:414
 #, c-format
-msgid "The bundle contains this ref:"
-msgid_plural "The bundle contains these %d refs:"
-msgstr[0] ""
-msgstr[1] ""
+msgid "not a tree object: %s"
+msgstr ""
 
-#: bundle.c:197
-msgid "The bundle records a complete history."
+#: archive.c:426
+msgid "current working directory is untracked"
 msgstr ""
 
-#: bundle.c:199
-#, c-format
-msgid "The bundle requires this ref:"
-msgid_plural "The bundle requires these %d refs:"
-msgstr[0] ""
-msgstr[1] ""
+#: archive.c:457
+msgid "fmt"
+msgstr ""
 
-#: bundle.c:258
-msgid "Could not spawn pack-objects"
+#: archive.c:457
+msgid "archive format"
 msgstr ""
 
-#: bundle.c:269
-msgid "pack-objects died"
+#: archive.c:458 builtin/log.c:1653
+msgid "prefix"
 msgstr ""
 
-#: bundle.c:311
-msgid "rev-list died"
+#: archive.c:459
+msgid "prepend prefix to each pathname in the archive"
 msgstr ""
 
-#: bundle.c:360
-#, c-format
-msgid "ref '%s' is excluded by the rev-list options"
+#: archive.c:460 builtin/blame.c:861 builtin/blame.c:865 builtin/blame.c:866
+#: builtin/commit-tree.c:117 builtin/config.c:129 builtin/fast-export.c:1162
+#: builtin/fast-export.c:1164 builtin/fast-export.c:1168 builtin/grep.c:899
+#: builtin/hash-object.c:105 builtin/ls-files.c:560 builtin/ls-files.c:563
+#: builtin/notes.c:412 builtin/notes.c:578 builtin/read-tree.c:123
+#: parse-options.h:190
+msgid "file"
 msgstr ""
 
-#: bundle.c:450 builtin/log.c:183 builtin/log.c:1607 builtin/shortlog.c:303
-#, c-format
-msgid "unrecognized argument: %s"
+#: archive.c:461 builtin/archive.c:90
+msgid "write the archive to this file"
 msgstr ""
 
-#: bundle.c:458
-msgid "Refusing to create empty bundle."
+#: archive.c:463
+msgid "read .gitattributes in working directory"
 msgstr ""
 
-#: bundle.c:470
-#, c-format
-msgid "cannot create '%s'"
+#: archive.c:464
+msgid "report archived files on stderr"
 msgstr ""
 
-#: bundle.c:498
-msgid "index-pack died"
+#: archive.c:465
+msgid "store only"
 msgstr ""
 
-#: color.c:296
-#, c-format
-msgid "invalid color value: %.*s"
+#: archive.c:466
+msgid "compress faster"
 msgstr ""
 
-#: commit.c:43 sequencer.c:2364 builtin/am.c:421 builtin/am.c:465
-#: builtin/am.c:1436 builtin/am.c:2072 builtin/replace.c:376
-#: builtin/replace.c:448
-#, c-format
-msgid "could not parse %s"
+#: archive.c:474
+msgid "compress better"
 msgstr ""
 
-#: commit.c:45
-#, c-format
-msgid "%s %s is not a commit!"
+#: archive.c:477
+msgid "list supported archive formats"
 msgstr ""
 
-#: commit.c:182
-msgid ""
-"Support for <GIT_DIR>/info/grafts is deprecated\n"
-"and will be removed in a future Git version.\n"
-"\n"
-"Please use \"git replace --convert-graft-file\"\n"
-"to convert the grafts into replace refs.\n"
-"\n"
-"Turn this message off by running\n"
-"\"git config advice.graftFileDeprecated false\""
+#: archive.c:479 builtin/archive.c:91 builtin/clone.c:113 builtin/clone.c:116
+#: builtin/submodule--helper.c:1391 builtin/submodule--helper.c:1884
+msgid "repo"
 msgstr ""
 
-#: commit.c:1540
-msgid ""
-"Warning: commit message did not conform to UTF-8.\n"
-"You may want to amend it after fixing the message, or set the config\n"
-"variable i18n.commitencoding to the encoding your project uses.\n"
+#: archive.c:480 builtin/archive.c:92
+msgid "retrieve the archive from remote repository <repo>"
 msgstr ""
 
-#: commit-graph.c:669
-#, c-format
-msgid "the commit graph format cannot write %d commits"
+#: archive.c:481 builtin/archive.c:93 builtin/difftool.c:715
+#: builtin/notes.c:498
+msgid "command"
 msgstr ""
 
-#: commit-graph.c:696
-msgid "too many commits to write graph"
+#: archive.c:482 builtin/archive.c:94
+msgid "path to the remote git-upload-archive command"
 msgstr ""
 
-#: commit-graph.c:707 builtin/init-db.c:516 builtin/init-db.c:521
-#, c-format
-msgid "cannot mkdir %s"
+#: archive.c:489
+msgid "Unexpected option --remote"
 msgstr ""
 
-#: compat/obstack.c:405 compat/obstack.c:407
-msgid "memory exhausted"
+#: archive.c:491
+msgid "Option --exec can only be used together with --remote"
 msgstr ""
 
-#: config.c:187
-msgid "relative config include conditionals must come from files"
+#: archive.c:493
+msgid "Unexpected option --output"
 msgstr ""
 
-#: config.c:788
+#: archive.c:515
 #, c-format
-msgid "bad config line %d in blob %s"
+msgid "Unknown archive format '%s'"
 msgstr ""
 
-#: config.c:792
+#: archive.c:522
 #, c-format
-msgid "bad config line %d in file %s"
+msgid "Argument not supported for format '%s': -%d"
 msgstr ""
 
-#: config.c:796
+#: archive-tar.c:125 archive-zip.c:350
 #, c-format
-msgid "bad config line %d in standard input"
+msgid "cannot stream blob %s"
 msgstr ""
 
-#: config.c:800
+#: archive-tar.c:266 archive-zip.c:368
 #, c-format
-msgid "bad config line %d in submodule-blob %s"
+msgid "unsupported file mode: 0%o (SHA1: %s)"
 msgstr ""
 
-#: config.c:804
+#: archive-tar.c:293 archive-zip.c:358
 #, c-format
-msgid "bad config line %d in command line %s"
+msgid "cannot read %s"
 msgstr ""
 
-#: config.c:808
+#: archive-tar.c:465
 #, c-format
-msgid "bad config line %d in %s"
+msgid "unable to start '%s' filter"
 msgstr ""
 
-#: config.c:936
-msgid "out of range"
+#: archive-tar.c:468
+msgid "unable to redirect descriptor"
 msgstr ""
 
-#: config.c:936
-msgid "invalid unit"
+#: archive-tar.c:475
+#, c-format
+msgid "'%s' filter reported error"
 msgstr ""
 
-#: config.c:942
+#: archive-zip.c:319
 #, c-format
-msgid "bad numeric config value '%s' for '%s': %s"
+msgid "path is not valid UTF-8: %s"
 msgstr ""
 
-#: config.c:947
+#: archive-zip.c:323
 #, c-format
-msgid "bad numeric config value '%s' for '%s' in blob %s: %s"
+msgid "path too long (%d chars, SHA1: %s): %s"
 msgstr ""
 
-#: config.c:950
+#: archive-zip.c:479 builtin/pack-objects.c:230 builtin/pack-objects.c:233
 #, c-format
-msgid "bad numeric config value '%s' for '%s' in file %s: %s"
+msgid "deflate error (%d)"
 msgstr ""
 
-#: config.c:953
+#: archive-zip.c:614
 #, c-format
-msgid "bad numeric config value '%s' for '%s' in standard input: %s"
+msgid "timestamp too large for this system: %<PRIuMAX>"
 msgstr ""
 
-#: config.c:956
+#: attr.c:212
 #, c-format
-msgid "bad numeric config value '%s' for '%s' in submodule-blob %s: %s"
+msgid "%.*s is not a valid attribute name"
 msgstr ""
 
-#: config.c:959
+#: attr.c:369
 #, c-format
-msgid "bad numeric config value '%s' for '%s' in command line %s: %s"
+msgid "%s not allowed: %s:%d"
 msgstr ""
 
-#: config.c:962
-#, c-format
-msgid "bad numeric config value '%s' for '%s' in %s: %s"
+#: attr.c:409
+msgid ""
+"Negative patterns are ignored in git attributes\n"
+"Use '\\!' for literal leading exclamation."
 msgstr ""
 
-#: config.c:1057
+#: bisect.c:468
 #, c-format
-msgid "failed to expand user dir in: '%s'"
+msgid "Badly quoted content in file '%s': %s"
 msgstr ""
 
-#: config.c:1066
+#: bisect.c:678
 #, c-format
-msgid "'%s' for '%s' is not a valid timestamp"
+msgid "We cannot bisect more!\n"
 msgstr ""
 
-#: config.c:1171 config.c:1182
+#: bisect.c:733
 #, c-format
-msgid "bad zlib compression level %d"
+msgid "Not a valid commit name %s"
 msgstr ""
 
-#: config.c:1307
+#: bisect.c:758
 #, c-format
-msgid "invalid mode for object creation: %s"
+msgid ""
+"The merge base %s is bad.\n"
+"This means the bug has been fixed between %s and [%s].\n"
 msgstr ""
 
-#: config.c:1473
+#: bisect.c:763
 #, c-format
-msgid "bad pack compression level %d"
+msgid ""
+"The merge base %s is new.\n"
+"The property has changed between %s and [%s].\n"
 msgstr ""
 
-#: config.c:1681
-msgid "unable to parse command-line config"
+#: bisect.c:768
+#, c-format
+msgid ""
+"The merge base %s is %s.\n"
+"This means the first '%s' commit is between %s and [%s].\n"
 msgstr ""
 
-#: config.c:2013
-msgid "unknown error occurred while reading the configuration files"
+#: bisect.c:776
+#, c-format
+msgid ""
+"Some %s revs are not ancestors of the %s rev.\n"
+"git bisect cannot work properly in this case.\n"
+"Maybe you mistook %s and %s revs?\n"
 msgstr ""
 
-#: config.c:2200
+#: bisect.c:789
 #, c-format
-msgid "Invalid %s: '%s'"
+msgid ""
+"the merge base between %s and [%s] must be skipped.\n"
+"So we cannot be sure the first %s commit is between %s and %s.\n"
+"We continue anyway."
 msgstr ""
 
-#: config.c:2243
+#: bisect.c:822
 #, c-format
-msgid "unknown core.untrackedCache value '%s'; using 'keep' default value"
+msgid "Bisecting: a merge base must be tested\n"
 msgstr ""
 
-#: config.c:2269
+#: bisect.c:865
 #, c-format
-msgid "splitIndex.maxPercentChange value '%d' should be between 0 and 100"
+msgid "a %s revision is needed"
 msgstr ""
 
-#: config.c:2294
+#: bisect.c:884 builtin/notes.c:177 builtin/tag.c:254
 #, c-format
-msgid "unable to parse '%s' from command-line config"
+msgid "could not create file '%s'"
 msgstr ""
 
-#: config.c:2296
+#: bisect.c:928 builtin/merge.c:148
 #, c-format
-msgid "bad config variable '%s' in file '%s' at line %d"
+msgid "could not read file '%s'"
 msgstr ""
 
-#: config.c:2402
-#, c-format
-msgid "%s has multiple values"
+#: bisect.c:958
+msgid "reading bisect refs failed"
 msgstr ""
 
-#: config.c:2766 config.c:3019
+#: bisect.c:977
 #, c-format
-msgid "fstat on %s failed"
+msgid "%s was both %s and %s\n"
 msgstr ""
 
-#: config.c:2905
+#: bisect.c:985
 #, c-format
-msgid "could not set '%s' to '%s'"
+msgid ""
+"No testable commit found.\n"
+"Maybe you started with bad path parameters?\n"
 msgstr ""
 
-#: config.c:2907 builtin/remote.c:779
+#: bisect.c:1004
 #, c-format
-msgid "could not unset '%s'"
-msgstr ""
+msgid "(roughly %d step)"
+msgid_plural "(roughly %d steps)"
+msgstr[0] ""
+msgstr[1] ""
 
-#: connect.c:61
-msgid "The remote end hung up upon initial contact"
+#. TRANSLATORS: the last %s will be replaced with "(roughly %d
+#. steps)" translation.
+#.
+#: bisect.c:1010
+#, c-format
+msgid "Bisecting: %d revision left to test after this %s\n"
+msgid_plural "Bisecting: %d revisions left to test after this %s\n"
+msgstr[0] ""
+msgstr[1] ""
+
+#: blame.c:2700
+msgid "--contents and --reverse do not blend well."
 msgstr ""
 
-#: connect.c:63
-msgid ""
-"Could not read from remote repository.\n"
-"\n"
-"Please make sure you have the correct access rights\n"
-"and the repository exists."
+#: blame.c:2714
+msgid "cannot use --contents with final commit object name"
 msgstr ""
 
-#: connected.c:66 builtin/fsck.c:201 builtin/prune.c:145
-msgid "Checking connectivity"
+#: blame.c:2735
+msgid "--reverse and --first-parent together require specified latest commit"
 msgstr ""
 
-#: connected.c:78
-msgid "Could not run 'git rev-list'"
+#: blame.c:2744 bundle.c:167 ref-filter.c:2203 remote.c:1941 sequencer.c:2093
+#: sequencer.c:4460 builtin/commit.c:1040 builtin/log.c:388 builtin/log.c:991
+#: builtin/log.c:1520 builtin/log.c:1925 builtin/log.c:2215 builtin/merge.c:411
+#: builtin/pack-objects.c:3128 builtin/pack-objects.c:3143
+#: builtin/shortlog.c:192
+msgid "revision walk setup failed"
 msgstr ""
 
-#: connected.c:98
-msgid "failed write to rev-list"
+#: blame.c:2762
+msgid ""
+"--reverse --first-parent together require range along first-parent chain"
 msgstr ""
 
-#: connected.c:105
-msgid "failed to close rev-list's stdin"
+#: blame.c:2773
+#, c-format
+msgid "no such path %s in %s"
 msgstr ""
 
-#: convert.c:206
+#: blame.c:2784
 #, c-format
-msgid "CRLF would be replaced by LF in %s."
+msgid "cannot read blob %s for path %s"
 msgstr ""
 
-#: convert.c:208
+#: branch.c:53
 #, c-format
 msgid ""
-"CRLF will be replaced by LF in %s.\n"
-"The file will have its original line endings in your working directory."
+"\n"
+"After fixing the error cause you may try to fix up\n"
+"the remote tracking information by invoking\n"
+"\"git branch --set-upstream-to=%s%s%s\"."
 msgstr ""
 
-#: convert.c:216
+#: branch.c:67
 #, c-format
-msgid "LF would be replaced by CRLF in %s"
+msgid "Not setting branch %s as its own upstream."
 msgstr ""
 
-#: convert.c:218
+#: branch.c:93
 #, c-format
-msgid ""
-"LF will be replaced by CRLF in %s.\n"
-"The file will have its original line endings in your working directory."
+msgid "Branch '%s' set up to track remote branch '%s' from '%s' by rebasing."
 msgstr ""
 
-#: convert.c:279
+#: branch.c:94
 #, c-format
-msgid "BOM is prohibited in '%s' if encoded as %s"
+msgid "Branch '%s' set up to track remote branch '%s' from '%s'."
 msgstr ""
 
-#: convert.c:286
+#: branch.c:98
 #, c-format
-msgid ""
-"The file '%s' contains a byte order mark (BOM). Please use UTF-%s as working-"
-"tree-encoding."
+msgid "Branch '%s' set up to track local branch '%s' by rebasing."
 msgstr ""
 
-#: convert.c:304
+#: branch.c:99
 #, c-format
-msgid "BOM is required in '%s' if encoded as %s"
+msgid "Branch '%s' set up to track local branch '%s'."
 msgstr ""
 
-#: convert.c:306
+#: branch.c:104
 #, c-format
-msgid ""
-"The file '%s' is missing a byte order mark (BOM). Please use UTF-%sBE or UTF-"
-"%sLE (depending on the byte order) as working-tree-encoding."
+msgid "Branch '%s' set up to track remote ref '%s' by rebasing."
 msgstr ""
 
-#: convert.c:424
+#: branch.c:105
 #, c-format
-msgid "failed to encode '%s' from %s to %s"
+msgid "Branch '%s' set up to track remote ref '%s'."
 msgstr ""
 
-#: convert.c:467
+#: branch.c:109
 #, c-format
-msgid "encoding '%s' from %s to %s and back is not the same"
+msgid "Branch '%s' set up to track local ref '%s' by rebasing."
 msgstr ""
 
-#: convert.c:1225
-msgid "true/false are no valid working-tree-encodings"
+#: branch.c:110
+#, c-format
+msgid "Branch '%s' set up to track local ref '%s'."
 msgstr ""
 
-#: date.c:116
-msgid "in the future"
+#: branch.c:119
+msgid "Unable to write upstream branch configuration"
 msgstr ""
 
-#: date.c:122
+#: branch.c:156
 #, c-format
-msgid "%<PRIuMAX> second ago"
-msgid_plural "%<PRIuMAX> seconds ago"
-msgstr[0] ""
-msgstr[1] ""
+msgid "Not tracking: ambiguous information for ref %s"
+msgstr ""
 
-#: date.c:129
+#: branch.c:189
 #, c-format
-msgid "%<PRIuMAX> minute ago"
-msgid_plural "%<PRIuMAX> minutes ago"
-msgstr[0] ""
-msgstr[1] ""
+msgid "'%s' is not a valid branch name."
+msgstr ""
 
-#: date.c:136
+#: branch.c:208
 #, c-format
-msgid "%<PRIuMAX> hour ago"
-msgid_plural "%<PRIuMAX> hours ago"
-msgstr[0] ""
-msgstr[1] ""
+msgid "A branch named '%s' already exists."
+msgstr ""
 
-#: date.c:143
-#, c-format
-msgid "%<PRIuMAX> day ago"
-msgid_plural "%<PRIuMAX> days ago"
-msgstr[0] ""
-msgstr[1] ""
+#: branch.c:213
+msgid "Cannot force update the current branch."
+msgstr ""
 
-#: date.c:149
+#: branch.c:233
 #, c-format
-msgid "%<PRIuMAX> week ago"
-msgid_plural "%<PRIuMAX> weeks ago"
-msgstr[0] ""
-msgstr[1] ""
+msgid "Cannot setup tracking information; starting point '%s' is not a branch."
+msgstr ""
 
-#: date.c:156
+#: branch.c:235
 #, c-format
-msgid "%<PRIuMAX> month ago"
-msgid_plural "%<PRIuMAX> months ago"
-msgstr[0] ""
-msgstr[1] ""
+msgid "the requested upstream branch '%s' does not exist"
+msgstr ""
+
+#: branch.c:237
+msgid ""
+"\n"
+"If you are planning on basing your work on an upstream\n"
+"branch that already exists at the remote, you may need to\n"
+"run \"git fetch\" to retrieve it.\n"
+"\n"
+"If you are planning to push out a new local branch that\n"
+"will track its remote counterpart, you may want to use\n"
+"\"git push -u\" to set the upstream config as you push."
+msgstr ""
 
-#: date.c:167
+#: branch.c:281
 #, c-format
-msgid "%<PRIuMAX> year"
-msgid_plural "%<PRIuMAX> years"
-msgstr[0] ""
-msgstr[1] ""
+msgid "Not a valid object name: '%s'."
+msgstr ""
 
-#. TRANSLATORS: "%s" is "<n> years"
-#: date.c:170
+#: branch.c:301
 #, c-format
-msgid "%s, %<PRIuMAX> month ago"
-msgid_plural "%s, %<PRIuMAX> months ago"
-msgstr[0] ""
-msgstr[1] ""
+msgid "Ambiguous object name: '%s'."
+msgstr ""
 
-#: date.c:175 date.c:180
+#: branch.c:306
 #, c-format
-msgid "%<PRIuMAX> year ago"
-msgid_plural "%<PRIuMAX> years ago"
-msgstr[0] ""
-msgstr[1] ""
+msgid "Not a valid branch point: '%s'."
+msgstr ""
 
-#: diffcore-order.c:24
+#: branch.c:364
 #, c-format
-msgid "failed to read orderfile '%s'"
+msgid "'%s' is already checked out at '%s'"
 msgstr ""
 
-#: diffcore-rename.c:535
-msgid "Performing inexact rename detection"
+#: branch.c:387
+#, c-format
+msgid "HEAD of working tree %s is not updated"
 msgstr ""
 
-#: diff.c:74
+#: bundle.c:36
 #, c-format
-msgid "option '%s' requires a value"
+msgid "'%s' does not look like a v2 bundle file"
 msgstr ""
 
-#: diff.c:152
+#: bundle.c:64
 #, c-format
-msgid "  Failed to parse dirstat cut-off percentage '%s'\n"
+msgid "unrecognized header: %s%s (%d)"
 msgstr ""
 
-#: diff.c:157
+#: bundle.c:90 rerere.c:480 rerere.c:690 sequencer.c:2344 sequencer.c:3108
+#: builtin/commit.c:811
 #, c-format
-msgid "  Unknown dirstat parameter '%s'\n"
+msgid "could not open '%s'"
 msgstr ""
 
-#: diff.c:281
-msgid ""
-"color moved setting must be one of 'no', 'default', 'zebra', 'dimmed_zebra', "
-"'plain'"
+#: bundle.c:143
+msgid "Repository lacks these prerequisite commits:"
 msgstr ""
 
-#: diff.c:341
-#, c-format
-msgid "Unknown value for 'diff.submodule' config variable: '%s'"
+#: bundle.c:146
+msgid "need a repository to verify a bundle"
 msgstr ""
 
-#: diff.c:401
+#: bundle.c:197
 #, c-format
-msgid ""
-"Found errors in 'diff.dirstat' config variable:\n"
-"%s"
+msgid "The bundle contains this ref:"
+msgid_plural "The bundle contains these %d refs:"
+msgstr[0] ""
+msgstr[1] ""
+
+#: bundle.c:204
+msgid "The bundle records a complete history."
 msgstr ""
 
-#: diff.c:3823
+#: bundle.c:206
 #, c-format
-msgid "external diff died, stopping at %s"
+msgid "The bundle requires this ref:"
+msgid_plural "The bundle requires these %d refs:"
+msgstr[0] ""
+msgstr[1] ""
+
+#: bundle.c:273
+msgid "unable to dup bundle descriptor"
 msgstr ""
 
-#: diff.c:4153
-msgid "--name-only, --name-status, --check and -s are mutually exclusive"
+#: bundle.c:280
+msgid "Could not spawn pack-objects"
 msgstr ""
 
-#: diff.c:4156
-msgid "-G, -S and --find-object are mutually exclusive"
+#: bundle.c:291
+msgid "pack-objects died"
 msgstr ""
 
-#: diff.c:4244
-msgid "--follow requires exactly one pathspec"
+#: bundle.c:333
+msgid "rev-list died"
 msgstr ""
 
-#: diff.c:4410
+#: bundle.c:382
 #, c-format
-msgid ""
-"Failed to parse --dirstat/-X option parameter:\n"
-"%s"
+msgid "ref '%s' is excluded by the rev-list options"
 msgstr ""
 
-#: diff.c:4424
+#: bundle.c:461 builtin/log.c:203 builtin/log.c:1814 builtin/shortlog.c:306
 #, c-format
-msgid "Failed to parse --submodule option parameter: '%s'"
+msgid "unrecognized argument: %s"
 msgstr ""
 
-#: diff.c:5500
-msgid "inexact rename detection was skipped due to too many files."
+#: bundle.c:469
+msgid "Refusing to create empty bundle."
 msgstr ""
 
-#: diff.c:5503
-msgid "only found copies from modified paths due to too many files."
+#: bundle.c:479
+#, c-format
+msgid "cannot create '%s'"
 msgstr ""
 
-#: diff.c:5506
-#, c-format
-msgid ""
-"you may want to set your %s variable to at least %d and retry the command."
+#: bundle.c:504
+msgid "index-pack died"
 msgstr ""
 
-#: dir.c:1867
+#: color.c:296
 #, c-format
-msgid "could not open directory '%s'"
+msgid "invalid color value: %.*s"
 msgstr ""
 
-#: dir.c:2109
-msgid "failed to get kernel name and information"
+#: commit.c:51 sequencer.c:2811 builtin/am.c:354 builtin/am.c:398
+#: builtin/am.c:1366 builtin/am.c:2009 builtin/replace.c:456
+#, c-format
+msgid "could not parse %s"
 msgstr ""
 
-#: dir.c:2233
-msgid "Untracked cache is disabled on this system or location."
+#: commit.c:53
+#, c-format
+msgid "%s %s is not a commit!"
 msgstr ""
 
-#: dir.c:3075 dir.c:3080
-#, c-format
-msgid "could not create directories for %s"
+#: commit.c:193
+msgid ""
+"Support for <GIT_DIR>/info/grafts is deprecated\n"
+"and will be removed in a future Git version.\n"
+"\n"
+"Please use \"git replace --convert-graft-file\"\n"
+"to convert the grafts into replace refs.\n"
+"\n"
+"Turn this message off by running\n"
+"\"git config advice.graftFileDeprecated false\""
 msgstr ""
 
-#: dir.c:3109
+#: commit.c:1152
 #, c-format
-msgid "could not migrate git directory from '%s' to '%s'"
+msgid "Commit %s has an untrusted GPG signature, allegedly by %s."
 msgstr ""
 
-#: editor.c:61
+#: commit.c:1155
 #, c-format
-msgid "hint: Waiting for your editor to close the file...%c"
+msgid "Commit %s has a bad GPG signature allegedly by %s."
 msgstr ""
 
-#: entry.c:177
-msgid "Filtering content"
+#: commit.c:1158
+#, c-format
+msgid "Commit %s does not have a GPG signature."
 msgstr ""
 
-#: entry.c:435
+#: commit.c:1161
 #, c-format
-msgid "could not stat file '%s'"
+msgid "Commit %s has a good GPG signature by %s\n"
 msgstr ""
 
-#: fetch-object.c:17
-msgid "Remote with no URL"
+#: commit.c:1415
+msgid ""
+"Warning: commit message did not conform to UTF-8.\n"
+"You may want to amend it after fixing the message, or set the config\n"
+"variable i18n.commitencoding to the encoding your project uses.\n"
 msgstr ""
 
-#: fetch-pack.c:254
-msgid "git fetch-pack: expected shallow list"
+#: commit-graph.c:130
+msgid "commit-graph file is too small"
 msgstr ""
 
-#: fetch-pack.c:266
-msgid "git fetch-pack: expected ACK/NAK, got a flush packet"
+#: commit-graph.c:195
+#, c-format
+msgid "commit-graph signature %X does not match signature %X"
 msgstr ""
 
-#: fetch-pack.c:285 builtin/archive.c:63
+#: commit-graph.c:202
 #, c-format
-msgid "remote error: %s"
+msgid "commit-graph version %X does not match version %X"
 msgstr ""
 
-#: fetch-pack.c:286
+#: commit-graph.c:209
 #, c-format
-msgid "git fetch-pack: expected ACK/NAK, got '%s'"
+msgid "commit-graph hash version %X does not match version %X"
 msgstr ""
 
-#: fetch-pack.c:338
-msgid "--stateless-rpc requires multi_ack_detailed"
+#: commit-graph.c:232
+msgid "commit-graph chunk lookup table entry missing; file may be incomplete"
 msgstr ""
 
-#: fetch-pack.c:429 fetch-pack.c:1310
+#: commit-graph.c:243
 #, c-format
-msgid "invalid shallow line: %s"
+msgid "commit-graph improper chunk offset %08x%08x"
 msgstr ""
 
-#: fetch-pack.c:435 fetch-pack.c:1316
+#: commit-graph.c:286
 #, c-format
-msgid "invalid unshallow line: %s"
+msgid "commit-graph chunk id %08x appears multiple times"
 msgstr ""
 
-#: fetch-pack.c:437 fetch-pack.c:1318
-#, c-format
-msgid "object not found: %s"
+#: commit-graph.c:350
+msgid "commit-graph has no base graphs chunk"
 msgstr ""
 
-#: fetch-pack.c:440 fetch-pack.c:1321
-#, c-format
-msgid "error in object: %s"
+#: commit-graph.c:360
+msgid "commit-graph chain does not match"
 msgstr ""
 
-#: fetch-pack.c:442 fetch-pack.c:1323
+#: commit-graph.c:407
 #, c-format
-msgid "no shallow found: %s"
+msgid "invalid commit-graph chain: line '%s' not a hash"
+msgstr ""
+
+#: commit-graph.c:433
+msgid "unable to find all commit-graph files"
+msgstr ""
+
+#: commit-graph.c:564 commit-graph.c:624
+msgid "invalid commit position. commit-graph is likely corrupt"
 msgstr ""
 
-#: fetch-pack.c:445 fetch-pack.c:1326
+#: commit-graph.c:585
 #, c-format
-msgid "expected shallow/unshallow, got %s"
+msgid "could not find commit %s"
 msgstr ""
 
-#: fetch-pack.c:486
+#: commit-graph.c:858 builtin/am.c:1287
 #, c-format
-msgid "got %s %d %s"
+msgid "unable to parse commit %s"
 msgstr ""
 
-#: fetch-pack.c:500
+#: commit-graph.c:1017 builtin/pack-objects.c:2641
 #, c-format
-msgid "invalid commit %s"
+msgid "unable to get type of object %s"
 msgstr ""
 
-#: fetch-pack.c:533
-msgid "giving up"
+#: commit-graph.c:1049
+msgid "Loading known commits in commit graph"
 msgstr ""
 
-#: fetch-pack.c:543 progress.c:229
-msgid "done"
+#: commit-graph.c:1066
+msgid "Expanding reachable commits in commit graph"
+msgstr ""
+
+#: commit-graph.c:1085
+msgid "Clearing commit marks in commit graph"
+msgstr ""
+
+#: commit-graph.c:1104
+msgid "Computing commit graph generation numbers"
 msgstr ""
 
-#: fetch-pack.c:555
+#: commit-graph.c:1179
 #, c-format
-msgid "got %s (%d) %s"
+msgid "Finding commits for commit graph in %d pack"
+msgid_plural "Finding commits for commit graph in %d packs"
+msgstr[0] ""
+msgstr[1] ""
+
+#: commit-graph.c:1192
+#, c-format
+msgid "error adding pack %s"
 msgstr ""
 
-#: fetch-pack.c:601
+#: commit-graph.c:1196
 #, c-format
-msgid "Marking %s as complete"
+msgid "error opening index for %s"
 msgstr ""
 
-#: fetch-pack.c:828
+#: commit-graph.c:1220
 #, c-format
-msgid "already have %s (%s)"
+msgid "Finding commits for commit graph from %d ref"
+msgid_plural "Finding commits for commit graph from %d refs"
+msgstr[0] ""
+msgstr[1] ""
+
+#: commit-graph.c:1240
+#, c-format
+msgid "invalid commit object id: %s"
 msgstr ""
 
-#: fetch-pack.c:869
-msgid "fetch-pack: unable to fork off sideband demultiplexer"
+#: commit-graph.c:1255
+msgid "Finding commits for commit graph among packed objects"
 msgstr ""
 
-#: fetch-pack.c:877
-msgid "protocol error: bad pack header"
+#: commit-graph.c:1270
+msgid "Counting distinct commits in commit graph"
+msgstr ""
+
+#: commit-graph.c:1300
+msgid "Finding extra edges in commit graph"
+msgstr ""
+
+#: commit-graph.c:1346
+msgid "failed to write correct number of base graph ids"
 msgstr ""
 
-#: fetch-pack.c:944
+#: commit-graph.c:1379 midx.c:814
 #, c-format
-msgid "fetch-pack: unable to fork off %s"
+msgid "unable to create leading directories of %s"
 msgstr ""
 
-#: fetch-pack.c:960
+#: commit-graph.c:1391 builtin/index-pack.c:306 builtin/repack.c:248
 #, c-format
-msgid "%s failed"
+msgid "unable to create '%s'"
 msgstr ""
 
-#: fetch-pack.c:962
-msgid "error in sideband demultiplexer"
+#: commit-graph.c:1451
+#, c-format
+msgid "Writing out commit graph in %d pass"
+msgid_plural "Writing out commit graph in %d passes"
+msgstr[0] ""
+msgstr[1] ""
+
+#: commit-graph.c:1492
+msgid "unable to open commit-graph chain file"
 msgstr ""
 
-#: fetch-pack.c:989
-msgid "Server does not support shallow clients"
+#: commit-graph.c:1504
+msgid "failed to rename base commit-graph file"
 msgstr ""
 
-#: fetch-pack.c:993
-msgid "Server supports multi_ack_detailed"
+#: commit-graph.c:1524
+msgid "failed to rename temporary commit-graph file"
 msgstr ""
 
-#: fetch-pack.c:996
-msgid "Server supports no-done"
+#: commit-graph.c:1635
+msgid "Scanning merged commits"
 msgstr ""
 
-#: fetch-pack.c:1002
-msgid "Server supports multi_ack"
+#: commit-graph.c:1646
+#, c-format
+msgid "unexpected duplicate commit id %s"
 msgstr ""
 
-#: fetch-pack.c:1006
-msgid "Server supports side-band-64k"
+#: commit-graph.c:1670
+msgid "Merging commit-graph"
 msgstr ""
 
-#: fetch-pack.c:1010
-msgid "Server supports side-band"
+#: commit-graph.c:1860
+#, c-format
+msgid "the commit graph format cannot write %d commits"
 msgstr ""
 
-#: fetch-pack.c:1014
-msgid "Server supports allow-tip-sha1-in-want"
+#: commit-graph.c:1871
+msgid "too many commits to write graph"
 msgstr ""
 
-#: fetch-pack.c:1018
-msgid "Server supports allow-reachable-sha1-in-want"
+#: commit-graph.c:1961
+msgid "the commit-graph file has incorrect checksum and is likely corrupt"
 msgstr ""
 
-#: fetch-pack.c:1028
-msgid "Server supports ofs-delta"
+#: commit-graph.c:1971
+#, c-format
+msgid "commit-graph has incorrect OID order: %s then %s"
 msgstr ""
 
-#: fetch-pack.c:1034 fetch-pack.c:1204
-msgid "Server supports filter"
+#: commit-graph.c:1981 commit-graph.c:1996
+#, c-format
+msgid "commit-graph has incorrect fanout value: fanout[%d] = %u != %u"
 msgstr ""
 
-#: fetch-pack.c:1042
+#: commit-graph.c:1988
 #, c-format
-msgid "Server version is %.*s"
+msgid "failed to parse commit %s from commit-graph"
 msgstr ""
 
-#: fetch-pack.c:1048
-msgid "Server does not support --shallow-since"
+#: commit-graph.c:2006
+msgid "Verifying commits in commit graph"
 msgstr ""
 
-#: fetch-pack.c:1052
-msgid "Server does not support --shallow-exclude"
+#: commit-graph.c:2020
+#, c-format
+msgid "failed to parse commit %s from object database for commit-graph"
 msgstr ""
 
-#: fetch-pack.c:1054
-msgid "Server does not support --deepen"
+#: commit-graph.c:2027
+#, c-format
+msgid "root tree OID for commit %s in commit-graph is %s != %s"
 msgstr ""
 
-#: fetch-pack.c:1065
-msgid "no common commits"
+#: commit-graph.c:2037
+#, c-format
+msgid "commit-graph parent list for commit %s is too long"
 msgstr ""
 
-#: fetch-pack.c:1077 fetch-pack.c:1414
-msgid "git fetch-pack: fetch failed."
+#: commit-graph.c:2046
+#, c-format
+msgid "commit-graph parent for %s is %s != %s"
 msgstr ""
 
-#: fetch-pack.c:1199
-msgid "Server does not support shallow requests"
+#: commit-graph.c:2059
+#, c-format
+msgid "commit-graph parent list for commit %s terminates early"
 msgstr ""
 
-#: fetch-pack.c:1584
-msgid "no matching remote head"
+#: commit-graph.c:2064
+#, c-format
+msgid ""
+"commit-graph has generation number zero for commit %s, but non-zero elsewhere"
 msgstr ""
 
-#: fetch-pack.c:1610
+#: commit-graph.c:2068
 #, c-format
-msgid "no such remote ref %s"
+msgid ""
+"commit-graph has non-zero generation number for commit %s, but zero elsewhere"
 msgstr ""
 
-#: fetch-pack.c:1613
+#: commit-graph.c:2083
 #, c-format
-msgid "Server does not allow request for unadvertised object %s"
+msgid "commit-graph generation for commit %s is %u != %u"
 msgstr ""
 
-#: gpg-interface.c:185
-msgid "gpg failed to sign the data"
+#: commit-graph.c:2089
+#, c-format
+msgid "commit date for commit %s in commit-graph is %<PRIuMAX> != %<PRIuMAX>"
 msgstr ""
 
-#: gpg-interface.c:210
-msgid "could not create temporary file"
+#: compat/obstack.c:406 compat/obstack.c:408
+msgid "memory exhausted"
 msgstr ""
 
-#: gpg-interface.c:213
+#: config.c:124
 #, c-format
-msgid "failed writing detached signature to '%s'"
+msgid ""
+"exceeded maximum include depth (%d) while including\n"
+"\t%s\n"
+"from\n"
+"\t%s\n"
+"This might be due to circular includes."
 msgstr ""
 
-#: graph.c:97
+#: config.c:140
 #, c-format
-msgid "ignore invalid color '%.*s' in log.graphColors"
+msgid "could not expand include path '%s'"
+msgstr ""
+
+#: config.c:151
+msgid "relative config includes must come from files"
+msgstr ""
+
+#: config.c:197
+msgid "relative config include conditionals must come from files"
 msgstr ""
 
-#: grep.c:2020
+#: config.c:376
 #, c-format
-msgid "'%s': unable to read %s"
+msgid "key does not contain a section: %s"
 msgstr ""
 
-#: grep.c:2037 setup.c:164 builtin/clone.c:409 builtin/diff.c:81
-#: builtin/rm.c:134
+#: config.c:382
 #, c-format
-msgid "failed to stat '%s'"
+msgid "key does not contain variable name: %s"
 msgstr ""
 
-#: grep.c:2048
+#: config.c:406 sequencer.c:2530
 #, c-format
-msgid "'%s': short read"
+msgid "invalid key: %s"
 msgstr ""
 
-#: help.c:23
-msgid "start a working area (see also: git help tutorial)"
+#: config.c:412
+#, c-format
+msgid "invalid key (newline): %s"
 msgstr ""
 
-#: help.c:24
-msgid "work on the current change (see also: git help everyday)"
+#: config.c:448 config.c:460
+#, c-format
+msgid "bogus config parameter: %s"
 msgstr ""
 
-#: help.c:25
-msgid "examine the history and state (see also: git help revisions)"
+#: config.c:495
+#, c-format
+msgid "bogus format in %s"
 msgstr ""
 
-#: help.c:26
-msgid "grow, mark and tweak your common history"
+#: config.c:821
+#, c-format
+msgid "bad config line %d in blob %s"
 msgstr ""
 
-#: help.c:27
-msgid "collaborate (see also: git help workflows)"
+#: config.c:825
+#, c-format
+msgid "bad config line %d in file %s"
 msgstr ""
 
-#: help.c:31
-msgid "Main Porcelain Commands"
+#: config.c:829
+#, c-format
+msgid "bad config line %d in standard input"
 msgstr ""
 
-#: help.c:32
-msgid "Ancillary Commands / Manipulators"
+#: config.c:833
+#, c-format
+msgid "bad config line %d in submodule-blob %s"
 msgstr ""
 
-#: help.c:33
-msgid "Ancillary Commands / Interrogators"
+#: config.c:837
+#, c-format
+msgid "bad config line %d in command line %s"
 msgstr ""
 
-#: help.c:34
-msgid "Interacting with Others"
+#: config.c:841
+#, c-format
+msgid "bad config line %d in %s"
 msgstr ""
 
-#: help.c:35
-msgid "Low-level Commands / Manipulators"
+#: config.c:978
+msgid "out of range"
 msgstr ""
 
-#: help.c:36
-msgid "Low-level Commands / Interrogators"
+#: config.c:978
+msgid "invalid unit"
 msgstr ""
 
-#: help.c:37
-msgid "Low-level Commands / Synching Repositories"
+#: config.c:979
+#, c-format
+msgid "bad numeric config value '%s' for '%s': %s"
 msgstr ""
 
-#: help.c:38
-msgid "Low-level Commands / Internal Helpers"
+#: config.c:998
+#, c-format
+msgid "bad numeric config value '%s' for '%s' in blob %s: %s"
 msgstr ""
 
-#: help.c:293
+#: config.c:1001
 #, c-format
-msgid "available git commands in '%s'"
+msgid "bad numeric config value '%s' for '%s' in file %s: %s"
 msgstr ""
 
-#: help.c:300
-msgid "git commands available from elsewhere on your $PATH"
+#: config.c:1004
+#, c-format
+msgid "bad numeric config value '%s' for '%s' in standard input: %s"
 msgstr ""
 
-#: help.c:309
-msgid "These are common Git commands used in various situations:"
+#: config.c:1007
+#, c-format
+msgid "bad numeric config value '%s' for '%s' in submodule-blob %s: %s"
 msgstr ""
 
-#: help.c:358 git.c:90
+#: config.c:1010
 #, c-format
-msgid "unsupported command listing type '%s'"
+msgid "bad numeric config value '%s' for '%s' in command line %s: %s"
 msgstr ""
 
-#: help.c:405
-msgid "The common Git guides are:"
+#: config.c:1013
+#, c-format
+msgid "bad numeric config value '%s' for '%s' in %s: %s"
 msgstr ""
 
-#: help.c:467
+#: config.c:1108
 #, c-format
-msgid ""
-"'%s' appears to be a git command, but we were not\n"
-"able to execute it. Maybe git-%s is broken?"
+msgid "failed to expand user dir in: '%s'"
 msgstr ""
 
-#: help.c:526
-msgid "Uh oh. Your system reports no Git commands at all."
+#: config.c:1117
+#, c-format
+msgid "'%s' for '%s' is not a valid timestamp"
 msgstr ""
 
-#: help.c:548
+#: config.c:1208
 #, c-format
-msgid "WARNING: You called a Git command named '%s', which does not exist."
+msgid "abbrev length out of range: %d"
 msgstr ""
 
-#: help.c:553
+#: config.c:1222 config.c:1233
 #, c-format
-msgid "Continuing under the assumption that you meant '%s'."
+msgid "bad zlib compression level %d"
+msgstr ""
+
+#: config.c:1325
+msgid "core.commentChar should only be one character"
 msgstr ""
 
-#: help.c:558
+#: config.c:1358
 #, c-format
-msgid "Continuing in %0.1f seconds, assuming that you meant '%s'."
+msgid "invalid mode for object creation: %s"
 msgstr ""
 
-#: help.c:566
+#: config.c:1430
 #, c-format
-msgid "git: '%s' is not a git command. See 'git --help'."
+msgid "malformed value for %s"
 msgstr ""
 
-#: help.c:570
-msgid ""
-"\n"
-"The most similar command is"
-msgid_plural ""
-"\n"
-"The most similar commands are"
-msgstr[0] ""
-msgstr[1] ""
+#: config.c:1456
+#, c-format
+msgid "malformed value for %s: %s"
+msgstr ""
 
-#: help.c:585
-msgid "git version [<options>]"
+#: config.c:1457
+msgid "must be one of nothing, matching, simple, upstream or current"
 msgstr ""
 
-#: help.c:652
+#: config.c:1518 builtin/pack-objects.c:3394
 #, c-format
-msgid "%s: %s - %s"
+msgid "bad pack compression level %d"
 msgstr ""
 
-#: help.c:656
-msgid ""
-"\n"
-"Did you mean this?"
-msgid_plural ""
-"\n"
-"Did you mean one of these?"
-msgstr[0] ""
-msgstr[1] ""
-
-#: ident.c:342
-msgid ""
-"\n"
-"*** Please tell me who you are.\n"
-"\n"
-"Run\n"
-"\n"
-"  git config --global user.email \"you@example.com\"\n"
-"  git config --global user.name \"Your Name\"\n"
-"\n"
-"to set your account's default identity.\n"
-"Omit --global to set the identity only in this repository.\n"
-"\n"
-msgstr ""
-
-#: ident.c:366
-msgid "no email was given and auto-detection is disabled"
-msgstr ""
-
-#: ident.c:371
-#, c-format
-msgid "unable to auto-detect email address (got '%s')"
-msgstr ""
-
-#: ident.c:381
-msgid "no name was given and auto-detection is disabled"
-msgstr ""
-
-#: ident.c:387
+#: config.c:1639
 #, c-format
-msgid "unable to auto-detect name (got '%s')"
+msgid "unable to load config blob object '%s'"
 msgstr ""
 
-#: ident.c:395
+#: config.c:1642
 #, c-format
-msgid "empty ident name (for <%s>) not allowed"
+msgid "reference '%s' does not point to a blob"
 msgstr ""
 
-#: ident.c:401
+#: config.c:1659
 #, c-format
-msgid "name consists only of disallowed characters: %s"
+msgid "unable to resolve config blob '%s'"
 msgstr ""
 
-#: ident.c:416 builtin/commit.c:587
+#: config.c:1689
 #, c-format
-msgid "invalid date format: %s"
+msgid "failed to parse %s"
 msgstr ""
 
-#: list-objects-filter-options.c:36
-msgid "multiple filter-specs cannot be combined"
+#: config.c:1745
+msgid "unable to parse command-line config"
 msgstr ""
 
-#: list-objects-filter-options.c:126
-msgid "cannot change partial clone promisor remote"
+#: config.c:2096
+msgid "unknown error occurred while reading the configuration files"
 msgstr ""
 
-#: lockfile.c:151
+#: config.c:2266
 #, c-format
-msgid ""
-"Unable to create '%s.lock': %s.\n"
-"\n"
-"Another git process seems to be running in this repository, e.g.\n"
-"an editor opened by 'git commit'. Please make sure all processes\n"
-"are terminated then try again. If it still fails, a git process\n"
-"may have crashed in this repository earlier:\n"
-"remove the file manually to continue."
+msgid "Invalid %s: '%s'"
 msgstr ""
 
-#: lockfile.c:159
+#: config.c:2311
 #, c-format
-msgid "Unable to create '%s.lock': %s"
-msgstr ""
-
-#: merge.c:71
-msgid "failed to read the cache"
-msgstr ""
-
-#: merge.c:136 builtin/am.c:1946 builtin/am.c:1980 builtin/checkout.c:378
-#: builtin/checkout.c:606 builtin/clone.c:761
-msgid "unable to write new index file"
-msgstr ""
-
-#: merge-recursive.c:298
-msgid "(bad commit)\n"
+msgid "splitIndex.maxPercentChange value '%d' should be between 0 and 100"
 msgstr ""
 
-#: merge-recursive.c:320
+#: config.c:2357
 #, c-format
-msgid "add_cacheinfo failed for path '%s'; merge aborting."
+msgid "unable to parse '%s' from command-line config"
 msgstr ""
 
-#: merge-recursive.c:328
+#: config.c:2359
 #, c-format
-msgid "add_cacheinfo failed to refresh for path '%s'; merge aborting."
-msgstr ""
-
-#: merge-recursive.c:410
-msgid "error building trees"
+msgid "bad config variable '%s' in file '%s' at line %d"
 msgstr ""
 
-#: merge-recursive.c:881
+#: config.c:2440
 #, c-format
-msgid "failed to create path '%s'%s"
+msgid "invalid section name '%s'"
 msgstr ""
 
-#: merge-recursive.c:892
+#: config.c:2472
 #, c-format
-msgid "Removing %s to make room for subdirectory\n"
-msgstr ""
-
-#: merge-recursive.c:906 merge-recursive.c:925
-msgid ": perhaps a D/F conflict?"
+msgid "%s has multiple values"
 msgstr ""
 
-#: merge-recursive.c:915
+#: config.c:2501
 #, c-format
-msgid "refusing to lose untracked file at '%s'"
+msgid "failed to write new configuration file %s"
 msgstr ""
 
-#: merge-recursive.c:957 builtin/cat-file.c:37
+#: config.c:2753 config.c:3077
 #, c-format
-msgid "cannot read object %s '%s'"
+msgid "could not lock config file %s"
 msgstr ""
 
-#: merge-recursive.c:959
+#: config.c:2764
 #, c-format
-msgid "blob expected for %s '%s'"
+msgid "opening %s"
 msgstr ""
 
-#: merge-recursive.c:983
+#: config.c:2799 builtin/config.c:328
 #, c-format
-msgid "failed to open '%s': %s"
+msgid "invalid pattern: %s"
 msgstr ""
 
-#: merge-recursive.c:994
+#: config.c:2824
 #, c-format
-msgid "failed to symlink '%s': %s"
+msgid "invalid config file %s"
 msgstr ""
 
-#: merge-recursive.c:999
+#: config.c:2837 config.c:3090
 #, c-format
-msgid "do not know what to do with %06o %s '%s'"
+msgid "fstat on %s failed"
 msgstr ""
 
-#: merge-recursive.c:1186
+#: config.c:2848
 #, c-format
-msgid "Failed to merge submodule %s (not checked out)"
+msgid "unable to mmap '%s'"
 msgstr ""
 
-#: merge-recursive.c:1193
+#: config.c:2857 config.c:3095
 #, c-format
-msgid "Failed to merge submodule %s (commits not present)"
+msgid "chmod on %s failed"
 msgstr ""
 
-#: merge-recursive.c:1200
+#: config.c:2942 config.c:3192
 #, c-format
-msgid "Failed to merge submodule %s (commits don't follow merge-base)"
+msgid "could not write config file %s"
 msgstr ""
 
-#: merge-recursive.c:1208 merge-recursive.c:1220
+#: config.c:2976
 #, c-format
-msgid "Fast-forwarding submodule %s to the following commit:"
+msgid "could not set '%s' to '%s'"
 msgstr ""
 
-#: merge-recursive.c:1211 merge-recursive.c:1223
+#: config.c:2978 builtin/remote.c:781
 #, c-format
-msgid "Fast-forwarding submodule %s"
+msgid "could not unset '%s'"
 msgstr ""
 
-#: merge-recursive.c:1245
+#: config.c:3068
 #, c-format
-msgid "Failed to merge submodule %s (merge following commits not found)"
+msgid "invalid section name: %s"
 msgstr ""
 
-#: merge-recursive.c:1249
+#: config.c:3235
 #, c-format
-msgid "Failed to merge submodule %s (not fast-forward)"
+msgid "missing value for '%s'"
 msgstr ""
 
-#: merge-recursive.c:1250
-msgid "Found a possible merge resolution for the submodule:\n"
+#: connect.c:61
+msgid "the remote end hung up upon initial contact"
 msgstr ""
 
-#: merge-recursive.c:1253
-#, c-format
+#: connect.c:63
 msgid ""
-"If this is correct simply add it to the index for example\n"
-"by using:\n"
-"\n"
-"  git update-index --cacheinfo 160000 %s \"%s\"\n"
+"Could not read from remote repository.\n"
 "\n"
-"which will accept this suggestion.\n"
-msgstr ""
-
-#: merge-recursive.c:1262
-#, c-format
-msgid "Failed to merge submodule %s (multiple merges found)"
-msgstr ""
-
-#: merge-recursive.c:1321
-msgid "Failed to execute internal merge"
-msgstr ""
-
-#: merge-recursive.c:1326
-#, c-format
-msgid "Unable to add %s to database"
+"Please make sure you have the correct access rights\n"
+"and the repository exists."
 msgstr ""
 
-#: merge-recursive.c:1358
+#: connect.c:81
 #, c-format
-msgid "Auto-merging %s"
+msgid "server doesn't support '%s'"
 msgstr ""
 
-#: merge-recursive.c:1423
+#: connect.c:103
 #, c-format
-msgid "Error: Refusing to lose untracked file at %s; writing to %s instead."
+msgid "server doesn't support feature '%s'"
 msgstr ""
 
-#: merge-recursive.c:1475
-#, c-format
-msgid ""
-"CONFLICT (%s/delete): %s deleted in %s and %s in %s. Version %s of %s left "
-"in tree."
+#: connect.c:114
+msgid "expected flush after capabilities"
 msgstr ""
 
-#: merge-recursive.c:1480
+#: connect.c:233
 #, c-format
-msgid ""
-"CONFLICT (%s/delete): %s deleted in %s and %s to %s in %s. Version %s of %s "
-"left in tree."
+msgid "ignoring capabilities after first line '%s'"
 msgstr ""
 
-#: merge-recursive.c:1487
-#, c-format
-msgid ""
-"CONFLICT (%s/delete): %s deleted in %s and %s in %s. Version %s of %s left "
-"in tree at %s."
+#: connect.c:252
+msgid "protocol error: unexpected capabilities^{}"
 msgstr ""
 
-#: merge-recursive.c:1492
+#: connect.c:273
 #, c-format
-msgid ""
-"CONFLICT (%s/delete): %s deleted in %s and %s to %s in %s. Version %s of %s "
-"left in tree at %s."
-msgstr ""
-
-#: merge-recursive.c:1526
-msgid "rename"
-msgstr ""
-
-#: merge-recursive.c:1526
-msgid "renamed"
+msgid "protocol error: expected shallow sha-1, got '%s'"
 msgstr ""
 
-#: merge-recursive.c:1580 merge-recursive.c:1736 merge-recursive.c:2368
-#: merge-recursive.c:3086
-#, c-format
-msgid "Refusing to lose dirty file at %s"
+#: connect.c:275
+msgid "repository on the other end cannot be shallow"
 msgstr ""
 
-#: merge-recursive.c:1594
-#, c-format
-msgid "%s is a directory in %s adding as %s instead"
+#: connect.c:313
+msgid "invalid packet"
 msgstr ""
 
-#: merge-recursive.c:1599
+#: connect.c:333
 #, c-format
-msgid "Refusing to lose untracked file at %s; adding as %s instead"
+msgid "protocol error: unexpected '%s'"
 msgstr ""
 
-#: merge-recursive.c:1625
+#: connect.c:441
 #, c-format
-msgid ""
-"CONFLICT (rename/rename): Rename \"%s\"->\"%s\" in branch \"%s\" rename \"%s"
-"\"->\"%s\" in \"%s\"%s"
-msgstr ""
-
-#: merge-recursive.c:1630
-msgid " (left unresolved)"
+msgid "invalid ls-refs response: %s"
 msgstr ""
 
-#: merge-recursive.c:1694
-#, c-format
-msgid "CONFLICT (rename/rename): Rename %s->%s in %s. Rename %s->%s in %s"
+#: connect.c:445
+msgid "expected flush after ref listing"
 msgstr ""
 
-#: merge-recursive.c:1733
+#: connect.c:544
 #, c-format
-msgid "Renaming %s to %s and %s to %s instead"
+msgid "protocol '%s' is not supported"
 msgstr ""
 
-#: merge-recursive.c:1745
-#, c-format
-msgid "Refusing to lose untracked file at %s, even though it's in the way."
+#: connect.c:595
+msgid "unable to set SO_KEEPALIVE on socket"
 msgstr ""
 
-#: merge-recursive.c:1951
+#: connect.c:635 connect.c:698
 #, c-format
-msgid ""
-"CONFLICT (directory rename split): Unclear where to place %s because "
-"directory %s was renamed to multiple other directories, with no destination "
-"getting a majority of the files."
+msgid "Looking up %s ... "
 msgstr ""
 
-#: merge-recursive.c:1983
+#: connect.c:639
 #, c-format
-msgid ""
-"CONFLICT (implicit dir rename): Existing file/dir at %s in the way of "
-"implicit directory rename(s) putting the following path(s) there: %s."
+msgid "unable to look up %s (port %s) (%s)"
 msgstr ""
 
-#: merge-recursive.c:1993
+#. TRANSLATORS: this is the end of "Looking up %s ... "
+#: connect.c:643 connect.c:714
 #, c-format
 msgid ""
-"CONFLICT (implicit dir rename): Cannot map more than one path to %s; "
-"implicit directory renames tried to put these paths there: %s"
+"done.\n"
+"Connecting to %s (port %s) ... "
 msgstr ""
 
-#: merge-recursive.c:2085
+#: connect.c:665 connect.c:742
 #, c-format
 msgid ""
-"CONFLICT (rename/rename): Rename directory %s->%s in %s. Rename directory %s-"
-">%s in %s"
+"unable to connect to %s:\n"
+"%s"
 msgstr ""
 
-#: merge-recursive.c:2330
-#, c-format
-msgid ""
-"WARNING: Avoiding applying %s -> %s rename to %s, because %s itself was "
-"renamed."
+#. TRANSLATORS: this is the end of "Connecting to %s (port %s) ... "
+#: connect.c:671 connect.c:748
+msgid "done."
 msgstr ""
 
-#: merge-recursive.c:2736
+#: connect.c:702
 #, c-format
-msgid "CONFLICT (rename/add): Rename %s->%s in %s. %s added in %s"
+msgid "unable to look up %s (%s)"
 msgstr ""
 
-#: merge-recursive.c:2751
+#: connect.c:708
 #, c-format
-msgid "Adding merged %s"
+msgid "unknown port %s"
 msgstr ""
 
-#: merge-recursive.c:2758 merge-recursive.c:3089
+#: connect.c:845 connect.c:1175
 #, c-format
-msgid "Adding as %s instead"
+msgid "strange hostname '%s' blocked"
 msgstr ""
 
-#: merge-recursive.c:2914
+#: connect.c:847
 #, c-format
-msgid "cannot read object %s"
+msgid "strange port '%s' blocked"
 msgstr ""
 
-#: merge-recursive.c:2917
+#: connect.c:857
 #, c-format
-msgid "object %s is not a blob"
+msgid "cannot start proxy %s"
 msgstr ""
 
-#: merge-recursive.c:2986
-msgid "modify"
+#: connect.c:928
+msgid "no path specified; see 'git help pull' for valid url syntax"
 msgstr ""
 
-#: merge-recursive.c:2986
-msgid "modified"
+#: connect.c:1123
+msgid "ssh variant 'simple' does not support -4"
 msgstr ""
 
-#: merge-recursive.c:2997
-msgid "content"
+#: connect.c:1135
+msgid "ssh variant 'simple' does not support -6"
 msgstr ""
 
-#: merge-recursive.c:3004
-msgid "add/add"
+#: connect.c:1152
+msgid "ssh variant 'simple' does not support setting port"
 msgstr ""
 
-#: merge-recursive.c:3046
+#: connect.c:1264
 #, c-format
-msgid "Skipped %s (merged same as existing)"
+msgid "strange pathname '%s' blocked"
 msgstr ""
 
-#: merge-recursive.c:3055 git-submodule.sh:895
-msgid "submodule"
+#: connect.c:1311
+msgid "unable to fork"
 msgstr ""
 
-#: merge-recursive.c:3056
-#, c-format
-msgid "CONFLICT (%s): Merge conflict in %s"
+#: connected.c:89 builtin/fsck.c:208 builtin/prune.c:43
+msgid "Checking connectivity"
 msgstr ""
 
-#: merge-recursive.c:3178
-#, c-format
-msgid "Removing %s"
+#: connected.c:101
+msgid "Could not run 'git rev-list'"
 msgstr ""
 
-#: merge-recursive.c:3204
-msgid "file/directory"
+#: connected.c:121
+msgid "failed write to rev-list"
 msgstr ""
 
-#: merge-recursive.c:3210
-msgid "directory/file"
+#: connected.c:128
+msgid "failed to close rev-list's stdin"
 msgstr ""
 
-#: merge-recursive.c:3217
+#: convert.c:194
 #, c-format
-msgid "CONFLICT (%s): There is a directory with name %s in %s. Adding %s as %s"
+msgid "illegal crlf_action %d"
 msgstr ""
 
-#: merge-recursive.c:3226
+#: convert.c:207
 #, c-format
-msgid "Adding %s"
+msgid "CRLF would be replaced by LF in %s"
 msgstr ""
 
-#: merge-recursive.c:3267
+#: convert.c:209
 #, c-format
-msgid "Dirty index: cannot merge (dirty: %s)"
-msgstr ""
-
-#: merge-recursive.c:3271
-msgid "Already up to date!"
+msgid ""
+"CRLF will be replaced by LF in %s.\n"
+"The file will have its original line endings in your working directory"
 msgstr ""
 
-#: merge-recursive.c:3280
+#: convert.c:217
 #, c-format
-msgid "merging of trees %s and %s failed"
-msgstr ""
-
-#: merge-recursive.c:3379
-msgid "Merging:"
+msgid "LF would be replaced by CRLF in %s"
 msgstr ""
 
-#: merge-recursive.c:3392
+#: convert.c:219
 #, c-format
-msgid "found %u common ancestor:"
-msgid_plural "found %u common ancestors:"
-msgstr[0] ""
-msgstr[1] ""
-
-#: merge-recursive.c:3431
-msgid "merge returned no commit"
+msgid ""
+"LF will be replaced by CRLF in %s.\n"
+"The file will have its original line endings in your working directory"
 msgstr ""
 
-#: merge-recursive.c:3495
+#: convert.c:284
 #, c-format
-msgid "Could not parse object '%s'"
-msgstr ""
-
-#: merge-recursive.c:3511 builtin/merge.c:659 builtin/merge.c:816
-msgid "Unable to write index."
+msgid "BOM is prohibited in '%s' if encoded as %s"
 msgstr ""
 
-#: notes-merge.c:272
+#: convert.c:291
 #, c-format
 msgid ""
-"You have not concluded your previous notes merge (%s exists).\n"
-"Please, use 'git notes merge --commit' or 'git notes merge --abort' to "
-"commit/abort the previous merge before you start a new notes merge."
+"The file '%s' contains a byte order mark (BOM). Please use UTF-%.*s as "
+"working-tree-encoding."
 msgstr ""
 
-#: notes-merge.c:279
+#: convert.c:304
 #, c-format
-msgid "You have not concluded your notes merge (%s exists)."
-msgstr ""
-
-#: notes-utils.c:43
-msgid "Cannot commit uninitialized/unreferenced notes tree"
+msgid "BOM is required in '%s' if encoded as %s"
 msgstr ""
 
-#: notes-utils.c:102
+#: convert.c:306
 #, c-format
-msgid "Bad notes.rewriteMode value: '%s'"
+msgid ""
+"The file '%s' is missing a byte order mark (BOM). Please use UTF-%sBE or UTF-"
+"%sLE (depending on the byte order) as working-tree-encoding."
 msgstr ""
 
-#: notes-utils.c:112
+#: convert.c:419 convert.c:490
 #, c-format
-msgid "Refusing to rewrite notes in %s (outside of refs/notes/)"
+msgid "failed to encode '%s' from %s to %s"
 msgstr ""
 
-#. TRANSLATORS: The first %s is the name of
-#. the environment variable, the second %s is
-#. its value.
-#.
-#: notes-utils.c:142
+#: convert.c:462
 #, c-format
-msgid "Bad %s value: '%s'"
+msgid "encoding '%s' from %s to %s and back is not the same"
 msgstr ""
 
-#: object.c:242
+#: convert.c:668
 #, c-format
-msgid "unable to parse object: %s"
+msgid "cannot fork to run external filter '%s'"
 msgstr ""
 
-#: packfile.c:563
-msgid "offset before end of packfile (broken .idx?)"
+#: convert.c:688
+#, c-format
+msgid "cannot feed the input to external filter '%s'"
 msgstr ""
 
-#: packfile.c:1742
+#: convert.c:695
 #, c-format
-msgid "offset before start of pack index for %s (corrupt index?)"
+msgid "external filter '%s' failed %d"
 msgstr ""
 
-#: packfile.c:1746
+#: convert.c:730 convert.c:733
 #, c-format
-msgid "offset beyond end of pack index for %s (truncated index?)"
+msgid "read from external filter '%s' failed"
 msgstr ""
 
-#: parse-options.c:621
-msgid "..."
+#: convert.c:736 convert.c:791
+#, c-format
+msgid "external filter '%s' failed"
 msgstr ""
 
-#: parse-options.c:640
-#, c-format
-msgid "usage: %s"
+#: convert.c:839
+msgid "unexpected filter type"
 msgstr ""
 
-#. TRANSLATORS: the colon here should align with the
-#. one in "usage: %s" translation.
-#.
-#: parse-options.c:646
-#, c-format
-msgid "   or: %s"
+#: convert.c:850
+msgid "path name too long for external filter"
 msgstr ""
 
-#: parse-options.c:649
+#: convert.c:924
 #, c-format
-msgid "    %s"
+msgid ""
+"external filter '%s' is not available anymore although not all paths have "
+"been filtered"
 msgstr ""
 
-#: parse-options.c:688
-msgid "-NUM"
+#: convert.c:1223
+msgid "true/false are no valid working-tree-encodings"
 msgstr ""
 
-#: parse-options-cb.c:44
+#: convert.c:1411 convert.c:1445
 #, c-format
-msgid "malformed expiration date '%s'"
+msgid "%s: clean filter '%s' failed"
 msgstr ""
 
-#: parse-options-cb.c:112
+#: convert.c:1489
 #, c-format
-msgid "malformed object name '%s'"
+msgid "%s: smudge filter %s failed"
 msgstr ""
 
-#: path.c:892
-#, c-format
-msgid "Could not make %s writable by group"
+#: date.c:138
+msgid "in the future"
 msgstr ""
 
-#: pathspec.c:129
-msgid "Escape character '\\' not allowed as last character in attr value"
-msgstr ""
+#: date.c:144
+#, c-format
+msgid "%<PRIuMAX> second ago"
+msgid_plural "%<PRIuMAX> seconds ago"
+msgstr[0] ""
+msgstr[1] ""
 
-#: pathspec.c:147
-msgid "Only one 'attr:' specification is allowed."
-msgstr ""
+#: date.c:151
+#, c-format
+msgid "%<PRIuMAX> minute ago"
+msgid_plural "%<PRIuMAX> minutes ago"
+msgstr[0] ""
+msgstr[1] ""
 
-#: pathspec.c:150
-msgid "attr spec must not be empty"
-msgstr ""
+#: date.c:158
+#, c-format
+msgid "%<PRIuMAX> hour ago"
+msgid_plural "%<PRIuMAX> hours ago"
+msgstr[0] ""
+msgstr[1] ""
 
-#: pathspec.c:193
+#: date.c:165
 #, c-format
-msgid "invalid attribute name %s"
-msgstr ""
+msgid "%<PRIuMAX> day ago"
+msgid_plural "%<PRIuMAX> days ago"
+msgstr[0] ""
+msgstr[1] ""
 
-#: pathspec.c:258
-msgid "global 'glob' and 'noglob' pathspec settings are incompatible"
-msgstr ""
+#: date.c:171
+#, c-format
+msgid "%<PRIuMAX> week ago"
+msgid_plural "%<PRIuMAX> weeks ago"
+msgstr[0] ""
+msgstr[1] ""
 
-#: pathspec.c:265
-msgid ""
-"global 'literal' pathspec setting is incompatible with all other global "
-"pathspec settings"
-msgstr ""
+#: date.c:178
+#, c-format
+msgid "%<PRIuMAX> month ago"
+msgid_plural "%<PRIuMAX> months ago"
+msgstr[0] ""
+msgstr[1] ""
 
-#: pathspec.c:305
-msgid "invalid parameter for pathspec magic 'prefix'"
-msgstr ""
+#: date.c:189
+#, c-format
+msgid "%<PRIuMAX> year"
+msgid_plural "%<PRIuMAX> years"
+msgstr[0] ""
+msgstr[1] ""
 
-#: pathspec.c:326
+#. TRANSLATORS: "%s" is "<n> years"
+#: date.c:192
 #, c-format
-msgid "Invalid pathspec magic '%.*s' in '%s'"
-msgstr ""
+msgid "%s, %<PRIuMAX> month ago"
+msgid_plural "%s, %<PRIuMAX> months ago"
+msgstr[0] ""
+msgstr[1] ""
 
-#: pathspec.c:331
+#: date.c:197 date.c:202
 #, c-format
-msgid "Missing ')' at the end of pathspec magic in '%s'"
+msgid "%<PRIuMAX> year ago"
+msgid_plural "%<PRIuMAX> years ago"
+msgstr[0] ""
+msgstr[1] ""
+
+#: delta-islands.c:272
+msgid "Propagating island marks"
 msgstr ""
 
-#: pathspec.c:369
+#: delta-islands.c:290
 #, c-format
-msgid "Unimplemented pathspec magic '%c' in '%s'"
+msgid "bad tree object %s"
 msgstr ""
 
-#: pathspec.c:428
+#: delta-islands.c:334
 #, c-format
-msgid "%s: 'literal' and 'glob' are incompatible"
+msgid "failed to load island regex for '%s': %s"
 msgstr ""
 
-#: pathspec.c:441
+#: delta-islands.c:390
 #, c-format
-msgid "%s: '%s' is outside repository"
+msgid "island regex from config has too many capture groups (max=%d)"
 msgstr ""
 
-#: pathspec.c:515
+#: delta-islands.c:467
 #, c-format
-msgid "'%s' (mnemonic: '%c')"
+msgid "Marked %d islands, done.\n"
 msgstr ""
 
-#: pathspec.c:525
+#: diffcore-order.c:24
 #, c-format
-msgid "%s: pathspec magic not supported by this command: %s"
+msgid "failed to read orderfile '%s'"
 msgstr ""
 
-#: pathspec.c:592
-#, c-format
-msgid "pathspec '%s' is beyond a symbolic link"
+#: diffcore-rename.c:543
+msgid "Performing inexact rename detection"
 msgstr ""
 
-#: pretty.c:962
-msgid "unable to parse --pretty format"
+#: diff-no-index.c:238
+msgid "git diff --no-index [<options>] <path> <path>"
 msgstr ""
 
-#: read-cache.c:1500
-#, c-format
+#: diff-no-index.c:263
 msgid ""
-"index.version set, but the value is invalid.\n"
-"Using version %i"
+"Not a git repository. Use --no-index to compare two paths outside a working "
+"tree"
 msgstr ""
 
-#: read-cache.c:1510
+#: diff.c:155
 #, c-format
-msgid ""
-"GIT_INDEX_VERSION set, but the value is invalid.\n"
-"Using version %i"
+msgid "  Failed to parse dirstat cut-off percentage '%s'\n"
 msgstr ""
 
-#: read-cache.c:2404 sequencer.c:4338 wrapper.c:658 builtin/merge.c:1048
+#: diff.c:160
 #, c-format
-msgid "could not close '%s'"
+msgid "  Unknown dirstat parameter '%s'\n"
 msgstr ""
 
-#: read-cache.c:2477 sequencer.c:2102 sequencer.c:3234
-#, c-format
-msgid "could not stat '%s'"
+#: diff.c:296
+msgid ""
+"color moved setting must be one of 'no', 'default', 'blocks', 'zebra', "
+"'dimmed-zebra', 'plain'"
 msgstr ""
 
-#: read-cache.c:2490
+#: diff.c:324
 #, c-format
-msgid "unable to open git dir: %s"
+msgid ""
+"unknown color-moved-ws mode '%s', possible values are 'ignore-space-change', "
+"'ignore-space-at-eol', 'ignore-all-space', 'allow-indentation-change'"
 msgstr ""
 
-#: read-cache.c:2502
-#, c-format
-msgid "unable to unlink: %s"
+#: diff.c:332
+msgid ""
+"color-moved-ws: allow-indentation-change cannot be combined with other "
+"whitespace modes"
 msgstr ""
 
-#: refs.c:732 sequencer.c:4334 sequencer.c:4393 wrapper.c:225 wrapper.c:395
-#: builtin/am.c:779
+#: diff.c:405
 #, c-format
-msgid "could not open '%s' for writing"
+msgid "Unknown value for 'diff.submodule' config variable: '%s'"
 msgstr ""
 
-#: refs.c:1880
-msgid "ref updates forbidden inside quarantine environment"
+#: diff.c:465
+#, c-format
+msgid ""
+"Found errors in 'diff.dirstat' config variable:\n"
+"%s"
 msgstr ""
 
-#: refs/files-backend.c:1191
+#: diff.c:4202
 #, c-format
-msgid "could not remove reference %s"
+msgid "external diff died, stopping at %s"
 msgstr ""
 
-#: refs/files-backend.c:1205 refs/packed-backend.c:1531
-#: refs/packed-backend.c:1541
-#, c-format
-msgid "could not delete reference %s: %s"
+#: diff.c:4547
+msgid "--name-only, --name-status, --check and -s are mutually exclusive"
 msgstr ""
 
-#: refs/files-backend.c:1208 refs/packed-backend.c:1544
-#, c-format
-msgid "could not delete references: %s"
+#: diff.c:4550
+msgid "-G, -S and --find-object are mutually exclusive"
 msgstr ""
 
-#: ref-filter.c:35 wt-status.c:1850
-msgid "gone"
+#: diff.c:4628
+msgid "--follow requires exactly one pathspec"
 msgstr ""
 
-#: ref-filter.c:36
+#: diff.c:4676
 #, c-format
-msgid "ahead %d"
+msgid "invalid --stat value: %s"
 msgstr ""
 
-#: ref-filter.c:37
+#: diff.c:4681 diff.c:4686 diff.c:4691 diff.c:4696 diff.c:5209
+#: parse-options.c:199 parse-options.c:203
 #, c-format
-msgid "behind %d"
+msgid "%s expects a numerical value"
 msgstr ""
 
-#: ref-filter.c:38
+#: diff.c:4713
 #, c-format
-msgid "ahead %d, behind %d"
+msgid ""
+"Failed to parse --dirstat/-X option parameter:\n"
+"%s"
 msgstr ""
 
-#: ref-filter.c:121
+#: diff.c:4798
 #, c-format
-msgid "expected format: %%(color:<color>)"
+msgid "unknown change class '%c' in --diff-filter=%s"
 msgstr ""
 
-#: ref-filter.c:123
+#: diff.c:4822
 #, c-format
-msgid "unrecognized color: %%(color:%s)"
+msgid "unknown value after ws-error-highlight=%.*s"
 msgstr ""
 
-#: ref-filter.c:145
+#: diff.c:4836
 #, c-format
-msgid "Integer value expected refname:lstrip=%s"
+msgid "unable to resolve '%s'"
 msgstr ""
 
-#: ref-filter.c:149
+#: diff.c:4886 diff.c:4892
 #, c-format
-msgid "Integer value expected refname:rstrip=%s"
+msgid "%s expects <n>/<m> form"
 msgstr ""
 
-#: ref-filter.c:151
+#: diff.c:4904
 #, c-format
-msgid "unrecognized %%(%s) argument: %s"
+msgid "%s expects a character, got '%s'"
 msgstr ""
 
-#: ref-filter.c:206
+#: diff.c:4925
 #, c-format
-msgid "%%(body) does not take arguments"
+msgid "bad --color-moved argument: %s"
 msgstr ""
 
-#: ref-filter.c:215
+#: diff.c:4944
 #, c-format
-msgid "%%(subject) does not take arguments"
+msgid "invalid mode '%s' in --color-moved-ws"
 msgstr ""
 
-#: ref-filter.c:235
-#, c-format
-msgid "unknown %%(trailers) argument: %s"
+#: diff.c:4984
+msgid ""
+"option diff-algorithm accepts \"myers\", \"minimal\", \"patience\" and "
+"\"histogram\""
 msgstr ""
 
-#: ref-filter.c:264
+#: diff.c:5020 diff.c:5040
 #, c-format
-msgid "positive value expected contents:lines=%s"
+msgid "invalid argument to %s"
 msgstr ""
 
-#: ref-filter.c:266
+#: diff.c:5178
 #, c-format
-msgid "unrecognized %%(contents) argument: %s"
+msgid "failed to parse --submodule option parameter: '%s'"
 msgstr ""
 
-#: ref-filter.c:281
+#: diff.c:5234
 #, c-format
-msgid "positive value expected objectname:short=%s"
+msgid "bad --word-diff argument: %s"
 msgstr ""
 
-#: ref-filter.c:285
-#, c-format
-msgid "unrecognized %%(objectname) argument: %s"
+#: diff.c:5257
+msgid "Diff output format options"
 msgstr ""
 
-#: ref-filter.c:315
-#, c-format
-msgid "expected format: %%(align:<width>,<position>)"
+#: diff.c:5259 diff.c:5265
+msgid "generate patch"
 msgstr ""
 
-#: ref-filter.c:327
-#, c-format
-msgid "unrecognized position:%s"
+#: diff.c:5262 builtin/log.c:173
+msgid "suppress diff output"
 msgstr ""
 
-#: ref-filter.c:334
-#, c-format
-msgid "unrecognized width:%s"
+#: diff.c:5267 diff.c:5381 diff.c:5388
+msgid "<n>"
 msgstr ""
 
-#: ref-filter.c:343
-#, c-format
-msgid "unrecognized %%(align) argument: %s"
+#: diff.c:5268 diff.c:5271
+msgid "generate diffs with <n> lines context"
 msgstr ""
 
-#: ref-filter.c:351
-#, c-format
-msgid "positive width expected with the %%(align) atom"
+#: diff.c:5273
+msgid "generate the diff in raw format"
 msgstr ""
 
-#: ref-filter.c:369
-#, c-format
-msgid "unrecognized %%(if) argument: %s"
+#: diff.c:5276
+msgid "synonym for '-p --raw'"
 msgstr ""
 
-#: ref-filter.c:464
-#, c-format
-msgid "malformed field name: %.*s"
+#: diff.c:5280
+msgid "synonym for '-p --stat'"
 msgstr ""
 
-#: ref-filter.c:491
-#, c-format
-msgid "unknown field name: %.*s"
+#: diff.c:5284
+msgid "machine friendly --stat"
 msgstr ""
 
-#: ref-filter.c:608
-#, c-format
-msgid "format: %%(if) atom used without a %%(then) atom"
+#: diff.c:5287
+msgid "output only the last line of --stat"
 msgstr ""
 
-#: ref-filter.c:671
-#, c-format
-msgid "format: %%(then) atom used without an %%(if) atom"
+#: diff.c:5289 diff.c:5297
+msgid "<param1,param2>..."
 msgstr ""
 
-#: ref-filter.c:673
-#, c-format
-msgid "format: %%(then) atom used more than once"
+#: diff.c:5290
+msgid ""
+"output the distribution of relative amount of changes for each sub-directory"
 msgstr ""
 
-#: ref-filter.c:675
-#, c-format
-msgid "format: %%(then) atom used after %%(else)"
+#: diff.c:5294
+msgid "synonym for --dirstat=cumulative"
 msgstr ""
 
-#: ref-filter.c:703
-#, c-format
-msgid "format: %%(else) atom used without an %%(if) atom"
+#: diff.c:5298
+msgid "synonym for --dirstat=files,param1,param2..."
 msgstr ""
 
-#: ref-filter.c:705
-#, c-format
-msgid "format: %%(else) atom used without a %%(then) atom"
+#: diff.c:5302
+msgid "warn if changes introduce conflict markers or whitespace errors"
 msgstr ""
 
-#: ref-filter.c:707
-#, c-format
-msgid "format: %%(else) atom used more than once"
+#: diff.c:5305
+msgid "condensed summary such as creations, renames and mode changes"
 msgstr ""
 
-#: ref-filter.c:722
-#, c-format
-msgid "format: %%(end) atom used without corresponding atom"
+#: diff.c:5308
+msgid "show only names of changed files"
 msgstr ""
 
-#: ref-filter.c:779
-#, c-format
-msgid "malformed format string %s"
+#: diff.c:5311
+msgid "show only names and status of changed files"
 msgstr ""
 
-#: ref-filter.c:1387
-#, c-format
-msgid "(no branch, rebasing %s)"
+#: diff.c:5313
+msgid "<width>[,<name-width>[,<count>]]"
 msgstr ""
 
-#: ref-filter.c:1390
-#, c-format
-msgid "(no branch, rebasing detached HEAD %s)"
+#: diff.c:5314
+msgid "generate diffstat"
 msgstr ""
 
-#: ref-filter.c:1393
-#, c-format
-msgid "(no branch, bisect started on %s)"
+#: diff.c:5316 diff.c:5319 diff.c:5322
+msgid "<width>"
 msgstr ""
 
-#. TRANSLATORS: make sure this matches "HEAD
-#. detached at " in wt-status.c
-#.
-#: ref-filter.c:1401
-#, c-format
-msgid "(HEAD detached at %s)"
+#: diff.c:5317
+msgid "generate diffstat with a given width"
 msgstr ""
 
-#. TRANSLATORS: make sure this matches "HEAD
-#. detached from " in wt-status.c
-#.
-#: ref-filter.c:1408
-#, c-format
-msgid "(HEAD detached from %s)"
+#: diff.c:5320
+msgid "generate diffstat with a given name width"
 msgstr ""
 
-#: ref-filter.c:1412
-msgid "(no branch)"
+#: diff.c:5323
+msgid "generate diffstat with a given graph width"
 msgstr ""
 
-#: ref-filter.c:1442
-#, c-format
-msgid "missing object %s for %s"
+#: diff.c:5325
+msgid "<count>"
 msgstr ""
 
-#: ref-filter.c:1445
-#, c-format
-msgid "parse_object_buffer failed on %s for %s"
+#: diff.c:5326
+msgid "generate diffstat with limited lines"
 msgstr ""
 
-#: ref-filter.c:1902
-#, c-format
-msgid "malformed object at '%s'"
+#: diff.c:5329
+msgid "generate compact summary in diffstat"
 msgstr ""
 
-#: ref-filter.c:1984
-#, c-format
-msgid "ignoring ref with broken name %s"
+#: diff.c:5332
+msgid "output a binary diff that can be applied"
 msgstr ""
 
-#: ref-filter.c:1989
-#, c-format
-msgid "ignoring broken ref %s"
+#: diff.c:5335
+msgid "show full pre- and post-image object names on the \"index\" lines"
 msgstr ""
 
-#: ref-filter.c:2261
-#, c-format
-msgid "format: %%(end) atom missing"
+#: diff.c:5337
+msgid "show colored diff"
 msgstr ""
 
-#: ref-filter.c:2365
-#, c-format
-msgid "malformed object name %s"
+#: diff.c:5338
+msgid "<kind>"
 msgstr ""
 
-#: remote.c:605
-#, c-format
-msgid "Cannot fetch both %s and %s to %s"
+#: diff.c:5339
+msgid ""
+"highlight whitespace errors in the 'context', 'old' or 'new' lines in the "
+"diff"
 msgstr ""
 
-#: remote.c:609
-#, c-format
-msgid "%s usually tracks %s, not %s"
+#: diff.c:5342
+msgid ""
+"do not munge pathnames and use NULs as output field terminators in --raw or "
+"--numstat"
 msgstr ""
 
-#: remote.c:613
-#, c-format
-msgid "%s tracks both %s and %s"
+#: diff.c:5345 diff.c:5348 diff.c:5351 diff.c:5457
+msgid "<prefix>"
 msgstr ""
 
-#: remote.c:621
-msgid "Internal error"
+#: diff.c:5346
+msgid "show the given source prefix instead of \"a/\""
 msgstr ""
 
-#: remote.c:1534 remote.c:1635
-msgid "HEAD does not point to a branch"
+#: diff.c:5349
+msgid "show the given destination prefix instead of \"b/\""
 msgstr ""
 
-#: remote.c:1543
-#, c-format
-msgid "no such branch: '%s'"
+#: diff.c:5352
+msgid "prepend an additional prefix to every line of output"
 msgstr ""
 
-#: remote.c:1546
-#, c-format
-msgid "no upstream configured for branch '%s'"
+#: diff.c:5355
+msgid "do not show any source or destination prefix"
 msgstr ""
 
-#: remote.c:1552
-#, c-format
-msgid "upstream branch '%s' not stored as a remote-tracking branch"
+#: diff.c:5358
+msgid "show context between diff hunks up to the specified number of lines"
 msgstr ""
 
-#: remote.c:1567
-#, c-format
-msgid "push destination '%s' on remote '%s' has no local tracking branch"
+#: diff.c:5362 diff.c:5367 diff.c:5372
+msgid "<char>"
 msgstr ""
 
-#: remote.c:1579
-#, c-format
-msgid "branch '%s' has no remote for pushing"
+#: diff.c:5363
+msgid "specify the character to indicate a new line instead of '+'"
 msgstr ""
 
-#: remote.c:1589
-#, c-format
-msgid "push refspecs for '%s' do not include '%s'"
+#: diff.c:5368
+msgid "specify the character to indicate an old line instead of '-'"
 msgstr ""
 
-#: remote.c:1602
-msgid "push has no destination (push.default is 'nothing')"
+#: diff.c:5373
+msgid "specify the character to indicate a context instead of ' '"
 msgstr ""
 
-#: remote.c:1624
-msgid "cannot resolve 'simple' push to a single destination"
+#: diff.c:5376
+msgid "Diff rename options"
 msgstr ""
 
-#: remote.c:1939
-#, c-format
-msgid "Your branch is based on '%s', but the upstream is gone.\n"
+#: diff.c:5377
+msgid "<n>[/<m>]"
 msgstr ""
 
-#: remote.c:1943
-msgid "  (use \"git branch --unset-upstream\" to fixup)\n"
+#: diff.c:5378
+msgid "break complete rewrite changes into pairs of delete and create"
 msgstr ""
 
-#: remote.c:1946
-#, c-format
-msgid "Your branch is up to date with '%s'.\n"
+#: diff.c:5382
+msgid "detect renames"
 msgstr ""
 
-#: remote.c:1950
-#, c-format
-msgid "Your branch and '%s' refer to different commits.\n"
+#: diff.c:5386
+msgid "omit the preimage for deletes"
 msgstr ""
 
-#: remote.c:1953
-#, c-format
-msgid "  (use \"%s\" for details)\n"
+#: diff.c:5389
+msgid "detect copies"
 msgstr ""
 
-#: remote.c:1957
-#, c-format
-msgid "Your branch is ahead of '%s' by %d commit.\n"
-msgid_plural "Your branch is ahead of '%s' by %d commits.\n"
-msgstr[0] ""
-msgstr[1] ""
+#: diff.c:5393
+msgid "use unmodified files as source to find copies"
+msgstr ""
 
-#: remote.c:1963
-msgid "  (use \"git push\" to publish your local commits)\n"
+#: diff.c:5395
+msgid "disable rename detection"
 msgstr ""
 
-#: remote.c:1966
-#, c-format
-msgid "Your branch is behind '%s' by %d commit, and can be fast-forwarded.\n"
-msgid_plural ""
-"Your branch is behind '%s' by %d commits, and can be fast-forwarded.\n"
-msgstr[0] ""
-msgstr[1] ""
+#: diff.c:5398
+msgid "use empty blobs as rename source"
+msgstr ""
 
-#: remote.c:1974
-msgid "  (use \"git pull\" to update your local branch)\n"
+#: diff.c:5400
+msgid "continue listing the history of a file beyond renames"
 msgstr ""
 
-#: remote.c:1977
-#, c-format
+#: diff.c:5403
 msgid ""
-"Your branch and '%s' have diverged,\n"
-"and have %d and %d different commit each, respectively.\n"
-msgid_plural ""
-"Your branch and '%s' have diverged,\n"
-"and have %d and %d different commits each, respectively.\n"
-msgstr[0] ""
-msgstr[1] ""
+"prevent rename/copy detection if the number of rename/copy targets exceeds "
+"given limit"
+msgstr ""
 
-#: remote.c:1987
-msgid "  (use \"git pull\" to merge the remote branch into yours)\n"
+#: diff.c:5405
+msgid "Diff algorithm options"
 msgstr ""
 
-#: revision.c:2289
-msgid "your current branch appears to be broken"
+#: diff.c:5407
+msgid "produce the smallest possible diff"
 msgstr ""
 
-#: revision.c:2292
-#, c-format
-msgid "your current branch '%s' does not have any commits yet"
+#: diff.c:5410
+msgid "ignore whitespace when comparing lines"
 msgstr ""
 
-#: revision.c:2489
-msgid "--first-parent is incompatible with --bisect"
+#: diff.c:5413
+msgid "ignore changes in amount of whitespace"
 msgstr ""
 
-#: run-command.c:728
-msgid "open /dev/null failed"
+#: diff.c:5416
+msgid "ignore changes in whitespace at EOL"
 msgstr ""
 
-#: run-command.c:1271
-#, c-format
-msgid ""
-"The '%s' hook was ignored because it's not set as executable.\n"
-"You can disable this warning with `git config advice.ignoredHook false`."
+#: diff.c:5419
+msgid "ignore carrier-return at the end of line"
 msgstr ""
 
-#: send-pack.c:141
-msgid "unexpected flush packet while reading remote unpack status"
+#: diff.c:5422
+msgid "ignore changes whose lines are all blank"
 msgstr ""
 
-#: send-pack.c:143
-#, c-format
-msgid "unable to parse remote unpack status: %s"
+#: diff.c:5425
+msgid "heuristic to shift diff hunk boundaries for easy reading"
 msgstr ""
 
-#: send-pack.c:145
-#, c-format
-msgid "remote unpack failed: %s"
+#: diff.c:5428
+msgid "generate diff using the \"patience diff\" algorithm"
 msgstr ""
 
-#: send-pack.c:308
-msgid "failed to sign the push certificate"
+#: diff.c:5432
+msgid "generate diff using the \"histogram diff\" algorithm"
 msgstr ""
 
-#: send-pack.c:421
-msgid "the receiving end does not support --signed push"
+#: diff.c:5434
+msgid "<algorithm>"
 msgstr ""
 
-#: send-pack.c:423
-msgid ""
-"not sending a push certificate since the receiving end does not support --"
-"signed push"
+#: diff.c:5435
+msgid "choose a diff algorithm"
 msgstr ""
 
-#: send-pack.c:435
-msgid "the receiving end does not support --atomic push"
+#: diff.c:5437
+msgid "<text>"
 msgstr ""
 
-#: send-pack.c:440
-msgid "the receiving end does not support push options"
+#: diff.c:5438
+msgid "generate diff using the \"anchored diff\" algorithm"
 msgstr ""
 
-#: sequencer.c:175
-#, c-format
-msgid "invalid commit message cleanup mode '%s'"
+#: diff.c:5440 diff.c:5449 diff.c:5452
+msgid "<mode>"
 msgstr ""
 
-#: sequencer.c:275
-#, c-format
-msgid "could not delete '%s'"
+#: diff.c:5441
+msgid "show word diff, using <mode> to delimit changed words"
 msgstr ""
 
-#: sequencer.c:301
-msgid "revert"
+#: diff.c:5443 diff.c:5446 diff.c:5491
+msgid "<regex>"
 msgstr ""
 
-#: sequencer.c:303
-msgid "cherry-pick"
+#: diff.c:5444
+msgid "use <regex> to decide what a word is"
 msgstr ""
 
-#: sequencer.c:305
-msgid "rebase -i"
+#: diff.c:5447
+msgid "equivalent to --word-diff=color --word-diff-regex=<regex>"
 msgstr ""
 
-#: sequencer.c:307
-#, c-format
-msgid "Unknown action: %d"
+#: diff.c:5450
+msgid "moved lines of code are colored differently"
 msgstr ""
 
-#: sequencer.c:364
-msgid ""
-"after resolving the conflicts, mark the corrected paths\n"
-"with 'git add <paths>' or 'git rm <paths>'"
+#: diff.c:5453
+msgid "how white spaces are ignored in --color-moved"
 msgstr ""
 
-#: sequencer.c:367
-msgid ""
-"after resolving the conflicts, mark the corrected paths\n"
-"with 'git add <paths>' or 'git rm <paths>'\n"
-"and commit the result with 'git commit'"
+#: diff.c:5456
+msgid "Other diff options"
 msgstr ""
 
-#: sequencer.c:380 sequencer.c:2468
-#, c-format
-msgid "could not lock '%s'"
+#: diff.c:5458
+msgid "when run from subdir, exclude changes outside and show relative paths"
 msgstr ""
 
-#: sequencer.c:382 sequencer.c:2346 sequencer.c:2472 sequencer.c:2486
-#: sequencer.c:2694 sequencer.c:4336 sequencer.c:4399 wrapper.c:656
-#, c-format
-msgid "could not write to '%s'"
+#: diff.c:5462
+msgid "treat all files as text"
 msgstr ""
 
-#: sequencer.c:387
-#, c-format
-msgid "could not write eol to '%s'"
+#: diff.c:5464
+msgid "swap two inputs, reverse the diff"
 msgstr ""
 
-#: sequencer.c:392 sequencer.c:2351 sequencer.c:2474 sequencer.c:2488
-#: sequencer.c:2702
-#, c-format
-msgid "failed to finalize '%s'"
+#: diff.c:5466
+msgid "exit with 1 if there were differences, 0 otherwise"
 msgstr ""
 
-#: sequencer.c:415 sequencer.c:804 sequencer.c:1493 sequencer.c:2371
-#: sequencer.c:2684 sequencer.c:2788 builtin/am.c:259 builtin/commit.c:727
-#: builtin/merge.c:1046
-#, c-format
-msgid "could not read '%s'"
+#: diff.c:5468
+msgid "disable all output of the program"
 msgstr ""
 
-#: sequencer.c:441
-#, c-format
-msgid "your local changes would be overwritten by %s."
+#: diff.c:5470
+msgid "allow an external diff helper to be executed"
 msgstr ""
 
-#: sequencer.c:445
-msgid "commit your changes or stash them to proceed."
+#: diff.c:5472
+msgid "run external text conversion filters when comparing binary files"
 msgstr ""
 
-#: sequencer.c:474
-#, c-format
-msgid "%s: fast-forward"
+#: diff.c:5474
+msgid "<when>"
 msgstr ""
 
-#. TRANSLATORS: %s will be "revert", "cherry-pick" or
-#. "rebase -i".
-#.
-#: sequencer.c:563
-#, c-format
-msgid "%s: Unable to write new index file"
+#: diff.c:5475
+msgid "ignore changes to submodules in the diff generation"
 msgstr ""
 
-#: sequencer.c:579
-msgid "unable to update cache tree"
+#: diff.c:5478
+msgid "<format>"
 msgstr ""
 
-#: sequencer.c:592
-msgid "could not resolve HEAD commit"
+#: diff.c:5479
+msgid "specify how differences in submodules are shown"
 msgstr ""
 
-#: sequencer.c:749
-#, c-format
-msgid ""
-"you have staged changes in your working tree\n"
-"If these changes are meant to be squashed into the previous commit, run:\n"
-"\n"
-"  git commit --amend %s\n"
-"\n"
-"If they are meant to go into a new commit, run:\n"
-"\n"
-"  git commit %s\n"
-"\n"
-"In both cases, once you're done, continue with:\n"
-"\n"
-"  git rebase --continue\n"
+#: diff.c:5483
+msgid "hide 'git add -N' entries from the index"
 msgstr ""
 
-#: sequencer.c:818
-msgid "writing root commit"
+#: diff.c:5486
+msgid "treat 'git add -N' entries as real in the index"
 msgstr ""
 
-#: sequencer.c:1043
-msgid "'prepare-commit-msg' hook failed"
+#: diff.c:5488
+msgid "<string>"
 msgstr ""
 
-#: sequencer.c:1050
+#: diff.c:5489
 msgid ""
-"Your name and email address were configured automatically based\n"
-"on your username and hostname. Please check that they are accurate.\n"
-"You can suppress this message by setting them explicitly. Run the\n"
-"following command and follow the instructions in your editor to edit\n"
-"your configuration file:\n"
-"\n"
-"    git config --global --edit\n"
-"\n"
-"After doing this, you may fix the identity used for this commit with:\n"
-"\n"
-"    git commit --amend --reset-author\n"
+"look for differences that change the number of occurrences of the specified "
+"string"
 msgstr ""
 
-#: sequencer.c:1063
+#: diff.c:5492
 msgid ""
-"Your name and email address were configured automatically based\n"
-"on your username and hostname. Please check that they are accurate.\n"
-"You can suppress this message by setting them explicitly:\n"
-"\n"
-"    git config --global user.name \"Your Name\"\n"
-"    git config --global user.email you@example.com\n"
-"\n"
-"After doing this, you may fix the identity used for this commit with:\n"
-"\n"
-"    git commit --amend --reset-author\n"
+"look for differences that change the number of occurrences of the specified "
+"regex"
 msgstr ""
 
-#: sequencer.c:1103
-msgid "couldn't look up newly created commit"
+#: diff.c:5495
+msgid "show all changes in the changeset with -S or -G"
 msgstr ""
 
-#: sequencer.c:1105
-msgid "could not parse newly created commit"
+#: diff.c:5498
+msgid "treat <string> in -S as extended POSIX regular expression"
 msgstr ""
 
-#: sequencer.c:1151
-msgid "unable to resolve HEAD after creating commit"
+#: diff.c:5501
+msgid "control the order in which files appear in the output"
 msgstr ""
 
-#: sequencer.c:1153
-msgid "detached HEAD"
+#: diff.c:5502
+msgid "<object-id>"
 msgstr ""
 
-#: sequencer.c:1157
-msgid " (root-commit)"
+#: diff.c:5503
+msgid ""
+"look for differences that change the number of occurrences of the specified "
+"object"
 msgstr ""
 
-#: sequencer.c:1178
-msgid "could not parse HEAD"
+#: diff.c:5505
+msgid "[(A|C|D|M|R|T|U|X|B)...[*]]"
 msgstr ""
 
-#: sequencer.c:1180
-#, c-format
-msgid "HEAD %s is not a commit!"
+#: diff.c:5506
+msgid "select files by diff type"
 msgstr ""
 
-#: sequencer.c:1184 builtin/commit.c:1528
-msgid "could not parse HEAD commit"
+#: diff.c:5508
+msgid "<file>"
 msgstr ""
 
-#: sequencer.c:1235 sequencer.c:1832
-msgid "unable to parse commit author"
+#: diff.c:5509
+msgid "Output to a specific file"
 msgstr ""
 
-#: sequencer.c:1245 builtin/am.c:1630 builtin/merge.c:645
-msgid "git write-tree failed to write a tree"
+#: diff.c:6164
+msgid "inexact rename detection was skipped due to too many files."
 msgstr ""
 
-#: sequencer.c:1262 sequencer.c:1317
-#, c-format
-msgid "unable to read commit message from '%s'"
+#: diff.c:6167
+msgid "only found copies from modified paths due to too many files."
 msgstr ""
 
-#: sequencer.c:1284 builtin/am.c:1650 builtin/commit.c:1631 builtin/merge.c:825
-#: builtin/merge.c:850
-msgid "failed to write commit object"
+#: diff.c:6170
+#, c-format
+msgid ""
+"you may want to set your %s variable to at least %d and retry the command."
 msgstr ""
 
-#: sequencer.c:1344
+#: dir.c:554
 #, c-format
-msgid "could not parse commit %s"
+msgid "pathspec '%s' did not match any file(s) known to git"
 msgstr ""
 
-#: sequencer.c:1349
+#: dir.c:664
 #, c-format
-msgid "could not parse parent commit %s"
+msgid "unrecognized pattern: '%s'"
 msgstr ""
 
-#: sequencer.c:1500 sequencer.c:1525
+#: dir.c:682 dir.c:696
 #, c-format
-msgid "This is a combination of %d commits."
+msgid "unrecognized negative pattern: '%s'"
 msgstr ""
 
-#: sequencer.c:1510 sequencer.c:4355
-msgid "need a HEAD to fixup"
+#: dir.c:714
+#, c-format
+msgid "your sparse-checkout file may have issues: pattern '%s' is repeated"
 msgstr ""
 
-#: sequencer.c:1512 sequencer.c:2729
-msgid "could not read HEAD"
+#: dir.c:724
+msgid "disabling cone pattern matching"
 msgstr ""
 
-#: sequencer.c:1514
-msgid "could not read HEAD's commit message"
+#: dir.c:1101
+#, c-format
+msgid "cannot use %s as an exclude file"
 msgstr ""
 
-#: sequencer.c:1520
+#: dir.c:2078
 #, c-format
-msgid "cannot write '%s'"
+msgid "could not open directory '%s'"
 msgstr ""
 
-#: sequencer.c:1527 git-rebase--interactive.sh:457
-msgid "This is the 1st commit message:"
+#: dir.c:2415
+msgid "failed to get kernel name and information"
 msgstr ""
 
-#: sequencer.c:1535
-#, c-format
-msgid "could not read commit message of %s"
+#: dir.c:2539
+msgid "untracked cache is disabled on this system or location"
 msgstr ""
 
-#: sequencer.c:1542
+#: dir.c:3343
 #, c-format
-msgid "This is the commit message #%d:"
+msgid "index file corrupt in repo %s"
 msgstr ""
 
-#: sequencer.c:1548
+#: dir.c:3388 dir.c:3393
 #, c-format
-msgid "The commit message #%d will be skipped:"
+msgid "could not create directories for %s"
 msgstr ""
 
-#: sequencer.c:1553
+#: dir.c:3422
 #, c-format
-msgid "unknown command: %d"
+msgid "could not migrate git directory from '%s' to '%s'"
 msgstr ""
 
-#: sequencer.c:1631
-msgid "your index file is unmerged."
+#: editor.c:73
+#, c-format
+msgid "hint: Waiting for your editor to close the file...%c"
 msgstr ""
 
-#: sequencer.c:1638
-msgid "cannot fixup root commit"
+#: entry.c:178
+msgid "Filtering content"
 msgstr ""
 
-#: sequencer.c:1657
+#: entry.c:476
 #, c-format
-msgid "commit %s is a merge but no -m option was given."
+msgid "could not stat file '%s'"
 msgstr ""
 
-#: sequencer.c:1665
+#: environment.c:149
 #, c-format
-msgid "commit %s does not have parent %d"
+msgid "bad git namespace path \"%s\""
 msgstr ""
 
-#: sequencer.c:1669
+#: environment.c:331
 #, c-format
-msgid "mainline was specified but commit %s is not a merge."
+msgid "could not set GIT_DIR to '%s'"
 msgstr ""
 
-#: sequencer.c:1675
+#: exec-cmd.c:363
 #, c-format
-msgid "cannot get commit message for %s"
+msgid "too many args to run %s"
 msgstr ""
 
-#. TRANSLATORS: The first %s will be a "todo" command like
-#. "revert" or "pick", the second %s a SHA1.
-#: sequencer.c:1694
-#, c-format
-msgid "%s: cannot parse parent commit %s"
+#: fetch-pack.c:150
+msgid "git fetch-pack: expected shallow list"
 msgstr ""
 
-#: sequencer.c:1759
-#, c-format
-msgid "could not rename '%s' to '%s'"
+#: fetch-pack.c:153
+msgid "git fetch-pack: expected a flush packet after shallow list"
 msgstr ""
 
-#: sequencer.c:1813
-#, c-format
-msgid "could not revert %s... %s"
+#: fetch-pack.c:164
+msgid "git fetch-pack: expected ACK/NAK, got a flush packet"
 msgstr ""
 
-#: sequencer.c:1814
+#: fetch-pack.c:184
 #, c-format
-msgid "could not apply %s... %s"
+msgid "git fetch-pack: expected ACK/NAK, got '%s'"
 msgstr ""
 
-#: sequencer.c:1864
-msgid "empty commit set passed"
+#: fetch-pack.c:195
+msgid "unable to write to remote"
 msgstr ""
 
-#: sequencer.c:1874
-#, c-format
-msgid "git %s: failed to read the index"
+#: fetch-pack.c:257
+msgid "--stateless-rpc requires multi_ack_detailed"
 msgstr ""
 
-#: sequencer.c:1881
+#: fetch-pack.c:356 fetch-pack.c:1340
 #, c-format
-msgid "git %s: failed to refresh the index"
+msgid "invalid shallow line: %s"
 msgstr ""
 
-#: sequencer.c:1961
+#: fetch-pack.c:362 fetch-pack.c:1346
 #, c-format
-msgid "%s does not accept arguments: '%s'"
+msgid "invalid unshallow line: %s"
 msgstr ""
 
-#: sequencer.c:1970
+#: fetch-pack.c:364 fetch-pack.c:1348
 #, c-format
-msgid "missing arguments for %s"
+msgid "object not found: %s"
 msgstr ""
 
-#: sequencer.c:2029
+#: fetch-pack.c:367 fetch-pack.c:1351
 #, c-format
-msgid "invalid line %d: %.*s"
+msgid "error in object: %s"
 msgstr ""
 
-#: sequencer.c:2037
+#: fetch-pack.c:369 fetch-pack.c:1353
 #, c-format
-msgid "cannot '%s' without a previous commit"
+msgid "no shallow found: %s"
 msgstr ""
 
-#: sequencer.c:2085 sequencer.c:4138 sequencer.c:4173
+#: fetch-pack.c:372 fetch-pack.c:1357
 #, c-format
-msgid "could not read '%s'."
-msgstr ""
-
-#: sequencer.c:2108
-msgid "please fix this using 'git rebase --edit-todo'."
+msgid "expected shallow/unshallow, got %s"
 msgstr ""
 
-#: sequencer.c:2110
+#: fetch-pack.c:414
 #, c-format
-msgid "unusable instruction sheet: '%s'"
+msgid "got %s %d %s"
 msgstr ""
 
-#: sequencer.c:2115
-msgid "no commits parsed."
+#: fetch-pack.c:431
+#, c-format
+msgid "invalid commit %s"
 msgstr ""
 
-#: sequencer.c:2126
-msgid "cannot cherry-pick during a revert."
+#: fetch-pack.c:462
+msgid "giving up"
 msgstr ""
 
-#: sequencer.c:2128
-msgid "cannot revert during a cherry-pick."
+#: fetch-pack.c:475 progress.c:323
+msgid "done"
 msgstr ""
 
-#: sequencer.c:2195
+#: fetch-pack.c:487
 #, c-format
-msgid "invalid key: %s"
+msgid "got %s (%d) %s"
 msgstr ""
 
-#: sequencer.c:2198
+#: fetch-pack.c:533
 #, c-format
-msgid "invalid value for %s: %s"
-msgstr ""
-
-#: sequencer.c:2269
-msgid "unusable squash-onto"
+msgid "Marking %s as complete"
 msgstr ""
 
-#: sequencer.c:2285
+#: fetch-pack.c:754
 #, c-format
-msgid "malformed options sheet: '%s'"
+msgid "already have %s (%s)"
 msgstr ""
 
-#: sequencer.c:2323
-msgid "a cherry-pick or revert is already in progress"
+#: fetch-pack.c:818
+msgid "fetch-pack: unable to fork off sideband demultiplexer"
 msgstr ""
 
-#: sequencer.c:2324
-msgid "try \"git cherry-pick (--continue | --quit | --abort)\""
+#: fetch-pack.c:826
+msgid "protocol error: bad pack header"
 msgstr ""
 
-#: sequencer.c:2327
+#: fetch-pack.c:900
 #, c-format
-msgid "could not create sequencer directory '%s'"
-msgstr ""
-
-#: sequencer.c:2341
-msgid "could not lock HEAD"
-msgstr ""
-
-#: sequencer.c:2396 sequencer.c:3403
-msgid "no cherry-pick or revert in progress"
+msgid "fetch-pack: unable to fork off %s"
 msgstr ""
 
-#: sequencer.c:2398
-msgid "cannot resolve HEAD"
+#: fetch-pack.c:916
+#, c-format
+msgid "%s failed"
 msgstr ""
 
-#: sequencer.c:2400 sequencer.c:2435
-msgid "cannot abort from a branch yet to be born"
+#: fetch-pack.c:918
+msgid "error in sideband demultiplexer"
 msgstr ""
 
-#: sequencer.c:2421 builtin/grep.c:720
+#: fetch-pack.c:965
 #, c-format
-msgid "cannot open '%s'"
+msgid "Server version is %.*s"
 msgstr ""
 
-#: sequencer.c:2423
+#: fetch-pack.c:970 fetch-pack.c:976 fetch-pack.c:979 fetch-pack.c:985
+#: fetch-pack.c:989 fetch-pack.c:993 fetch-pack.c:997 fetch-pack.c:1001
+#: fetch-pack.c:1005 fetch-pack.c:1009 fetch-pack.c:1013 fetch-pack.c:1017
+#: fetch-pack.c:1023 fetch-pack.c:1029 fetch-pack.c:1034 fetch-pack.c:1039
 #, c-format
-msgid "cannot read '%s': %s"
+msgid "Server supports %s"
 msgstr ""
 
-#: sequencer.c:2424
-msgid "unexpected end of file"
+#: fetch-pack.c:972
+msgid "Server does not support shallow clients"
 msgstr ""
 
-#: sequencer.c:2430
-#, c-format
-msgid "stored pre-cherry-pick HEAD file '%s' is corrupt"
+#: fetch-pack.c:1032
+msgid "Server does not support --shallow-since"
 msgstr ""
 
-#: sequencer.c:2441
-msgid "You seem to have moved HEAD. Not rewinding, check your HEAD!"
+#: fetch-pack.c:1037
+msgid "Server does not support --shallow-exclude"
 msgstr ""
 
-#: sequencer.c:2545 sequencer.c:3321
-#, c-format
-msgid "could not update %s"
+#: fetch-pack.c:1041
+msgid "Server does not support --deepen"
 msgstr ""
 
-#: sequencer.c:2583 sequencer.c:3301
-msgid "cannot read HEAD"
+#: fetch-pack.c:1058
+msgid "no common commits"
 msgstr ""
 
-#: sequencer.c:2618 sequencer.c:2622 builtin/difftool.c:639
-#, c-format
-msgid "could not copy '%s' to '%s'"
+#: fetch-pack.c:1070 fetch-pack.c:1536
+msgid "git fetch-pack: fetch failed."
 msgstr ""
 
-#: sequencer.c:2641
-msgid "could not read index"
+#: fetch-pack.c:1209
+msgid "Server does not support shallow requests"
 msgstr ""
 
-#: sequencer.c:2646
-#, c-format
-msgid ""
-"execution failed: %s\n"
-"%sYou can fix the problem, and then run\n"
-"\n"
-"  git rebase --continue\n"
-"\n"
+#: fetch-pack.c:1216
+msgid "Server supports filter"
 msgstr ""
 
-#: sequencer.c:2652
-msgid "and made changes to the index and/or the working tree\n"
+#: fetch-pack.c:1239
+msgid "unable to write request to remote"
 msgstr ""
 
-#: sequencer.c:2658
+#: fetch-pack.c:1257
 #, c-format
-msgid ""
-"execution succeeded: %s\n"
-"but left changes to the index and/or the working tree\n"
-"Commit or stash your changes, and then run\n"
-"\n"
-"  git rebase --continue\n"
-"\n"
+msgid "error reading section header '%s'"
 msgstr ""
 
-#: sequencer.c:2771
-msgid "writing fake root commit"
+#: fetch-pack.c:1263
+#, c-format
+msgid "expected '%s', received '%s'"
 msgstr ""
 
-#: sequencer.c:2776
-msgid "writing squash-onto"
+#: fetch-pack.c:1303
+#, c-format
+msgid "unexpected acknowledgment line: '%s'"
 msgstr ""
 
-#: sequencer.c:2811
+#: fetch-pack.c:1308
 #, c-format
-msgid "failed to find tree of %s"
+msgid "error processing acks: %d"
 msgstr ""
 
-#: sequencer.c:2829
-msgid "could not write index"
+#: fetch-pack.c:1318
+msgid "expected packfile to be sent after 'ready'"
 msgstr ""
 
-#: sequencer.c:2861
-msgid "cannot merge without a current revision"
+#: fetch-pack.c:1320
+msgid "expected no other sections to be sent after no 'ready'"
 msgstr ""
 
-#: sequencer.c:2884
+#: fetch-pack.c:1362
 #, c-format
-msgid "could not resolve '%s'"
+msgid "error processing shallow info: %d"
 msgstr ""
 
-#: sequencer.c:2906
+#: fetch-pack.c:1409
 #, c-format
-msgid "could not get commit message of '%s'"
+msgid "expected wanted-ref, got '%s'"
 msgstr ""
 
-#: sequencer.c:2916 sequencer.c:2941
+#: fetch-pack.c:1414
 #, c-format
-msgid "could not write '%s'"
+msgid "unexpected wanted-ref: '%s'"
 msgstr ""
 
-#: sequencer.c:3005
+#: fetch-pack.c:1419
 #, c-format
-msgid "could not even attempt to merge '%.*s'"
+msgid "error processing wanted refs: %d"
 msgstr ""
 
-#: sequencer.c:3021
-msgid "merge: Unable to write new index file"
+#: fetch-pack.c:1762
+msgid "no matching remote head"
 msgstr ""
 
-#: sequencer.c:3088
-#, c-format
-msgid "Applied autostash.\n"
+#: fetch-pack.c:1785 builtin/clone.c:688
+msgid "remote did not send all necessary objects"
 msgstr ""
 
-#: sequencer.c:3100
+#: fetch-pack.c:1812
 #, c-format
-msgid "cannot store %s"
+msgid "no such remote ref %s"
 msgstr ""
 
-#: sequencer.c:3103 git-rebase.sh:188
+#: fetch-pack.c:1815
 #, c-format
-msgid ""
-"Applying autostash resulted in conflicts.\n"
-"Your changes are safe in the stash.\n"
-"You can run \"git stash pop\" or \"git stash drop\" at any time.\n"
+msgid "Server does not allow request for unadvertised object %s"
 msgstr ""
 
-#: sequencer.c:3134
-#, c-format
-msgid ""
-"Could not execute the todo command\n"
-"\n"
-"    %.*s\n"
-"It has been rescheduled; To edit the command before continuing, please\n"
-"edit the todo list first:\n"
-"\n"
-"    git rebase --edit-todo\n"
-"    git rebase --continue\n"
+#: gpg-interface.c:223
+msgid "could not create temporary file"
 msgstr ""
 
-#: sequencer.c:3202
+#: gpg-interface.c:226
 #, c-format
-msgid "Stopped at %s...  %.*s\n"
+msgid "failed writing detached signature to '%s'"
 msgstr ""
 
-#: sequencer.c:3264
+#: gpg-interface.c:390
+msgid "gpg failed to sign the data"
+msgstr ""
+
+#: graph.c:98
 #, c-format
-msgid "unknown command %d"
+msgid "ignore invalid color '%.*s' in log.graphColors"
 msgstr ""
 
-#: sequencer.c:3309
-msgid "could not read orig-head"
+#: grep.c:668
+msgid ""
+"given pattern contains NULL byte (via -f <file>). This is only supported "
+"with -P under PCRE v2"
 msgstr ""
 
-#: sequencer.c:3314 sequencer.c:4352
-msgid "could not read 'onto'"
+#: grep.c:2124
+#, c-format
+msgid "'%s': unable to read %s"
 msgstr ""
 
-#: sequencer.c:3328
+#: grep.c:2141 setup.c:165 builtin/clone.c:411 builtin/diff.c:82
+#: builtin/rm.c:135
 #, c-format
-msgid "could not update HEAD to %s"
+msgid "failed to stat '%s'"
 msgstr ""
 
-#: sequencer.c:3414
-msgid "cannot rebase: You have unstaged changes."
+#: grep.c:2152
+#, c-format
+msgid "'%s': short read"
 msgstr ""
 
-#: sequencer.c:3423
-msgid "cannot amend non-existing commit"
+#: help.c:23
+msgid "start a working area (see also: git help tutorial)"
 msgstr ""
 
-#: sequencer.c:3425
-#, c-format
-msgid "invalid file: '%s'"
+#: help.c:24
+msgid "work on the current change (see also: git help everyday)"
 msgstr ""
 
-#: sequencer.c:3427
-#, c-format
-msgid "invalid contents: '%s'"
+#: help.c:25
+msgid "examine the history and state (see also: git help revisions)"
 msgstr ""
 
-#: sequencer.c:3430
-msgid ""
-"\n"
-"You have uncommitted changes in your working tree. Please, commit them\n"
-"first and then run 'git rebase --continue' again."
+#: help.c:26
+msgid "grow, mark and tweak your common history"
 msgstr ""
 
-#: sequencer.c:3455 sequencer.c:3493
-#, c-format
-msgid "could not write file: '%s'"
+#: help.c:27
+msgid "collaborate (see also: git help workflows)"
 msgstr ""
 
-#: sequencer.c:3508
-msgid "could not remove CHERRY_PICK_HEAD"
+#: help.c:31
+msgid "Main Porcelain Commands"
 msgstr ""
 
-#: sequencer.c:3515
-msgid "could not commit staged changes."
+#: help.c:32
+msgid "Ancillary Commands / Manipulators"
 msgstr ""
 
-#: sequencer.c:3612
-#, c-format
-msgid "%s: can't cherry-pick a %s"
+#: help.c:33
+msgid "Ancillary Commands / Interrogators"
 msgstr ""
 
-#: sequencer.c:3616
-#, c-format
-msgid "%s: bad revision"
+#: help.c:34
+msgid "Interacting with Others"
 msgstr ""
 
-#: sequencer.c:3649
-msgid "can't revert as initial commit"
+#: help.c:35
+msgid "Low-level Commands / Manipulators"
 msgstr ""
 
-#: sequencer.c:4098
-msgid "make_script: unhandled options"
+#: help.c:36
+msgid "Low-level Commands / Interrogators"
 msgstr ""
 
-#: sequencer.c:4101
-msgid "make_script: error preparing revisions"
+#: help.c:37
+msgid "Low-level Commands / Syncing Repositories"
 msgstr ""
 
-#: sequencer.c:4142 sequencer.c:4177
-#, c-format
-msgid "unusable todo list: '%s'"
+#: help.c:38
+msgid "Low-level Commands / Internal Helpers"
 msgstr ""
 
-#: sequencer.c:4236
+#: help.c:298
 #, c-format
-msgid ""
-"unrecognized setting %s for option rebase.missingCommitsCheck. Ignoring."
+msgid "available git commands in '%s'"
 msgstr ""
 
-#: sequencer.c:4302
-#, c-format
-msgid ""
-"Warning: some commits may have been dropped accidentally.\n"
-"Dropped commits (newer to older):\n"
+#: help.c:305
+msgid "git commands available from elsewhere on your $PATH"
+msgstr ""
+
+#: help.c:314
+msgid "These are common Git commands used in various situations:"
 msgstr ""
 
-#: sequencer.c:4309
+#: help.c:363 git.c:98
 #, c-format
-msgid ""
-"To avoid this message, use \"drop\" to explicitly remove a commit.\n"
-"\n"
-"Use 'git config rebase.missingCommitsCheck' to change the level of "
-"warnings.\n"
-"The possible behaviours are: ignore, warn, error.\n"
-"\n"
+msgid "unsupported command listing type '%s'"
+msgstr ""
+
+#: help.c:403
+msgid "The common Git guides are:"
 msgstr ""
 
-#: sequencer.c:4321
+#: help.c:512
+msgid "See 'git help <command>' to read about a specific subcommand"
+msgstr ""
+
+#: help.c:517
+msgid "External commands"
+msgstr ""
+
+#: help.c:532
+msgid "Command aliases"
+msgstr ""
+
+#: help.c:596
 #, c-format
 msgid ""
-"You can fix this with 'git rebase --edit-todo' and then run 'git rebase --"
-"continue'.\n"
-"Or you can abort the rebase with 'git rebase --abort'.\n"
+"'%s' appears to be a git command, but we were not\n"
+"able to execute it. Maybe git-%s is broken?"
 msgstr ""
 
-#: sequencer.c:4375
-#, c-format
-msgid "could not parse commit '%s'"
+#: help.c:655
+msgid "Uh oh. Your system reports no Git commands at all."
 msgstr ""
 
-#: sequencer.c:4490
-msgid "the script was already rearranged."
+#: help.c:677
+#, c-format
+msgid "WARNING: You called a Git command named '%s', which does not exist."
 msgstr ""
 
-#: setup.c:123
+#: help.c:682
 #, c-format
-msgid "'%s' is outside repository"
+msgid "Continuing under the assumption that you meant '%s'."
 msgstr ""
 
-#: setup.c:172
+#: help.c:687
 #, c-format
-msgid ""
-"%s: no such path in the working tree.\n"
-"Use 'git <command> -- <path>...' to specify paths that do not exist locally."
+msgid "Continuing in %0.1f seconds, assuming that you meant '%s'."
 msgstr ""
 
-#: setup.c:185
+#: help.c:695
 #, c-format
+msgid "git: '%s' is not a git command. See 'git --help'."
+msgstr ""
+
+#: help.c:699
 msgid ""
-"ambiguous argument '%s': unknown revision or path not in the working tree.\n"
-"Use '--' to separate paths from revisions, like this:\n"
-"'git <command> [<revision>...] -- [<file>...]'"
+"\n"
+"The most similar command is"
+msgid_plural ""
+"\n"
+"The most similar commands are"
+msgstr[0] ""
+msgstr[1] ""
+
+#: help.c:714
+msgid "git version [<options>]"
 msgstr ""
 
-#: setup.c:234
+#: help.c:783
 #, c-format
-msgid "option '%s' must come before non-option arguments"
+msgid "%s: %s - %s"
 msgstr ""
 
-#: setup.c:253
-#, c-format
+#: help.c:787
 msgid ""
-"ambiguous argument '%s': both revision and filename\n"
-"Use '--' to separate paths from revisions, like this:\n"
-"'git <command> [<revision>...] -- [<file>...]'"
-msgstr ""
+"\n"
+"Did you mean this?"
+msgid_plural ""
+"\n"
+"Did you mean one of these?"
+msgstr[0] ""
+msgstr[1] ""
 
-#: setup.c:389
-msgid "unable to set up work tree using invalid config"
+#: ident.c:349
+msgid ""
+"\n"
+"*** Please tell me who you are.\n"
+"\n"
+"Run\n"
+"\n"
+"  git config --global user.email \"you@example.com\"\n"
+"  git config --global user.name \"Your Name\"\n"
+"\n"
+"to set your account's default identity.\n"
+"Omit --global to set the identity only in this repository.\n"
+"\n"
 msgstr ""
 
-#: setup.c:393
-msgid "this operation must be run in a work tree"
+#: ident.c:379
+msgid "no email was given and auto-detection is disabled"
 msgstr ""
 
-#: setup.c:503
+#: ident.c:384
 #, c-format
-msgid "Expected git repo version <= %d, found %d"
+msgid "unable to auto-detect email address (got '%s')"
 msgstr ""
 
-#: setup.c:511
-msgid "unknown repository extensions found:"
+#: ident.c:401
+msgid "no name was given and auto-detection is disabled"
 msgstr ""
 
-#: setup.c:530
+#: ident.c:407
 #, c-format
-msgid "error opening '%s'"
+msgid "unable to auto-detect name (got '%s')"
 msgstr ""
 
-#: setup.c:532
+#: ident.c:415
 #, c-format
-msgid "too large to be a .git file: '%s'"
+msgid "empty ident name (for <%s>) not allowed"
 msgstr ""
 
-#: setup.c:534
+#: ident.c:421
 #, c-format
-msgid "error reading %s"
+msgid "name consists only of disallowed characters: %s"
 msgstr ""
 
-#: setup.c:536
+#: ident.c:436 builtin/commit.c:631
 #, c-format
-msgid "invalid gitfile format: %s"
+msgid "invalid date format: %s"
 msgstr ""
 
-#: setup.c:538
+#: list-objects.c:127
 #, c-format
-msgid "no path in gitfile: %s"
+msgid "entry '%s' in tree %s has tree mode, but is not a tree"
 msgstr ""
 
-#: setup.c:540
+#: list-objects.c:140
 #, c-format
-msgid "not a git repository: %s"
+msgid "entry '%s' in tree %s has blob mode, but is not a blob"
 msgstr ""
 
-#: setup.c:639
+#: list-objects.c:375
 #, c-format
-msgid "'$%s' too big"
+msgid "unable to load root tree for commit %s"
 msgstr ""
 
-#: setup.c:653
+#: list-objects-filter.c:492
 #, c-format
-msgid "not a git repository: '%s'"
+msgid "unable to access sparse blob in '%s'"
 msgstr ""
 
-#: setup.c:682 setup.c:684 setup.c:715
+#: list-objects-filter.c:495
 #, c-format
-msgid "cannot chdir to '%s'"
+msgid "unable to parse sparse filter data in %s"
 msgstr ""
 
-#: setup.c:687 setup.c:743 setup.c:753 setup.c:792 setup.c:800 setup.c:815
-msgid "cannot come back to cwd"
+#: list-objects-filter-options.c:58
+msgid "expected 'tree:<depth>'"
+msgstr ""
+
+#: list-objects-filter-options.c:73
+msgid "sparse:path filters support has been dropped"
 msgstr ""
 
-#: setup.c:813
+#: list-objects-filter-options.c:86
 #, c-format
-msgid "not a git repository (or any of the parent directories): %s"
+msgid "invalid filter-spec '%s'"
 msgstr ""
 
-#: setup.c:824
+#: list-objects-filter-options.c:102
 #, c-format
-msgid "failed to stat '%*s%s%s'"
+msgid "must escape char in sub-filter-spec: '%c'"
 msgstr ""
 
-#: setup.c:1054
-msgid "Unable to read current working directory"
+#: list-objects-filter-options.c:144
+msgid "expected something after combine:"
 msgstr ""
 
-#: setup.c:1066 setup.c:1072
-#, c-format
-msgid "cannot change to '%s'"
+#: list-objects-filter-options.c:226
+msgid "multiple filter-specs cannot be combined"
 msgstr ""
 
-#: setup.c:1085
+#: lockfile.c:151
 #, c-format
 msgid ""
-"not a git repository (or any parent up to mount point %s)\n"
-"Stopping at filesystem boundary (GIT_DISCOVERY_ACROSS_FILESYSTEM not set)."
+"Unable to create '%s.lock': %s.\n"
+"\n"
+"Another git process seems to be running in this repository, e.g.\n"
+"an editor opened by 'git commit'. Please make sure all processes\n"
+"are terminated then try again. If it still fails, a git process\n"
+"may have crashed in this repository earlier:\n"
+"remove the file manually to continue."
 msgstr ""
 
-#: setup.c:1168
+#: lockfile.c:159
 #, c-format
-msgid ""
-"problem with core.sharedRepository filemode value (0%.3o).\n"
-"The owner of files must always have read and write permissions."
+msgid "Unable to create '%s.lock': %s"
 msgstr ""
 
-#: setup.c:1211
-msgid "open /dev/null or dup failed"
+#: merge.c:41
+msgid "failed to read the cache"
 msgstr ""
 
-#: setup.c:1226
-msgid "fork failed"
+#: merge.c:107 rerere.c:720 builtin/am.c:1874 builtin/am.c:1908
+#: builtin/checkout.c:539 builtin/checkout.c:798 builtin/clone.c:809
+#: builtin/stash.c:264
+msgid "unable to write new index file"
 msgstr ""
 
-#: setup.c:1231
-msgid "setsid failed"
+#: merge-recursive.c:367
+msgid "(bad commit)\n"
 msgstr ""
 
-#: sha1-file.c:625
+#: merge-recursive.c:390
 #, c-format
-msgid "path '%s' does not exist"
+msgid "add_cacheinfo failed for path '%s'; merge aborting."
 msgstr ""
 
-#: sha1-file.c:651
+#: merge-recursive.c:399
 #, c-format
-msgid "reference repository '%s' as a linked checkout is not supported yet."
+msgid "add_cacheinfo failed to refresh for path '%s'; merge aborting."
 msgstr ""
 
-#: sha1-file.c:657
+#: merge-recursive.c:885
 #, c-format
-msgid "reference repository '%s' is not a local repository."
+msgid "failed to create path '%s'%s"
 msgstr ""
 
-#: sha1-file.c:663
+#: merge-recursive.c:896
 #, c-format
-msgid "reference repository '%s' is shallow"
+msgid "Removing %s to make room for subdirectory\n"
 msgstr ""
 
-#: sha1-file.c:671
-#, c-format
-msgid "reference repository '%s' is grafted"
+#: merge-recursive.c:910 merge-recursive.c:929
+msgid ": perhaps a D/F conflict?"
 msgstr ""
 
-#: sha1-name.c:442
+#: merge-recursive.c:919
 #, c-format
-msgid "short SHA1 %s is ambiguous"
+msgid "refusing to lose untracked file at '%s'"
 msgstr ""
 
-#: sha1-name.c:453
-msgid "The candidates are:"
+#: merge-recursive.c:960 builtin/cat-file.c:41
+#, c-format
+msgid "cannot read object %s '%s'"
 msgstr ""
 
-#: sha1-name.c:695
-msgid ""
-"Git normally never creates a ref that ends with 40 hex characters\n"
-"because it will be ignored when you just specify 40-hex. These refs\n"
-"may be created by mistake. For example,\n"
-"\n"
-"  git checkout -b $br $(git rev-parse ...)\n"
-"\n"
-"where \"$br\" is somehow empty and a 40-hex ref is created. Please\n"
-"examine these refs and maybe delete them. Turn this message off by\n"
-"running \"git config advice.objectNameWarning false\""
+#: merge-recursive.c:965
+#, c-format
+msgid "blob expected for %s '%s'"
 msgstr ""
 
-#: submodule.c:97 submodule.c:131
-msgid "Cannot change unmerged .gitmodules, resolve merge conflicts first"
+#: merge-recursive.c:990
+#, c-format
+msgid "failed to open '%s': %s"
 msgstr ""
 
-#: submodule.c:101 submodule.c:135
+#: merge-recursive.c:1001
 #, c-format
-msgid "Could not find section in .gitmodules where path=%s"
+msgid "failed to symlink '%s': %s"
 msgstr ""
 
-#: submodule.c:109
+#: merge-recursive.c:1006
 #, c-format
-msgid "Could not update .gitmodules entry %s"
+msgid "do not know what to do with %06o %s '%s'"
 msgstr ""
 
-#: submodule.c:142
+#: merge-recursive.c:1199
 #, c-format
-msgid "Could not remove .gitmodules entry for %s"
+msgid "Failed to merge submodule %s (not checked out)"
 msgstr ""
 
-#: submodule.c:153
-msgid "staging updated .gitmodules failed"
-msgstr ""
-
-#: submodule.c:315
+#: merge-recursive.c:1206
 #, c-format
-msgid "in unpopulated submodule '%s'"
+msgid "Failed to merge submodule %s (commits not present)"
 msgstr ""
 
-#: submodule.c:346
+#: merge-recursive.c:1213
 #, c-format
-msgid "Pathspec '%s' is in submodule '%.*s'"
+msgid "Failed to merge submodule %s (commits don't follow merge-base)"
 msgstr ""
 
-#: submodule.c:837
+#: merge-recursive.c:1221 merge-recursive.c:1233
 #, c-format
-msgid "submodule entry '%s' (%s) is a %s, not a commit"
-msgstr ""
-
-#: submodule.c:1069 builtin/branch.c:651 builtin/submodule--helper.c:1743
-msgid "Failed to resolve HEAD as a valid ref."
+msgid "Fast-forwarding submodule %s to the following commit:"
 msgstr ""
 
-#: submodule.c:1375
+#: merge-recursive.c:1224 merge-recursive.c:1236
 #, c-format
-msgid "'%s' not recognized as a git repository"
+msgid "Fast-forwarding submodule %s"
 msgstr ""
 
-#: submodule.c:1513
+#: merge-recursive.c:1259
 #, c-format
-msgid "could not start 'git status' in submodule '%s'"
+msgid "Failed to merge submodule %s (merge following commits not found)"
 msgstr ""
 
-#: submodule.c:1526
+#: merge-recursive.c:1263
 #, c-format
-msgid "could not run 'git status' in submodule '%s'"
+msgid "Failed to merge submodule %s (not fast-forward)"
 msgstr ""
 
-#: submodule.c:1619
-#, c-format
-msgid "submodule '%s' has dirty index"
+#: merge-recursive.c:1264
+msgid "Found a possible merge resolution for the submodule:\n"
 msgstr ""
 
-#: submodule.c:1718
+#: merge-recursive.c:1267
 #, c-format
 msgid ""
-"relocate_gitdir for submodule '%s' with more than one worktree not supported"
+"If this is correct simply add it to the index for example\n"
+"by using:\n"
+"\n"
+"  git update-index --cacheinfo 160000 %s \"%s\"\n"
+"\n"
+"which will accept this suggestion.\n"
 msgstr ""
 
-#: submodule.c:1730 submodule.c:1786
+#: merge-recursive.c:1276
 #, c-format
-msgid "could not lookup name for submodule '%s'"
+msgid "Failed to merge submodule %s (multiple merges found)"
 msgstr ""
 
-#: submodule.c:1734 builtin/submodule--helper.c:1261
-#: builtin/submodule--helper.c:1271
-#, c-format
-msgid "could not create directory '%s'"
+#: merge-recursive.c:1349
+msgid "Failed to execute internal merge"
 msgstr ""
 
-#: submodule.c:1737
+#: merge-recursive.c:1354
 #, c-format
-msgid ""
-"Migrating git directory of '%s%s' from\n"
-"'%s' to\n"
-"'%s'\n"
+msgid "Unable to add %s to database"
 msgstr ""
 
-#: submodule.c:1821
+#: merge-recursive.c:1386
 #, c-format
-msgid "could not recurse into submodule '%s'"
-msgstr ""
-
-#: submodule.c:1865
-msgid "could not start ls-files in .."
+msgid "Auto-merging %s"
 msgstr ""
 
-#: submodule.c:1904
+#: merge-recursive.c:1410
 #, c-format
-msgid "ls-tree returned unexpected return code %d"
+msgid "Error: Refusing to lose untracked file at %s; writing to %s instead."
 msgstr ""
 
-#: submodule-config.c:230
+#: merge-recursive.c:1482
 #, c-format
-msgid "ignoring suspicious submodule name: %s"
+msgid ""
+"CONFLICT (%s/delete): %s deleted in %s and %s in %s. Version %s of %s left "
+"in tree."
 msgstr ""
 
-#: submodule-config.c:294
-msgid "negative values not allowed for submodule.fetchjobs"
+#: merge-recursive.c:1487
+#, c-format
+msgid ""
+"CONFLICT (%s/delete): %s deleted in %s and %s to %s in %s. Version %s of %s "
+"left in tree."
 msgstr ""
 
-#: submodule-config.c:467
+#: merge-recursive.c:1494
 #, c-format
-msgid "invalid value for %s"
+msgid ""
+"CONFLICT (%s/delete): %s deleted in %s and %s in %s. Version %s of %s left "
+"in tree at %s."
 msgstr ""
 
-#: trailer.c:238
+#: merge-recursive.c:1499
 #, c-format
-msgid "running trailer command '%s' failed"
+msgid ""
+"CONFLICT (%s/delete): %s deleted in %s and %s to %s in %s. Version %s of %s "
+"left in tree at %s."
 msgstr ""
 
-#: trailer.c:485 trailer.c:490 trailer.c:495 trailer.c:549 trailer.c:553
-#: trailer.c:557
-#, c-format
-msgid "unknown value '%s' for key '%s'"
+#: merge-recursive.c:1534
+msgid "rename"
 msgstr ""
 
-#: trailer.c:539 trailer.c:544 builtin/remote.c:293
-#, c-format
-msgid "more than one %s"
+#: merge-recursive.c:1534
+msgid "renamed"
 msgstr ""
 
-#: trailer.c:730
+#: merge-recursive.c:1614 merge-recursive.c:2530 merge-recursive.c:3175
 #, c-format
-msgid "empty trailer token in trailer '%.*s'"
+msgid "Refusing to lose dirty file at %s"
 msgstr ""
 
-#: trailer.c:750
+#: merge-recursive.c:1624
 #, c-format
-msgid "could not read input file '%s'"
+msgid "Refusing to lose untracked file at %s, even though it's in the way."
 msgstr ""
 
-#: trailer.c:753
-msgid "could not read from stdin"
+#: merge-recursive.c:1682
+#, c-format
+msgid "CONFLICT (rename/add): Rename %s->%s in %s.  Added %s in %s"
 msgstr ""
 
-#: trailer.c:1008 builtin/am.c:46
+#: merge-recursive.c:1713
 #, c-format
-msgid "could not stat %s"
+msgid "%s is a directory in %s adding as %s instead"
 msgstr ""
 
-#: trailer.c:1010
+#: merge-recursive.c:1718
 #, c-format
-msgid "file %s is not a regular file"
+msgid "Refusing to lose untracked file at %s; adding as %s instead"
 msgstr ""
 
-#: trailer.c:1012
+#: merge-recursive.c:1737
 #, c-format
-msgid "file %s is not writable by user"
+msgid ""
+"CONFLICT (rename/rename): Rename \"%s\"->\"%s\" in branch \"%s\" rename \"%s"
+"\"->\"%s\" in \"%s\"%s"
 msgstr ""
 
-#: trailer.c:1024
-msgid "could not open temporary file"
+#: merge-recursive.c:1742
+msgid " (left unresolved)"
 msgstr ""
 
-#: trailer.c:1064
+#: merge-recursive.c:1851
 #, c-format
-msgid "could not rename temporary file to %s"
+msgid "CONFLICT (rename/rename): Rename %s->%s in %s. Rename %s->%s in %s"
 msgstr ""
 
-#: transport.c:116
+#: merge-recursive.c:2114
 #, c-format
-msgid "Would set upstream of '%s' to '%s' of '%s'\n"
+msgid ""
+"CONFLICT (directory rename split): Unclear where to place %s because "
+"directory %s was renamed to multiple other directories, with no destination "
+"getting a majority of the files."
 msgstr ""
 
-#: transport.c:208
+#: merge-recursive.c:2146
 #, c-format
-msgid "transport: invalid depth option '%s'"
+msgid ""
+"CONFLICT (implicit dir rename): Existing file/dir at %s in the way of "
+"implicit directory rename(s) putting the following path(s) there: %s."
 msgstr ""
 
-#: transport.c:584
-msgid "could not parse transport.color.* config"
+#: merge-recursive.c:2156
+#, c-format
+msgid ""
+"CONFLICT (implicit dir rename): Cannot map more than one path to %s; "
+"implicit directory renames tried to put these paths there: %s"
 msgstr ""
 
-#: transport.c:996
+#: merge-recursive.c:2248
 #, c-format
 msgid ""
-"The following submodule paths contain changes that can\n"
-"not be found on any remote:\n"
+"CONFLICT (rename/rename): Rename directory %s->%s in %s. Rename directory %s-"
+">%s in %s"
 msgstr ""
 
-#: transport.c:1000
+#: merge-recursive.c:2493
 #, c-format
 msgid ""
-"\n"
-"Please try\n"
-"\n"
-"\tgit push --recurse-submodules=on-demand\n"
-"\n"
-"or cd to the path and use\n"
-"\n"
-"\tgit push\n"
-"\n"
-"to push them to a remote.\n"
-"\n"
+"WARNING: Avoiding applying %s -> %s rename to %s, because %s itself was "
+"renamed."
 msgstr ""
 
-#: transport.c:1008
-msgid "Aborting."
+#: merge-recursive.c:3019
+#, c-format
+msgid "cannot read object %s"
 msgstr ""
 
-#: transport-helper.c:1087
+#: merge-recursive.c:3022
 #, c-format
-msgid "Could not read ref %s"
+msgid "object %s is not a blob"
 msgstr ""
 
-#: tree-walk.c:31
-msgid "too-short tree object"
+#: merge-recursive.c:3086
+msgid "modify"
 msgstr ""
 
-#: tree-walk.c:37
-msgid "malformed mode in tree entry"
+#: merge-recursive.c:3086
+msgid "modified"
 msgstr ""
 
-#: tree-walk.c:41
-msgid "empty filename in tree entry"
+#: merge-recursive.c:3098
+msgid "content"
 msgstr ""
 
-#: tree-walk.c:113
-msgid "too-short tree file"
+#: merge-recursive.c:3102
+msgid "add/add"
 msgstr ""
 
-#: unpack-trees.c:111
+#: merge-recursive.c:3125
 #, c-format
-msgid ""
-"Your local changes to the following files would be overwritten by checkout:\n"
-"%%sPlease commit your changes or stash them before you switch branches."
+msgid "Skipped %s (merged same as existing)"
 msgstr ""
 
-#: unpack-trees.c:113
-#, c-format
-msgid ""
-"Your local changes to the following files would be overwritten by checkout:\n"
-"%%s"
+#: merge-recursive.c:3147 git-submodule.sh:993
+msgid "submodule"
 msgstr ""
 
-#: unpack-trees.c:116
+#: merge-recursive.c:3148
 #, c-format
-msgid ""
-"Your local changes to the following files would be overwritten by merge:\n"
-"%%sPlease commit your changes or stash them before you merge."
+msgid "CONFLICT (%s): Merge conflict in %s"
 msgstr ""
 
-#: unpack-trees.c:118
+#: merge-recursive.c:3178
 #, c-format
-msgid ""
-"Your local changes to the following files would be overwritten by merge:\n"
-"%%s"
+msgid "Adding as %s instead"
 msgstr ""
 
-#: unpack-trees.c:121
+#: merge-recursive.c:3261
 #, c-format
 msgid ""
-"Your local changes to the following files would be overwritten by %s:\n"
-"%%sPlease commit your changes or stash them before you %s."
+"Path updated: %s added in %s inside a directory that was renamed in %s; "
+"moving it to %s."
 msgstr ""
 
-#: unpack-trees.c:123
+#: merge-recursive.c:3264
 #, c-format
 msgid ""
-"Your local changes to the following files would be overwritten by %s:\n"
-"%%s"
+"CONFLICT (file location): %s added in %s inside a directory that was renamed "
+"in %s, suggesting it should perhaps be moved to %s."
 msgstr ""
 
-#: unpack-trees.c:128
+#: merge-recursive.c:3268
 #, c-format
 msgid ""
-"Updating the following directories would lose untracked files in them:\n"
-"%s"
+"Path updated: %s renamed to %s in %s, inside a directory that was renamed in "
+"%s; moving it to %s."
 msgstr ""
 
-#: unpack-trees.c:132
+#: merge-recursive.c:3271
 #, c-format
 msgid ""
-"The following untracked working tree files would be removed by checkout:\n"
-"%%sPlease move or remove them before you switch branches."
+"CONFLICT (file location): %s renamed to %s in %s, inside a directory that "
+"was renamed in %s, suggesting it should perhaps be moved to %s."
 msgstr ""
 
-#: unpack-trees.c:134
+#: merge-recursive.c:3385
 #, c-format
-msgid ""
-"The following untracked working tree files would be removed by checkout:\n"
-"%%s"
+msgid "Removing %s"
 msgstr ""
 
-#: unpack-trees.c:137
-#, c-format
-msgid ""
-"The following untracked working tree files would be removed by merge:\n"
-"%%sPlease move or remove them before you merge."
+#: merge-recursive.c:3408
+msgid "file/directory"
 msgstr ""
 
-#: unpack-trees.c:139
-#, c-format
-msgid ""
-"The following untracked working tree files would be removed by merge:\n"
-"%%s"
+#: merge-recursive.c:3413
+msgid "directory/file"
 msgstr ""
 
-#: unpack-trees.c:142
+#: merge-recursive.c:3420
 #, c-format
-msgid ""
-"The following untracked working tree files would be removed by %s:\n"
-"%%sPlease move or remove them before you %s."
+msgid "CONFLICT (%s): There is a directory with name %s in %s. Adding %s as %s"
 msgstr ""
 
-#: unpack-trees.c:144
+#: merge-recursive.c:3429
 #, c-format
-msgid ""
-"The following untracked working tree files would be removed by %s:\n"
-"%%s"
+msgid "Adding %s"
 msgstr ""
 
-#: unpack-trees.c:150
+#: merge-recursive.c:3438
 #, c-format
-msgid ""
-"The following untracked working tree files would be overwritten by "
-"checkout:\n"
-"%%sPlease move or remove them before you switch branches."
+msgid "CONFLICT (add/add): Merge conflict in %s"
 msgstr ""
 
-#: unpack-trees.c:152
-#, c-format
-msgid ""
-"The following untracked working tree files would be overwritten by "
-"checkout:\n"
-"%%s"
+#: merge-recursive.c:3482
+msgid "Already up to date!"
 msgstr ""
 
-#: unpack-trees.c:155
+#: merge-recursive.c:3491
 #, c-format
-msgid ""
-"The following untracked working tree files would be overwritten by merge:\n"
-"%%sPlease move or remove them before you merge."
+msgid "merging of trees %s and %s failed"
 msgstr ""
 
-#: unpack-trees.c:157
-#, c-format
-msgid ""
-"The following untracked working tree files would be overwritten by merge:\n"
-"%%s"
+#: merge-recursive.c:3595
+msgid "Merging:"
 msgstr ""
 
-#: unpack-trees.c:160
+#: merge-recursive.c:3608
 #, c-format
-msgid ""
-"The following untracked working tree files would be overwritten by %s:\n"
-"%%sPlease move or remove them before you %s."
+msgid "found %u common ancestor:"
+msgid_plural "found %u common ancestors:"
+msgstr[0] ""
+msgstr[1] ""
+
+#: merge-recursive.c:3658
+msgid "merge returned no commit"
 msgstr ""
 
-#: unpack-trees.c:162
+#: merge-recursive.c:3717
 #, c-format
 msgid ""
-"The following untracked working tree files would be overwritten by %s:\n"
-"%%s"
+"Your local changes to the following files would be overwritten by merge:\n"
+"  %s"
 msgstr ""
 
-#: unpack-trees.c:170
+#: merge-recursive.c:3814
 #, c-format
-msgid "Entry '%s' overlaps with '%s'.  Cannot bind."
+msgid "Could not parse object '%s'"
 msgstr ""
 
-#: unpack-trees.c:173
-#, c-format
-msgid ""
-"Cannot update sparse checkout: the following entries are not up to date:\n"
-"%s"
+#: merge-recursive.c:3832 builtin/merge.c:694 builtin/merge.c:874
+msgid "Unable to write index."
 msgstr ""
 
-#: unpack-trees.c:175
+#: midx.c:68
 #, c-format
-msgid ""
-"The following working tree files would be overwritten by sparse checkout "
-"update:\n"
-"%s"
+msgid "multi-pack-index file %s is too small"
 msgstr ""
 
-#: unpack-trees.c:177
+#: midx.c:84
 #, c-format
-msgid ""
-"The following working tree files would be removed by sparse checkout "
-"update:\n"
-"%s"
+msgid "multi-pack-index signature 0x%08x does not match signature 0x%08x"
 msgstr ""
 
-#: unpack-trees.c:179
+#: midx.c:89
 #, c-format
-msgid ""
-"Cannot update submodule:\n"
-"%s"
+msgid "multi-pack-index version %d not recognized"
 msgstr ""
 
-#: unpack-trees.c:262
+#: midx.c:94
 #, c-format
-msgid "Aborting\n"
+msgid "hash version %u does not match"
 msgstr ""
 
-#: unpack-trees.c:344
-msgid "Checking out files"
+#: midx.c:108
+msgid "invalid chunk offset (too large)"
 msgstr ""
 
-#: urlmatch.c:163
-msgid "invalid URL scheme name or missing '://' suffix"
+#: midx.c:132
+msgid "terminating multi-pack-index chunk id appears earlier than expected"
 msgstr ""
 
-#: urlmatch.c:187 urlmatch.c:346 urlmatch.c:405
-#, c-format
-msgid "invalid %XX escape sequence"
+#: midx.c:145
+msgid "multi-pack-index missing required pack-name chunk"
 msgstr ""
 
-#: urlmatch.c:215
-msgid "missing host and scheme is not 'file:'"
+#: midx.c:147
+msgid "multi-pack-index missing required OID fanout chunk"
 msgstr ""
 
-#: urlmatch.c:232
-msgid "a 'file:' URL may not have a port number"
+#: midx.c:149
+msgid "multi-pack-index missing required OID lookup chunk"
 msgstr ""
 
-#: urlmatch.c:247
-msgid "invalid characters in host name"
+#: midx.c:151
+msgid "multi-pack-index missing required object offsets chunk"
 msgstr ""
 
-#: urlmatch.c:292 urlmatch.c:303
-msgid "invalid port number"
+#: midx.c:165
+#, c-format
+msgid "multi-pack-index pack names out of order: '%s' before '%s'"
 msgstr ""
 
-#: urlmatch.c:371
-msgid "invalid '..' path segment"
+#: midx.c:210
+#, c-format
+msgid "bad pack-int-id: %u (%u total packs)"
 msgstr ""
 
-#: worktree.c:245 builtin/am.c:2147
-#, c-format
-msgid "failed to read '%s'"
+#: midx.c:260
+msgid "multi-pack-index stores a 64-bit offset, but off_t is too small"
 msgstr ""
 
-#: worktree.c:291
-#, c-format
-msgid "'%s' at main working tree is not the repository directory"
+#: midx.c:288
+msgid "error preparing packfile from multi-pack-index"
 msgstr ""
 
-#: worktree.c:302
+#: midx.c:472
 #, c-format
-msgid "'%s' file does not contain absolute path to the working tree location"
+msgid "failed to add packfile '%s'"
 msgstr ""
 
-#: worktree.c:314
+#: midx.c:478
 #, c-format
-msgid "'%s' does not exist"
+msgid "failed to open pack-index '%s'"
 msgstr ""
 
-#: worktree.c:320
+#: midx.c:538
 #, c-format
-msgid "'%s' is not a .git file, error code %d"
+msgid "failed to locate object %d in packfile"
 msgstr ""
 
-#: worktree.c:328
-#, c-format
-msgid "'%s' does not point back to '%s'"
+#: midx.c:842
+msgid "Adding packfiles to multi-pack-index"
 msgstr ""
 
-#: wrapper.c:223 wrapper.c:393
+#: midx.c:875
 #, c-format
-msgid "could not open '%s' for reading and writing"
+msgid "did not see pack-file %s to drop"
 msgstr ""
 
-#: wrapper.c:227 wrapper.c:397 builtin/am.c:320 builtin/am.c:770
-#: builtin/am.c:862 builtin/merge.c:1043
-#, c-format
-msgid "could not open '%s' for reading"
+#: midx.c:973
+msgid "Writing chunks to multi-pack-index"
 msgstr ""
 
-#: wrapper.c:424 wrapper.c:624
+#: midx.c:1052
 #, c-format
-msgid "unable to access '%s'"
+msgid "failed to clear multi-pack-index at %s"
 msgstr ""
 
-#: wrapper.c:632
-msgid "unable to get current working directory"
+#: midx.c:1108
+msgid "Looking for referenced packfiles"
 msgstr ""
 
-#: wt-status.c:154
-msgid "Unmerged paths:"
+#: midx.c:1123
+#, c-format
+msgid ""
+"oid fanout out of order: fanout[%d] = %<PRIx32> > %<PRIx32> = fanout[%d]"
 msgstr ""
 
-#: wt-status.c:181 wt-status.c:208
-#, c-format
-msgid "  (use \"git reset %s <file>...\" to unstage)"
+#: midx.c:1128
+msgid "Verifying OID order in multi-pack-index"
 msgstr ""
 
-#: wt-status.c:183 wt-status.c:210
-msgid "  (use \"git rm --cached <file>...\" to unstage)"
+#: midx.c:1137
+#, c-format
+msgid "oid lookup out of order: oid[%d] = %s >= %s = oid[%d]"
 msgstr ""
 
-#: wt-status.c:187
-msgid "  (use \"git add <file>...\" to mark resolution)"
+#: midx.c:1157
+msgid "Sorting objects by packfile"
 msgstr ""
 
-#: wt-status.c:189 wt-status.c:193
-msgid "  (use \"git add/rm <file>...\" as appropriate to mark resolution)"
+#: midx.c:1164
+msgid "Verifying object offsets"
 msgstr ""
 
-#: wt-status.c:191
-msgid "  (use \"git rm <file>...\" to mark resolution)"
+#: midx.c:1180
+#, c-format
+msgid "failed to load pack entry for oid[%d] = %s"
 msgstr ""
 
-#: wt-status.c:202 wt-status.c:1015
-msgid "Changes to be committed:"
+#: midx.c:1186
+#, c-format
+msgid "failed to load pack-index for packfile %s"
 msgstr ""
 
-#: wt-status.c:220 wt-status.c:1024
-msgid "Changes not staged for commit:"
+#: midx.c:1195
+#, c-format
+msgid "incorrect object offset for oid[%d] = %s: %<PRIx64> != %<PRIx64>"
 msgstr ""
 
-#: wt-status.c:224
-msgid "  (use \"git add <file>...\" to update what will be committed)"
+#: midx.c:1220
+msgid "Counting referenced objects"
 msgstr ""
 
-#: wt-status.c:226
-msgid "  (use \"git add/rm <file>...\" to update what will be committed)"
+#: midx.c:1230
+msgid "Finding and deleting unreferenced packfiles"
 msgstr ""
 
-#: wt-status.c:227
-msgid ""
-"  (use \"git checkout -- <file>...\" to discard changes in working directory)"
+#: midx.c:1388
+msgid "could not start pack-objects"
 msgstr ""
 
-#: wt-status.c:229
-msgid "  (commit or discard the untracked or modified content in submodules)"
+#: midx.c:1407
+msgid "could not finish pack-objects"
 msgstr ""
 
-#: wt-status.c:241
+#: name-hash.c:537
 #, c-format
-msgid "  (use \"git %s <file>...\" to include in what will be committed)"
+msgid "unable to create lazy_dir thread: %s"
 msgstr ""
 
-#: wt-status.c:256
-msgid "both deleted:"
+#: name-hash.c:559
+#, c-format
+msgid "unable to create lazy_name thread: %s"
 msgstr ""
 
-#: wt-status.c:258
-msgid "added by us:"
+#: name-hash.c:565
+#, c-format
+msgid "unable to join lazy_name thread: %s"
 msgstr ""
 
-#: wt-status.c:260
-msgid "deleted by them:"
+#: notes-merge.c:277
+#, c-format
+msgid ""
+"You have not concluded your previous notes merge (%s exists).\n"
+"Please, use 'git notes merge --commit' or 'git notes merge --abort' to "
+"commit/abort the previous merge before you start a new notes merge."
 msgstr ""
 
-#: wt-status.c:262
-msgid "added by them:"
+#: notes-merge.c:284
+#, c-format
+msgid "You have not concluded your notes merge (%s exists)."
 msgstr ""
 
-#: wt-status.c:264
-msgid "deleted by us:"
+#: notes-utils.c:46
+msgid "Cannot commit uninitialized/unreferenced notes tree"
 msgstr ""
 
-#: wt-status.c:266
-msgid "both added:"
+#: notes-utils.c:105
+#, c-format
+msgid "Bad notes.rewriteMode value: '%s'"
 msgstr ""
 
-#: wt-status.c:268
-msgid "both modified:"
+#: notes-utils.c:115
+#, c-format
+msgid "Refusing to rewrite notes in %s (outside of refs/notes/)"
 msgstr ""
 
-#: wt-status.c:278
-msgid "new file:"
+#. TRANSLATORS: The first %s is the name of
+#. the environment variable, the second %s is
+#. its value.
+#.
+#: notes-utils.c:145
+#, c-format
+msgid "Bad %s value: '%s'"
 msgstr ""
 
-#: wt-status.c:280
-msgid "copied:"
+#: object.c:53
+#, c-format
+msgid "invalid object type \"%s\""
 msgstr ""
 
-#: wt-status.c:282
-msgid "deleted:"
+#: object.c:173
+#, c-format
+msgid "object %s is a %s, not a %s"
 msgstr ""
 
-#: wt-status.c:284
-msgid "modified:"
+#: object.c:233
+#, c-format
+msgid "object %s has unknown type id %d"
 msgstr ""
 
-#: wt-status.c:286
-msgid "renamed:"
+#: object.c:246
+#, c-format
+msgid "unable to parse object: %s"
 msgstr ""
 
-#: wt-status.c:288
-msgid "typechange:"
+#: object.c:266 object.c:277
+#, c-format
+msgid "hash mismatch %s"
 msgstr ""
 
-#: wt-status.c:290
-msgid "unknown:"
+#: packfile.c:641
+msgid "offset before end of packfile (broken .idx?)"
 msgstr ""
 
-#: wt-status.c:292
-msgid "unmerged:"
+#: packfile.c:1888
+#, c-format
+msgid "offset before start of pack index for %s (corrupt index?)"
 msgstr ""
 
-#: wt-status.c:372
-msgid "new commits, "
+#: packfile.c:1892
+#, c-format
+msgid "offset beyond end of pack index for %s (truncated index?)"
 msgstr ""
 
-#: wt-status.c:374
-msgid "modified content, "
+#: parse-options.c:38
+#, c-format
+msgid "%s requires a value"
 msgstr ""
 
-#: wt-status.c:376
-msgid "untracked content, "
+#: parse-options.c:73
+#, c-format
+msgid "%s is incompatible with %s"
 msgstr ""
 
-#: wt-status.c:853
+#: parse-options.c:78
 #, c-format
-msgid "Your stash currently has %d entry"
-msgid_plural "Your stash currently has %d entries"
-msgstr[0] ""
-msgstr[1] ""
-
-#: wt-status.c:885
-msgid "Submodules changed but not updated:"
+msgid "%s : incompatible with something else"
 msgstr ""
 
-#: wt-status.c:887
-msgid "Submodule changes to be committed:"
+#: parse-options.c:92 parse-options.c:96 parse-options.c:319
+#, c-format
+msgid "%s takes no value"
 msgstr ""
 
-#: wt-status.c:969
-msgid ""
-"Do not modify or remove the line above.\n"
-"Everything below it will be ignored."
+#: parse-options.c:94
+#, c-format
+msgid "%s isn't available"
 msgstr ""
 
-#: wt-status.c:1084
-msgid "You have unmerged paths."
+#: parse-options.c:219
+#, c-format
+msgid "%s expects a non-negative integer value with an optional k/m/g suffix"
 msgstr ""
 
-#: wt-status.c:1087
-msgid "  (fix conflicts and run \"git commit\")"
+#: parse-options.c:389
+#, c-format
+msgid "ambiguous option: %s (could be --%s%s or --%s%s)"
 msgstr ""
 
-#: wt-status.c:1089
-msgid "  (use \"git merge --abort\" to abort the merge)"
+#: parse-options.c:423 parse-options.c:431
+#, c-format
+msgid "did you mean `--%s` (with two dashes ?)"
 msgstr ""
 
-#: wt-status.c:1094
-msgid "All conflicts fixed but you are still merging."
+#: parse-options.c:860
+#, c-format
+msgid "unknown option `%s'"
 msgstr ""
 
-#: wt-status.c:1097
-msgid "  (use \"git commit\" to conclude merge)"
+#: parse-options.c:862
+#, c-format
+msgid "unknown switch `%c'"
 msgstr ""
 
-#: wt-status.c:1107
-msgid "You are in the middle of an am session."
+#: parse-options.c:864
+#, c-format
+msgid "unknown non-ascii option in string: `%s'"
 msgstr ""
 
-#: wt-status.c:1110
-msgid "The current patch is empty."
+#: parse-options.c:888
+msgid "..."
 msgstr ""
 
-#: wt-status.c:1114
-msgid "  (fix conflicts and then run \"git am --continue\")"
+#: parse-options.c:907
+#, c-format
+msgid "usage: %s"
 msgstr ""
 
-#: wt-status.c:1116
-msgid "  (use \"git am --skip\" to skip this patch)"
+#. TRANSLATORS: the colon here should align with the
+#. one in "usage: %s" translation.
+#.
+#: parse-options.c:913
+#, c-format
+msgid "   or: %s"
 msgstr ""
 
-#: wt-status.c:1118
-msgid "  (use \"git am --abort\" to restore the original branch)"
+#: parse-options.c:916
+#, c-format
+msgid "    %s"
 msgstr ""
 
-#: wt-status.c:1250
-msgid "git-rebase-todo is missing."
+#: parse-options.c:955
+msgid "-NUM"
 msgstr ""
 
-#: wt-status.c:1252
-msgid "No commands done."
+#: parse-options.c:969
+#, c-format
+msgid "alias of --%s"
 msgstr ""
 
-#: wt-status.c:1255
+#: parse-options-cb.c:20 parse-options-cb.c:24
 #, c-format
-msgid "Last command done (%d command done):"
-msgid_plural "Last commands done (%d commands done):"
-msgstr[0] ""
-msgstr[1] ""
+msgid "option `%s' expects a numerical value"
+msgstr ""
 
-#: wt-status.c:1266
+#: parse-options-cb.c:41
 #, c-format
-msgid "  (see more in file %s)"
+msgid "malformed expiration date '%s'"
 msgstr ""
 
-#: wt-status.c:1271
-msgid "No commands remaining."
+#: parse-options-cb.c:54
+#, c-format
+msgid "option `%s' expects \"always\", \"auto\", or \"never\""
 msgstr ""
 
-#: wt-status.c:1274
+#: parse-options-cb.c:130 parse-options-cb.c:147
 #, c-format
-msgid "Next command to do (%d remaining command):"
-msgid_plural "Next commands to do (%d remaining commands):"
-msgstr[0] ""
-msgstr[1] ""
-
-#: wt-status.c:1282
-msgid "  (use \"git rebase --edit-todo\" to view and edit)"
+msgid "malformed object name '%s'"
 msgstr ""
 
-#: wt-status.c:1295
+#: path.c:915
 #, c-format
-msgid "You are currently rebasing branch '%s' on '%s'."
+msgid "Could not make %s writable by group"
 msgstr ""
 
-#: wt-status.c:1300
-msgid "You are currently rebasing."
+#: pathspec.c:130
+msgid "Escape character '\\' not allowed as last character in attr value"
 msgstr ""
 
-#: wt-status.c:1314
-msgid "  (fix conflicts and then run \"git rebase --continue\")"
+#: pathspec.c:148
+msgid "Only one 'attr:' specification is allowed."
 msgstr ""
 
-#: wt-status.c:1316
-msgid "  (use \"git rebase --skip\" to skip this patch)"
+#: pathspec.c:151
+msgid "attr spec must not be empty"
 msgstr ""
 
-#: wt-status.c:1318
-msgid "  (use \"git rebase --abort\" to check out the original branch)"
+#: pathspec.c:194
+#, c-format
+msgid "invalid attribute name %s"
 msgstr ""
 
-#: wt-status.c:1324
-msgid "  (all conflicts fixed: run \"git rebase --continue\")"
+#: pathspec.c:259
+msgid "global 'glob' and 'noglob' pathspec settings are incompatible"
 msgstr ""
 
-#: wt-status.c:1328
-#, c-format
+#: pathspec.c:266
 msgid ""
-"You are currently splitting a commit while rebasing branch '%s' on '%s'."
-msgstr ""
-
-#: wt-status.c:1333
-msgid "You are currently splitting a commit during a rebase."
+"global 'literal' pathspec setting is incompatible with all other global "
+"pathspec settings"
 msgstr ""
 
-#: wt-status.c:1336
-msgid "  (Once your working directory is clean, run \"git rebase --continue\")"
+#: pathspec.c:306
+msgid "invalid parameter for pathspec magic 'prefix'"
 msgstr ""
 
-#: wt-status.c:1340
+#: pathspec.c:327
 #, c-format
-msgid "You are currently editing a commit while rebasing branch '%s' on '%s'."
+msgid "Invalid pathspec magic '%.*s' in '%s'"
 msgstr ""
 
-#: wt-status.c:1345
-msgid "You are currently editing a commit during a rebase."
+#: pathspec.c:332
+#, c-format
+msgid "Missing ')' at the end of pathspec magic in '%s'"
 msgstr ""
 
-#: wt-status.c:1348
-msgid "  (use \"git commit --amend\" to amend the current commit)"
+#: pathspec.c:370
+#, c-format
+msgid "Unimplemented pathspec magic '%c' in '%s'"
 msgstr ""
 
-#: wt-status.c:1350
-msgid ""
-"  (use \"git rebase --continue\" once you are satisfied with your changes)"
+#: pathspec.c:429
+#, c-format
+msgid "%s: 'literal' and 'glob' are incompatible"
 msgstr ""
 
-#: wt-status.c:1360
+#: pathspec.c:442
 #, c-format
-msgid "You are currently cherry-picking commit %s."
+msgid "%s: '%s' is outside repository"
 msgstr ""
 
-#: wt-status.c:1365
-msgid "  (fix conflicts and run \"git cherry-pick --continue\")"
+#: pathspec.c:516
+#, c-format
+msgid "'%s' (mnemonic: '%c')"
 msgstr ""
 
-#: wt-status.c:1368
-msgid "  (all conflicts fixed: run \"git cherry-pick --continue\")"
+#: pathspec.c:526
+#, c-format
+msgid "%s: pathspec magic not supported by this command: %s"
 msgstr ""
 
-#: wt-status.c:1370
-msgid "  (use \"git cherry-pick --abort\" to cancel the cherry-pick operation)"
+#: pathspec.c:593
+#, c-format
+msgid "pathspec '%s' is beyond a symbolic link"
 msgstr ""
 
-#: wt-status.c:1379
+#: pathspec.c:638
 #, c-format
-msgid "You are currently reverting commit %s."
+msgid "line is badly quoted: %s"
 msgstr ""
 
-#: wt-status.c:1384
-msgid "  (fix conflicts and run \"git revert --continue\")"
+#: pkt-line.c:92
+msgid "unable to write flush packet"
 msgstr ""
 
-#: wt-status.c:1387
-msgid "  (all conflicts fixed: run \"git revert --continue\")"
+#: pkt-line.c:99
+msgid "unable to write delim packet"
 msgstr ""
 
-#: wt-status.c:1389
-msgid "  (use \"git revert --abort\" to cancel the revert operation)"
+#: pkt-line.c:106
+msgid "flush packet write failed"
 msgstr ""
 
-#: wt-status.c:1400
-#, c-format
-msgid "You are currently bisecting, started from branch '%s'."
+#: pkt-line.c:146 pkt-line.c:232
+msgid "protocol error: impossibly long line"
 msgstr ""
 
-#: wt-status.c:1404
-msgid "You are currently bisecting."
+#: pkt-line.c:162 pkt-line.c:164
+msgid "packet write with format failed"
 msgstr ""
 
-#: wt-status.c:1407
-msgid "  (use \"git bisect reset\" to get back to the original branch)"
+#: pkt-line.c:196
+msgid "packet write failed - data exceeds max packet size"
 msgstr ""
 
-#: wt-status.c:1604
-msgid "On branch "
+#: pkt-line.c:203 pkt-line.c:210
+msgid "packet write failed"
 msgstr ""
 
-#: wt-status.c:1610
-msgid "interactive rebase in progress; onto "
+#: pkt-line.c:295
+msgid "read error"
 msgstr ""
 
-#: wt-status.c:1612
-msgid "rebase in progress; onto "
+#: pkt-line.c:303
+msgid "the remote end hung up unexpectedly"
 msgstr ""
 
-#: wt-status.c:1617
-msgid "HEAD detached at "
+#: pkt-line.c:331
+#, c-format
+msgid "protocol error: bad line length character: %.4s"
 msgstr ""
 
-#: wt-status.c:1619
-msgid "HEAD detached from "
+#: pkt-line.c:341 pkt-line.c:346
+#, c-format
+msgid "protocol error: bad line length %d"
 msgstr ""
 
-#: wt-status.c:1622
-msgid "Not currently on any branch."
+#: pkt-line.c:362
+#, c-format
+msgid "remote error: %s"
 msgstr ""
 
-#: wt-status.c:1642
-msgid "Initial commit"
+#: preload-index.c:119
+msgid "Refreshing index"
 msgstr ""
 
-#: wt-status.c:1643
-msgid "No commits yet"
+#: preload-index.c:138
+#, c-format
+msgid "unable to create threaded lstat: %s"
 msgstr ""
 
-#: wt-status.c:1657
-msgid "Untracked files"
+#: pretty.c:981
+msgid "unable to parse --pretty format"
 msgstr ""
 
-#: wt-status.c:1659
-msgid "Ignored files"
+#: promisor-remote.c:23
+msgid "Remote with no URL"
 msgstr ""
 
-#: wt-status.c:1663
+#: promisor-remote.c:58
 #, c-format
-msgid ""
-"It took %.2f seconds to enumerate untracked files. 'status -uno'\n"
-"may speed it up, but you have to be careful not to forget to add\n"
-"new files yourself (see 'git help status')."
+msgid "promisor remote name cannot begin with '/': %s"
 msgstr ""
 
-#: wt-status.c:1669
-#, c-format
-msgid "Untracked files not listed%s"
+#: range-diff.c:75
+msgid "could not start `log`"
 msgstr ""
 
-#: wt-status.c:1671
-msgid " (use -u option to show untracked files)"
+#: range-diff.c:77
+msgid "could not read `log` output"
 msgstr ""
 
-#: wt-status.c:1677
-msgid "No changes"
+#: range-diff.c:96 sequencer.c:5163
+#, c-format
+msgid "could not parse commit '%s'"
 msgstr ""
 
-#: wt-status.c:1682
+#: range-diff.c:122
 #, c-format
-msgid "no changes added to commit (use \"git add\" and/or \"git commit -a\")\n"
+msgid "could not parse git header '%.*s'"
 msgstr ""
 
-#: wt-status.c:1685
-#, c-format
-msgid "no changes added to commit\n"
+#: range-diff.c:285
+msgid "failed to generate diff"
 msgstr ""
 
-#: wt-status.c:1688
+#: range-diff.c:518 range-diff.c:520
 #, c-format
-msgid ""
-"nothing added to commit but untracked files present (use \"git add\" to "
-"track)\n"
+msgid "could not parse log for '%s'"
 msgstr ""
 
-#: wt-status.c:1691
+#: read-cache.c:680
 #, c-format
-msgid "nothing added to commit but untracked files present\n"
+msgid "will not add file alias '%s' ('%s' already exists in index)"
 msgstr ""
 
-#: wt-status.c:1694
-#, c-format
-msgid "nothing to commit (create/copy files and use \"git add\" to track)\n"
+#: read-cache.c:696
+msgid "cannot create an empty blob in the object database"
 msgstr ""
 
-#: wt-status.c:1697 wt-status.c:1702
+#: read-cache.c:718
 #, c-format
-msgid "nothing to commit\n"
+msgid "%s: can only add regular files, symbolic links or git-directories"
 msgstr ""
 
-#: wt-status.c:1700
+#: read-cache.c:723
 #, c-format
-msgid "nothing to commit (use -u to show untracked files)\n"
+msgid "'%s' does not have a commit checked out"
 msgstr ""
 
-#: wt-status.c:1704
+#: read-cache.c:775
 #, c-format
-msgid "nothing to commit, working tree clean\n"
+msgid "unable to index file '%s'"
 msgstr ""
 
-#: wt-status.c:1817
-msgid "No commits yet on "
+#: read-cache.c:794
+#, c-format
+msgid "unable to add '%s' to index"
 msgstr ""
 
-#: wt-status.c:1821
-msgid "HEAD (no branch)"
+#: read-cache.c:805
+#, c-format
+msgid "unable to stat '%s'"
 msgstr ""
 
-#: wt-status.c:1852
-msgid "different"
+#: read-cache.c:1325
+#, c-format
+msgid "'%s' appears as both a file and as a directory"
 msgstr ""
 
-#: wt-status.c:1854 wt-status.c:1862
-msgid "behind "
+#: read-cache.c:1531
+msgid "Refresh index"
 msgstr ""
 
-#: wt-status.c:1857 wt-status.c:1860
-msgid "ahead "
+#: read-cache.c:1646
+#, c-format
+msgid ""
+"index.version set, but the value is invalid.\n"
+"Using version %i"
 msgstr ""
 
-#. TRANSLATORS: the action is e.g. "pull with rebase"
-#: wt-status.c:2366
+#: read-cache.c:1656
 #, c-format
-msgid "cannot %s: You have unstaged changes."
-msgstr ""
-
-#: wt-status.c:2372
-msgid "additionally, your index contains uncommitted changes."
+msgid ""
+"GIT_INDEX_VERSION set, but the value is invalid.\n"
+"Using version %i"
 msgstr ""
 
-#: wt-status.c:2374
+#: read-cache.c:1712
 #, c-format
-msgid "cannot %s: Your index contains uncommitted changes."
+msgid "bad signature 0x%08x"
 msgstr ""
 
-#: compat/precompose_utf8.c:58 builtin/clone.c:442
+#: read-cache.c:1715
 #, c-format
-msgid "failed to unlink '%s'"
+msgid "bad index version %d"
 msgstr ""
 
-#: builtin/add.c:24
-msgid "git add [<options>] [--] <pathspec>..."
+#: read-cache.c:1724
+msgid "bad index file sha1 signature"
 msgstr ""
 
-#: builtin/add.c:83
+#: read-cache.c:1754
 #, c-format
-msgid "unexpected diff status %c"
+msgid "index uses %.4s extension, which we do not understand"
 msgstr ""
 
-#: builtin/add.c:88 builtin/commit.c:266
-msgid "updating files failed"
+#: read-cache.c:1756
+#, c-format
+msgid "ignoring %.4s extension"
 msgstr ""
 
-#: builtin/add.c:98
+#: read-cache.c:1793
 #, c-format
-msgid "remove '%s'\n"
+msgid "unknown index entry format 0x%08x"
 msgstr ""
 
-#: builtin/add.c:173
-msgid "Unstaged changes after refreshing the index:"
+#: read-cache.c:1809
+#, c-format
+msgid "malformed name field in the index, near path '%s'"
 msgstr ""
 
-#: builtin/add.c:233 builtin/rev-parse.c:892
-msgid "Could not read the index"
+#: read-cache.c:1866
+msgid "unordered stage entries in index"
 msgstr ""
 
-#: builtin/add.c:244
+#: read-cache.c:1869
 #, c-format
-msgid "Could not open '%s' for writing."
+msgid "multiple stage entries for merged file '%s'"
 msgstr ""
 
-#: builtin/add.c:248
-msgid "Could not write patch"
+#: read-cache.c:1872
+#, c-format
+msgid "unordered stage entries for '%s'"
 msgstr ""
 
-#: builtin/add.c:251
-msgid "editing patch failed"
+#: read-cache.c:1978 read-cache.c:2266 rerere.c:565 rerere.c:599 rerere.c:1111
+#: builtin/add.c:499 builtin/check-ignore.c:178 builtin/checkout.c:470
+#: builtin/checkout.c:654 builtin/clean.c:967 builtin/commit.c:367
+#: builtin/diff-tree.c:120 builtin/grep.c:499 builtin/mv.c:145
+#: builtin/reset.c:246 builtin/rm.c:271 builtin/submodule--helper.c:332
+msgid "index file corrupt"
 msgstr ""
 
-#: builtin/add.c:254
+#: read-cache.c:2119
 #, c-format
-msgid "Could not stat '%s'"
+msgid "unable to create load_cache_entries thread: %s"
 msgstr ""
 
-#: builtin/add.c:256
-msgid "Empty patch. Aborted."
+#: read-cache.c:2132
+#, c-format
+msgid "unable to join load_cache_entries thread: %s"
 msgstr ""
 
-#: builtin/add.c:261
+#: read-cache.c:2165
 #, c-format
-msgid "Could not apply '%s'"
+msgid "%s: index file open failed"
 msgstr ""
 
-#: builtin/add.c:269
-msgid "The following paths are ignored by one of your .gitignore files:\n"
+#: read-cache.c:2169
+#, c-format
+msgid "%s: cannot stat the open index"
 msgstr ""
 
-#: builtin/add.c:289 builtin/clean.c:911 builtin/fetch.c:145 builtin/mv.c:123
-#: builtin/prune-packed.c:55 builtin/pull.c:212 builtin/push.c:557
-#: builtin/remote.c:1342 builtin/rm.c:240 builtin/send-pack.c:165
-msgid "dry run"
+#: read-cache.c:2173
+#, c-format
+msgid "%s: index file smaller than expected"
 msgstr ""
 
-#: builtin/add.c:292
-msgid "interactive picking"
+#: read-cache.c:2177
+#, c-format
+msgid "%s: unable to map index file"
 msgstr ""
 
-#: builtin/add.c:293 builtin/checkout.c:1135 builtin/reset.c:302
-msgid "select hunks interactively"
+#: read-cache.c:2219
+#, c-format
+msgid "unable to create load_index_extensions thread: %s"
 msgstr ""
 
-#: builtin/add.c:294
-msgid "edit current diff and apply"
+#: read-cache.c:2246
+#, c-format
+msgid "unable to join load_index_extensions thread: %s"
 msgstr ""
 
-#: builtin/add.c:295
-msgid "allow adding otherwise ignored files"
+#: read-cache.c:2278
+#, c-format
+msgid "could not freshen shared index '%s'"
 msgstr ""
 
-#: builtin/add.c:296
-msgid "update tracked files"
+#: read-cache.c:2325
+#, c-format
+msgid "broken index, expect %s in %s, got %s"
 msgstr ""
 
-#: builtin/add.c:297
-msgid "renormalize EOL of tracked files (implies -u)"
+#: read-cache.c:3021 strbuf.c:1145 wrapper.c:622 builtin/merge.c:1119
+#, c-format
+msgid "could not close '%s'"
 msgstr ""
 
-#: builtin/add.c:298
-msgid "record only the fact that the path will be added later"
+#: read-cache.c:3124 sequencer.c:2429 sequencer.c:4069
+#, c-format
+msgid "could not stat '%s'"
 msgstr ""
 
-#: builtin/add.c:299
-msgid "add changes from all tracked and untracked files"
+#: read-cache.c:3137
+#, c-format
+msgid "unable to open git dir: %s"
 msgstr ""
 
-#: builtin/add.c:302
-msgid "ignore paths removed in the working tree (same as --no-all)"
+#: read-cache.c:3149
+#, c-format
+msgid "unable to unlink: %s"
 msgstr ""
 
-#: builtin/add.c:304
-msgid "don't add, only refresh the index"
+#: read-cache.c:3174
+#, c-format
+msgid "cannot fix permission bits on '%s'"
 msgstr ""
 
-#: builtin/add.c:305
-msgid "just skip files which cannot be added because of errors"
+#: read-cache.c:3323
+#, c-format
+msgid "%s: cannot drop to stage #0"
 msgstr ""
 
-#: builtin/add.c:306
-msgid "check if - even missing - files are ignored in dry run"
+#: rebase-interactive.c:26
+#, c-format
+msgid ""
+"unrecognized setting %s for option rebase.missingCommitsCheck. Ignoring."
 msgstr ""
 
-#: builtin/add.c:307 builtin/update-index.c:974
-msgid "(+/-)x"
+#: rebase-interactive.c:35
+msgid ""
+"\n"
+"Commands:\n"
+"p, pick <commit> = use commit\n"
+"r, reword <commit> = use commit, but edit the commit message\n"
+"e, edit <commit> = use commit, but stop for amending\n"
+"s, squash <commit> = use commit, but meld into previous commit\n"
+"f, fixup <commit> = like \"squash\", but discard this commit's log message\n"
+"x, exec <command> = run command (the rest of the line) using shell\n"
+"b, break = stop here (continue rebase later with 'git rebase --continue')\n"
+"d, drop <commit> = remove commit\n"
+"l, label <label> = label current HEAD with a name\n"
+"t, reset <label> = reset HEAD to a label\n"
+"m, merge [-C <commit> | -c <commit>] <label> [# <oneline>]\n"
+".       create a merge commit using the original merge commit's\n"
+".       message (or the oneline, if no original merge commit was\n"
+".       specified). Use -c <commit> to reword the commit message.\n"
+"\n"
+"These lines can be re-ordered; they are executed from top to bottom.\n"
 msgstr ""
 
-#: builtin/add.c:307 builtin/update-index.c:975
-msgid "override the executable bit of the listed files"
+#: rebase-interactive.c:56
+#, c-format
+msgid "Rebase %s onto %s (%d command)"
+msgid_plural "Rebase %s onto %s (%d commands)"
+msgstr[0] ""
+msgstr[1] ""
+
+#: rebase-interactive.c:65 git-rebase--preserve-merges.sh:228
+msgid ""
+"\n"
+"Do not remove any line. Use 'drop' explicitly to remove a commit.\n"
 msgstr ""
 
-#: builtin/add.c:309
-msgid "warn when adding an embedded repository"
+#: rebase-interactive.c:68 git-rebase--preserve-merges.sh:232
+msgid ""
+"\n"
+"If you remove a line here THAT COMMIT WILL BE LOST.\n"
 msgstr ""
 
-#: builtin/add.c:324
-#, c-format
+#: rebase-interactive.c:74 git-rebase--preserve-merges.sh:871
 msgid ""
-"You've added another git repository inside your current repository.\n"
-"Clones of the outer repository will not contain the contents of\n"
-"the embedded repository and will not know how to obtain it.\n"
-"If you meant to add a submodule, use:\n"
 "\n"
-"\tgit submodule add <url> %s\n"
+"You are editing the todo file of an ongoing interactive rebase.\n"
+"To continue rebase after editing, run:\n"
+"    git rebase --continue\n"
 "\n"
-"If you added this path by mistake, you can remove it from the\n"
-"index with:\n"
+msgstr ""
+
+#: rebase-interactive.c:79 git-rebase--preserve-merges.sh:948
+msgid ""
 "\n"
-"\tgit rm --cached %s\n"
+"However, if you remove everything, the rebase will be aborted.\n"
 "\n"
-"See \"git help submodule\" for more information."
 msgstr ""
 
-#: builtin/add.c:352
-#, c-format
-msgid "adding embedded git repository: %s"
+#: rebase-interactive.c:85 git-rebase--preserve-merges.sh:955
+msgid "Note that empty commits are commented out"
 msgstr ""
 
-#: builtin/add.c:370
+#: rebase-interactive.c:105 rerere.c:485 rerere.c:692 sequencer.c:3536
+#: sequencer.c:3562 sequencer.c:5263 builtin/fsck.c:346 builtin/rebase.c:254
 #, c-format
-msgid "Use -f if you really want to add them.\n"
+msgid "could not write '%s'"
 msgstr ""
 
-#: builtin/add.c:378
-msgid "adding files failed"
+#: rebase-interactive.c:108
+#, c-format
+msgid "could not copy '%s' to '%s'."
 msgstr ""
 
-#: builtin/add.c:416
-msgid "-A and -u are mutually incompatible"
+#: rebase-interactive.c:173
+#, c-format
+msgid ""
+"Warning: some commits may have been dropped accidentally.\n"
+"Dropped commits (newer to older):\n"
 msgstr ""
 
-#: builtin/add.c:423
-msgid "Option --ignore-missing can only be used together with --dry-run"
+#: rebase-interactive.c:180
+#, c-format
+msgid ""
+"To avoid this message, use \"drop\" to explicitly remove a commit.\n"
+"\n"
+"Use 'git config rebase.missingCommitsCheck' to change the level of "
+"warnings.\n"
+"The possible behaviours are: ignore, warn, error.\n"
+"\n"
 msgstr ""
 
-#: builtin/add.c:427
+#: refs.c:262
 #, c-format
-msgid "--chmod param '%s' must be either -x or +x"
+msgid "%s does not point to a valid object!"
 msgstr ""
 
-#: builtin/add.c:442
+#: refs.c:667
 #, c-format
-msgid "Nothing specified, nothing added.\n"
+msgid "ignoring dangling symref %s"
 msgstr ""
 
-#: builtin/add.c:443
+#: refs.c:669 ref-filter.c:2098
 #, c-format
-msgid "Maybe you wanted to say 'git add .'?\n"
+msgid "ignoring broken ref %s"
 msgstr ""
 
-#: builtin/add.c:448 builtin/check-ignore.c:177 builtin/checkout.c:280
-#: builtin/checkout.c:483 builtin/clean.c:958 builtin/commit.c:325
-#: builtin/diff-tree.c:114 builtin/mv.c:144 builtin/reset.c:241
-#: builtin/rm.c:270 builtin/submodule--helper.c:328
-msgid "index file corrupt"
+#: refs.c:804
+#, c-format
+msgid "could not open '%s' for writing: %s"
 msgstr ""
 
-#: builtin/am.c:414
-msgid "could not parse author script"
+#: refs.c:814 refs.c:865
+#, c-format
+msgid "could not read ref '%s'"
 msgstr ""
 
-#: builtin/am.c:498
+#: refs.c:820
 #, c-format
-msgid "'%s' was deleted by the applypatch-msg hook"
+msgid "ref '%s' already exists"
 msgstr ""
 
-#: builtin/am.c:539
+#: refs.c:825
 #, c-format
-msgid "Malformed input line: '%s'."
+msgid "unexpected object ID when writing '%s'"
 msgstr ""
 
-#: builtin/am.c:576
+#: refs.c:833 sequencer.c:405 sequencer.c:2793 sequencer.c:2997
+#: sequencer.c:3011 sequencer.c:3269 sequencer.c:5179 strbuf.c:1142
+#: wrapper.c:620
 #, c-format
-msgid "Failed to copy notes from '%s' to '%s'"
+msgid "could not write to '%s'"
 msgstr ""
 
-#: builtin/am.c:602
-msgid "fseek failed"
+#: refs.c:860 strbuf.c:1140 wrapper.c:188 wrapper.c:358 builtin/am.c:714
+#: builtin/rebase.c:1031
+#, c-format
+msgid "could not open '%s' for writing"
 msgstr ""
 
-#: builtin/am.c:790
+#: refs.c:867
 #, c-format
-msgid "could not parse patch '%s'"
+msgid "unexpected object ID when deleting '%s'"
 msgstr ""
 
-#: builtin/am.c:855
-msgid "Only one StGIT patch series can be applied at once"
+#: refs.c:998
+#, c-format
+msgid "log for ref %s has gap after %s"
 msgstr ""
 
-#: builtin/am.c:903
-msgid "invalid timestamp"
+#: refs.c:1004
+#, c-format
+msgid "log for ref %s unexpectedly ended on %s"
 msgstr ""
 
-#: builtin/am.c:908 builtin/am.c:920
-msgid "invalid Date line"
+#: refs.c:1063
+#, c-format
+msgid "log for %s is empty"
 msgstr ""
 
-#: builtin/am.c:915
-msgid "invalid timezone offset"
+#: refs.c:1155
+#, c-format
+msgid "refusing to update ref with bad name '%s'"
 msgstr ""
 
-#: builtin/am.c:1008
-msgid "Patch format detection failed."
+#: refs.c:1231
+#, c-format
+msgid "update_ref failed for ref '%s': %s"
 msgstr ""
 
-#: builtin/am.c:1013 builtin/clone.c:407
+#: refs.c:2023
 #, c-format
-msgid "failed to create directory '%s'"
+msgid "multiple updates for ref '%s' not allowed"
 msgstr ""
 
-#: builtin/am.c:1018
-msgid "Failed to split patches."
+#: refs.c:2055
+msgid "ref updates forbidden inside quarantine environment"
 msgstr ""
 
-#: builtin/am.c:1148 builtin/commit.c:351
-msgid "unable to write index file"
+#: refs.c:2151 refs.c:2181
+#, c-format
+msgid "'%s' exists; cannot create '%s'"
 msgstr ""
 
-#: builtin/am.c:1162
+#: refs.c:2157 refs.c:2192
 #, c-format
-msgid "When you have resolved this problem, run \"%s --continue\"."
+msgid "cannot process '%s' and '%s' at the same time"
 msgstr ""
 
-#: builtin/am.c:1163
+#: refs/files-backend.c:1234
 #, c-format
-msgid "If you prefer to skip this patch, run \"%s --skip\" instead."
+msgid "could not remove reference %s"
 msgstr ""
 
-#: builtin/am.c:1164
+#: refs/files-backend.c:1248 refs/packed-backend.c:1541
+#: refs/packed-backend.c:1551
 #, c-format
-msgid "To restore the original branch and stop patching, run \"%s --abort\"."
+msgid "could not delete reference %s: %s"
 msgstr ""
 
-#: builtin/am.c:1271
-msgid "Patch is empty."
+#: refs/files-backend.c:1251 refs/packed-backend.c:1554
+#, c-format
+msgid "could not delete references: %s"
 msgstr ""
 
-#: builtin/am.c:1337
+#: refspec.c:137
 #, c-format
-msgid "invalid ident line: %.*s"
+msgid "invalid refspec '%s'"
 msgstr ""
 
-#: builtin/am.c:1359
-#, c-format
-msgid "unable to parse commit %s"
+#: ref-filter.c:42 wt-status.c:1938
+msgid "gone"
 msgstr ""
 
-#: builtin/am.c:1554
-msgid "Repository lacks necessary blobs to fall back on 3-way merge."
+#: ref-filter.c:43
+#, c-format
+msgid "ahead %d"
 msgstr ""
 
-#: builtin/am.c:1556
-msgid "Using index info to reconstruct a base tree..."
+#: ref-filter.c:44
+#, c-format
+msgid "behind %d"
 msgstr ""
 
-#: builtin/am.c:1575
-msgid ""
-"Did you hand edit your patch?\n"
-"It does not apply to blobs recorded in its index."
+#: ref-filter.c:45
+#, c-format
+msgid "ahead %d, behind %d"
 msgstr ""
 
-#: builtin/am.c:1581
-msgid "Falling back to patching base and 3-way merge..."
+#: ref-filter.c:165
+#, c-format
+msgid "expected format: %%(color:<color>)"
 msgstr ""
 
-#: builtin/am.c:1606
-msgid "Failed to merge in the changes."
+#: ref-filter.c:167
+#, c-format
+msgid "unrecognized color: %%(color:%s)"
 msgstr ""
 
-#: builtin/am.c:1637
-msgid "applying to an empty history"
+#: ref-filter.c:189
+#, c-format
+msgid "Integer value expected refname:lstrip=%s"
 msgstr ""
 
-#: builtin/am.c:1683 builtin/am.c:1687
+#: ref-filter.c:193
 #, c-format
-msgid "cannot resume: %s does not exist."
+msgid "Integer value expected refname:rstrip=%s"
 msgstr ""
 
-#: builtin/am.c:1703
-msgid "cannot be interactive without stdin connected to a terminal."
+#: ref-filter.c:195
+#, c-format
+msgid "unrecognized %%(%s) argument: %s"
 msgstr ""
 
-#: builtin/am.c:1708
-msgid "Commit Body is:"
+#: ref-filter.c:250
+#, c-format
+msgid "%%(objecttype) does not take arguments"
 msgstr ""
 
-#. TRANSLATORS: Make sure to include [y], [n], [e], [v] and [a]
-#. in your translation. The program will only accept English
-#. input at this point.
-#.
-#: builtin/am.c:1718
-msgid "Apply? [y]es/[n]o/[e]dit/[v]iew patch/[a]ccept all: "
+#: ref-filter.c:272
+#, c-format
+msgid "unrecognized %%(objectsize) argument: %s"
 msgstr ""
 
-#: builtin/am.c:1768
+#: ref-filter.c:280
 #, c-format
-msgid "Dirty index: cannot apply patches (dirty: %s)"
+msgid "%%(deltabase) does not take arguments"
 msgstr ""
 
-#: builtin/am.c:1808 builtin/am.c:1879
+#: ref-filter.c:292
 #, c-format
-msgid "Applying: %.*s"
+msgid "%%(body) does not take arguments"
 msgstr ""
 
-#: builtin/am.c:1824
-msgid "No changes -- Patch already applied."
+#: ref-filter.c:301
+#, c-format
+msgid "%%(subject) does not take arguments"
 msgstr ""
 
-#: builtin/am.c:1832
+#: ref-filter.c:323
 #, c-format
-msgid "Patch failed at %s %.*s"
+msgid "unknown %%(trailers) argument: %s"
 msgstr ""
 
-#: builtin/am.c:1838
-msgid "Use 'git am --show-current-patch' to see the failed patch"
+#: ref-filter.c:352
+#, c-format
+msgid "positive value expected contents:lines=%s"
 msgstr ""
 
-#: builtin/am.c:1882
-msgid ""
-"No changes - did you forget to use 'git add'?\n"
-"If there is nothing left to stage, chances are that something else\n"
-"already introduced the same changes; you might want to skip this patch."
+#: ref-filter.c:354
+#, c-format
+msgid "unrecognized %%(contents) argument: %s"
 msgstr ""
 
-#: builtin/am.c:1889
-msgid ""
-"You still have unmerged paths in your index.\n"
-"You should 'git add' each file with resolved conflicts to mark them as "
-"such.\n"
-"You might run `git rm` on a file to accept \"deleted by them\" for it."
+#: ref-filter.c:369
+#, c-format
+msgid "positive value expected objectname:short=%s"
 msgstr ""
 
-#: builtin/am.c:1996 builtin/am.c:2000 builtin/am.c:2012 builtin/reset.c:324
-#: builtin/reset.c:332
+#: ref-filter.c:373
 #, c-format
-msgid "Could not parse object '%s'."
+msgid "unrecognized %%(objectname) argument: %s"
 msgstr ""
 
-#: builtin/am.c:2048
-msgid "failed to clean index"
+#: ref-filter.c:403
+#, c-format
+msgid "expected format: %%(align:<width>,<position>)"
 msgstr ""
 
-#: builtin/am.c:2083
-msgid ""
-"You seem to have moved HEAD since the last 'am' failure.\n"
-"Not rewinding to ORIG_HEAD"
+#: ref-filter.c:415
+#, c-format
+msgid "unrecognized position:%s"
 msgstr ""
 
-#: builtin/am.c:2174
+#: ref-filter.c:422
 #, c-format
-msgid "Invalid value for --patch-format: %s"
+msgid "unrecognized width:%s"
 msgstr ""
 
-#: builtin/am.c:2210
-msgid "git am [<options>] [(<mbox> | <Maildir>)...]"
+#: ref-filter.c:431
+#, c-format
+msgid "unrecognized %%(align) argument: %s"
 msgstr ""
 
-#: builtin/am.c:2211
-msgid "git am [<options>] (--continue | --skip | --abort)"
+#: ref-filter.c:439
+#, c-format
+msgid "positive width expected with the %%(align) atom"
 msgstr ""
 
-#: builtin/am.c:2217
-msgid "run interactively"
+#: ref-filter.c:457
+#, c-format
+msgid "unrecognized %%(if) argument: %s"
 msgstr ""
 
-#: builtin/am.c:2219
-msgid "historical option -- no-op"
+#: ref-filter.c:559
+#, c-format
+msgid "malformed field name: %.*s"
 msgstr ""
 
-#: builtin/am.c:2221
-msgid "allow fall back on 3way merging if needed"
+#: ref-filter.c:586
+#, c-format
+msgid "unknown field name: %.*s"
 msgstr ""
 
-#: builtin/am.c:2222 builtin/init-db.c:484 builtin/prune-packed.c:57
-#: builtin/repack.c:192
-msgid "be quiet"
+#: ref-filter.c:590
+#, c-format
+msgid ""
+"not a git repository, but the field '%.*s' requires access to object data"
 msgstr ""
 
-#: builtin/am.c:2224
-msgid "add a Signed-off-by line to the commit message"
+#: ref-filter.c:714
+#, c-format
+msgid "format: %%(if) atom used without a %%(then) atom"
 msgstr ""
 
-#: builtin/am.c:2227
-msgid "recode into utf8 (default)"
+#: ref-filter.c:777
+#, c-format
+msgid "format: %%(then) atom used without an %%(if) atom"
 msgstr ""
 
-#: builtin/am.c:2229
-msgid "pass -k flag to git-mailinfo"
+#: ref-filter.c:779
+#, c-format
+msgid "format: %%(then) atom used more than once"
 msgstr ""
 
-#: builtin/am.c:2231
-msgid "pass -b flag to git-mailinfo"
+#: ref-filter.c:781
+#, c-format
+msgid "format: %%(then) atom used after %%(else)"
 msgstr ""
 
-#: builtin/am.c:2233
-msgid "pass -m flag to git-mailinfo"
+#: ref-filter.c:809
+#, c-format
+msgid "format: %%(else) atom used without an %%(if) atom"
 msgstr ""
 
-#: builtin/am.c:2235
-msgid "pass --keep-cr flag to git-mailsplit for mbox format"
+#: ref-filter.c:811
+#, c-format
+msgid "format: %%(else) atom used without a %%(then) atom"
 msgstr ""
 
-#: builtin/am.c:2238
-msgid "do not pass --keep-cr flag to git-mailsplit independent of am.keepcr"
+#: ref-filter.c:813
+#, c-format
+msgid "format: %%(else) atom used more than once"
 msgstr ""
 
-#: builtin/am.c:2241
-msgid "strip everything before a scissors line"
+#: ref-filter.c:828
+#, c-format
+msgid "format: %%(end) atom used without corresponding atom"
 msgstr ""
 
-#: builtin/am.c:2243 builtin/am.c:2246 builtin/am.c:2249 builtin/am.c:2252
-#: builtin/am.c:2255 builtin/am.c:2258 builtin/am.c:2261 builtin/am.c:2264
-#: builtin/am.c:2270
-msgid "pass it through git-apply"
+#: ref-filter.c:885
+#, c-format
+msgid "malformed format string %s"
 msgstr ""
 
-#: builtin/am.c:2260 builtin/commit.c:1332 builtin/fmt-merge-msg.c:665
-#: builtin/fmt-merge-msg.c:668 builtin/grep.c:853 builtin/merge.c:208
-#: builtin/pull.c:150 builtin/pull.c:208 builtin/repack.c:201
-#: builtin/repack.c:205 builtin/repack.c:207 builtin/show-branch.c:631
-#: builtin/show-ref.c:169 builtin/tag.c:383 parse-options.h:144
-#: parse-options.h:146 parse-options.h:258
-msgid "n"
+#: ref-filter.c:1488
+#, c-format
+msgid "no branch, rebasing %s"
 msgstr ""
 
-#: builtin/am.c:2266 builtin/branch.c:632 builtin/for-each-ref.c:38
-#: builtin/replace.c:543 builtin/tag.c:419 builtin/verify-tag.c:39
-msgid "format"
+#: ref-filter.c:1491
+#, c-format
+msgid "no branch, rebasing detached HEAD %s"
 msgstr ""
 
-#: builtin/am.c:2267
-msgid "format the patch(es) are in"
+#: ref-filter.c:1494
+#, c-format
+msgid "no branch, bisect started on %s"
 msgstr ""
 
-#: builtin/am.c:2273
-msgid "override error message when patch failure occurs"
+#: ref-filter.c:1504
+msgid "no branch"
 msgstr ""
 
-#: builtin/am.c:2275
-msgid "continue applying patches after resolving a conflict"
+#: ref-filter.c:1540 ref-filter.c:1749
+#, c-format
+msgid "missing object %s for %s"
 msgstr ""
 
-#: builtin/am.c:2278
-msgid "synonyms for --continue"
+#: ref-filter.c:1550
+#, c-format
+msgid "parse_object_buffer failed on %s for %s"
 msgstr ""
 
-#: builtin/am.c:2281
-msgid "skip the current patch"
+#: ref-filter.c:2004
+#, c-format
+msgid "malformed object at '%s'"
 msgstr ""
 
-#: builtin/am.c:2284
-msgid "restore the original branch and abort the patching operation."
+#: ref-filter.c:2093
+#, c-format
+msgid "ignoring ref with broken name %s"
 msgstr ""
 
-#: builtin/am.c:2287
-msgid "abort the patching operation but keep HEAD where it is."
+#: ref-filter.c:2389
+#, c-format
+msgid "format: %%(end) atom missing"
 msgstr ""
 
-#: builtin/am.c:2290
-msgid "show the patch being applied."
+#: ref-filter.c:2489
+#, c-format
+msgid "option `%s' is incompatible with --merged"
 msgstr ""
 
-#: builtin/am.c:2294
-msgid "lie about committer date"
+#: ref-filter.c:2492
+#, c-format
+msgid "option `%s' is incompatible with --no-merged"
 msgstr ""
 
-#: builtin/am.c:2296
-msgid "use current timestamp for author date"
+#: ref-filter.c:2502
+#, c-format
+msgid "malformed object name %s"
 msgstr ""
 
-#: builtin/am.c:2298 builtin/commit.c:1468 builtin/merge.c:239
-#: builtin/pull.c:183 builtin/revert.c:112 builtin/tag.c:399
-msgid "key-id"
+#: ref-filter.c:2507
+#, c-format
+msgid "option `%s' must point to a commit"
 msgstr ""
 
-#: builtin/am.c:2299
-msgid "GPG-sign commits"
+#: remote.c:366
+#, c-format
+msgid "config remote shorthand cannot begin with '/': %s"
 msgstr ""
 
-#: builtin/am.c:2302
-msgid "(internal use for git-rebase)"
+#: remote.c:413
+msgid "more than one receivepack given, using the first"
 msgstr ""
 
-#: builtin/am.c:2320
-msgid ""
-"The -b/--binary option has been a no-op for long time, and\n"
-"it will be removed. Please do not use it anymore."
+#: remote.c:421
+msgid "more than one uploadpack given, using the first"
 msgstr ""
 
-#: builtin/am.c:2327
-msgid "failed to read the index"
+#: remote.c:611
+#, c-format
+msgid "Cannot fetch both %s and %s to %s"
 msgstr ""
 
-#: builtin/am.c:2342
+#: remote.c:615
 #, c-format
-msgid "previous rebase directory %s still exists but mbox given."
+msgid "%s usually tracks %s, not %s"
 msgstr ""
 
-#: builtin/am.c:2366
+#: remote.c:619
 #, c-format
-msgid ""
-"Stray %s directory found.\n"
-"Use \"git am --abort\" to remove it."
+msgid "%s tracks both %s and %s"
 msgstr ""
 
-#: builtin/am.c:2372
-msgid "Resolve operation not in progress, we are not resuming."
+#: remote.c:687
+#, c-format
+msgid "key '%s' of pattern had no '*'"
 msgstr ""
 
-#: builtin/apply.c:8
-msgid "git apply [<options>] [<patch>...]"
+#: remote.c:697
+#, c-format
+msgid "value '%s' of pattern has no '*'"
 msgstr ""
 
-#: builtin/archive.c:17
+#: remote.c:1003
 #, c-format
-msgid "could not create archive file '%s'"
+msgid "src refspec %s does not match any"
 msgstr ""
 
-#: builtin/archive.c:20
-msgid "could not redirect output"
+#: remote.c:1008
+#, c-format
+msgid "src refspec %s matches more than one"
 msgstr ""
 
-#: builtin/archive.c:37
-msgid "git archive: Remote with no URL"
+#. TRANSLATORS: "matches '%s'%" is the <dst> part of "git push
+#. <remote> <src>:<dst>" push, and "being pushed ('%s')" is
+#. the <src>.
+#.
+#: remote.c:1023
+#, c-format
+msgid ""
+"The destination you provided is not a full refname (i.e.,\n"
+"starting with \"refs/\"). We tried to guess what you meant by:\n"
+"\n"
+"- Looking for a ref that matches '%s' on the remote side.\n"
+"- Checking if the <src> being pushed ('%s')\n"
+"  is a ref in \"refs/{heads,tags}/\". If so we add a corresponding\n"
+"  refs/{heads,tags}/ prefix on the remote side.\n"
+"\n"
+"Neither worked, so we gave up. You must fully qualify the ref."
 msgstr ""
 
-#: builtin/archive.c:58
-msgid "git archive: expected ACK/NAK, got a flush packet"
+#: remote.c:1043
+#, c-format
+msgid ""
+"The <src> part of the refspec is a commit object.\n"
+"Did you mean to create a new branch by pushing to\n"
+"'%s:refs/heads/%s'?"
 msgstr ""
 
-#: builtin/archive.c:61
+#: remote.c:1048
 #, c-format
-msgid "git archive: NACK %s"
+msgid ""
+"The <src> part of the refspec is a tag object.\n"
+"Did you mean to create a new tag by pushing to\n"
+"'%s:refs/tags/%s'?"
 msgstr ""
 
-#: builtin/archive.c:64
-msgid "git archive: protocol error"
+#: remote.c:1053
+#, c-format
+msgid ""
+"The <src> part of the refspec is a tree object.\n"
+"Did you mean to tag a new tree by pushing to\n"
+"'%s:refs/tags/%s'?"
 msgstr ""
 
-#: builtin/archive.c:68
-msgid "git archive: expected a flush"
+#: remote.c:1058
+#, c-format
+msgid ""
+"The <src> part of the refspec is a blob object.\n"
+"Did you mean to tag a new blob by pushing to\n"
+"'%s:refs/tags/%s'?"
 msgstr ""
 
-#: builtin/bisect--helper.c:12
-msgid "git bisect--helper --next-all [--no-checkout]"
+#: remote.c:1094
+#, c-format
+msgid "%s cannot be resolved to branch"
 msgstr ""
 
-#: builtin/bisect--helper.c:13
-msgid "git bisect--helper --write-terms <bad_term> <good_term>"
+#: remote.c:1105
+#, c-format
+msgid "unable to delete '%s': remote ref does not exist"
 msgstr ""
 
-#: builtin/bisect--helper.c:14
-msgid "git bisect--helper --bisect-clean-state"
+#: remote.c:1117
+#, c-format
+msgid "dst refspec %s matches more than one"
 msgstr ""
 
-#: builtin/bisect--helper.c:46
+#: remote.c:1124
 #, c-format
-msgid "'%s' is not a valid term"
+msgid "dst ref %s receives from more than one src"
 msgstr ""
 
-#: builtin/bisect--helper.c:50
-#, c-format
-msgid "can't use the builtin command '%s' as a term"
+#: remote.c:1627 remote.c:1728
+msgid "HEAD does not point to a branch"
 msgstr ""
 
-#: builtin/bisect--helper.c:60
+#: remote.c:1636
 #, c-format
-msgid "can't change the meaning of the term '%s'"
+msgid "no such branch: '%s'"
 msgstr ""
 
-#: builtin/bisect--helper.c:71
-msgid "please use two different terms"
+#: remote.c:1639
+#, c-format
+msgid "no upstream configured for branch '%s'"
 msgstr ""
 
-#: builtin/bisect--helper.c:78
-msgid "could not open the file BISECT_TERMS"
+#: remote.c:1645
+#, c-format
+msgid "upstream branch '%s' not stored as a remote-tracking branch"
 msgstr ""
 
-#: builtin/bisect--helper.c:120
-msgid "perform 'git bisect next'"
+#: remote.c:1660
+#, c-format
+msgid "push destination '%s' on remote '%s' has no local tracking branch"
 msgstr ""
 
-#: builtin/bisect--helper.c:122
-msgid "write the terms to .git/BISECT_TERMS"
+#: remote.c:1672
+#, c-format
+msgid "branch '%s' has no remote for pushing"
 msgstr ""
 
-#: builtin/bisect--helper.c:124
-msgid "cleanup the bisection state"
+#: remote.c:1682
+#, c-format
+msgid "push refspecs for '%s' do not include '%s'"
 msgstr ""
 
-#: builtin/bisect--helper.c:126
-msgid "check for expected revs"
+#: remote.c:1695
+msgid "push has no destination (push.default is 'nothing')"
 msgstr ""
 
-#: builtin/bisect--helper.c:128
-msgid "update BISECT_HEAD instead of checking out the current commit"
+#: remote.c:1717
+msgid "cannot resolve 'simple' push to a single destination"
 msgstr ""
 
-#: builtin/bisect--helper.c:143
-msgid "--write-terms requires two arguments"
+#: remote.c:1843
+#, c-format
+msgid "couldn't find remote ref %s"
 msgstr ""
 
-#: builtin/bisect--helper.c:147
-msgid "--bisect-clean-state requires no arguments"
+#: remote.c:1856
+#, c-format
+msgid "* Ignoring funny ref '%s' locally"
 msgstr ""
 
-#: builtin/blame.c:29
-msgid "git blame [<options>] [<rev-opts>] [<rev>] [--] <file>"
+#: remote.c:2019
+#, c-format
+msgid "Your branch is based on '%s', but the upstream is gone.\n"
 msgstr ""
 
-#: builtin/blame.c:34
-msgid "<rev-opts> are documented in git-rev-list(1)"
+#: remote.c:2023
+msgid "  (use \"git branch --unset-upstream\" to fixup)\n"
 msgstr ""
 
-#: builtin/blame.c:404
+#: remote.c:2026
 #, c-format
-msgid "expecting a color: %s"
+msgid "Your branch is up to date with '%s'.\n"
 msgstr ""
 
-#: builtin/blame.c:411
-msgid "must end with a color"
+#: remote.c:2030
+#, c-format
+msgid "Your branch and '%s' refer to different commits.\n"
 msgstr ""
 
-#: builtin/blame.c:697
+#: remote.c:2033
 #, c-format
-msgid "invalid color '%s' in color.blame.repeatedLines"
+msgid "  (use \"%s\" for details)\n"
 msgstr ""
 
-#: builtin/blame.c:715
-msgid "invalid value for blame.coloring"
-msgstr ""
+#: remote.c:2037
+#, c-format
+msgid "Your branch is ahead of '%s' by %d commit.\n"
+msgid_plural "Your branch is ahead of '%s' by %d commits.\n"
+msgstr[0] ""
+msgstr[1] ""
 
-#: builtin/blame.c:786
-msgid "Show blame entries as we find them, incrementally"
+#: remote.c:2043
+msgid "  (use \"git push\" to publish your local commits)\n"
 msgstr ""
 
-#: builtin/blame.c:787
-msgid "Show blank SHA-1 for boundary commits (Default: off)"
-msgstr ""
+#: remote.c:2046
+#, c-format
+msgid "Your branch is behind '%s' by %d commit, and can be fast-forwarded.\n"
+msgid_plural ""
+"Your branch is behind '%s' by %d commits, and can be fast-forwarded.\n"
+msgstr[0] ""
+msgstr[1] ""
 
-#: builtin/blame.c:788
-msgid "Do not treat root commits as boundaries (Default: off)"
+#: remote.c:2054
+msgid "  (use \"git pull\" to update your local branch)\n"
 msgstr ""
 
-#: builtin/blame.c:789
-msgid "Show work cost statistics"
-msgstr ""
+#: remote.c:2057
+#, c-format
+msgid ""
+"Your branch and '%s' have diverged,\n"
+"and have %d and %d different commit each, respectively.\n"
+msgid_plural ""
+"Your branch and '%s' have diverged,\n"
+"and have %d and %d different commits each, respectively.\n"
+msgstr[0] ""
+msgstr[1] ""
 
-#: builtin/blame.c:790
-msgid "Force progress reporting"
+#: remote.c:2067
+msgid "  (use \"git pull\" to merge the remote branch into yours)\n"
 msgstr ""
 
-#: builtin/blame.c:791
-msgid "Show output score for blame entries"
+#: remote.c:2250
+#, c-format
+msgid "cannot parse expected object name '%s'"
 msgstr ""
 
-#: builtin/blame.c:792
-msgid "Show original filename (Default: auto)"
+#: replace-object.c:21
+#, c-format
+msgid "bad replace ref name: %s"
 msgstr ""
 
-#: builtin/blame.c:793
-msgid "Show original linenumber (Default: off)"
+#: replace-object.c:30
+#, c-format
+msgid "duplicate replace ref: %s"
 msgstr ""
 
-#: builtin/blame.c:794
-msgid "Show in a format designed for machine consumption"
+#: replace-object.c:73
+#, c-format
+msgid "replace depth too high for object %s"
 msgstr ""
 
-#: builtin/blame.c:795
-msgid "Show porcelain format with per-line commit information"
+#: rerere.c:217 rerere.c:226 rerere.c:229
+msgid "corrupt MERGE_RR"
 msgstr ""
 
-#: builtin/blame.c:796
-msgid "Use the same output mode as git-annotate (Default: off)"
+#: rerere.c:264 rerere.c:269
+msgid "unable to write rerere record"
 msgstr ""
 
-#: builtin/blame.c:797
-msgid "Show raw timestamp (Default: off)"
+#: rerere.c:495
+#, c-format
+msgid "there were errors while writing '%s' (%s)"
 msgstr ""
 
-#: builtin/blame.c:798
-msgid "Show long commit SHA1 (Default: off)"
+#: rerere.c:498
+#, c-format
+msgid "failed to flush '%s'"
 msgstr ""
 
-#: builtin/blame.c:799
-msgid "Suppress author name and timestamp (Default: off)"
+#: rerere.c:503 rerere.c:1039
+#, c-format
+msgid "could not parse conflict hunks in '%s'"
 msgstr ""
 
-#: builtin/blame.c:800
-msgid "Show author email instead of name (Default: off)"
+#: rerere.c:684
+#, c-format
+msgid "failed utime() on '%s'"
 msgstr ""
 
-#: builtin/blame.c:801
-msgid "Ignore whitespace differences"
+#: rerere.c:694
+#, c-format
+msgid "writing '%s' failed"
 msgstr ""
 
-#: builtin/blame.c:802
-msgid "color redundant metadata from previous line differently"
+#: rerere.c:714
+#, c-format
+msgid "Staged '%s' using previous resolution."
 msgstr ""
 
-#: builtin/blame.c:803
-msgid "color lines by age"
+#: rerere.c:753
+#, c-format
+msgid "Recorded resolution for '%s'."
 msgstr ""
 
-#: builtin/blame.c:810
-msgid "Use an experimental heuristic to improve diffs"
+#: rerere.c:788
+#, c-format
+msgid "Resolved '%s' using previous resolution."
 msgstr ""
 
-#: builtin/blame.c:812
-msgid "Spend extra cycles to find better match"
+#: rerere.c:803
+#, c-format
+msgid "cannot unlink stray '%s'"
 msgstr ""
 
-#: builtin/blame.c:813
-msgid "Use revisions from <file> instead of calling git-rev-list"
+#: rerere.c:807
+#, c-format
+msgid "Recorded preimage for '%s'"
 msgstr ""
 
-#: builtin/blame.c:814
-msgid "Use <file>'s contents as the final image"
+#: rerere.c:881 submodule.c:2067 builtin/log.c:1871
+#: builtin/submodule--helper.c:1436 builtin/submodule--helper.c:1448
+#, c-format
+msgid "could not create directory '%s'"
 msgstr ""
 
-#: builtin/blame.c:815 builtin/blame.c:816
-msgid "score"
+#: rerere.c:1057
+#, c-format
+msgid "failed to update conflicted state in '%s'"
 msgstr ""
 
-#: builtin/blame.c:815
-msgid "Find line copies within and across files"
+#: rerere.c:1068 rerere.c:1075
+#, c-format
+msgid "no remembered resolution for '%s'"
 msgstr ""
 
-#: builtin/blame.c:816
-msgid "Find line movements within and across files"
+#: rerere.c:1077
+#, c-format
+msgid "cannot unlink '%s'"
 msgstr ""
 
-#: builtin/blame.c:817
-msgid "n,m"
+#: rerere.c:1087
+#, c-format
+msgid "Updated preimage for '%s'"
 msgstr ""
 
-#: builtin/blame.c:817
-msgid "Process only line range n,m, counting from 1"
+#: rerere.c:1096
+#, c-format
+msgid "Forgot resolution for '%s'\n"
 msgstr ""
 
-#: builtin/blame.c:866
-msgid "--progress can't be used with --incremental or porcelain formats"
+#: rerere.c:1199
+msgid "unable to open rr-cache directory"
 msgstr ""
 
-#. TRANSLATORS: This string is used to tell us the
-#. maximum display width for a relative timestamp in
-#. "git blame" output.  For C locale, "4 years, 11
-#. months ago", which takes 22 places, is the longest
-#. among various forms of relative timestamps, but
-#. your language may need more or fewer display
-#. columns.
-#.
-#: builtin/blame.c:917
-msgid "4 years, 11 months ago"
+#: revision.c:2497
+msgid "your current branch appears to be broken"
 msgstr ""
 
-#: builtin/blame.c:1003
+#: revision.c:2500
 #, c-format
-msgid "file %s has only %lu line"
-msgid_plural "file %s has only %lu lines"
-msgstr[0] ""
-msgstr[1] ""
+msgid "your current branch '%s' does not have any commits yet"
+msgstr ""
 
-#: builtin/blame.c:1049
-msgid "Blaming lines"
+#: revision.c:2708
+msgid "--first-parent is incompatible with --bisect"
 msgstr ""
 
-#: builtin/branch.c:27
-msgid "git branch [<options>] [-r | -a] [--merged | --no-merged]"
+#: revision.c:2712
+msgid "-L does not yet support diff formats besides -p and -s"
 msgstr ""
 
-#: builtin/branch.c:28
-msgid "git branch [<options>] [-l] [-f] <branch-name> [<start-point>]"
-msgstr ""
-
-#: builtin/branch.c:29
-msgid "git branch [<options>] [-r] (-d | -D) <branch-name>..."
-msgstr ""
-
-#: builtin/branch.c:30
-msgid "git branch [<options>] (-m | -M) [<old-branch>] <new-branch>"
+#: run-command.c:762
+msgid "open /dev/null failed"
 msgstr ""
 
-#: builtin/branch.c:31
-msgid "git branch [<options>] (-c | -C) [<old-branch>] <new-branch>"
+#: run-command.c:1268
+#, c-format
+msgid "cannot create async thread: %s"
 msgstr ""
 
-#: builtin/branch.c:32
-msgid "git branch [<options>] [-r | -a] [--points-at]"
+#: run-command.c:1332
+#, c-format
+msgid ""
+"The '%s' hook was ignored because it's not set as executable.\n"
+"You can disable this warning with `git config advice.ignoredHook false`."
 msgstr ""
 
-#: builtin/branch.c:33
-msgid "git branch [<options>] [-r | -a] [--format]"
+#: send-pack.c:144
+msgid "unexpected flush packet while reading remote unpack status"
 msgstr ""
 
-#: builtin/branch.c:146
+#: send-pack.c:146
 #, c-format
-msgid ""
-"deleting branch '%s' that has been merged to\n"
-"         '%s', but not yet merged to HEAD."
+msgid "unable to parse remote unpack status: %s"
 msgstr ""
 
-#: builtin/branch.c:150
+#: send-pack.c:148
 #, c-format
-msgid ""
-"not deleting branch '%s' that is not yet merged to\n"
-"         '%s', even though it is merged to HEAD."
+msgid "remote unpack failed: %s"
 msgstr ""
 
-#: builtin/branch.c:164
-#, c-format
-msgid "Couldn't look up commit object for '%s'"
+#: send-pack.c:309
+msgid "failed to sign the push certificate"
 msgstr ""
 
-#: builtin/branch.c:168
-#, c-format
-msgid ""
-"The branch '%s' is not fully merged.\n"
-"If you are sure you want to delete it, run 'git branch -D %s'."
+#: send-pack.c:423
+msgid "the receiving end does not support --signed push"
 msgstr ""
 
-#: builtin/branch.c:181
-msgid "Update of config-file failed"
+#: send-pack.c:425
+msgid ""
+"not sending a push certificate since the receiving end does not support --"
+"signed push"
 msgstr ""
 
-#: builtin/branch.c:212
-msgid "cannot use -a with -d"
+#: send-pack.c:437
+msgid "the receiving end does not support --atomic push"
 msgstr ""
 
-#: builtin/branch.c:218
-msgid "Couldn't look up commit object for HEAD"
+#: send-pack.c:442
+msgid "the receiving end does not support push options"
 msgstr ""
 
-#: builtin/branch.c:232
+#: sequencer.c:189
 #, c-format
-msgid "Cannot delete branch '%s' checked out at '%s'"
+msgid "invalid commit message cleanup mode '%s'"
 msgstr ""
 
-#: builtin/branch.c:247
+#: sequencer.c:294
 #, c-format
-msgid "remote-tracking branch '%s' not found."
+msgid "could not delete '%s'"
 msgstr ""
 
-#: builtin/branch.c:248
+#: sequencer.c:313 builtin/rebase.c:781 builtin/rebase.c:1706 builtin/rm.c:369
 #, c-format
-msgid "branch '%s' not found."
+msgid "could not remove '%s'"
 msgstr ""
 
-#: builtin/branch.c:263
-#, c-format
-msgid "Error deleting remote-tracking branch '%s'"
+#: sequencer.c:323
+msgid "revert"
 msgstr ""
 
-#: builtin/branch.c:264
-#, c-format
-msgid "Error deleting branch '%s'"
+#: sequencer.c:325
+msgid "cherry-pick"
 msgstr ""
 
-#: builtin/branch.c:271
-#, c-format
-msgid "Deleted remote-tracking branch %s (was %s).\n"
+#: sequencer.c:327
+msgid "rebase -i"
 msgstr ""
 
-#: builtin/branch.c:272
+#: sequencer.c:329
 #, c-format
-msgid "Deleted branch %s (was %s).\n"
+msgid "unknown action: %d"
 msgstr ""
 
-#: builtin/branch.c:416 builtin/tag.c:58
-msgid "unable to parse format string"
+#: sequencer.c:387
+msgid ""
+"after resolving the conflicts, mark the corrected paths\n"
+"with 'git add <paths>' or 'git rm <paths>'"
 msgstr ""
 
-#: builtin/branch.c:453
-#, c-format
-msgid "Branch %s is being rebased at %s"
+#: sequencer.c:390
+msgid ""
+"after resolving the conflicts, mark the corrected paths\n"
+"with 'git add <paths>' or 'git rm <paths>'\n"
+"and commit the result with 'git commit'"
 msgstr ""
 
-#: builtin/branch.c:457
+#: sequencer.c:403 sequencer.c:2993
 #, c-format
-msgid "Branch %s is being bisected at %s"
+msgid "could not lock '%s'"
 msgstr ""
 
-#: builtin/branch.c:474
-msgid "cannot copy the current branch while not on any."
+#: sequencer.c:410
+#, c-format
+msgid "could not write eol to '%s'"
 msgstr ""
 
-#: builtin/branch.c:476
-msgid "cannot rename the current branch while not on any."
+#: sequencer.c:415 sequencer.c:2798 sequencer.c:2999 sequencer.c:3013
+#: sequencer.c:3277
+#, c-format
+msgid "failed to finalize '%s'"
 msgstr ""
 
-#: builtin/branch.c:487
+#: sequencer.c:438 sequencer.c:1707 sequencer.c:2818 sequencer.c:3259
+#: sequencer.c:3368 builtin/am.c:244 builtin/commit.c:783 builtin/merge.c:1117
+#: builtin/rebase.c:589
 #, c-format
-msgid "Invalid branch name: '%s'"
+msgid "could not read '%s'"
 msgstr ""
 
-#: builtin/branch.c:514
-msgid "Branch rename failed"
+#: sequencer.c:464
+#, c-format
+msgid "your local changes would be overwritten by %s."
 msgstr ""
 
-#: builtin/branch.c:516
-msgid "Branch copy failed"
+#: sequencer.c:468
+msgid "commit your changes or stash them to proceed."
 msgstr ""
 
-#: builtin/branch.c:520
+#: sequencer.c:500
 #, c-format
-msgid "Created a copy of a misnamed branch '%s'"
+msgid "%s: fast-forward"
 msgstr ""
 
-#: builtin/branch.c:523
+#: sequencer.c:539 builtin/tag.c:565
 #, c-format
-msgid "Renamed a misnamed branch '%s' away"
+msgid "Invalid cleanup mode %s"
 msgstr ""
 
-#: builtin/branch.c:529
+#. TRANSLATORS: %s will be "revert", "cherry-pick" or
+#. "rebase -i".
+#.
+#: sequencer.c:633
 #, c-format
-msgid "Branch renamed to %s, but HEAD is not updated!"
+msgid "%s: Unable to write new index file"
 msgstr ""
 
-#: builtin/branch.c:538
-msgid "Branch is renamed, but update of config-file failed"
+#: sequencer.c:650
+msgid "unable to update cache tree"
 msgstr ""
 
-#: builtin/branch.c:540
-msgid "Branch is copied, but update of config-file failed"
+#: sequencer.c:664
+msgid "could not resolve HEAD commit"
 msgstr ""
 
-#: builtin/branch.c:556
+#: sequencer.c:744
 #, c-format
-msgid ""
-"Please edit the description for the branch\n"
-"  %s\n"
-"Lines starting with '%c' will be stripped.\n"
+msgid "no key present in '%.*s'"
 msgstr ""
 
-#: builtin/branch.c:589
-msgid "Generic options"
+#: sequencer.c:755
+#, c-format
+msgid "unable to dequote value of '%s'"
 msgstr ""
 
-#: builtin/branch.c:591
-msgid "show hash and subject, give twice for upstream branch"
+#: sequencer.c:792 wrapper.c:190 wrapper.c:360 builtin/am.c:705
+#: builtin/am.c:797 builtin/merge.c:1114 builtin/rebase.c:1074
+#, c-format
+msgid "could not open '%s' for reading"
 msgstr ""
 
-#: builtin/branch.c:592
-msgid "suppress informational messages"
+#: sequencer.c:802
+msgid "'GIT_AUTHOR_NAME' already given"
 msgstr ""
 
-#: builtin/branch.c:593
-msgid "set up tracking mode (see git-pull(1))"
+#: sequencer.c:807
+msgid "'GIT_AUTHOR_EMAIL' already given"
 msgstr ""
 
-#: builtin/branch.c:595
-msgid "do not use"
+#: sequencer.c:812
+msgid "'GIT_AUTHOR_DATE' already given"
 msgstr ""
 
-#: builtin/branch.c:597
-msgid "upstream"
+#: sequencer.c:816
+#, c-format
+msgid "unknown variable '%s'"
 msgstr ""
 
-#: builtin/branch.c:597
-msgid "change the upstream info"
+#: sequencer.c:821
+msgid "missing 'GIT_AUTHOR_NAME'"
 msgstr ""
 
-#: builtin/branch.c:598
-msgid "Unset the upstream info"
+#: sequencer.c:823
+msgid "missing 'GIT_AUTHOR_EMAIL'"
 msgstr ""
 
-#: builtin/branch.c:599
-msgid "use colored output"
+#: sequencer.c:825
+msgid "missing 'GIT_AUTHOR_DATE'"
 msgstr ""
 
-#: builtin/branch.c:600
-msgid "act on remote-tracking branches"
+#: sequencer.c:902 sequencer.c:1427
+msgid "malformed ident line"
 msgstr ""
 
-#: builtin/branch.c:602 builtin/branch.c:604
-msgid "print only branches that contain the commit"
+#: sequencer.c:925
+#, c-format
+msgid ""
+"you have staged changes in your working tree\n"
+"If these changes are meant to be squashed into the previous commit, run:\n"
+"\n"
+"  git commit --amend %s\n"
+"\n"
+"If they are meant to go into a new commit, run:\n"
+"\n"
+"  git commit %s\n"
+"\n"
+"In both cases, once you're done, continue with:\n"
+"\n"
+"  git rebase --continue\n"
 msgstr ""
 
-#: builtin/branch.c:603 builtin/branch.c:605
-msgid "print only branches that don't contain the commit"
+#: sequencer.c:1218
+msgid "'prepare-commit-msg' hook failed"
 msgstr ""
 
-#: builtin/branch.c:608
-msgid "Specific git-branch actions:"
+#: sequencer.c:1224
+msgid ""
+"Your name and email address were configured automatically based\n"
+"on your username and hostname. Please check that they are accurate.\n"
+"You can suppress this message by setting them explicitly. Run the\n"
+"following command and follow the instructions in your editor to edit\n"
+"your configuration file:\n"
+"\n"
+"    git config --global --edit\n"
+"\n"
+"After doing this, you may fix the identity used for this commit with:\n"
+"\n"
+"    git commit --amend --reset-author\n"
 msgstr ""
 
-#: builtin/branch.c:609
-msgid "list both remote-tracking and local branches"
+#: sequencer.c:1237
+msgid ""
+"Your name and email address were configured automatically based\n"
+"on your username and hostname. Please check that they are accurate.\n"
+"You can suppress this message by setting them explicitly:\n"
+"\n"
+"    git config --global user.name \"Your Name\"\n"
+"    git config --global user.email you@example.com\n"
+"\n"
+"After doing this, you may fix the identity used for this commit with:\n"
+"\n"
+"    git commit --amend --reset-author\n"
 msgstr ""
 
-#: builtin/branch.c:611
-msgid "delete fully merged branch"
+#: sequencer.c:1279
+msgid "couldn't look up newly created commit"
 msgstr ""
 
-#: builtin/branch.c:612
-msgid "delete branch (even if not merged)"
+#: sequencer.c:1281
+msgid "could not parse newly created commit"
 msgstr ""
 
-#: builtin/branch.c:613
-msgid "move/rename a branch and its reflog"
+#: sequencer.c:1327
+msgid "unable to resolve HEAD after creating commit"
 msgstr ""
 
-#: builtin/branch.c:614
-msgid "move/rename a branch, even if target exists"
+#: sequencer.c:1329
+msgid "detached HEAD"
 msgstr ""
 
-#: builtin/branch.c:615
-msgid "copy a branch and its reflog"
+#: sequencer.c:1333
+msgid " (root-commit)"
 msgstr ""
 
-#: builtin/branch.c:616
-msgid "copy a branch, even if target exists"
+#: sequencer.c:1354
+msgid "could not parse HEAD"
 msgstr ""
 
-#: builtin/branch.c:617
-msgid "list branch names"
+#: sequencer.c:1356
+#, c-format
+msgid "HEAD %s is not a commit!"
 msgstr ""
 
-#: builtin/branch.c:618
-msgid "create the branch's reflog"
+#: sequencer.c:1360 sequencer.c:1458 builtin/commit.c:1569
+msgid "could not parse HEAD commit"
 msgstr ""
 
-#: builtin/branch.c:620
-msgid "edit the description for the branch"
+#: sequencer.c:1411 sequencer.c:2055
+msgid "unable to parse commit author"
 msgstr ""
 
-#: builtin/branch.c:621
-msgid "force creation, move/rename, deletion"
+#: sequencer.c:1431
+msgid "corrupted author without date information"
 msgstr ""
 
-#: builtin/branch.c:622
-msgid "print only branches that are merged"
+#: sequencer.c:1447 builtin/am.c:1561 builtin/merge.c:684
+msgid "git write-tree failed to write a tree"
 msgstr ""
 
-#: builtin/branch.c:623
-msgid "print only branches that are not merged"
+#: sequencer.c:1480 sequencer.c:1550
+#, c-format
+msgid "unable to read commit message from '%s'"
 msgstr ""
 
-#: builtin/branch.c:624
-msgid "list branches in columns"
+#: sequencer.c:1516 builtin/am.c:1583 builtin/commit.c:1668 builtin/merge.c:883
+#: builtin/merge.c:908
+msgid "failed to write commit object"
 msgstr ""
 
-#: builtin/branch.c:625 builtin/for-each-ref.c:40 builtin/ls-remote.c:70
-#: builtin/tag.c:412
-msgid "key"
+#: sequencer.c:1577
+#, c-format
+msgid "could not parse commit %s"
 msgstr ""
 
-#: builtin/branch.c:626 builtin/for-each-ref.c:41 builtin/ls-remote.c:71
-#: builtin/tag.c:413
-msgid "field name to sort on"
+#: sequencer.c:1582
+#, c-format
+msgid "could not parse parent commit %s"
 msgstr ""
 
-#: builtin/branch.c:628 builtin/for-each-ref.c:43 builtin/notes.c:408
-#: builtin/notes.c:411 builtin/notes.c:571 builtin/notes.c:574
-#: builtin/tag.c:415
-msgid "object"
+#: sequencer.c:1656 sequencer.c:1767
+#, c-format
+msgid "unknown command: %d"
 msgstr ""
 
-#: builtin/branch.c:629
-msgid "print only branches of the object"
+#: sequencer.c:1714 sequencer.c:1739
+#, c-format
+msgid "This is a combination of %d commits."
 msgstr ""
 
-#: builtin/branch.c:631 builtin/for-each-ref.c:49 builtin/tag.c:422
-msgid "sorting and filtering are case insensitive"
+#: sequencer.c:1724
+msgid "need a HEAD to fixup"
 msgstr ""
 
-#: builtin/branch.c:632 builtin/for-each-ref.c:38 builtin/tag.c:420
-#: builtin/verify-tag.c:39
-msgid "format to use for the output"
+#: sequencer.c:1726 sequencer.c:3304
+msgid "could not read HEAD"
 msgstr ""
 
-#: builtin/branch.c:655 builtin/clone.c:737
-msgid "HEAD not found below refs/heads!"
+#: sequencer.c:1728
+msgid "could not read HEAD's commit message"
 msgstr ""
 
-#: builtin/branch.c:678
-msgid "--column and --verbose are incompatible"
+#: sequencer.c:1734
+#, c-format
+msgid "cannot write '%s'"
 msgstr ""
 
-#: builtin/branch.c:693 builtin/branch.c:745 builtin/branch.c:754
-msgid "branch name required"
+#: sequencer.c:1741 git-rebase--preserve-merges.sh:496
+msgid "This is the 1st commit message:"
 msgstr ""
 
-#: builtin/branch.c:721
-msgid "Cannot give description to detached HEAD"
+#: sequencer.c:1749
+#, c-format
+msgid "could not read commit message of %s"
 msgstr ""
 
-#: builtin/branch.c:726
-msgid "cannot edit description of more than one branch"
+#: sequencer.c:1756
+#, c-format
+msgid "This is the commit message #%d:"
 msgstr ""
 
-#: builtin/branch.c:733
+#: sequencer.c:1762
 #, c-format
-msgid "No commit on branch '%s' yet."
+msgid "The commit message #%d will be skipped:"
 msgstr ""
 
-#: builtin/branch.c:736
-#, c-format
-msgid "No branch named '%s'."
+#: sequencer.c:1850
+msgid "your index file is unmerged."
 msgstr ""
 
-#: builtin/branch.c:751
-msgid "too many branches for a copy operation"
+#: sequencer.c:1857
+msgid "cannot fixup root commit"
 msgstr ""
 
-#: builtin/branch.c:760
-msgid "too many arguments for a rename operation"
+#: sequencer.c:1876
+#, c-format
+msgid "commit %s is a merge but no -m option was given."
 msgstr ""
 
-#: builtin/branch.c:765
-msgid "too many arguments to set new upstream"
+#: sequencer.c:1884 sequencer.c:1892
+#, c-format
+msgid "commit %s does not have parent %d"
 msgstr ""
 
-#: builtin/branch.c:769
+#: sequencer.c:1898
 #, c-format
-msgid ""
-"could not set upstream of HEAD to %s when it does not point to any branch."
+msgid "cannot get commit message for %s"
 msgstr ""
 
-#: builtin/branch.c:772 builtin/branch.c:794 builtin/branch.c:810
+#. TRANSLATORS: The first %s will be a "todo" command like
+#. "revert" or "pick", the second %s a SHA1.
+#: sequencer.c:1917
 #, c-format
-msgid "no such branch '%s'"
+msgid "%s: cannot parse parent commit %s"
 msgstr ""
 
-#: builtin/branch.c:776
+#: sequencer.c:1982
 #, c-format
-msgid "branch '%s' does not exist"
+msgid "could not rename '%s' to '%s'"
 msgstr ""
 
-#: builtin/branch.c:788
-msgid "too many arguments to unset upstream"
+#: sequencer.c:2037
+#, c-format
+msgid "could not revert %s... %s"
 msgstr ""
 
-#: builtin/branch.c:792
-msgid "could not unset upstream of HEAD when it does not point to any branch."
+#: sequencer.c:2038
+#, c-format
+msgid "could not apply %s... %s"
 msgstr ""
 
-#: builtin/branch.c:798
+#: sequencer.c:2105
 #, c-format
-msgid "Branch '%s' has no upstream information"
+msgid "git %s: failed to read the index"
 msgstr ""
 
-#: builtin/branch.c:813
-msgid "-a and -r options to 'git branch' do not make sense with a branch name"
+#: sequencer.c:2112
+#, c-format
+msgid "git %s: failed to refresh the index"
 msgstr ""
 
-#: builtin/branch.c:816
-msgid ""
-"the '--set-upstream' option is no longer supported. Please use '--track' or "
-"'--set-upstream-to' instead."
+#: sequencer.c:2189
+#, c-format
+msgid "%s does not accept arguments: '%s'"
 msgstr ""
 
-#: builtin/bundle.c:45
+#: sequencer.c:2198
 #, c-format
-msgid "%s is okay\n"
+msgid "missing arguments for %s"
 msgstr ""
 
-#: builtin/bundle.c:58
-msgid "Need a repository to create a bundle."
+#: sequencer.c:2235
+#, c-format
+msgid "could not parse '%.*s'"
 msgstr ""
 
-#: builtin/bundle.c:62
-msgid "Need a repository to unbundle."
+#: sequencer.c:2289
+#, c-format
+msgid "invalid line %d: %.*s"
 msgstr ""
 
-#: builtin/cat-file.c:525
-msgid ""
-"git cat-file (-t [--allow-unknown-type] | -s [--allow-unknown-type] | -e | -"
-"p | <type> | --textconv | --filters) [--path=<path>] <object>"
+#: sequencer.c:2300
+#, c-format
+msgid "cannot '%s' without a previous commit"
 msgstr ""
 
-#: builtin/cat-file.c:526
-msgid ""
-"git cat-file (--batch | --batch-check) [--follow-symlinks] [--textconv | --"
-"filters]"
+#: sequencer.c:2348 builtin/rebase.c:172 builtin/rebase.c:197
+#: builtin/rebase.c:223 builtin/rebase.c:248
+#, c-format
+msgid "could not read '%s'."
 msgstr ""
 
-#: builtin/cat-file.c:563
-msgid "<type> can be one of: blob, tree, commit, tag"
+#: sequencer.c:2384
+msgid "cancelling a cherry picking in progress"
 msgstr ""
 
-#: builtin/cat-file.c:564
-msgid "show object type"
+#: sequencer.c:2391
+msgid "cancelling a revert in progress"
 msgstr ""
 
-#: builtin/cat-file.c:565
-msgid "show object size"
+#: sequencer.c:2435
+msgid "please fix this using 'git rebase --edit-todo'."
 msgstr ""
 
-#: builtin/cat-file.c:567
-msgid "exit with zero when there's no error"
+#: sequencer.c:2437
+#, c-format
+msgid "unusable instruction sheet: '%s'"
 msgstr ""
 
-#: builtin/cat-file.c:568
-msgid "pretty-print object's content"
+#: sequencer.c:2442
+msgid "no commits parsed."
 msgstr ""
 
-#: builtin/cat-file.c:570
-msgid "for blob objects, run textconv on object's content"
+#: sequencer.c:2453
+msgid "cannot cherry-pick during a revert."
 msgstr ""
 
-#: builtin/cat-file.c:572
-msgid "for blob objects, run filters on object's content"
+#: sequencer.c:2455
+msgid "cannot revert during a cherry-pick."
 msgstr ""
 
-#: builtin/cat-file.c:573 git-submodule.sh:894
-msgid "blob"
+#: sequencer.c:2533
+#, c-format
+msgid "invalid value for %s: %s"
 msgstr ""
 
-#: builtin/cat-file.c:574
-msgid "use a specific path for --textconv/--filters"
+#: sequencer.c:2630
+msgid "unusable squash-onto"
 msgstr ""
 
-#: builtin/cat-file.c:576
-msgid "allow -s and -t to work with broken/corrupt objects"
+#: sequencer.c:2646
+#, c-format
+msgid "malformed options sheet: '%s'"
 msgstr ""
 
-#: builtin/cat-file.c:577
-msgid "buffer --batch output"
+#: sequencer.c:2736 sequencer.c:4463
+msgid "empty commit set passed"
 msgstr ""
 
-#: builtin/cat-file.c:579
-msgid "show info and content of objects fed from the standard input"
+#: sequencer.c:2752
+msgid "revert is already in progress"
 msgstr ""
 
-#: builtin/cat-file.c:582
-msgid "show info about objects fed from the standard input"
+#: sequencer.c:2754
+#, c-format
+msgid "try \"git revert (--continue | %s--abort | --quit)\""
 msgstr ""
 
-#: builtin/cat-file.c:585
-msgid "follow in-tree symlinks (used with --batch or --batch-check)"
+#: sequencer.c:2757
+msgid "cherry-pick is already in progress"
 msgstr ""
 
-#: builtin/cat-file.c:587
-msgid "show all objects with --batch or --batch-check"
+#: sequencer.c:2759
+#, c-format
+msgid "try \"git cherry-pick (--continue | %s--abort | --quit)\""
 msgstr ""
 
-#: builtin/check-attr.c:12
-msgid "git check-attr [-a | --all | <attr>...] [--] <pathname>..."
+#: sequencer.c:2773
+#, c-format
+msgid "could not create sequencer directory '%s'"
 msgstr ""
 
-#: builtin/check-attr.c:13
-msgid "git check-attr --stdin [-z] [-a | --all | <attr>...]"
+#: sequencer.c:2788
+msgid "could not lock HEAD"
 msgstr ""
 
-#: builtin/check-attr.c:20
-msgid "report all attributes set on file"
+#: sequencer.c:2848 sequencer.c:4209
+msgid "no cherry-pick or revert in progress"
 msgstr ""
 
-#: builtin/check-attr.c:21
-msgid "use .gitattributes only from the index"
+#: sequencer.c:2850 sequencer.c:2861
+msgid "cannot resolve HEAD"
 msgstr ""
 
-#: builtin/check-attr.c:22 builtin/check-ignore.c:24 builtin/hash-object.c:100
-msgid "read file names from stdin"
+#: sequencer.c:2852 sequencer.c:2896
+msgid "cannot abort from a branch yet to be born"
 msgstr ""
 
-#: builtin/check-attr.c:24 builtin/check-ignore.c:26
-msgid "terminate input and output records by a NUL character"
+#: sequencer.c:2882 builtin/grep.c:736
+#, c-format
+msgid "cannot open '%s'"
 msgstr ""
 
-#: builtin/check-ignore.c:20 builtin/checkout.c:1113 builtin/gc.c:500
-msgid "suppress progress reporting"
+#: sequencer.c:2884
+#, c-format
+msgid "cannot read '%s': %s"
 msgstr ""
 
-#: builtin/check-ignore.c:28
-msgid "show non-matching input paths"
+#: sequencer.c:2885
+msgid "unexpected end of file"
 msgstr ""
 
-#: builtin/check-ignore.c:30
-msgid "ignore index when checking"
+#: sequencer.c:2891
+#, c-format
+msgid "stored pre-cherry-pick HEAD file '%s' is corrupt"
 msgstr ""
 
-#: builtin/check-ignore.c:159
-msgid "cannot specify pathnames with --stdin"
+#: sequencer.c:2902
+msgid "You seem to have moved HEAD. Not rewinding, check your HEAD!"
 msgstr ""
 
-#: builtin/check-ignore.c:162
-msgid "-z only makes sense with --stdin"
+#: sequencer.c:2943
+msgid "no revert in progress"
 msgstr ""
 
-#: builtin/check-ignore.c:164
-msgid "no path specified"
+#: sequencer.c:2951
+msgid "no cherry-pick in progress"
 msgstr ""
 
-#: builtin/check-ignore.c:168
-msgid "--quiet is only valid with a single pathname"
+#: sequencer.c:2961
+msgid "failed to skip the commit"
 msgstr ""
 
-#: builtin/check-ignore.c:170
-msgid "cannot have both --quiet and --verbose"
+#: sequencer.c:2968
+msgid "there is nothing to skip"
 msgstr ""
 
-#: builtin/check-ignore.c:173
-msgid "--non-matching is only valid with --verbose"
+#: sequencer.c:2971
+#, c-format
+msgid ""
+"have you committed already?\n"
+"try \"git %s --continue\""
 msgstr ""
 
-#: builtin/check-mailmap.c:9
-msgid "git check-mailmap [<options>] <contact>..."
+#: sequencer.c:3095 sequencer.c:4121
+#, c-format
+msgid "could not update %s"
 msgstr ""
 
-#: builtin/check-mailmap.c:14
-msgid "also read contacts from stdin"
+#: sequencer.c:3134 sequencer.c:4101
+msgid "cannot read HEAD"
 msgstr ""
 
-#: builtin/check-mailmap.c:25
+#: sequencer.c:3151
 #, c-format
-msgid "unable to parse contact: %s"
+msgid "unable to copy '%s' to '%s'"
 msgstr ""
 
-#: builtin/check-mailmap.c:48
-msgid "no contacts specified"
+#: sequencer.c:3159
+#, c-format
+msgid ""
+"You can amend the commit now, with\n"
+"\n"
+"  git commit --amend %s\n"
+"\n"
+"Once you are satisfied with your changes, run\n"
+"\n"
+"  git rebase --continue\n"
 msgstr ""
 
-#: builtin/checkout-index.c:128
-msgid "git checkout-index [<options>] [--] [<file>...]"
+#: sequencer.c:3169
+#, c-format
+msgid "Could not apply %s... %.*s"
 msgstr ""
 
-#: builtin/checkout-index.c:143
-msgid "stage should be between 1 and 3 or all"
+#: sequencer.c:3176
+#, c-format
+msgid "Could not merge %.*s"
 msgstr ""
 
-#: builtin/checkout-index.c:159
-msgid "check out all files in the index"
+#: sequencer.c:3190 sequencer.c:3194 builtin/difftool.c:641
+#, c-format
+msgid "could not copy '%s' to '%s'"
 msgstr ""
 
-#: builtin/checkout-index.c:160
-msgid "force overwrite of existing files"
+#: sequencer.c:3221
+#, c-format
+msgid ""
+"execution failed: %s\n"
+"%sYou can fix the problem, and then run\n"
+"\n"
+"  git rebase --continue\n"
+"\n"
 msgstr ""
 
-#: builtin/checkout-index.c:162
-msgid "no warning for existing files and files not in index"
+#: sequencer.c:3227
+msgid "and made changes to the index and/or the working tree\n"
 msgstr ""
 
-#: builtin/checkout-index.c:164
-msgid "don't checkout new files"
+#: sequencer.c:3233
+#, c-format
+msgid ""
+"execution succeeded: %s\n"
+"but left changes to the index and/or the working tree\n"
+"Commit or stash your changes, and then run\n"
+"\n"
+"  git rebase --continue\n"
+"\n"
 msgstr ""
 
-#: builtin/checkout-index.c:166
-msgid "update stat information in the index file"
+#: sequencer.c:3294
+#, c-format
+msgid "illegal label name: '%.*s'"
 msgstr ""
 
-#: builtin/checkout-index.c:170
-msgid "read list of paths from the standard input"
+#: sequencer.c:3348
+msgid "writing fake root commit"
 msgstr ""
 
-#: builtin/checkout-index.c:172
-msgid "write the content to temporary files"
+#: sequencer.c:3353
+msgid "writing squash-onto"
 msgstr ""
 
-#: builtin/checkout-index.c:173 builtin/column.c:31
-#: builtin/submodule--helper.c:1216 builtin/submodule--helper.c:1219
-#: builtin/submodule--helper.c:1227 builtin/submodule--helper.c:1591
-#: builtin/worktree.c:610
-msgid "string"
+#: sequencer.c:3391 builtin/rebase.c:876 builtin/rebase.c:882
+#, c-format
+msgid "failed to find tree of %s"
 msgstr ""
 
-#: builtin/checkout-index.c:174
-msgid "when creating files, prepend <string>"
+#: sequencer.c:3436
+#, c-format
+msgid "could not resolve '%s'"
 msgstr ""
 
-#: builtin/checkout-index.c:176
-msgid "copy out the files from named stage"
+#: sequencer.c:3467
+msgid "cannot merge without a current revision"
 msgstr ""
 
-#: builtin/checkout.c:27
-msgid "git checkout [<options>] <branch>"
+#: sequencer.c:3489
+#, c-format
+msgid "unable to parse '%.*s'"
 msgstr ""
 
-#: builtin/checkout.c:28
-msgid "git checkout [<options>] [<branch>] -- <file>..."
+#: sequencer.c:3498
+#, c-format
+msgid "nothing to merge: '%.*s'"
 msgstr ""
 
-#: builtin/checkout.c:136 builtin/checkout.c:169
-#, c-format
-msgid "path '%s' does not have our version"
+#: sequencer.c:3510
+msgid "octopus merge cannot be executed on top of a [new root]"
 msgstr ""
 
-#: builtin/checkout.c:138 builtin/checkout.c:171
+#: sequencer.c:3526
 #, c-format
-msgid "path '%s' does not have their version"
+msgid "could not get commit message of '%s'"
 msgstr ""
 
-#: builtin/checkout.c:154
+#: sequencer.c:3688
 #, c-format
-msgid "path '%s' does not have all necessary versions"
+msgid "could not even attempt to merge '%.*s'"
+msgstr ""
+
+#: sequencer.c:3704
+msgid "merge: Unable to write new index file"
 msgstr ""
 
-#: builtin/checkout.c:198
+#: sequencer.c:3773 builtin/rebase.c:733
 #, c-format
-msgid "path '%s' does not have necessary versions"
+msgid "Applied autostash.\n"
 msgstr ""
 
-#: builtin/checkout.c:215
+#: sequencer.c:3785
 #, c-format
-msgid "path '%s': cannot merge"
+msgid "cannot store %s"
 msgstr ""
 
-#: builtin/checkout.c:231
+#: sequencer.c:3788 builtin/rebase.c:749 git-rebase--preserve-merges.sh:113
 #, c-format
-msgid "Unable to add merge result for '%s'"
+msgid ""
+"Applying autostash resulted in conflicts.\n"
+"Your changes are safe in the stash.\n"
+"You can run \"git stash pop\" or \"git stash drop\" at any time.\n"
 msgstr ""
 
-#: builtin/checkout.c:253 builtin/checkout.c:256 builtin/checkout.c:259
-#: builtin/checkout.c:262
+#: sequencer.c:3849
 #, c-format
-msgid "'%s' cannot be used with updating paths"
+msgid "could not checkout %s"
 msgstr ""
 
-#: builtin/checkout.c:265 builtin/checkout.c:268
+#: sequencer.c:3863
 #, c-format
-msgid "'%s' cannot be used with %s"
+msgid "%s: not a valid OID"
+msgstr ""
+
+#: sequencer.c:3868 git-rebase--preserve-merges.sh:779
+msgid "could not detach HEAD"
 msgstr ""
 
-#: builtin/checkout.c:271
+#: sequencer.c:3883
 #, c-format
-msgid "Cannot update paths and switch to branch '%s' at the same time."
+msgid "Stopped at HEAD\n"
 msgstr ""
 
-#: builtin/checkout.c:340 builtin/checkout.c:347
+#: sequencer.c:3885
 #, c-format
-msgid "path '%s' is unmerged"
+msgid "Stopped at %s\n"
 msgstr ""
 
-#: builtin/checkout.c:506
-msgid "you need to resolve your current index first"
+#: sequencer.c:3893
+#, c-format
+msgid ""
+"Could not execute the todo command\n"
+"\n"
+"    %.*s\n"
+"It has been rescheduled; To edit the command before continuing, please\n"
+"edit the todo list first:\n"
+"\n"
+"    git rebase --edit-todo\n"
+"    git rebase --continue\n"
 msgstr ""
 
-#: builtin/checkout.c:643
+#: sequencer.c:3979
 #, c-format
-msgid "Can not do reflog for '%s': %s\n"
+msgid "Stopped at %s...  %.*s\n"
 msgstr ""
 
-#: builtin/checkout.c:684
-msgid "HEAD is now at"
+#: sequencer.c:4050
+#, c-format
+msgid "unknown command %d"
 msgstr ""
 
-#: builtin/checkout.c:688 builtin/clone.c:691
-msgid "unable to update HEAD"
+#: sequencer.c:4109
+msgid "could not read orig-head"
 msgstr ""
 
-#: builtin/checkout.c:692
-#, c-format
-msgid "Reset branch '%s'\n"
+#: sequencer.c:4114
+msgid "could not read 'onto'"
 msgstr ""
 
-#: builtin/checkout.c:695
+#: sequencer.c:4128
 #, c-format
-msgid "Already on '%s'\n"
+msgid "could not update HEAD to %s"
 msgstr ""
 
-#: builtin/checkout.c:699
-#, c-format
-msgid "Switched to and reset branch '%s'\n"
+#: sequencer.c:4221
+msgid "cannot rebase: You have unstaged changes."
 msgstr ""
 
-#: builtin/checkout.c:701 builtin/checkout.c:1046
-#, c-format
-msgid "Switched to a new branch '%s'\n"
+#: sequencer.c:4230
+msgid "cannot amend non-existing commit"
 msgstr ""
 
-#: builtin/checkout.c:703
+#: sequencer.c:4232
 #, c-format
-msgid "Switched to branch '%s'\n"
+msgid "invalid file: '%s'"
 msgstr ""
 
-#: builtin/checkout.c:754
+#: sequencer.c:4234
 #, c-format
-msgid " ... and %d more.\n"
+msgid "invalid contents: '%s'"
 msgstr ""
 
-#: builtin/checkout.c:760
-#, c-format
+#: sequencer.c:4237
 msgid ""
-"Warning: you are leaving %d commit behind, not connected to\n"
-"any of your branches:\n"
-"\n"
-"%s\n"
-msgid_plural ""
-"Warning: you are leaving %d commits behind, not connected to\n"
-"any of your branches:\n"
 "\n"
-"%s\n"
-msgstr[0] ""
-msgstr[1] ""
+"You have uncommitted changes in your working tree. Please, commit them\n"
+"first and then run 'git rebase --continue' again."
+msgstr ""
 
-#: builtin/checkout.c:779
+#: sequencer.c:4273 sequencer.c:4312
 #, c-format
-msgid ""
-"If you want to keep it by creating a new branch, this may be a good time\n"
-"to do so with:\n"
-"\n"
-" git branch <new-branch-name> %s\n"
-"\n"
-msgid_plural ""
-"If you want to keep them by creating a new branch, this may be a good time\n"
-"to do so with:\n"
-"\n"
-" git branch <new-branch-name> %s\n"
-"\n"
-msgstr[0] ""
-msgstr[1] ""
-
-#: builtin/checkout.c:811
-msgid "internal error in revision walk"
+msgid "could not write file: '%s'"
 msgstr ""
 
-#: builtin/checkout.c:815
-msgid "Previous HEAD position was"
+#: sequencer.c:4327
+msgid "could not remove CHERRY_PICK_HEAD"
 msgstr ""
 
-#: builtin/checkout.c:843 builtin/checkout.c:1041
-msgid "You are on a branch yet to be born"
+#: sequencer.c:4334
+msgid "could not commit staged changes."
 msgstr ""
 
-#: builtin/checkout.c:947
+#: sequencer.c:4440
 #, c-format
-msgid "only one reference expected, %d given."
+msgid "%s: can't cherry-pick a %s"
 msgstr ""
 
-#: builtin/checkout.c:987 builtin/worktree.c:240 builtin/worktree.c:389
+#: sequencer.c:4444
 #, c-format
-msgid "invalid reference: %s"
+msgid "%s: bad revision"
 msgstr ""
 
-#: builtin/checkout.c:1016
-#, c-format
-msgid "reference is not a tree: %s"
+#: sequencer.c:4479
+msgid "can't revert as initial commit"
 msgstr ""
 
-#: builtin/checkout.c:1055
-msgid "paths cannot be used with switching branches"
+#: sequencer.c:4952
+msgid "make_script: unhandled options"
 msgstr ""
 
-#: builtin/checkout.c:1058 builtin/checkout.c:1062
-#, c-format
-msgid "'%s' cannot be used with switching branches"
+#: sequencer.c:4955
+msgid "make_script: error preparing revisions"
 msgstr ""
 
-#: builtin/checkout.c:1066 builtin/checkout.c:1069 builtin/checkout.c:1074
-#: builtin/checkout.c:1077
-#, c-format
-msgid "'%s' cannot be used with '%s'"
+#: sequencer.c:5113
+msgid ""
+"You can fix this with 'git rebase --edit-todo' and then run 'git rebase --"
+"continue'.\n"
+"Or you can abort the rebase with 'git rebase --abort'.\n"
 msgstr ""
 
-#: builtin/checkout.c:1082
-#, c-format
-msgid "Cannot switch branch to a non-commit '%s'"
+#: sequencer.c:5226 sequencer.c:5243
+msgid "nothing to do"
 msgstr ""
 
-#: builtin/checkout.c:1114 builtin/checkout.c:1116 builtin/clone.c:118
-#: builtin/remote.c:167 builtin/remote.c:169 builtin/worktree.c:433
-#: builtin/worktree.c:435
-msgid "branch"
+#: sequencer.c:5257
+msgid "could not skip unnecessary pick commands"
 msgstr ""
 
-#: builtin/checkout.c:1115
-msgid "create and checkout a new branch"
+#: sequencer.c:5351
+msgid "the script was already rearranged."
 msgstr ""
 
-#: builtin/checkout.c:1117
-msgid "create/reset and checkout a branch"
+#: setup.c:124
+#, c-format
+msgid "'%s' is outside repository"
 msgstr ""
 
-#: builtin/checkout.c:1118
-msgid "create reflog for new branch"
+#: setup.c:174
+#, c-format
+msgid ""
+"%s: no such path in the working tree.\n"
+"Use 'git <command> -- <path>...' to specify paths that do not exist locally."
 msgstr ""
 
-#: builtin/checkout.c:1119 builtin/worktree.c:437
-msgid "detach HEAD at named commit"
+#: setup.c:187
+#, c-format
+msgid ""
+"ambiguous argument '%s': unknown revision or path not in the working tree.\n"
+"Use '--' to separate paths from revisions, like this:\n"
+"'git <command> [<revision>...] -- [<file>...]'"
 msgstr ""
 
-#: builtin/checkout.c:1120
-msgid "set upstream info for new branch"
+#: setup.c:236
+#, c-format
+msgid "option '%s' must come before non-option arguments"
 msgstr ""
 
-#: builtin/checkout.c:1122
-msgid "new-branch"
+#: setup.c:255
+#, c-format
+msgid ""
+"ambiguous argument '%s': both revision and filename\n"
+"Use '--' to separate paths from revisions, like this:\n"
+"'git <command> [<revision>...] -- [<file>...]'"
 msgstr ""
 
-#: builtin/checkout.c:1122
-msgid "new unparented branch"
+#: setup.c:391
+msgid "unable to set up work tree using invalid config"
 msgstr ""
 
-#: builtin/checkout.c:1123
-msgid "checkout our version for unmerged files"
+#: setup.c:395
+msgid "this operation must be run in a work tree"
 msgstr ""
 
-#: builtin/checkout.c:1125
-msgid "checkout their version for unmerged files"
+#: setup.c:541
+#, c-format
+msgid "Expected git repo version <= %d, found %d"
 msgstr ""
 
-#: builtin/checkout.c:1127
-msgid "force checkout (throw away local modifications)"
+#: setup.c:549
+msgid "unknown repository extensions found:"
 msgstr ""
 
-#: builtin/checkout.c:1129
-msgid "perform a 3-way merge with the new branch"
+#: setup.c:568
+#, c-format
+msgid "error opening '%s'"
 msgstr ""
 
-#: builtin/checkout.c:1131 builtin/merge.c:241
-msgid "update ignored files (default)"
+#: setup.c:570
+#, c-format
+msgid "too large to be a .git file: '%s'"
 msgstr ""
 
-#: builtin/checkout.c:1133 builtin/log.c:1499 parse-options.h:264
-msgid "style"
+#: setup.c:572
+#, c-format
+msgid "error reading %s"
 msgstr ""
 
-#: builtin/checkout.c:1134
-msgid "conflict style (merge or diff3)"
+#: setup.c:574
+#, c-format
+msgid "invalid gitfile format: %s"
 msgstr ""
 
-#: builtin/checkout.c:1137
-msgid "do not limit pathspecs to sparse entries only"
+#: setup.c:576
+#, c-format
+msgid "no path in gitfile: %s"
 msgstr ""
 
-#: builtin/checkout.c:1139
-msgid "second guess 'git checkout <no-such-branch>'"
+#: setup.c:578
+#, c-format
+msgid "not a git repository: %s"
 msgstr ""
 
-#: builtin/checkout.c:1141
-msgid "do not check if another worktree is holding the given ref"
+#: setup.c:677
+#, c-format
+msgid "'$%s' too big"
 msgstr ""
 
-#: builtin/checkout.c:1145 builtin/clone.c:85 builtin/fetch.c:149
-#: builtin/merge.c:238 builtin/pull.c:128 builtin/push.c:572
-#: builtin/send-pack.c:174
-msgid "force progress reporting"
+#: setup.c:691
+#, c-format
+msgid "not a git repository: '%s'"
 msgstr ""
 
-#: builtin/checkout.c:1175
-msgid "-b, -B and --orphan are mutually exclusive"
+#: setup.c:720 setup.c:722 setup.c:753
+#, c-format
+msgid "cannot chdir to '%s'"
 msgstr ""
 
-#: builtin/checkout.c:1192
-msgid "--track needs a branch name"
+#: setup.c:725 setup.c:781 setup.c:791 setup.c:830 setup.c:838
+msgid "cannot come back to cwd"
 msgstr ""
 
-#: builtin/checkout.c:1197
-msgid "Missing branch name; try -b"
+#: setup.c:852
+#, c-format
+msgid "failed to stat '%*s%s%s'"
 msgstr ""
 
-#: builtin/checkout.c:1233
-msgid "invalid path specification"
+#: setup.c:1090
+msgid "Unable to read current working directory"
 msgstr ""
 
-#: builtin/checkout.c:1240
+#: setup.c:1099 setup.c:1105
 #, c-format
-msgid "'%s' is not a commit and a branch '%s' cannot be created from it"
+msgid "cannot change to '%s'"
 msgstr ""
 
-#: builtin/checkout.c:1244
+#: setup.c:1110
 #, c-format
-msgid "git checkout: --detach does not take a path argument '%s'"
+msgid "not a git repository (or any of the parent directories): %s"
 msgstr ""
 
-#: builtin/checkout.c:1248
+#: setup.c:1116
+#, c-format
 msgid ""
-"git checkout: --ours/--theirs, --force and --merge are incompatible when\n"
-"checking out of the index."
+"not a git repository (or any parent up to mount point %s)\n"
+"Stopping at filesystem boundary (GIT_DISCOVERY_ACROSS_FILESYSTEM not set)."
 msgstr ""
 
-#: builtin/clean.c:26
+#: setup.c:1227
+#, c-format
 msgid ""
-"git clean [-d] [-f] [-i] [-n] [-q] [-e <pattern>] [-x | -X] [--] <paths>..."
+"problem with core.sharedRepository filemode value (0%.3o).\n"
+"The owner of files must always have read and write permissions."
 msgstr ""
 
-#: builtin/clean.c:30
-#, c-format
-msgid "Removing %s\n"
+#: setup.c:1271
+msgid "open /dev/null or dup failed"
 msgstr ""
 
-#: builtin/clean.c:31
-#, c-format
-msgid "Would remove %s\n"
+#: setup.c:1286
+msgid "fork failed"
 msgstr ""
 
-#: builtin/clean.c:32
-#, c-format
-msgid "Skipping repository %s\n"
+#: setup.c:1291
+msgid "setsid failed"
 msgstr ""
 
-#: builtin/clean.c:33
+#: sha1-file.c:452
 #, c-format
-msgid "Would skip repository %s\n"
+msgid "object directory %s does not exist; check .git/objects/info/alternates"
 msgstr ""
 
-#: builtin/clean.c:34
+#: sha1-file.c:503
 #, c-format
-msgid "failed to remove %s"
+msgid "unable to normalize alternate object path: %s"
 msgstr ""
 
-#: builtin/clean.c:302 git-add--interactive.perl:579
+#: sha1-file.c:575
 #, c-format
-msgid ""
-"Prompt help:\n"
-"1          - select a numbered item\n"
-"foo        - select item based on unique prefix\n"
-"           - (empty) select nothing\n"
+msgid "%s: ignoring alternate object stores, nesting too deep"
 msgstr ""
 
-#: builtin/clean.c:306 git-add--interactive.perl:588
+#: sha1-file.c:582
 #, c-format
-msgid ""
-"Prompt help:\n"
-"1          - select a single item\n"
-"3-5        - select a range of items\n"
-"2-3,6-9    - select multiple ranges\n"
-"foo        - select item based on unique prefix\n"
-"-...       - unselect specified items\n"
-"*          - choose all items\n"
-"           - (empty) finish selecting\n"
-msgstr ""
-
-#: builtin/clean.c:522 git-add--interactive.perl:554
-#: git-add--interactive.perl:559
-#, c-format, perl-format
-msgid "Huh (%s)?\n"
+msgid "unable to normalize object directory: %s"
 msgstr ""
 
-#: builtin/clean.c:664
-#, c-format
-msgid "Input ignore patterns>> "
+#: sha1-file.c:625
+msgid "unable to fdopen alternates lockfile"
 msgstr ""
 
-#: builtin/clean.c:701
-#, c-format
-msgid "WARNING: Cannot find items matched by: %s"
+#: sha1-file.c:643
+msgid "unable to read alternates file"
 msgstr ""
 
-#: builtin/clean.c:722
-msgid "Select items to delete"
+#: sha1-file.c:650
+msgid "unable to move new alternates file into place"
 msgstr ""
 
-#. TRANSLATORS: Make sure to keep [y/N] as is
-#: builtin/clean.c:763
+#: sha1-file.c:685
 #, c-format
-msgid "Remove %s [y/N]? "
+msgid "path '%s' does not exist"
 msgstr ""
 
-#: builtin/clean.c:788 git-add--interactive.perl:1717
+#: sha1-file.c:711
 #, c-format
-msgid "Bye.\n"
-msgstr ""
-
-#: builtin/clean.c:796
-msgid ""
-"clean               - start cleaning\n"
-"filter by pattern   - exclude items from deletion\n"
-"select by numbers   - select items to be deleted by numbers\n"
-"ask each            - confirm each deletion (like \"rm -i\")\n"
-"quit                - stop cleaning\n"
-"help                - this screen\n"
-"?                   - help for prompt selection"
+msgid "reference repository '%s' as a linked checkout is not supported yet."
 msgstr ""
 
-#: builtin/clean.c:823 git-add--interactive.perl:1793
-msgid "*** Commands ***"
+#: sha1-file.c:717
+#, c-format
+msgid "reference repository '%s' is not a local repository."
 msgstr ""
 
-#: builtin/clean.c:824 git-add--interactive.perl:1790
-msgid "What now"
+#: sha1-file.c:723
+#, c-format
+msgid "reference repository '%s' is shallow"
 msgstr ""
 
-#: builtin/clean.c:832
-msgid "Would remove the following item:"
-msgid_plural "Would remove the following items:"
-msgstr[0] ""
-msgstr[1] ""
-
-#: builtin/clean.c:848
-msgid "No more files to clean, exiting."
+#: sha1-file.c:731
+#, c-format
+msgid "reference repository '%s' is grafted"
 msgstr ""
 
-#: builtin/clean.c:910
-msgid "do not print names of files removed"
+#: sha1-file.c:791
+#, c-format
+msgid "invalid line while parsing alternate refs: %s"
 msgstr ""
 
-#: builtin/clean.c:912
-msgid "force"
+#: sha1-file.c:943
+#, c-format
+msgid "attempting to mmap %<PRIuMAX> over limit %<PRIuMAX>"
 msgstr ""
 
-#: builtin/clean.c:913
-msgid "interactive cleaning"
+#: sha1-file.c:964
+msgid "mmap failed"
 msgstr ""
 
-#: builtin/clean.c:915
-msgid "remove whole directories"
+#: sha1-file.c:1128
+#, c-format
+msgid "object file %s is empty"
 msgstr ""
 
-#: builtin/clean.c:916 builtin/describe.c:533 builtin/describe.c:535
-#: builtin/grep.c:871 builtin/log.c:157 builtin/log.c:159
-#: builtin/ls-files.c:548 builtin/name-rev.c:397 builtin/name-rev.c:399
-#: builtin/show-ref.c:176
-msgid "pattern"
+#: sha1-file.c:1252 sha1-file.c:2392
+#, c-format
+msgid "corrupt loose object '%s'"
 msgstr ""
 
-#: builtin/clean.c:917
-msgid "add <pattern> to ignore rules"
+#: sha1-file.c:1254 sha1-file.c:2396
+#, c-format
+msgid "garbage at end of loose object '%s'"
 msgstr ""
 
-#: builtin/clean.c:918
-msgid "remove ignored files, too"
+#: sha1-file.c:1296
+msgid "invalid object type"
 msgstr ""
 
-#: builtin/clean.c:920
-msgid "remove only ignored files"
+#: sha1-file.c:1380
+#, c-format
+msgid "unable to unpack %s header with --allow-unknown-type"
 msgstr ""
 
-#: builtin/clean.c:938
-msgid "-x and -X cannot be used together"
+#: sha1-file.c:1383
+#, c-format
+msgid "unable to unpack %s header"
 msgstr ""
 
-#: builtin/clean.c:942
-msgid ""
-"clean.requireForce set to true and neither -i, -n, nor -f given; refusing to "
-"clean"
+#: sha1-file.c:1389
+#, c-format
+msgid "unable to parse %s header with --allow-unknown-type"
 msgstr ""
 
-#: builtin/clean.c:945
-msgid ""
-"clean.requireForce defaults to true and neither -i, -n, nor -f given; "
-"refusing to clean"
+#: sha1-file.c:1392
+#, c-format
+msgid "unable to parse %s header"
 msgstr ""
 
-#: builtin/clone.c:42
-msgid "git clone [<options>] [--] <repo> [<dir>]"
+#: sha1-file.c:1584
+#, c-format
+msgid "failed to read object %s"
 msgstr ""
 
-#: builtin/clone.c:87
-msgid "don't create a checkout"
+#: sha1-file.c:1588
+#, c-format
+msgid "replacement %s not found for %s"
 msgstr ""
 
-#: builtin/clone.c:88 builtin/clone.c:90 builtin/init-db.c:479
-msgid "create a bare repository"
+#: sha1-file.c:1592
+#, c-format
+msgid "loose object %s (stored in %s) is corrupt"
 msgstr ""
 
-#: builtin/clone.c:92
-msgid "create a mirror repository (implies bare)"
+#: sha1-file.c:1596
+#, c-format
+msgid "packed object %s (stored in %s) is corrupt"
 msgstr ""
 
-#: builtin/clone.c:94
-msgid "to clone from a local repository"
+#: sha1-file.c:1699
+#, c-format
+msgid "unable to write file %s"
 msgstr ""
 
-#: builtin/clone.c:96
-msgid "don't use local hardlinks, always copy"
+#: sha1-file.c:1706
+#, c-format
+msgid "unable to set permission to '%s'"
 msgstr ""
 
-#: builtin/clone.c:98
-msgid "setup as shared repository"
+#: sha1-file.c:1713
+msgid "file write error"
 msgstr ""
 
-#: builtin/clone.c:100 builtin/clone.c:104
-msgid "pathspec"
+#: sha1-file.c:1732
+msgid "error when closing loose object file"
 msgstr ""
 
-#: builtin/clone.c:100 builtin/clone.c:104
-msgid "initialize submodules in the clone"
+#: sha1-file.c:1797
+#, c-format
+msgid "insufficient permission for adding an object to repository database %s"
 msgstr ""
 
-#: builtin/clone.c:107
-msgid "number of submodules cloned in parallel"
+#: sha1-file.c:1799
+msgid "unable to create temporary file"
 msgstr ""
 
-#: builtin/clone.c:108 builtin/init-db.c:476
-msgid "template-directory"
+#: sha1-file.c:1823
+msgid "unable to write loose object file"
 msgstr ""
 
-#: builtin/clone.c:109 builtin/init-db.c:477
-msgid "directory from which templates will be used"
+#: sha1-file.c:1829
+#, c-format
+msgid "unable to deflate new object %s (%d)"
 msgstr ""
 
-#: builtin/clone.c:111 builtin/clone.c:113 builtin/submodule--helper.c:1223
-#: builtin/submodule--helper.c:1594
-msgid "reference repository"
+#: sha1-file.c:1833
+#, c-format
+msgid "deflateEnd on object %s failed (%d)"
 msgstr ""
 
-#: builtin/clone.c:115 builtin/submodule--helper.c:1225
-#: builtin/submodule--helper.c:1596
-msgid "use --reference only while cloning"
+#: sha1-file.c:1837
+#, c-format
+msgid "confused by unstable object source data for %s"
 msgstr ""
 
-#: builtin/clone.c:116 builtin/column.c:27 builtin/merge-file.c:44
-#: builtin/pack-objects.c:3166 builtin/repack.c:213
-msgid "name"
+#: sha1-file.c:1847 builtin/pack-objects.c:925
+#, c-format
+msgid "failed utime() on %s"
 msgstr ""
 
-#: builtin/clone.c:117
-msgid "use <name> instead of 'origin' to track upstream"
+#: sha1-file.c:1922
+#, c-format
+msgid "cannot read object for %s"
 msgstr ""
 
-#: builtin/clone.c:119
-msgid "checkout <branch> instead of the remote's HEAD"
+#: sha1-file.c:1962
+msgid "corrupt commit"
 msgstr ""
 
-#: builtin/clone.c:121
-msgid "path to git-upload-pack on the remote"
+#: sha1-file.c:1970
+msgid "corrupt tag"
 msgstr ""
 
-#: builtin/clone.c:122 builtin/fetch.c:150 builtin/grep.c:813
-#: builtin/pull.c:216
-msgid "depth"
+#: sha1-file.c:2069
+#, c-format
+msgid "read error while indexing %s"
 msgstr ""
 
-#: builtin/clone.c:123
-msgid "create a shallow clone of that depth"
+#: sha1-file.c:2072
+#, c-format
+msgid "short read while indexing %s"
 msgstr ""
 
-#: builtin/clone.c:124 builtin/fetch.c:152 builtin/pack-objects.c:3157
-#: parse-options.h:154
-msgid "time"
+#: sha1-file.c:2145 sha1-file.c:2154
+#, c-format
+msgid "%s: failed to insert into database"
 msgstr ""
 
-#: builtin/clone.c:125
-msgid "create a shallow clone since a specific time"
+#: sha1-file.c:2160
+#, c-format
+msgid "%s: unsupported file type"
 msgstr ""
 
-#: builtin/clone.c:126 builtin/fetch.c:154
-msgid "revision"
+#: sha1-file.c:2184
+#, c-format
+msgid "%s is not a valid object"
 msgstr ""
 
-#: builtin/clone.c:127 builtin/fetch.c:155
-msgid "deepen history of shallow clone, excluding rev"
+#: sha1-file.c:2186
+#, c-format
+msgid "%s is not a valid '%s' object"
 msgstr ""
 
-#: builtin/clone.c:129
-msgid "clone only one branch, HEAD or --branch"
+#: sha1-file.c:2213 builtin/index-pack.c:155
+#, c-format
+msgid "unable to open %s"
 msgstr ""
 
-#: builtin/clone.c:131
-msgid "don't clone any tags, and make later fetches not to follow them"
+#: sha1-file.c:2403 sha1-file.c:2455
+#, c-format
+msgid "hash mismatch for %s (expected %s)"
 msgstr ""
 
-#: builtin/clone.c:133
-msgid "any cloned submodules will be shallow"
+#: sha1-file.c:2427
+#, c-format
+msgid "unable to mmap %s"
 msgstr ""
 
-#: builtin/clone.c:134 builtin/init-db.c:485
-msgid "gitdir"
+#: sha1-file.c:2432
+#, c-format
+msgid "unable to unpack header of %s"
 msgstr ""
 
-#: builtin/clone.c:135 builtin/init-db.c:486
-msgid "separate git dir from working tree"
+#: sha1-file.c:2438
+#, c-format
+msgid "unable to parse header of %s"
 msgstr ""
 
-#: builtin/clone.c:136
-msgid "key=value"
+#: sha1-file.c:2449
+#, c-format
+msgid "unable to unpack contents of %s"
 msgstr ""
 
-#: builtin/clone.c:137
-msgid "set config inside the new repository"
+#: sha1-name.c:487
+#, c-format
+msgid "short SHA1 %s is ambiguous"
 msgstr ""
 
-#: builtin/clone.c:138 builtin/fetch.c:173 builtin/pull.c:229
-#: builtin/push.c:583
-msgid "use IPv4 addresses only"
+#: sha1-name.c:498
+msgid "The candidates are:"
 msgstr ""
 
-#: builtin/clone.c:140 builtin/fetch.c:175 builtin/pull.c:232
-#: builtin/push.c:585
-msgid "use IPv6 addresses only"
-msgstr ""
-
-#: builtin/clone.c:278
+#: sha1-name.c:797
 msgid ""
-"No directory name could be guessed.\n"
-"Please specify a directory on the command line"
+"Git normally never creates a ref that ends with 40 hex characters\n"
+"because it will be ignored when you just specify 40-hex. These refs\n"
+"may be created by mistake. For example,\n"
+"\n"
+"  git switch -c $br $(git rev-parse ...)\n"
+"\n"
+"where \"$br\" is somehow empty and a 40-hex ref is created. Please\n"
+"examine these refs and maybe delete them. Turn this message off by\n"
+"running \"git config advice.objectNameWarning false\""
 msgstr ""
 
-#: builtin/clone.c:331
+#. TRANSLATORS: IEC 80000-13:2008 gibibyte
+#: strbuf.c:822
 #, c-format
-msgid "info: Could not add alternate for '%s': %s\n"
+msgid "%u.%2.2u GiB"
 msgstr ""
 
-#: builtin/clone.c:403
+#. TRANSLATORS: IEC 80000-13:2008 gibibyte/second
+#: strbuf.c:824
 #, c-format
-msgid "failed to open '%s'"
+msgid "%u.%2.2u GiB/s"
 msgstr ""
 
-#: builtin/clone.c:411
+#. TRANSLATORS: IEC 80000-13:2008 mebibyte
+#: strbuf.c:832
 #, c-format
-msgid "%s exists and is not a directory"
+msgid "%u.%2.2u MiB"
 msgstr ""
 
-#: builtin/clone.c:425
+#. TRANSLATORS: IEC 80000-13:2008 mebibyte/second
+#: strbuf.c:834
 #, c-format
-msgid "failed to stat %s\n"
+msgid "%u.%2.2u MiB/s"
 msgstr ""
 
-#: builtin/clone.c:447
+#. TRANSLATORS: IEC 80000-13:2008 kibibyte
+#: strbuf.c:841
 #, c-format
-msgid "failed to create link '%s'"
+msgid "%u.%2.2u KiB"
 msgstr ""
 
-#: builtin/clone.c:451
+#. TRANSLATORS: IEC 80000-13:2008 kibibyte/second
+#: strbuf.c:843
 #, c-format
-msgid "failed to copy file to '%s'"
+msgid "%u.%2.2u KiB/s"
 msgstr ""
 
-#: builtin/clone.c:477
+#. TRANSLATORS: IEC 80000-13:2008 byte
+#: strbuf.c:849
 #, c-format
-msgid "done.\n"
-msgstr ""
+msgid "%u byte"
+msgid_plural "%u bytes"
+msgstr[0] ""
+msgstr[1] ""
 
-#: builtin/clone.c:491
-msgid ""
-"Clone succeeded, but checkout failed.\n"
-"You can inspect what was checked out with 'git status'\n"
-"and retry the checkout with 'git checkout -f HEAD'\n"
-msgstr ""
+#. TRANSLATORS: IEC 80000-13:2008 byte/second
+#: strbuf.c:851
+#, c-format
+msgid "%u byte/s"
+msgid_plural "%u bytes/s"
+msgstr[0] ""
+msgstr[1] ""
 
-#: builtin/clone.c:568
+#: strbuf.c:1149
 #, c-format
-msgid "Could not find remote branch %s to clone."
+msgid "could not edit '%s'"
 msgstr ""
 
-#: builtin/clone.c:663
-msgid "remote did not send all necessary objects"
+#: submodule.c:114 submodule.c:143
+msgid "Cannot change unmerged .gitmodules, resolve merge conflicts first"
 msgstr ""
 
-#: builtin/clone.c:679
+#: submodule.c:118 submodule.c:147
 #, c-format
-msgid "unable to update %s"
+msgid "Could not find section in .gitmodules where path=%s"
 msgstr ""
 
-#: builtin/clone.c:728
-msgid "remote HEAD refers to nonexistent ref, unable to checkout.\n"
+#: submodule.c:154
+#, c-format
+msgid "Could not remove .gitmodules entry for %s"
 msgstr ""
 
-#: builtin/clone.c:758
-msgid "unable to checkout working tree"
+#: submodule.c:165
+msgid "staging updated .gitmodules failed"
 msgstr ""
 
-#: builtin/clone.c:803
-msgid "unable to write parameters to config file"
+#: submodule.c:327
+#, c-format
+msgid "in unpopulated submodule '%s'"
 msgstr ""
 
-#: builtin/clone.c:866
-msgid "cannot repack to clean up"
+#: submodule.c:358
+#, c-format
+msgid "Pathspec '%s' is in submodule '%.*s'"
 msgstr ""
 
-#: builtin/clone.c:868
-msgid "cannot unlink temporary alternates file"
+#: submodule.c:910
+#, c-format
+msgid "submodule entry '%s' (%s) is a %s, not a commit"
 msgstr ""
 
-#: builtin/clone.c:907 builtin/receive-pack.c:1947
-msgid "Too many arguments."
+#: submodule.c:1147 builtin/branch.c:680 builtin/submodule--helper.c:2016
+msgid "Failed to resolve HEAD as a valid ref."
 msgstr ""
 
-#: builtin/clone.c:911
-msgid "You must specify a repository to clone."
+#: submodule.c:1481
+#, c-format
+msgid "Could not access submodule '%s'"
 msgstr ""
 
-#: builtin/clone.c:924
+#: submodule.c:1651
 #, c-format
-msgid "--bare and --origin %s options are incompatible."
+msgid "'%s' not recognized as a git repository"
 msgstr ""
 
-#: builtin/clone.c:927
-msgid "--bare and --separate-git-dir are incompatible."
+#: submodule.c:1789
+#, c-format
+msgid "could not start 'git status' in submodule '%s'"
 msgstr ""
 
-#: builtin/clone.c:940
+#: submodule.c:1802
 #, c-format
-msgid "repository '%s' does not exist"
+msgid "could not run 'git status' in submodule '%s'"
 msgstr ""
 
-#: builtin/clone.c:946 builtin/fetch.c:1460
+#: submodule.c:1817
 #, c-format
-msgid "depth %s is not a positive number"
+msgid "Could not unset core.worktree setting in submodule '%s'"
 msgstr ""
 
-#: builtin/clone.c:956
+#: submodule.c:1907
 #, c-format
-msgid "destination path '%s' already exists and is not an empty directory."
+msgid "submodule '%s' has dirty index"
 msgstr ""
 
-#: builtin/clone.c:966
+#: submodule.c:1959
 #, c-format
-msgid "working tree '%s' already exists."
+msgid "Submodule '%s' could not be updated."
 msgstr ""
 
-#: builtin/clone.c:981 builtin/clone.c:1002 builtin/difftool.c:270
-#: builtin/worktree.c:246 builtin/worktree.c:276
+#: submodule.c:2027
 #, c-format
-msgid "could not create leading directories of '%s'"
+msgid "submodule git dir '%s' is inside git dir '%.*s'"
 msgstr ""
 
-#: builtin/clone.c:986
+#: submodule.c:2048
 #, c-format
-msgid "could not create work tree dir '%s'"
+msgid ""
+"relocate_gitdir for submodule '%s' with more than one worktree not supported"
 msgstr ""
 
-#: builtin/clone.c:1006
+#: submodule.c:2060 submodule.c:2119
 #, c-format
-msgid "Cloning into bare repository '%s'...\n"
+msgid "could not lookup name for submodule '%s'"
 msgstr ""
 
-#: builtin/clone.c:1008
+#: submodule.c:2064
 #, c-format
-msgid "Cloning into '%s'...\n"
+msgid "refusing to move '%s' into an existing git dir"
 msgstr ""
 
-#: builtin/clone.c:1032
+#: submodule.c:2071
+#, c-format
 msgid ""
-"clone --recursive is not compatible with both --reference and --reference-if-"
-"able"
+"Migrating git directory of '%s%s' from\n"
+"'%s' to\n"
+"'%s'\n"
 msgstr ""
 
-#: builtin/clone.c:1093
-msgid "--depth is ignored in local clones; use file:// instead."
+#: submodule.c:2154
+#, c-format
+msgid "could not recurse into submodule '%s'"
 msgstr ""
 
-#: builtin/clone.c:1095
-msgid "--shallow-since is ignored in local clones; use file:// instead."
+#: submodule.c:2198
+msgid "could not start ls-files in .."
 msgstr ""
 
-#: builtin/clone.c:1097
-msgid "--shallow-exclude is ignored in local clones; use file:// instead."
+#: submodule.c:2237
+#, c-format
+msgid "ls-tree returned unexpected return code %d"
 msgstr ""
 
-#: builtin/clone.c:1099
-msgid "--filter is ignored in local clones; use file:// instead."
+#: submodule-config.c:236
+#, c-format
+msgid "ignoring suspicious submodule name: %s"
 msgstr ""
 
-#: builtin/clone.c:1102
-msgid "source repository is shallow, ignoring --local"
+#: submodule-config.c:303
+msgid "negative values not allowed for submodule.fetchjobs"
 msgstr ""
 
-#: builtin/clone.c:1107
-msgid "--local is ignored"
+#: submodule-config.c:401
+#, c-format
+msgid "ignoring '%s' which may be interpreted as a command-line option: %s"
 msgstr ""
 
-#: builtin/clone.c:1169 builtin/clone.c:1177
+#: submodule-config.c:498
 #, c-format
-msgid "Remote branch %s not found in upstream %s"
+msgid "invalid value for %s"
 msgstr ""
 
-#: builtin/clone.c:1180
-msgid "You appear to have cloned an empty repository."
+#: submodule-config.c:769
+#, c-format
+msgid "Could not update .gitmodules entry %s"
 msgstr ""
 
-#: builtin/column.c:10
-msgid "git column [<options>]"
+#: trailer.c:238
+#, c-format
+msgid "running trailer command '%s' failed"
 msgstr ""
 
-#: builtin/column.c:27
-msgid "lookup config vars"
+#: trailer.c:485 trailer.c:490 trailer.c:495 trailer.c:549 trailer.c:553
+#: trailer.c:557
+#, c-format
+msgid "unknown value '%s' for key '%s'"
 msgstr ""
 
-#: builtin/column.c:28 builtin/column.c:29
-msgid "layout to use"
+#: trailer.c:539 trailer.c:544 builtin/remote.c:295
+#, c-format
+msgid "more than one %s"
 msgstr ""
 
-#: builtin/column.c:30
-msgid "Maximum width"
+#: trailer.c:730
+#, c-format
+msgid "empty trailer token in trailer '%.*s'"
 msgstr ""
 
-#: builtin/column.c:31
-msgid "Padding space on left border"
+#: trailer.c:750
+#, c-format
+msgid "could not read input file '%s'"
 msgstr ""
 
-#: builtin/column.c:32
-msgid "Padding space on right border"
+#: trailer.c:753
+msgid "could not read from stdin"
 msgstr ""
 
-#: builtin/column.c:33
-msgid "Padding space between columns"
+#: trailer.c:1011 wrapper.c:665
+#, c-format
+msgid "could not stat %s"
 msgstr ""
 
-#: builtin/column.c:51
-msgid "--command must be the first argument"
+#: trailer.c:1013
+#, c-format
+msgid "file %s is not a regular file"
 msgstr ""
 
-#: builtin/commit.c:37
-msgid "git commit [<options>] [--] <pathspec>..."
+#: trailer.c:1015
+#, c-format
+msgid "file %s is not writable by user"
 msgstr ""
 
-#: builtin/commit.c:42
-msgid "git status [<options>] [--] <pathspec>..."
+#: trailer.c:1027
+msgid "could not open temporary file"
 msgstr ""
 
-#: builtin/commit.c:47
-msgid ""
-"You asked to amend the most recent commit, but doing so would make\n"
-"it empty. You can repeat your command with --allow-empty, or you can\n"
-"remove the commit entirely with \"git reset HEAD^\".\n"
+#: trailer.c:1067
+#, c-format
+msgid "could not rename temporary file to %s"
 msgstr ""
 
-#: builtin/commit.c:52
-msgid ""
-"The previous cherry-pick is now empty, possibly due to conflict resolution.\n"
-"If you wish to commit it anyway, use:\n"
-"\n"
-"    git commit --allow-empty\n"
-"\n"
+#: transport.c:116
+#, c-format
+msgid "Would set upstream of '%s' to '%s' of '%s'\n"
 msgstr ""
 
-#: builtin/commit.c:59
-msgid "Otherwise, please use 'git reset'\n"
+#: transport.c:145
+#, c-format
+msgid "could not read bundle '%s'"
 msgstr ""
 
-#: builtin/commit.c:62
-msgid ""
-"If you wish to skip this commit, use:\n"
-"\n"
-"    git reset\n"
-"\n"
-"Then \"git cherry-pick --continue\" will resume cherry-picking\n"
-"the remaining commits.\n"
+#: transport.c:214
+#, c-format
+msgid "transport: invalid depth option '%s'"
 msgstr ""
 
-#: builtin/commit.c:293
-msgid "failed to unpack HEAD tree object"
+#: transport.c:266
+msgid "see protocol.version in 'git help config' for more details"
 msgstr ""
 
-#: builtin/commit.c:334
-msgid "unable to create temporary index"
+#: transport.c:267
+msgid "server options require protocol version 2 or later"
 msgstr ""
 
-#: builtin/commit.c:340
-msgid "interactive add failed"
+#: transport.c:632
+msgid "could not parse transport.color.* config"
 msgstr ""
 
-#: builtin/commit.c:353
-msgid "unable to update temporary index"
+#: transport.c:705
+msgid "support for protocol v2 not implemented yet"
 msgstr ""
 
-#: builtin/commit.c:355
-msgid "Failed to update main cache tree"
+#: transport.c:831
+#, c-format
+msgid "unknown value for config '%s': %s"
 msgstr ""
 
-#: builtin/commit.c:380 builtin/commit.c:403 builtin/commit.c:449
-msgid "unable to write new_index file"
+#: transport.c:897
+#, c-format
+msgid "transport '%s' not allowed"
 msgstr ""
 
-#: builtin/commit.c:432
-msgid "cannot do a partial commit during a merge."
+#: transport.c:949
+msgid "git-over-rsync is no longer supported"
 msgstr ""
 
-#: builtin/commit.c:434
-msgid "cannot do a partial commit during a cherry-pick."
+#: transport.c:1044
+#, c-format
+msgid ""
+"The following submodule paths contain changes that can\n"
+"not be found on any remote:\n"
 msgstr ""
 
-#: builtin/commit.c:442
-msgid "cannot read the index"
+#: transport.c:1048
+#, c-format
+msgid ""
+"\n"
+"Please try\n"
+"\n"
+"\tgit push --recurse-submodules=on-demand\n"
+"\n"
+"or cd to the path and use\n"
+"\n"
+"\tgit push\n"
+"\n"
+"to push them to a remote.\n"
+"\n"
 msgstr ""
 
-#: builtin/commit.c:461
-msgid "unable to write temporary index file"
+#: transport.c:1056
+msgid "Aborting."
 msgstr ""
 
-#: builtin/commit.c:558
-#, c-format
-msgid "commit '%s' lacks author header"
+#: transport.c:1201
+msgid "failed to push all needed submodules"
 msgstr ""
 
-#: builtin/commit.c:560
-#, c-format
-msgid "commit '%s' has malformed author line"
+#: transport.c:1345 transport-helper.c:656
+msgid "operation not supported by protocol"
 msgstr ""
 
-#: builtin/commit.c:579
-msgid "malformed --author parameter"
+#: transport-helper.c:61 transport-helper.c:90
+msgid "full write to remote helper failed"
 msgstr ""
 
-#: builtin/commit.c:631
-msgid ""
-"unable to select a comment character that is not used\n"
-"in the current commit message"
+#: transport-helper.c:144
+#, c-format
+msgid "unable to find remote helper for '%s'"
 msgstr ""
 
-#: builtin/commit.c:668 builtin/commit.c:701 builtin/commit.c:1029
-#, c-format
-msgid "could not lookup commit %s"
+#: transport-helper.c:160 transport-helper.c:570
+msgid "can't dup helper output fd"
 msgstr ""
 
-#: builtin/commit.c:680 builtin/shortlog.c:316
+#: transport-helper.c:211
 #, c-format
-msgid "(reading log message from standard input)\n"
+msgid ""
+"unknown mandatory capability %s; this remote helper probably needs newer "
+"version of Git"
 msgstr ""
 
-#: builtin/commit.c:682
-msgid "could not read log from standard input"
+#: transport-helper.c:217
+msgid "this remote helper should implement refspec capability"
 msgstr ""
 
-#: builtin/commit.c:686
+#: transport-helper.c:284 transport-helper.c:424
 #, c-format
-msgid "could not read log file '%s'"
+msgid "%s unexpectedly said: '%s'"
 msgstr ""
 
-#: builtin/commit.c:715 builtin/commit.c:723
-msgid "could not read SQUASH_MSG"
+#: transport-helper.c:413
+#, c-format
+msgid "%s also locked %s"
 msgstr ""
 
-#: builtin/commit.c:720
-msgid "could not read MERGE_MSG"
+#: transport-helper.c:492
+msgid "couldn't run fast-import"
 msgstr ""
 
-#: builtin/commit.c:774
-msgid "could not write commit template"
+#: transport-helper.c:515
+msgid "error while running fast-import"
 msgstr ""
 
-#: builtin/commit.c:792
+#: transport-helper.c:544 transport-helper.c:1133
 #, c-format
-msgid ""
-"\n"
-"It looks like you may be committing a merge.\n"
-"If this is not correct, please remove the file\n"
-"\t%s\n"
-"and try again.\n"
+msgid "could not read ref %s"
 msgstr ""
 
-#: builtin/commit.c:797
+#: transport-helper.c:589
 #, c-format
-msgid ""
-"\n"
-"It looks like you may be committing a cherry-pick.\n"
-"If this is not correct, please remove the file\n"
-"\t%s\n"
-"and try again.\n"
+msgid "unknown response to connect: %s"
 msgstr ""
 
-#: builtin/commit.c:810
-#, c-format
-msgid ""
-"Please enter the commit message for your changes. Lines starting\n"
-"with '%c' will be ignored, and an empty message aborts the commit.\n"
+#: transport-helper.c:611
+msgid "setting remote service path not supported by protocol"
 msgstr ""
 
-#: builtin/commit.c:818
-#, c-format
-msgid ""
-"Please enter the commit message for your changes. Lines starting\n"
-"with '%c' will be kept; you may remove them yourself if you want to.\n"
-"An empty message aborts the commit.\n"
+#: transport-helper.c:613
+msgid "invalid remote service path"
 msgstr ""
 
-#: builtin/commit.c:835
+#: transport-helper.c:659
 #, c-format
-msgid "%sAuthor:    %.*s <%.*s>"
+msgid "can't connect to subservice %s"
 msgstr ""
 
-#: builtin/commit.c:843
+#: transport-helper.c:735
 #, c-format
-msgid "%sDate:      %s"
+msgid "expected ok/error, helper said '%s'"
 msgstr ""
 
-#: builtin/commit.c:850
+#: transport-helper.c:788
 #, c-format
-msgid "%sCommitter: %.*s <%.*s>"
-msgstr ""
-
-#: builtin/commit.c:867
-msgid "Cannot read index"
+msgid "helper reported unexpected status of %s"
 msgstr ""
 
-#: builtin/commit.c:933
-msgid "Error building trees"
+#: transport-helper.c:849
+#, c-format
+msgid "helper %s does not support dry-run"
 msgstr ""
 
-#: builtin/commit.c:947 builtin/tag.c:257
+#: transport-helper.c:852
 #, c-format
-msgid "Please supply the message using either -m or -F option.\n"
+msgid "helper %s does not support --signed"
 msgstr ""
 
-#: builtin/commit.c:991
+#: transport-helper.c:855
 #, c-format
-msgid "--author '%s' is not 'Name <email>' and matches no existing author"
+msgid "helper %s does not support --signed=if-asked"
 msgstr ""
 
-#: builtin/commit.c:1005
+#: transport-helper.c:860
 #, c-format
-msgid "Invalid ignored mode '%s'"
+msgid "helper %s does not support --atomic"
 msgstr ""
 
-#: builtin/commit.c:1019 builtin/commit.c:1269
+#: transport-helper.c:866
 #, c-format
-msgid "Invalid untracked files mode '%s'"
+msgid "helper %s does not support 'push-option'"
 msgstr ""
 
-#: builtin/commit.c:1057
-msgid "--long and -z are incompatible"
+#: transport-helper.c:964
+msgid "remote-helper doesn't support push; refspec needed"
 msgstr ""
 
-#: builtin/commit.c:1090
-msgid "Using both --reset-author and --author does not make sense"
+#: transport-helper.c:969
+#, c-format
+msgid "helper %s does not support 'force'"
 msgstr ""
 
-#: builtin/commit.c:1099
-msgid "You have nothing to amend."
+#: transport-helper.c:1016
+msgid "couldn't run fast-export"
 msgstr ""
 
-#: builtin/commit.c:1102
-msgid "You are in the middle of a merge -- cannot amend."
+#: transport-helper.c:1021
+msgid "error while running fast-export"
 msgstr ""
 
-#: builtin/commit.c:1104
-msgid "You are in the middle of a cherry-pick -- cannot amend."
+#: transport-helper.c:1046
+#, c-format
+msgid ""
+"No refs in common and none specified; doing nothing.\n"
+"Perhaps you should specify a branch such as 'master'.\n"
 msgstr ""
 
-#: builtin/commit.c:1107
-msgid "Options --squash and --fixup cannot be used together"
+#: transport-helper.c:1119
+#, c-format
+msgid "malformed response in ref list: %s"
 msgstr ""
 
-#: builtin/commit.c:1117
-msgid "Only one of -c/-C/-F/--fixup can be used."
+#: transport-helper.c:1271
+#, c-format
+msgid "read(%s) failed"
 msgstr ""
 
-#: builtin/commit.c:1119
-msgid "Option -m cannot be combined with -c/-C/-F."
+#: transport-helper.c:1298
+#, c-format
+msgid "write(%s) failed"
 msgstr ""
 
-#: builtin/commit.c:1127
-msgid "--reset-author can be used only with -C, -c or --amend."
+#: transport-helper.c:1347
+#, c-format
+msgid "%s thread failed"
 msgstr ""
 
-#: builtin/commit.c:1144
-msgid "Only one of --include/--only/--all/--interactive/--patch can be used."
+#: transport-helper.c:1351
+#, c-format
+msgid "%s thread failed to join: %s"
 msgstr ""
 
-#: builtin/commit.c:1146
-msgid "No paths with --include/--only does not make sense."
+#: transport-helper.c:1370 transport-helper.c:1374
+#, c-format
+msgid "can't start thread for copying data: %s"
 msgstr ""
 
-#: builtin/commit.c:1160 builtin/tag.c:543
+#: transport-helper.c:1411
 #, c-format
-msgid "Invalid cleanup mode %s"
+msgid "%s process failed to wait"
 msgstr ""
 
-#: builtin/commit.c:1165
-msgid "Paths with -a does not make sense."
+#: transport-helper.c:1415
+#, c-format
+msgid "%s process failed"
 msgstr ""
 
-#: builtin/commit.c:1303 builtin/commit.c:1480
-msgid "show status concisely"
+#: transport-helper.c:1433 transport-helper.c:1442
+msgid "can't start thread for copying data"
 msgstr ""
 
-#: builtin/commit.c:1305 builtin/commit.c:1482
-msgid "show branch information"
+#: tree-walk.c:33
+msgid "too-short tree object"
 msgstr ""
 
-#: builtin/commit.c:1307
-msgid "show stash information"
+#: tree-walk.c:39
+msgid "malformed mode in tree entry"
 msgstr ""
 
-#: builtin/commit.c:1309 builtin/commit.c:1484
-msgid "compute full ahead/behind values"
+#: tree-walk.c:43
+msgid "empty filename in tree entry"
 msgstr ""
 
-#: builtin/commit.c:1311
-msgid "version"
+#: tree-walk.c:48
+#, c-format
+msgid "filename in tree entry contains backslash: '%s'"
 msgstr ""
 
-#: builtin/commit.c:1311 builtin/commit.c:1486 builtin/push.c:558
-#: builtin/worktree.c:581
-msgid "machine-readable output"
+#: tree-walk.c:124
+msgid "too-short tree file"
 msgstr ""
 
-#: builtin/commit.c:1314 builtin/commit.c:1488
-msgid "show status in long format (default)"
+#: unpack-trees.c:110
+#, c-format
+msgid ""
+"Your local changes to the following files would be overwritten by checkout:\n"
+"%%sPlease commit your changes or stash them before you switch branches."
 msgstr ""
 
-#: builtin/commit.c:1317 builtin/commit.c:1491
-msgid "terminate entries with NUL"
+#: unpack-trees.c:112
+#, c-format
+msgid ""
+"Your local changes to the following files would be overwritten by checkout:\n"
+"%%s"
 msgstr ""
 
-#: builtin/commit.c:1319 builtin/commit.c:1323 builtin/commit.c:1494
-#: builtin/fast-export.c:1001 builtin/fast-export.c:1004 builtin/tag.c:397
-msgid "mode"
+#: unpack-trees.c:115
+#, c-format
+msgid ""
+"Your local changes to the following files would be overwritten by merge:\n"
+"%%sPlease commit your changes or stash them before you merge."
 msgstr ""
 
-#: builtin/commit.c:1320 builtin/commit.c:1494
-msgid "show untracked files, optional modes: all, normal, no. (Default: all)"
+#: unpack-trees.c:117
+#, c-format
+msgid ""
+"Your local changes to the following files would be overwritten by merge:\n"
+"%%s"
 msgstr ""
 
-#: builtin/commit.c:1324
+#: unpack-trees.c:120
+#, c-format
 msgid ""
-"show ignored files, optional modes: traditional, matching, no. (Default: "
-"traditional)"
+"Your local changes to the following files would be overwritten by %s:\n"
+"%%sPlease commit your changes or stash them before you %s."
 msgstr ""
 
-#: builtin/commit.c:1326 parse-options.h:167
-msgid "when"
+#: unpack-trees.c:122
+#, c-format
+msgid ""
+"Your local changes to the following files would be overwritten by %s:\n"
+"%%s"
 msgstr ""
 
-#: builtin/commit.c:1327
+#: unpack-trees.c:127
+#, c-format
 msgid ""
-"ignore changes to submodules, optional when: all, dirty, untracked. "
-"(Default: all)"
+"Updating the following directories would lose untracked files in them:\n"
+"%s"
 msgstr ""
 
-#: builtin/commit.c:1329
-msgid "list untracked files in columns"
+#: unpack-trees.c:131
+#, c-format
+msgid ""
+"The following untracked working tree files would be removed by checkout:\n"
+"%%sPlease move or remove them before you switch branches."
 msgstr ""
 
-#: builtin/commit.c:1330
-msgid "do not detect renames"
+#: unpack-trees.c:133
+#, c-format
+msgid ""
+"The following untracked working tree files would be removed by checkout:\n"
+"%%s"
 msgstr ""
 
-#: builtin/commit.c:1332
-msgid "detect renames, optionally set similarity index"
+#: unpack-trees.c:136
+#, c-format
+msgid ""
+"The following untracked working tree files would be removed by merge:\n"
+"%%sPlease move or remove them before you merge."
 msgstr ""
 
-#: builtin/commit.c:1352
-msgid "Unsupported combination of ignored and untracked-files arguments"
+#: unpack-trees.c:138
+#, c-format
+msgid ""
+"The following untracked working tree files would be removed by merge:\n"
+"%%s"
 msgstr ""
 
-#: builtin/commit.c:1450
-msgid "suppress summary after successful commit"
+#: unpack-trees.c:141
+#, c-format
+msgid ""
+"The following untracked working tree files would be removed by %s:\n"
+"%%sPlease move or remove them before you %s."
 msgstr ""
 
-#: builtin/commit.c:1451
-msgid "show diff in commit message template"
+#: unpack-trees.c:143
+#, c-format
+msgid ""
+"The following untracked working tree files would be removed by %s:\n"
+"%%s"
 msgstr ""
 
-#: builtin/commit.c:1453
-msgid "Commit message options"
+#: unpack-trees.c:149
+#, c-format
+msgid ""
+"The following untracked working tree files would be overwritten by "
+"checkout:\n"
+"%%sPlease move or remove them before you switch branches."
 msgstr ""
 
-#: builtin/commit.c:1454 builtin/tag.c:394
-msgid "read message from file"
+#: unpack-trees.c:151
+#, c-format
+msgid ""
+"The following untracked working tree files would be overwritten by "
+"checkout:\n"
+"%%s"
 msgstr ""
 
-#: builtin/commit.c:1455
-msgid "author"
+#: unpack-trees.c:154
+#, c-format
+msgid ""
+"The following untracked working tree files would be overwritten by merge:\n"
+"%%sPlease move or remove them before you merge."
 msgstr ""
 
-#: builtin/commit.c:1455
-msgid "override author for commit"
+#: unpack-trees.c:156
+#, c-format
+msgid ""
+"The following untracked working tree files would be overwritten by merge:\n"
+"%%s"
 msgstr ""
 
-#: builtin/commit.c:1456 builtin/gc.c:501
-msgid "date"
+#: unpack-trees.c:159
+#, c-format
+msgid ""
+"The following untracked working tree files would be overwritten by %s:\n"
+"%%sPlease move or remove them before you %s."
 msgstr ""
 
-#: builtin/commit.c:1456
-msgid "override date for commit"
+#: unpack-trees.c:161
+#, c-format
+msgid ""
+"The following untracked working tree files would be overwritten by %s:\n"
+"%%s"
 msgstr ""
 
-#: builtin/commit.c:1457 builtin/merge.c:228 builtin/notes.c:402
-#: builtin/notes.c:565 builtin/tag.c:392
-msgid "message"
+#: unpack-trees.c:169
+#, c-format
+msgid "Entry '%s' overlaps with '%s'.  Cannot bind."
 msgstr ""
 
-#: builtin/commit.c:1457
-msgid "commit message"
+#: unpack-trees.c:172
+#, c-format
+msgid ""
+"Cannot update sparse checkout: the following entries are not up to date:\n"
+"%s"
 msgstr ""
 
-#: builtin/commit.c:1458 builtin/commit.c:1459 builtin/commit.c:1460
-#: builtin/commit.c:1461 parse-options.h:270 ref-filter.h:92
-msgid "commit"
+#: unpack-trees.c:174
+#, c-format
+msgid ""
+"The following working tree files would be overwritten by sparse checkout "
+"update:\n"
+"%s"
 msgstr ""
 
-#: builtin/commit.c:1458
-msgid "reuse and edit message from specified commit"
+#: unpack-trees.c:176
+#, c-format
+msgid ""
+"The following working tree files would be removed by sparse checkout "
+"update:\n"
+"%s"
 msgstr ""
 
-#: builtin/commit.c:1459
-msgid "reuse message from specified commit"
+#: unpack-trees.c:178
+#, c-format
+msgid ""
+"Cannot update submodule:\n"
+"%s"
 msgstr ""
 
-#: builtin/commit.c:1460
-msgid "use autosquash formatted message to fixup specified commit"
+#: unpack-trees.c:255
+#, c-format
+msgid "Aborting\n"
 msgstr ""
 
-#: builtin/commit.c:1461
-msgid "use autosquash formatted message to squash specified commit"
+#: unpack-trees.c:317
+msgid "Updating files"
 msgstr ""
 
-#: builtin/commit.c:1462
-msgid "the commit is authored by me now (used with -C/-c/--amend)"
+#: unpack-trees.c:349
+msgid ""
+"the following paths have collided (e.g. case-sensitive paths\n"
+"on a case-insensitive filesystem) and only one from the same\n"
+"colliding group is in the working tree:\n"
 msgstr ""
 
-#: builtin/commit.c:1463 builtin/log.c:1446 builtin/merge.c:242
-#: builtin/pull.c:154 builtin/revert.c:105
-msgid "add Signed-off-by:"
+#: unpack-trees.c:1441
+msgid "Updating index flags"
 msgstr ""
 
-#: builtin/commit.c:1464
-msgid "use specified template file"
+#: urlmatch.c:163
+msgid "invalid URL scheme name or missing '://' suffix"
 msgstr ""
 
-#: builtin/commit.c:1465
-msgid "force edit of commit"
+#: urlmatch.c:187 urlmatch.c:346 urlmatch.c:405
+#, c-format
+msgid "invalid %XX escape sequence"
 msgstr ""
 
-#: builtin/commit.c:1466
-msgid "default"
+#: urlmatch.c:215
+msgid "missing host and scheme is not 'file:'"
 msgstr ""
 
-#: builtin/commit.c:1466 builtin/tag.c:398
-msgid "how to strip spaces and #comments from message"
+#: urlmatch.c:232
+msgid "a 'file:' URL may not have a port number"
 msgstr ""
 
-#: builtin/commit.c:1467
-msgid "include status in commit message template"
+#: urlmatch.c:247
+msgid "invalid characters in host name"
 msgstr ""
 
-#: builtin/commit.c:1469 builtin/merge.c:240 builtin/pull.c:184
-#: builtin/revert.c:113
-msgid "GPG sign commit"
+#: urlmatch.c:292 urlmatch.c:303
+msgid "invalid port number"
 msgstr ""
 
-#: builtin/commit.c:1472
-msgid "Commit contents options"
+#: urlmatch.c:371
+msgid "invalid '..' path segment"
 msgstr ""
 
-#: builtin/commit.c:1473
-msgid "commit all changed files"
+#: worktree.c:258 builtin/am.c:2084
+#, c-format
+msgid "failed to read '%s'"
 msgstr ""
 
-#: builtin/commit.c:1474
-msgid "add specified files to index for commit"
+#: worktree.c:304
+#, c-format
+msgid "'%s' at main working tree is not the repository directory"
 msgstr ""
 
-#: builtin/commit.c:1475
-msgid "interactively add files"
+#: worktree.c:315
+#, c-format
+msgid "'%s' file does not contain absolute path to the working tree location"
 msgstr ""
 
-#: builtin/commit.c:1476
-msgid "interactively add changes"
+#: worktree.c:327
+#, c-format
+msgid "'%s' does not exist"
 msgstr ""
 
-#: builtin/commit.c:1477
-msgid "commit only specified files"
+#: worktree.c:333
+#, c-format
+msgid "'%s' is not a .git file, error code %d"
 msgstr ""
 
-#: builtin/commit.c:1478
-msgid "bypass pre-commit and commit-msg hooks"
+#: worktree.c:341
+#, c-format
+msgid "'%s' does not point back to '%s'"
 msgstr ""
 
-#: builtin/commit.c:1479
-msgid "show what would be committed"
+#: wrapper.c:186 wrapper.c:356
+#, c-format
+msgid "could not open '%s' for reading and writing"
 msgstr ""
 
-#: builtin/commit.c:1492
-msgid "amend previous commit"
+#: wrapper.c:387 wrapper.c:588
+#, c-format
+msgid "unable to access '%s'"
 msgstr ""
 
-#: builtin/commit.c:1493
-msgid "bypass post-rewrite hook"
+#: wrapper.c:596
+msgid "unable to get current working directory"
 msgstr ""
 
-#: builtin/commit.c:1498
-msgid "ok to record an empty change"
+#: wt-status.c:158
+msgid "Unmerged paths:"
 msgstr ""
 
-#: builtin/commit.c:1500
-msgid "ok to record a change with an empty message"
+#: wt-status.c:187 wt-status.c:219
+msgid "  (use \"git restore --staged <file>...\" to unstage)"
 msgstr ""
 
-#: builtin/commit.c:1573
+#: wt-status.c:190 wt-status.c:222
 #, c-format
-msgid "Corrupt MERGE_HEAD file (%s)"
+msgid "  (use \"git restore --source=%s --staged <file>...\" to unstage)"
 msgstr ""
 
-#: builtin/commit.c:1580
-msgid "could not read MERGE_MODE"
+#: wt-status.c:193 wt-status.c:225
+msgid "  (use \"git rm --cached <file>...\" to unstage)"
 msgstr ""
 
-#: builtin/commit.c:1599
-#, c-format
-msgid "could not read commit message: %s"
+#: wt-status.c:197
+msgid "  (use \"git add <file>...\" to mark resolution)"
 msgstr ""
 
-#: builtin/commit.c:1610
-#, c-format
-msgid "Aborting commit due to empty commit message.\n"
+#: wt-status.c:199 wt-status.c:203
+msgid "  (use \"git add/rm <file>...\" as appropriate to mark resolution)"
 msgstr ""
 
-#: builtin/commit.c:1615
-#, c-format
-msgid "Aborting commit; you did not edit the message.\n"
+#: wt-status.c:201
+msgid "  (use \"git rm <file>...\" to mark resolution)"
 msgstr ""
 
-#: builtin/commit.c:1650
-msgid ""
-"Repository has been updated, but unable to write\n"
-"new_index file. Check that disk is not full and quota is\n"
-"not exceeded, and then \"git reset HEAD\" to recover."
+#: wt-status.c:211 wt-status.c:1074
+msgid "Changes to be committed:"
+msgstr ""
+
+#: wt-status.c:234 wt-status.c:1083
+msgid "Changes not staged for commit:"
 msgstr ""
 
-#: builtin/commit-graph.c:9
-msgid "git commit-graph [--object-dir <objdir>]"
+#: wt-status.c:238
+msgid "  (use \"git add <file>...\" to update what will be committed)"
 msgstr ""
 
-#: builtin/commit-graph.c:10 builtin/commit-graph.c:16
-msgid "git commit-graph read [--object-dir <objdir>]"
+#: wt-status.c:240
+msgid "  (use \"git add/rm <file>...\" to update what will be committed)"
 msgstr ""
 
-#: builtin/commit-graph.c:11 builtin/commit-graph.c:21
+#: wt-status.c:241
 msgid ""
-"git commit-graph write [--object-dir <objdir>] [--append] [--stdin-packs|--"
-"stdin-commits]"
+"  (use \"git restore <file>...\" to discard changes in working directory)"
 msgstr ""
 
-#: builtin/commit-graph.c:39 builtin/commit-graph.c:92
-#: builtin/commit-graph.c:147 builtin/fetch.c:161 builtin/log.c:1466
-msgid "dir"
+#: wt-status.c:243
+msgid "  (commit or discard the untracked or modified content in submodules)"
 msgstr ""
 
-#: builtin/commit-graph.c:40 builtin/commit-graph.c:93
-#: builtin/commit-graph.c:148
-msgid "The object directory to store the graph"
+#: wt-status.c:254
+#, c-format
+msgid "  (use \"git %s <file>...\" to include in what will be committed)"
 msgstr ""
 
-#: builtin/commit-graph.c:95
-msgid "scan pack-indexes listed by stdin for commits"
+#: wt-status.c:268
+msgid "both deleted:"
 msgstr ""
 
-#: builtin/commit-graph.c:97
-msgid "start walk at commits listed by stdin"
+#: wt-status.c:270
+msgid "added by us:"
 msgstr ""
 
-#: builtin/commit-graph.c:99
-msgid "include all commits already in the commit-graph file"
+#: wt-status.c:272
+msgid "deleted by them:"
 msgstr ""
 
-#: builtin/commit-graph.c:108
-msgid "cannot use both --stdin-commits and --stdin-packs"
+#: wt-status.c:274
+msgid "added by them:"
 msgstr ""
 
-#: builtin/config.c:10
-msgid "git config [<options>]"
+#: wt-status.c:276
+msgid "deleted by us:"
 msgstr ""
 
-#: builtin/config.c:101
-#, c-format
-msgid "unrecognized --type argument, %s"
+#: wt-status.c:278
+msgid "both added:"
 msgstr ""
 
-#: builtin/config.c:123
-msgid "Config file location"
+#: wt-status.c:280
+msgid "both modified:"
 msgstr ""
 
-#: builtin/config.c:124
-msgid "use global config file"
+#: wt-status.c:290
+msgid "new file:"
 msgstr ""
 
-#: builtin/config.c:125
-msgid "use system config file"
+#: wt-status.c:292
+msgid "copied:"
 msgstr ""
 
-#: builtin/config.c:126
-msgid "use repository config file"
-msgstr ""
-
-#: builtin/config.c:127
-msgid "use given config file"
-msgstr ""
-
-#: builtin/config.c:128
-msgid "blob-id"
+#: wt-status.c:294
+msgid "deleted:"
 msgstr ""
 
-#: builtin/config.c:128
-msgid "read config from given blob object"
+#: wt-status.c:296
+msgid "modified:"
 msgstr ""
 
-#: builtin/config.c:129
-msgid "Action"
+#: wt-status.c:298
+msgid "renamed:"
 msgstr ""
 
-#: builtin/config.c:130
-msgid "get value: name [value-regex]"
+#: wt-status.c:300
+msgid "typechange:"
 msgstr ""
 
-#: builtin/config.c:131
-msgid "get all values: key [value-regex]"
+#: wt-status.c:302
+msgid "unknown:"
 msgstr ""
 
-#: builtin/config.c:132
-msgid "get values for regexp: name-regex [value-regex]"
+#: wt-status.c:304
+msgid "unmerged:"
 msgstr ""
 
-#: builtin/config.c:133
-msgid "get value specific for the URL: section[.var] URL"
+#: wt-status.c:384
+msgid "new commits, "
 msgstr ""
 
-#: builtin/config.c:134
-msgid "replace all matching variables: name value [value_regex]"
+#: wt-status.c:386
+msgid "modified content, "
 msgstr ""
 
-#: builtin/config.c:135
-msgid "add a new variable: name value"
+#: wt-status.c:388
+msgid "untracked content, "
 msgstr ""
 
-#: builtin/config.c:136
-msgid "remove a variable: name [value-regex]"
-msgstr ""
+#: wt-status.c:906
+#, c-format
+msgid "Your stash currently has %d entry"
+msgid_plural "Your stash currently has %d entries"
+msgstr[0] ""
+msgstr[1] ""
 
-#: builtin/config.c:137
-msgid "remove all matches: name [value-regex]"
+#: wt-status.c:938
+msgid "Submodules changed but not updated:"
 msgstr ""
 
-#: builtin/config.c:138
-msgid "rename section: old-name new-name"
+#: wt-status.c:940
+msgid "Submodule changes to be committed:"
 msgstr ""
 
-#: builtin/config.c:139
-msgid "remove a section: name"
+#: wt-status.c:1022
+msgid ""
+"Do not modify or remove the line above.\n"
+"Everything below it will be ignored."
 msgstr ""
 
-#: builtin/config.c:140
-msgid "list all"
+#: wt-status.c:1114
+#, c-format
+msgid ""
+"\n"
+"It took %.2f seconds to compute the branch ahead/behind values.\n"
+"You can use '--no-ahead-behind' to avoid this.\n"
 msgstr ""
 
-#: builtin/config.c:141
-msgid "open an editor"
+#: wt-status.c:1144
+msgid "You have unmerged paths."
 msgstr ""
 
-#: builtin/config.c:142
-msgid "find the color configured: slot [default]"
+#: wt-status.c:1147
+msgid "  (fix conflicts and run \"git commit\")"
 msgstr ""
 
-#: builtin/config.c:143
-msgid "find the color setting: slot [stdout-is-tty]"
+#: wt-status.c:1149
+msgid "  (use \"git merge --abort\" to abort the merge)"
 msgstr ""
 
-#: builtin/config.c:144
-msgid "Type"
+#: wt-status.c:1153
+msgid "All conflicts fixed but you are still merging."
 msgstr ""
 
-#: builtin/config.c:145
-msgid "value is given this type"
+#: wt-status.c:1156
+msgid "  (use \"git commit\" to conclude merge)"
 msgstr ""
 
-#: builtin/config.c:146
-msgid "value is \"true\" or \"false\""
+#: wt-status.c:1165
+msgid "You are in the middle of an am session."
 msgstr ""
 
-#: builtin/config.c:147
-msgid "value is decimal number"
+#: wt-status.c:1168
+msgid "The current patch is empty."
 msgstr ""
 
-#: builtin/config.c:148
-msgid "value is --bool or --int"
+#: wt-status.c:1172
+msgid "  (fix conflicts and then run \"git am --continue\")"
 msgstr ""
 
-#: builtin/config.c:149
-msgid "value is a path (file or directory name)"
+#: wt-status.c:1174
+msgid "  (use \"git am --skip\" to skip this patch)"
 msgstr ""
 
-#: builtin/config.c:150
-msgid "value is an expiry date"
+#: wt-status.c:1176
+msgid "  (use \"git am --abort\" to restore the original branch)"
 msgstr ""
 
-#: builtin/config.c:151
-msgid "Other"
+#: wt-status.c:1309
+msgid "git-rebase-todo is missing."
 msgstr ""
 
-#: builtin/config.c:152
-msgid "terminate values with NUL byte"
+#: wt-status.c:1311
+msgid "No commands done."
 msgstr ""
 
-#: builtin/config.c:153
-msgid "show variable names only"
-msgstr ""
+#: wt-status.c:1314
+#, c-format
+msgid "Last command done (%d command done):"
+msgid_plural "Last commands done (%d commands done):"
+msgstr[0] ""
+msgstr[1] ""
 
-#: builtin/config.c:154
-msgid "respect include directives on lookup"
+#: wt-status.c:1325
+#, c-format
+msgid "  (see more in file %s)"
 msgstr ""
 
-#: builtin/config.c:155
-msgid "show origin of config (file, standard input, blob, command line)"
+#: wt-status.c:1330
+msgid "No commands remaining."
 msgstr ""
 
-#: builtin/config.c:156
-msgid "value"
-msgstr ""
+#: wt-status.c:1333
+#, c-format
+msgid "Next command to do (%d remaining command):"
+msgid_plural "Next commands to do (%d remaining commands):"
+msgstr[0] ""
+msgstr[1] ""
 
-#: builtin/config.c:156
-msgid "with --get, use default value when missing entry"
+#: wt-status.c:1341
+msgid "  (use \"git rebase --edit-todo\" to view and edit)"
 msgstr ""
 
-#: builtin/config.c:332
+#: wt-status.c:1353
 #, c-format
-msgid "failed to format default config value: %s"
+msgid "You are currently rebasing branch '%s' on '%s'."
 msgstr ""
 
-#: builtin/config.c:431
-msgid "unable to parse default color value"
+#: wt-status.c:1358
+msgid "You are currently rebasing."
 msgstr ""
 
-#: builtin/config.c:575
-#, c-format
-msgid ""
-"# This is Git's per-user configuration file.\n"
-"[user]\n"
-"# Please adapt and uncomment the following lines:\n"
-"#\tname = %s\n"
-"#\temail = %s\n"
+#: wt-status.c:1371
+msgid "  (fix conflicts and then run \"git rebase --continue\")"
 msgstr ""
 
-#: builtin/config.c:603
-msgid "--local can only be used inside a git repository"
+#: wt-status.c:1373
+msgid "  (use \"git rebase --skip\" to skip this patch)"
 msgstr ""
 
-#: builtin/config.c:606
-msgid "--blob can only be used inside a git repository"
+#: wt-status.c:1375
+msgid "  (use \"git rebase --abort\" to check out the original branch)"
 msgstr ""
 
-#: builtin/config.c:735
-#, c-format
-msgid "cannot create configuration file %s"
+#: wt-status.c:1382
+msgid "  (all conflicts fixed: run \"git rebase --continue\")"
 msgstr ""
 
-#: builtin/config.c:748
+#: wt-status.c:1386
 #, c-format
 msgid ""
-"cannot overwrite multiple values with a single value\n"
-"       Use a regexp, --add or --replace-all to change %s."
+"You are currently splitting a commit while rebasing branch '%s' on '%s'."
 msgstr ""
 
-#: builtin/count-objects.c:90
-msgid "git count-objects [-v] [-H | --human-readable]"
+#: wt-status.c:1391
+msgid "You are currently splitting a commit during a rebase."
 msgstr ""
 
-#: builtin/count-objects.c:100
-msgid "print sizes in human readable format"
+#: wt-status.c:1394
+msgid "  (Once your working directory is clean, run \"git rebase --continue\")"
 msgstr ""
 
-#: builtin/describe.c:22
-msgid "git describe [<options>] [<commit-ish>...]"
+#: wt-status.c:1398
+#, c-format
+msgid "You are currently editing a commit while rebasing branch '%s' on '%s'."
 msgstr ""
 
-#: builtin/describe.c:23
-msgid "git describe [<options>] --dirty"
+#: wt-status.c:1403
+msgid "You are currently editing a commit during a rebase."
 msgstr ""
 
-#: builtin/describe.c:57
-msgid "head"
+#: wt-status.c:1406
+msgid "  (use \"git commit --amend\" to amend the current commit)"
 msgstr ""
 
-#: builtin/describe.c:57
-msgid "lightweight"
+#: wt-status.c:1408
+msgid ""
+"  (use \"git rebase --continue\" once you are satisfied with your changes)"
 msgstr ""
 
-#: builtin/describe.c:57
-msgid "annotated"
+#: wt-status.c:1419
+msgid "Cherry-pick currently in progress."
 msgstr ""
 
-#: builtin/describe.c:267
+#: wt-status.c:1422
 #, c-format
-msgid "annotated tag %s not available"
+msgid "You are currently cherry-picking commit %s."
 msgstr ""
 
-#: builtin/describe.c:271
-#, c-format
-msgid "annotated tag %s has no embedded name"
+#: wt-status.c:1429
+msgid "  (fix conflicts and run \"git cherry-pick --continue\")"
 msgstr ""
 
-#: builtin/describe.c:273
-#, c-format
-msgid "tag '%s' is really '%s' here"
+#: wt-status.c:1432
+msgid "  (run \"git cherry-pick --continue\" to continue)"
 msgstr ""
 
-#: builtin/describe.c:317
-#, c-format
-msgid "no tag exactly matches '%s'"
+#: wt-status.c:1435
+msgid "  (all conflicts fixed: run \"git cherry-pick --continue\")"
 msgstr ""
 
-#: builtin/describe.c:319
-#, c-format
-msgid "No exact match on refs or tags, searching to describe\n"
+#: wt-status.c:1437
+msgid "  (use \"git cherry-pick --skip\" to skip this patch)"
 msgstr ""
 
-#: builtin/describe.c:366
-#, c-format
-msgid "finished search at %s\n"
+#: wt-status.c:1439
+msgid "  (use \"git cherry-pick --abort\" to cancel the cherry-pick operation)"
 msgstr ""
 
-#: builtin/describe.c:392
-#, c-format
-msgid ""
-"No annotated tags can describe '%s'.\n"
-"However, there were unannotated tags: try --tags."
+#: wt-status.c:1449
+msgid "Revert currently in progress."
 msgstr ""
 
-#: builtin/describe.c:396
+#: wt-status.c:1452
 #, c-format
-msgid ""
-"No tags can describe '%s'.\n"
-"Try --always, or create some tags."
+msgid "You are currently reverting commit %s."
 msgstr ""
 
-#: builtin/describe.c:426
-#, c-format
-msgid "traversed %lu commits\n"
+#: wt-status.c:1458
+msgid "  (fix conflicts and run \"git revert --continue\")"
 msgstr ""
 
-#: builtin/describe.c:429
-#, c-format
-msgid ""
-"more than %i tags found; listed %i most recent\n"
-"gave up search at %s\n"
+#: wt-status.c:1461
+msgid "  (run \"git revert --continue\" to continue)"
 msgstr ""
 
-#: builtin/describe.c:497
-#, c-format
-msgid "describe %s\n"
+#: wt-status.c:1464
+msgid "  (all conflicts fixed: run \"git revert --continue\")"
 msgstr ""
 
-#: builtin/describe.c:500 builtin/log.c:502
-#, c-format
-msgid "Not a valid object name %s"
+#: wt-status.c:1466
+msgid "  (use \"git revert --skip\" to skip this patch)"
 msgstr ""
 
-#: builtin/describe.c:508
-#, c-format
-msgid "%s is neither a commit nor blob"
+#: wt-status.c:1468
+msgid "  (use \"git revert --abort\" to cancel the revert operation)"
 msgstr ""
 
-#: builtin/describe.c:522
-msgid "find the tag that comes after the commit"
+#: wt-status.c:1478
+#, c-format
+msgid "You are currently bisecting, started from branch '%s'."
 msgstr ""
 
-#: builtin/describe.c:523
-msgid "debug search strategy on stderr"
+#: wt-status.c:1482
+msgid "You are currently bisecting."
 msgstr ""
 
-#: builtin/describe.c:524
-msgid "use any ref"
+#: wt-status.c:1485
+msgid "  (use \"git bisect reset\" to get back to the original branch)"
 msgstr ""
 
-#: builtin/describe.c:525
-msgid "use any tag, even unannotated"
+#: wt-status.c:1694
+msgid "On branch "
 msgstr ""
 
-#: builtin/describe.c:526
-msgid "always use long format"
+#: wt-status.c:1701
+msgid "interactive rebase in progress; onto "
 msgstr ""
 
-#: builtin/describe.c:527
-msgid "only follow first parent"
+#: wt-status.c:1703
+msgid "rebase in progress; onto "
 msgstr ""
 
-#: builtin/describe.c:530
-msgid "only output exact matches"
+#: wt-status.c:1713
+msgid "Not currently on any branch."
 msgstr ""
 
-#: builtin/describe.c:532
-msgid "consider <n> most recent tags (default: 10)"
+#: wt-status.c:1730
+msgid "Initial commit"
 msgstr ""
 
-#: builtin/describe.c:534
-msgid "only consider tags matching <pattern>"
+#: wt-status.c:1731
+msgid "No commits yet"
 msgstr ""
 
-#: builtin/describe.c:536
-msgid "do not consider tags matching <pattern>"
+#: wt-status.c:1745
+msgid "Untracked files"
 msgstr ""
 
-#: builtin/describe.c:538 builtin/name-rev.c:406
-msgid "show abbreviated commit object as fallback"
+#: wt-status.c:1747
+msgid "Ignored files"
 msgstr ""
 
-#: builtin/describe.c:539 builtin/describe.c:542
-msgid "mark"
+#: wt-status.c:1751
+#, c-format
+msgid ""
+"It took %.2f seconds to enumerate untracked files. 'status -uno'\n"
+"may speed it up, but you have to be careful not to forget to add\n"
+"new files yourself (see 'git help status')."
 msgstr ""
 
-#: builtin/describe.c:540
-msgid "append <mark> on dirty working tree (default: \"-dirty\")"
+#: wt-status.c:1757
+#, c-format
+msgid "Untracked files not listed%s"
 msgstr ""
 
-#: builtin/describe.c:543
-msgid "append <mark> on broken working tree (default: \"-broken\")"
+#: wt-status.c:1759
+msgid " (use -u option to show untracked files)"
 msgstr ""
 
-#: builtin/describe.c:561
-msgid "--long is incompatible with --abbrev=0"
+#: wt-status.c:1765
+msgid "No changes"
 msgstr ""
 
-#: builtin/describe.c:590
-msgid "No names found, cannot describe anything."
+#: wt-status.c:1770
+#, c-format
+msgid "no changes added to commit (use \"git add\" and/or \"git commit -a\")\n"
 msgstr ""
 
-#: builtin/describe.c:640
-msgid "--dirty is incompatible with commit-ishes"
+#: wt-status.c:1773
+#, c-format
+msgid "no changes added to commit\n"
 msgstr ""
 
-#: builtin/describe.c:642
-msgid "--broken is incompatible with commit-ishes"
+#: wt-status.c:1776
+#, c-format
+msgid ""
+"nothing added to commit but untracked files present (use \"git add\" to "
+"track)\n"
 msgstr ""
 
-#: builtin/diff.c:83
+#: wt-status.c:1779
 #, c-format
-msgid "'%s': not a regular file or symlink"
+msgid "nothing added to commit but untracked files present\n"
 msgstr ""
 
-#: builtin/diff.c:234
+#: wt-status.c:1782
 #, c-format
-msgid "invalid option: %s"
+msgid "nothing to commit (create/copy files and use \"git add\" to track)\n"
 msgstr ""
 
-#: builtin/diff.c:356
-msgid "Not a git repository"
+#: wt-status.c:1785 wt-status.c:1790
+#, c-format
+msgid "nothing to commit\n"
 msgstr ""
 
-#: builtin/diff.c:399
+#: wt-status.c:1788
 #, c-format
-msgid "invalid object '%s' given."
+msgid "nothing to commit (use -u to show untracked files)\n"
 msgstr ""
 
-#: builtin/diff.c:408
+#: wt-status.c:1792
 #, c-format
-msgid "more than two blobs given: '%s'"
+msgid "nothing to commit, working tree clean\n"
 msgstr ""
 
-#: builtin/diff.c:413
-#, c-format
-msgid "unhandled object '%s' given."
+#: wt-status.c:1905
+msgid "No commits yet on "
 msgstr ""
 
-#: builtin/difftool.c:29
-msgid "git difftool [<options>] [<commit> [<commit>]] [--] [<path>...]"
+#: wt-status.c:1909
+msgid "HEAD (no branch)"
 msgstr ""
 
-#: builtin/difftool.c:259
-#, c-format
-msgid "failed: %d"
+#: wt-status.c:1940
+msgid "different"
 msgstr ""
 
-#: builtin/difftool.c:301
-#, c-format
-msgid "could not read symlink %s"
+#: wt-status.c:1942 wt-status.c:1950
+msgid "behind "
 msgstr ""
 
-#: builtin/difftool.c:303
-#, c-format
-msgid "could not read symlink file %s"
+#: wt-status.c:1945 wt-status.c:1948
+msgid "ahead "
 msgstr ""
 
-#: builtin/difftool.c:311
+#. TRANSLATORS: the action is e.g. "pull with rebase"
+#: wt-status.c:2470
 #, c-format
-msgid "could not read object %s for symlink %s"
+msgid "cannot %s: You have unstaged changes."
 msgstr ""
 
-#: builtin/difftool.c:412
-msgid ""
-"combined diff formats('-c' and '--cc') are not supported in\n"
-"directory diff mode('-d' and '--dir-diff')."
+#: wt-status.c:2476
+msgid "additionally, your index contains uncommitted changes."
 msgstr ""
 
-#: builtin/difftool.c:632
+#: wt-status.c:2478
 #, c-format
-msgid "both files modified: '%s' and '%s'."
-msgstr ""
-
-#: builtin/difftool.c:634
-msgid "working tree file has been left."
+msgid "cannot %s: Your index contains uncommitted changes."
 msgstr ""
 
-#: builtin/difftool.c:645
+#: compat/precompose_utf8.c:58 builtin/clone.c:455
 #, c-format
-msgid "temporary files exist in '%s'."
+msgid "failed to unlink '%s'"
 msgstr ""
 
-#: builtin/difftool.c:646
-msgid "you may want to cleanup or recover these."
+#: builtin/add.c:26
+msgid "git add [<options>] [--] <pathspec>..."
 msgstr ""
 
-#: builtin/difftool.c:695
-msgid "use `diff.guitool` instead of `diff.tool`"
+#: builtin/add.c:87
+#, c-format
+msgid "unexpected diff status %c"
 msgstr ""
 
-#: builtin/difftool.c:697
-msgid "perform a full-directory diff"
+#: builtin/add.c:92 builtin/commit.c:288
+msgid "updating files failed"
 msgstr ""
 
-#: builtin/difftool.c:699
-msgid "do not prompt before launching a diff tool"
+#: builtin/add.c:102
+#, c-format
+msgid "remove '%s'\n"
 msgstr ""
 
-#: builtin/difftool.c:704
-msgid "use symlinks in dir-diff mode"
+#: builtin/add.c:177
+msgid "Unstaged changes after refreshing the index:"
 msgstr ""
 
-#: builtin/difftool.c:705
-msgid "<tool>"
+#: builtin/add.c:252 builtin/rev-parse.c:899
+msgid "Could not read the index"
 msgstr ""
 
-#: builtin/difftool.c:706
-msgid "use the specified diff tool"
+#: builtin/add.c:263
+#, c-format
+msgid "Could not open '%s' for writing."
 msgstr ""
 
-#: builtin/difftool.c:708
-msgid "print a list of diff tools that may be used with `--tool`"
+#: builtin/add.c:267
+msgid "Could not write patch"
 msgstr ""
 
-#: builtin/difftool.c:711
-msgid ""
-"make 'git-difftool' exit when an invoked diff tool returns a non - zero exit "
-"code"
+#: builtin/add.c:270
+msgid "editing patch failed"
 msgstr ""
 
-#: builtin/difftool.c:713
-msgid "<command>"
+#: builtin/add.c:273
+#, c-format
+msgid "Could not stat '%s'"
 msgstr ""
 
-#: builtin/difftool.c:714
-msgid "specify a custom command for viewing diffs"
+#: builtin/add.c:275
+msgid "Empty patch. Aborted."
 msgstr ""
 
-#: builtin/difftool.c:738
-msgid "no <tool> given for --tool=<tool>"
+#: builtin/add.c:280
+#, c-format
+msgid "Could not apply '%s'"
 msgstr ""
 
-#: builtin/difftool.c:745
-msgid "no <cmd> given for --extcmd=<cmd>"
+#: builtin/add.c:288
+msgid "The following paths are ignored by one of your .gitignore files:\n"
 msgstr ""
 
-#: builtin/fast-export.c:27
-msgid "git fast-export [rev-list-opts]"
+#: builtin/add.c:308 builtin/clean.c:910 builtin/fetch.c:163 builtin/mv.c:124
+#: builtin/prune-packed.c:56 builtin/pull.c:223 builtin/push.c:548
+#: builtin/remote.c:1344 builtin/rm.c:241 builtin/send-pack.c:165
+msgid "dry run"
 msgstr ""
 
-#: builtin/fast-export.c:1000
-msgid "show progress after <n> objects"
+#: builtin/add.c:311
+msgid "interactive picking"
 msgstr ""
 
-#: builtin/fast-export.c:1002
-msgid "select handling of signed tags"
+#: builtin/add.c:312 builtin/checkout.c:1482 builtin/reset.c:307
+msgid "select hunks interactively"
 msgstr ""
 
-#: builtin/fast-export.c:1005
-msgid "select handling of tags that tag filtered objects"
+#: builtin/add.c:313
+msgid "edit current diff and apply"
 msgstr ""
 
-#: builtin/fast-export.c:1008
-msgid "Dump marks to this file"
+#: builtin/add.c:314
+msgid "allow adding otherwise ignored files"
 msgstr ""
 
-#: builtin/fast-export.c:1010
-msgid "Import marks from this file"
+#: builtin/add.c:315
+msgid "update tracked files"
 msgstr ""
 
-#: builtin/fast-export.c:1012
-msgid "Fake a tagger when tags lack one"
+#: builtin/add.c:316
+msgid "renormalize EOL of tracked files (implies -u)"
 msgstr ""
 
-#: builtin/fast-export.c:1014
-msgid "Output full tree for each commit"
+#: builtin/add.c:317
+msgid "record only the fact that the path will be added later"
 msgstr ""
 
-#: builtin/fast-export.c:1016
-msgid "Use the done feature to terminate the stream"
+#: builtin/add.c:318
+msgid "add changes from all tracked and untracked files"
 msgstr ""
 
-#: builtin/fast-export.c:1017
-msgid "Skip output of blob data"
+#: builtin/add.c:321
+msgid "ignore paths removed in the working tree (same as --no-all)"
 msgstr ""
 
-#: builtin/fast-export.c:1018
-msgid "refspec"
+#: builtin/add.c:323
+msgid "don't add, only refresh the index"
 msgstr ""
 
-#: builtin/fast-export.c:1019
-msgid "Apply refspec to exported refs"
+#: builtin/add.c:324
+msgid "just skip files which cannot be added because of errors"
 msgstr ""
 
-#: builtin/fast-export.c:1020
-msgid "anonymize output"
+#: builtin/add.c:325
+msgid "check if - even missing - files are ignored in dry run"
 msgstr ""
 
-#: builtin/fetch.c:26
-msgid "git fetch [<options>] [<repository> [<refspec>...]]"
+#: builtin/add.c:327 builtin/update-index.c:1004
+msgid "override the executable bit of the listed files"
 msgstr ""
 
-#: builtin/fetch.c:27
-msgid "git fetch [<options>] <group>"
+#: builtin/add.c:329
+msgid "warn when adding an embedded repository"
 msgstr ""
 
-#: builtin/fetch.c:28
-msgid "git fetch --multiple [<options>] [(<repository> | <group>)...]"
+#: builtin/add.c:347
+#, c-format
+msgid ""
+"You've added another git repository inside your current repository.\n"
+"Clones of the outer repository will not contain the contents of\n"
+"the embedded repository and will not know how to obtain it.\n"
+"If you meant to add a submodule, use:\n"
+"\n"
+"\tgit submodule add <url> %s\n"
+"\n"
+"If you added this path by mistake, you can remove it from the\n"
+"index with:\n"
+"\n"
+"\tgit rm --cached %s\n"
+"\n"
+"See \"git help submodule\" for more information."
 msgstr ""
 
-#: builtin/fetch.c:29
-msgid "git fetch --all [<options>]"
+#: builtin/add.c:375
+#, c-format
+msgid "adding embedded git repository: %s"
 msgstr ""
 
-#: builtin/fetch.c:123 builtin/pull.c:193
-msgid "fetch from all remotes"
+#: builtin/add.c:393
+#, c-format
+msgid "Use -f if you really want to add them.\n"
 msgstr ""
 
-#: builtin/fetch.c:125 builtin/pull.c:196
-msgid "append to .git/FETCH_HEAD instead of overwriting"
+#: builtin/add.c:400
+msgid "adding files failed"
 msgstr ""
 
-#: builtin/fetch.c:127 builtin/pull.c:199
-msgid "path to upload pack on remote end"
+#: builtin/add.c:428 builtin/commit.c:348
+msgid "--pathspec-from-file is incompatible with --interactive/--patch"
 msgstr ""
 
-#: builtin/fetch.c:128 builtin/pull.c:201
-msgid "force overwrite of local branch"
+#: builtin/add.c:434
+msgid "--pathspec-from-file is incompatible with --edit"
 msgstr ""
 
-#: builtin/fetch.c:130
-msgid "fetch from multiple remotes"
+#: builtin/add.c:446
+msgid "-A and -u are mutually incompatible"
 msgstr ""
 
-#: builtin/fetch.c:132 builtin/pull.c:203
-msgid "fetch all tags and associated objects"
+#: builtin/add.c:449
+msgid "Option --ignore-missing can only be used together with --dry-run"
 msgstr ""
 
-#: builtin/fetch.c:134
-msgid "do not fetch all tags (--no-tags)"
+#: builtin/add.c:453
+#, c-format
+msgid "--chmod param '%s' must be either -x or +x"
 msgstr ""
 
-#: builtin/fetch.c:136
-msgid "number of submodules fetched in parallel"
+#: builtin/add.c:471 builtin/checkout.c:1648 builtin/commit.c:354
+#: builtin/reset.c:327
+msgid "--pathspec-from-file is incompatible with pathspec arguments"
 msgstr ""
 
-#: builtin/fetch.c:138 builtin/pull.c:206
-msgid "prune remote-tracking branches no longer on remote"
+#: builtin/add.c:478 builtin/checkout.c:1660 builtin/commit.c:360
+#: builtin/reset.c:333
+msgid "--pathspec-file-nul requires --pathspec-from-file"
 msgstr ""
 
-#: builtin/fetch.c:140
-msgid "prune local tags no longer on remote and clobber changed tags"
+#: builtin/add.c:482
+#, c-format
+msgid "Nothing specified, nothing added.\n"
 msgstr ""
 
-#: builtin/fetch.c:141 builtin/fetch.c:164 builtin/pull.c:131
-msgid "on-demand"
+#: builtin/add.c:483
+#, c-format
+msgid "Maybe you wanted to say 'git add .'?\n"
 msgstr ""
 
-#: builtin/fetch.c:142
-msgid "control recursive fetching of submodules"
+#: builtin/am.c:347
+msgid "could not parse author script"
 msgstr ""
 
-#: builtin/fetch.c:146 builtin/pull.c:214
-msgid "keep downloaded pack"
+#: builtin/am.c:431
+#, c-format
+msgid "'%s' was deleted by the applypatch-msg hook"
 msgstr ""
 
-#: builtin/fetch.c:148
-msgid "allow updating of HEAD ref"
+#: builtin/am.c:473
+#, c-format
+msgid "Malformed input line: '%s'."
 msgstr ""
 
-#: builtin/fetch.c:151 builtin/fetch.c:157 builtin/pull.c:217
-msgid "deepen history of shallow clone"
+#: builtin/am.c:511
+#, c-format
+msgid "Failed to copy notes from '%s' to '%s'"
 msgstr ""
 
-#: builtin/fetch.c:153
-msgid "deepen history of shallow repository based on time"
+#: builtin/am.c:537
+msgid "fseek failed"
 msgstr ""
 
-#: builtin/fetch.c:159 builtin/pull.c:220
-msgid "convert to a complete repository"
+#: builtin/am.c:725
+#, c-format
+msgid "could not parse patch '%s'"
 msgstr ""
 
-#: builtin/fetch.c:162
-msgid "prepend this to submodule path output"
+#: builtin/am.c:790
+msgid "Only one StGIT patch series can be applied at once"
 msgstr ""
 
-#: builtin/fetch.c:165
-msgid ""
-"default for recursive fetching of submodules (lower priority than config "
-"files)"
+#: builtin/am.c:838
+msgid "invalid timestamp"
 msgstr ""
 
-#: builtin/fetch.c:169 builtin/pull.c:223
-msgid "accept refs that update .git/shallow"
+#: builtin/am.c:843 builtin/am.c:855
+msgid "invalid Date line"
 msgstr ""
 
-#: builtin/fetch.c:170 builtin/pull.c:225
-msgid "refmap"
+#: builtin/am.c:850
+msgid "invalid timezone offset"
 msgstr ""
 
-#: builtin/fetch.c:171 builtin/pull.c:226
-msgid "specify fetch refmap"
+#: builtin/am.c:943
+msgid "Patch format detection failed."
 msgstr ""
 
-#: builtin/fetch.c:172 builtin/ls-remote.c:77 builtin/push.c:582
-#: builtin/send-pack.c:172
-msgid "server-specific"
+#: builtin/am.c:948 builtin/clone.c:409
+#, c-format
+msgid "failed to create directory '%s'"
 msgstr ""
 
-#: builtin/fetch.c:172 builtin/ls-remote.c:77 builtin/push.c:582
-#: builtin/send-pack.c:173
-msgid "option to transmit"
+#: builtin/am.c:953
+msgid "Failed to split patches."
 msgstr ""
 
-#: builtin/fetch.c:442
-msgid "Couldn't find remote ref HEAD"
+#: builtin/am.c:1084
+#, c-format
+msgid "When you have resolved this problem, run \"%s --continue\"."
 msgstr ""
 
-#: builtin/fetch.c:560
+#: builtin/am.c:1085
 #, c-format
-msgid "configuration fetch.output contains invalid value %s"
+msgid "If you prefer to skip this patch, run \"%s --skip\" instead."
 msgstr ""
 
-#: builtin/fetch.c:653
+#: builtin/am.c:1086
 #, c-format
-msgid "object %s not found"
+msgid "To restore the original branch and stop patching, run \"%s --abort\"."
 msgstr ""
 
-#: builtin/fetch.c:657
-msgid "[up to date]"
+#: builtin/am.c:1169
+msgid "Patch sent with format=flowed; space at the end of lines might be lost."
 msgstr ""
 
-#: builtin/fetch.c:670 builtin/fetch.c:750
-msgid "[rejected]"
+#: builtin/am.c:1197
+msgid "Patch is empty."
 msgstr ""
 
-#: builtin/fetch.c:671
-msgid "can't fetch in current branch"
+#: builtin/am.c:1262
+#, c-format
+msgid "missing author line in commit %s"
 msgstr ""
 
-#: builtin/fetch.c:680
-msgid "[tag update]"
+#: builtin/am.c:1265
+#, c-format
+msgid "invalid ident line: %.*s"
 msgstr ""
 
-#: builtin/fetch.c:681 builtin/fetch.c:714 builtin/fetch.c:730
-#: builtin/fetch.c:745
-msgid "unable to update local ref"
+#: builtin/am.c:1484
+msgid "Repository lacks necessary blobs to fall back on 3-way merge."
 msgstr ""
 
-#: builtin/fetch.c:700
-msgid "[new tag]"
+#: builtin/am.c:1486
+msgid "Using index info to reconstruct a base tree..."
 msgstr ""
 
-#: builtin/fetch.c:703
-msgid "[new branch]"
+#: builtin/am.c:1505
+msgid ""
+"Did you hand edit your patch?\n"
+"It does not apply to blobs recorded in its index."
 msgstr ""
 
-#: builtin/fetch.c:706
-msgid "[new ref]"
+#: builtin/am.c:1511
+msgid "Falling back to patching base and 3-way merge..."
 msgstr ""
 
-#: builtin/fetch.c:745
-msgid "forced update"
+#: builtin/am.c:1537
+msgid "Failed to merge in the changes."
 msgstr ""
 
-#: builtin/fetch.c:750
-msgid "non-fast-forward"
+#: builtin/am.c:1569
+msgid "applying to an empty history"
 msgstr ""
 
-#: builtin/fetch.c:795
+#: builtin/am.c:1616 builtin/am.c:1620
 #, c-format
-msgid "%s did not send all necessary objects\n"
+msgid "cannot resume: %s does not exist."
 msgstr ""
 
-#: builtin/fetch.c:815
-#, c-format
-msgid "reject %s because shallow roots are not allowed to be updated"
+#: builtin/am.c:1638
+msgid "Commit Body is:"
 msgstr ""
 
-#: builtin/fetch.c:903 builtin/fetch.c:999
+#. TRANSLATORS: Make sure to include [y], [n], [e], [v] and [a]
+#. in your translation. The program will only accept English
+#. input at this point.
+#.
+#: builtin/am.c:1648
 #, c-format
-msgid "From %.*s\n"
+msgid "Apply? [y]es/[n]o/[e]dit/[v]iew patch/[a]ccept all: "
 msgstr ""
 
-#: builtin/fetch.c:914
-#, c-format
-msgid ""
-"some local refs could not be updated; try running\n"
-" 'git remote prune %s' to remove any old, conflicting branches"
+#: builtin/am.c:1695 builtin/commit.c:394
+msgid "unable to write index file"
 msgstr ""
 
-#: builtin/fetch.c:969
+#: builtin/am.c:1699
 #, c-format
-msgid "   (%s will become dangling)"
+msgid "Dirty index: cannot apply patches (dirty: %s)"
 msgstr ""
 
-#: builtin/fetch.c:970
+#: builtin/am.c:1739 builtin/am.c:1807
 #, c-format
-msgid "   (%s has become dangling)"
+msgid "Applying: %.*s"
 msgstr ""
 
-#: builtin/fetch.c:1002
-msgid "[deleted]"
+#: builtin/am.c:1756
+msgid "No changes -- Patch already applied."
 msgstr ""
 
-#: builtin/fetch.c:1003 builtin/remote.c:1033
-msgid "(none)"
+#: builtin/am.c:1762
+#, c-format
+msgid "Patch failed at %s %.*s"
 msgstr ""
 
-#: builtin/fetch.c:1026
-#, c-format
-msgid "Refusing to fetch into current branch %s of non-bare repository"
+#: builtin/am.c:1766
+msgid "Use 'git am --show-current-patch' to see the failed patch"
 msgstr ""
 
-#: builtin/fetch.c:1045
-#, c-format
-msgid "Option \"%s\" value \"%s\" is not valid for %s"
+#: builtin/am.c:1810
+msgid ""
+"No changes - did you forget to use 'git add'?\n"
+"If there is nothing left to stage, chances are that something else\n"
+"already introduced the same changes; you might want to skip this patch."
 msgstr ""
 
-#: builtin/fetch.c:1048
-#, c-format
-msgid "Option \"%s\" is ignored for %s\n"
+#: builtin/am.c:1817
+msgid ""
+"You still have unmerged paths in your index.\n"
+"You should 'git add' each file with resolved conflicts to mark them as "
+"such.\n"
+"You might run `git rm` on a file to accept \"deleted by them\" for it."
 msgstr ""
 
-#: builtin/fetch.c:1287
+#: builtin/am.c:1924 builtin/am.c:1928 builtin/am.c:1940 builtin/reset.c:346
+#: builtin/reset.c:354
 #, c-format
-msgid "Fetching %s\n"
+msgid "Could not parse object '%s'."
 msgstr ""
 
-#: builtin/fetch.c:1289 builtin/remote.c:98
-#, c-format
-msgid "Could not fetch %s"
+#: builtin/am.c:1976
+msgid "failed to clean index"
 msgstr ""
 
-#: builtin/fetch.c:1335 builtin/fetch.c:1503
+#: builtin/am.c:2020
 msgid ""
-"--filter can only be used with the remote configured in core.partialClone"
+"You seem to have moved HEAD since the last 'am' failure.\n"
+"Not rewinding to ORIG_HEAD"
 msgstr ""
 
-#: builtin/fetch.c:1358
-msgid ""
-"No remote repository specified.  Please, specify either a URL or a\n"
-"remote name from which new revisions should be fetched."
+#: builtin/am.c:2117
+#, c-format
+msgid "Invalid value for --patch-format: %s"
 msgstr ""
 
-#: builtin/fetch.c:1395
-msgid "You need to specify a tag name."
+#: builtin/am.c:2153
+msgid "git am [<options>] [(<mbox> | <Maildir>)...]"
 msgstr ""
 
-#: builtin/fetch.c:1444
-msgid "Negative depth in --deepen is not supported"
+#: builtin/am.c:2154
+msgid "git am [<options>] (--continue | --skip | --abort)"
 msgstr ""
 
-#: builtin/fetch.c:1446
-msgid "--deepen and --depth are mutually exclusive"
+#: builtin/am.c:2160
+msgid "run interactively"
 msgstr ""
 
-#: builtin/fetch.c:1451
-msgid "--depth and --unshallow cannot be used together"
+#: builtin/am.c:2162
+msgid "historical option -- no-op"
 msgstr ""
 
-#: builtin/fetch.c:1453
-msgid "--unshallow on a complete repository does not make sense"
+#: builtin/am.c:2164
+msgid "allow fall back on 3way merging if needed"
 msgstr ""
 
-#: builtin/fetch.c:1469
-msgid "fetch --all does not take a repository argument"
+#: builtin/am.c:2165 builtin/init-db.c:494 builtin/prune-packed.c:58
+#: builtin/repack.c:304 builtin/stash.c:811
+msgid "be quiet"
 msgstr ""
 
-#: builtin/fetch.c:1471
-msgid "fetch --all does not make sense with refspecs"
+#: builtin/am.c:2167
+msgid "add a Signed-off-by line to the commit message"
 msgstr ""
 
-#: builtin/fetch.c:1480
-#, c-format
-msgid "No such remote or remote group: %s"
+#: builtin/am.c:2170
+msgid "recode into utf8 (default)"
 msgstr ""
 
-#: builtin/fetch.c:1487
-msgid "Fetching a group and specifying refspecs does not make sense"
+#: builtin/am.c:2172
+msgid "pass -k flag to git-mailinfo"
 msgstr ""
 
-#: builtin/fmt-merge-msg.c:15
-msgid ""
-"git fmt-merge-msg [-m <message>] [--log[=<n>] | --no-log] [--file <file>]"
+#: builtin/am.c:2174
+msgid "pass -b flag to git-mailinfo"
 msgstr ""
 
-#: builtin/fmt-merge-msg.c:666
-msgid "populate log with at most <n> entries from shortlog"
+#: builtin/am.c:2176
+msgid "pass -m flag to git-mailinfo"
 msgstr ""
 
-#: builtin/fmt-merge-msg.c:669
-msgid "alias for --log (deprecated)"
+#: builtin/am.c:2178
+msgid "pass --keep-cr flag to git-mailsplit for mbox format"
 msgstr ""
 
-#: builtin/fmt-merge-msg.c:672
-msgid "text"
+#: builtin/am.c:2181
+msgid "do not pass --keep-cr flag to git-mailsplit independent of am.keepcr"
 msgstr ""
 
-#: builtin/fmt-merge-msg.c:673
-msgid "use <text> as start of message"
+#: builtin/am.c:2184
+msgid "strip everything before a scissors line"
 msgstr ""
 
-#: builtin/fmt-merge-msg.c:674
-msgid "file to read from"
+#: builtin/am.c:2186 builtin/am.c:2189 builtin/am.c:2192 builtin/am.c:2195
+#: builtin/am.c:2198 builtin/am.c:2201 builtin/am.c:2204 builtin/am.c:2207
+#: builtin/am.c:2213
+msgid "pass it through git-apply"
 msgstr ""
 
-#: builtin/for-each-ref.c:10
-msgid "git for-each-ref [<options>] [<pattern>]"
+#: builtin/am.c:2203 builtin/commit.c:1386 builtin/fmt-merge-msg.c:673
+#: builtin/fmt-merge-msg.c:676 builtin/grep.c:883 builtin/merge.c:249
+#: builtin/pull.c:160 builtin/pull.c:219 builtin/rebase.c:1469
+#: builtin/repack.c:315 builtin/repack.c:319 builtin/repack.c:321
+#: builtin/show-branch.c:650 builtin/show-ref.c:172 builtin/tag.c:403
+#: parse-options.h:154 parse-options.h:175 parse-options.h:316
+msgid "n"
 msgstr ""
 
-#: builtin/for-each-ref.c:11
-msgid "git for-each-ref [--points-at <object>]"
+#: builtin/am.c:2209 builtin/branch.c:661 builtin/for-each-ref.c:38
+#: builtin/replace.c:555 builtin/tag.c:437 builtin/verify-tag.c:38
+msgid "format"
 msgstr ""
 
-#: builtin/for-each-ref.c:12
-msgid "git for-each-ref [(--merged | --no-merged) [<commit>]]"
+#: builtin/am.c:2210
+msgid "format the patch(es) are in"
 msgstr ""
 
-#: builtin/for-each-ref.c:13
-msgid "git for-each-ref [--contains [<commit>]] [--no-contains [<commit>]]"
+#: builtin/am.c:2216
+msgid "override error message when patch failure occurs"
 msgstr ""
 
-#: builtin/for-each-ref.c:28
-msgid "quote placeholders suitably for shells"
+#: builtin/am.c:2218
+msgid "continue applying patches after resolving a conflict"
 msgstr ""
 
-#: builtin/for-each-ref.c:30
-msgid "quote placeholders suitably for perl"
+#: builtin/am.c:2221
+msgid "synonyms for --continue"
 msgstr ""
 
-#: builtin/for-each-ref.c:32
-msgid "quote placeholders suitably for python"
+#: builtin/am.c:2224
+msgid "skip the current patch"
 msgstr ""
 
-#: builtin/for-each-ref.c:34
-msgid "quote placeholders suitably for Tcl"
+#: builtin/am.c:2227
+msgid "restore the original branch and abort the patching operation."
 msgstr ""
 
-#: builtin/for-each-ref.c:37
-msgid "show only <n> matched refs"
+#: builtin/am.c:2230
+msgid "abort the patching operation but keep HEAD where it is."
 msgstr ""
 
-#: builtin/for-each-ref.c:39 builtin/tag.c:421
-msgid "respect format colors"
+#: builtin/am.c:2233
+msgid "show the patch being applied."
 msgstr ""
 
-#: builtin/for-each-ref.c:43
-msgid "print only refs which points at the given object"
+#: builtin/am.c:2237
+msgid "lie about committer date"
 msgstr ""
 
-#: builtin/for-each-ref.c:45
-msgid "print only refs that are merged"
+#: builtin/am.c:2239
+msgid "use current timestamp for author date"
 msgstr ""
 
-#: builtin/for-each-ref.c:46
-msgid "print only refs that are not merged"
+#: builtin/am.c:2241 builtin/commit-tree.c:120 builtin/commit.c:1507
+#: builtin/merge.c:286 builtin/pull.c:194 builtin/rebase.c:509
+#: builtin/rebase.c:1513 builtin/revert.c:117 builtin/tag.c:418
+msgid "key-id"
 msgstr ""
 
-#: builtin/for-each-ref.c:47
-msgid "print only refs which contain the commit"
+#: builtin/am.c:2242 builtin/rebase.c:510 builtin/rebase.c:1514
+msgid "GPG-sign commits"
 msgstr ""
 
-#: builtin/for-each-ref.c:48
-msgid "print only refs which don't contain the commit"
+#: builtin/am.c:2245
+msgid "(internal use for git-rebase)"
 msgstr ""
 
-#: builtin/fsck.c:569
-msgid "Checking object directories"
+#: builtin/am.c:2263
+msgid ""
+"The -b/--binary option has been a no-op for long time, and\n"
+"it will be removed. Please do not use it anymore."
 msgstr ""
 
-#: builtin/fsck.c:661
-msgid "git fsck [<options>] [<object>...]"
+#: builtin/am.c:2270
+msgid "failed to read the index"
 msgstr ""
 
-#: builtin/fsck.c:667
-msgid "show unreachable objects"
+#: builtin/am.c:2285
+#, c-format
+msgid "previous rebase directory %s still exists but mbox given."
 msgstr ""
 
-#: builtin/fsck.c:668
-msgid "show dangling objects"
+#: builtin/am.c:2309
+#, c-format
+msgid ""
+"Stray %s directory found.\n"
+"Use \"git am --abort\" to remove it."
 msgstr ""
 
-#: builtin/fsck.c:669
-msgid "report tags"
+#: builtin/am.c:2315
+msgid "Resolve operation not in progress, we are not resuming."
 msgstr ""
 
-#: builtin/fsck.c:670
-msgid "report root nodes"
+#: builtin/am.c:2325
+msgid "interactive mode requires patches on the command line"
 msgstr ""
 
-#: builtin/fsck.c:671
-msgid "make index objects head nodes"
+#: builtin/apply.c:8
+msgid "git apply [<options>] [<patch>...]"
 msgstr ""
 
-#: builtin/fsck.c:672
-msgid "make reflogs head nodes (default)"
+#: builtin/archive.c:17
+#, c-format
+msgid "could not create archive file '%s'"
 msgstr ""
 
-#: builtin/fsck.c:673
-msgid "also consider packs and alternate objects"
+#: builtin/archive.c:20
+msgid "could not redirect output"
 msgstr ""
 
-#: builtin/fsck.c:674
-msgid "check only connectivity"
+#: builtin/archive.c:37
+msgid "git archive: Remote with no URL"
 msgstr ""
 
-#: builtin/fsck.c:675
-msgid "enable more strict checking"
+#: builtin/archive.c:61
+msgid "git archive: expected ACK/NAK, got a flush packet"
 msgstr ""
 
-#: builtin/fsck.c:677
-msgid "write dangling objects in .git/lost-found"
+#: builtin/archive.c:64
+#, c-format
+msgid "git archive: NACK %s"
 msgstr ""
 
-#: builtin/fsck.c:678 builtin/prune.c:109
-msgid "show progress"
+#: builtin/archive.c:65
+msgid "git archive: protocol error"
 msgstr ""
 
-#: builtin/fsck.c:679
-msgid "show verbose names for reachable objects"
+#: builtin/archive.c:69
+msgid "git archive: expected a flush"
 msgstr ""
 
-#: builtin/fsck.c:745
-msgid "Checking objects"
+#: builtin/bisect--helper.c:22
+msgid "git bisect--helper --next-all [--no-checkout]"
 msgstr ""
 
-#: builtin/gc.c:33
-msgid "git gc [<options>]"
+#: builtin/bisect--helper.c:23
+msgid "git bisect--helper --write-terms <bad_term> <good_term>"
 msgstr ""
 
-#: builtin/gc.c:88
-#, c-format
-msgid "Failed to fstat %s: %s"
+#: builtin/bisect--helper.c:24
+msgid "git bisect--helper --bisect-clean-state"
 msgstr ""
 
-#: builtin/gc.c:452
-#, c-format
-msgid "Can't stat %s"
+#: builtin/bisect--helper.c:25
+msgid "git bisect--helper --bisect-reset [<commit>]"
 msgstr ""
 
-#: builtin/gc.c:461
-#, c-format
+#: builtin/bisect--helper.c:26
 msgid ""
-"The last gc run reported the following. Please correct the root cause\n"
-"and remove %s.\n"
-"Automatic cleanup will not be performed until the file is removed.\n"
-"\n"
-"%s"
+"git bisect--helper --bisect-write [--no-log] <state> <revision> <good_term> "
+"<bad_term>"
 msgstr ""
 
-#: builtin/gc.c:502
-msgid "prune unreferenced objects"
+#: builtin/bisect--helper.c:27
+msgid ""
+"git bisect--helper --bisect-check-and-set-terms <command> <good_term> "
+"<bad_term>"
 msgstr ""
 
-#: builtin/gc.c:504
-msgid "be more thorough (increased runtime)"
+#: builtin/bisect--helper.c:28
+msgid "git bisect--helper --bisect-next-check <good_term> <bad_term> [<term>]"
 msgstr ""
 
-#: builtin/gc.c:505
-msgid "enable auto-gc mode"
+#: builtin/bisect--helper.c:29
+msgid ""
+"git bisect--helper --bisect-terms [--term-good | --term-old | --term-bad | --"
+"term-new]"
 msgstr ""
 
-#: builtin/gc.c:508
-msgid "force running gc even if there may be another gc running"
+#: builtin/bisect--helper.c:30
+msgid ""
+"git bisect--helper --bisect-start [--term-{old,good}=<term> --term-{new,bad}"
+"=<term>][--no-checkout] [<bad> [<good>...]] [--] [<paths>...]"
 msgstr ""
 
-#: builtin/gc.c:511
-msgid "repack all other packs except the largest pack"
+#: builtin/bisect--helper.c:86
+#, c-format
+msgid "'%s' is not a valid term"
 msgstr ""
 
-#: builtin/gc.c:528
+#: builtin/bisect--helper.c:90
 #, c-format
-msgid "failed to parse gc.logexpiry value %s"
+msgid "can't use the builtin command '%s' as a term"
 msgstr ""
 
-#: builtin/gc.c:539
+#: builtin/bisect--helper.c:100
 #, c-format
-msgid "failed to parse prune expiry value %s"
+msgid "can't change the meaning of the term '%s'"
 msgstr ""
 
-#: builtin/gc.c:559
-#, c-format
-msgid "Auto packing the repository in background for optimum performance.\n"
+#: builtin/bisect--helper.c:111
+msgid "please use two different terms"
 msgstr ""
 
-#: builtin/gc.c:561
-#, c-format
-msgid "Auto packing the repository for optimum performance.\n"
+#: builtin/bisect--helper.c:118
+msgid "could not open the file BISECT_TERMS"
 msgstr ""
 
-#: builtin/gc.c:562
+#: builtin/bisect--helper.c:155
 #, c-format
-msgid "See \"git help gc\" for manual housekeeping.\n"
+msgid "We are not bisecting.\n"
 msgstr ""
 
-#: builtin/gc.c:598
+#: builtin/bisect--helper.c:163
 #, c-format
-msgid ""
-"gc is already running on machine '%s' pid %<PRIuMAX> (use --force if not)"
+msgid "'%s' is not a valid commit"
 msgstr ""
 
-#: builtin/gc.c:645
+#: builtin/bisect--helper.c:172
+#, c-format
 msgid ""
-"There are too many unreachable loose objects; run 'git prune' to remove them."
+"could not check out original HEAD '%s'. Try 'git bisect reset <commit>'."
 msgstr ""
 
-#: builtin/grep.c:28
-msgid "git grep [<options>] [-e] <pattern> [<rev>...] [[--] <path>...]"
+#: builtin/bisect--helper.c:216
+#, c-format
+msgid "Bad bisect_write argument: %s"
 msgstr ""
 
-#: builtin/grep.c:226
+#: builtin/bisect--helper.c:221
 #, c-format
-msgid "grep: failed to create thread: %s"
+msgid "couldn't get the oid of the rev '%s'"
 msgstr ""
 
-#: builtin/grep.c:284
+#: builtin/bisect--helper.c:233
 #, c-format
-msgid "invalid number of threads specified (%d) for %s"
+msgid "couldn't open the file '%s'"
 msgstr ""
 
-#. TRANSLATORS: %s is the configuration
-#. variable for tweaking threads, currently
-#. grep.threads
-#.
-#: builtin/grep.c:293 builtin/index-pack.c:1535 builtin/index-pack.c:1727
+#: builtin/bisect--helper.c:259
 #, c-format
-msgid "no threads support, ignoring %s"
+msgid "Invalid command: you're currently in a %s/%s bisect"
 msgstr ""
 
-#: builtin/grep.c:461 builtin/grep.c:582 builtin/grep.c:623
+#: builtin/bisect--helper.c:286
 #, c-format
-msgid "unable to read tree (%s)"
+msgid ""
+"You need to give me at least one %s and %s revision.\n"
+"You can use \"git bisect %s\" and \"git bisect %s\" for that."
 msgstr ""
 
-#: builtin/grep.c:638
+#: builtin/bisect--helper.c:290
 #, c-format
-msgid "unable to grep from object of type %s"
+msgid ""
+"You need to start by \"git bisect start\".\n"
+"You then need to give me at least one %s and %s revision.\n"
+"You can use \"git bisect %s\" and \"git bisect %s\" for that."
 msgstr ""
 
-#: builtin/grep.c:703
+#: builtin/bisect--helper.c:322
 #, c-format
-msgid "switch `%c' expects a numerical value"
+msgid "bisecting only with a %s commit"
 msgstr ""
 
-#: builtin/grep.c:790
-msgid "search in index instead of in the work tree"
+#. TRANSLATORS: Make sure to include [Y] and [n] in your
+#. translation. The program will only accept English input
+#. at this point.
+#.
+#: builtin/bisect--helper.c:330
+msgid "Are you sure [Y/n]? "
 msgstr ""
 
-#: builtin/grep.c:792
-msgid "find in contents not managed by git"
+#: builtin/bisect--helper.c:377
+msgid "no terms defined"
 msgstr ""
 
-#: builtin/grep.c:794
-msgid "search in both tracked and untracked files"
+#: builtin/bisect--helper.c:380
+#, c-format
+msgid ""
+"Your current terms are %s for the old state\n"
+"and %s for the new state.\n"
 msgstr ""
 
-#: builtin/grep.c:796
-msgid "ignore files specified via '.gitignore'"
+#: builtin/bisect--helper.c:390
+#, c-format
+msgid ""
+"invalid argument %s for 'git bisect terms'.\n"
+"Supported options are: --term-good|--term-old and --term-bad|--term-new."
 msgstr ""
 
-#: builtin/grep.c:798
-msgid "recursively search in each submodule"
+#: builtin/bisect--helper.c:476
+#, c-format
+msgid "unrecognized option: '%s'"
 msgstr ""
 
-#: builtin/grep.c:801
-msgid "show non-matching lines"
+#: builtin/bisect--helper.c:480
+#, c-format
+msgid "'%s' does not appear to be a valid revision"
 msgstr ""
 
-#: builtin/grep.c:803
-msgid "case insensitive matching"
+#: builtin/bisect--helper.c:512
+msgid "bad HEAD - I need a HEAD"
 msgstr ""
 
-#: builtin/grep.c:805
-msgid "match patterns only at word boundaries"
+#: builtin/bisect--helper.c:527
+#, c-format
+msgid "checking out '%s' failed. Try 'git bisect start <valid-branch>'."
 msgstr ""
 
-#: builtin/grep.c:807
-msgid "process binary files as text"
+#: builtin/bisect--helper.c:548
+msgid "won't bisect on cg-seek'ed tree"
 msgstr ""
 
-#: builtin/grep.c:809
-msgid "don't match patterns in binary files"
+#: builtin/bisect--helper.c:551
+msgid "bad HEAD - strange symbolic ref"
 msgstr ""
 
-#: builtin/grep.c:812
-msgid "process binary files with textconv filters"
+#: builtin/bisect--helper.c:575
+#, c-format
+msgid "invalid ref: '%s'"
 msgstr ""
 
-#: builtin/grep.c:814
-msgid "descend at most <depth> levels"
+#: builtin/bisect--helper.c:631
+msgid "perform 'git bisect next'"
 msgstr ""
 
-#: builtin/grep.c:818
-msgid "use extended POSIX regular expressions"
+#: builtin/bisect--helper.c:633
+msgid "write the terms to .git/BISECT_TERMS"
 msgstr ""
 
-#: builtin/grep.c:821
-msgid "use basic POSIX regular expressions (default)"
+#: builtin/bisect--helper.c:635
+msgid "cleanup the bisection state"
 msgstr ""
 
-#: builtin/grep.c:824
-msgid "interpret patterns as fixed strings"
+#: builtin/bisect--helper.c:637
+msgid "check for expected revs"
 msgstr ""
 
-#: builtin/grep.c:827
-msgid "use Perl-compatible regular expressions"
+#: builtin/bisect--helper.c:639
+msgid "reset the bisection state"
 msgstr ""
 
-#: builtin/grep.c:830
-msgid "show line numbers"
+#: builtin/bisect--helper.c:641
+msgid "write out the bisection state in BISECT_LOG"
 msgstr ""
 
-#: builtin/grep.c:831
-msgid "don't show filenames"
+#: builtin/bisect--helper.c:643
+msgid "check and set terms in a bisection state"
 msgstr ""
 
-#: builtin/grep.c:832
-msgid "show filenames"
+#: builtin/bisect--helper.c:645
+msgid "check whether bad or good terms exist"
 msgstr ""
 
-#: builtin/grep.c:834
-msgid "show filenames relative to top directory"
+#: builtin/bisect--helper.c:647
+msgid "print out the bisect terms"
 msgstr ""
 
-#: builtin/grep.c:836
-msgid "show only filenames instead of matching lines"
+#: builtin/bisect--helper.c:649
+msgid "start the bisect session"
 msgstr ""
 
-#: builtin/grep.c:838
-msgid "synonym for --files-with-matches"
+#: builtin/bisect--helper.c:651
+msgid "update BISECT_HEAD instead of checking out the current commit"
 msgstr ""
 
-#: builtin/grep.c:841
-msgid "show only the names of files without match"
+#: builtin/bisect--helper.c:653
+msgid "no log for BISECT_WRITE"
 msgstr ""
 
-#: builtin/grep.c:843
-msgid "print NUL after filenames"
+#: builtin/bisect--helper.c:670
+msgid "--write-terms requires two arguments"
 msgstr ""
 
-#: builtin/grep.c:846
-msgid "show the number of matches instead of matching lines"
+#: builtin/bisect--helper.c:674
+msgid "--bisect-clean-state requires no arguments"
 msgstr ""
 
-#: builtin/grep.c:847
-msgid "highlight matches"
+#: builtin/bisect--helper.c:681
+msgid "--bisect-reset requires either no argument or a commit"
 msgstr ""
 
-#: builtin/grep.c:849
-msgid "print empty line between matches from different files"
+#: builtin/bisect--helper.c:685
+msgid "--bisect-write requires either 4 or 5 arguments"
 msgstr ""
 
-#: builtin/grep.c:851
-msgid "show filename only once above matches from same file"
+#: builtin/bisect--helper.c:691
+msgid "--check-and-set-terms requires 3 arguments"
 msgstr ""
 
-#: builtin/grep.c:854
-msgid "show <n> context lines before and after matches"
+#: builtin/bisect--helper.c:697
+msgid "--bisect-next-check requires 2 or 3 arguments"
 msgstr ""
 
-#: builtin/grep.c:857
-msgid "show <n> context lines before matches"
+#: builtin/bisect--helper.c:703
+msgid "--bisect-terms requires 0 or 1 argument"
 msgstr ""
 
-#: builtin/grep.c:859
-msgid "show <n> context lines after matches"
+#: builtin/blame.c:31
+msgid "git blame [<options>] [<rev-opts>] [<rev>] [--] <file>"
 msgstr ""
 
-#: builtin/grep.c:861
-msgid "use <n> worker threads"
+#: builtin/blame.c:36
+msgid "<rev-opts> are documented in git-rev-list(1)"
 msgstr ""
 
-#: builtin/grep.c:862
-msgid "shortcut for -C NUM"
+#: builtin/blame.c:409
+#, c-format
+msgid "expecting a color: %s"
 msgstr ""
 
-#: builtin/grep.c:865
-msgid "show a line with the function name before matches"
+#: builtin/blame.c:416
+msgid "must end with a color"
 msgstr ""
 
-#: builtin/grep.c:867
-msgid "show the surrounding function"
+#: builtin/blame.c:729
+#, c-format
+msgid "invalid color '%s' in color.blame.repeatedLines"
 msgstr ""
 
-#: builtin/grep.c:870
-msgid "read patterns from file"
+#: builtin/blame.c:747
+msgid "invalid value for blame.coloring"
 msgstr ""
 
-#: builtin/grep.c:872
-msgid "match <pattern>"
+#: builtin/blame.c:822
+#, c-format
+msgid "cannot find revision %s to ignore"
 msgstr ""
 
-#: builtin/grep.c:874
-msgid "combine patterns specified with -e"
+#: builtin/blame.c:844
+msgid "Show blame entries as we find them, incrementally"
 msgstr ""
 
-#: builtin/grep.c:886
-msgid "indicate hit with exit status without output"
+#: builtin/blame.c:845
+msgid "Show blank SHA-1 for boundary commits (Default: off)"
 msgstr ""
 
-#: builtin/grep.c:888
-msgid "show only matches from files that match all patterns"
+#: builtin/blame.c:846
+msgid "Do not treat root commits as boundaries (Default: off)"
 msgstr ""
 
-#: builtin/grep.c:890
-msgid "show parse tree for grep expression"
+#: builtin/blame.c:847
+msgid "Show work cost statistics"
 msgstr ""
 
-#: builtin/grep.c:894
-msgid "pager"
+#: builtin/blame.c:848
+msgid "Force progress reporting"
 msgstr ""
 
-#: builtin/grep.c:894
-msgid "show matching files in the pager"
+#: builtin/blame.c:849
+msgid "Show output score for blame entries"
 msgstr ""
 
-#: builtin/grep.c:898
-msgid "allow calling of grep(1) (ignored by this build)"
+#: builtin/blame.c:850
+msgid "Show original filename (Default: auto)"
 msgstr ""
 
-#: builtin/grep.c:962
-msgid "no pattern given."
+#: builtin/blame.c:851
+msgid "Show original linenumber (Default: off)"
 msgstr ""
 
-#: builtin/grep.c:994
-msgid "--no-index or --untracked cannot be used with revs"
+#: builtin/blame.c:852
+msgid "Show in a format designed for machine consumption"
 msgstr ""
 
-#: builtin/grep.c:1001
-#, c-format
-msgid "unable to resolve revision: %s"
+#: builtin/blame.c:853
+msgid "Show porcelain format with per-line commit information"
 msgstr ""
 
-#: builtin/grep.c:1036 builtin/index-pack.c:1531
-#, c-format
-msgid "invalid number of threads specified (%d)"
+#: builtin/blame.c:854
+msgid "Use the same output mode as git-annotate (Default: off)"
 msgstr ""
 
-#: builtin/grep.c:1041
-msgid "no threads support, ignoring --threads"
+#: builtin/blame.c:855
+msgid "Show raw timestamp (Default: off)"
 msgstr ""
 
-#: builtin/grep.c:1065
-msgid "--open-files-in-pager only works on the worktree"
+#: builtin/blame.c:856
+msgid "Show long commit SHA1 (Default: off)"
 msgstr ""
 
-#: builtin/grep.c:1088
-msgid "option not supported with --recurse-submodules."
+#: builtin/blame.c:857
+msgid "Suppress author name and timestamp (Default: off)"
 msgstr ""
 
-#: builtin/grep.c:1094
-msgid "--cached or --untracked cannot be used with --no-index."
+#: builtin/blame.c:858
+msgid "Show author email instead of name (Default: off)"
 msgstr ""
 
-#: builtin/grep.c:1100
-msgid "--[no-]exclude-standard cannot be used for tracked contents."
+#: builtin/blame.c:859
+msgid "Ignore whitespace differences"
 msgstr ""
 
-#: builtin/grep.c:1108
-msgid "both --cached and trees are given."
+#: builtin/blame.c:860 builtin/log.c:1702
+msgid "rev"
 msgstr ""
 
-#: builtin/hash-object.c:83
-msgid ""
-"git hash-object [-t <type>] [-w] [--path=<file> | --no-filters] [--stdin] "
-"[--] <file>..."
+#: builtin/blame.c:860
+msgid "Ignore <rev> when blaming"
 msgstr ""
 
-#: builtin/hash-object.c:84
-msgid "git hash-object  --stdin-paths"
+#: builtin/blame.c:861
+msgid "Ignore revisions from <file>"
 msgstr ""
 
-#: builtin/hash-object.c:96
-msgid "type"
+#: builtin/blame.c:862
+msgid "color redundant metadata from previous line differently"
 msgstr ""
 
-#: builtin/hash-object.c:96
-msgid "object type"
+#: builtin/blame.c:863
+msgid "color lines by age"
 msgstr ""
 
-#: builtin/hash-object.c:97
-msgid "write the object into the object database"
+#: builtin/blame.c:864
+msgid "Spend extra cycles to find better match"
 msgstr ""
 
-#: builtin/hash-object.c:99
-msgid "read the object from stdin"
+#: builtin/blame.c:865
+msgid "Use revisions from <file> instead of calling git-rev-list"
 msgstr ""
 
-#: builtin/hash-object.c:101
-msgid "store file as is without filters"
+#: builtin/blame.c:866
+msgid "Use <file>'s contents as the final image"
 msgstr ""
 
-#: builtin/hash-object.c:102
-msgid ""
-"just hash any random garbage to create corrupt objects for debugging Git"
+#: builtin/blame.c:867 builtin/blame.c:868
+msgid "score"
 msgstr ""
 
-#: builtin/hash-object.c:103
-msgid "process file as it were from this path"
+#: builtin/blame.c:867
+msgid "Find line copies within and across files"
 msgstr ""
 
-#: builtin/help.c:45
-msgid "print all available commands"
+#: builtin/blame.c:868
+msgid "Find line movements within and across files"
 msgstr ""
 
-#: builtin/help.c:46
-msgid "exclude guides"
+#: builtin/blame.c:869
+msgid "n,m"
 msgstr ""
 
-#: builtin/help.c:47
-msgid "print list of useful guides"
+#: builtin/blame.c:869
+msgid "Process only line range n,m, counting from 1"
 msgstr ""
 
-#: builtin/help.c:48
-msgid "show man page"
+#: builtin/blame.c:921
+msgid "--progress can't be used with --incremental or porcelain formats"
 msgstr ""
 
-#: builtin/help.c:49
-msgid "show manual in web browser"
+#. TRANSLATORS: This string is used to tell us the
+#. maximum display width for a relative timestamp in
+#. "git blame" output.  For C locale, "4 years, 11
+#. months ago", which takes 22 places, is the longest
+#. among various forms of relative timestamps, but
+#. your language may need more or fewer display
+#. columns.
+#.
+#: builtin/blame.c:972
+msgid "4 years, 11 months ago"
 msgstr ""
 
-#: builtin/help.c:51
-msgid "show info page"
+#: builtin/blame.c:1079
+#, c-format
+msgid "file %s has only %lu line"
+msgid_plural "file %s has only %lu lines"
+msgstr[0] ""
+msgstr[1] ""
+
+#: builtin/blame.c:1125
+msgid "Blaming lines"
 msgstr ""
 
-#: builtin/help.c:53
-msgid "print command description"
+#: builtin/branch.c:29
+msgid "git branch [<options>] [-r | -a] [--merged | --no-merged]"
 msgstr ""
 
-#: builtin/help.c:58
-msgid "git help [--all] [--guides] [--man | --web | --info] [<command>]"
+#: builtin/branch.c:30
+msgid "git branch [<options>] [-l] [-f] <branch-name> [<start-point>]"
 msgstr ""
 
-#: builtin/help.c:70
-#, c-format
-msgid "unrecognized help format '%s'"
+#: builtin/branch.c:31
+msgid "git branch [<options>] [-r] (-d | -D) <branch-name>..."
 msgstr ""
 
-#: builtin/help.c:97
-msgid "Failed to start emacsclient."
+#: builtin/branch.c:32
+msgid "git branch [<options>] (-m | -M) [<old-branch>] <new-branch>"
 msgstr ""
 
-#: builtin/help.c:110
-msgid "Failed to parse emacsclient version."
+#: builtin/branch.c:33
+msgid "git branch [<options>] (-c | -C) [<old-branch>] <new-branch>"
 msgstr ""
 
-#: builtin/help.c:118
-#, c-format
-msgid "emacsclient version '%d' too old (< 22)."
+#: builtin/branch.c:34
+msgid "git branch [<options>] [-r | -a] [--points-at]"
 msgstr ""
 
-#: builtin/help.c:136 builtin/help.c:158 builtin/help.c:168 builtin/help.c:176
-#, c-format
-msgid "failed to exec '%s'"
+#: builtin/branch.c:35
+msgid "git branch [<options>] [-r | -a] [--format]"
 msgstr ""
 
-#: builtin/help.c:214
+#: builtin/branch.c:154
 #, c-format
 msgid ""
-"'%s': path for unsupported man viewer.\n"
-"Please consider using 'man.<tool>.cmd' instead."
+"deleting branch '%s' that has been merged to\n"
+"         '%s', but not yet merged to HEAD."
 msgstr ""
 
-#: builtin/help.c:226
+#: builtin/branch.c:158
 #, c-format
 msgid ""
-"'%s': cmd for supported man viewer.\n"
-"Please consider using 'man.<tool>.path' instead."
+"not deleting branch '%s' that is not yet merged to\n"
+"         '%s', even though it is merged to HEAD."
 msgstr ""
 
-#: builtin/help.c:343
+#: builtin/branch.c:172
 #, c-format
-msgid "'%s': unknown man viewer."
+msgid "Couldn't look up commit object for '%s'"
 msgstr ""
 
-#: builtin/help.c:360
-msgid "no man viewer handled the request"
+#: builtin/branch.c:176
+#, c-format
+msgid ""
+"The branch '%s' is not fully merged.\n"
+"If you are sure you want to delete it, run 'git branch -D %s'."
 msgstr ""
 
-#: builtin/help.c:368
-msgid "no info viewer handled the request"
+#: builtin/branch.c:189
+msgid "Update of config-file failed"
 msgstr ""
 
-#: builtin/help.c:415
-#, c-format
-msgid "'%s' is aliased to '%s'"
+#: builtin/branch.c:220
+msgid "cannot use -a with -d"
 msgstr ""
 
-#: builtin/help.c:442 builtin/help.c:459
-#, c-format
-msgid "usage: %s%s"
+#: builtin/branch.c:226
+msgid "Couldn't look up commit object for HEAD"
 msgstr ""
 
-#: builtin/index-pack.c:158
+#: builtin/branch.c:240
 #, c-format
-msgid "unable to open %s"
+msgid "Cannot delete branch '%s' checked out at '%s'"
 msgstr ""
 
-#: builtin/index-pack.c:208
+#: builtin/branch.c:255
 #, c-format
-msgid "object type mismatch at %s"
+msgid "remote-tracking branch '%s' not found."
 msgstr ""
 
-#: builtin/index-pack.c:228
+#: builtin/branch.c:256
 #, c-format
-msgid "did not receive expected object %s"
+msgid "branch '%s' not found."
 msgstr ""
 
-#: builtin/index-pack.c:231
+#: builtin/branch.c:271
 #, c-format
-msgid "object %s: expected type %s, found %s"
+msgid "Error deleting remote-tracking branch '%s'"
 msgstr ""
 
-#: builtin/index-pack.c:273
+#: builtin/branch.c:272
 #, c-format
-msgid "cannot fill %d byte"
-msgid_plural "cannot fill %d bytes"
-msgstr[0] ""
-msgstr[1] ""
-
-#: builtin/index-pack.c:283
-msgid "early EOF"
+msgid "Error deleting branch '%s'"
 msgstr ""
 
-#: builtin/index-pack.c:284
-msgid "read error on input"
+#: builtin/branch.c:279
+#, c-format
+msgid "Deleted remote-tracking branch %s (was %s).\n"
 msgstr ""
 
-#: builtin/index-pack.c:296
-msgid "used more bytes than were available"
+#: builtin/branch.c:280
+#, c-format
+msgid "Deleted branch %s (was %s).\n"
 msgstr ""
 
-#: builtin/index-pack.c:303
-msgid "pack too large for current definition of off_t"
+#: builtin/branch.c:429 builtin/tag.c:61
+msgid "unable to parse format string"
 msgstr ""
 
-#: builtin/index-pack.c:306 builtin/unpack-objects.c:93
-msgid "pack exceeds maximum allowed size"
+#: builtin/branch.c:460
+msgid "could not resolve HEAD"
 msgstr ""
 
-#: builtin/index-pack.c:321
+#: builtin/branch.c:466
 #, c-format
-msgid "unable to create '%s'"
+msgid "HEAD (%s) points outside of refs/heads/"
 msgstr ""
 
-#: builtin/index-pack.c:327
+#: builtin/branch.c:481
 #, c-format
-msgid "cannot open packfile '%s'"
+msgid "Branch %s is being rebased at %s"
 msgstr ""
 
-#: builtin/index-pack.c:341
-msgid "pack signature mismatch"
+#: builtin/branch.c:485
+#, c-format
+msgid "Branch %s is being bisected at %s"
 msgstr ""
 
-#: builtin/index-pack.c:343
-#, c-format
-msgid "pack version %<PRIu32> unsupported"
+#: builtin/branch.c:502
+msgid "cannot copy the current branch while not on any."
 msgstr ""
 
-#: builtin/index-pack.c:361
-#, c-format
-msgid "pack has bad object at offset %<PRIuMAX>: %s"
+#: builtin/branch.c:504
+msgid "cannot rename the current branch while not on any."
 msgstr ""
 
-#: builtin/index-pack.c:482
+#: builtin/branch.c:515
 #, c-format
-msgid "inflate returned %d"
+msgid "Invalid branch name: '%s'"
 msgstr ""
 
-#: builtin/index-pack.c:531
-msgid "offset value overflow for delta base object"
+#: builtin/branch.c:542
+msgid "Branch rename failed"
 msgstr ""
 
-#: builtin/index-pack.c:539
-msgid "delta base offset is out of bound"
+#: builtin/branch.c:544
+msgid "Branch copy failed"
 msgstr ""
 
-#: builtin/index-pack.c:547
+#: builtin/branch.c:548
 #, c-format
-msgid "unknown object type %d"
-msgstr ""
-
-#: builtin/index-pack.c:578
-msgid "cannot pread pack file"
+msgid "Created a copy of a misnamed branch '%s'"
 msgstr ""
 
-#: builtin/index-pack.c:580
+#: builtin/branch.c:551
 #, c-format
-msgid "premature end of pack file, %<PRIuMAX> byte missing"
-msgid_plural "premature end of pack file, %<PRIuMAX> bytes missing"
-msgstr[0] ""
-msgstr[1] ""
-
-#: builtin/index-pack.c:606
-msgid "serious inflate inconsistency"
+msgid "Renamed a misnamed branch '%s' away"
 msgstr ""
 
-#: builtin/index-pack.c:751 builtin/index-pack.c:757 builtin/index-pack.c:780
-#: builtin/index-pack.c:819 builtin/index-pack.c:828
+#: builtin/branch.c:557
 #, c-format
-msgid "SHA1 COLLISION FOUND WITH %s !"
+msgid "Branch renamed to %s, but HEAD is not updated!"
 msgstr ""
 
-#: builtin/index-pack.c:754 builtin/pack-objects.c:198
-#: builtin/pack-objects.c:292
-#, c-format
-msgid "unable to read %s"
+#: builtin/branch.c:566
+msgid "Branch is renamed, but update of config-file failed"
 msgstr ""
 
-#: builtin/index-pack.c:817
-#, c-format
-msgid "cannot read existing object info %s"
+#: builtin/branch.c:568
+msgid "Branch is copied, but update of config-file failed"
 msgstr ""
 
-#: builtin/index-pack.c:825
+#: builtin/branch.c:584
 #, c-format
-msgid "cannot read existing object %s"
+msgid ""
+"Please edit the description for the branch\n"
+"  %s\n"
+"Lines starting with '%c' will be stripped.\n"
 msgstr ""
 
-#: builtin/index-pack.c:839
-#, c-format
-msgid "invalid blob object %s"
+#: builtin/branch.c:618
+msgid "Generic options"
 msgstr ""
 
-#: builtin/index-pack.c:842 builtin/index-pack.c:860
-msgid "fsck error in packed object"
+#: builtin/branch.c:620
+msgid "show hash and subject, give twice for upstream branch"
 msgstr ""
 
-#: builtin/index-pack.c:857
-#, c-format
-msgid "invalid %s"
+#: builtin/branch.c:621
+msgid "suppress informational messages"
 msgstr ""
 
-#: builtin/index-pack.c:862
-#, c-format
-msgid "Not all child objects of %s are reachable"
+#: builtin/branch.c:622
+msgid "set up tracking mode (see git-pull(1))"
 msgstr ""
 
-#: builtin/index-pack.c:934 builtin/index-pack.c:965
-msgid "failed to apply delta"
+#: builtin/branch.c:624
+msgid "do not use"
 msgstr ""
 
-#: builtin/index-pack.c:1135
-msgid "Receiving objects"
+#: builtin/branch.c:626 builtin/rebase.c:505
+msgid "upstream"
 msgstr ""
 
-#: builtin/index-pack.c:1135
-msgid "Indexing objects"
+#: builtin/branch.c:626
+msgid "change the upstream info"
 msgstr ""
 
-#: builtin/index-pack.c:1169
-msgid "pack is corrupted (SHA1 mismatch)"
+#: builtin/branch.c:627
+msgid "unset the upstream info"
 msgstr ""
 
-#: builtin/index-pack.c:1174
-msgid "cannot fstat packfile"
+#: builtin/branch.c:628
+msgid "use colored output"
 msgstr ""
 
-#: builtin/index-pack.c:1177
-msgid "pack has junk at the end"
+#: builtin/branch.c:629
+msgid "act on remote-tracking branches"
 msgstr ""
 
-#: builtin/index-pack.c:1189
-msgid "confusion beyond insanity in parse_pack_objects()"
+#: builtin/branch.c:631 builtin/branch.c:633
+msgid "print only branches that contain the commit"
 msgstr ""
 
-#: builtin/index-pack.c:1212
-msgid "Resolving deltas"
+#: builtin/branch.c:632 builtin/branch.c:634
+msgid "print only branches that don't contain the commit"
 msgstr ""
 
-#: builtin/index-pack.c:1223
-#, c-format
-msgid "unable to create thread: %s"
+#: builtin/branch.c:637
+msgid "Specific git-branch actions:"
 msgstr ""
 
-#: builtin/index-pack.c:1265
-msgid "confusion beyond insanity"
+#: builtin/branch.c:638
+msgid "list both remote-tracking and local branches"
 msgstr ""
 
-#: builtin/index-pack.c:1271
-#, c-format
-msgid "completed with %d local object"
-msgid_plural "completed with %d local objects"
-msgstr[0] ""
-msgstr[1] ""
+#: builtin/branch.c:640
+msgid "delete fully merged branch"
+msgstr ""
 
-#: builtin/index-pack.c:1283
-#, c-format
-msgid "Unexpected tail checksum for %s (disk corruption?)"
+#: builtin/branch.c:641
+msgid "delete branch (even if not merged)"
 msgstr ""
 
-#: builtin/index-pack.c:1287
-#, c-format
-msgid "pack has %d unresolved delta"
-msgid_plural "pack has %d unresolved deltas"
-msgstr[0] ""
-msgstr[1] ""
-
-#: builtin/index-pack.c:1311
-#, c-format
-msgid "unable to deflate appended object (%d)"
+#: builtin/branch.c:642
+msgid "move/rename a branch and its reflog"
 msgstr ""
 
-#: builtin/index-pack.c:1388
-#, c-format
-msgid "local object %s is corrupt"
+#: builtin/branch.c:643
+msgid "move/rename a branch, even if target exists"
 msgstr ""
 
-#: builtin/index-pack.c:1402
-#, c-format
-msgid "packfile name '%s' does not end with '.pack'"
+#: builtin/branch.c:644
+msgid "copy a branch and its reflog"
 msgstr ""
 
-#: builtin/index-pack.c:1427
-#, c-format
-msgid "cannot write %s file '%s'"
+#: builtin/branch.c:645
+msgid "copy a branch, even if target exists"
 msgstr ""
 
-#: builtin/index-pack.c:1435
-#, c-format
-msgid "cannot close written %s file '%s'"
+#: builtin/branch.c:646
+msgid "list branch names"
 msgstr ""
 
-#: builtin/index-pack.c:1459
-msgid "error while closing pack file"
+#: builtin/branch.c:647
+msgid "show current branch name"
 msgstr ""
 
-#: builtin/index-pack.c:1473
-msgid "cannot store pack file"
+#: builtin/branch.c:648
+msgid "create the branch's reflog"
 msgstr ""
 
-#: builtin/index-pack.c:1481
-msgid "cannot store index file"
+#: builtin/branch.c:650
+msgid "edit the description for the branch"
 msgstr ""
 
-#: builtin/index-pack.c:1525
-#, c-format
-msgid "bad pack.indexversion=%<PRIu32>"
+#: builtin/branch.c:651
+msgid "force creation, move/rename, deletion"
 msgstr ""
 
-#: builtin/index-pack.c:1594
-#, c-format
-msgid "Cannot open existing pack file '%s'"
+#: builtin/branch.c:652
+msgid "print only branches that are merged"
 msgstr ""
 
-#: builtin/index-pack.c:1596
-#, c-format
-msgid "Cannot open existing pack idx file for '%s'"
+#: builtin/branch.c:653
+msgid "print only branches that are not merged"
 msgstr ""
 
-#: builtin/index-pack.c:1644
-#, c-format
-msgid "non delta: %d object"
-msgid_plural "non delta: %d objects"
-msgstr[0] ""
-msgstr[1] ""
-
-#: builtin/index-pack.c:1651
-#, c-format
-msgid "chain length = %d: %lu object"
-msgid_plural "chain length = %d: %lu objects"
-msgstr[0] ""
-msgstr[1] ""
-
-#: builtin/index-pack.c:1688
-msgid "Cannot come back to cwd"
+#: builtin/branch.c:654
+msgid "list branches in columns"
 msgstr ""
 
-#: builtin/index-pack.c:1739 builtin/index-pack.c:1742
-#: builtin/index-pack.c:1758 builtin/index-pack.c:1762
-#, c-format
-msgid "bad %s"
+#: builtin/branch.c:657 builtin/for-each-ref.c:42 builtin/notes.c:415
+#: builtin/notes.c:418 builtin/notes.c:581 builtin/notes.c:584
+#: builtin/tag.c:433
+msgid "object"
 msgstr ""
 
-#: builtin/index-pack.c:1778
-msgid "--fix-thin cannot be used without --stdin"
+#: builtin/branch.c:658
+msgid "print only branches of the object"
 msgstr ""
 
-#: builtin/index-pack.c:1780
-msgid "--stdin requires a git repository"
+#: builtin/branch.c:660 builtin/for-each-ref.c:48 builtin/tag.c:440
+msgid "sorting and filtering are case insensitive"
 msgstr ""
 
-#: builtin/index-pack.c:1786
-msgid "--verify with no packfile name given"
+#: builtin/branch.c:661 builtin/for-each-ref.c:38 builtin/tag.c:438
+#: builtin/verify-tag.c:38
+msgid "format to use for the output"
 msgstr ""
 
-#: builtin/index-pack.c:1836 builtin/unpack-objects.c:578
-msgid "fsck error in pack objects"
+#: builtin/branch.c:684 builtin/clone.c:784
+msgid "HEAD not found below refs/heads!"
 msgstr ""
 
-#: builtin/init-db.c:55
-#, c-format
-msgid "cannot stat '%s'"
+#: builtin/branch.c:708
+msgid "--column and --verbose are incompatible"
 msgstr ""
 
-#: builtin/init-db.c:61
-#, c-format
-msgid "cannot stat template '%s'"
+#: builtin/branch.c:723 builtin/branch.c:777 builtin/branch.c:786
+msgid "branch name required"
 msgstr ""
 
-#: builtin/init-db.c:66
-#, c-format
-msgid "cannot opendir '%s'"
+#: builtin/branch.c:753
+msgid "Cannot give description to detached HEAD"
 msgstr ""
 
-#: builtin/init-db.c:77
-#, c-format
-msgid "cannot readlink '%s'"
+#: builtin/branch.c:758
+msgid "cannot edit description of more than one branch"
 msgstr ""
 
-#: builtin/init-db.c:79
+#: builtin/branch.c:765
 #, c-format
-msgid "cannot symlink '%s' '%s'"
+msgid "No commit on branch '%s' yet."
 msgstr ""
 
-#: builtin/init-db.c:85
+#: builtin/branch.c:768
 #, c-format
-msgid "cannot copy '%s' to '%s'"
+msgid "No branch named '%s'."
 msgstr ""
 
-#: builtin/init-db.c:89
-#, c-format
-msgid "ignoring template %s"
+#: builtin/branch.c:783
+msgid "too many branches for a copy operation"
 msgstr ""
 
-#: builtin/init-db.c:120
-#, c-format
-msgid "templates not found in %s"
+#: builtin/branch.c:792
+msgid "too many arguments for a rename operation"
 msgstr ""
 
-#: builtin/init-db.c:135
-#, c-format
-msgid "not copying templates from '%s': %s"
+#: builtin/branch.c:797
+msgid "too many arguments to set new upstream"
 msgstr ""
 
-#: builtin/init-db.c:328
+#: builtin/branch.c:801
 #, c-format
-msgid "unable to handle file type %d"
+msgid ""
+"could not set upstream of HEAD to %s when it does not point to any branch."
 msgstr ""
 
-#: builtin/init-db.c:331
+#: builtin/branch.c:804 builtin/branch.c:827
 #, c-format
-msgid "unable to move %s to %s"
+msgid "no such branch '%s'"
 msgstr ""
 
-#: builtin/init-db.c:348 builtin/init-db.c:351
+#: builtin/branch.c:808
 #, c-format
-msgid "%s already exists"
+msgid "branch '%s' does not exist"
 msgstr ""
 
-#: builtin/init-db.c:404
-#, c-format
-msgid "Reinitialized existing shared Git repository in %s%s\n"
+#: builtin/branch.c:821
+msgid "too many arguments to unset upstream"
 msgstr ""
 
-#: builtin/init-db.c:405
-#, c-format
-msgid "Reinitialized existing Git repository in %s%s\n"
+#: builtin/branch.c:825
+msgid "could not unset upstream of HEAD when it does not point to any branch."
 msgstr ""
 
-#: builtin/init-db.c:409
+#: builtin/branch.c:831
 #, c-format
-msgid "Initialized empty shared Git repository in %s%s\n"
+msgid "Branch '%s' has no upstream information"
 msgstr ""
 
-#: builtin/init-db.c:410
-#, c-format
-msgid "Initialized empty Git repository in %s%s\n"
+#: builtin/branch.c:841
+msgid ""
+"The -a, and -r, options to 'git branch' do not take a branch name.\n"
+"Did you mean to use: -a|-r --list <pattern>?"
 msgstr ""
 
-#: builtin/init-db.c:458
+#: builtin/branch.c:845
 msgid ""
-"git init [-q | --quiet] [--bare] [--template=<template-directory>] [--"
-"shared[=<permissions>]] [<directory>]"
+"the '--set-upstream' option is no longer supported. Please use '--track' or "
+"'--set-upstream-to' instead."
 msgstr ""
 
-#: builtin/init-db.c:481
-msgid "permissions"
+#: builtin/bundle.c:15 builtin/bundle.c:23
+msgid "git bundle create [<options>] <file> <git-rev-list args>"
 msgstr ""
 
-#: builtin/init-db.c:482
-msgid "specify that the git repository is to be shared amongst several users"
+#: builtin/bundle.c:16 builtin/bundle.c:28
+msgid "git bundle verify [<options>] <file>"
 msgstr ""
 
-#: builtin/init-db.c:525
-#, c-format
-msgid "cannot chdir to %s"
+#: builtin/bundle.c:17 builtin/bundle.c:33
+msgid "git bundle list-heads <file> [<refname>...]"
 msgstr ""
 
-#: builtin/init-db.c:546
-#, c-format
-msgid ""
-"%s (or --work-tree=<directory>) not allowed without specifying %s (or --git-"
-"dir=<directory>)"
+#: builtin/bundle.c:18 builtin/bundle.c:38
+msgid "git bundle unbundle <file> [<refname>...]"
 msgstr ""
 
-#: builtin/init-db.c:574
-#, c-format
-msgid "Cannot access work tree '%s'"
+#: builtin/bundle.c:66 builtin/pack-objects.c:3228
+msgid "do not show progress meter"
 msgstr ""
 
-#: builtin/interpret-trailers.c:15
-msgid ""
-"git interpret-trailers [--in-place] [--trim-empty] [(--trailer "
-"<token>[(=|:)<value>])...] [<file>...]"
+#: builtin/bundle.c:68 builtin/pack-objects.c:3230
+msgid "show progress meter"
 msgstr ""
 
-#: builtin/interpret-trailers.c:92
-msgid "edit files in place"
+#: builtin/bundle.c:70 builtin/pack-objects.c:3232
+msgid "show progress meter during object writing phase"
 msgstr ""
 
-#: builtin/interpret-trailers.c:93
-msgid "trim empty trailers"
+#: builtin/bundle.c:73 builtin/pack-objects.c:3235
+msgid "similar to --all-progress when progress meter is shown"
 msgstr ""
 
-#: builtin/interpret-trailers.c:96
-msgid "where to place the new trailer"
+#: builtin/bundle.c:93
+msgid "Need a repository to create a bundle."
 msgstr ""
 
-#: builtin/interpret-trailers.c:98
-msgid "action if trailer already exists"
+#: builtin/bundle.c:104
+msgid "do not show bundle details"
 msgstr ""
 
-#: builtin/interpret-trailers.c:100
-msgid "action if trailer is missing"
+#: builtin/bundle.c:119
+#, c-format
+msgid "%s is okay\n"
 msgstr ""
 
-#: builtin/interpret-trailers.c:102
-msgid "output only the trailers"
+#: builtin/bundle.c:160
+msgid "Need a repository to unbundle."
 msgstr ""
 
-#: builtin/interpret-trailers.c:103
-msgid "do not apply config rules"
+#: builtin/bundle.c:168 builtin/remote.c:1609
+msgid "be verbose; must be placed before a subcommand"
 msgstr ""
 
-#: builtin/interpret-trailers.c:104
-msgid "join whitespace-continued values"
+#: builtin/bundle.c:190 builtin/remote.c:1640
+#, c-format
+msgid "Unknown subcommand: %s"
 msgstr ""
 
-#: builtin/interpret-trailers.c:105
-msgid "set parsing options"
+#: builtin/cat-file.c:595
+msgid ""
+"git cat-file (-t [--allow-unknown-type] | -s [--allow-unknown-type] | -e | -"
+"p | <type> | --textconv | --filters) [--path=<path>] <object>"
 msgstr ""
 
-#: builtin/interpret-trailers.c:107
-msgid "trailer"
+#: builtin/cat-file.c:596
+msgid ""
+"git cat-file (--batch | --batch-check) [--follow-symlinks] [--textconv | --"
+"filters]"
 msgstr ""
 
-#: builtin/interpret-trailers.c:108
-msgid "trailer(s) to add"
+#: builtin/cat-file.c:617
+msgid "only one batch option may be specified"
 msgstr ""
 
-#: builtin/interpret-trailers.c:117
-msgid "--trailer with --only-input does not make sense"
+#: builtin/cat-file.c:635
+msgid "<type> can be one of: blob, tree, commit, tag"
 msgstr ""
 
-#: builtin/interpret-trailers.c:127
-msgid "no input file given for in-place editing"
+#: builtin/cat-file.c:636
+msgid "show object type"
 msgstr ""
 
-#: builtin/log.c:48
-msgid "git log [<options>] [<revision-range>] [[--] <path>...]"
+#: builtin/cat-file.c:637
+msgid "show object size"
 msgstr ""
 
-#: builtin/log.c:49
-msgid "git show [<options>] <object>..."
+#: builtin/cat-file.c:639
+msgid "exit with zero when there's no error"
 msgstr ""
 
-#: builtin/log.c:93
-#, c-format
-msgid "invalid --decorate option: %s"
+#: builtin/cat-file.c:640
+msgid "pretty-print object's content"
 msgstr ""
 
-#: builtin/log.c:153
-msgid "suppress diff output"
+#: builtin/cat-file.c:642
+msgid "for blob objects, run textconv on object's content"
 msgstr ""
 
-#: builtin/log.c:154
-msgid "show source"
+#: builtin/cat-file.c:644
+msgid "for blob objects, run filters on object's content"
 msgstr ""
 
-#: builtin/log.c:155
-msgid "Use mail map file"
+#: builtin/cat-file.c:645 git-submodule.sh:992
+msgid "blob"
 msgstr ""
 
-#: builtin/log.c:157
-msgid "only decorate refs that match <pattern>"
+#: builtin/cat-file.c:646
+msgid "use a specific path for --textconv/--filters"
 msgstr ""
 
-#: builtin/log.c:159
-msgid "do not decorate refs that match <pattern>"
+#: builtin/cat-file.c:648
+msgid "allow -s and -t to work with broken/corrupt objects"
 msgstr ""
 
-#: builtin/log.c:160
-msgid "decorate options"
+#: builtin/cat-file.c:649
+msgid "buffer --batch output"
 msgstr ""
 
-#: builtin/log.c:163
-msgid "Process line range n,m in file, counting from 1"
+#: builtin/cat-file.c:651
+msgid "show info and content of objects fed from the standard input"
 msgstr ""
 
-#: builtin/log.c:259
-#, c-format
-msgid "Final output: %d %s\n"
+#: builtin/cat-file.c:655
+msgid "show info about objects fed from the standard input"
 msgstr ""
 
-#: builtin/log.c:510
-#, c-format
-msgid "git show %s: bad file"
+#: builtin/cat-file.c:659
+msgid "follow in-tree symlinks (used with --batch or --batch-check)"
 msgstr ""
 
-#: builtin/log.c:525 builtin/log.c:619
-#, c-format
-msgid "Could not read object %s"
+#: builtin/cat-file.c:661
+msgid "show all objects with --batch or --batch-check"
 msgstr ""
 
-#: builtin/log.c:643
-#, c-format
-msgid "Unknown type: %d"
+#: builtin/cat-file.c:663
+msgid "do not order --batch-all-objects output"
 msgstr ""
 
-#: builtin/log.c:764
-msgid "format.headers without value"
+#: builtin/check-attr.c:13
+msgid "git check-attr [-a | --all | <attr>...] [--] <pathname>..."
 msgstr ""
 
-#: builtin/log.c:865
-msgid "name of output directory is too long"
+#: builtin/check-attr.c:14
+msgid "git check-attr --stdin [-z] [-a | --all | <attr>...]"
 msgstr ""
 
-#: builtin/log.c:881
-#, c-format
-msgid "Cannot open patch file %s"
+#: builtin/check-attr.c:21
+msgid "report all attributes set on file"
 msgstr ""
 
-#: builtin/log.c:898
-msgid "Need exactly one range."
+#: builtin/check-attr.c:22
+msgid "use .gitattributes only from the index"
 msgstr ""
 
-#: builtin/log.c:908
-msgid "Not a range."
+#: builtin/check-attr.c:23 builtin/check-ignore.c:25 builtin/hash-object.c:102
+msgid "read file names from stdin"
 msgstr ""
 
-#: builtin/log.c:1014
-msgid "Cover letter needs email format"
+#: builtin/check-attr.c:25 builtin/check-ignore.c:27
+msgid "terminate input and output records by a NUL character"
 msgstr ""
 
-#: builtin/log.c:1095
-#, c-format
-msgid "insane in-reply-to: %s"
+#: builtin/check-ignore.c:21 builtin/checkout.c:1435 builtin/gc.c:537
+#: builtin/worktree.c:506
+msgid "suppress progress reporting"
 msgstr ""
 
-#: builtin/log.c:1122
-msgid "git format-patch [<options>] [<since> | <revision-range>]"
+#: builtin/check-ignore.c:29
+msgid "show non-matching input paths"
 msgstr ""
 
-#: builtin/log.c:1172
-msgid "Two output directories?"
+#: builtin/check-ignore.c:31
+msgid "ignore index when checking"
 msgstr ""
 
-#: builtin/log.c:1279 builtin/log.c:1932 builtin/log.c:1934 builtin/log.c:1946
-#, c-format
-msgid "Unknown commit %s"
+#: builtin/check-ignore.c:160
+msgid "cannot specify pathnames with --stdin"
 msgstr ""
 
-#: builtin/log.c:1289 builtin/notes.c:887 builtin/tag.c:523
-#, c-format
-msgid "Failed to resolve '%s' as a valid ref."
+#: builtin/check-ignore.c:163
+msgid "-z only makes sense with --stdin"
 msgstr ""
 
-#: builtin/log.c:1294
-msgid "Could not find exact merge base."
+#: builtin/check-ignore.c:165
+msgid "no path specified"
 msgstr ""
 
-#: builtin/log.c:1298
-msgid ""
-"Failed to get upstream, if you want to record base commit automatically,\n"
-"please use git branch --set-upstream-to to track a remote branch.\n"
-"Or you could specify base commit by --base=<base-commit-id> manually."
+#: builtin/check-ignore.c:169
+msgid "--quiet is only valid with a single pathname"
 msgstr ""
 
-#: builtin/log.c:1318
-msgid "Failed to find exact merge base"
+#: builtin/check-ignore.c:171
+msgid "cannot have both --quiet and --verbose"
 msgstr ""
 
-#: builtin/log.c:1329
-msgid "base commit should be the ancestor of revision list"
+#: builtin/check-ignore.c:174
+msgid "--non-matching is only valid with --verbose"
 msgstr ""
 
-#: builtin/log.c:1333
-msgid "base commit shouldn't be in revision list"
+#: builtin/check-mailmap.c:9
+msgid "git check-mailmap [<options>] <contact>..."
 msgstr ""
 
-#: builtin/log.c:1382
-msgid "cannot get patch id"
+#: builtin/check-mailmap.c:14
+msgid "also read contacts from stdin"
 msgstr ""
 
-#: builtin/log.c:1441
-msgid "use [PATCH n/m] even with a single patch"
+#: builtin/check-mailmap.c:25
+#, c-format
+msgid "unable to parse contact: %s"
 msgstr ""
 
-#: builtin/log.c:1444
-msgid "use [PATCH] even with multiple patches"
+#: builtin/check-mailmap.c:48
+msgid "no contacts specified"
 msgstr ""
 
-#: builtin/log.c:1448
-msgid "print patches to standard out"
+#: builtin/checkout-index.c:131
+msgid "git checkout-index [<options>] [--] [<file>...]"
 msgstr ""
 
-#: builtin/log.c:1450
-msgid "generate a cover letter"
+#: builtin/checkout-index.c:148
+msgid "stage should be between 1 and 3 or all"
 msgstr ""
 
-#: builtin/log.c:1452
-msgid "use simple number sequence for output file names"
+#: builtin/checkout-index.c:164
+msgid "check out all files in the index"
 msgstr ""
 
-#: builtin/log.c:1453
-msgid "sfx"
+#: builtin/checkout-index.c:165
+msgid "force overwrite of existing files"
 msgstr ""
 
-#: builtin/log.c:1454
-msgid "use <sfx> instead of '.patch'"
+#: builtin/checkout-index.c:167
+msgid "no warning for existing files and files not in index"
 msgstr ""
 
-#: builtin/log.c:1456
-msgid "start numbering patches at <n> instead of 1"
+#: builtin/checkout-index.c:169
+msgid "don't checkout new files"
 msgstr ""
 
-#: builtin/log.c:1458
-msgid "mark the series as Nth re-roll"
+#: builtin/checkout-index.c:171
+msgid "update stat information in the index file"
 msgstr ""
 
-#: builtin/log.c:1460
-msgid "Use [RFC PATCH] instead of [PATCH]"
+#: builtin/checkout-index.c:175
+msgid "read list of paths from the standard input"
 msgstr ""
 
-#: builtin/log.c:1463
-msgid "Use [<prefix>] instead of [PATCH]"
+#: builtin/checkout-index.c:177
+msgid "write the content to temporary files"
 msgstr ""
 
-#: builtin/log.c:1466
-msgid "store resulting files in <dir>"
+#: builtin/checkout-index.c:178 builtin/column.c:31
+#: builtin/submodule--helper.c:1385 builtin/submodule--helper.c:1388
+#: builtin/submodule--helper.c:1396 builtin/submodule--helper.c:1882
+#: builtin/worktree.c:679
+msgid "string"
 msgstr ""
 
-#: builtin/log.c:1469
-msgid "don't strip/add [PATCH]"
+#: builtin/checkout-index.c:179
+msgid "when creating files, prepend <string>"
 msgstr ""
 
-#: builtin/log.c:1472
-msgid "don't output binary diffs"
+#: builtin/checkout-index.c:181
+msgid "copy out the files from named stage"
 msgstr ""
 
-#: builtin/log.c:1474
-msgid "output all-zero hash in From header"
+#: builtin/checkout.c:31
+msgid "git checkout [<options>] <branch>"
 msgstr ""
 
-#: builtin/log.c:1476
-msgid "don't include a patch matching a commit upstream"
+#: builtin/checkout.c:32
+msgid "git checkout [<options>] [<branch>] -- <file>..."
 msgstr ""
 
-#: builtin/log.c:1478
-msgid "show patch format instead of default (patch + stat)"
+#: builtin/checkout.c:37
+msgid "git switch [<options>] [<branch>]"
 msgstr ""
 
-#: builtin/log.c:1480
-msgid "Messaging"
+#: builtin/checkout.c:42
+msgid "git restore [<options>] [--source=<branch>] <file>..."
 msgstr ""
 
-#: builtin/log.c:1481
-msgid "header"
+#: builtin/checkout.c:175 builtin/checkout.c:214
+#, c-format
+msgid "path '%s' does not have our version"
 msgstr ""
 
-#: builtin/log.c:1482
-msgid "add email header"
+#: builtin/checkout.c:177 builtin/checkout.c:216
+#, c-format
+msgid "path '%s' does not have their version"
 msgstr ""
 
-#: builtin/log.c:1483 builtin/log.c:1485
-msgid "email"
+#: builtin/checkout.c:193
+#, c-format
+msgid "path '%s' does not have all necessary versions"
 msgstr ""
 
-#: builtin/log.c:1483
-msgid "add To: header"
+#: builtin/checkout.c:243
+#, c-format
+msgid "path '%s' does not have necessary versions"
 msgstr ""
 
-#: builtin/log.c:1485
-msgid "add Cc: header"
+#: builtin/checkout.c:261
+#, c-format
+msgid "path '%s': cannot merge"
 msgstr ""
 
-#: builtin/log.c:1487
-msgid "ident"
+#: builtin/checkout.c:277
+#, c-format
+msgid "Unable to add merge result for '%s'"
 msgstr ""
 
-#: builtin/log.c:1488
-msgid "set From address to <ident> (or committer ident if absent)"
-msgstr ""
+#: builtin/checkout.c:377
+#, c-format
+msgid "Recreated %d merge conflict"
+msgid_plural "Recreated %d merge conflicts"
+msgstr[0] ""
+msgstr[1] ""
 
-#: builtin/log.c:1490
-msgid "message-id"
-msgstr ""
+#: builtin/checkout.c:382
+#, c-format
+msgid "Updated %d path from %s"
+msgid_plural "Updated %d paths from %s"
+msgstr[0] ""
+msgstr[1] ""
 
-#: builtin/log.c:1491
-msgid "make first mail a reply to <message-id>"
+#: builtin/checkout.c:389
+#, c-format
+msgid "Updated %d path from the index"
+msgid_plural "Updated %d paths from the index"
+msgstr[0] ""
+msgstr[1] ""
+
+#: builtin/checkout.c:412 builtin/checkout.c:415 builtin/checkout.c:418
+#: builtin/checkout.c:422
+#, c-format
+msgid "'%s' cannot be used with updating paths"
 msgstr ""
 
-#: builtin/log.c:1492 builtin/log.c:1495
-msgid "boundary"
+#: builtin/checkout.c:425 builtin/checkout.c:428
+#, c-format
+msgid "'%s' cannot be used with %s"
 msgstr ""
 
-#: builtin/log.c:1493
-msgid "attach the patch"
+#: builtin/checkout.c:432
+#, c-format
+msgid "Cannot update paths and switch to branch '%s' at the same time."
 msgstr ""
 
-#: builtin/log.c:1496
-msgid "inline the patch"
+#: builtin/checkout.c:436
+#, c-format
+msgid "neither '%s' or '%s' is specified"
 msgstr ""
 
-#: builtin/log.c:1500
-msgid "enable message threading, styles: shallow, deep"
+#: builtin/checkout.c:440
+#, c-format
+msgid "'%s' must be used when '%s' is not specified"
 msgstr ""
 
-#: builtin/log.c:1502
-msgid "signature"
+#: builtin/checkout.c:445 builtin/checkout.c:450
+#, c-format
+msgid "'%s' or '%s' cannot be used with %s"
 msgstr ""
 
-#: builtin/log.c:1503
-msgid "add a signature"
+#: builtin/checkout.c:509 builtin/checkout.c:516
+#, c-format
+msgid "path '%s' is unmerged"
 msgstr ""
 
-#: builtin/log.c:1504
-msgid "base-commit"
+#: builtin/checkout.c:682 builtin/sparse-checkout.c:82
+msgid "you need to resolve your current index first"
 msgstr ""
 
-#: builtin/log.c:1505
-msgid "add prerequisite tree info to the patch series"
+#: builtin/checkout.c:732
+#, c-format
+msgid ""
+"cannot continue with staged changes in the following files:\n"
+"%s"
 msgstr ""
 
-#: builtin/log.c:1507
-msgid "add a signature from a file"
+#: builtin/checkout.c:835
+#, c-format
+msgid "Can not do reflog for '%s': %s\n"
 msgstr ""
 
-#: builtin/log.c:1508
-msgid "don't print the patch filenames"
+#: builtin/checkout.c:877
+msgid "HEAD is now at"
 msgstr ""
 
-#: builtin/log.c:1510
-msgid "show progress while generating patches"
+#: builtin/checkout.c:881 builtin/clone.c:716
+msgid "unable to update HEAD"
 msgstr ""
 
-#: builtin/log.c:1585
+#: builtin/checkout.c:885
 #, c-format
-msgid "invalid ident line: %s"
+msgid "Reset branch '%s'\n"
 msgstr ""
 
-#: builtin/log.c:1600
-msgid "-n and -k are mutually exclusive."
+#: builtin/checkout.c:888
+#, c-format
+msgid "Already on '%s'\n"
 msgstr ""
 
-#: builtin/log.c:1602
-msgid "--subject-prefix/--rfc and -k are mutually exclusive."
+#: builtin/checkout.c:892
+#, c-format
+msgid "Switched to and reset branch '%s'\n"
 msgstr ""
 
-#: builtin/log.c:1610
-msgid "--name-only does not make sense"
+#: builtin/checkout.c:894 builtin/checkout.c:1291
+#, c-format
+msgid "Switched to a new branch '%s'\n"
 msgstr ""
 
-#: builtin/log.c:1612
-msgid "--name-status does not make sense"
+#: builtin/checkout.c:896
+#, c-format
+msgid "Switched to branch '%s'\n"
 msgstr ""
 
-#: builtin/log.c:1614
-msgid "--check does not make sense"
+#: builtin/checkout.c:947
+#, c-format
+msgid " ... and %d more.\n"
 msgstr ""
 
-#: builtin/log.c:1646
-msgid "standard output, or directory, which one?"
-msgstr ""
+#: builtin/checkout.c:953
+#, c-format
+msgid ""
+"Warning: you are leaving %d commit behind, not connected to\n"
+"any of your branches:\n"
+"\n"
+"%s\n"
+msgid_plural ""
+"Warning: you are leaving %d commits behind, not connected to\n"
+"any of your branches:\n"
+"\n"
+"%s\n"
+msgstr[0] ""
+msgstr[1] ""
 
-#: builtin/log.c:1648
+#: builtin/checkout.c:972
 #, c-format
-msgid "Could not create directory '%s'"
+msgid ""
+"If you want to keep it by creating a new branch, this may be a good time\n"
+"to do so with:\n"
+"\n"
+" git branch <new-branch-name> %s\n"
+"\n"
+msgid_plural ""
+"If you want to keep them by creating a new branch, this may be a good time\n"
+"to do so with:\n"
+"\n"
+" git branch <new-branch-name> %s\n"
+"\n"
+msgstr[0] ""
+msgstr[1] ""
+
+#: builtin/checkout.c:1007
+msgid "internal error in revision walk"
 msgstr ""
 
-#: builtin/log.c:1741
-#, c-format
-msgid "unable to read signature file '%s'"
+#: builtin/checkout.c:1011
+msgid "Previous HEAD position was"
 msgstr ""
 
-#: builtin/log.c:1773
-msgid "Generating patches"
+#: builtin/checkout.c:1051 builtin/checkout.c:1286
+msgid "You are on a branch yet to be born"
 msgstr ""
 
-#: builtin/log.c:1817
-msgid "Failed to create output files"
+#: builtin/checkout.c:1178
+msgid "only one reference expected"
 msgstr ""
 
-#: builtin/log.c:1867
-msgid "git cherry [-v] [<upstream> [<head> [<limit>]]]"
+#: builtin/checkout.c:1195
+#, c-format
+msgid "only one reference expected, %d given."
 msgstr ""
 
-#: builtin/log.c:1921
+#: builtin/checkout.c:1232
 #, c-format
 msgid ""
-"Could not find a tracked remote branch, please specify <upstream> manually.\n"
+"'%s' could be both a local file and a tracking branch.\n"
+"Please use -- (and optionally --no-guess) to disambiguate"
 msgstr ""
 
-#: builtin/ls-files.c:468
-msgid "git ls-files [<options>] [<file>...]"
+#: builtin/checkout.c:1245 builtin/worktree.c:290 builtin/worktree.c:455
+#, c-format
+msgid "invalid reference: %s"
 msgstr ""
 
-#: builtin/ls-files.c:517
-msgid "identify the file status with tags"
+#: builtin/checkout.c:1258 builtin/checkout.c:1622
+#, c-format
+msgid "reference is not a tree: %s"
 msgstr ""
 
-#: builtin/ls-files.c:519
-msgid "use lowercase letters for 'assume unchanged' files"
+#: builtin/checkout.c:1305
+#, c-format
+msgid "a branch is expected, got tag '%s'"
 msgstr ""
 
-#: builtin/ls-files.c:521
-msgid "use lowercase letters for 'fsmonitor clean' files"
+#: builtin/checkout.c:1307
+#, c-format
+msgid "a branch is expected, got remote branch '%s'"
 msgstr ""
 
-#: builtin/ls-files.c:523
-msgid "show cached files in the output (default)"
+#: builtin/checkout.c:1308 builtin/checkout.c:1316
+#, c-format
+msgid "a branch is expected, got '%s'"
 msgstr ""
 
-#: builtin/ls-files.c:525
-msgid "show deleted files in the output"
+#: builtin/checkout.c:1311
+#, c-format
+msgid "a branch is expected, got commit '%s'"
 msgstr ""
 
-#: builtin/ls-files.c:527
-msgid "show modified files in the output"
+#: builtin/checkout.c:1327
+msgid ""
+"cannot switch branch while merging\n"
+"Consider \"git merge --quit\" or \"git worktree add\"."
 msgstr ""
 
-#: builtin/ls-files.c:529
-msgid "show other files in the output"
+#: builtin/checkout.c:1331
+msgid ""
+"cannot switch branch in the middle of an am session\n"
+"Consider \"git am --quit\" or \"git worktree add\"."
 msgstr ""
 
-#: builtin/ls-files.c:531
-msgid "show ignored files in the output"
+#: builtin/checkout.c:1335
+msgid ""
+"cannot switch branch while rebasing\n"
+"Consider \"git rebase --quit\" or \"git worktree add\"."
 msgstr ""
 
-#: builtin/ls-files.c:534
-msgid "show staged contents' object name in the output"
+#: builtin/checkout.c:1339
+msgid ""
+"cannot switch branch while cherry-picking\n"
+"Consider \"git cherry-pick --quit\" or \"git worktree add\"."
 msgstr ""
 
-#: builtin/ls-files.c:536
-msgid "show files on the filesystem that need to be removed"
+#: builtin/checkout.c:1343
+msgid ""
+"cannot switch branch while reverting\n"
+"Consider \"git revert --quit\" or \"git worktree add\"."
 msgstr ""
 
-#: builtin/ls-files.c:538
-msgid "show 'other' directories' names only"
+#: builtin/checkout.c:1347
+msgid "you are switching branch while bisecting"
 msgstr ""
 
-#: builtin/ls-files.c:540
-msgid "show line endings of files"
+#: builtin/checkout.c:1354
+msgid "paths cannot be used with switching branches"
 msgstr ""
 
-#: builtin/ls-files.c:542
-msgid "don't show empty directories"
+#: builtin/checkout.c:1357 builtin/checkout.c:1361 builtin/checkout.c:1365
+#, c-format
+msgid "'%s' cannot be used with switching branches"
 msgstr ""
 
-#: builtin/ls-files.c:545
-msgid "show unmerged files in the output"
+#: builtin/checkout.c:1369 builtin/checkout.c:1372 builtin/checkout.c:1375
+#: builtin/checkout.c:1380 builtin/checkout.c:1385
+#, c-format
+msgid "'%s' cannot be used with '%s'"
 msgstr ""
 
-#: builtin/ls-files.c:547
-msgid "show resolve-undo information"
+#: builtin/checkout.c:1382
+#, c-format
+msgid "'%s' cannot take <start-point>"
 msgstr ""
 
-#: builtin/ls-files.c:549
-msgid "skip files matching pattern"
+#: builtin/checkout.c:1390
+#, c-format
+msgid "Cannot switch branch to a non-commit '%s'"
 msgstr ""
 
-#: builtin/ls-files.c:552
-msgid "exclude patterns are read from <file>"
+#: builtin/checkout.c:1397
+msgid "missing branch or commit argument"
 msgstr ""
 
-#: builtin/ls-files.c:555
-msgid "read additional per-directory exclude patterns in <file>"
+#: builtin/checkout.c:1439 builtin/clone.c:91 builtin/commit-graph.c:52
+#: builtin/commit-graph.c:113 builtin/fetch.c:167 builtin/merge.c:285
+#: builtin/multi-pack-index.c:27 builtin/pull.c:138 builtin/push.c:563
+#: builtin/send-pack.c:174
+msgid "force progress reporting"
 msgstr ""
 
-#: builtin/ls-files.c:557
-msgid "add the standard git exclusions"
+#: builtin/checkout.c:1440
+msgid "perform a 3-way merge with the new branch"
 msgstr ""
 
-#: builtin/ls-files.c:560
-msgid "make the output relative to the project top directory"
+#: builtin/checkout.c:1441 builtin/log.c:1690 parse-options.h:322
+msgid "style"
 msgstr ""
 
-#: builtin/ls-files.c:563
-msgid "recurse through submodules"
+#: builtin/checkout.c:1442
+msgid "conflict style (merge or diff3)"
 msgstr ""
 
-#: builtin/ls-files.c:565
-msgid "if any <file> is not in the index, treat this as an error"
+#: builtin/checkout.c:1454 builtin/worktree.c:503
+msgid "detach HEAD at named commit"
 msgstr ""
 
-#: builtin/ls-files.c:566
-msgid "tree-ish"
+#: builtin/checkout.c:1455
+msgid "set upstream info for new branch"
 msgstr ""
 
-#: builtin/ls-files.c:567
-msgid "pretend that paths removed since <tree-ish> are still present"
+#: builtin/checkout.c:1457
+msgid "force checkout (throw away local modifications)"
 msgstr ""
 
-#: builtin/ls-files.c:569
-msgid "show debugging data"
+#: builtin/checkout.c:1459
+msgid "new-branch"
 msgstr ""
 
-#: builtin/ls-remote.c:9
-msgid ""
-"git ls-remote [--heads] [--tags] [--refs] [--upload-pack=<exec>]\n"
-"                     [-q | --quiet] [--exit-code] [--get-url]\n"
-"                     [--symref] [<repository> [<refs>...]]"
+#: builtin/checkout.c:1459
+msgid "new unparented branch"
 msgstr ""
 
-#: builtin/ls-remote.c:59
-msgid "do not print remote URL"
+#: builtin/checkout.c:1461 builtin/merge.c:288
+msgid "update ignored files (default)"
 msgstr ""
 
-#: builtin/ls-remote.c:60 builtin/ls-remote.c:62
-msgid "exec"
+#: builtin/checkout.c:1464
+msgid "do not check if another worktree is holding the given ref"
 msgstr ""
 
-#: builtin/ls-remote.c:61 builtin/ls-remote.c:63
-msgid "path of git-upload-pack on the remote host"
+#: builtin/checkout.c:1477
+msgid "checkout our version for unmerged files"
 msgstr ""
 
-#: builtin/ls-remote.c:65
-msgid "limit to tags"
+#: builtin/checkout.c:1480
+msgid "checkout their version for unmerged files"
 msgstr ""
 
-#: builtin/ls-remote.c:66
-msgid "limit to heads"
+#: builtin/checkout.c:1484
+msgid "do not limit pathspecs to sparse entries only"
 msgstr ""
 
-#: builtin/ls-remote.c:67
-msgid "do not show peeled tags"
+#: builtin/checkout.c:1537
+msgid "-b, -B and --orphan are mutually exclusive"
 msgstr ""
 
-#: builtin/ls-remote.c:69
-msgid "take url.<base>.insteadOf into account"
+#: builtin/checkout.c:1540
+msgid "-p and --overlay are mutually exclusive"
 msgstr ""
 
-#: builtin/ls-remote.c:73
-msgid "exit with exit code 2 if no matching refs are found"
+#: builtin/checkout.c:1577
+msgid "--track needs a branch name"
 msgstr ""
 
-#: builtin/ls-remote.c:76
-msgid "show underlying ref in addition to the object pointed by it"
+#: builtin/checkout.c:1582
+msgid "missing branch name; try -b"
 msgstr ""
 
-#: builtin/ls-tree.c:29
-msgid "git ls-tree [<options>] <tree-ish> [<path>...]"
+#: builtin/checkout.c:1615
+#, c-format
+msgid "could not resolve %s"
 msgstr ""
 
-#: builtin/ls-tree.c:127
-msgid "only show trees"
+#: builtin/checkout.c:1631
+msgid "invalid path specification"
 msgstr ""
 
-#: builtin/ls-tree.c:129
-msgid "recurse into subtrees"
+#: builtin/checkout.c:1638
+#, c-format
+msgid "'%s' is not a commit and a branch '%s' cannot be created from it"
 msgstr ""
 
-#: builtin/ls-tree.c:131
-msgid "show trees when recursing"
+#: builtin/checkout.c:1642
+#, c-format
+msgid "git checkout: --detach does not take a path argument '%s'"
 msgstr ""
 
-#: builtin/ls-tree.c:134
-msgid "terminate entries with NUL byte"
+#: builtin/checkout.c:1651
+msgid "--pathspec-from-file is incompatible with --detach"
 msgstr ""
 
-#: builtin/ls-tree.c:135
-msgid "include object size"
+#: builtin/checkout.c:1654 builtin/reset.c:324
+msgid "--pathspec-from-file is incompatible with --patch"
 msgstr ""
 
-#: builtin/ls-tree.c:137 builtin/ls-tree.c:139
-msgid "list only filenames"
+#: builtin/checkout.c:1665
+msgid ""
+"git checkout: --ours/--theirs, --force and --merge are incompatible when\n"
+"checking out of the index."
 msgstr ""
 
-#: builtin/ls-tree.c:142
-msgid "use full path names"
+#: builtin/checkout.c:1670
+msgid "you must specify path(s) to restore"
 msgstr ""
 
-#: builtin/ls-tree.c:144
-msgid "list entire tree; not just current directory (implies --full-name)"
+#: builtin/checkout.c:1689
+#, c-format
+msgid ""
+"'%s' matched more than one remote tracking branch.\n"
+"We found %d remotes with a reference that matched. So we fell back\n"
+"on trying to resolve the argument as a path, but failed there too!\n"
+"\n"
+"If you meant to check out a remote tracking branch on, e.g. 'origin',\n"
+"you can do so by fully qualifying the name with the --track option:\n"
+"\n"
+"    git checkout --track origin/<name>\n"
+"\n"
+"If you'd like to always have checkouts of an ambiguous <name> prefer\n"
+"one remote, e.g. the 'origin' remote, consider setting\n"
+"checkout.defaultRemote=origin in your config."
 msgstr ""
 
-#: builtin/mailsplit.c:241
-#, c-format
-msgid "empty mbox: '%s'"
+#: builtin/checkout.c:1714 builtin/checkout.c:1716 builtin/checkout.c:1765
+#: builtin/checkout.c:1767 builtin/clone.c:121 builtin/remote.c:169
+#: builtin/remote.c:171 builtin/worktree.c:499 builtin/worktree.c:501
+msgid "branch"
 msgstr ""
 
-#: builtin/merge.c:51
-msgid "git merge [<options>] [<commit>...]"
+#: builtin/checkout.c:1715
+msgid "create and checkout a new branch"
 msgstr ""
 
-#: builtin/merge.c:52
-msgid "git merge --abort"
+#: builtin/checkout.c:1717
+msgid "create/reset and checkout a branch"
 msgstr ""
 
-#: builtin/merge.c:53
-msgid "git merge --continue"
+#: builtin/checkout.c:1718
+msgid "create reflog for new branch"
 msgstr ""
 
-#: builtin/merge.c:110
-msgid "switch `m' requires a value"
+#: builtin/checkout.c:1720
+msgid "second guess 'git checkout <no-such-branch>' (default)"
 msgstr ""
 
-#: builtin/merge.c:147
-#, c-format
-msgid "Could not find merge strategy '%s'.\n"
+#: builtin/checkout.c:1721
+msgid "use overlay mode (default)"
 msgstr ""
 
-#: builtin/merge.c:148
-#, c-format
-msgid "Available strategies are:"
+#: builtin/checkout.c:1766
+msgid "create and switch to a new branch"
 msgstr ""
 
-#: builtin/merge.c:153
-#, c-format
-msgid "Available custom strategies are:"
+#: builtin/checkout.c:1768
+msgid "create/reset and switch to a branch"
 msgstr ""
 
-#: builtin/merge.c:203 builtin/pull.c:142
-msgid "do not show a diffstat at the end of the merge"
+#: builtin/checkout.c:1770
+msgid "second guess 'git switch <no-such-branch>'"
 msgstr ""
 
-#: builtin/merge.c:206 builtin/pull.c:145
-msgid "show a diffstat at the end of the merge"
+#: builtin/checkout.c:1772
+msgid "throw away local modifications"
 msgstr ""
 
-#: builtin/merge.c:207 builtin/pull.c:148
-msgid "(synonym to --stat)"
+#: builtin/checkout.c:1804
+msgid "which tree-ish to checkout from"
 msgstr ""
 
-#: builtin/merge.c:209 builtin/pull.c:151
-msgid "add (at most <n>) entries from shortlog to merge commit message"
+#: builtin/checkout.c:1806
+msgid "restore the index"
 msgstr ""
 
-#: builtin/merge.c:212 builtin/pull.c:157
-msgid "create a single commit instead of doing a merge"
+#: builtin/checkout.c:1808
+msgid "restore the working tree (default)"
 msgstr ""
 
-#: builtin/merge.c:214 builtin/pull.c:160
-msgid "perform a commit if the merge succeeds (default)"
+#: builtin/checkout.c:1810
+msgid "ignore unmerged entries"
 msgstr ""
 
-#: builtin/merge.c:216 builtin/pull.c:163
-msgid "edit message before committing"
+#: builtin/checkout.c:1811
+msgid "use overlay mode"
 msgstr ""
 
-#: builtin/merge.c:217
-msgid "allow fast-forward (default)"
+#: builtin/clean.c:28
+msgid ""
+"git clean [-d] [-f] [-i] [-n] [-q] [-e <pattern>] [-x | -X] [--] <paths>..."
 msgstr ""
 
-#: builtin/merge.c:219 builtin/pull.c:169
-msgid "abort if fast-forward is not possible"
+#: builtin/clean.c:32
+#, c-format
+msgid "Removing %s\n"
 msgstr ""
 
-#: builtin/merge.c:223 builtin/pull.c:172
-msgid "verify that the named commit has a valid GPG signature"
+#: builtin/clean.c:33
+#, c-format
+msgid "Would remove %s\n"
 msgstr ""
 
-#: builtin/merge.c:224 builtin/notes.c:777 builtin/pull.c:176
-#: builtin/revert.c:109
-msgid "strategy"
+#: builtin/clean.c:34
+#, c-format
+msgid "Skipping repository %s\n"
 msgstr ""
 
-#: builtin/merge.c:225 builtin/pull.c:177
-msgid "merge strategy to use"
+#: builtin/clean.c:35
+#, c-format
+msgid "Would skip repository %s\n"
 msgstr ""
 
-#: builtin/merge.c:226 builtin/pull.c:180
-msgid "option=value"
+#: builtin/clean.c:36
+#, c-format
+msgid "failed to remove %s"
 msgstr ""
 
-#: builtin/merge.c:227 builtin/pull.c:181
-msgid "option for selected merge strategy"
+#: builtin/clean.c:37
+#, c-format
+msgid "could not lstat %s\n"
 msgstr ""
 
-#: builtin/merge.c:229
-msgid "merge commit message (for a non-fast-forward merge)"
+#: builtin/clean.c:301 git-add--interactive.perl:595
+#, c-format
+msgid ""
+"Prompt help:\n"
+"1          - select a numbered item\n"
+"foo        - select item based on unique prefix\n"
+"           - (empty) select nothing\n"
 msgstr ""
 
-#: builtin/merge.c:233
-msgid "abort the current in-progress merge"
+#: builtin/clean.c:305 git-add--interactive.perl:604
+#, c-format
+msgid ""
+"Prompt help:\n"
+"1          - select a single item\n"
+"3-5        - select a range of items\n"
+"2-3,6-9    - select multiple ranges\n"
+"foo        - select item based on unique prefix\n"
+"-...       - unselect specified items\n"
+"*          - choose all items\n"
+"           - (empty) finish selecting\n"
 msgstr ""
 
-#: builtin/merge.c:235
-msgid "continue the current in-progress merge"
+#: builtin/clean.c:521 git-add--interactive.perl:570
+#: git-add--interactive.perl:575
+#, c-format, perl-format
+msgid "Huh (%s)?\n"
 msgstr ""
 
-#: builtin/merge.c:237 builtin/pull.c:188
-msgid "allow merging unrelated histories"
+#: builtin/clean.c:663
+#, c-format
+msgid "Input ignore patterns>> "
 msgstr ""
 
-#: builtin/merge.c:243
-msgid "verify commit-msg hook"
+#: builtin/clean.c:700
+#, c-format
+msgid "WARNING: Cannot find items matched by: %s"
 msgstr ""
 
-#: builtin/merge.c:268
-msgid "could not run stash."
+#: builtin/clean.c:721
+msgid "Select items to delete"
 msgstr ""
 
-#: builtin/merge.c:273
-msgid "stash failed"
+#. TRANSLATORS: Make sure to keep [y/N] as is
+#: builtin/clean.c:762
+#, c-format
+msgid "Remove %s [y/N]? "
 msgstr ""
 
-#: builtin/merge.c:278
-#, c-format
-msgid "not a valid object: %s"
+#: builtin/clean.c:795
+msgid ""
+"clean               - start cleaning\n"
+"filter by pattern   - exclude items from deletion\n"
+"select by numbers   - select items to be deleted by numbers\n"
+"ask each            - confirm each deletion (like \"rm -i\")\n"
+"quit                - stop cleaning\n"
+"help                - this screen\n"
+"?                   - help for prompt selection"
 msgstr ""
 
-#: builtin/merge.c:300 builtin/merge.c:317
-msgid "read-tree failed"
+#: builtin/clean.c:831
+msgid "Would remove the following item:"
+msgid_plural "Would remove the following items:"
+msgstr[0] ""
+msgstr[1] ""
+
+#: builtin/clean.c:847
+msgid "No more files to clean, exiting."
 msgstr ""
 
-#: builtin/merge.c:347
-msgid " (nothing to squash)"
+#: builtin/clean.c:909
+msgid "do not print names of files removed"
 msgstr ""
 
-#: builtin/merge.c:358
-#, c-format
-msgid "Squash commit -- not updating HEAD\n"
+#: builtin/clean.c:911
+msgid "force"
 msgstr ""
 
-#: builtin/merge.c:408
-#, c-format
-msgid "No merge message -- not updating HEAD\n"
+#: builtin/clean.c:912
+msgid "interactive cleaning"
 msgstr ""
 
-#: builtin/merge.c:458
-#, c-format
-msgid "'%s' does not point to a commit"
+#: builtin/clean.c:914
+msgid "remove whole directories"
 msgstr ""
 
-#: builtin/merge.c:548
-#, c-format
-msgid "Bad branch.%s.mergeoptions string: %s"
+#: builtin/clean.c:915 builtin/describe.c:548 builtin/describe.c:550
+#: builtin/grep.c:901 builtin/log.c:177 builtin/log.c:179
+#: builtin/ls-files.c:557 builtin/name-rev.c:464 builtin/name-rev.c:466
+#: builtin/show-ref.c:179
+msgid "pattern"
 msgstr ""
 
-#: builtin/merge.c:669
-msgid "Not handling anything other than two heads merge."
+#: builtin/clean.c:916
+msgid "add <pattern> to ignore rules"
 msgstr ""
 
-#: builtin/merge.c:683
-#, c-format
-msgid "Unknown option for merge-recursive: -X%s"
+#: builtin/clean.c:917
+msgid "remove ignored files, too"
 msgstr ""
 
-#: builtin/merge.c:698
-#, c-format
-msgid "unable to write %s"
+#: builtin/clean.c:919
+msgid "remove only ignored files"
 msgstr ""
 
-#: builtin/merge.c:749
-#, c-format
-msgid "Could not read from '%s'"
+#: builtin/clean.c:937
+msgid "-x and -X cannot be used together"
 msgstr ""
 
-#: builtin/merge.c:758
-#, c-format
-msgid "Not committing merge; use 'git commit' to complete the merge.\n"
+#: builtin/clean.c:941
+msgid ""
+"clean.requireForce set to true and neither -i, -n, nor -f given; refusing to "
+"clean"
 msgstr ""
 
-#: builtin/merge.c:764
-#, c-format
+#: builtin/clean.c:944
 msgid ""
-"Please enter a commit message to explain why this merge is necessary,\n"
-"especially if it merges an updated upstream into a topic branch.\n"
-"\n"
-"Lines starting with '%c' will be ignored, and an empty message aborts\n"
-"the commit.\n"
+"clean.requireForce defaults to true and neither -i, -n, nor -f given; "
+"refusing to clean"
 msgstr ""
 
-#: builtin/merge.c:800
-msgid "Empty commit message."
+#: builtin/clone.c:45
+msgid "git clone [<options>] [--] <repo> [<dir>]"
 msgstr ""
 
-#: builtin/merge.c:819
-#, c-format
-msgid "Wonderful.\n"
+#: builtin/clone.c:93
+msgid "don't create a checkout"
 msgstr ""
 
-#: builtin/merge.c:872
-#, c-format
-msgid "Automatic merge failed; fix conflicts and then commit the result.\n"
+#: builtin/clone.c:94 builtin/clone.c:96 builtin/init-db.c:489
+msgid "create a bare repository"
 msgstr ""
 
-#: builtin/merge.c:911
-msgid "No current branch."
+#: builtin/clone.c:98
+msgid "create a mirror repository (implies bare)"
 msgstr ""
 
-#: builtin/merge.c:913
-msgid "No remote for the current branch."
+#: builtin/clone.c:100
+msgid "to clone from a local repository"
 msgstr ""
 
-#: builtin/merge.c:915
-msgid "No default upstream defined for the current branch."
+#: builtin/clone.c:102
+msgid "don't use local hardlinks, always copy"
 msgstr ""
 
-#: builtin/merge.c:920
-#, c-format
-msgid "No remote-tracking branch for %s from %s"
+#: builtin/clone.c:104
+msgid "setup as shared repository"
 msgstr ""
 
-#: builtin/merge.c:973
-#, c-format
-msgid "Bad value '%s' in environment '%s'"
+#: builtin/clone.c:107
+msgid "pathspec"
 msgstr ""
 
-#: builtin/merge.c:1075
-#, c-format
-msgid "not something we can merge in %s: %s"
+#: builtin/clone.c:107
+msgid "initialize submodules in the clone"
 msgstr ""
 
-#: builtin/merge.c:1109
-msgid "not something we can merge"
+#: builtin/clone.c:110
+msgid "number of submodules cloned in parallel"
 msgstr ""
 
-#: builtin/merge.c:1211
-msgid "--abort expects no arguments"
+#: builtin/clone.c:111 builtin/init-db.c:486
+msgid "template-directory"
 msgstr ""
 
-#: builtin/merge.c:1215
-msgid "There is no merge to abort (MERGE_HEAD missing)."
+#: builtin/clone.c:112 builtin/init-db.c:487
+msgid "directory from which templates will be used"
 msgstr ""
 
-#: builtin/merge.c:1227
-msgid "--continue expects no arguments"
+#: builtin/clone.c:114 builtin/clone.c:116 builtin/submodule--helper.c:1392
+#: builtin/submodule--helper.c:1885
+msgid "reference repository"
 msgstr ""
 
-#: builtin/merge.c:1231
-msgid "There is no merge in progress (MERGE_HEAD missing)."
+#: builtin/clone.c:118 builtin/submodule--helper.c:1394
+#: builtin/submodule--helper.c:1887
+msgid "use --reference only while cloning"
 msgstr ""
 
-#: builtin/merge.c:1247
-msgid ""
-"You have not concluded your merge (MERGE_HEAD exists).\n"
-"Please, commit your changes before you merge."
+#: builtin/clone.c:119 builtin/column.c:27 builtin/merge-file.c:46
+#: builtin/pack-objects.c:3294 builtin/repack.c:327
+msgid "name"
 msgstr ""
 
-#: builtin/merge.c:1254
-msgid ""
-"You have not concluded your cherry-pick (CHERRY_PICK_HEAD exists).\n"
-"Please, commit your changes before you merge."
+#: builtin/clone.c:120
+msgid "use <name> instead of 'origin' to track upstream"
 msgstr ""
 
-#: builtin/merge.c:1257
-msgid "You have not concluded your cherry-pick (CHERRY_PICK_HEAD exists)."
+#: builtin/clone.c:122
+msgid "checkout <branch> instead of the remote's HEAD"
 msgstr ""
 
-#: builtin/merge.c:1266
-msgid "You cannot combine --squash with --no-ff."
+#: builtin/clone.c:124
+msgid "path to git-upload-pack on the remote"
 msgstr ""
 
-#: builtin/merge.c:1274
-msgid "No commit specified and merge.defaultToUpstream not set."
+#: builtin/clone.c:125 builtin/fetch.c:168 builtin/grep.c:840
+#: builtin/pull.c:227
+msgid "depth"
 msgstr ""
 
-#: builtin/merge.c:1291
-msgid "Squash commit into empty head not supported yet"
+#: builtin/clone.c:126
+msgid "create a shallow clone of that depth"
 msgstr ""
 
-#: builtin/merge.c:1293
-msgid "Non-fast-forward commit does not make sense into an empty head"
+#: builtin/clone.c:127 builtin/fetch.c:170 builtin/pack-objects.c:3283
+msgid "time"
 msgstr ""
 
-#: builtin/merge.c:1298
-#, c-format
-msgid "%s - not something we can merge"
+#: builtin/clone.c:128
+msgid "create a shallow clone since a specific time"
 msgstr ""
 
-#: builtin/merge.c:1300
-msgid "Can merge only exactly one commit into empty head"
+#: builtin/clone.c:129 builtin/fetch.c:172 builtin/fetch.c:195
+#: builtin/rebase.c:1445
+msgid "revision"
 msgstr ""
 
-#: builtin/merge.c:1334
-#, c-format
-msgid "Commit %s has an untrusted GPG signature, allegedly by %s."
+#: builtin/clone.c:130 builtin/fetch.c:173
+msgid "deepen history of shallow clone, excluding rev"
 msgstr ""
 
-#: builtin/merge.c:1337
-#, c-format
-msgid "Commit %s has a bad GPG signature allegedly by %s."
+#: builtin/clone.c:132
+msgid "clone only one branch, HEAD or --branch"
 msgstr ""
 
-#: builtin/merge.c:1340
-#, c-format
-msgid "Commit %s does not have a GPG signature."
+#: builtin/clone.c:134
+msgid "don't clone any tags, and make later fetches not to follow them"
 msgstr ""
 
-#: builtin/merge.c:1343
-#, c-format
-msgid "Commit %s has a good GPG signature by %s\n"
+#: builtin/clone.c:136
+msgid "any cloned submodules will be shallow"
 msgstr ""
 
-#: builtin/merge.c:1402
-msgid "refusing to merge unrelated histories"
+#: builtin/clone.c:137 builtin/init-db.c:495
+msgid "gitdir"
 msgstr ""
 
-#: builtin/merge.c:1411
-msgid "Already up to date."
+#: builtin/clone.c:138 builtin/init-db.c:496
+msgid "separate git dir from working tree"
 msgstr ""
 
-#: builtin/merge.c:1421
-#, c-format
-msgid "Updating %s..%s\n"
+#: builtin/clone.c:139
+msgid "key=value"
 msgstr ""
 
-#: builtin/merge.c:1462
-#, c-format
-msgid "Trying really trivial in-index merge...\n"
+#: builtin/clone.c:140
+msgid "set config inside the new repository"
 msgstr ""
 
-#: builtin/merge.c:1469
-#, c-format
-msgid "Nope.\n"
+#: builtin/clone.c:142 builtin/fetch.c:190 builtin/ls-remote.c:76
+#: builtin/push.c:573 builtin/send-pack.c:172
+msgid "server-specific"
 msgstr ""
 
-#: builtin/merge.c:1494
-msgid "Already up to date. Yeeah!"
+#: builtin/clone.c:142 builtin/fetch.c:190 builtin/ls-remote.c:76
+#: builtin/push.c:573 builtin/send-pack.c:173
+msgid "option to transmit"
 msgstr ""
 
-#: builtin/merge.c:1500
-msgid "Not possible to fast-forward, aborting."
+#: builtin/clone.c:143 builtin/fetch.c:191 builtin/pull.c:240
+#: builtin/push.c:574
+msgid "use IPv4 addresses only"
 msgstr ""
 
-#: builtin/merge.c:1523 builtin/merge.c:1602
-#, c-format
-msgid "Rewinding the tree to pristine...\n"
+#: builtin/clone.c:145 builtin/fetch.c:193 builtin/pull.c:243
+#: builtin/push.c:576
+msgid "use IPv6 addresses only"
 msgstr ""
 
-#: builtin/merge.c:1527
-#, c-format
-msgid "Trying merge strategy %s...\n"
+#: builtin/clone.c:149
+msgid "any cloned submodules will use their remote-tracking branch"
 msgstr ""
 
-#: builtin/merge.c:1593
-#, c-format
-msgid "No merge strategy handled the merge.\n"
+#: builtin/clone.c:151
+msgid "initialize sparse-checkout file to include only files at root"
 msgstr ""
 
-#: builtin/merge.c:1595
-#, c-format
-msgid "Merge with strategy %s failed.\n"
+#: builtin/clone.c:287
+msgid ""
+"No directory name could be guessed.\n"
+"Please specify a directory on the command line"
 msgstr ""
 
-#: builtin/merge.c:1604
+#: builtin/clone.c:340
 #, c-format
-msgid "Using the %s to prepare resolving by hand.\n"
+msgid "info: Could not add alternate for '%s': %s\n"
 msgstr ""
 
-#: builtin/merge.c:1616
+#: builtin/clone.c:413
 #, c-format
-msgid "Automatic merge went well; stopped before committing as requested\n"
+msgid "%s exists and is not a directory"
 msgstr ""
 
-#: builtin/merge-base.c:30
-msgid "git merge-base [-a | --all] <commit> <commit>..."
+#: builtin/clone.c:430
+#, c-format
+msgid "failed to start iterator over '%s'"
 msgstr ""
 
-#: builtin/merge-base.c:31
-msgid "git merge-base [-a | --all] --octopus <commit>..."
+#: builtin/clone.c:460
+#, c-format
+msgid "failed to create link '%s'"
 msgstr ""
 
-#: builtin/merge-base.c:32
-msgid "git merge-base --independent <commit>..."
+#: builtin/clone.c:464
+#, c-format
+msgid "failed to copy file to '%s'"
 msgstr ""
 
-#: builtin/merge-base.c:33
-msgid "git merge-base --is-ancestor <commit> <commit>"
+#: builtin/clone.c:469
+#, c-format
+msgid "failed to iterate over '%s'"
 msgstr ""
 
-#: builtin/merge-base.c:34
-msgid "git merge-base --fork-point <ref> [<commit>]"
-msgstr ""
-
-#: builtin/merge-base.c:220
-msgid "output all common ancestors"
+#: builtin/clone.c:494
+#, c-format
+msgid "done.\n"
 msgstr ""
 
-#: builtin/merge-base.c:222
-msgid "find ancestors for a single n-way merge"
+#: builtin/clone.c:508
+msgid ""
+"Clone succeeded, but checkout failed.\n"
+"You can inspect what was checked out with 'git status'\n"
+"and retry with 'git restore --source=HEAD :/'\n"
 msgstr ""
 
-#: builtin/merge-base.c:224
-msgid "list revs not reachable from others"
+#: builtin/clone.c:585
+#, c-format
+msgid "Could not find remote branch %s to clone."
 msgstr ""
 
-#: builtin/merge-base.c:226
-msgid "is the first one ancestor of the other?"
+#: builtin/clone.c:704
+#, c-format
+msgid "unable to update %s"
 msgstr ""
 
-#: builtin/merge-base.c:228
-msgid "find where <commit> forked from reflog of <ref>"
+#: builtin/clone.c:752
+msgid "failed to initialize sparse-checkout"
 msgstr ""
 
-#: builtin/merge-file.c:9
-msgid ""
-"git merge-file [<options>] [-L <name1> [-L <orig> [-L <name2>]]] <file1> "
-"<orig-file> <file2>"
+#: builtin/clone.c:775
+msgid "remote HEAD refers to nonexistent ref, unable to checkout.\n"
 msgstr ""
 
-#: builtin/merge-file.c:33
-msgid "send results to standard output"
+#: builtin/clone.c:806
+msgid "unable to checkout working tree"
 msgstr ""
 
-#: builtin/merge-file.c:34
-msgid "use a diff3 based merge"
+#: builtin/clone.c:856
+msgid "unable to write parameters to config file"
 msgstr ""
 
-#: builtin/merge-file.c:35
-msgid "for conflicts, use our version"
+#: builtin/clone.c:919
+msgid "cannot repack to clean up"
 msgstr ""
 
-#: builtin/merge-file.c:37
-msgid "for conflicts, use their version"
+#: builtin/clone.c:921
+msgid "cannot unlink temporary alternates file"
 msgstr ""
 
-#: builtin/merge-file.c:39
-msgid "for conflicts, use a union version"
+#: builtin/clone.c:959 builtin/receive-pack.c:1948
+msgid "Too many arguments."
 msgstr ""
 
-#: builtin/merge-file.c:42
-msgid "for conflicts, use this marker size"
+#: builtin/clone.c:963
+msgid "You must specify a repository to clone."
 msgstr ""
 
-#: builtin/merge-file.c:43
-msgid "do not warn about conflicts"
+#: builtin/clone.c:976
+#, c-format
+msgid "--bare and --origin %s options are incompatible."
 msgstr ""
 
-#: builtin/merge-file.c:45
-msgid "set labels for file1/orig-file/file2"
+#: builtin/clone.c:979
+msgid "--bare and --separate-git-dir are incompatible."
 msgstr ""
 
-#: builtin/merge-recursive.c:45
+#: builtin/clone.c:992
 #, c-format
-msgid "unknown option %s"
+msgid "repository '%s' does not exist"
 msgstr ""
 
-#: builtin/merge-recursive.c:51
+#: builtin/clone.c:998 builtin/fetch.c:1787
 #, c-format
-msgid "could not parse object '%s'"
+msgid "depth %s is not a positive number"
 msgstr ""
 
-#: builtin/merge-recursive.c:55
+#: builtin/clone.c:1008
 #, c-format
-msgid "cannot handle more than %d base. Ignoring %s."
-msgid_plural "cannot handle more than %d bases. Ignoring %s."
-msgstr[0] ""
-msgstr[1] ""
-
-#: builtin/merge-recursive.c:63
-msgid "not handling anything other than two heads merge."
+msgid "destination path '%s' already exists and is not an empty directory."
 msgstr ""
 
-#: builtin/merge-recursive.c:69 builtin/merge-recursive.c:71
+#: builtin/clone.c:1018
 #, c-format
-msgid "could not resolve ref '%s'"
+msgid "working tree '%s' already exists."
 msgstr ""
 
-#: builtin/merge-recursive.c:77
+#: builtin/clone.c:1033 builtin/clone.c:1054 builtin/difftool.c:271
+#: builtin/log.c:1866 builtin/worktree.c:302 builtin/worktree.c:334
 #, c-format
-msgid "Merging %s with %s\n"
-msgstr ""
-
-#: builtin/mktree.c:65
-msgid "git mktree [-z] [--missing] [--batch]"
+msgid "could not create leading directories of '%s'"
 msgstr ""
 
-#: builtin/mktree.c:153
-msgid "input is NUL terminated"
+#: builtin/clone.c:1038
+#, c-format
+msgid "could not create work tree dir '%s'"
 msgstr ""
 
-#: builtin/mktree.c:154 builtin/write-tree.c:25
-msgid "allow missing objects"
+#: builtin/clone.c:1058
+#, c-format
+msgid "Cloning into bare repository '%s'...\n"
 msgstr ""
 
-#: builtin/mktree.c:155
-msgid "allow creation of more than one tree"
+#: builtin/clone.c:1060
+#, c-format
+msgid "Cloning into '%s'...\n"
 msgstr ""
 
-#: builtin/mv.c:17
-msgid "git mv [<options>] <source>... <destination>"
+#: builtin/clone.c:1084
+msgid ""
+"clone --recursive is not compatible with both --reference and --reference-if-"
+"able"
 msgstr ""
 
-#: builtin/mv.c:82
-#, c-format
-msgid "Directory %s is in index and no submodule?"
+#: builtin/clone.c:1148
+msgid "--depth is ignored in local clones; use file:// instead."
 msgstr ""
 
-#: builtin/mv.c:84 builtin/rm.c:288
-msgid "Please stage your changes to .gitmodules or stash them to proceed"
+#: builtin/clone.c:1150
+msgid "--shallow-since is ignored in local clones; use file:// instead."
 msgstr ""
 
-#: builtin/mv.c:102
-#, c-format
-msgid "%.*s is in index"
+#: builtin/clone.c:1152
+msgid "--shallow-exclude is ignored in local clones; use file:// instead."
 msgstr ""
 
-#: builtin/mv.c:124
-msgid "force move/rename even if target exists"
+#: builtin/clone.c:1154
+msgid "--filter is ignored in local clones; use file:// instead."
 msgstr ""
 
-#: builtin/mv.c:126
-msgid "skip move/rename errors"
+#: builtin/clone.c:1157
+msgid "source repository is shallow, ignoring --local"
 msgstr ""
 
-#: builtin/mv.c:168
-#, c-format
-msgid "destination '%s' is not a directory"
+#: builtin/clone.c:1162
+msgid "--local is ignored"
 msgstr ""
 
-#: builtin/mv.c:179
+#: builtin/clone.c:1237 builtin/clone.c:1245
 #, c-format
-msgid "Checking rename of '%s' to '%s'\n"
+msgid "Remote branch %s not found in upstream %s"
 msgstr ""
 
-#: builtin/mv.c:183
-msgid "bad source"
+#: builtin/clone.c:1248
+msgid "You appear to have cloned an empty repository."
 msgstr ""
 
-#: builtin/mv.c:186
-msgid "can not move directory into itself"
+#: builtin/column.c:10
+msgid "git column [<options>]"
 msgstr ""
 
-#: builtin/mv.c:189
-msgid "cannot move directory over file"
+#: builtin/column.c:27
+msgid "lookup config vars"
 msgstr ""
 
-#: builtin/mv.c:198
-msgid "source directory is empty"
+#: builtin/column.c:28 builtin/column.c:29
+msgid "layout to use"
 msgstr ""
 
-#: builtin/mv.c:223
-msgid "not under version control"
+#: builtin/column.c:30
+msgid "Maximum width"
 msgstr ""
 
-#: builtin/mv.c:226
-msgid "destination exists"
+#: builtin/column.c:31
+msgid "Padding space on left border"
 msgstr ""
 
-#: builtin/mv.c:234
-#, c-format
-msgid "overwriting '%s'"
+#: builtin/column.c:32
+msgid "Padding space on right border"
 msgstr ""
 
-#: builtin/mv.c:237
-msgid "Cannot overwrite"
+#: builtin/column.c:33
+msgid "Padding space between columns"
 msgstr ""
 
-#: builtin/mv.c:240
-msgid "multiple sources for the same target"
+#: builtin/column.c:51
+msgid "--command must be the first argument"
 msgstr ""
 
-#: builtin/mv.c:242
-msgid "destination directory does not exist"
+#: builtin/commit-tree.c:18
+msgid ""
+"git commit-tree [(-p <parent>)...] [-S[<keyid>]] [(-m <message>)...] [(-F "
+"<file>)...] <tree>"
 msgstr ""
 
-#: builtin/mv.c:249
+#: builtin/commit-tree.c:31
 #, c-format
-msgid "%s, source=%s, destination=%s"
+msgid "duplicate parent %s ignored"
 msgstr ""
 
-#: builtin/mv.c:270
+#: builtin/commit-tree.c:56 builtin/commit-tree.c:136 builtin/log.c:526
 #, c-format
-msgid "Renaming %s to %s\n"
+msgid "not a valid object name %s"
 msgstr ""
 
-#: builtin/mv.c:276 builtin/remote.c:715 builtin/repack.c:409
+#: builtin/commit-tree.c:93
 #, c-format
-msgid "renaming '%s' failed"
+msgid "git commit-tree: failed to open '%s'"
 msgstr ""
 
-#: builtin/name-rev.c:338
-msgid "git name-rev [<options>] <commit>..."
+#: builtin/commit-tree.c:96
+#, c-format
+msgid "git commit-tree: failed to read '%s'"
 msgstr ""
 
-#: builtin/name-rev.c:339
-msgid "git name-rev [<options>] --all"
+#: builtin/commit-tree.c:98
+#, c-format
+msgid "git commit-tree: failed to close '%s'"
 msgstr ""
 
-#: builtin/name-rev.c:340
-msgid "git name-rev [<options>] --stdin"
+#: builtin/commit-tree.c:111
+msgid "parent"
 msgstr ""
 
-#: builtin/name-rev.c:395
-msgid "print only names (no SHA-1)"
+#: builtin/commit-tree.c:112
+msgid "id of a parent commit object"
 msgstr ""
 
-#: builtin/name-rev.c:396
-msgid "only use tags to name the commits"
+#: builtin/commit-tree.c:114 builtin/commit.c:1496 builtin/merge.c:270
+#: builtin/notes.c:409 builtin/notes.c:575 builtin/stash.c:1469
+#: builtin/tag.c:412
+msgid "message"
 msgstr ""
 
-#: builtin/name-rev.c:398
-msgid "only use refs matching <pattern>"
+#: builtin/commit-tree.c:115 builtin/commit.c:1496
+msgid "commit message"
 msgstr ""
 
-#: builtin/name-rev.c:400
-msgid "ignore refs matching <pattern>"
+#: builtin/commit-tree.c:118
+msgid "read commit log message from file"
 msgstr ""
 
-#: builtin/name-rev.c:402
-msgid "list all commits reachable from all refs"
+#: builtin/commit-tree.c:121 builtin/commit.c:1508 builtin/merge.c:287
+#: builtin/pull.c:195 builtin/revert.c:118
+msgid "GPG sign commit"
 msgstr ""
 
-#: builtin/name-rev.c:403
-msgid "read from stdin"
+#: builtin/commit-tree.c:133
+msgid "must give exactly one tree"
 msgstr ""
 
-#: builtin/name-rev.c:404
-msgid "allow to print `undefined` names (default)"
+#: builtin/commit-tree.c:140
+msgid "git commit-tree: failed to read"
 msgstr ""
 
-#: builtin/name-rev.c:410
-msgid "dereference tags in the input (internal use)"
+#: builtin/commit.c:41
+msgid "git commit [<options>] [--] <pathspec>..."
 msgstr ""
 
-#: builtin/notes.c:26
-msgid "git notes [--ref <notes-ref>] [list [<object>]]"
+#: builtin/commit.c:46
+msgid "git status [<options>] [--] <pathspec>..."
 msgstr ""
 
-#: builtin/notes.c:27
+#: builtin/commit.c:51
 msgid ""
-"git notes [--ref <notes-ref>] add [-f] [--allow-empty] [-m <msg> | -F <file> "
-"| (-c | -C) <object>] [<object>]"
-msgstr ""
-
-#: builtin/notes.c:28
-msgid "git notes [--ref <notes-ref>] copy [-f] <from-object> <to-object>"
+"You asked to amend the most recent commit, but doing so would make\n"
+"it empty. You can repeat your command with --allow-empty, or you can\n"
+"remove the commit entirely with \"git reset HEAD^\".\n"
 msgstr ""
 
-#: builtin/notes.c:29
+#: builtin/commit.c:56
 msgid ""
-"git notes [--ref <notes-ref>] append [--allow-empty] [-m <msg> | -F <file> | "
-"(-c | -C) <object>] [<object>]"
-msgstr ""
-
-#: builtin/notes.c:30
-msgid "git notes [--ref <notes-ref>] edit [--allow-empty] [<object>]"
+"The previous cherry-pick is now empty, possibly due to conflict resolution.\n"
+"If you wish to commit it anyway, use:\n"
+"\n"
+"    git commit --allow-empty\n"
+"\n"
 msgstr ""
 
-#: builtin/notes.c:31
-msgid "git notes [--ref <notes-ref>] show [<object>]"
+#: builtin/commit.c:63
+msgid "Otherwise, please use 'git cherry-pick --skip'\n"
 msgstr ""
 
-#: builtin/notes.c:32
+#: builtin/commit.c:66
 msgid ""
-"git notes [--ref <notes-ref>] merge [-v | -q] [-s <strategy>] <notes-ref>"
+"and then use:\n"
+"\n"
+"    git cherry-pick --continue\n"
+"\n"
+"to resume cherry-picking the remaining commits.\n"
+"If you wish to skip this commit, use:\n"
+"\n"
+"    git cherry-pick --skip\n"
+"\n"
 msgstr ""
 
-#: builtin/notes.c:33
-msgid "git notes merge --commit [-v | -q]"
+#: builtin/commit.c:315
+msgid "failed to unpack HEAD tree object"
 msgstr ""
 
-#: builtin/notes.c:34
-msgid "git notes merge --abort [-v | -q]"
+#: builtin/commit.c:351
+msgid "--pathspec-from-file with -a does not make sense"
 msgstr ""
 
-#: builtin/notes.c:35
-msgid "git notes [--ref <notes-ref>] remove [<object>...]"
+#: builtin/commit.c:364
+msgid "No paths with --include/--only does not make sense."
 msgstr ""
 
-#: builtin/notes.c:36
-msgid "git notes [--ref <notes-ref>] prune [-n] [-v]"
+#: builtin/commit.c:376
+msgid "unable to create temporary index"
 msgstr ""
 
-#: builtin/notes.c:37
-msgid "git notes [--ref <notes-ref>] get-ref"
+#: builtin/commit.c:382
+msgid "interactive add failed"
 msgstr ""
 
-#: builtin/notes.c:42
-msgid "git notes [list [<object>]]"
+#: builtin/commit.c:396
+msgid "unable to update temporary index"
 msgstr ""
 
-#: builtin/notes.c:47
-msgid "git notes add [<options>] [<object>]"
+#: builtin/commit.c:398
+msgid "Failed to update main cache tree"
 msgstr ""
 
-#: builtin/notes.c:52
-msgid "git notes copy [<options>] <from-object> <to-object>"
+#: builtin/commit.c:423 builtin/commit.c:446 builtin/commit.c:492
+msgid "unable to write new_index file"
 msgstr ""
 
-#: builtin/notes.c:53
-msgid "git notes copy --stdin [<from-object> <to-object>]..."
+#: builtin/commit.c:475
+msgid "cannot do a partial commit during a merge."
 msgstr ""
 
-#: builtin/notes.c:58
-msgid "git notes append [<options>] [<object>]"
+#: builtin/commit.c:477
+msgid "cannot do a partial commit during a cherry-pick."
 msgstr ""
 
-#: builtin/notes.c:63
-msgid "git notes edit [<object>]"
+#: builtin/commit.c:485
+msgid "cannot read the index"
 msgstr ""
 
-#: builtin/notes.c:68
-msgid "git notes show [<object>]"
+#: builtin/commit.c:504
+msgid "unable to write temporary index file"
 msgstr ""
 
-#: builtin/notes.c:73
-msgid "git notes merge [<options>] <notes-ref>"
+#: builtin/commit.c:602
+#, c-format
+msgid "commit '%s' lacks author header"
 msgstr ""
 
-#: builtin/notes.c:74
-msgid "git notes merge --commit [<options>]"
+#: builtin/commit.c:604
+#, c-format
+msgid "commit '%s' has malformed author line"
 msgstr ""
 
-#: builtin/notes.c:75
-msgid "git notes merge --abort [<options>]"
+#: builtin/commit.c:623
+msgid "malformed --author parameter"
 msgstr ""
 
-#: builtin/notes.c:80
-msgid "git notes remove [<object>]"
+#: builtin/commit.c:676
+msgid ""
+"unable to select a comment character that is not used\n"
+"in the current commit message"
 msgstr ""
 
-#: builtin/notes.c:85
-msgid "git notes prune [<options>]"
+#: builtin/commit.c:714 builtin/commit.c:747 builtin/commit.c:1092
+#, c-format
+msgid "could not lookup commit %s"
 msgstr ""
 
-#: builtin/notes.c:90
-msgid "git notes get-ref"
+#: builtin/commit.c:726 builtin/shortlog.c:319
+#, c-format
+msgid "(reading log message from standard input)\n"
 msgstr ""
 
-#: builtin/notes.c:95
-msgid "Write/edit the notes for the following object:"
+#: builtin/commit.c:728
+msgid "could not read log from standard input"
 msgstr ""
 
-#: builtin/notes.c:148
+#: builtin/commit.c:732
 #, c-format
-msgid "unable to start 'show' for object '%s'"
+msgid "could not read log file '%s'"
 msgstr ""
 
-#: builtin/notes.c:152
-msgid "could not read 'show' output"
+#: builtin/commit.c:763 builtin/commit.c:779
+msgid "could not read SQUASH_MSG"
 msgstr ""
 
-#: builtin/notes.c:160
-#, c-format
-msgid "failed to finish 'show' for object '%s'"
+#: builtin/commit.c:770
+msgid "could not read MERGE_MSG"
 msgstr ""
 
-#: builtin/notes.c:195
-msgid "please supply the note contents using either -m or -F option"
+#: builtin/commit.c:830
+msgid "could not write commit template"
 msgstr ""
 
-#: builtin/notes.c:204
-msgid "unable to write note object"
+#: builtin/commit.c:849
+#, c-format
+msgid ""
+"\n"
+"It looks like you may be committing a merge.\n"
+"If this is not correct, please remove the file\n"
+"\t%s\n"
+"and try again.\n"
 msgstr ""
 
-#: builtin/notes.c:206
+#: builtin/commit.c:854
 #, c-format
-msgid "the note contents have been left in %s"
+msgid ""
+"\n"
+"It looks like you may be committing a cherry-pick.\n"
+"If this is not correct, please remove the file\n"
+"\t%s\n"
+"and try again.\n"
 msgstr ""
 
-#: builtin/notes.c:234 builtin/tag.c:507
+#: builtin/commit.c:867
 #, c-format
-msgid "cannot read '%s'"
+msgid ""
+"Please enter the commit message for your changes. Lines starting\n"
+"with '%c' will be ignored, and an empty message aborts the commit.\n"
 msgstr ""
 
-#: builtin/notes.c:236 builtin/tag.c:510
+#: builtin/commit.c:875
 #, c-format
-msgid "could not open or read '%s'"
+msgid ""
+"Please enter the commit message for your changes. Lines starting\n"
+"with '%c' will be kept; you may remove them yourself if you want to.\n"
+"An empty message aborts the commit.\n"
 msgstr ""
 
-#: builtin/notes.c:255 builtin/notes.c:306 builtin/notes.c:308
-#: builtin/notes.c:376 builtin/notes.c:431 builtin/notes.c:517
-#: builtin/notes.c:522 builtin/notes.c:600 builtin/notes.c:662
+#: builtin/commit.c:892
 #, c-format
-msgid "failed to resolve '%s' as a valid ref."
+msgid "%sAuthor:    %.*s <%.*s>"
 msgstr ""
 
-#: builtin/notes.c:258
+#: builtin/commit.c:900
 #, c-format
-msgid "failed to read object '%s'."
+msgid "%sDate:      %s"
 msgstr ""
 
-#: builtin/notes.c:262
+#: builtin/commit.c:907
 #, c-format
-msgid "cannot read note data from non-blob object '%s'."
+msgid "%sCommitter: %.*s <%.*s>"
 msgstr ""
 
-#: builtin/notes.c:302
-#, c-format
-msgid "malformed input line: '%s'."
+#: builtin/commit.c:925
+msgid "Cannot read index"
 msgstr ""
 
-#: builtin/notes.c:317
-#, c-format
-msgid "failed to copy notes from '%s' to '%s'"
+#: builtin/commit.c:992
+msgid "Error building trees"
 msgstr ""
 
-#. TRANSLATORS: the first %s will be replaced by a git
-#. notes command: 'add', 'merge', 'remove', etc.
-#.
-#: builtin/notes.c:349
+#: builtin/commit.c:1006 builtin/tag.c:275
 #, c-format
-msgid "refusing to %s notes in %s (outside of refs/notes/)"
-msgstr ""
-
-#: builtin/notes.c:369 builtin/notes.c:424 builtin/notes.c:500
-#: builtin/notes.c:512 builtin/notes.c:588 builtin/notes.c:655
-#: builtin/notes.c:805 builtin/notes.c:952 builtin/notes.c:973
-msgid "too many parameters"
+msgid "Please supply the message using either -m or -F option.\n"
 msgstr ""
 
-#: builtin/notes.c:382 builtin/notes.c:668
+#: builtin/commit.c:1050
 #, c-format
-msgid "no note found for object %s."
+msgid "--author '%s' is not 'Name <email>' and matches no existing author"
 msgstr ""
 
-#: builtin/notes.c:403 builtin/notes.c:566
-msgid "note contents as a string"
+#: builtin/commit.c:1064
+#, c-format
+msgid "Invalid ignored mode '%s'"
 msgstr ""
 
-#: builtin/notes.c:406 builtin/notes.c:569
-msgid "note contents in a file"
+#: builtin/commit.c:1082 builtin/commit.c:1322
+#, c-format
+msgid "Invalid untracked files mode '%s'"
 msgstr ""
 
-#: builtin/notes.c:409 builtin/notes.c:572
-msgid "reuse and edit specified note object"
+#: builtin/commit.c:1122
+msgid "--long and -z are incompatible"
 msgstr ""
 
-#: builtin/notes.c:412 builtin/notes.c:575
-msgid "reuse specified note object"
+#: builtin/commit.c:1166
+msgid "Using both --reset-author and --author does not make sense"
 msgstr ""
 
-#: builtin/notes.c:415 builtin/notes.c:578
-msgid "allow storing empty note"
+#: builtin/commit.c:1175
+msgid "You have nothing to amend."
 msgstr ""
 
-#: builtin/notes.c:416 builtin/notes.c:487
-msgid "replace existing notes"
+#: builtin/commit.c:1178
+msgid "You are in the middle of a merge -- cannot amend."
 msgstr ""
 
-#: builtin/notes.c:441
-#, c-format
-msgid ""
-"Cannot add notes. Found existing notes for object %s. Use '-f' to overwrite "
-"existing notes"
+#: builtin/commit.c:1180
+msgid "You are in the middle of a cherry-pick -- cannot amend."
 msgstr ""
 
-#: builtin/notes.c:456 builtin/notes.c:535
-#, c-format
-msgid "Overwriting existing notes for object %s\n"
+#: builtin/commit.c:1183
+msgid "Options --squash and --fixup cannot be used together"
 msgstr ""
 
-#: builtin/notes.c:467 builtin/notes.c:627 builtin/notes.c:892
-#, c-format
-msgid "Removing note for object %s\n"
+#: builtin/commit.c:1193
+msgid "Only one of -c/-C/-F/--fixup can be used."
 msgstr ""
 
-#: builtin/notes.c:488
-msgid "read objects from stdin"
+#: builtin/commit.c:1195
+msgid "Option -m cannot be combined with -c/-C/-F."
 msgstr ""
 
-#: builtin/notes.c:490
-msgid "load rewriting config for <command> (implies --stdin)"
+#: builtin/commit.c:1203
+msgid "--reset-author can be used only with -C, -c or --amend."
 msgstr ""
 
-#: builtin/notes.c:508
-msgid "too few parameters"
+#: builtin/commit.c:1220
+msgid "Only one of --include/--only/--all/--interactive/--patch can be used."
 msgstr ""
 
-#: builtin/notes.c:529
+#: builtin/commit.c:1226
 #, c-format
-msgid ""
-"Cannot copy notes. Found existing notes for object %s. Use '-f' to overwrite "
-"existing notes"
+msgid "paths '%s ...' with -a does not make sense"
 msgstr ""
 
-#: builtin/notes.c:541
-#, c-format
-msgid "missing notes on source object %s. Cannot copy."
+#: builtin/commit.c:1357 builtin/commit.c:1519
+msgid "show status concisely"
 msgstr ""
 
-#: builtin/notes.c:593
-#, c-format
-msgid ""
-"The -m/-F/-c/-C options have been deprecated for the 'edit' subcommand.\n"
-"Please use 'git notes add -f -m/-F/-c/-C' instead.\n"
+#: builtin/commit.c:1359 builtin/commit.c:1521
+msgid "show branch information"
 msgstr ""
 
-#: builtin/notes.c:688
-msgid "failed to delete ref NOTES_MERGE_PARTIAL"
+#: builtin/commit.c:1361
+msgid "show stash information"
 msgstr ""
 
-#: builtin/notes.c:690
-msgid "failed to delete ref NOTES_MERGE_REF"
+#: builtin/commit.c:1363 builtin/commit.c:1523
+msgid "compute full ahead/behind values"
 msgstr ""
 
-#: builtin/notes.c:692
-msgid "failed to remove 'git notes merge' worktree"
+#: builtin/commit.c:1365
+msgid "version"
 msgstr ""
 
-#: builtin/notes.c:712
-msgid "failed to read ref NOTES_MERGE_PARTIAL"
+#: builtin/commit.c:1365 builtin/commit.c:1525 builtin/push.c:549
+#: builtin/worktree.c:650
+msgid "machine-readable output"
 msgstr ""
 
-#: builtin/notes.c:714
-msgid "could not find commit from NOTES_MERGE_PARTIAL."
+#: builtin/commit.c:1368 builtin/commit.c:1527
+msgid "show status in long format (default)"
 msgstr ""
 
-#: builtin/notes.c:716
-msgid "could not parse commit from NOTES_MERGE_PARTIAL."
+#: builtin/commit.c:1371 builtin/commit.c:1530
+msgid "terminate entries with NUL"
 msgstr ""
 
-#: builtin/notes.c:729
-msgid "failed to resolve NOTES_MERGE_REF"
+#: builtin/commit.c:1373 builtin/commit.c:1377 builtin/commit.c:1533
+#: builtin/fast-export.c:1153 builtin/fast-export.c:1156
+#: builtin/fast-export.c:1159 builtin/rebase.c:1525 parse-options.h:336
+msgid "mode"
 msgstr ""
 
-#: builtin/notes.c:732
-msgid "failed to finalize notes merge"
+#: builtin/commit.c:1374 builtin/commit.c:1533
+msgid "show untracked files, optional modes: all, normal, no. (Default: all)"
 msgstr ""
 
-#: builtin/notes.c:758
-#, c-format
-msgid "unknown notes merge strategy %s"
+#: builtin/commit.c:1378
+msgid ""
+"show ignored files, optional modes: traditional, matching, no. (Default: "
+"traditional)"
 msgstr ""
 
-#: builtin/notes.c:774
-msgid "General options"
+#: builtin/commit.c:1380 parse-options.h:192
+msgid "when"
 msgstr ""
 
-#: builtin/notes.c:776
-msgid "Merge options"
+#: builtin/commit.c:1381
+msgid ""
+"ignore changes to submodules, optional when: all, dirty, untracked. "
+"(Default: all)"
 msgstr ""
 
-#: builtin/notes.c:778
-msgid ""
-"resolve notes conflicts using the given strategy (manual/ours/theirs/union/"
-"cat_sort_uniq)"
+#: builtin/commit.c:1383
+msgid "list untracked files in columns"
 msgstr ""
 
-#: builtin/notes.c:780
-msgid "Committing unmerged notes"
+#: builtin/commit.c:1384
+msgid "do not detect renames"
 msgstr ""
 
-#: builtin/notes.c:782
-msgid "finalize notes merge by committing unmerged notes"
+#: builtin/commit.c:1386
+msgid "detect renames, optionally set similarity index"
 msgstr ""
 
-#: builtin/notes.c:784
-msgid "Aborting notes merge resolution"
+#: builtin/commit.c:1406
+msgid "Unsupported combination of ignored and untracked-files arguments"
 msgstr ""
 
-#: builtin/notes.c:786
-msgid "abort notes merge"
+#: builtin/commit.c:1489
+msgid "suppress summary after successful commit"
 msgstr ""
 
-#: builtin/notes.c:797
-msgid "cannot mix --commit, --abort or -s/--strategy"
+#: builtin/commit.c:1490
+msgid "show diff in commit message template"
 msgstr ""
 
-#: builtin/notes.c:802
-msgid "must specify a notes ref to merge"
+#: builtin/commit.c:1492
+msgid "Commit message options"
 msgstr ""
 
-#: builtin/notes.c:826
-#, c-format
-msgid "unknown -s/--strategy: %s"
+#: builtin/commit.c:1493 builtin/merge.c:274 builtin/tag.c:414
+msgid "read message from file"
 msgstr ""
 
-#: builtin/notes.c:863
-#, c-format
-msgid "a notes merge into %s is already in-progress at %s"
+#: builtin/commit.c:1494
+msgid "author"
 msgstr ""
 
-#: builtin/notes.c:866
-#, c-format
-msgid "failed to store link to current notes ref (%s)"
+#: builtin/commit.c:1494
+msgid "override author for commit"
 msgstr ""
 
-#: builtin/notes.c:868
-#, c-format
-msgid ""
-"Automatic notes merge failed. Fix conflicts in %s and commit the result with "
-"'git notes merge --commit', or abort the merge with 'git notes merge --"
-"abort'.\n"
+#: builtin/commit.c:1495 builtin/gc.c:538
+msgid "date"
 msgstr ""
 
-#: builtin/notes.c:890
-#, c-format
-msgid "Object %s has no note\n"
+#: builtin/commit.c:1495
+msgid "override date for commit"
 msgstr ""
 
-#: builtin/notes.c:902
-msgid "attempt to remove non-existent note is not an error"
+#: builtin/commit.c:1497 builtin/commit.c:1498 builtin/commit.c:1499
+#: builtin/commit.c:1500 parse-options.h:328 ref-filter.h:92
+msgid "commit"
 msgstr ""
 
-#: builtin/notes.c:905
-msgid "read object names from the standard input"
+#: builtin/commit.c:1497
+msgid "reuse and edit message from specified commit"
 msgstr ""
 
-#: builtin/notes.c:943 builtin/prune.c:107 builtin/worktree.c:151
-msgid "do not remove, show only"
+#: builtin/commit.c:1498
+msgid "reuse message from specified commit"
 msgstr ""
 
-#: builtin/notes.c:944
-msgid "report pruned notes"
+#: builtin/commit.c:1499
+msgid "use autosquash formatted message to fixup specified commit"
 msgstr ""
 
-#: builtin/notes.c:986
-msgid "notes-ref"
+#: builtin/commit.c:1500
+msgid "use autosquash formatted message to squash specified commit"
 msgstr ""
 
-#: builtin/notes.c:987
-msgid "use notes from <notes-ref>"
+#: builtin/commit.c:1501
+msgid "the commit is authored by me now (used with -C/-c/--amend)"
 msgstr ""
 
-#: builtin/notes.c:1022
-#, c-format
-msgid "unknown subcommand: %s"
+#: builtin/commit.c:1502 builtin/log.c:1634 builtin/merge.c:289
+#: builtin/pull.c:164 builtin/revert.c:110
+msgid "add Signed-off-by:"
 msgstr ""
 
-#: builtin/pack-objects.c:48
-msgid ""
-"git pack-objects --stdout [<options>...] [< <ref-list> | < <object-list>]"
+#: builtin/commit.c:1503
+msgid "use specified template file"
 msgstr ""
 
-#: builtin/pack-objects.c:49
-msgid ""
-"git pack-objects [<options>...] <base-name> [< <ref-list> | < <object-list>]"
+#: builtin/commit.c:1504
+msgid "force edit of commit"
 msgstr ""
 
-#: builtin/pack-objects.c:211 builtin/pack-objects.c:214
-#, c-format
-msgid "deflate error (%d)"
+#: builtin/commit.c:1506
+msgid "include status in commit message template"
 msgstr ""
 
-#: builtin/pack-objects.c:810
-msgid "disabling bitmap writing, packs are split due to pack.packSizeLimit"
+#: builtin/commit.c:1511
+msgid "Commit contents options"
 msgstr ""
 
-#: builtin/pack-objects.c:823
-msgid "Writing objects"
+#: builtin/commit.c:1512
+msgid "commit all changed files"
 msgstr ""
 
-#: builtin/pack-objects.c:1106
-msgid "disabling bitmap writing, as some objects are not being packed"
+#: builtin/commit.c:1513
+msgid "add specified files to index for commit"
 msgstr ""
 
-#: builtin/pack-objects.c:1765
-msgid "Counting objects"
+#: builtin/commit.c:1514
+msgid "interactively add files"
 msgstr ""
 
-#: builtin/pack-objects.c:1895
-#, c-format
-msgid "unable to get size of %s"
+#: builtin/commit.c:1515
+msgid "interactively add changes"
 msgstr ""
 
-#: builtin/pack-objects.c:1910
-#, c-format
-msgid "unable to parse object header of %s"
+#: builtin/commit.c:1516
+msgid "commit only specified files"
 msgstr ""
 
-#: builtin/pack-objects.c:2564
-msgid "Compressing objects"
+#: builtin/commit.c:1517
+msgid "bypass pre-commit and commit-msg hooks"
 msgstr ""
 
-#: builtin/pack-objects.c:2735
-msgid "invalid value for --missing"
+#: builtin/commit.c:1518
+msgid "show what would be committed"
 msgstr ""
 
-#: builtin/pack-objects.c:3067
-#, c-format
-msgid "unsupported index version %s"
+#: builtin/commit.c:1531
+msgid "amend previous commit"
 msgstr ""
 
-#: builtin/pack-objects.c:3071
-#, c-format
-msgid "bad index version '%s'"
+#: builtin/commit.c:1532
+msgid "bypass post-rewrite hook"
 msgstr ""
 
-#: builtin/pack-objects.c:3102
-msgid "do not show progress meter"
+#: builtin/commit.c:1539
+msgid "ok to record an empty change"
 msgstr ""
 
-#: builtin/pack-objects.c:3104
-msgid "show progress meter"
+#: builtin/commit.c:1541
+msgid "ok to record a change with an empty message"
 msgstr ""
 
-#: builtin/pack-objects.c:3106
-msgid "show progress meter during object writing phase"
+#: builtin/commit.c:1614
+#, c-format
+msgid "Corrupt MERGE_HEAD file (%s)"
 msgstr ""
 
-#: builtin/pack-objects.c:3109
-msgid "similar to --all-progress when progress meter is shown"
+#: builtin/commit.c:1621
+msgid "could not read MERGE_MODE"
 msgstr ""
 
-#: builtin/pack-objects.c:3110
-msgid "version[,offset]"
+#: builtin/commit.c:1640
+#, c-format
+msgid "could not read commit message: %s"
 msgstr ""
 
-#: builtin/pack-objects.c:3111
-msgid "write the pack index file in the specified idx format version"
+#: builtin/commit.c:1647
+#, c-format
+msgid "Aborting commit due to empty commit message.\n"
 msgstr ""
 
-#: builtin/pack-objects.c:3114
-msgid "maximum size of each output pack file"
+#: builtin/commit.c:1652
+#, c-format
+msgid "Aborting commit; you did not edit the message.\n"
 msgstr ""
 
-#: builtin/pack-objects.c:3116
-msgid "ignore borrowed objects from alternate object store"
+#: builtin/commit.c:1686
+msgid ""
+"repository has been updated, but unable to write\n"
+"new_index file. Check that disk is not full and quota is\n"
+"not exceeded, and then \"git restore --staged :/\" to recover."
 msgstr ""
 
-#: builtin/pack-objects.c:3118
-msgid "ignore packed objects"
+#: builtin/commit-graph.c:11 builtin/commit-graph.c:17
+msgid ""
+"git commit-graph verify [--object-dir <objdir>] [--shallow] [--[no-]progress]"
 msgstr ""
 
-#: builtin/pack-objects.c:3120
-msgid "limit pack window by objects"
+#: builtin/commit-graph.c:12 builtin/commit-graph.c:22
+msgid ""
+"git commit-graph write [--object-dir <objdir>] [--append|--split] [--"
+"reachable|--stdin-packs|--stdin-commits] [--[no-]progress] <split options>"
 msgstr ""
 
-#: builtin/pack-objects.c:3122
-msgid "limit pack window by memory in addition to object limit"
+#: builtin/commit-graph.c:48 builtin/commit-graph.c:103
+#: builtin/commit-graph.c:187 builtin/fetch.c:179 builtin/log.c:1657
+msgid "dir"
 msgstr ""
 
-#: builtin/pack-objects.c:3124
-msgid "maximum length of delta chain allowed in the resulting pack"
+#: builtin/commit-graph.c:49 builtin/commit-graph.c:104
+#: builtin/commit-graph.c:188
+msgid "The object directory to store the graph"
 msgstr ""
 
-#: builtin/pack-objects.c:3126
-msgid "reuse existing deltas"
+#: builtin/commit-graph.c:51
+msgid "if the commit-graph is split, only verify the tip file"
 msgstr ""
 
-#: builtin/pack-objects.c:3128
-msgid "reuse existing objects"
+#: builtin/commit-graph.c:73 t/helper/test-read-graph.c:23
+#, c-format
+msgid "Could not open commit-graph '%s'"
 msgstr ""
 
-#: builtin/pack-objects.c:3130
-msgid "use OFS_DELTA objects"
+#: builtin/commit-graph.c:106
+msgid "start walk at all refs"
 msgstr ""
 
-#: builtin/pack-objects.c:3132
-msgid "use threads when searching for best delta matches"
+#: builtin/commit-graph.c:108
+msgid "scan pack-indexes listed by stdin for commits"
 msgstr ""
 
-#: builtin/pack-objects.c:3134
-msgid "do not create an empty pack output"
+#: builtin/commit-graph.c:110
+msgid "start walk at commits listed by stdin"
 msgstr ""
 
-#: builtin/pack-objects.c:3136
-msgid "read revision arguments from standard input"
+#: builtin/commit-graph.c:112
+msgid "include all commits already in the commit-graph file"
 msgstr ""
 
-#: builtin/pack-objects.c:3138
-msgid "limit the objects to those that are not yet packed"
+#: builtin/commit-graph.c:115
+msgid "allow writing an incremental commit-graph file"
 msgstr ""
 
-#: builtin/pack-objects.c:3141
-msgid "include objects reachable from any reference"
+#: builtin/commit-graph.c:117 builtin/commit-graph.c:121
+msgid "maximum number of commits in a non-base split commit-graph"
 msgstr ""
 
-#: builtin/pack-objects.c:3144
-msgid "include objects referred by reflog entries"
+#: builtin/commit-graph.c:119
+msgid "maximum ratio between two levels of a split commit-graph"
 msgstr ""
 
-#: builtin/pack-objects.c:3147
-msgid "include objects referred to by the index"
+#: builtin/commit-graph.c:137
+msgid "use at most one of --reachable, --stdin-commits, or --stdin-packs"
 msgstr ""
 
-#: builtin/pack-objects.c:3150
-msgid "output pack to stdout"
+#: builtin/config.c:11
+msgid "git config [<options>]"
 msgstr ""
 
-#: builtin/pack-objects.c:3152
-msgid "include tag objects that refer to objects to be packed"
+#: builtin/config.c:103 builtin/env--helper.c:23
+#, c-format
+msgid "unrecognized --type argument, %s"
 msgstr ""
 
-#: builtin/pack-objects.c:3154
-msgid "keep unreachable objects"
+#: builtin/config.c:115
+msgid "only one type at a time"
 msgstr ""
 
-#: builtin/pack-objects.c:3156
-msgid "pack loose unreachable objects"
+#: builtin/config.c:124
+msgid "Config file location"
 msgstr ""
 
-#: builtin/pack-objects.c:3158
-msgid "unpack unreachable objects newer than <time>"
+#: builtin/config.c:125
+msgid "use global config file"
 msgstr ""
 
-#: builtin/pack-objects.c:3161
-msgid "create thin packs"
+#: builtin/config.c:126
+msgid "use system config file"
 msgstr ""
 
-#: builtin/pack-objects.c:3163
-msgid "create packs suitable for shallow fetches"
+#: builtin/config.c:127
+msgid "use repository config file"
 msgstr ""
 
-#: builtin/pack-objects.c:3165
-msgid "ignore packs that have companion .keep file"
+#: builtin/config.c:128
+msgid "use per-worktree config file"
 msgstr ""
 
-#: builtin/pack-objects.c:3167
-msgid "ignore this pack"
+#: builtin/config.c:129
+msgid "use given config file"
 msgstr ""
 
-#: builtin/pack-objects.c:3169
-msgid "pack compression level"
+#: builtin/config.c:130
+msgid "blob-id"
 msgstr ""
 
-#: builtin/pack-objects.c:3171
-msgid "do not hide commits by grafts"
+#: builtin/config.c:130
+msgid "read config from given blob object"
 msgstr ""
 
-#: builtin/pack-objects.c:3173
-msgid "use a bitmap index if available to speed up counting objects"
-msgstr ""
-
-#: builtin/pack-objects.c:3175
-msgid "write a bitmap index together with the pack index"
+#: builtin/config.c:131
+msgid "Action"
 msgstr ""
 
-#: builtin/pack-objects.c:3178
-msgid "handling for missing objects"
+#: builtin/config.c:132
+msgid "get value: name [value-regex]"
 msgstr ""
 
-#: builtin/pack-objects.c:3181
-msgid "do not pack objects in promisor packfiles"
+#: builtin/config.c:133
+msgid "get all values: key [value-regex]"
 msgstr ""
 
-#: builtin/pack-objects.c:3205
-#, c-format
-msgid "delta chain depth %d is too deep, forcing %d"
+#: builtin/config.c:134
+msgid "get values for regexp: name-regex [value-regex]"
 msgstr ""
 
-#: builtin/pack-objects.c:3210
-#, c-format
-msgid "pack.deltaCacheLimit is too high, forcing %d"
+#: builtin/config.c:135
+msgid "get value specific for the URL: section[.var] URL"
 msgstr ""
 
-#: builtin/pack-objects.c:3338
-msgid "Enumerating objects"
+#: builtin/config.c:136
+msgid "replace all matching variables: name value [value_regex]"
 msgstr ""
 
-#: builtin/pack-refs.c:7
-msgid "git pack-refs [<options>]"
+#: builtin/config.c:137
+msgid "add a new variable: name value"
 msgstr ""
 
-#: builtin/pack-refs.c:15
-msgid "pack everything"
+#: builtin/config.c:138
+msgid "remove a variable: name [value-regex]"
 msgstr ""
 
-#: builtin/pack-refs.c:16
-msgid "prune loose refs (default)"
+#: builtin/config.c:139
+msgid "remove all matches: name [value-regex]"
 msgstr ""
 
-#: builtin/prune-packed.c:8
-msgid "git prune-packed [-n | --dry-run] [-q | --quiet]"
+#: builtin/config.c:140
+msgid "rename section: old-name new-name"
 msgstr ""
 
-#: builtin/prune-packed.c:41
-msgid "Removing duplicate objects"
+#: builtin/config.c:141
+msgid "remove a section: name"
 msgstr ""
 
-#: builtin/prune.c:11
-msgid "git prune [-n] [-v] [--progress] [--expire <time>] [--] [<head>...]"
+#: builtin/config.c:142
+msgid "list all"
 msgstr ""
 
-#: builtin/prune.c:108
-msgid "report pruned objects"
+#: builtin/config.c:143
+msgid "open an editor"
 msgstr ""
 
-#: builtin/prune.c:111
-msgid "expire objects older than <time>"
+#: builtin/config.c:144
+msgid "find the color configured: slot [default]"
 msgstr ""
 
-#: builtin/prune.c:113
-msgid "limit traversal to objects outside promisor packfiles"
+#: builtin/config.c:145
+msgid "find the color setting: slot [stdout-is-tty]"
 msgstr ""
 
-#: builtin/prune.c:127
-msgid "cannot prune in a precious-objects repo"
+#: builtin/config.c:146
+msgid "Type"
 msgstr ""
 
-#: builtin/pull.c:59 builtin/pull.c:61
-#, c-format
-msgid "Invalid value for %s: %s"
+#: builtin/config.c:147 builtin/env--helper.c:38
+msgid "value is given this type"
 msgstr ""
 
-#: builtin/pull.c:81
-msgid "git pull [<options>] [<repository> [<refspec>...]]"
+#: builtin/config.c:148
+msgid "value is \"true\" or \"false\""
 msgstr ""
 
-#: builtin/pull.c:132
-msgid "control for recursive fetching of submodules"
+#: builtin/config.c:149
+msgid "value is decimal number"
 msgstr ""
 
-#: builtin/pull.c:136
-msgid "Options related to merging"
+#: builtin/config.c:150
+msgid "value is --bool or --int"
 msgstr ""
 
-#: builtin/pull.c:139
-msgid "incorporate changes by rebasing rather than merging"
+#: builtin/config.c:151
+msgid "value is a path (file or directory name)"
 msgstr ""
 
-#: builtin/pull.c:166 builtin/rebase--helper.c:23 builtin/revert.c:121
-msgid "allow fast-forward"
+#: builtin/config.c:152
+msgid "value is an expiry date"
 msgstr ""
 
-#: builtin/pull.c:175
-msgid "automatically stash/stash pop before and after rebase"
+#: builtin/config.c:153
+msgid "Other"
 msgstr ""
 
-#: builtin/pull.c:191
-msgid "Options related to fetching"
+#: builtin/config.c:154
+msgid "terminate values with NUL byte"
 msgstr ""
 
-#: builtin/pull.c:209
-msgid "number of submodules pulled in parallel"
+#: builtin/config.c:155
+msgid "show variable names only"
 msgstr ""
 
-#: builtin/pull.c:304
-#, c-format
-msgid "Invalid value for pull.ff: %s"
+#: builtin/config.c:156
+msgid "respect include directives on lookup"
 msgstr ""
 
-#: builtin/pull.c:420
-msgid ""
-"There is no candidate for rebasing against among the refs that you just "
-"fetched."
+#: builtin/config.c:157
+msgid "show origin of config (file, standard input, blob, command line)"
 msgstr ""
 
-#: builtin/pull.c:422
-msgid ""
-"There are no candidates for merging among the refs that you just fetched."
+#: builtin/config.c:158 builtin/env--helper.c:40
+msgid "value"
 msgstr ""
 
-#: builtin/pull.c:423
-msgid ""
-"Generally this means that you provided a wildcard refspec which had no\n"
-"matches on the remote end."
+#: builtin/config.c:158
+msgid "with --get, use default value when missing entry"
 msgstr ""
 
-#: builtin/pull.c:426
+#: builtin/config.c:172
 #, c-format
-msgid ""
-"You asked to pull from the remote '%s', but did not specify\n"
-"a branch. Because this is not the default configured remote\n"
-"for your current branch, you must specify a branch on the command line."
+msgid "wrong number of arguments, should be %d"
 msgstr ""
 
-#: builtin/pull.c:431 git-parse-remote.sh:73
-msgid "You are not currently on a branch."
+#: builtin/config.c:174
+#, c-format
+msgid "wrong number of arguments, should be from %d to %d"
 msgstr ""
 
-#: builtin/pull.c:433 builtin/pull.c:448 git-parse-remote.sh:79
-msgid "Please specify which branch you want to rebase against."
+#: builtin/config.c:308
+#, c-format
+msgid "invalid key pattern: %s"
 msgstr ""
 
-#: builtin/pull.c:435 builtin/pull.c:450 git-parse-remote.sh:82
-msgid "Please specify which branch you want to merge with."
+#: builtin/config.c:344
+#, c-format
+msgid "failed to format default config value: %s"
 msgstr ""
 
-#: builtin/pull.c:436 builtin/pull.c:451
-msgid "See git-pull(1) for details."
+#: builtin/config.c:401
+#, c-format
+msgid "cannot parse color '%s'"
 msgstr ""
 
-#: builtin/pull.c:438 builtin/pull.c:444 builtin/pull.c:453
-#: git-parse-remote.sh:64
-msgid "<remote>"
+#: builtin/config.c:443
+msgid "unable to parse default color value"
 msgstr ""
 
-#: builtin/pull.c:438 builtin/pull.c:453 builtin/pull.c:458 git-rebase.sh:523
-#: git-parse-remote.sh:65
-msgid "<branch>"
+#: builtin/config.c:496 builtin/config.c:742
+msgid "not in a git directory"
 msgstr ""
 
-#: builtin/pull.c:446 git-parse-remote.sh:75
-msgid "There is no tracking information for the current branch."
+#: builtin/config.c:499
+msgid "writing to stdin is not supported"
 msgstr ""
 
-#: builtin/pull.c:455 git-parse-remote.sh:95
-msgid ""
-"If you wish to set tracking information for this branch you can do so with:"
+#: builtin/config.c:502
+msgid "writing config blobs is not supported"
 msgstr ""
 
-#: builtin/pull.c:460
+#: builtin/config.c:587
 #, c-format
 msgid ""
-"Your configuration specifies to merge with the ref '%s'\n"
-"from the remote, but no such ref was fetched."
-msgstr ""
-
-#: builtin/pull.c:826
-msgid "ignoring --verify-signatures for rebase"
+"# This is Git's per-user configuration file.\n"
+"[user]\n"
+"# Please adapt and uncomment the following lines:\n"
+"#\tname = %s\n"
+"#\temail = %s\n"
 msgstr ""
 
-#: builtin/pull.c:874
-msgid "--[no-]autostash option is only valid with --rebase."
+#: builtin/config.c:611
+msgid "only one config file at a time"
 msgstr ""
 
-#: builtin/pull.c:882
-msgid "Updating an unborn branch with changes added to the index."
+#: builtin/config.c:616
+msgid "--local can only be used inside a git repository"
 msgstr ""
 
-#: builtin/pull.c:885
-msgid "pull with rebase"
+#: builtin/config.c:619
+msgid "--blob can only be used inside a git repository"
 msgstr ""
 
-#: builtin/pull.c:886
-msgid "please commit or stash them."
+#: builtin/config.c:638
+msgid "$HOME not set"
 msgstr ""
 
-#: builtin/pull.c:911
-#, c-format
+#: builtin/config.c:658
 msgid ""
-"fetch updated the current branch head.\n"
-"fast-forwarding your working tree from\n"
-"commit %s."
+"--worktree cannot be used with multiple working trees unless the config\n"
+"extension worktreeConfig is enabled. Please read \"CONFIGURATION FILE\"\n"
+"section in \"git help worktree\" for details"
 msgstr ""
 
-#: builtin/pull.c:916
-#, c-format
-msgid ""
-"Cannot fast-forward your working tree.\n"
-"After making sure that you saved anything precious from\n"
-"$ git diff %s\n"
-"output, run\n"
-"$ git reset --hard\n"
-"to recover."
+#: builtin/config.c:688
+msgid "--get-color and variable type are incoherent"
 msgstr ""
 
-#: builtin/pull.c:931
-msgid "Cannot merge multiple branches into empty head."
+#: builtin/config.c:693
+msgid "only one action at a time"
 msgstr ""
 
-#: builtin/pull.c:935
-msgid "Cannot rebase onto multiple branches."
+#: builtin/config.c:706
+msgid "--name-only is only applicable to --list or --get-regexp"
 msgstr ""
 
-#: builtin/pull.c:942
-msgid "cannot rebase with locally recorded submodule modifications"
+#: builtin/config.c:712
+msgid ""
+"--show-origin is only applicable to --get, --get-all, --get-regexp, and --"
+"list"
 msgstr ""
 
-#: builtin/push.c:19
-msgid "git push [<options>] [<repository> [<refspec>...]]"
+#: builtin/config.c:718
+msgid "--default is only applicable to --get"
 msgstr ""
 
-#: builtin/push.c:111
-msgid "tag shorthand without <tag>"
+#: builtin/config.c:731
+#, c-format
+msgid "unable to read config file '%s'"
 msgstr ""
 
-#: builtin/push.c:121
-msgid "--delete only accepts plain target ref names"
+#: builtin/config.c:734
+msgid "error processing config file(s)"
 msgstr ""
 
-#: builtin/push.c:165
-msgid ""
-"\n"
-"To choose either option permanently, see push.default in 'git help config'."
+#: builtin/config.c:744
+msgid "editing stdin is not supported"
 msgstr ""
 
-#: builtin/push.c:168
-#, c-format
-msgid ""
-"The upstream branch of your current branch does not match\n"
-"the name of your current branch.  To push to the upstream branch\n"
-"on the remote, use\n"
-"\n"
-"    git push %s HEAD:%s\n"
-"\n"
-"To push to the branch of the same name on the remote, use\n"
-"\n"
-"    git push %s %s\n"
-"%s"
+#: builtin/config.c:746
+msgid "editing blobs is not supported"
 msgstr ""
 
-#: builtin/push.c:183
+#: builtin/config.c:760
 #, c-format
-msgid ""
-"You are not currently on a branch.\n"
-"To push the history leading to the current (detached HEAD)\n"
-"state now, use\n"
-"\n"
-"    git push %s HEAD:<name-of-remote-branch>\n"
+msgid "cannot create configuration file %s"
 msgstr ""
 
-#: builtin/push.c:197
+#: builtin/config.c:773
 #, c-format
 msgid ""
-"The current branch %s has no upstream branch.\n"
-"To push the current branch and set the remote as upstream, use\n"
-"\n"
-"    git push --set-upstream %s %s\n"
+"cannot overwrite multiple values with a single value\n"
+"       Use a regexp, --add or --replace-all to change %s."
 msgstr ""
 
-#: builtin/push.c:205
+#: builtin/config.c:847 builtin/config.c:858
 #, c-format
-msgid "The current branch %s has multiple upstream branches, refusing to push."
+msgid "no such section: %s"
 msgstr ""
 
-#: builtin/push.c:208
-#, c-format
-msgid ""
-"You are pushing to remote '%s', which is not the upstream of\n"
-"your current branch '%s', without telling me what to push\n"
-"to update which remote branch."
+#: builtin/count-objects.c:90
+msgid "git count-objects [-v] [-H | --human-readable]"
 msgstr ""
 
-#: builtin/push.c:267
-msgid ""
-"You didn't specify any refspecs to push, and push.default is \"nothing\"."
+#: builtin/count-objects.c:100
+msgid "print sizes in human readable format"
 msgstr ""
 
-#: builtin/push.c:274
-msgid ""
-"Updates were rejected because the tip of your current branch is behind\n"
-"its remote counterpart. Integrate the remote changes (e.g.\n"
-"'git pull ...') before pushing again.\n"
-"See the 'Note about fast-forwards' in 'git push --help' for details."
+#: builtin/describe.c:26
+msgid "git describe [<options>] [<commit-ish>...]"
 msgstr ""
 
-#: builtin/push.c:280
-msgid ""
-"Updates were rejected because a pushed branch tip is behind its remote\n"
-"counterpart. Check out this branch and integrate the remote changes\n"
-"(e.g. 'git pull ...') before pushing again.\n"
-"See the 'Note about fast-forwards' in 'git push --help' for details."
+#: builtin/describe.c:27
+msgid "git describe [<options>] --dirty"
 msgstr ""
 
-#: builtin/push.c:286
-msgid ""
-"Updates were rejected because the remote contains work that you do\n"
-"not have locally. This is usually caused by another repository pushing\n"
-"to the same ref. You may want to first integrate the remote changes\n"
-"(e.g., 'git pull ...') before pushing again.\n"
-"See the 'Note about fast-forwards' in 'git push --help' for details."
+#: builtin/describe.c:62
+msgid "head"
 msgstr ""
 
-#: builtin/push.c:293
-msgid "Updates were rejected because the tag already exists in the remote."
+#: builtin/describe.c:62
+msgid "lightweight"
 msgstr ""
 
-#: builtin/push.c:296
-msgid ""
-"You cannot update a remote ref that points at a non-commit object,\n"
-"or update a remote ref to make it point at a non-commit object,\n"
-"without using the '--force' option.\n"
+#: builtin/describe.c:62
+msgid "annotated"
 msgstr ""
 
-#: builtin/push.c:357
+#: builtin/describe.c:275
 #, c-format
-msgid "Pushing to %s\n"
+msgid "annotated tag %s not available"
 msgstr ""
 
-#: builtin/push.c:361
+#: builtin/describe.c:279
 #, c-format
-msgid "failed to push some refs to '%s'"
+msgid "annotated tag %s has no embedded name"
 msgstr ""
 
-#: builtin/push.c:395
+#: builtin/describe.c:281
 #, c-format
-msgid "bad repository '%s'"
+msgid "tag '%s' is really '%s' here"
 msgstr ""
 
-#: builtin/push.c:396
-msgid ""
-"No configured push destination.\n"
-"Either specify the URL from the command-line or configure a remote "
-"repository using\n"
-"\n"
-"    git remote add <name> <url>\n"
-"\n"
-"and then push using the remote name\n"
-"\n"
-"    git push <name>\n"
+#: builtin/describe.c:325
+#, c-format
+msgid "no tag exactly matches '%s'"
 msgstr ""
 
-#: builtin/push.c:551
-msgid "repository"
+#: builtin/describe.c:327
+#, c-format
+msgid "No exact match on refs or tags, searching to describe\n"
 msgstr ""
 
-#: builtin/push.c:552 builtin/send-pack.c:164
-msgid "push all refs"
+#: builtin/describe.c:381
+#, c-format
+msgid "finished search at %s\n"
 msgstr ""
 
-#: builtin/push.c:553 builtin/send-pack.c:166
-msgid "mirror all refs"
+#: builtin/describe.c:407
+#, c-format
+msgid ""
+"No annotated tags can describe '%s'.\n"
+"However, there were unannotated tags: try --tags."
 msgstr ""
 
-#: builtin/push.c:555
-msgid "delete refs"
+#: builtin/describe.c:411
+#, c-format
+msgid ""
+"No tags can describe '%s'.\n"
+"Try --always, or create some tags."
 msgstr ""
 
-#: builtin/push.c:556
-msgid "push tags (can't be used with --all or --mirror)"
+#: builtin/describe.c:441
+#, c-format
+msgid "traversed %lu commits\n"
 msgstr ""
 
-#: builtin/push.c:559 builtin/send-pack.c:167
-msgid "force updates"
+#: builtin/describe.c:444
+#, c-format
+msgid ""
+"more than %i tags found; listed %i most recent\n"
+"gave up search at %s\n"
 msgstr ""
 
-#: builtin/push.c:561 builtin/send-pack.c:181
-msgid "refname>:<expect"
+#: builtin/describe.c:512
+#, c-format
+msgid "describe %s\n"
 msgstr ""
 
-#: builtin/push.c:562 builtin/send-pack.c:182
-msgid "require old value of ref to be at this value"
+#: builtin/describe.c:515
+#, c-format
+msgid "Not a valid object name %s"
 msgstr ""
 
-#: builtin/push.c:565
-msgid "control recursive pushing of submodules"
+#: builtin/describe.c:523
+#, c-format
+msgid "%s is neither a commit nor blob"
 msgstr ""
 
-#: builtin/push.c:567 builtin/send-pack.c:175
-msgid "use thin pack"
+#: builtin/describe.c:537
+msgid "find the tag that comes after the commit"
 msgstr ""
 
-#: builtin/push.c:568 builtin/push.c:569 builtin/send-pack.c:161
-#: builtin/send-pack.c:162
-msgid "receive pack program"
+#: builtin/describe.c:538
+msgid "debug search strategy on stderr"
 msgstr ""
 
-#: builtin/push.c:570
-msgid "set upstream for git pull/status"
+#: builtin/describe.c:539
+msgid "use any ref"
 msgstr ""
 
-#: builtin/push.c:573
-msgid "prune locally removed refs"
+#: builtin/describe.c:540
+msgid "use any tag, even unannotated"
 msgstr ""
 
-#: builtin/push.c:575
-msgid "bypass pre-push hook"
+#: builtin/describe.c:541
+msgid "always use long format"
 msgstr ""
 
-#: builtin/push.c:576
-msgid "push missing but relevant tags"
+#: builtin/describe.c:542
+msgid "only follow first parent"
 msgstr ""
 
-#: builtin/push.c:579 builtin/send-pack.c:169
-msgid "GPG sign the push"
+#: builtin/describe.c:545
+msgid "only output exact matches"
 msgstr ""
 
-#: builtin/push.c:581 builtin/send-pack.c:176
-msgid "request atomic transaction on remote side"
+#: builtin/describe.c:547
+msgid "consider <n> most recent tags (default: 10)"
 msgstr ""
 
-#: builtin/push.c:599
-msgid "--delete is incompatible with --all, --mirror and --tags"
+#: builtin/describe.c:549
+msgid "only consider tags matching <pattern>"
 msgstr ""
 
-#: builtin/push.c:601
-msgid "--delete doesn't make sense without any refs"
+#: builtin/describe.c:551
+msgid "do not consider tags matching <pattern>"
 msgstr ""
 
-#: builtin/push.c:604
-msgid "--all and --tags are incompatible"
+#: builtin/describe.c:553 builtin/name-rev.c:473
+msgid "show abbreviated commit object as fallback"
 msgstr ""
 
-#: builtin/push.c:606
-msgid "--all can't be combined with refspecs"
+#: builtin/describe.c:554 builtin/describe.c:557
+msgid "mark"
 msgstr ""
 
-#: builtin/push.c:610
-msgid "--mirror and --tags are incompatible"
+#: builtin/describe.c:555
+msgid "append <mark> on dirty working tree (default: \"-dirty\")"
 msgstr ""
 
-#: builtin/push.c:612
-msgid "--mirror can't be combined with refspecs"
+#: builtin/describe.c:558
+msgid "append <mark> on broken working tree (default: \"-broken\")"
 msgstr ""
 
-#: builtin/push.c:615
-msgid "--all and --mirror are incompatible"
+#: builtin/describe.c:576
+msgid "--long is incompatible with --abbrev=0"
 msgstr ""
 
-#: builtin/push.c:634
-msgid "push options must not have new line characters"
+#: builtin/describe.c:605
+msgid "No names found, cannot describe anything."
 msgstr ""
 
-#: builtin/read-tree.c:40
-msgid ""
-"git read-tree [(-m [--trivial] [--aggressive] | --reset | --prefix=<prefix>) "
-"[-u [--exclude-per-directory=<gitignore>] | -i]] [--no-sparse-checkout] [--"
-"index-output=<file>] (--empty | <tree-ish1> [<tree-ish2> [<tree-ish3>]])"
+#: builtin/describe.c:656
+msgid "--dirty is incompatible with commit-ishes"
 msgstr ""
 
-#: builtin/read-tree.c:120
-msgid "write resulting index to <file>"
+#: builtin/describe.c:658
+msgid "--broken is incompatible with commit-ishes"
 msgstr ""
 
-#: builtin/read-tree.c:123
-msgid "only empty the index"
+#: builtin/diff.c:84
+#, c-format
+msgid "'%s': not a regular file or symlink"
 msgstr ""
 
-#: builtin/read-tree.c:125
-msgid "Merging"
+#: builtin/diff.c:235
+#, c-format
+msgid "invalid option: %s"
 msgstr ""
 
-#: builtin/read-tree.c:127
-msgid "perform a merge in addition to a read"
+#: builtin/diff.c:350
+msgid "Not a git repository"
 msgstr ""
 
-#: builtin/read-tree.c:129
-msgid "3-way merge if no file level merging required"
+#: builtin/diff.c:394
+#, c-format
+msgid "invalid object '%s' given."
 msgstr ""
 
-#: builtin/read-tree.c:131
-msgid "3-way merge in presence of adds and removes"
+#: builtin/diff.c:403
+#, c-format
+msgid "more than two blobs given: '%s'"
 msgstr ""
 
-#: builtin/read-tree.c:133
-msgid "same as -m, but discard unmerged entries"
+#: builtin/diff.c:408
+#, c-format
+msgid "unhandled object '%s' given."
 msgstr ""
 
-#: builtin/read-tree.c:134
-msgid "<subdirectory>/"
+#: builtin/difftool.c:30
+msgid "git difftool [<options>] [<commit> [<commit>]] [--] [<path>...]"
 msgstr ""
 
-#: builtin/read-tree.c:135
-msgid "read the tree into the index under <subdirectory>/"
+#: builtin/difftool.c:260
+#, c-format
+msgid "failed: %d"
 msgstr ""
 
-#: builtin/read-tree.c:138
-msgid "update working tree with merge result"
+#: builtin/difftool.c:302
+#, c-format
+msgid "could not read symlink %s"
 msgstr ""
 
-#: builtin/read-tree.c:140
-msgid "gitignore"
+#: builtin/difftool.c:304
+#, c-format
+msgid "could not read symlink file %s"
 msgstr ""
 
-#: builtin/read-tree.c:141
-msgid "allow explicitly ignored files to be overwritten"
+#: builtin/difftool.c:312
+#, c-format
+msgid "could not read object %s for symlink %s"
 msgstr ""
 
-#: builtin/read-tree.c:144
-msgid "don't check the working tree after merging"
+#: builtin/difftool.c:413
+msgid ""
+"combined diff formats('-c' and '--cc') are not supported in\n"
+"directory diff mode('-d' and '--dir-diff')."
 msgstr ""
 
-#: builtin/read-tree.c:145
-msgid "don't update the index or the work tree"
+#: builtin/difftool.c:634
+#, c-format
+msgid "both files modified: '%s' and '%s'."
 msgstr ""
 
-#: builtin/read-tree.c:147
-msgid "skip applying sparse checkout filter"
+#: builtin/difftool.c:636
+msgid "working tree file has been left."
 msgstr ""
 
-#: builtin/read-tree.c:149
-msgid "debug unpack-trees"
+#: builtin/difftool.c:647
+#, c-format
+msgid "temporary files exist in '%s'."
 msgstr ""
 
-#: builtin/rebase--helper.c:8
-msgid "git rebase--helper [<options>]"
+#: builtin/difftool.c:648
+msgid "you may want to cleanup or recover these."
 msgstr ""
 
-#: builtin/rebase--helper.c:24
-msgid "keep empty commits"
+#: builtin/difftool.c:697
+msgid "use `diff.guitool` instead of `diff.tool`"
 msgstr ""
 
-#: builtin/rebase--helper.c:26 builtin/revert.c:123
-msgid "allow commits with empty messages"
+#: builtin/difftool.c:699
+msgid "perform a full-directory diff"
 msgstr ""
 
-#: builtin/rebase--helper.c:27
-msgid "rebase merge commits"
+#: builtin/difftool.c:701
+msgid "do not prompt before launching a diff tool"
 msgstr ""
 
-#: builtin/rebase--helper.c:29
-msgid "keep original branch points of cousins"
+#: builtin/difftool.c:706
+msgid "use symlinks in dir-diff mode"
 msgstr ""
 
-#: builtin/rebase--helper.c:30
-msgid "continue rebase"
+#: builtin/difftool.c:707
+msgid "tool"
 msgstr ""
 
-#: builtin/rebase--helper.c:32
-msgid "abort rebase"
+#: builtin/difftool.c:708
+msgid "use the specified diff tool"
 msgstr ""
 
-#: builtin/rebase--helper.c:35
-msgid "make rebase script"
+#: builtin/difftool.c:710
+msgid "print a list of diff tools that may be used with `--tool`"
 msgstr ""
 
-#: builtin/rebase--helper.c:37
-msgid "shorten commit ids in the todo list"
+#: builtin/difftool.c:713
+msgid ""
+"make 'git-difftool' exit when an invoked diff tool returns a non - zero exit "
+"code"
 msgstr ""
 
-#: builtin/rebase--helper.c:39
-msgid "expand commit ids in the todo list"
+#: builtin/difftool.c:716
+msgid "specify a custom command for viewing diffs"
 msgstr ""
 
-#: builtin/rebase--helper.c:41
-msgid "check the todo list"
+#: builtin/difftool.c:717
+msgid "passed to `diff`"
 msgstr ""
 
-#: builtin/rebase--helper.c:43
-msgid "skip unnecessary picks"
+#: builtin/difftool.c:732
+msgid "difftool requires worktree or --no-index"
 msgstr ""
 
-#: builtin/rebase--helper.c:45
-msgid "rearrange fixup/squash lines"
+#: builtin/difftool.c:739
+msgid "--dir-diff is incompatible with --no-index"
 msgstr ""
 
-#: builtin/rebase--helper.c:47
-msgid "insert exec commands in todo list"
+#: builtin/difftool.c:742
+msgid "--gui, --tool and --extcmd are mutually exclusive"
 msgstr ""
 
-#: builtin/rebase--helper.c:68
-msgid "--[no-]rebase-cousins has no effect without --rebase-merges"
+#: builtin/difftool.c:750
+msgid "no <tool> given for --tool=<tool>"
 msgstr ""
 
-#: builtin/receive-pack.c:31
-msgid "git receive-pack <git-dir>"
+#: builtin/difftool.c:757
+msgid "no <cmd> given for --extcmd=<cmd>"
 msgstr ""
 
-#: builtin/receive-pack.c:842
-msgid ""
-"By default, updating the current branch in a non-bare repository\n"
-"is denied, because it will make the index and work tree inconsistent\n"
-"with what you pushed, and will require 'git reset --hard' to match\n"
-"the work tree to HEAD.\n"
-"\n"
-"You can set the 'receive.denyCurrentBranch' configuration variable\n"
-"to 'ignore' or 'warn' in the remote repository to allow pushing into\n"
-"its current branch; however, this is not recommended unless you\n"
-"arranged to update its work tree to match what you pushed in some\n"
-"other way.\n"
-"\n"
-"To squelch this message and still keep the default behaviour, set\n"
-"'receive.denyCurrentBranch' configuration variable to 'refuse'."
+#: builtin/env--helper.c:6
+msgid "git env--helper --type=[bool|ulong] <options> <env-var>"
 msgstr ""
 
-#: builtin/receive-pack.c:862
-msgid ""
-"By default, deleting the current branch is denied, because the next\n"
-"'git clone' won't result in any file checked out, causing confusion.\n"
-"\n"
-"You can set 'receive.denyDeleteCurrent' configuration variable to\n"
-"'warn' or 'ignore' in the remote repository to allow deleting the\n"
-"current branch, with or without a warning message.\n"
-"\n"
-"To squelch this message, you can set it to 'refuse'."
+#: builtin/env--helper.c:37 builtin/hash-object.c:98
+msgid "type"
 msgstr ""
 
-#: builtin/receive-pack.c:1935
-msgid "quiet"
+#: builtin/env--helper.c:41
+msgid "default for git_env_*(...) to fall back on"
 msgstr ""
 
-#: builtin/receive-pack.c:1949
-msgid "You must specify a directory."
+#: builtin/env--helper.c:43
+msgid "be quiet only use git_env_*() value as exit code"
 msgstr ""
 
-#: builtin/reflog.c:532 builtin/reflog.c:537
+#: builtin/env--helper.c:62
 #, c-format
-msgid "'%s' is not a valid timestamp"
-msgstr ""
-
-#: builtin/remote.c:14
-msgid "git remote [-v | --verbose]"
+msgid "option `--default' expects a boolean value with `--type=bool`, not `%s`"
 msgstr ""
 
-#: builtin/remote.c:15
+#: builtin/env--helper.c:77
+#, c-format
 msgid ""
-"git remote add [-t <branch>] [-m <master>] [-f] [--tags | --no-tags] [--"
-"mirror=<fetch|push>] <name> <url>"
+"option `--default' expects an unsigned long value with `--type=ulong`, not `"
+"%s`"
 msgstr ""
 
-#: builtin/remote.c:16 builtin/remote.c:36
-msgid "git remote rename <old> <new>"
+#: builtin/fast-export.c:29
+msgid "git fast-export [rev-list-opts]"
 msgstr ""
 
-#: builtin/remote.c:17 builtin/remote.c:41
-msgid "git remote remove <name>"
+#: builtin/fast-export.c:852
+msgid "Error: Cannot export nested tags unless --mark-tags is specified."
 msgstr ""
 
-#: builtin/remote.c:18 builtin/remote.c:46
-msgid "git remote set-head <name> (-a | --auto | -d | --delete | <branch>)"
+#: builtin/fast-export.c:1152
+msgid "show progress after <n> objects"
 msgstr ""
 
-#: builtin/remote.c:19
-msgid "git remote [-v | --verbose] show [-n] <name>"
+#: builtin/fast-export.c:1154
+msgid "select handling of signed tags"
 msgstr ""
 
-#: builtin/remote.c:20
-msgid "git remote prune [-n | --dry-run] <name>"
+#: builtin/fast-export.c:1157
+msgid "select handling of tags that tag filtered objects"
 msgstr ""
 
-#: builtin/remote.c:21
-msgid ""
-"git remote [-v | --verbose] update [-p | --prune] [(<group> | <remote>)...]"
+#: builtin/fast-export.c:1160
+msgid "select handling of commit messages in an alternate encoding"
 msgstr ""
 
-#: builtin/remote.c:22
-msgid "git remote set-branches [--add] <name> <branch>..."
+#: builtin/fast-export.c:1163
+msgid "Dump marks to this file"
 msgstr ""
 
-#: builtin/remote.c:23 builtin/remote.c:72
-msgid "git remote get-url [--push] [--all] <name>"
+#: builtin/fast-export.c:1165
+msgid "Import marks from this file"
 msgstr ""
 
-#: builtin/remote.c:24 builtin/remote.c:77
-msgid "git remote set-url [--push] <name> <newurl> [<oldurl>]"
+#: builtin/fast-export.c:1169
+msgid "Import marks from this file if it exists"
 msgstr ""
 
-#: builtin/remote.c:25 builtin/remote.c:78
-msgid "git remote set-url --add <name> <newurl>"
+#: builtin/fast-export.c:1171
+msgid "Fake a tagger when tags lack one"
 msgstr ""
 
-#: builtin/remote.c:26 builtin/remote.c:79
-msgid "git remote set-url --delete <name> <url>"
+#: builtin/fast-export.c:1173
+msgid "Output full tree for each commit"
 msgstr ""
 
-#: builtin/remote.c:31
-msgid "git remote add [<options>] <name> <url>"
+#: builtin/fast-export.c:1175
+msgid "Use the done feature to terminate the stream"
 msgstr ""
 
-#: builtin/remote.c:51
-msgid "git remote set-branches <name> <branch>..."
+#: builtin/fast-export.c:1176
+msgid "Skip output of blob data"
 msgstr ""
 
-#: builtin/remote.c:52
-msgid "git remote set-branches --add <name> <branch>..."
+#: builtin/fast-export.c:1177 builtin/log.c:1705
+msgid "refspec"
 msgstr ""
 
-#: builtin/remote.c:57
-msgid "git remote show [<options>] <name>"
+#: builtin/fast-export.c:1178
+msgid "Apply refspec to exported refs"
 msgstr ""
 
-#: builtin/remote.c:62
-msgid "git remote prune [<options>] <name>"
+#: builtin/fast-export.c:1179
+msgid "anonymize output"
 msgstr ""
 
-#: builtin/remote.c:67
-msgid "git remote update [<options>] [<group> | <remote>]..."
+#: builtin/fast-export.c:1181
+msgid "Reference parents which are not in fast-export stream by object id"
 msgstr ""
 
-#: builtin/remote.c:96
-#, c-format
-msgid "Updating %s"
+#: builtin/fast-export.c:1183
+msgid "Show original object ids of blobs/commits"
 msgstr ""
 
-#: builtin/remote.c:128
-msgid ""
-"--mirror is dangerous and deprecated; please\n"
-"\t use --mirror=fetch or --mirror=push instead"
+#: builtin/fast-export.c:1185
+msgid "Label tags with mark ids"
 msgstr ""
 
-#: builtin/remote.c:145
-#, c-format
-msgid "unknown mirror argument: %s"
+#: builtin/fast-export.c:1220
+msgid "Cannot pass both --import-marks and --import-marks-if-exists"
 msgstr ""
 
-#: builtin/remote.c:161
-msgid "fetch the remote branches"
+#: builtin/fetch.c:34
+msgid "git fetch [<options>] [<repository> [<refspec>...]]"
 msgstr ""
 
-#: builtin/remote.c:163
-msgid "import all tags and associated objects when fetching"
+#: builtin/fetch.c:35
+msgid "git fetch [<options>] <group>"
 msgstr ""
 
-#: builtin/remote.c:166
-msgid "or do not fetch any tag at all (--no-tags)"
+#: builtin/fetch.c:36
+msgid "git fetch --multiple [<options>] [(<repository> | <group>)...]"
 msgstr ""
 
-#: builtin/remote.c:168
-msgid "branch(es) to track"
+#: builtin/fetch.c:37
+msgid "git fetch --all [<options>]"
 msgstr ""
 
-#: builtin/remote.c:169
-msgid "master branch"
+#: builtin/fetch.c:116
+msgid "fetch.parallel cannot be negative"
 msgstr ""
 
-#: builtin/remote.c:170
-msgid "push|fetch"
+#: builtin/fetch.c:139 builtin/pull.c:204
+msgid "fetch from all remotes"
 msgstr ""
 
-#: builtin/remote.c:171
-msgid "set up remote as a mirror to push to or fetch from"
+#: builtin/fetch.c:141 builtin/pull.c:248
+msgid "set upstream for git pull/fetch"
 msgstr ""
 
-#: builtin/remote.c:183
-msgid "specifying a master branch makes no sense with --mirror"
+#: builtin/fetch.c:143 builtin/pull.c:207
+msgid "append to .git/FETCH_HEAD instead of overwriting"
 msgstr ""
 
-#: builtin/remote.c:185
-msgid "specifying branches to track makes sense only with fetch mirrors"
+#: builtin/fetch.c:145 builtin/pull.c:210
+msgid "path to upload pack on remote end"
 msgstr ""
 
-#: builtin/remote.c:192 builtin/remote.c:634
-#, c-format
-msgid "remote %s already exists."
+#: builtin/fetch.c:146
+msgid "force overwrite of local reference"
 msgstr ""
 
-#: builtin/remote.c:196 builtin/remote.c:638
-#, c-format
-msgid "'%s' is not a valid remote name"
+#: builtin/fetch.c:148
+msgid "fetch from multiple remotes"
 msgstr ""
 
-#: builtin/remote.c:236
-#, c-format
-msgid "Could not setup master '%s'"
+#: builtin/fetch.c:150 builtin/pull.c:214
+msgid "fetch all tags and associated objects"
 msgstr ""
 
-#: builtin/remote.c:342
-#, c-format
-msgid "Could not get fetch map for refspec %s"
+#: builtin/fetch.c:152
+msgid "do not fetch all tags (--no-tags)"
 msgstr ""
 
-#: builtin/remote.c:441 builtin/remote.c:449
-msgid "(matching)"
+#: builtin/fetch.c:154
+msgid "number of submodules fetched in parallel"
 msgstr ""
 
-#: builtin/remote.c:453
-msgid "(delete)"
+#: builtin/fetch.c:156 builtin/pull.c:217
+msgid "prune remote-tracking branches no longer on remote"
 msgstr ""
 
-#: builtin/remote.c:627 builtin/remote.c:762 builtin/remote.c:861
-#, c-format
-msgid "No such remote: %s"
+#: builtin/fetch.c:158
+msgid "prune local tags no longer on remote and clobber changed tags"
 msgstr ""
 
-#: builtin/remote.c:644
-#, c-format
-msgid "Could not rename config section '%s' to '%s'"
+#: builtin/fetch.c:159 builtin/fetch.c:182 builtin/pull.c:141
+msgid "on-demand"
 msgstr ""
 
-#: builtin/remote.c:664
-#, c-format
-msgid ""
-"Not updating non-default fetch refspec\n"
-"\t%s\n"
-"\tPlease update the configuration manually if necessary."
+#: builtin/fetch.c:160
+msgid "control recursive fetching of submodules"
 msgstr ""
 
-#: builtin/remote.c:700
-#, c-format
-msgid "deleting '%s' failed"
+#: builtin/fetch.c:164 builtin/pull.c:225
+msgid "keep downloaded pack"
 msgstr ""
 
-#: builtin/remote.c:734
-#, c-format
-msgid "creating '%s' failed"
+#: builtin/fetch.c:166
+msgid "allow updating of HEAD ref"
 msgstr ""
 
-#: builtin/remote.c:799
-msgid ""
-"Note: A branch outside the refs/remotes/ hierarchy was not removed;\n"
-"to delete it, use:"
-msgid_plural ""
-"Note: Some branches outside the refs/remotes/ hierarchy were not removed;\n"
-"to delete them, use:"
-msgstr[0] ""
-msgstr[1] ""
+#: builtin/fetch.c:169 builtin/fetch.c:175 builtin/pull.c:228
+msgid "deepen history of shallow clone"
+msgstr ""
 
-#: builtin/remote.c:813
-#, c-format
-msgid "Could not remove config section '%s'"
+#: builtin/fetch.c:171
+msgid "deepen history of shallow repository based on time"
 msgstr ""
 
-#: builtin/remote.c:914
-#, c-format
-msgid " new (next fetch will store in remotes/%s)"
+#: builtin/fetch.c:177 builtin/pull.c:231
+msgid "convert to a complete repository"
 msgstr ""
 
-#: builtin/remote.c:917
-msgid " tracked"
+#: builtin/fetch.c:180
+msgid "prepend this to submodule path output"
 msgstr ""
 
-#: builtin/remote.c:919
-msgid " stale (use 'git remote prune' to remove)"
+#: builtin/fetch.c:183
+msgid ""
+"default for recursive fetching of submodules (lower priority than config "
+"files)"
 msgstr ""
 
-#: builtin/remote.c:921
-msgid " ???"
+#: builtin/fetch.c:187 builtin/pull.c:234
+msgid "accept refs that update .git/shallow"
 msgstr ""
 
-#: builtin/remote.c:962
-#, c-format
-msgid "invalid branch.%s.merge; cannot rebase onto > 1 branch"
+#: builtin/fetch.c:188 builtin/pull.c:236
+msgid "refmap"
 msgstr ""
 
-#: builtin/remote.c:971
-#, c-format
-msgid "rebases interactively onto remote %s"
+#: builtin/fetch.c:189 builtin/pull.c:237
+msgid "specify fetch refmap"
 msgstr ""
 
-#: builtin/remote.c:973
-#, c-format
-msgid "rebases interactively (with merges) onto remote %s"
+#: builtin/fetch.c:196
+msgid "report that we have only objects reachable from this object"
 msgstr ""
 
-#: builtin/remote.c:976
-#, c-format
-msgid "rebases onto remote %s"
+#: builtin/fetch.c:199
+msgid "run 'gc --auto' after fetching"
 msgstr ""
 
-#: builtin/remote.c:980
-#, c-format
-msgid " merges with remote %s"
+#: builtin/fetch.c:201 builtin/pull.c:246
+msgid "check for forced-updates on all updated branches"
 msgstr ""
 
-#: builtin/remote.c:983
-#, c-format
-msgid "merges with remote %s"
+#: builtin/fetch.c:203
+msgid "write the commit-graph after fetching"
+msgstr ""
+
+#: builtin/fetch.c:513
+msgid "Couldn't find remote ref HEAD"
 msgstr ""
 
-#: builtin/remote.c:986
+#: builtin/fetch.c:653
 #, c-format
-msgid "%-*s    and with remote %s\n"
+msgid "configuration fetch.output contains invalid value %s"
 msgstr ""
 
-#: builtin/remote.c:1029
-msgid "create"
+#: builtin/fetch.c:751
+#, c-format
+msgid "object %s not found"
 msgstr ""
 
-#: builtin/remote.c:1032
-msgid "delete"
+#: builtin/fetch.c:755
+msgid "[up to date]"
 msgstr ""
 
-#: builtin/remote.c:1036
-msgid "up to date"
+#: builtin/fetch.c:768 builtin/fetch.c:784 builtin/fetch.c:856
+msgid "[rejected]"
 msgstr ""
 
-#: builtin/remote.c:1039
-msgid "fast-forwardable"
+#: builtin/fetch.c:769
+msgid "can't fetch in current branch"
 msgstr ""
 
-#: builtin/remote.c:1042
-msgid "local out of date"
+#: builtin/fetch.c:779
+msgid "[tag update]"
 msgstr ""
 
-#: builtin/remote.c:1049
-#, c-format
-msgid "    %-*s forces to %-*s (%s)"
+#: builtin/fetch.c:780 builtin/fetch.c:817 builtin/fetch.c:839
+#: builtin/fetch.c:851
+msgid "unable to update local ref"
 msgstr ""
 
-#: builtin/remote.c:1052
-#, c-format
-msgid "    %-*s pushes to %-*s (%s)"
+#: builtin/fetch.c:784
+msgid "would clobber existing tag"
 msgstr ""
 
-#: builtin/remote.c:1056
-#, c-format
-msgid "    %-*s forces to %s"
+#: builtin/fetch.c:806
+msgid "[new tag]"
 msgstr ""
 
-#: builtin/remote.c:1059
-#, c-format
-msgid "    %-*s pushes to %s"
+#: builtin/fetch.c:809
+msgid "[new branch]"
 msgstr ""
 
-#: builtin/remote.c:1127
-msgid "do not query remotes"
+#: builtin/fetch.c:812
+msgid "[new ref]"
 msgstr ""
 
-#: builtin/remote.c:1154
-#, c-format
-msgid "* remote %s"
+#: builtin/fetch.c:851
+msgid "forced update"
 msgstr ""
 
-#: builtin/remote.c:1155
-#, c-format
-msgid "  Fetch URL: %s"
+#: builtin/fetch.c:856
+msgid "non-fast-forward"
 msgstr ""
 
-#: builtin/remote.c:1156 builtin/remote.c:1172 builtin/remote.c:1311
-msgid "(no URL)"
+#: builtin/fetch.c:877
+msgid ""
+"Fetch normally indicates which branches had a forced update,\n"
+"but that check has been disabled. To re-enable, use '--show-forced-updates'\n"
+"flag or run 'git config fetch.showForcedUpdates true'."
 msgstr ""
 
-#. TRANSLATORS: the colon ':' should align
-#. with the one in " Fetch URL: %s"
-#. translation.
-#.
-#: builtin/remote.c:1170 builtin/remote.c:1172
+#: builtin/fetch.c:881
 #, c-format
-msgid "  Push  URL: %s"
+msgid ""
+"It took %.2f seconds to check forced updates. You can use\n"
+"'--no-show-forced-updates' or run 'git config fetch.showForcedUpdates "
+"false'\n"
+" to avoid this check.\n"
 msgstr ""
 
-#: builtin/remote.c:1174 builtin/remote.c:1176 builtin/remote.c:1178
+#: builtin/fetch.c:911
 #, c-format
-msgid "  HEAD branch: %s"
+msgid "%s did not send all necessary objects\n"
 msgstr ""
 
-#: builtin/remote.c:1174
-msgid "(not queried)"
+#: builtin/fetch.c:932
+#, c-format
+msgid "reject %s because shallow roots are not allowed to be updated"
 msgstr ""
 
-#: builtin/remote.c:1176
-msgid "(unknown)"
+#: builtin/fetch.c:1017 builtin/fetch.c:1155
+#, c-format
+msgid "From %.*s\n"
 msgstr ""
 
-#: builtin/remote.c:1180
+#: builtin/fetch.c:1028
 #, c-format
 msgid ""
-"  HEAD branch (remote HEAD is ambiguous, may be one of the following):\n"
+"some local refs could not be updated; try running\n"
+" 'git remote prune %s' to remove any old, conflicting branches"
 msgstr ""
 
-#: builtin/remote.c:1192
+#: builtin/fetch.c:1125
 #, c-format
-msgid "  Remote branch:%s"
-msgid_plural "  Remote branches:%s"
-msgstr[0] ""
-msgstr[1] ""
+msgid "   (%s will become dangling)"
+msgstr ""
 
-#: builtin/remote.c:1195 builtin/remote.c:1221
-msgid " (status not queried)"
+#: builtin/fetch.c:1126
+#, c-format
+msgid "   (%s has become dangling)"
 msgstr ""
 
-#: builtin/remote.c:1204
-msgid "  Local branch configured for 'git pull':"
-msgid_plural "  Local branches configured for 'git pull':"
-msgstr[0] ""
-msgstr[1] ""
+#: builtin/fetch.c:1158
+msgid "[deleted]"
+msgstr ""
 
-#: builtin/remote.c:1212
-msgid "  Local refs will be mirrored by 'git push'"
+#: builtin/fetch.c:1159 builtin/remote.c:1035
+msgid "(none)"
 msgstr ""
 
-#: builtin/remote.c:1218
+#: builtin/fetch.c:1182
 #, c-format
-msgid "  Local ref configured for 'git push'%s:"
-msgid_plural "  Local refs configured for 'git push'%s:"
-msgstr[0] ""
-msgstr[1] ""
-
-#: builtin/remote.c:1239
-msgid "set refs/remotes/<name>/HEAD according to remote"
+msgid "Refusing to fetch into current branch %s of non-bare repository"
 msgstr ""
 
-#: builtin/remote.c:1241
-msgid "delete refs/remotes/<name>/HEAD"
+#: builtin/fetch.c:1201
+#, c-format
+msgid "Option \"%s\" value \"%s\" is not valid for %s"
 msgstr ""
 
-#: builtin/remote.c:1256
-msgid "Cannot determine remote HEAD"
+#: builtin/fetch.c:1204
+#, c-format
+msgid "Option \"%s\" is ignored for %s\n"
 msgstr ""
 
-#: builtin/remote.c:1258
-msgid "Multiple remote HEAD branches. Please choose one explicitly with:"
+#: builtin/fetch.c:1412
+msgid "multiple branches detected, incompatible with --set-upstream"
 msgstr ""
 
-#: builtin/remote.c:1268
-#, c-format
-msgid "Could not delete %s"
+#: builtin/fetch.c:1427
+msgid "not setting upstream for a remote remote-tracking branch"
 msgstr ""
 
-#: builtin/remote.c:1276
-#, c-format
-msgid "Not a valid ref: %s"
+#: builtin/fetch.c:1429
+msgid "not setting upstream for a remote tag"
 msgstr ""
 
-#: builtin/remote.c:1278
-#, c-format
-msgid "Could not setup %s"
+#: builtin/fetch.c:1431
+msgid "unknown branch type"
 msgstr ""
 
-#: builtin/remote.c:1296
-#, c-format
-msgid " %s will become dangling!"
+#: builtin/fetch.c:1433
+msgid ""
+"no source branch found.\n"
+"you need to specify exactly one branch with the --set-upstream option."
 msgstr ""
 
-#: builtin/remote.c:1297
+#: builtin/fetch.c:1559 builtin/fetch.c:1622
 #, c-format
-msgid " %s has become dangling!"
+msgid "Fetching %s\n"
 msgstr ""
 
-#: builtin/remote.c:1307
+#: builtin/fetch.c:1569 builtin/fetch.c:1624 builtin/remote.c:100
 #, c-format
-msgid "Pruning %s"
+msgid "Could not fetch %s"
 msgstr ""
 
-#: builtin/remote.c:1308
+#: builtin/fetch.c:1581
 #, c-format
-msgid "URL: %s"
+msgid "could not fetch '%s' (exit code: %d)\n"
 msgstr ""
 
-#: builtin/remote.c:1324
-#, c-format
-msgid " * [would prune] %s"
+#: builtin/fetch.c:1684
+msgid ""
+"No remote repository specified.  Please, specify either a URL or a\n"
+"remote name from which new revisions should be fetched."
 msgstr ""
 
-#: builtin/remote.c:1327
-#, c-format
-msgid " * [pruned] %s"
+#: builtin/fetch.c:1721
+msgid "You need to specify a tag name."
 msgstr ""
 
-#: builtin/remote.c:1372
-msgid "prune remotes after fetching"
+#: builtin/fetch.c:1771
+msgid "Negative depth in --deepen is not supported"
 msgstr ""
 
-#: builtin/remote.c:1435 builtin/remote.c:1489 builtin/remote.c:1557
-#, c-format
-msgid "No such remote '%s'"
+#: builtin/fetch.c:1773
+msgid "--deepen and --depth are mutually exclusive"
 msgstr ""
 
-#: builtin/remote.c:1451
-msgid "add branch"
+#: builtin/fetch.c:1778
+msgid "--depth and --unshallow cannot be used together"
 msgstr ""
 
-#: builtin/remote.c:1458
-msgid "no remote specified"
+#: builtin/fetch.c:1780
+msgid "--unshallow on a complete repository does not make sense"
 msgstr ""
 
-#: builtin/remote.c:1475
-msgid "query push URLs rather than fetch URLs"
+#: builtin/fetch.c:1796
+msgid "fetch --all does not take a repository argument"
 msgstr ""
 
-#: builtin/remote.c:1477
-msgid "return all URLs"
+#: builtin/fetch.c:1798
+msgid "fetch --all does not make sense with refspecs"
 msgstr ""
 
-#: builtin/remote.c:1505
+#: builtin/fetch.c:1807
 #, c-format
-msgid "no URLs configured for remote '%s'"
+msgid "No such remote or remote group: %s"
 msgstr ""
 
-#: builtin/remote.c:1531
-msgid "manipulate push URLs"
+#: builtin/fetch.c:1814
+msgid "Fetching a group and specifying refspecs does not make sense"
 msgstr ""
 
-#: builtin/remote.c:1533
-msgid "add URL"
+#: builtin/fetch.c:1832
+msgid ""
+"--filter can only be used with the remote configured in extensions."
+"partialclone"
 msgstr ""
 
-#: builtin/remote.c:1535
-msgid "delete URLs"
+#: builtin/fmt-merge-msg.c:18
+msgid ""
+"git fmt-merge-msg [-m <message>] [--log[=<n>] | --no-log] [--file <file>]"
 msgstr ""
 
-#: builtin/remote.c:1542
-msgid "--add --delete doesn't make sense"
+#: builtin/fmt-merge-msg.c:674
+msgid "populate log with at most <n> entries from shortlog"
 msgstr ""
 
-#: builtin/remote.c:1581
-#, c-format
-msgid "Invalid old URL pattern: %s"
+#: builtin/fmt-merge-msg.c:677
+msgid "alias for --log (deprecated)"
 msgstr ""
 
-#: builtin/remote.c:1589
-#, c-format
-msgid "No such URL found: %s"
+#: builtin/fmt-merge-msg.c:680
+msgid "text"
 msgstr ""
 
-#: builtin/remote.c:1591
-msgid "Will not delete all non-push URLs"
+#: builtin/fmt-merge-msg.c:681
+msgid "use <text> as start of message"
 msgstr ""
 
-#: builtin/remote.c:1607
-msgid "be verbose; must be placed before a subcommand"
+#: builtin/fmt-merge-msg.c:682
+msgid "file to read from"
 msgstr ""
 
-#: builtin/remote.c:1638
-#, c-format
-msgid "Unknown subcommand: %s"
+#: builtin/for-each-ref.c:10
+msgid "git for-each-ref [<options>] [<pattern>]"
 msgstr ""
 
-#: builtin/repack.c:18
-msgid "git repack [<options>]"
+#: builtin/for-each-ref.c:11
+msgid "git for-each-ref [--points-at <object>]"
 msgstr ""
 
-#: builtin/repack.c:23
-msgid ""
-"Incremental repacks are incompatible with bitmap indexes.  Use\n"
-"--no-write-bitmap-index or disable the pack.writebitmaps configuration."
+#: builtin/for-each-ref.c:12
+msgid "git for-each-ref [(--merged | --no-merged) [<commit>]]"
 msgstr ""
 
-#: builtin/repack.c:180
-msgid "pack everything in a single pack"
+#: builtin/for-each-ref.c:13
+msgid "git for-each-ref [--contains [<commit>]] [--no-contains [<commit>]]"
 msgstr ""
 
-#: builtin/repack.c:182
-msgid "same as -a, and turn unreachable objects loose"
+#: builtin/for-each-ref.c:28
+msgid "quote placeholders suitably for shells"
 msgstr ""
 
-#: builtin/repack.c:185
-msgid "remove redundant packs, and run git-prune-packed"
+#: builtin/for-each-ref.c:30
+msgid "quote placeholders suitably for perl"
 msgstr ""
 
-#: builtin/repack.c:187
-msgid "pass --no-reuse-delta to git-pack-objects"
+#: builtin/for-each-ref.c:32
+msgid "quote placeholders suitably for python"
 msgstr ""
 
-#: builtin/repack.c:189
-msgid "pass --no-reuse-object to git-pack-objects"
+#: builtin/for-each-ref.c:34
+msgid "quote placeholders suitably for Tcl"
 msgstr ""
 
-#: builtin/repack.c:191
-msgid "do not run git-update-server-info"
+#: builtin/for-each-ref.c:37
+msgid "show only <n> matched refs"
 msgstr ""
 
-#: builtin/repack.c:194
-msgid "pass --local to git-pack-objects"
+#: builtin/for-each-ref.c:39 builtin/tag.c:439
+msgid "respect format colors"
 msgstr ""
 
-#: builtin/repack.c:196
-msgid "write bitmap index"
+#: builtin/for-each-ref.c:42
+msgid "print only refs which points at the given object"
 msgstr ""
 
-#: builtin/repack.c:197
-msgid "approxidate"
+#: builtin/for-each-ref.c:44
+msgid "print only refs that are merged"
 msgstr ""
 
-#: builtin/repack.c:198
-msgid "with -A, do not loosen objects older than this"
+#: builtin/for-each-ref.c:45
+msgid "print only refs that are not merged"
 msgstr ""
 
-#: builtin/repack.c:200
-msgid "with -a, repack unreachable objects"
+#: builtin/for-each-ref.c:46
+msgid "print only refs which contain the commit"
 msgstr ""
 
-#: builtin/repack.c:202
-msgid "size of the window used for delta compression"
+#: builtin/for-each-ref.c:47
+msgid "print only refs which don't contain the commit"
 msgstr ""
 
-#: builtin/repack.c:203 builtin/repack.c:209
-msgid "bytes"
+#: builtin/fsck.c:68 builtin/fsck.c:147 builtin/fsck.c:148
+msgid "unknown"
 msgstr ""
 
-#: builtin/repack.c:204
-msgid "same as the above, but limit memory size instead of entries count"
+#. TRANSLATORS: e.g. error in tree 01bfda: <more explanation>
+#: builtin/fsck.c:100 builtin/fsck.c:120
+#, c-format
+msgid "error in %s %s: %s"
 msgstr ""
 
-#: builtin/repack.c:206
-msgid "limits the maximum delta depth"
+#. TRANSLATORS: e.g. warning in tree 01bfda: <more explanation>
+#: builtin/fsck.c:114
+#, c-format
+msgid "warning in %s %s: %s"
 msgstr ""
 
-#: builtin/repack.c:208
-msgid "limits the maximum number of threads"
+#: builtin/fsck.c:143 builtin/fsck.c:146
+#, c-format
+msgid "broken link from %7s %s"
 msgstr ""
 
-#: builtin/repack.c:210
-msgid "maximum size of each packfile"
+#: builtin/fsck.c:155
+msgid "wrong object type in link"
 msgstr ""
 
-#: builtin/repack.c:212
-msgid "repack objects in packs marked with .keep"
+#: builtin/fsck.c:171
+#, c-format
+msgid ""
+"broken link from %7s %s\n"
+"              to %7s %s"
 msgstr ""
 
-#: builtin/repack.c:214
-msgid "do not repack this pack"
+#: builtin/fsck.c:282
+#, c-format
+msgid "missing %s %s"
 msgstr ""
 
-#: builtin/repack.c:224
-msgid "cannot delete packs in a precious-objects repo"
+#: builtin/fsck.c:309
+#, c-format
+msgid "unreachable %s %s"
 msgstr ""
 
-#: builtin/repack.c:228
-msgid "--keep-unreachable and -A are incompatible"
+#: builtin/fsck.c:329
+#, c-format
+msgid "dangling %s %s"
+msgstr ""
+
+#: builtin/fsck.c:339
+msgid "could not create lost-found"
 msgstr ""
 
-#: builtin/repack.c:425 builtin/worktree.c:139
+#: builtin/fsck.c:350
 #, c-format
-msgid "failed to remove '%s'"
+msgid "could not finish '%s'"
 msgstr ""
 
-#: builtin/replace.c:22
-msgid "git replace [-f] <object> <replacement>"
+#: builtin/fsck.c:367
+#, c-format
+msgid "Checking %s"
 msgstr ""
 
-#: builtin/replace.c:23
-msgid "git replace [-f] --edit <object>"
+#: builtin/fsck.c:405
+#, c-format
+msgid "Checking connectivity (%d objects)"
 msgstr ""
 
-#: builtin/replace.c:24
-msgid "git replace [-f] --graft <commit> [<parent>...]"
+#: builtin/fsck.c:424
+#, c-format
+msgid "Checking %s %s"
 msgstr ""
 
-#: builtin/replace.c:25
-msgid "git replace [-f] --convert-graft-file"
+#: builtin/fsck.c:429
+msgid "broken links"
 msgstr ""
 
-#: builtin/replace.c:26
-msgid "git replace -d <object>..."
+#: builtin/fsck.c:438
+#, c-format
+msgid "root %s"
 msgstr ""
 
-#: builtin/replace.c:27
-msgid "git replace [--format=<format>] [-l [<pattern>]]"
+#: builtin/fsck.c:446
+#, c-format
+msgid "tagged %s %s (%s) in %s"
 msgstr ""
 
-#: builtin/replace.c:371 builtin/replace.c:415 builtin/replace.c:445
+#: builtin/fsck.c:475
 #, c-format
-msgid "Not a valid object name: '%s'"
+msgid "%s: object corrupt or missing"
 msgstr ""
 
-#: builtin/replace.c:407
+#: builtin/fsck.c:500
 #, c-format
-msgid "bad mergetag in commit '%s'"
+msgid "%s: invalid reflog entry %s"
 msgstr ""
 
-#: builtin/replace.c:409
+#: builtin/fsck.c:514
 #, c-format
-msgid "malformed mergetag in commit '%s'"
+msgid "Checking reflog %s->%s"
 msgstr ""
 
-#: builtin/replace.c:421
+#: builtin/fsck.c:548
 #, c-format
-msgid ""
-"original commit '%s' contains mergetag '%s' that is discarded; use --edit "
-"instead of --graft"
+msgid "%s: invalid sha1 pointer %s"
 msgstr ""
 
-#: builtin/replace.c:460
+#: builtin/fsck.c:555
 #, c-format
-msgid "the original commit '%s' has a gpg signature."
+msgid "%s: not a commit"
 msgstr ""
 
-#: builtin/replace.c:461
-msgid "the signature will be removed in the replacement commit!"
+#: builtin/fsck.c:609
+msgid "notice: No default references"
 msgstr ""
 
-#: builtin/replace.c:471
+#: builtin/fsck.c:624
 #, c-format
-msgid "could not write replacement commit for: '%s'"
+msgid "%s: object corrupt or missing: %s"
 msgstr ""
 
-#: builtin/replace.c:514
+#: builtin/fsck.c:637
 #, c-format
-msgid ""
-"could not convert the following graft(s):\n"
-"%s"
+msgid "%s: object could not be parsed: %s"
 msgstr ""
 
-#: builtin/replace.c:535
-msgid "list replace refs"
+#: builtin/fsck.c:657
+#, c-format
+msgid "bad sha1 file: %s"
 msgstr ""
 
-#: builtin/replace.c:536
-msgid "delete replace refs"
+#: builtin/fsck.c:672
+msgid "Checking object directory"
 msgstr ""
 
-#: builtin/replace.c:537
-msgid "edit existing object"
+#: builtin/fsck.c:675
+msgid "Checking object directories"
 msgstr ""
 
-#: builtin/replace.c:538
-msgid "change a commit's parents"
+#: builtin/fsck.c:690
+#, c-format
+msgid "Checking %s link"
 msgstr ""
 
-#: builtin/replace.c:539
-msgid "convert existing graft file"
+#: builtin/fsck.c:695 builtin/index-pack.c:842
+#, c-format
+msgid "invalid %s"
 msgstr ""
 
-#: builtin/replace.c:540
-msgid "replace the ref if it exists"
+#: builtin/fsck.c:702
+#, c-format
+msgid "%s points to something strange (%s)"
 msgstr ""
 
-#: builtin/replace.c:542
-msgid "do not pretty-print contents for --edit"
+#: builtin/fsck.c:708
+#, c-format
+msgid "%s: detached HEAD points at nothing"
 msgstr ""
 
-#: builtin/replace.c:543
-msgid "use this format"
+#: builtin/fsck.c:712
+#, c-format
+msgid "notice: %s points to an unborn branch (%s)"
 msgstr ""
 
-#: builtin/rerere.c:13
-msgid "git rerere [clear | forget <path>... | status | remaining | diff | gc]"
+#: builtin/fsck.c:724
+msgid "Checking cache tree"
 msgstr ""
 
-#: builtin/rerere.c:59
-msgid "register clean resolutions in index"
+#: builtin/fsck.c:729
+#, c-format
+msgid "%s: invalid sha1 pointer in cache-tree"
 msgstr ""
 
-#: builtin/reset.c:29
-msgid ""
-"git reset [--mixed | --soft | --hard | --merge | --keep] [-q] [<commit>]"
+#: builtin/fsck.c:738
+msgid "non-tree in cache-tree"
 msgstr ""
 
-#: builtin/reset.c:30
-msgid "git reset [-q] [<tree-ish>] [--] <paths>..."
+#: builtin/fsck.c:769
+msgid "git fsck [<options>] [<object>...]"
 msgstr ""
 
-#: builtin/reset.c:31
-msgid "git reset --patch [<tree-ish>] [--] [<paths>...]"
+#: builtin/fsck.c:775
+msgid "show unreachable objects"
 msgstr ""
 
-#: builtin/reset.c:37
-msgid "mixed"
+#: builtin/fsck.c:776
+msgid "show dangling objects"
 msgstr ""
 
-#: builtin/reset.c:37
-msgid "soft"
+#: builtin/fsck.c:777
+msgid "report tags"
 msgstr ""
 
-#: builtin/reset.c:37
-msgid "hard"
+#: builtin/fsck.c:778
+msgid "report root nodes"
 msgstr ""
 
-#: builtin/reset.c:37
-msgid "merge"
+#: builtin/fsck.c:779
+msgid "make index objects head nodes"
 msgstr ""
 
-#: builtin/reset.c:37
-msgid "keep"
+#: builtin/fsck.c:780
+msgid "make reflogs head nodes (default)"
 msgstr ""
 
-#: builtin/reset.c:78
-msgid "You do not have a valid HEAD."
+#: builtin/fsck.c:781
+msgid "also consider packs and alternate objects"
 msgstr ""
 
-#: builtin/reset.c:80
-msgid "Failed to find tree of HEAD."
+#: builtin/fsck.c:782
+msgid "check only connectivity"
+msgstr ""
+
+#: builtin/fsck.c:783
+msgid "enable more strict checking"
+msgstr ""
+
+#: builtin/fsck.c:785
+msgid "write dangling objects in .git/lost-found"
+msgstr ""
+
+#: builtin/fsck.c:786 builtin/prune.c:132
+msgid "show progress"
 msgstr ""
 
-#: builtin/reset.c:86
+#: builtin/fsck.c:787
+msgid "show verbose names for reachable objects"
+msgstr ""
+
+#: builtin/fsck.c:846 builtin/index-pack.c:225
+msgid "Checking objects"
+msgstr ""
+
+#: builtin/fsck.c:874
 #, c-format
-msgid "Failed to find tree of %s."
+msgid "%s: object missing"
 msgstr ""
 
-#: builtin/reset.c:111
+#: builtin/fsck.c:885
 #, c-format
-msgid "HEAD is now at %s"
+msgid "invalid parameter: expected sha1, got '%s'"
 msgstr ""
 
-#: builtin/reset.c:189
+#: builtin/gc.c:35
+msgid "git gc [<options>]"
+msgstr ""
+
+#: builtin/gc.c:90
 #, c-format
-msgid "Cannot do a %s reset in the middle of a merge."
+msgid "Failed to fstat %s: %s"
 msgstr ""
 
-#: builtin/reset.c:289
-msgid "be quiet, only report errors"
+#: builtin/gc.c:126
+#, c-format
+msgid "failed to parse '%s' value '%s'"
 msgstr ""
 
-#: builtin/reset.c:291
-msgid "reset HEAD and index"
+#: builtin/gc.c:475 builtin/init-db.c:55
+#, c-format
+msgid "cannot stat '%s'"
 msgstr ""
 
-#: builtin/reset.c:292
-msgid "reset only HEAD"
+#: builtin/gc.c:484 builtin/notes.c:240 builtin/tag.c:529
+#, c-format
+msgid "cannot read '%s'"
 msgstr ""
 
-#: builtin/reset.c:294 builtin/reset.c:296
-msgid "reset HEAD, index and working tree"
+#: builtin/gc.c:491
+#, c-format
+msgid ""
+"The last gc run reported the following. Please correct the root cause\n"
+"and remove %s.\n"
+"Automatic cleanup will not be performed until the file is removed.\n"
+"\n"
+"%s"
 msgstr ""
 
-#: builtin/reset.c:298
-msgid "reset HEAD but keep local changes"
+#: builtin/gc.c:539
+msgid "prune unreferenced objects"
 msgstr ""
 
-#: builtin/reset.c:304
-msgid "record only the fact that removed paths will be added later"
+#: builtin/gc.c:541
+msgid "be more thorough (increased runtime)"
+msgstr ""
+
+#: builtin/gc.c:542
+msgid "enable auto-gc mode"
+msgstr ""
+
+#: builtin/gc.c:545
+msgid "force running gc even if there may be another gc running"
 msgstr ""
 
-#: builtin/reset.c:321
+#: builtin/gc.c:548
+msgid "repack all other packs except the largest pack"
+msgstr ""
+
+#: builtin/gc.c:565
 #, c-format
-msgid "Failed to resolve '%s' as a valid revision."
+msgid "failed to parse gc.logexpiry value %s"
 msgstr ""
 
-#: builtin/reset.c:329
+#: builtin/gc.c:576
 #, c-format
-msgid "Failed to resolve '%s' as a valid tree."
+msgid "failed to parse prune expiry value %s"
 msgstr ""
 
-#: builtin/reset.c:338
-msgid "--patch is incompatible with --{hard,mixed,soft}"
+#: builtin/gc.c:596
+#, c-format
+msgid "Auto packing the repository in background for optimum performance.\n"
 msgstr ""
 
-#: builtin/reset.c:347
-msgid "--mixed with paths is deprecated; use 'git reset -- <paths>' instead."
+#: builtin/gc.c:598
+#, c-format
+msgid "Auto packing the repository for optimum performance.\n"
 msgstr ""
 
-#: builtin/reset.c:349
+#: builtin/gc.c:599
 #, c-format
-msgid "Cannot do %s reset with paths."
+msgid "See \"git help gc\" for manual housekeeping.\n"
 msgstr ""
 
-#: builtin/reset.c:359
+#: builtin/gc.c:639
 #, c-format
-msgid "%s reset is not allowed in a bare repository"
+msgid ""
+"gc is already running on machine '%s' pid %<PRIuMAX> (use --force if not)"
 msgstr ""
 
-#: builtin/reset.c:363
-msgid "-N can only be used with --mixed"
+#: builtin/gc.c:694
+msgid ""
+"There are too many unreachable loose objects; run 'git prune' to remove them."
 msgstr ""
 
-#: builtin/reset.c:380
-msgid "Unstaged changes after reset:"
+#: builtin/grep.c:29
+msgid "git grep [<options>] [-e] <pattern> [<rev>...] [[--] <path>...]"
 msgstr ""
 
-#: builtin/reset.c:386
+#: builtin/grep.c:225
 #, c-format
-msgid "Could not reset index file to revision '%s'."
+msgid "grep: failed to create thread: %s"
 msgstr ""
 
-#: builtin/reset.c:390
-msgid "Could not write new index file."
+#: builtin/grep.c:279
+#, c-format
+msgid "invalid number of threads specified (%d) for %s"
 msgstr ""
 
-#: builtin/rev-list.c:397
-msgid "cannot combine --exclude-promisor-objects and --missing"
+#. TRANSLATORS: %s is the configuration
+#. variable for tweaking threads, currently
+#. grep.threads
+#.
+#: builtin/grep.c:287 builtin/index-pack.c:1534 builtin/index-pack.c:1727
+#: builtin/pack-objects.c:2708
+#, c-format
+msgid "no threads support, ignoring %s"
 msgstr ""
 
-#: builtin/rev-list.c:455
-msgid "object filtering requires --objects"
+#: builtin/grep.c:467 builtin/grep.c:592 builtin/grep.c:635
+#, c-format
+msgid "unable to read tree (%s)"
 msgstr ""
 
-#: builtin/rev-list.c:458
+#: builtin/grep.c:650
 #, c-format
-msgid "invalid sparse value '%s'"
+msgid "unable to grep from object of type %s"
 msgstr ""
 
-#: builtin/rev-list.c:499
-msgid "rev-list does not support display of notes"
+#: builtin/grep.c:716
+#, c-format
+msgid "switch `%c' expects a numerical value"
 msgstr ""
 
-#: builtin/rev-list.c:502
-msgid "cannot combine --use-bitmap-index with object filtering"
+#: builtin/grep.c:815
+msgid "search in index instead of in the work tree"
 msgstr ""
 
-#: builtin/rev-parse.c:406
-msgid "git rev-parse --parseopt [<options>] -- [<args>...]"
+#: builtin/grep.c:817
+msgid "find in contents not managed by git"
 msgstr ""
 
-#: builtin/rev-parse.c:411
-msgid "keep the `--` passed as an arg"
+#: builtin/grep.c:819
+msgid "search in both tracked and untracked files"
 msgstr ""
 
-#: builtin/rev-parse.c:413
-msgid "stop parsing after the first non-option argument"
+#: builtin/grep.c:821
+msgid "ignore files specified via '.gitignore'"
 msgstr ""
 
-#: builtin/rev-parse.c:416
-msgid "output in stuck long form"
+#: builtin/grep.c:823
+msgid "recursively search in each submodule"
 msgstr ""
 
-#: builtin/rev-parse.c:549
-msgid ""
-"git rev-parse --parseopt [<options>] -- [<args>...]\n"
-"   or: git rev-parse --sq-quote [<arg>...]\n"
-"   or: git rev-parse [<options>] [<arg>...]\n"
-"\n"
-"Run \"git rev-parse --parseopt -h\" for more information on the first usage."
+#: builtin/grep.c:826
+msgid "show non-matching lines"
 msgstr ""
 
-#: builtin/revert.c:23
-msgid "git revert [<options>] <commit-ish>..."
+#: builtin/grep.c:828
+msgid "case insensitive matching"
 msgstr ""
 
-#: builtin/revert.c:24
-msgid "git revert <subcommand>"
+#: builtin/grep.c:830
+msgid "match patterns only at word boundaries"
 msgstr ""
 
-#: builtin/revert.c:29
-msgid "git cherry-pick [<options>] <commit-ish>..."
+#: builtin/grep.c:832
+msgid "process binary files as text"
 msgstr ""
 
-#: builtin/revert.c:30
-msgid "git cherry-pick <subcommand>"
+#: builtin/grep.c:834
+msgid "don't match patterns in binary files"
 msgstr ""
 
-#: builtin/revert.c:90
-#, c-format
-msgid "%s: %s cannot be used with %s"
+#: builtin/grep.c:837
+msgid "process binary files with textconv filters"
 msgstr ""
 
-#: builtin/revert.c:99
-msgid "end revert or cherry-pick sequence"
+#: builtin/grep.c:839
+msgid "search in subdirectories (default)"
 msgstr ""
 
-#: builtin/revert.c:100
-msgid "resume revert or cherry-pick sequence"
+#: builtin/grep.c:841
+msgid "descend at most <depth> levels"
 msgstr ""
 
-#: builtin/revert.c:101
-msgid "cancel revert or cherry-pick sequence"
+#: builtin/grep.c:845
+msgid "use extended POSIX regular expressions"
 msgstr ""
 
-#: builtin/revert.c:102
-msgid "don't automatically commit"
+#: builtin/grep.c:848
+msgid "use basic POSIX regular expressions (default)"
 msgstr ""
 
-#: builtin/revert.c:103
-msgid "edit the commit message"
+#: builtin/grep.c:851
+msgid "interpret patterns as fixed strings"
 msgstr ""
 
-#: builtin/revert.c:106
-msgid "parent-number"
+#: builtin/grep.c:854
+msgid "use Perl-compatible regular expressions"
 msgstr ""
 
-#: builtin/revert.c:107
-msgid "select mainline parent"
+#: builtin/grep.c:857
+msgid "show line numbers"
 msgstr ""
 
-#: builtin/revert.c:109
-msgid "merge strategy"
+#: builtin/grep.c:858
+msgid "show column number of first match"
 msgstr ""
 
-#: builtin/revert.c:110
-msgid "option"
+#: builtin/grep.c:859
+msgid "don't show filenames"
 msgstr ""
 
-#: builtin/revert.c:111
-msgid "option for merge strategy"
+#: builtin/grep.c:860
+msgid "show filenames"
 msgstr ""
 
-#: builtin/revert.c:120
-msgid "append commit name"
+#: builtin/grep.c:862
+msgid "show filenames relative to top directory"
 msgstr ""
 
-#: builtin/revert.c:122
-msgid "preserve initially empty commits"
+#: builtin/grep.c:864
+msgid "show only filenames instead of matching lines"
 msgstr ""
 
-#: builtin/revert.c:124
-msgid "keep redundant, empty commits"
+#: builtin/grep.c:866
+msgid "synonym for --files-with-matches"
 msgstr ""
 
-#: builtin/revert.c:214
-msgid "revert failed"
+#: builtin/grep.c:869
+msgid "show only the names of files without match"
 msgstr ""
 
-#: builtin/revert.c:227
-msgid "cherry-pick failed"
+#: builtin/grep.c:871
+msgid "print NUL after filenames"
 msgstr ""
 
-#: builtin/rm.c:18
-msgid "git rm [<options>] [--] <file>..."
+#: builtin/grep.c:874
+msgid "show only matching parts of a line"
 msgstr ""
 
-#: builtin/rm.c:206
-msgid ""
-"the following file has staged content different from both the\n"
-"file and the HEAD:"
-msgid_plural ""
-"the following files have staged content different from both the\n"
-"file and the HEAD:"
-msgstr[0] ""
-msgstr[1] ""
-
-#: builtin/rm.c:211
-msgid ""
-"\n"
-"(use -f to force removal)"
+#: builtin/grep.c:876
+msgid "show the number of matches instead of matching lines"
 msgstr ""
 
-#: builtin/rm.c:215
-msgid "the following file has changes staged in the index:"
-msgid_plural "the following files have changes staged in the index:"
-msgstr[0] ""
-msgstr[1] ""
-
-#: builtin/rm.c:219 builtin/rm.c:228
-msgid ""
-"\n"
-"(use --cached to keep the file, or -f to force removal)"
+#: builtin/grep.c:877
+msgid "highlight matches"
 msgstr ""
 
-#: builtin/rm.c:225
-msgid "the following file has local modifications:"
-msgid_plural "the following files have local modifications:"
-msgstr[0] ""
-msgstr[1] ""
+#: builtin/grep.c:879
+msgid "print empty line between matches from different files"
+msgstr ""
 
-#: builtin/rm.c:241
-msgid "do not list removed files"
+#: builtin/grep.c:881
+msgid "show filename only once above matches from same file"
 msgstr ""
 
-#: builtin/rm.c:242
-msgid "only remove from the index"
+#: builtin/grep.c:884
+msgid "show <n> context lines before and after matches"
 msgstr ""
 
-#: builtin/rm.c:243
-msgid "override the up-to-date check"
+#: builtin/grep.c:887
+msgid "show <n> context lines before matches"
 msgstr ""
 
-#: builtin/rm.c:244
-msgid "allow recursive removal"
+#: builtin/grep.c:889
+msgid "show <n> context lines after matches"
 msgstr ""
 
-#: builtin/rm.c:246
-msgid "exit with a zero status even if nothing matched"
+#: builtin/grep.c:891
+msgid "use <n> worker threads"
 msgstr ""
 
-#: builtin/rm.c:306
-#, c-format
-msgid "not removing '%s' recursively without -r"
+#: builtin/grep.c:892
+msgid "shortcut for -C NUM"
 msgstr ""
 
-#: builtin/rm.c:345
-#, c-format
-msgid "git rm: unable to remove %s"
+#: builtin/grep.c:895
+msgid "show a line with the function name before matches"
 msgstr ""
 
-#: builtin/rm.c:368
-#, c-format
-msgid "could not remove '%s'"
+#: builtin/grep.c:897
+msgid "show the surrounding function"
 msgstr ""
 
-#: builtin/send-pack.c:20
-msgid ""
-"git send-pack [--all | --mirror] [--dry-run] [--force] [--receive-pack=<git-"
-"receive-pack>] [--verbose] [--thin] [--atomic] [<host>:]<directory> "
-"[<ref>...]\n"
-"  --all and explicit <ref> specification are mutually exclusive."
+#: builtin/grep.c:900
+msgid "read patterns from file"
 msgstr ""
 
-#: builtin/send-pack.c:163
-msgid "remote name"
+#: builtin/grep.c:902
+msgid "match <pattern>"
 msgstr ""
 
-#: builtin/send-pack.c:177
-msgid "use stateless RPC protocol"
+#: builtin/grep.c:904
+msgid "combine patterns specified with -e"
 msgstr ""
 
-#: builtin/send-pack.c:178
-msgid "read refs from stdin"
+#: builtin/grep.c:916
+msgid "indicate hit with exit status without output"
 msgstr ""
 
-#: builtin/send-pack.c:179
-msgid "print status from remote helper"
+#: builtin/grep.c:918
+msgid "show only matches from files that match all patterns"
 msgstr ""
 
-#: builtin/serve.c:7
-msgid "git serve [<options>]"
+#: builtin/grep.c:920
+msgid "show parse tree for grep expression"
 msgstr ""
 
-#: builtin/serve.c:17 builtin/upload-pack.c:23
-msgid "quit after a single request/response exchange"
+#: builtin/grep.c:924
+msgid "pager"
 msgstr ""
 
-#: builtin/serve.c:19
-msgid "exit immediately after advertising capabilities"
+#: builtin/grep.c:924
+msgid "show matching files in the pager"
 msgstr ""
 
-#: builtin/shortlog.c:14
-msgid "git shortlog [<options>] [<revision-range>] [[--] <path>...]"
+#: builtin/grep.c:928
+msgid "allow calling of grep(1) (ignored by this build)"
 msgstr ""
 
-#: builtin/shortlog.c:15
-msgid "git log --pretty=short | git shortlog [<options>]"
+#: builtin/grep.c:992
+msgid "no pattern given"
 msgstr ""
 
-#: builtin/shortlog.c:264
-msgid "Group by committer rather than author"
+#: builtin/grep.c:1028
+msgid "--no-index or --untracked cannot be used with revs"
 msgstr ""
 
-#: builtin/shortlog.c:266
-msgid "sort output according to the number of commits per author"
+#: builtin/grep.c:1036
+#, c-format
+msgid "unable to resolve revision: %s"
 msgstr ""
 
-#: builtin/shortlog.c:268
-msgid "Suppress commit descriptions, only provides commit count"
+#: builtin/grep.c:1067
+msgid "invalid option combination, ignoring --threads"
 msgstr ""
 
-#: builtin/shortlog.c:270
-msgid "Show the email address of each author"
+#: builtin/grep.c:1070 builtin/pack-objects.c:3400
+msgid "no threads support, ignoring --threads"
 msgstr ""
 
-#: builtin/shortlog.c:271
-msgid "w[,i1[,i2]]"
+#: builtin/grep.c:1073 builtin/index-pack.c:1531 builtin/pack-objects.c:2705
+#, c-format
+msgid "invalid number of threads specified (%d)"
 msgstr ""
 
-#: builtin/shortlog.c:272
-msgid "Linewrap output"
+#: builtin/grep.c:1096
+msgid "--open-files-in-pager only works on the worktree"
 msgstr ""
 
-#: builtin/shortlog.c:298
-msgid "too many arguments given outside repository"
+#: builtin/grep.c:1119
+msgid "option not supported with --recurse-submodules"
 msgstr ""
 
-#: builtin/show-branch.c:12
-msgid ""
-"git show-branch [-a | --all] [-r | --remotes] [--topo-order | --date-order]\n"
-"\t\t[--current] [--color[=<when>] | --no-color] [--sparse]\n"
-"\t\t[--more=<n> | --list | --independent | --merge-base]\n"
-"\t\t[--no-name | --sha1-name] [--topics] [(<rev> | <glob>)...]"
+#: builtin/grep.c:1125
+msgid "--cached or --untracked cannot be used with --no-index"
 msgstr ""
 
-#: builtin/show-branch.c:16
-msgid "git show-branch (-g | --reflog)[=<n>[,<base>]] [--list] [<ref>]"
+#: builtin/grep.c:1131
+msgid "--[no-]exclude-standard cannot be used for tracked contents"
 msgstr ""
 
-#: builtin/show-branch.c:376
-#, c-format
-msgid "ignoring %s; cannot handle more than %d ref"
-msgid_plural "ignoring %s; cannot handle more than %d refs"
-msgstr[0] ""
-msgstr[1] ""
+#: builtin/grep.c:1139
+msgid "both --cached and trees are given"
+msgstr ""
 
-#: builtin/show-branch.c:530
-#, c-format
-msgid "no matching refs with %s"
+#: builtin/hash-object.c:85
+msgid ""
+"git hash-object [-t <type>] [-w] [--path=<file> | --no-filters] [--stdin] "
+"[--] <file>..."
 msgstr ""
 
-#: builtin/show-branch.c:626
-msgid "show remote-tracking and local branches"
+#: builtin/hash-object.c:86
+msgid "git hash-object  --stdin-paths"
 msgstr ""
 
-#: builtin/show-branch.c:628
-msgid "show remote-tracking branches"
+#: builtin/hash-object.c:98
+msgid "object type"
 msgstr ""
 
-#: builtin/show-branch.c:630
-msgid "color '*!+-' corresponding to the branch"
+#: builtin/hash-object.c:99
+msgid "write the object into the object database"
 msgstr ""
 
-#: builtin/show-branch.c:632
-msgid "show <n> more commits after the common ancestor"
+#: builtin/hash-object.c:101
+msgid "read the object from stdin"
 msgstr ""
 
-#: builtin/show-branch.c:634
-msgid "synonym to more=-1"
+#: builtin/hash-object.c:103
+msgid "store file as is without filters"
 msgstr ""
 
-#: builtin/show-branch.c:635
-msgid "suppress naming strings"
+#: builtin/hash-object.c:104
+msgid ""
+"just hash any random garbage to create corrupt objects for debugging Git"
 msgstr ""
 
-#: builtin/show-branch.c:637
-msgid "include the current branch"
+#: builtin/hash-object.c:105
+msgid "process file as it were from this path"
 msgstr ""
 
-#: builtin/show-branch.c:639
-msgid "name commits with their object names"
+#: builtin/help.c:46
+msgid "print all available commands"
 msgstr ""
 
-#: builtin/show-branch.c:641
-msgid "show possible merge bases"
+#: builtin/help.c:47
+msgid "exclude guides"
 msgstr ""
 
-#: builtin/show-branch.c:643
-msgid "show refs unreachable from any other ref"
+#: builtin/help.c:48
+msgid "print list of useful guides"
 msgstr ""
 
-#: builtin/show-branch.c:645
-msgid "show commits in topological order"
+#: builtin/help.c:49
+msgid "print all configuration variable names"
 msgstr ""
 
-#: builtin/show-branch.c:648
-msgid "show only commits not on the first branch"
+#: builtin/help.c:51
+msgid "show man page"
 msgstr ""
 
-#: builtin/show-branch.c:650
-msgid "show merges reachable from only one tip"
+#: builtin/help.c:52
+msgid "show manual in web browser"
 msgstr ""
 
-#: builtin/show-branch.c:652
-msgid "topologically sort, maintaining date order where possible"
+#: builtin/help.c:54
+msgid "show info page"
 msgstr ""
 
-#: builtin/show-branch.c:655
-msgid "<n>[,<base>]"
+#: builtin/help.c:56
+msgid "print command description"
 msgstr ""
 
-#: builtin/show-branch.c:656
-msgid "show <n> most recent ref-log entries starting at base"
+#: builtin/help.c:61
+msgid "git help [--all] [--guides] [--man | --web | --info] [<command>]"
 msgstr ""
 
-#: builtin/show-branch.c:690
-msgid ""
-"--reflog is incompatible with --all, --remotes, --independent or --merge-base"
+#: builtin/help.c:77
+#, c-format
+msgid "unrecognized help format '%s'"
 msgstr ""
 
-#: builtin/show-branch.c:714
-msgid "no branches given, and HEAD is not valid"
+#: builtin/help.c:104
+msgid "Failed to start emacsclient."
 msgstr ""
 
-#: builtin/show-branch.c:717
-msgid "--reflog option needs one branch name"
+#: builtin/help.c:117
+msgid "Failed to parse emacsclient version."
 msgstr ""
 
-#: builtin/show-branch.c:720
+#: builtin/help.c:125
 #, c-format
-msgid "only %d entry can be shown at one time."
-msgid_plural "only %d entries can be shown at one time."
-msgstr[0] ""
-msgstr[1] ""
+msgid "emacsclient version '%d' too old (< 22)."
+msgstr ""
 
-#: builtin/show-branch.c:724
+#: builtin/help.c:143 builtin/help.c:165 builtin/help.c:175 builtin/help.c:183
 #, c-format
-msgid "no such ref %s"
+msgid "failed to exec '%s'"
 msgstr ""
 
-#: builtin/show-branch.c:808
+#: builtin/help.c:221
 #, c-format
-msgid "cannot handle more than %d rev."
-msgid_plural "cannot handle more than %d revs."
-msgstr[0] ""
-msgstr[1] ""
+msgid ""
+"'%s': path for unsupported man viewer.\n"
+"Please consider using 'man.<tool>.cmd' instead."
+msgstr ""
 
-#: builtin/show-branch.c:812
+#: builtin/help.c:233
 #, c-format
-msgid "'%s' is not a valid ref."
+msgid ""
+"'%s': cmd for supported man viewer.\n"
+"Please consider using 'man.<tool>.path' instead."
 msgstr ""
 
-#: builtin/show-branch.c:815
+#: builtin/help.c:350
 #, c-format
-msgid "cannot find commit %s (%s)"
+msgid "'%s': unknown man viewer."
 msgstr ""
 
-#: builtin/show-ref.c:10
-msgid ""
-"git show-ref [-q | --quiet] [--verify] [--head] [-d | --dereference] [-s | --"
-"hash[=<n>]] [--abbrev[=<n>]] [--tags] [--heads] [--] [<pattern>...]"
+#: builtin/help.c:367
+msgid "no man viewer handled the request"
 msgstr ""
 
-#: builtin/show-ref.c:11
-msgid "git show-ref --exclude-existing[=<pattern>]"
+#: builtin/help.c:375
+msgid "no info viewer handled the request"
 msgstr ""
 
-#: builtin/show-ref.c:159
-msgid "only show tags (can be combined with heads)"
+#: builtin/help.c:434 builtin/help.c:445 git.c:336
+#, c-format
+msgid "'%s' is aliased to '%s'"
 msgstr ""
 
-#: builtin/show-ref.c:160
-msgid "only show heads (can be combined with tags)"
+#: builtin/help.c:448 git.c:365
+#, c-format
+msgid "bad alias.%s string: %s"
 msgstr ""
 
-#: builtin/show-ref.c:161
-msgid "stricter reference checking, requires exact ref path"
+#: builtin/help.c:477 builtin/help.c:507
+#, c-format
+msgid "usage: %s%s"
 msgstr ""
 
-#: builtin/show-ref.c:164 builtin/show-ref.c:166
-msgid "show the HEAD reference, even if it would be filtered out"
+#: builtin/help.c:491
+msgid "'git help config' for more information"
 msgstr ""
 
-#: builtin/show-ref.c:168
-msgid "dereference tags into object IDs"
+#: builtin/index-pack.c:185
+#, c-format
+msgid "object type mismatch at %s"
 msgstr ""
 
-#: builtin/show-ref.c:170
-msgid "only show SHA1 hash using <n> digits"
+#: builtin/index-pack.c:205
+#, c-format
+msgid "did not receive expected object %s"
 msgstr ""
 
-#: builtin/show-ref.c:174
-msgid "do not print results to stdout (useful with --verify)"
+#: builtin/index-pack.c:208
+#, c-format
+msgid "object %s: expected type %s, found %s"
 msgstr ""
 
-#: builtin/show-ref.c:176
-msgid "show refs from stdin that aren't in local repository"
-msgstr ""
+#: builtin/index-pack.c:258
+#, c-format
+msgid "cannot fill %d byte"
+msgid_plural "cannot fill %d bytes"
+msgstr[0] ""
+msgstr[1] ""
 
-#: builtin/stripspace.c:18
-msgid "git stripspace [-s | --strip-comments]"
+#: builtin/index-pack.c:268
+msgid "early EOF"
 msgstr ""
 
-#: builtin/stripspace.c:19
-msgid "git stripspace [-c | --comment-lines]"
+#: builtin/index-pack.c:269
+msgid "read error on input"
 msgstr ""
 
-#: builtin/stripspace.c:36
-msgid "skip and remove all lines starting with comment character"
+#: builtin/index-pack.c:281
+msgid "used more bytes than were available"
 msgstr ""
 
-#: builtin/stripspace.c:39
-msgid "prepend comment character and space to each line"
+#: builtin/index-pack.c:288 builtin/pack-objects.c:604
+msgid "pack too large for current definition of off_t"
 msgstr ""
 
-#: builtin/submodule--helper.c:37 builtin/submodule--helper.c:1688
-#, c-format
-msgid "No such ref: %s"
+#: builtin/index-pack.c:291 builtin/unpack-objects.c:95
+msgid "pack exceeds maximum allowed size"
 msgstr ""
 
-#: builtin/submodule--helper.c:44 builtin/submodule--helper.c:1697
+#: builtin/index-pack.c:312
 #, c-format
-msgid "Expecting a full ref name, got %s"
+msgid "cannot open packfile '%s'"
 msgstr ""
 
-#: builtin/submodule--helper.c:61
-msgid "submodule--helper print-default-remote takes no arguments"
+#: builtin/index-pack.c:326
+msgid "pack signature mismatch"
 msgstr ""
 
-#: builtin/submodule--helper.c:98
+#: builtin/index-pack.c:328
 #, c-format
-msgid "cannot strip one component off url '%s'"
+msgid "pack version %<PRIu32> unsupported"
 msgstr ""
 
-#: builtin/submodule--helper.c:406 builtin/submodule--helper.c:1211
-msgid "alternative anchor for relative paths"
+#: builtin/index-pack.c:346
+#, c-format
+msgid "pack has bad object at offset %<PRIuMAX>: %s"
 msgstr ""
 
-#: builtin/submodule--helper.c:411
-msgid "git submodule--helper list [--prefix=<path>] [<path>...]"
+#: builtin/index-pack.c:466
+#, c-format
+msgid "inflate returned %d"
 msgstr ""
 
-#: builtin/submodule--helper.c:462 builtin/submodule--helper.c:485
-#, c-format
-msgid "No url found for submodule path '%s' in .gitmodules"
+#: builtin/index-pack.c:515
+msgid "offset value overflow for delta base object"
 msgstr ""
 
-#: builtin/submodule--helper.c:500
-#, c-format
-msgid ""
-"could not lookup configuration '%s'. Assuming this repository is its own "
-"authoritative upstream."
+#: builtin/index-pack.c:523
+msgid "delta base offset is out of bound"
 msgstr ""
 
-#: builtin/submodule--helper.c:511
+#: builtin/index-pack.c:531
 #, c-format
-msgid "Failed to register url for submodule path '%s'"
+msgid "unknown object type %d"
 msgstr ""
 
-#: builtin/submodule--helper.c:515
-#, c-format
-msgid "Submodule '%s' (%s) registered for path '%s'\n"
+#: builtin/index-pack.c:562
+msgid "cannot pread pack file"
 msgstr ""
 
-#: builtin/submodule--helper.c:525
+#: builtin/index-pack.c:564
 #, c-format
-msgid "warning: command update mode suggested for submodule '%s'\n"
+msgid "premature end of pack file, %<PRIuMAX> byte missing"
+msgid_plural "premature end of pack file, %<PRIuMAX> bytes missing"
+msgstr[0] ""
+msgstr[1] ""
+
+#: builtin/index-pack.c:590
+msgid "serious inflate inconsistency"
 msgstr ""
 
-#: builtin/submodule--helper.c:532
+#: builtin/index-pack.c:735 builtin/index-pack.c:741 builtin/index-pack.c:764
+#: builtin/index-pack.c:803 builtin/index-pack.c:812
 #, c-format
-msgid "Failed to register update mode for submodule path '%s'"
+msgid "SHA1 COLLISION FOUND WITH %s !"
 msgstr ""
 
-#: builtin/submodule--helper.c:554
-msgid "Suppress output for initializing a submodule"
+#: builtin/index-pack.c:738 builtin/pack-objects.c:157
+#: builtin/pack-objects.c:217 builtin/pack-objects.c:311
+#, c-format
+msgid "unable to read %s"
 msgstr ""
 
-#: builtin/submodule--helper.c:559
-msgid "git submodule--helper init [<path>]"
+#: builtin/index-pack.c:801
+#, c-format
+msgid "cannot read existing object info %s"
 msgstr ""
 
-#: builtin/submodule--helper.c:631 builtin/submodule--helper.c:757
+#: builtin/index-pack.c:809
 #, c-format
-msgid "no submodule mapping found in .gitmodules for path '%s'"
+msgid "cannot read existing object %s"
 msgstr ""
 
-#: builtin/submodule--helper.c:670
+#: builtin/index-pack.c:823
 #, c-format
-msgid "could not resolve HEAD ref inside the submodule '%s'"
+msgid "invalid blob object %s"
+msgstr ""
+
+#: builtin/index-pack.c:826 builtin/index-pack.c:845
+msgid "fsck error in packed object"
 msgstr ""
 
-#: builtin/submodule--helper.c:697 builtin/submodule--helper.c:866
+#: builtin/index-pack.c:847
 #, c-format
-msgid "failed to recurse into submodule '%s'"
+msgid "Not all child objects of %s are reachable"
 msgstr ""
 
-#: builtin/submodule--helper.c:721 builtin/submodule--helper.c:1031
-msgid "Suppress submodule status output"
+#: builtin/index-pack.c:919 builtin/index-pack.c:950
+msgid "failed to apply delta"
 msgstr ""
 
-#: builtin/submodule--helper.c:722
-msgid ""
-"Use commit stored in the index instead of the one stored in the submodule "
-"HEAD"
+#: builtin/index-pack.c:1118
+msgid "Receiving objects"
 msgstr ""
 
-#: builtin/submodule--helper.c:723
-msgid "recurse into nested submodules"
+#: builtin/index-pack.c:1118
+msgid "Indexing objects"
 msgstr ""
 
-#: builtin/submodule--helper.c:728
-msgid "git submodule status [--quiet] [--cached] [--recursive] [<path>...]"
+#: builtin/index-pack.c:1152
+msgid "pack is corrupted (SHA1 mismatch)"
 msgstr ""
 
-#: builtin/submodule--helper.c:752
-msgid "git submodule--helper name <path>"
+#: builtin/index-pack.c:1157
+msgid "cannot fstat packfile"
 msgstr ""
 
-#: builtin/submodule--helper.c:816
-#, c-format
-msgid "Synchronizing submodule url for '%s'\n"
+#: builtin/index-pack.c:1160
+msgid "pack has junk at the end"
 msgstr ""
 
-#: builtin/submodule--helper.c:822
-#, c-format
-msgid "failed to register url for submodule path '%s'"
+#: builtin/index-pack.c:1172
+msgid "confusion beyond insanity in parse_pack_objects()"
 msgstr ""
 
-#: builtin/submodule--helper.c:836
-#, c-format
-msgid "failed to get the default remote for submodule '%s'"
+#: builtin/index-pack.c:1195
+msgid "Resolving deltas"
 msgstr ""
 
-#: builtin/submodule--helper.c:847
+#: builtin/index-pack.c:1205 builtin/pack-objects.c:2481
 #, c-format
-msgid "failed to update remote for submodule '%s'"
+msgid "unable to create thread: %s"
 msgstr ""
 
-#: builtin/submodule--helper.c:895
-msgid "Suppress output of synchronizing submodule url"
+#: builtin/index-pack.c:1246
+msgid "confusion beyond insanity"
 msgstr ""
 
-#: builtin/submodule--helper.c:897
-msgid "Recurse into nested submodules"
-msgstr ""
+#: builtin/index-pack.c:1252
+#, c-format
+msgid "completed with %d local object"
+msgid_plural "completed with %d local objects"
+msgstr[0] ""
+msgstr[1] ""
 
-#: builtin/submodule--helper.c:902
-msgid "git submodule--helper sync [--quiet] [--recursive] [<path>]"
+#: builtin/index-pack.c:1264
+#, c-format
+msgid "Unexpected tail checksum for %s (disk corruption?)"
 msgstr ""
 
-#: builtin/submodule--helper.c:956
+#: builtin/index-pack.c:1268
 #, c-format
-msgid ""
-"Submodule work tree '%s' contains a .git directory (use 'rm -rf' if you "
-"really want to remove it including all of its history)"
-msgstr ""
+msgid "pack has %d unresolved delta"
+msgid_plural "pack has %d unresolved deltas"
+msgstr[0] ""
+msgstr[1] ""
 
-#: builtin/submodule--helper.c:968
+#: builtin/index-pack.c:1292
 #, c-format
-msgid ""
-"Submodule work tree '%s' contains local modifications; use '-f' to discard "
-"them"
+msgid "unable to deflate appended object (%d)"
 msgstr ""
 
-#: builtin/submodule--helper.c:976
+#: builtin/index-pack.c:1388
 #, c-format
-msgid "Cleared directory '%s'\n"
+msgid "local object %s is corrupt"
 msgstr ""
 
-#: builtin/submodule--helper.c:978
+#: builtin/index-pack.c:1402
 #, c-format
-msgid "Could not remove submodule work tree '%s'\n"
+msgid "packfile name '%s' does not end with '.pack'"
 msgstr ""
 
-#: builtin/submodule--helper.c:987
+#: builtin/index-pack.c:1427
 #, c-format
-msgid "could not create empty submodule directory %s"
+msgid "cannot write %s file '%s'"
 msgstr ""
 
-#: builtin/submodule--helper.c:1003
+#: builtin/index-pack.c:1435
 #, c-format
-msgid "Submodule '%s' (%s) unregistered for path '%s'\n"
+msgid "cannot close written %s file '%s'"
 msgstr ""
 
-#: builtin/submodule--helper.c:1032
-msgid "Remove submodule working trees even if they contain local changes"
+#: builtin/index-pack.c:1459
+msgid "error while closing pack file"
 msgstr ""
 
-#: builtin/submodule--helper.c:1033
-msgid "Unregister all submodules"
+#: builtin/index-pack.c:1473
+msgid "cannot store pack file"
 msgstr ""
 
-#: builtin/submodule--helper.c:1038
-msgid ""
-"git submodule deinit [--quiet] [-f | --force] [--all | [--] [<path>...]]"
+#: builtin/index-pack.c:1481
+msgid "cannot store index file"
 msgstr ""
 
-#: builtin/submodule--helper.c:1052
-msgid "Use '--all' if you really want to deinitialize all submodules"
+#: builtin/index-pack.c:1525 builtin/pack-objects.c:2716
+#, c-format
+msgid "bad pack.indexversion=%<PRIu32>"
 msgstr ""
 
-#: builtin/submodule--helper.c:1145 builtin/submodule--helper.c:1148
+#: builtin/index-pack.c:1593
 #, c-format
-msgid "submodule '%s' cannot add alternate: %s"
+msgid "Cannot open existing pack file '%s'"
 msgstr ""
 
-#: builtin/submodule--helper.c:1184
+#: builtin/index-pack.c:1595
 #, c-format
-msgid "Value '%s' for submodule.alternateErrorStrategy is not recognized"
+msgid "Cannot open existing pack idx file for '%s'"
 msgstr ""
 
-#: builtin/submodule--helper.c:1191
+#: builtin/index-pack.c:1643
 #, c-format
-msgid "Value '%s' for submodule.alternateLocation is not recognized"
-msgstr ""
+msgid "non delta: %d object"
+msgid_plural "non delta: %d objects"
+msgstr[0] ""
+msgstr[1] ""
 
-#: builtin/submodule--helper.c:1214
-msgid "where the new submodule will be cloned to"
+#: builtin/index-pack.c:1650
+#, c-format
+msgid "chain length = %d: %lu object"
+msgid_plural "chain length = %d: %lu objects"
+msgstr[0] ""
+msgstr[1] ""
+
+#: builtin/index-pack.c:1689
+msgid "Cannot come back to cwd"
 msgstr ""
 
-#: builtin/submodule--helper.c:1217
-msgid "name of the new submodule"
+#: builtin/index-pack.c:1738 builtin/index-pack.c:1741
+#: builtin/index-pack.c:1757 builtin/index-pack.c:1761
+#, c-format
+msgid "bad %s"
 msgstr ""
 
-#: builtin/submodule--helper.c:1220
-msgid "url where to clone the submodule from"
+#: builtin/index-pack.c:1777
+msgid "--fix-thin cannot be used without --stdin"
 msgstr ""
 
-#: builtin/submodule--helper.c:1228
-msgid "depth for shallow clones"
+#: builtin/index-pack.c:1779
+msgid "--stdin requires a git repository"
 msgstr ""
 
-#: builtin/submodule--helper.c:1231 builtin/submodule--helper.c:1606
-msgid "force cloning progress"
+#: builtin/index-pack.c:1785
+msgid "--verify with no packfile name given"
 msgstr ""
 
-#: builtin/submodule--helper.c:1236
-msgid ""
-"git submodule--helper clone [--prefix=<path>] [--quiet] [--reference "
-"<repository>] [--name <name>] [--depth <depth>] --url <url> --path <path>"
+#: builtin/index-pack.c:1833 builtin/unpack-objects.c:581
+msgid "fsck error in pack objects"
 msgstr ""
 
-#: builtin/submodule--helper.c:1267
+#: builtin/init-db.c:61
 #, c-format
-msgid "clone of '%s' into submodule path '%s' failed"
+msgid "cannot stat template '%s'"
 msgstr ""
 
-#: builtin/submodule--helper.c:1281
+#: builtin/init-db.c:66
 #, c-format
-msgid "could not get submodule directory for '%s'"
+msgid "cannot opendir '%s'"
 msgstr ""
 
-#: builtin/submodule--helper.c:1347
+#: builtin/init-db.c:78
 #, c-format
-msgid "Submodule path '%s' not initialized"
+msgid "cannot readlink '%s'"
 msgstr ""
 
-#: builtin/submodule--helper.c:1351
-msgid "Maybe you want to use 'update --init'?"
+#: builtin/init-db.c:80
+#, c-format
+msgid "cannot symlink '%s' '%s'"
 msgstr ""
 
-#: builtin/submodule--helper.c:1380
+#: builtin/init-db.c:86
 #, c-format
-msgid "Skipping unmerged submodule %s"
+msgid "cannot copy '%s' to '%s'"
 msgstr ""
 
-#: builtin/submodule--helper.c:1409
+#: builtin/init-db.c:90
 #, c-format
-msgid "Skipping submodule '%s'"
+msgid "ignoring template %s"
 msgstr ""
 
-#: builtin/submodule--helper.c:1544
+#: builtin/init-db.c:121
 #, c-format
-msgid "Failed to clone '%s'. Retry scheduled"
+msgid "templates not found in %s"
 msgstr ""
 
-#: builtin/submodule--helper.c:1555
+#: builtin/init-db.c:136
 #, c-format
-msgid "Failed to clone '%s' a second time, aborting"
+msgid "not copying templates from '%s': %s"
 msgstr ""
 
-#: builtin/submodule--helper.c:1585 builtin/submodule--helper.c:1808
-msgid "path into the working tree"
+#: builtin/init-db.c:334
+#, c-format
+msgid "unable to handle file type %d"
 msgstr ""
 
-#: builtin/submodule--helper.c:1588
-msgid "path into the working tree, across nested submodule boundaries"
+#: builtin/init-db.c:337
+#, c-format
+msgid "unable to move %s to %s"
 msgstr ""
 
-#: builtin/submodule--helper.c:1592
-msgid "rebase, merge, checkout or none"
+#: builtin/init-db.c:354 builtin/init-db.c:357
+#, c-format
+msgid "%s already exists"
 msgstr ""
 
-#: builtin/submodule--helper.c:1598
-msgid "Create a shallow clone truncated to the specified number of revisions"
+#: builtin/init-db.c:413
+#, c-format
+msgid "Reinitialized existing shared Git repository in %s%s\n"
 msgstr ""
 
-#: builtin/submodule--helper.c:1601
-msgid "parallel jobs"
+#: builtin/init-db.c:414
+#, c-format
+msgid "Reinitialized existing Git repository in %s%s\n"
 msgstr ""
 
-#: builtin/submodule--helper.c:1603
-msgid "whether the initial clone should follow the shallow recommendation"
+#: builtin/init-db.c:418
+#, c-format
+msgid "Initialized empty shared Git repository in %s%s\n"
 msgstr ""
 
-#: builtin/submodule--helper.c:1604
-msgid "don't print cloning progress"
+#: builtin/init-db.c:419
+#, c-format
+msgid "Initialized empty Git repository in %s%s\n"
 msgstr ""
 
-#: builtin/submodule--helper.c:1611
-msgid "git submodule--helper update_clone [--prefix=<path>] [<path>...]"
+#: builtin/init-db.c:468
+msgid ""
+"git init [-q | --quiet] [--bare] [--template=<template-directory>] [--"
+"shared[=<permissions>]] [<directory>]"
 msgstr ""
 
-#: builtin/submodule--helper.c:1624
-msgid "bad value for update parameter"
+#: builtin/init-db.c:491
+msgid "permissions"
 msgstr ""
 
-#: builtin/submodule--helper.c:1692
-#, c-format
-msgid ""
-"Submodule (%s) branch configured to inherit branch from superproject, but "
-"the superproject is not on any branch"
+#: builtin/init-db.c:492
+msgid "specify that the git repository is to be shared amongst several users"
 msgstr ""
 
-#: builtin/submodule--helper.c:1809
-msgid "recurse into submodules"
+#: builtin/init-db.c:529 builtin/init-db.c:534
+#, c-format
+msgid "cannot mkdir %s"
 msgstr ""
 
-#: builtin/submodule--helper.c:1815
-msgid "git submodule--helper embed-git-dir [<path>...]"
+#: builtin/init-db.c:538
+#, c-format
+msgid "cannot chdir to %s"
 msgstr ""
 
-#: builtin/submodule--helper.c:1901
+#: builtin/init-db.c:559
 #, c-format
-msgid "%s doesn't support --super-prefix"
+msgid ""
+"%s (or --work-tree=<directory>) not allowed without specifying %s (or --git-"
+"dir=<directory>)"
 msgstr ""
 
-#: builtin/submodule--helper.c:1907
+#: builtin/init-db.c:587
 #, c-format
-msgid "'%s' is not a valid submodule--helper subcommand"
+msgid "Cannot access work tree '%s'"
 msgstr ""
 
-#: builtin/symbolic-ref.c:8
-msgid "git symbolic-ref [<options>] <name> [<ref>]"
+#: builtin/interpret-trailers.c:16
+msgid ""
+"git interpret-trailers [--in-place] [--trim-empty] [(--trailer "
+"<token>[(=|:)<value>])...] [<file>...]"
 msgstr ""
 
-#: builtin/symbolic-ref.c:9
-msgid "git symbolic-ref -d [-q] <name>"
+#: builtin/interpret-trailers.c:95
+msgid "edit files in place"
 msgstr ""
 
-#: builtin/symbolic-ref.c:40
-msgid "suppress error message for non-symbolic (detached) refs"
+#: builtin/interpret-trailers.c:96
+msgid "trim empty trailers"
 msgstr ""
 
-#: builtin/symbolic-ref.c:41
-msgid "delete symbolic ref"
+#: builtin/interpret-trailers.c:99
+msgid "where to place the new trailer"
 msgstr ""
 
-#: builtin/symbolic-ref.c:42
-msgid "shorten ref output"
+#: builtin/interpret-trailers.c:101
+msgid "action if trailer already exists"
 msgstr ""
 
-#: builtin/symbolic-ref.c:43 builtin/update-ref.c:362
-msgid "reason"
+#: builtin/interpret-trailers.c:103
+msgid "action if trailer is missing"
 msgstr ""
 
-#: builtin/symbolic-ref.c:43 builtin/update-ref.c:362
-msgid "reason of the update"
+#: builtin/interpret-trailers.c:105
+msgid "output only the trailers"
 msgstr ""
 
-#: builtin/tag.c:24
-msgid ""
-"git tag [-a | -s | -u <key-id>] [-f] [-m <msg> | -F <file>] <tagname> "
-"[<head>]"
+#: builtin/interpret-trailers.c:106
+msgid "do not apply config rules"
 msgstr ""
 
-#: builtin/tag.c:25
-msgid "git tag -d <tagname>..."
+#: builtin/interpret-trailers.c:107
+msgid "join whitespace-continued values"
 msgstr ""
 
-#: builtin/tag.c:26
-msgid ""
-"git tag -l [-n[<num>]] [--contains <commit>] [--no-contains <commit>] [--"
-"points-at <object>]\n"
-"\t\t[--format=<format>] [--[no-]merged [<commit>]] [<pattern>...]"
+#: builtin/interpret-trailers.c:108
+msgid "set parsing options"
 msgstr ""
 
-#: builtin/tag.c:28
-msgid "git tag -v [--format=<format>] <tagname>..."
+#: builtin/interpret-trailers.c:110
+msgid "do not treat --- specially"
 msgstr ""
 
-#: builtin/tag.c:86
-#, c-format
-msgid "tag '%s' not found."
+#: builtin/interpret-trailers.c:111
+msgid "trailer"
 msgstr ""
 
-#: builtin/tag.c:102
-#, c-format
-msgid "Deleted tag '%s' (was %s)\n"
+#: builtin/interpret-trailers.c:112
+msgid "trailer(s) to add"
 msgstr ""
 
-#: builtin/tag.c:132
-#, c-format
-msgid ""
-"\n"
-"Write a message for tag:\n"
-"  %s\n"
-"Lines starting with '%c' will be ignored.\n"
+#: builtin/interpret-trailers.c:123
+msgid "--trailer with --only-input does not make sense"
 msgstr ""
 
-#: builtin/tag.c:136
-#, c-format
-msgid ""
-"\n"
-"Write a message for tag:\n"
-"  %s\n"
-"Lines starting with '%c' will be kept; you may remove them yourself if you "
-"want to.\n"
+#: builtin/interpret-trailers.c:133
+msgid "no input file given for in-place editing"
 msgstr ""
 
-#: builtin/tag.c:190
-msgid "unable to sign the tag"
+#: builtin/log.c:56
+msgid "git log [<options>] [<revision-range>] [[--] <path>...]"
 msgstr ""
 
-#: builtin/tag.c:192
-msgid "unable to write tag file"
+#: builtin/log.c:57
+msgid "git show [<options>] <object>..."
 msgstr ""
 
-#: builtin/tag.c:217
-msgid "bad object type."
+#: builtin/log.c:110
+#, c-format
+msgid "invalid --decorate option: %s"
 msgstr ""
 
-#: builtin/tag.c:266
-msgid "no tag message?"
+#: builtin/log.c:174
+msgid "show source"
 msgstr ""
 
-#: builtin/tag.c:273
-#, c-format
-msgid "The tag message has been left in %s\n"
+#: builtin/log.c:175
+msgid "Use mail map file"
 msgstr ""
 
-#: builtin/tag.c:382
-msgid "list tag names"
+#: builtin/log.c:177
+msgid "only decorate refs that match <pattern>"
 msgstr ""
 
-#: builtin/tag.c:384
-msgid "print <n> lines of each tag message"
+#: builtin/log.c:179
+msgid "do not decorate refs that match <pattern>"
 msgstr ""
 
-#: builtin/tag.c:386
-msgid "delete tags"
+#: builtin/log.c:180
+msgid "decorate options"
 msgstr ""
 
-#: builtin/tag.c:387
-msgid "verify tags"
+#: builtin/log.c:183
+msgid "Process line range n,m in file, counting from 1"
 msgstr ""
 
-#: builtin/tag.c:389
-msgid "Tag creation options"
+#: builtin/log.c:281
+#, c-format
+msgid "Final output: %d %s\n"
 msgstr ""
 
-#: builtin/tag.c:391
-msgid "annotated tag, needs a message"
+#: builtin/log.c:535
+#, c-format
+msgid "git show %s: bad file"
 msgstr ""
 
-#: builtin/tag.c:393
-msgid "tag message"
+#: builtin/log.c:550 builtin/log.c:645
+#, c-format
+msgid "could not read object %s"
 msgstr ""
 
-#: builtin/tag.c:395
-msgid "force edit of tag message"
+#: builtin/log.c:670
+#, c-format
+msgid "unknown type: %d"
 msgstr ""
 
-#: builtin/tag.c:396
-msgid "annotated and GPG-signed tag"
+#: builtin/log.c:814
+#, c-format
+msgid "%s: invalid cover from description mode"
 msgstr ""
 
-#: builtin/tag.c:400
-msgid "use another key to sign the tag"
+#: builtin/log.c:821
+msgid "format.headers without value"
 msgstr ""
 
-#: builtin/tag.c:401
-msgid "replace the tag if exists"
+#: builtin/log.c:936
+msgid "name of output directory is too long"
 msgstr ""
 
-#: builtin/tag.c:402 builtin/update-ref.c:368
-msgid "create a reflog"
+#: builtin/log.c:952
+#, c-format
+msgid "cannot open patch file %s"
 msgstr ""
 
-#: builtin/tag.c:404
-msgid "Tag listing options"
+#: builtin/log.c:969
+msgid "need exactly one range"
 msgstr ""
 
-#: builtin/tag.c:405
-msgid "show tag list in columns"
+#: builtin/log.c:979
+msgid "not a range"
 msgstr ""
 
-#: builtin/tag.c:406 builtin/tag.c:408
-msgid "print only tags that contain the commit"
+#: builtin/log.c:1143
+msgid "cover letter needs email format"
 msgstr ""
 
-#: builtin/tag.c:407 builtin/tag.c:409
-msgid "print only tags that don't contain the commit"
+#: builtin/log.c:1149
+msgid "failed to create cover-letter file"
 msgstr ""
 
-#: builtin/tag.c:410
-msgid "print only tags that are merged"
+#: builtin/log.c:1228
+#, c-format
+msgid "insane in-reply-to: %s"
 msgstr ""
 
-#: builtin/tag.c:411
-msgid "print only tags that are not merged"
+#: builtin/log.c:1255
+msgid "git format-patch [<options>] [<since> | <revision-range>]"
 msgstr ""
 
-#: builtin/tag.c:416
-msgid "print only tags of the object"
+#: builtin/log.c:1313
+msgid "two output directories?"
 msgstr ""
 
-#: builtin/tag.c:460
-msgid "--column and -n are incompatible"
+#: builtin/log.c:1424 builtin/log.c:2197 builtin/log.c:2199 builtin/log.c:2211
+#, c-format
+msgid "unknown commit %s"
 msgstr ""
 
-#: builtin/tag.c:482
-msgid "-n option is only allowed in list mode"
+#: builtin/log.c:1434 builtin/replace.c:58 builtin/replace.c:207
+#: builtin/replace.c:210
+#, c-format
+msgid "failed to resolve '%s' as a valid ref"
 msgstr ""
 
-#: builtin/tag.c:484
-msgid "--contains option is only allowed in list mode"
+#: builtin/log.c:1439
+msgid "could not find exact merge base"
 msgstr ""
 
-#: builtin/tag.c:486
-msgid "--no-contains option is only allowed in list mode"
+#: builtin/log.c:1443
+msgid ""
+"failed to get upstream, if you want to record base commit automatically,\n"
+"please use git branch --set-upstream-to to track a remote branch.\n"
+"Or you could specify base commit by --base=<base-commit-id> manually"
 msgstr ""
 
-#: builtin/tag.c:488
-msgid "--points-at option is only allowed in list mode"
+#: builtin/log.c:1463
+msgid "failed to find exact merge base"
 msgstr ""
 
-#: builtin/tag.c:490
-msgid "--merged and --no-merged options are only allowed in list mode"
+#: builtin/log.c:1474
+msgid "base commit should be the ancestor of revision list"
 msgstr ""
 
-#: builtin/tag.c:501
-msgid "only one -F or -m option is allowed."
+#: builtin/log.c:1478
+msgid "base commit shouldn't be in revision list"
 msgstr ""
 
-#: builtin/tag.c:520
-msgid "too many params"
+#: builtin/log.c:1531
+msgid "cannot get patch id"
 msgstr ""
 
-#: builtin/tag.c:526
-#, c-format
-msgid "'%s' is not a valid tag name."
+#: builtin/log.c:1583
+msgid "failed to infer range-diff ranges"
 msgstr ""
 
-#: builtin/tag.c:531
-#, c-format
-msgid "tag '%s' already exists"
+#: builtin/log.c:1629
+msgid "use [PATCH n/m] even with a single patch"
 msgstr ""
 
-#: builtin/tag.c:562
-#, c-format
-msgid "Updated tag '%s' (was %s)\n"
+#: builtin/log.c:1632
+msgid "use [PATCH] even with multiple patches"
 msgstr ""
 
-#: builtin/unpack-objects.c:498
-msgid "Unpacking objects"
+#: builtin/log.c:1636
+msgid "print patches to standard out"
 msgstr ""
 
-#: builtin/update-index.c:82
-#, c-format
-msgid "failed to create directory %s"
+#: builtin/log.c:1638
+msgid "generate a cover letter"
 msgstr ""
 
-#: builtin/update-index.c:88
-#, c-format
-msgid "failed to stat %s"
+#: builtin/log.c:1640
+msgid "use simple number sequence for output file names"
 msgstr ""
 
-#: builtin/update-index.c:98
-#, c-format
-msgid "failed to create file %s"
+#: builtin/log.c:1641
+msgid "sfx"
 msgstr ""
 
-#: builtin/update-index.c:106
-#, c-format
-msgid "failed to delete file %s"
+#: builtin/log.c:1642
+msgid "use <sfx> instead of '.patch'"
 msgstr ""
 
-#: builtin/update-index.c:113 builtin/update-index.c:219
-#, c-format
-msgid "failed to delete directory %s"
+#: builtin/log.c:1644
+msgid "start numbering patches at <n> instead of 1"
 msgstr ""
 
-#: builtin/update-index.c:138
-#, c-format
-msgid "Testing mtime in '%s' "
+#: builtin/log.c:1646
+msgid "mark the series as Nth re-roll"
 msgstr ""
 
-#: builtin/update-index.c:152
-msgid "directory stat info does not change after adding a new file"
+#: builtin/log.c:1648
+msgid "Use [RFC PATCH] instead of [PATCH]"
 msgstr ""
 
-#: builtin/update-index.c:165
-msgid "directory stat info does not change after adding a new directory"
+#: builtin/log.c:1651
+msgid "cover-from-description-mode"
 msgstr ""
 
-#: builtin/update-index.c:178
-msgid "directory stat info changes after updating a file"
+#: builtin/log.c:1652
+msgid "generate parts of a cover letter based on a branch's description"
 msgstr ""
 
-#: builtin/update-index.c:189
-msgid "directory stat info changes after adding a file inside subdirectory"
+#: builtin/log.c:1654
+msgid "Use [<prefix>] instead of [PATCH]"
 msgstr ""
 
-#: builtin/update-index.c:200
-msgid "directory stat info does not change after deleting a file"
+#: builtin/log.c:1657
+msgid "store resulting files in <dir>"
 msgstr ""
 
-#: builtin/update-index.c:213
-msgid "directory stat info does not change after deleting a directory"
+#: builtin/log.c:1660
+msgid "don't strip/add [PATCH]"
 msgstr ""
 
-#: builtin/update-index.c:220
-msgid " OK"
+#: builtin/log.c:1663
+msgid "don't output binary diffs"
 msgstr ""
 
-#: builtin/update-index.c:589
-msgid "git update-index [<options>] [--] [<file>...]"
+#: builtin/log.c:1665
+msgid "output all-zero hash in From header"
 msgstr ""
 
-#: builtin/update-index.c:946
-msgid "continue refresh even when index needs update"
+#: builtin/log.c:1667
+msgid "don't include a patch matching a commit upstream"
 msgstr ""
 
-#: builtin/update-index.c:949
-msgid "refresh: ignore submodules"
+#: builtin/log.c:1669
+msgid "show patch format instead of default (patch + stat)"
 msgstr ""
 
-#: builtin/update-index.c:952
-msgid "do not ignore new files"
+#: builtin/log.c:1671
+msgid "Messaging"
 msgstr ""
 
-#: builtin/update-index.c:954
-msgid "let files replace directories and vice-versa"
+#: builtin/log.c:1672
+msgid "header"
 msgstr ""
 
-#: builtin/update-index.c:956
-msgid "notice files missing from worktree"
+#: builtin/log.c:1673
+msgid "add email header"
 msgstr ""
 
-#: builtin/update-index.c:958
-msgid "refresh even if index contains unmerged entries"
+#: builtin/log.c:1674 builtin/log.c:1676
+msgid "email"
 msgstr ""
 
-#: builtin/update-index.c:961
-msgid "refresh stat information"
+#: builtin/log.c:1674
+msgid "add To: header"
 msgstr ""
 
-#: builtin/update-index.c:965
-msgid "like --refresh, but ignore assume-unchanged setting"
+#: builtin/log.c:1676
+msgid "add Cc: header"
 msgstr ""
 
-#: builtin/update-index.c:969
-msgid "<mode>,<object>,<path>"
+#: builtin/log.c:1678
+msgid "ident"
 msgstr ""
 
-#: builtin/update-index.c:970
-msgid "add the specified entry to the index"
+#: builtin/log.c:1679
+msgid "set From address to <ident> (or committer ident if absent)"
 msgstr ""
 
-#: builtin/update-index.c:979
-msgid "mark files as \"not changing\""
+#: builtin/log.c:1681
+msgid "message-id"
 msgstr ""
 
-#: builtin/update-index.c:982
-msgid "clear assumed-unchanged bit"
+#: builtin/log.c:1682
+msgid "make first mail a reply to <message-id>"
 msgstr ""
 
-#: builtin/update-index.c:985
-msgid "mark files as \"index-only\""
+#: builtin/log.c:1683 builtin/log.c:1686
+msgid "boundary"
 msgstr ""
 
-#: builtin/update-index.c:988
-msgid "clear skip-worktree bit"
+#: builtin/log.c:1684
+msgid "attach the patch"
 msgstr ""
 
-#: builtin/update-index.c:991
-msgid "add to index only; do not add content to object database"
+#: builtin/log.c:1687
+msgid "inline the patch"
 msgstr ""
 
-#: builtin/update-index.c:993
-msgid "remove named paths even if present in worktree"
+#: builtin/log.c:1691
+msgid "enable message threading, styles: shallow, deep"
 msgstr ""
 
-#: builtin/update-index.c:995
-msgid "with --stdin: input lines are terminated by null bytes"
+#: builtin/log.c:1693
+msgid "signature"
 msgstr ""
 
-#: builtin/update-index.c:997
-msgid "read list of paths to be updated from standard input"
+#: builtin/log.c:1694
+msgid "add a signature"
 msgstr ""
 
-#: builtin/update-index.c:1001
-msgid "add entries from standard input to the index"
+#: builtin/log.c:1695
+msgid "base-commit"
 msgstr ""
 
-#: builtin/update-index.c:1005
-msgid "repopulate stages #2 and #3 for the listed paths"
+#: builtin/log.c:1696
+msgid "add prerequisite tree info to the patch series"
 msgstr ""
 
-#: builtin/update-index.c:1009
-msgid "only update entries that differ from HEAD"
+#: builtin/log.c:1698
+msgid "add a signature from a file"
 msgstr ""
 
-#: builtin/update-index.c:1013
-msgid "ignore files missing from worktree"
+#: builtin/log.c:1699
+msgid "don't print the patch filenames"
 msgstr ""
 
-#: builtin/update-index.c:1016
-msgid "report actions to standard output"
+#: builtin/log.c:1701
+msgid "show progress while generating patches"
 msgstr ""
 
-#: builtin/update-index.c:1018
-msgid "(for porcelains) forget saved unresolved conflicts"
+#: builtin/log.c:1703
+msgid "show changes against <rev> in cover letter or single patch"
 msgstr ""
 
-#: builtin/update-index.c:1022
-msgid "write index in this format"
+#: builtin/log.c:1706
+msgid "show changes against <refspec> in cover letter or single patch"
 msgstr ""
 
-#: builtin/update-index.c:1024
-msgid "enable or disable split index"
+#: builtin/log.c:1708
+msgid "percentage by which creation is weighted"
 msgstr ""
 
-#: builtin/update-index.c:1026
-msgid "enable/disable untracked cache"
+#: builtin/log.c:1792
+#, c-format
+msgid "invalid ident line: %s"
 msgstr ""
 
-#: builtin/update-index.c:1028
-msgid "test if the filesystem supports untracked cache"
+#: builtin/log.c:1807
+msgid "-n and -k are mutually exclusive"
 msgstr ""
 
-#: builtin/update-index.c:1030
-msgid "enable untracked cache without testing the filesystem"
+#: builtin/log.c:1809
+msgid "--subject-prefix/--rfc and -k are mutually exclusive"
 msgstr ""
 
-#: builtin/update-index.c:1032
-msgid "write out the index even if is not flagged as changed"
+#: builtin/log.c:1817
+msgid "--name-only does not make sense"
 msgstr ""
 
-#: builtin/update-index.c:1034
-msgid "enable or disable file system monitor"
+#: builtin/log.c:1819
+msgid "--name-status does not make sense"
 msgstr ""
 
-#: builtin/update-index.c:1036
-msgid "mark files as fsmonitor valid"
+#: builtin/log.c:1821
+msgid "--check does not make sense"
 msgstr ""
 
-#: builtin/update-index.c:1039
-msgid "clear fsmonitor valid bit"
+#: builtin/log.c:1854
+msgid "standard output, or directory, which one?"
 msgstr ""
 
-#: builtin/update-index.c:1138
-msgid ""
-"core.splitIndex is set to false; remove or change it, if you really want to "
-"enable split index"
+#: builtin/log.c:1958
+msgid "--interdiff requires --cover-letter or single patch"
 msgstr ""
 
-#: builtin/update-index.c:1147
-msgid ""
-"core.splitIndex is set to true; remove or change it, if you really want to "
-"disable split index"
+#: builtin/log.c:1962
+msgid "Interdiff:"
 msgstr ""
 
-#: builtin/update-index.c:1158
-msgid ""
-"core.untrackedCache is set to true; remove or change it, if you really want "
-"to disable the untracked cache"
+#: builtin/log.c:1963
+#, c-format
+msgid "Interdiff against v%d:"
 msgstr ""
 
-#: builtin/update-index.c:1162
-msgid "Untracked cache disabled"
+#: builtin/log.c:1969
+msgid "--creation-factor requires --range-diff"
 msgstr ""
 
-#: builtin/update-index.c:1170
-msgid ""
-"core.untrackedCache is set to false; remove or change it, if you really want "
-"to enable the untracked cache"
+#: builtin/log.c:1973
+msgid "--range-diff requires --cover-letter or single patch"
+msgstr ""
+
+#: builtin/log.c:1981
+msgid "Range-diff:"
 msgstr ""
 
-#: builtin/update-index.c:1174
+#: builtin/log.c:1982
 #, c-format
-msgid "Untracked cache enabled for '%s'"
+msgid "Range-diff against v%d:"
 msgstr ""
 
-#: builtin/update-index.c:1182
-msgid "core.fsmonitor is unset; set it if you really want to enable fsmonitor"
+#: builtin/log.c:1993
+#, c-format
+msgid "unable to read signature file '%s'"
 msgstr ""
 
-#: builtin/update-index.c:1186
-msgid "fsmonitor enabled"
+#: builtin/log.c:2029
+msgid "Generating patches"
 msgstr ""
 
-#: builtin/update-index.c:1189
-msgid ""
-"core.fsmonitor is set; remove it if you really want to disable fsmonitor"
+#: builtin/log.c:2073
+msgid "failed to create output files"
 msgstr ""
 
-#: builtin/update-index.c:1193
-msgid "fsmonitor disabled"
+#: builtin/log.c:2132
+msgid "git cherry [-v] [<upstream> [<head> [<limit>]]]"
 msgstr ""
 
-#: builtin/update-ref.c:10
-msgid "git update-ref [<options>] -d <refname> [<old-val>]"
+#: builtin/log.c:2186
+#, c-format
+msgid ""
+"Could not find a tracked remote branch, please specify <upstream> manually.\n"
 msgstr ""
 
-#: builtin/update-ref.c:11
-msgid "git update-ref [<options>]    <refname> <new-val> [<old-val>]"
+#: builtin/ls-files.c:470
+msgid "git ls-files [<options>] [<file>...]"
 msgstr ""
 
-#: builtin/update-ref.c:12
-msgid "git update-ref [<options>] --stdin [-z]"
+#: builtin/ls-files.c:526
+msgid "identify the file status with tags"
 msgstr ""
 
-#: builtin/update-ref.c:363
-msgid "delete the reference"
+#: builtin/ls-files.c:528
+msgid "use lowercase letters for 'assume unchanged' files"
 msgstr ""
 
-#: builtin/update-ref.c:365
-msgid "update <refname> not the one it points to"
+#: builtin/ls-files.c:530
+msgid "use lowercase letters for 'fsmonitor clean' files"
 msgstr ""
 
-#: builtin/update-ref.c:366
-msgid "stdin has NUL-terminated arguments"
+#: builtin/ls-files.c:532
+msgid "show cached files in the output (default)"
 msgstr ""
 
-#: builtin/update-ref.c:367
-msgid "read updates from stdin"
+#: builtin/ls-files.c:534
+msgid "show deleted files in the output"
 msgstr ""
 
-#: builtin/update-server-info.c:7
-msgid "git update-server-info [--force]"
+#: builtin/ls-files.c:536
+msgid "show modified files in the output"
 msgstr ""
 
-#: builtin/update-server-info.c:15
-msgid "update the info files from scratch"
+#: builtin/ls-files.c:538
+msgid "show other files in the output"
 msgstr ""
 
-#: builtin/upload-pack.c:11
-msgid "git upload-pack [<options>] <dir>"
+#: builtin/ls-files.c:540
+msgid "show ignored files in the output"
 msgstr ""
 
-#: builtin/upload-pack.c:25
-msgid "exit immediately after initial ref advertisement"
+#: builtin/ls-files.c:543
+msgid "show staged contents' object name in the output"
 msgstr ""
 
-#: builtin/upload-pack.c:27
-msgid "do not try <directory>/.git/ if <directory> is no Git directory"
+#: builtin/ls-files.c:545
+msgid "show files on the filesystem that need to be removed"
 msgstr ""
 
-#: builtin/upload-pack.c:29
-msgid "interrupt transfer after <n> seconds of inactivity"
+#: builtin/ls-files.c:547
+msgid "show 'other' directories' names only"
 msgstr ""
 
-#: builtin/verify-commit.c:18
-msgid "git verify-commit [-v | --verbose] <commit>..."
+#: builtin/ls-files.c:549
+msgid "show line endings of files"
 msgstr ""
 
-#: builtin/verify-commit.c:73
-msgid "print commit contents"
+#: builtin/ls-files.c:551
+msgid "don't show empty directories"
 msgstr ""
 
-#: builtin/verify-commit.c:74 builtin/verify-tag.c:38
-msgid "print raw gpg status output"
+#: builtin/ls-files.c:554
+msgid "show unmerged files in the output"
 msgstr ""
 
-#: builtin/verify-pack.c:55
-msgid "git verify-pack [-v | --verbose] [-s | --stat-only] <pack>..."
-msgstr ""
-
-#: builtin/verify-pack.c:65
-msgid "verbose"
+#: builtin/ls-files.c:556
+msgid "show resolve-undo information"
 msgstr ""
 
-#: builtin/verify-pack.c:67
-msgid "show statistics only"
+#: builtin/ls-files.c:558
+msgid "skip files matching pattern"
 msgstr ""
 
-#: builtin/verify-tag.c:19
-msgid "git verify-tag [-v | --verbose] [--format=<format>] <tag>..."
+#: builtin/ls-files.c:561
+msgid "exclude patterns are read from <file>"
 msgstr ""
 
-#: builtin/verify-tag.c:37
-msgid "print tag contents"
+#: builtin/ls-files.c:564
+msgid "read additional per-directory exclude patterns in <file>"
 msgstr ""
 
-#: builtin/worktree.c:17
-msgid "git worktree add [<options>] <path> [<commit-ish>]"
+#: builtin/ls-files.c:566
+msgid "add the standard git exclusions"
 msgstr ""
 
-#: builtin/worktree.c:18
-msgid "git worktree list [<options>]"
+#: builtin/ls-files.c:570
+msgid "make the output relative to the project top directory"
 msgstr ""
 
-#: builtin/worktree.c:19
-msgid "git worktree lock [<options>] <path>"
+#: builtin/ls-files.c:573
+msgid "recurse through submodules"
 msgstr ""
 
-#: builtin/worktree.c:20
-msgid "git worktree move <worktree> <new-path>"
+#: builtin/ls-files.c:575
+msgid "if any <file> is not in the index, treat this as an error"
 msgstr ""
 
-#: builtin/worktree.c:21
-msgid "git worktree prune [<options>]"
+#: builtin/ls-files.c:576
+msgid "tree-ish"
 msgstr ""
 
-#: builtin/worktree.c:22
-msgid "git worktree remove [<options>] <worktree>"
+#: builtin/ls-files.c:577
+msgid "pretend that paths removed since <tree-ish> are still present"
 msgstr ""
 
-#: builtin/worktree.c:23
-msgid "git worktree unlock <path>"
+#: builtin/ls-files.c:579
+msgid "show debugging data"
 msgstr ""
 
-#: builtin/worktree.c:58
-#, c-format
-msgid "Removing worktrees/%s: not a valid directory"
+#: builtin/ls-remote.c:9
+msgid ""
+"git ls-remote [--heads] [--tags] [--refs] [--upload-pack=<exec>]\n"
+"                     [-q | --quiet] [--exit-code] [--get-url]\n"
+"                     [--symref] [<repository> [<refs>...]]"
 msgstr ""
 
-#: builtin/worktree.c:64
-#, c-format
-msgid "Removing worktrees/%s: gitdir file does not exist"
+#: builtin/ls-remote.c:59
+msgid "do not print remote URL"
 msgstr ""
 
-#: builtin/worktree.c:69 builtin/worktree.c:78
-#, c-format
-msgid "Removing worktrees/%s: unable to read gitdir file (%s)"
+#: builtin/ls-remote.c:60 builtin/ls-remote.c:62 builtin/rebase.c:1518
+msgid "exec"
 msgstr ""
 
-#: builtin/worktree.c:88
-#, c-format
-msgid ""
-"Removing worktrees/%s: short read (expected %<PRIuMAX> bytes, read "
-"%<PRIuMAX>)"
+#: builtin/ls-remote.c:61 builtin/ls-remote.c:63
+msgid "path of git-upload-pack on the remote host"
 msgstr ""
 
-#: builtin/worktree.c:96
-#, c-format
-msgid "Removing worktrees/%s: invalid gitdir file"
+#: builtin/ls-remote.c:65
+msgid "limit to tags"
 msgstr ""
 
-#: builtin/worktree.c:105
-#, c-format
-msgid "Removing worktrees/%s: gitdir file points to non-existent location"
+#: builtin/ls-remote.c:66
+msgid "limit to heads"
 msgstr ""
 
-#: builtin/worktree.c:152
-msgid "report pruned working trees"
+#: builtin/ls-remote.c:67
+msgid "do not show peeled tags"
 msgstr ""
 
-#: builtin/worktree.c:154
-msgid "expire working trees older than <time>"
+#: builtin/ls-remote.c:69
+msgid "take url.<base>.insteadOf into account"
 msgstr ""
 
-#: builtin/worktree.c:229
-#, c-format
-msgid "'%s' already exists"
+#: builtin/ls-remote.c:72
+msgid "exit with exit code 2 if no matching refs are found"
 msgstr ""
 
-#: builtin/worktree.c:260
-#, c-format
-msgid "could not create directory of '%s'"
+#: builtin/ls-remote.c:75
+msgid "show underlying ref in addition to the object pointed by it"
 msgstr ""
 
-#: builtin/worktree.c:373 builtin/worktree.c:379
-#, c-format
-msgid "Preparing worktree (new branch '%s')"
+#: builtin/ls-tree.c:30
+msgid "git ls-tree [<options>] <tree-ish> [<path>...]"
 msgstr ""
 
-#: builtin/worktree.c:375
-#, c-format
-msgid "Preparing worktree (resetting branch '%s'; was at %s)"
+#: builtin/ls-tree.c:128
+msgid "only show trees"
 msgstr ""
 
-#: builtin/worktree.c:384
-#, c-format
-msgid "Preparing worktree (checking out '%s')"
+#: builtin/ls-tree.c:130
+msgid "recurse into subtrees"
 msgstr ""
 
-#: builtin/worktree.c:390
-#, c-format
-msgid "Preparing worktree (detached HEAD %s)"
+#: builtin/ls-tree.c:132
+msgid "show trees when recursing"
 msgstr ""
 
-#: builtin/worktree.c:431
-msgid "checkout <branch> even if already checked out in other worktree"
+#: builtin/ls-tree.c:135
+msgid "terminate entries with NUL byte"
 msgstr ""
 
-#: builtin/worktree.c:434
-msgid "create a new branch"
+#: builtin/ls-tree.c:136
+msgid "include object size"
 msgstr ""
 
-#: builtin/worktree.c:436
-msgid "create or reset a branch"
+#: builtin/ls-tree.c:138 builtin/ls-tree.c:140
+msgid "list only filenames"
 msgstr ""
 
-#: builtin/worktree.c:438
-msgid "populate the new working tree"
+#: builtin/ls-tree.c:143
+msgid "use full path names"
 msgstr ""
 
-#: builtin/worktree.c:439
-msgid "keep the new working tree locked"
+#: builtin/ls-tree.c:145
+msgid "list entire tree; not just current directory (implies --full-name)"
 msgstr ""
 
-#: builtin/worktree.c:441
-msgid "set up tracking mode (see git-branch(1))"
+#: builtin/mailsplit.c:241
+#, c-format
+msgid "empty mbox: '%s'"
 msgstr ""
 
-#: builtin/worktree.c:444
-msgid "try to match the new branch name with a remote-tracking branch"
+#: builtin/merge.c:55
+msgid "git merge [<options>] [<commit>...]"
 msgstr ""
 
-#: builtin/worktree.c:452
-msgid "-b, -B, and --detach are mutually exclusive"
+#: builtin/merge.c:56
+msgid "git merge --abort"
 msgstr ""
 
-#: builtin/worktree.c:511
-msgid "--[no-]track can only be used if a new branch is created"
+#: builtin/merge.c:57
+msgid "git merge --continue"
 msgstr ""
 
-#: builtin/worktree.c:611
-msgid "reason for locking"
+#: builtin/merge.c:118
+msgid "switch `m' requires a value"
 msgstr ""
 
-#: builtin/worktree.c:623 builtin/worktree.c:656 builtin/worktree.c:710
-#: builtin/worktree.c:850
+#: builtin/merge.c:141
 #, c-format
-msgid "'%s' is not a working tree"
-msgstr ""
-
-#: builtin/worktree.c:625 builtin/worktree.c:658
-msgid "The main working tree cannot be locked or unlocked"
+msgid "option `%s' requires a value"
 msgstr ""
 
-#: builtin/worktree.c:630
+#: builtin/merge.c:187
 #, c-format
-msgid "'%s' is already locked, reason: %s"
+msgid "Could not find merge strategy '%s'.\n"
 msgstr ""
 
-#: builtin/worktree.c:632
+#: builtin/merge.c:188
 #, c-format
-msgid "'%s' is already locked"
+msgid "Available strategies are:"
 msgstr ""
 
-#: builtin/worktree.c:660
+#: builtin/merge.c:193
 #, c-format
-msgid "'%s' is not locked"
+msgid "Available custom strategies are:"
 msgstr ""
 
-#: builtin/worktree.c:685
-msgid "working trees containing submodules cannot be moved or removed"
+#: builtin/merge.c:244 builtin/pull.c:152
+msgid "do not show a diffstat at the end of the merge"
 msgstr ""
 
-#: builtin/worktree.c:712 builtin/worktree.c:852
-#, c-format
-msgid "'%s' is a main working tree"
+#: builtin/merge.c:247 builtin/pull.c:155
+msgid "show a diffstat at the end of the merge"
 msgstr ""
 
-#: builtin/worktree.c:717
-#, c-format
-msgid "could not figure out destination name from '%s'"
+#: builtin/merge.c:248 builtin/pull.c:158
+msgid "(synonym to --stat)"
 msgstr ""
 
-#: builtin/worktree.c:723
-#, c-format
-msgid "target '%s' already exists"
+#: builtin/merge.c:250 builtin/pull.c:161
+msgid "add (at most <n>) entries from shortlog to merge commit message"
 msgstr ""
 
-#: builtin/worktree.c:730
-#, c-format
-msgid "cannot move a locked working tree, lock reason: %s"
+#: builtin/merge.c:253 builtin/pull.c:167
+msgid "create a single commit instead of doing a merge"
 msgstr ""
 
-#: builtin/worktree.c:732
-msgid "cannot move a locked working tree"
+#: builtin/merge.c:255 builtin/pull.c:170
+msgid "perform a commit if the merge succeeds (default)"
 msgstr ""
 
-#: builtin/worktree.c:735
-#, c-format
-msgid "validation failed, cannot move working tree: %s"
+#: builtin/merge.c:257 builtin/pull.c:173
+msgid "edit message before committing"
 msgstr ""
 
-#: builtin/worktree.c:740
-#, c-format
-msgid "failed to move '%s' to '%s'"
+#: builtin/merge.c:259
+msgid "allow fast-forward (default)"
 msgstr ""
 
-#: builtin/worktree.c:788
-#, c-format
-msgid "failed to run 'git status' on '%s'"
+#: builtin/merge.c:261 builtin/pull.c:180
+msgid "abort if fast-forward is not possible"
 msgstr ""
 
-#: builtin/worktree.c:792
-#, c-format
-msgid "'%s' is dirty, use --force to delete it"
+#: builtin/merge.c:265 builtin/pull.c:183
+msgid "verify that the named commit has a valid GPG signature"
 msgstr ""
 
-#: builtin/worktree.c:797
-#, c-format
-msgid "failed to run 'git status' on '%s', code %d"
+#: builtin/merge.c:266 builtin/notes.c:787 builtin/pull.c:187
+#: builtin/rebase.c:512 builtin/rebase.c:1531 builtin/revert.c:114
+msgid "strategy"
 msgstr ""
 
-#: builtin/worktree.c:808 builtin/worktree.c:822
-#, c-format
-msgid "failed to delete '%s'"
+#: builtin/merge.c:267 builtin/pull.c:188
+msgid "merge strategy to use"
 msgstr ""
 
-#: builtin/worktree.c:834
-msgid "force removing even if the worktree is dirty"
+#: builtin/merge.c:268 builtin/pull.c:191
+msgid "option=value"
 msgstr ""
 
-#: builtin/worktree.c:856
-#, c-format
-msgid "cannot remove a locked working tree, lock reason: %s"
+#: builtin/merge.c:269 builtin/pull.c:192
+msgid "option for selected merge strategy"
 msgstr ""
 
-#: builtin/worktree.c:858
-msgid "cannot remove a locked working tree"
+#: builtin/merge.c:271
+msgid "merge commit message (for a non-fast-forward merge)"
 msgstr ""
 
-#: builtin/worktree.c:861
-#, c-format
-msgid "validation failed, cannot remove working tree: %s"
+#: builtin/merge.c:278
+msgid "abort the current in-progress merge"
 msgstr ""
 
-#: builtin/write-tree.c:14
-msgid "git write-tree [--missing-ok] [--prefix=<prefix>/]"
+#: builtin/merge.c:280
+msgid "--abort but leave index and working tree alone"
 msgstr ""
 
-#: builtin/write-tree.c:27
-msgid "<prefix>/"
+#: builtin/merge.c:282
+msgid "continue the current in-progress merge"
 msgstr ""
 
-#: builtin/write-tree.c:28
-msgid "write tree object for a subdirectory <prefix>"
+#: builtin/merge.c:284 builtin/pull.c:199
+msgid "allow merging unrelated histories"
 msgstr ""
 
-#: builtin/write-tree.c:31
-msgid "only useful for debugging"
+#: builtin/merge.c:290
+msgid "bypass pre-merge-commit and commit-msg hooks"
 msgstr ""
 
-#: credential-cache--daemon.c:222
-#, c-format
-msgid ""
-"The permissions on your socket directory are too loose; other\n"
-"users may be able to read your cached credentials. Consider running:\n"
-"\n"
-"\tchmod 0700 %s"
+#: builtin/merge.c:307
+msgid "could not run stash."
 msgstr ""
 
-#: credential-cache--daemon.c:271
-msgid "print debugging messages to stderr"
+#: builtin/merge.c:312
+msgid "stash failed"
 msgstr ""
 
-#: git.c:27
-msgid ""
-"git [--version] [--help] [-C <path>] [-c <name>=<value>]\n"
-"           [--exec-path[=<path>]] [--html-path] [--man-path] [--info-path]\n"
-"           [-p | --paginate | -P | --no-pager] [--no-replace-objects] [--"
-"bare]\n"
-"           [--git-dir=<path>] [--work-tree=<path>] [--namespace=<name>]\n"
-"           <command> [<args>]"
+#: builtin/merge.c:317
+#, c-format
+msgid "not a valid object: %s"
 msgstr ""
 
-#: git.c:34
-msgid ""
-"'git help -a' and 'git help -g' list available subcommands and some\n"
-"concept guides. See 'git help <command>' or 'git help <concept>'\n"
-"to read about a specific subcommand or concept."
+#: builtin/merge.c:339 builtin/merge.c:356
+msgid "read-tree failed"
 msgstr ""
 
-#: git.c:173
-#, c-format
-msgid "no directory given for --git-dir\n"
+#: builtin/merge.c:386
+msgid " (nothing to squash)"
 msgstr ""
 
-#: git.c:187
+#: builtin/merge.c:397
 #, c-format
-msgid "no namespace given for --namespace\n"
+msgid "Squash commit -- not updating HEAD\n"
 msgstr ""
 
-#: git.c:201
+#: builtin/merge.c:447
 #, c-format
-msgid "no directory given for --work-tree\n"
+msgid "No merge message -- not updating HEAD\n"
 msgstr ""
 
-#: git.c:215
+#: builtin/merge.c:498
 #, c-format
-msgid "no prefix given for --super-prefix\n"
+msgid "'%s' does not point to a commit"
 msgstr ""
 
-#: git.c:237
+#: builtin/merge.c:585
 #, c-format
-msgid "-c expects a configuration string\n"
+msgid "Bad branch.%s.mergeoptions string: %s"
 msgstr ""
 
-#: git.c:275
-#, c-format
-msgid "no directory given for -C\n"
+#: builtin/merge.c:705
+msgid "Not handling anything other than two heads merge."
 msgstr ""
 
-#: git.c:300
+#: builtin/merge.c:719
 #, c-format
-msgid "unknown option: %s\n"
+msgid "Unknown option for merge-recursive: -X%s"
 msgstr ""
 
-#: git.c:765
+#: builtin/merge.c:734
 #, c-format
-msgid "expansion of alias '%s' failed; '%s' is not a git command\n"
+msgid "unable to write %s"
 msgstr ""
 
-#: git.c:777
+#: builtin/merge.c:786
 #, c-format
-msgid "failed to run command '%s': %s\n"
+msgid "Could not read from '%s'"
 msgstr ""
 
-#: http.c:348
+#: builtin/merge.c:795
 #, c-format
-msgid "negative value for http.postbuffer; defaulting to %d"
+msgid "Not committing merge; use 'git commit' to complete the merge.\n"
 msgstr ""
 
-#: http.c:369
-msgid "Delegation control is not supported with cURL < 7.22.0"
+#: builtin/merge.c:801
+msgid ""
+"Please enter a commit message to explain why this merge is necessary,\n"
+"especially if it merges an updated upstream into a topic branch.\n"
+"\n"
 msgstr ""
 
-#: http.c:378
-msgid "Public key pinning not supported with cURL < 7.44.0"
+#: builtin/merge.c:806
+msgid "An empty message aborts the commit.\n"
 msgstr ""
 
-#: http.c:1854
+#: builtin/merge.c:809
 #, c-format
 msgid ""
-"unable to update url base from redirection:\n"
-"  asked for: %s\n"
-"   redirect: %s"
+"Lines starting with '%c' will be ignored, and an empty message aborts\n"
+"the commit.\n"
 msgstr ""
 
-#: remote-curl.c:401
-#, c-format
-msgid "redirecting to %s"
+#: builtin/merge.c:862
+msgid "Empty commit message."
 msgstr ""
 
-#: list-objects-filter-options.h:59
-msgid "args"
+#: builtin/merge.c:877
+#, c-format
+msgid "Wonderful.\n"
 msgstr ""
 
-#: list-objects-filter-options.h:60
-msgid "object filtering"
+#: builtin/merge.c:938
+#, c-format
+msgid "Automatic merge failed; fix conflicts and then commit the result.\n"
 msgstr ""
 
-#: parse-options.h:157
-msgid "expiry-date"
+#: builtin/merge.c:977
+msgid "No current branch."
 msgstr ""
 
-#: parse-options.h:172
-msgid "no-op (backward compatibility)"
+#: builtin/merge.c:979
+msgid "No remote for the current branch."
 msgstr ""
 
-#: parse-options.h:251
-msgid "be more verbose"
+#: builtin/merge.c:981
+msgid "No default upstream defined for the current branch."
 msgstr ""
 
-#: parse-options.h:253
-msgid "be more quiet"
+#: builtin/merge.c:986
+#, c-format
+msgid "No remote-tracking branch for %s from %s"
 msgstr ""
 
-#: parse-options.h:259
-msgid "use <n> digits to display SHA-1s"
+#: builtin/merge.c:1043
+#, c-format
+msgid "Bad value '%s' in environment '%s'"
 msgstr ""
 
-#: command-list.h:50
-msgid "Add file contents to the index"
+#: builtin/merge.c:1146
+#, c-format
+msgid "not something we can merge in %s: %s"
 msgstr ""
 
-#: command-list.h:51
-msgid "Apply a series of patches from a mailbox"
+#: builtin/merge.c:1180
+msgid "not something we can merge"
 msgstr ""
 
-#: command-list.h:52
-msgid "Annotate file lines with commit information"
+#: builtin/merge.c:1283
+msgid "--abort expects no arguments"
 msgstr ""
 
-#: command-list.h:53
-msgid "Apply a patch to files and/or to the index"
+#: builtin/merge.c:1287
+msgid "There is no merge to abort (MERGE_HEAD missing)."
 msgstr ""
 
-#: command-list.h:54
-msgid "Import an Arch repository into Git"
+#: builtin/merge.c:1296
+msgid "--quit expects no arguments"
 msgstr ""
 
-#: command-list.h:55
-msgid "Create an archive of files from a named tree"
+#: builtin/merge.c:1309
+msgid "--continue expects no arguments"
 msgstr ""
 
-#: command-list.h:56
-msgid "Use binary search to find the commit that introduced a bug"
+#: builtin/merge.c:1313
+msgid "There is no merge in progress (MERGE_HEAD missing)."
 msgstr ""
 
-#: command-list.h:57
-msgid "Show what revision and author last modified each line of a file"
+#: builtin/merge.c:1329
+msgid ""
+"You have not concluded your merge (MERGE_HEAD exists).\n"
+"Please, commit your changes before you merge."
 msgstr ""
 
-#: command-list.h:58
-msgid "List, create, or delete branches"
+#: builtin/merge.c:1336
+msgid ""
+"You have not concluded your cherry-pick (CHERRY_PICK_HEAD exists).\n"
+"Please, commit your changes before you merge."
 msgstr ""
 
-#: command-list.h:59
-msgid "Move objects and refs by archive"
+#: builtin/merge.c:1339
+msgid "You have not concluded your cherry-pick (CHERRY_PICK_HEAD exists)."
 msgstr ""
 
-#: command-list.h:60
-msgid "Provide content or type and size information for repository objects"
+#: builtin/merge.c:1353
+msgid "You cannot combine --squash with --no-ff."
 msgstr ""
 
-#: command-list.h:61
-msgid "Display gitattributes information"
+#: builtin/merge.c:1355
+msgid "You cannot combine --squash with --commit."
 msgstr ""
 
-#: command-list.h:62
-msgid "Debug gitignore / exclude files"
+#: builtin/merge.c:1371
+msgid "No commit specified and merge.defaultToUpstream not set."
 msgstr ""
 
-#: command-list.h:63
-msgid "Show canonical names and email addresses of contacts"
+#: builtin/merge.c:1388
+msgid "Squash commit into empty head not supported yet"
 msgstr ""
 
-#: command-list.h:64
-msgid "Switch branches or restore working tree files"
+#: builtin/merge.c:1390
+msgid "Non-fast-forward commit does not make sense into an empty head"
 msgstr ""
 
-#: command-list.h:65
-msgid "Copy files from the index to the working tree"
+#: builtin/merge.c:1395
+#, c-format
+msgid "%s - not something we can merge"
 msgstr ""
 
-#: command-list.h:66
-msgid "Ensures that a reference name is well formed"
+#: builtin/merge.c:1397
+msgid "Can merge only exactly one commit into empty head"
 msgstr ""
 
-#: command-list.h:67
-msgid "Find commits yet to be applied to upstream"
+#: builtin/merge.c:1476
+msgid "refusing to merge unrelated histories"
 msgstr ""
 
-#: command-list.h:68
-msgid "Apply the changes introduced by some existing commits"
+#: builtin/merge.c:1485
+msgid "Already up to date."
 msgstr ""
 
-#: command-list.h:69
-msgid "Graphical alternative to git-commit"
+#: builtin/merge.c:1495
+#, c-format
+msgid "Updating %s..%s\n"
 msgstr ""
 
-#: command-list.h:70
-msgid "Remove untracked files from the working tree"
+#: builtin/merge.c:1537
+#, c-format
+msgid "Trying really trivial in-index merge...\n"
 msgstr ""
 
-#: command-list.h:71
-msgid "Clone a repository into a new directory"
+#: builtin/merge.c:1544
+#, c-format
+msgid "Nope.\n"
 msgstr ""
 
-#: command-list.h:72
-msgid "Display data in columns"
+#: builtin/merge.c:1569
+msgid "Already up to date. Yeeah!"
 msgstr ""
 
-#: command-list.h:73
-msgid "Record changes to the repository"
+#: builtin/merge.c:1575
+msgid "Not possible to fast-forward, aborting."
 msgstr ""
 
-#: command-list.h:74
-msgid "Write and verify Git commit graph files"
+#: builtin/merge.c:1598 builtin/merge.c:1663
+#, c-format
+msgid "Rewinding the tree to pristine...\n"
 msgstr ""
 
-#: command-list.h:75
-msgid "Create a new commit object"
+#: builtin/merge.c:1602
+#, c-format
+msgid "Trying merge strategy %s...\n"
 msgstr ""
 
-#: command-list.h:76
-msgid "Get and set repository or global options"
+#: builtin/merge.c:1654
+#, c-format
+msgid "No merge strategy handled the merge.\n"
 msgstr ""
 
-#: command-list.h:77
-msgid "Count unpacked number of objects and their disk consumption"
+#: builtin/merge.c:1656
+#, c-format
+msgid "Merge with strategy %s failed.\n"
 msgstr ""
 
-#: command-list.h:78
-msgid "Retrieve and store user credentials"
+#: builtin/merge.c:1665
+#, c-format
+msgid "Using the %s to prepare resolving by hand.\n"
 msgstr ""
 
-#: command-list.h:79
-msgid "Helper to temporarily store passwords in memory"
+#: builtin/merge.c:1677
+#, c-format
+msgid "Automatic merge went well; stopped before committing as requested\n"
 msgstr ""
 
-#: command-list.h:80
-msgid "Helper to store credentials on disk"
+#: builtin/merge-base.c:32
+msgid "git merge-base [-a | --all] <commit> <commit>..."
 msgstr ""
 
-#: command-list.h:81
-msgid "Export a single commit to a CVS checkout"
+#: builtin/merge-base.c:33
+msgid "git merge-base [-a | --all] --octopus <commit>..."
 msgstr ""
 
-#: command-list.h:82
-msgid "Salvage your data out of another SCM people love to hate"
+#: builtin/merge-base.c:34
+msgid "git merge-base --independent <commit>..."
 msgstr ""
 
-#: command-list.h:83
-msgid "A CVS server emulator for Git"
+#: builtin/merge-base.c:35
+msgid "git merge-base --is-ancestor <commit> <commit>"
 msgstr ""
 
-#: command-list.h:84
-msgid "A really simple server for Git repositories"
+#: builtin/merge-base.c:36
+msgid "git merge-base --fork-point <ref> [<commit>]"
 msgstr ""
 
-#: command-list.h:85
-msgid "Give an object a human readable name based on an available ref"
+#: builtin/merge-base.c:153
+msgid "output all common ancestors"
 msgstr ""
 
-#: command-list.h:86
-msgid "Show changes between commits, commit and working tree, etc"
+#: builtin/merge-base.c:155
+msgid "find ancestors for a single n-way merge"
 msgstr ""
 
-#: command-list.h:87
-msgid "Compares files in the working tree and the index"
+#: builtin/merge-base.c:157
+msgid "list revs not reachable from others"
 msgstr ""
 
-#: command-list.h:88
-msgid "Compare a tree to the working tree or index"
+#: builtin/merge-base.c:159
+msgid "is the first one ancestor of the other?"
 msgstr ""
 
-#: command-list.h:89
-msgid "Compares the content and mode of blobs found via two tree objects"
+#: builtin/merge-base.c:161
+msgid "find where <commit> forked from reflog of <ref>"
 msgstr ""
 
-#: command-list.h:90
-msgid "Show changes using common diff tools"
+#: builtin/merge-file.c:9
+msgid ""
+"git merge-file [<options>] [-L <name1> [-L <orig> [-L <name2>]]] <file1> "
+"<orig-file> <file2>"
 msgstr ""
 
-#: command-list.h:91
-msgid "Git data exporter"
+#: builtin/merge-file.c:35
+msgid "send results to standard output"
 msgstr ""
 
-#: command-list.h:92
-msgid "Backend for fast Git data importers"
+#: builtin/merge-file.c:36
+msgid "use a diff3 based merge"
 msgstr ""
 
-#: command-list.h:93
-msgid "Download objects and refs from another repository"
+#: builtin/merge-file.c:37
+msgid "for conflicts, use our version"
 msgstr ""
 
-#: command-list.h:94
-msgid "Receive missing objects from another repository"
+#: builtin/merge-file.c:39
+msgid "for conflicts, use their version"
 msgstr ""
 
-#: command-list.h:95
-msgid "Rewrite branches"
+#: builtin/merge-file.c:41
+msgid "for conflicts, use a union version"
 msgstr ""
 
-#: command-list.h:96
-msgid "Produce a merge commit message"
+#: builtin/merge-file.c:44
+msgid "for conflicts, use this marker size"
 msgstr ""
 
-#: command-list.h:97
-msgid "Output information on each ref"
+#: builtin/merge-file.c:45
+msgid "do not warn about conflicts"
 msgstr ""
 
-#: command-list.h:98
-msgid "Prepare patches for e-mail submission"
+#: builtin/merge-file.c:47
+msgid "set labels for file1/orig-file/file2"
 msgstr ""
 
-#: command-list.h:99
-msgid "Verifies the connectivity and validity of the objects in the database"
+#: builtin/merge-recursive.c:47
+#, c-format
+msgid "unknown option %s"
 msgstr ""
 
-#: command-list.h:100
-msgid "Cleanup unnecessary files and optimize the local repository"
+#: builtin/merge-recursive.c:53
+#, c-format
+msgid "could not parse object '%s'"
 msgstr ""
 
-#: command-list.h:101
-msgid "Extract commit ID from an archive created using git-archive"
+#: builtin/merge-recursive.c:57
+#, c-format
+msgid "cannot handle more than %d base. Ignoring %s."
+msgid_plural "cannot handle more than %d bases. Ignoring %s."
+msgstr[0] ""
+msgstr[1] ""
+
+#: builtin/merge-recursive.c:65
+msgid "not handling anything other than two heads merge."
 msgstr ""
 
-#: command-list.h:102
-msgid "Print lines matching a pattern"
+#: builtin/merge-recursive.c:74 builtin/merge-recursive.c:76
+#, c-format
+msgid "could not resolve ref '%s'"
 msgstr ""
 
-#: command-list.h:103
-msgid "A portable graphical interface to Git"
+#: builtin/merge-recursive.c:82
+#, c-format
+msgid "Merging %s with %s\n"
 msgstr ""
 
-#: command-list.h:104
-msgid "Compute object ID and optionally creates a blob from a file"
+#: builtin/mktree.c:66
+msgid "git mktree [-z] [--missing] [--batch]"
 msgstr ""
 
-#: command-list.h:105
-msgid "Display help information about Git"
+#: builtin/mktree.c:154
+msgid "input is NUL terminated"
 msgstr ""
 
-#: command-list.h:106
-msgid "Server side implementation of Git over HTTP"
+#: builtin/mktree.c:155 builtin/write-tree.c:26
+msgid "allow missing objects"
 msgstr ""
 
-#: command-list.h:107
-msgid "Download from a remote Git repository via HTTP"
+#: builtin/mktree.c:156
+msgid "allow creation of more than one tree"
 msgstr ""
 
-#: command-list.h:108
-msgid "Push objects over HTTP/DAV to another repository"
+#: builtin/multi-pack-index.c:9
+msgid ""
+"git multi-pack-index [<options>] (write|verify|expire|repack --batch-"
+"size=<size>)"
 msgstr ""
 
-#: command-list.h:109
-msgid "Send a collection of patches from stdin to an IMAP folder"
+#: builtin/multi-pack-index.c:26
+msgid "object directory containing set of packfile and pack-index pairs"
 msgstr ""
 
-#: command-list.h:110
-msgid "Build pack index file for an existing packed archive"
+#: builtin/multi-pack-index.c:29
+msgid ""
+"during repack, collect pack-files of smaller size into a batch that is "
+"larger than this size"
 msgstr ""
 
-#: command-list.h:111
-msgid "Create an empty Git repository or reinitialize an existing one"
+#: builtin/multi-pack-index.c:50 builtin/prune-packed.c:67
+msgid "too many arguments"
 msgstr ""
 
-#: command-list.h:112
-msgid "Instantly browse your working repository in gitweb"
+#: builtin/multi-pack-index.c:60
+msgid "--batch-size option is only for 'repack' subcommand"
 msgstr ""
 
-#: command-list.h:113
-msgid "add or parse structured information in commit messages"
+#: builtin/multi-pack-index.c:69
+#, c-format
+msgid "unrecognized subcommand: %s"
 msgstr ""
 
-#: command-list.h:114
-msgid "The Git repository browser"
+#: builtin/mv.c:18
+msgid "git mv [<options>] <source>... <destination>"
 msgstr ""
 
-#: command-list.h:115
-msgid "Show commit logs"
+#: builtin/mv.c:83
+#, c-format
+msgid "Directory %s is in index and no submodule?"
 msgstr ""
 
-#: command-list.h:116
-msgid "Show information about files in the index and the working tree"
+#: builtin/mv.c:85
+msgid "Please stage your changes to .gitmodules or stash them to proceed"
 msgstr ""
 
-#: command-list.h:117
-msgid "List references in a remote repository"
+#: builtin/mv.c:103
+#, c-format
+msgid "%.*s is in index"
 msgstr ""
 
-#: command-list.h:118
-msgid "List the contents of a tree object"
+#: builtin/mv.c:125
+msgid "force move/rename even if target exists"
 msgstr ""
 
-#: command-list.h:119
-msgid "Extracts patch and authorship from a single e-mail message"
+#: builtin/mv.c:127
+msgid "skip move/rename errors"
 msgstr ""
 
-#: command-list.h:120
-msgid "Simple UNIX mbox splitter program"
+#: builtin/mv.c:169
+#, c-format
+msgid "destination '%s' is not a directory"
 msgstr ""
 
-#: command-list.h:121
-msgid "Join two or more development histories together"
+#: builtin/mv.c:180
+#, c-format
+msgid "Checking rename of '%s' to '%s'\n"
 msgstr ""
 
-#: command-list.h:122
-msgid "Find as good common ancestors as possible for a merge"
+#: builtin/mv.c:184
+msgid "bad source"
 msgstr ""
 
-#: command-list.h:123
-msgid "Run a three-way file merge"
+#: builtin/mv.c:187
+msgid "can not move directory into itself"
 msgstr ""
 
-#: command-list.h:124
-msgid "Run a merge for files needing merging"
+#: builtin/mv.c:190
+msgid "cannot move directory over file"
 msgstr ""
 
-#: command-list.h:125
-msgid "The standard helper program to use with git-merge-index"
+#: builtin/mv.c:199
+msgid "source directory is empty"
 msgstr ""
 
-#: command-list.h:126
-msgid "Run merge conflict resolution tools to resolve merge conflicts"
+#: builtin/mv.c:224
+msgid "not under version control"
 msgstr ""
 
-#: command-list.h:127
-msgid "Show three-way merge without touching index"
+#: builtin/mv.c:227
+msgid "destination exists"
 msgstr ""
 
-#: command-list.h:128
-msgid "Creates a tag object"
+#: builtin/mv.c:235
+#, c-format
+msgid "overwriting '%s'"
 msgstr ""
 
-#: command-list.h:129
-msgid "Build a tree-object from ls-tree formatted text"
+#: builtin/mv.c:238
+msgid "Cannot overwrite"
 msgstr ""
 
-#: command-list.h:130
-msgid "Move or rename a file, a directory, or a symlink"
+#: builtin/mv.c:241
+msgid "multiple sources for the same target"
 msgstr ""
 
-#: command-list.h:131
-msgid "Find symbolic names for given revs"
+#: builtin/mv.c:243
+msgid "destination directory does not exist"
 msgstr ""
 
-#: command-list.h:132
-msgid "Add or inspect object notes"
+#: builtin/mv.c:250
+#, c-format
+msgid "%s, source=%s, destination=%s"
 msgstr ""
 
-#: command-list.h:133
-msgid "Import from and submit to Perforce repositories"
+#: builtin/mv.c:271
+#, c-format
+msgid "Renaming %s to %s\n"
 msgstr ""
 
-#: command-list.h:134
-msgid "Create a packed archive of objects"
+#: builtin/mv.c:277 builtin/remote.c:716 builtin/repack.c:518
+#, c-format
+msgid "renaming '%s' failed"
 msgstr ""
 
-#: command-list.h:135
-msgid "Find redundant pack files"
+#: builtin/name-rev.c:403
+msgid "git name-rev [<options>] <commit>..."
 msgstr ""
 
-#: command-list.h:136
-msgid "Pack heads and tags for efficient repository access"
+#: builtin/name-rev.c:404
+msgid "git name-rev [<options>] --all"
 msgstr ""
 
-#: command-list.h:137
-msgid "Routines to help parsing remote repository access parameters"
+#: builtin/name-rev.c:405
+msgid "git name-rev [<options>] --stdin"
 msgstr ""
 
-#: command-list.h:138
-msgid "Compute unique ID for a patch"
+#: builtin/name-rev.c:462
+msgid "print only names (no SHA-1)"
 msgstr ""
 
-#: command-list.h:139
-msgid "Prune all unreachable objects from the object database"
+#: builtin/name-rev.c:463
+msgid "only use tags to name the commits"
 msgstr ""
 
-#: command-list.h:140
-msgid "Remove extra objects that are already in pack files"
+#: builtin/name-rev.c:465
+msgid "only use refs matching <pattern>"
 msgstr ""
 
-#: command-list.h:141
-msgid "Fetch from and integrate with another repository or a local branch"
+#: builtin/name-rev.c:467
+msgid "ignore refs matching <pattern>"
 msgstr ""
 
-#: command-list.h:142
-msgid "Update remote refs along with associated objects"
+#: builtin/name-rev.c:469
+msgid "list all commits reachable from all refs"
 msgstr ""
 
-#: command-list.h:143
-msgid "Applies a quilt patchset onto the current branch"
+#: builtin/name-rev.c:470
+msgid "read from stdin"
 msgstr ""
 
-#: command-list.h:144
-msgid "Reads tree information into the index"
+#: builtin/name-rev.c:471
+msgid "allow to print `undefined` names (default)"
 msgstr ""
 
-#: command-list.h:145
-msgid "Reapply commits on top of another base tip"
+#: builtin/name-rev.c:477
+msgid "dereference tags in the input (internal use)"
 msgstr ""
 
-#: command-list.h:146
-msgid "Receive what is pushed into the repository"
+#: builtin/notes.c:28
+msgid "git notes [--ref <notes-ref>] [list [<object>]]"
 msgstr ""
 
-#: command-list.h:147
-msgid "Manage reflog information"
+#: builtin/notes.c:29
+msgid ""
+"git notes [--ref <notes-ref>] add [-f] [--allow-empty] [-m <msg> | -F <file> "
+"| (-c | -C) <object>] [<object>]"
 msgstr ""
 
-#: command-list.h:148
-msgid "Manage set of tracked repositories"
+#: builtin/notes.c:30
+msgid "git notes [--ref <notes-ref>] copy [-f] <from-object> <to-object>"
 msgstr ""
 
-#: command-list.h:149
-msgid "Pack unpacked objects in a repository"
+#: builtin/notes.c:31
+msgid ""
+"git notes [--ref <notes-ref>] append [--allow-empty] [-m <msg> | -F <file> | "
+"(-c | -C) <object>] [<object>]"
 msgstr ""
 
-#: command-list.h:150
-msgid "Create, list, delete refs to replace objects"
+#: builtin/notes.c:32
+msgid "git notes [--ref <notes-ref>] edit [--allow-empty] [<object>]"
 msgstr ""
 
-#: command-list.h:151
-msgid "Generates a summary of pending changes"
+#: builtin/notes.c:33
+msgid "git notes [--ref <notes-ref>] show [<object>]"
 msgstr ""
 
-#: command-list.h:152
-msgid "Reuse recorded resolution of conflicted merges"
+#: builtin/notes.c:34
+msgid ""
+"git notes [--ref <notes-ref>] merge [-v | -q] [-s <strategy>] <notes-ref>"
 msgstr ""
 
-#: command-list.h:153
-msgid "Reset current HEAD to the specified state"
+#: builtin/notes.c:35
+msgid "git notes merge --commit [-v | -q]"
 msgstr ""
 
-#: command-list.h:154
-msgid "Revert some existing commits"
+#: builtin/notes.c:36
+msgid "git notes merge --abort [-v | -q]"
 msgstr ""
 
-#: command-list.h:155
-msgid "Lists commit objects in reverse chronological order"
+#: builtin/notes.c:37
+msgid "git notes [--ref <notes-ref>] remove [<object>...]"
 msgstr ""
 
-#: command-list.h:156
-msgid "Pick out and massage parameters"
+#: builtin/notes.c:38
+msgid "git notes [--ref <notes-ref>] prune [-n] [-v]"
 msgstr ""
 
-#: command-list.h:157
-msgid "Remove files from the working tree and from the index"
+#: builtin/notes.c:39
+msgid "git notes [--ref <notes-ref>] get-ref"
 msgstr ""
 
-#: command-list.h:158
-msgid "Send a collection of patches as emails"
+#: builtin/notes.c:44
+msgid "git notes [list [<object>]]"
 msgstr ""
 
-#: command-list.h:159
-msgid "Push objects over Git protocol to another repository"
+#: builtin/notes.c:49
+msgid "git notes add [<options>] [<object>]"
 msgstr ""
 
-#: command-list.h:160
-msgid "Restricted login shell for Git-only SSH access"
+#: builtin/notes.c:54
+msgid "git notes copy [<options>] <from-object> <to-object>"
 msgstr ""
 
-#: command-list.h:161
-msgid "Summarize 'git log' output"
+#: builtin/notes.c:55
+msgid "git notes copy --stdin [<from-object> <to-object>]..."
 msgstr ""
 
-#: command-list.h:162
-msgid "Show various types of objects"
+#: builtin/notes.c:60
+msgid "git notes append [<options>] [<object>]"
 msgstr ""
 
-#: command-list.h:163
-msgid "Show branches and their commits"
+#: builtin/notes.c:65
+msgid "git notes edit [<object>]"
 msgstr ""
 
-#: command-list.h:164
-msgid "Show packed archive index"
+#: builtin/notes.c:70
+msgid "git notes show [<object>]"
 msgstr ""
 
-#: command-list.h:165
-msgid "List references in a local repository"
+#: builtin/notes.c:75
+msgid "git notes merge [<options>] <notes-ref>"
 msgstr ""
 
-#: command-list.h:166
-msgid "Git's i18n setup code for shell scripts"
+#: builtin/notes.c:76
+msgid "git notes merge --commit [<options>]"
 msgstr ""
 
-#: command-list.h:167
-msgid "Common Git shell script setup code"
+#: builtin/notes.c:77
+msgid "git notes merge --abort [<options>]"
 msgstr ""
 
-#: command-list.h:168
-msgid "Stash the changes in a dirty working directory away"
+#: builtin/notes.c:82
+msgid "git notes remove [<object>]"
 msgstr ""
 
-#: command-list.h:169
-msgid "Add file contents to the staging area"
+#: builtin/notes.c:87
+msgid "git notes prune [<options>]"
 msgstr ""
 
-#: command-list.h:170
-msgid "Show the working tree status"
+#: builtin/notes.c:92
+msgid "git notes get-ref"
 msgstr ""
 
-#: command-list.h:171
-msgid "Remove unnecessary whitespace"
+#: builtin/notes.c:97
+msgid "Write/edit the notes for the following object:"
 msgstr ""
 
-#: command-list.h:172
-msgid "Initialize, update or inspect submodules"
+#: builtin/notes.c:150
+#, c-format
+msgid "unable to start 'show' for object '%s'"
 msgstr ""
 
-#: command-list.h:173
-msgid "Bidirectional operation between a Subversion repository and Git"
+#: builtin/notes.c:154
+msgid "could not read 'show' output"
 msgstr ""
 
-#: command-list.h:174
-msgid "Read, modify and delete symbolic refs"
+#: builtin/notes.c:162
+#, c-format
+msgid "failed to finish 'show' for object '%s'"
 msgstr ""
 
-#: command-list.h:175
-msgid "Create, list, delete or verify a tag object signed with GPG"
+#: builtin/notes.c:197
+msgid "please supply the note contents using either -m or -F option"
 msgstr ""
 
-#: command-list.h:176
-msgid "Creates a temporary file with a blob's contents"
+#: builtin/notes.c:206
+msgid "unable to write note object"
 msgstr ""
 
-#: command-list.h:177
-msgid "Unpack objects from a packed archive"
+#: builtin/notes.c:208
+#, c-format
+msgid "the note contents have been left in %s"
 msgstr ""
 
-#: command-list.h:178
-msgid "Register file contents in the working tree to the index"
+#: builtin/notes.c:242 builtin/tag.c:532
+#, c-format
+msgid "could not open or read '%s'"
 msgstr ""
 
-#: command-list.h:179
-msgid "Update the object name stored in a ref safely"
+#: builtin/notes.c:263 builtin/notes.c:313 builtin/notes.c:315
+#: builtin/notes.c:383 builtin/notes.c:438 builtin/notes.c:526
+#: builtin/notes.c:531 builtin/notes.c:610 builtin/notes.c:672
+#, c-format
+msgid "failed to resolve '%s' as a valid ref."
 msgstr ""
 
-#: command-list.h:180
-msgid "Update auxiliary info file to help dumb servers"
+#: builtin/notes.c:265
+#, c-format
+msgid "failed to read object '%s'."
 msgstr ""
 
-#: command-list.h:181
-msgid "Send archive back to git-archive"
+#: builtin/notes.c:268
+#, c-format
+msgid "cannot read note data from non-blob object '%s'."
 msgstr ""
 
-#: command-list.h:182
-msgid "Send objects packed back to git-fetch-pack"
+#: builtin/notes.c:309
+#, c-format
+msgid "malformed input line: '%s'."
 msgstr ""
 
-#: command-list.h:183
-msgid "Show a Git logical variable"
+#: builtin/notes.c:324
+#, c-format
+msgid "failed to copy notes from '%s' to '%s'"
 msgstr ""
 
-#: command-list.h:184
-msgid "Check the GPG signature of commits"
+#. TRANSLATORS: the first %s will be replaced by a git
+#. notes command: 'add', 'merge', 'remove', etc.
+#.
+#: builtin/notes.c:356
+#, c-format
+msgid "refusing to %s notes in %s (outside of refs/notes/)"
 msgstr ""
 
-#: command-list.h:185
-msgid "Validate packed Git archive files"
+#: builtin/notes.c:376 builtin/notes.c:431 builtin/notes.c:509
+#: builtin/notes.c:521 builtin/notes.c:598 builtin/notes.c:665
+#: builtin/notes.c:815 builtin/notes.c:963 builtin/notes.c:985
+msgid "too many parameters"
 msgstr ""
 
-#: command-list.h:186
-msgid "Check the GPG signature of tags"
+#: builtin/notes.c:389 builtin/notes.c:678
+#, c-format
+msgid "no note found for object %s."
 msgstr ""
 
-#: command-list.h:187
-msgid "Git web interface (web frontend to Git repositories)"
+#: builtin/notes.c:410 builtin/notes.c:576
+msgid "note contents as a string"
 msgstr ""
 
-#: command-list.h:188
-msgid "Show logs with difference each commit introduces"
+#: builtin/notes.c:413 builtin/notes.c:579
+msgid "note contents in a file"
 msgstr ""
 
-#: command-list.h:189
-msgid "Manage multiple working trees"
+#: builtin/notes.c:416 builtin/notes.c:582
+msgid "reuse and edit specified note object"
 msgstr ""
 
-#: command-list.h:190
-msgid "Create a tree object from the current index"
+#: builtin/notes.c:419 builtin/notes.c:585
+msgid "reuse specified note object"
 msgstr ""
 
-#: command-list.h:191
-msgid "Defining attributes per path"
+#: builtin/notes.c:422 builtin/notes.c:588
+msgid "allow storing empty note"
 msgstr ""
 
-#: command-list.h:192
-msgid "Git command-line interface and conventions"
+#: builtin/notes.c:423 builtin/notes.c:496
+msgid "replace existing notes"
 msgstr ""
 
-#: command-list.h:193
-msgid "A Git core tutorial for developers"
+#: builtin/notes.c:448
+#, c-format
+msgid ""
+"Cannot add notes. Found existing notes for object %s. Use '-f' to overwrite "
+"existing notes"
 msgstr ""
 
-#: command-list.h:194
-msgid "Git for CVS users"
+#: builtin/notes.c:463 builtin/notes.c:544
+#, c-format
+msgid "Overwriting existing notes for object %s\n"
 msgstr ""
 
-#: command-list.h:195
-msgid "Tweaking diff output"
+#: builtin/notes.c:475 builtin/notes.c:637 builtin/notes.c:902
+#, c-format
+msgid "Removing note for object %s\n"
 msgstr ""
 
-#: command-list.h:196
-msgid "A useful minimum set of commands for Everyday Git"
+#: builtin/notes.c:497
+msgid "read objects from stdin"
 msgstr ""
 
-#: command-list.h:197
-msgid "A Git Glossary"
+#: builtin/notes.c:499
+msgid "load rewriting config for <command> (implies --stdin)"
 msgstr ""
 
-#: command-list.h:198
-msgid "Hooks used by Git"
+#: builtin/notes.c:517
+msgid "too few parameters"
 msgstr ""
 
-#: command-list.h:199
-msgid "Specifies intentionally untracked files to ignore"
+#: builtin/notes.c:538
+#, c-format
+msgid ""
+"Cannot copy notes. Found existing notes for object %s. Use '-f' to overwrite "
+"existing notes"
 msgstr ""
 
-#: command-list.h:200
-msgid "Defining submodule properties"
+#: builtin/notes.c:550
+#, c-format
+msgid "missing notes on source object %s. Cannot copy."
 msgstr ""
 
-#: command-list.h:201
-msgid "Git namespaces"
+#: builtin/notes.c:603
+#, c-format
+msgid ""
+"The -m/-F/-c/-C options have been deprecated for the 'edit' subcommand.\n"
+"Please use 'git notes add -f -m/-F/-c/-C' instead.\n"
 msgstr ""
 
-#: command-list.h:202
-msgid "Git Repository Layout"
+#: builtin/notes.c:698
+msgid "failed to delete ref NOTES_MERGE_PARTIAL"
 msgstr ""
 
-#: command-list.h:203
-msgid "Specifying revisions and ranges for Git"
+#: builtin/notes.c:700
+msgid "failed to delete ref NOTES_MERGE_REF"
 msgstr ""
 
-#: command-list.h:204
-msgid "A tutorial introduction to Git: part two"
+#: builtin/notes.c:702
+msgid "failed to remove 'git notes merge' worktree"
 msgstr ""
 
-#: command-list.h:205
-msgid "A tutorial introduction to Git"
+#: builtin/notes.c:722
+msgid "failed to read ref NOTES_MERGE_PARTIAL"
 msgstr ""
 
-#: command-list.h:206
-msgid "An overview of recommended workflows with Git"
+#: builtin/notes.c:724
+msgid "could not find commit from NOTES_MERGE_PARTIAL."
 msgstr ""
 
-#: rerere.h:40
-msgid "update the index with reused conflict resolution if possible"
+#: builtin/notes.c:726
+msgid "could not parse commit from NOTES_MERGE_PARTIAL."
 msgstr ""
 
-#: git-bisect.sh:54
-msgid "You need to start by \"git bisect start\""
+#: builtin/notes.c:739
+msgid "failed to resolve NOTES_MERGE_REF"
 msgstr ""
 
-#. TRANSLATORS: Make sure to include [Y] and [n] in your
-#. translation. The program will only accept English input
-#. at this point.
-#: git-bisect.sh:60
-msgid "Do you want me to do it for you [Y/n]? "
+#: builtin/notes.c:742
+msgid "failed to finalize notes merge"
 msgstr ""
 
-#: git-bisect.sh:121
-#, sh-format
-msgid "unrecognised option: '$arg'"
+#: builtin/notes.c:768
+#, c-format
+msgid "unknown notes merge strategy %s"
 msgstr ""
 
-#: git-bisect.sh:125
-#, sh-format
-msgid "'$arg' does not appear to be a valid revision"
+#: builtin/notes.c:784
+msgid "General options"
 msgstr ""
 
-#: git-bisect.sh:154
-msgid "Bad HEAD - I need a HEAD"
+#: builtin/notes.c:786
+msgid "Merge options"
 msgstr ""
 
-#: git-bisect.sh:167
-#, sh-format
+#: builtin/notes.c:788
 msgid ""
-"Checking out '$start_head' failed. Try 'git bisect reset <valid-branch>'."
+"resolve notes conflicts using the given strategy (manual/ours/theirs/union/"
+"cat_sort_uniq)"
 msgstr ""
 
-#: git-bisect.sh:177
-msgid "won't bisect on cg-seek'ed tree"
+#: builtin/notes.c:790
+msgid "Committing unmerged notes"
 msgstr ""
 
-#: git-bisect.sh:181
-msgid "Bad HEAD - strange symbolic ref"
+#: builtin/notes.c:792
+msgid "finalize notes merge by committing unmerged notes"
 msgstr ""
 
-#: git-bisect.sh:233
-#, sh-format
-msgid "Bad bisect_write argument: $state"
+#: builtin/notes.c:794
+msgid "Aborting notes merge resolution"
 msgstr ""
 
-#: git-bisect.sh:246
-#, sh-format
-msgid "Bad rev input: $arg"
+#: builtin/notes.c:796
+msgid "abort notes merge"
 msgstr ""
 
-#: git-bisect.sh:265
-#, sh-format
-msgid "Bad rev input: $bisected_head"
+#: builtin/notes.c:807
+msgid "cannot mix --commit, --abort or -s/--strategy"
 msgstr ""
 
-#: git-bisect.sh:274
-#, sh-format
-msgid "Bad rev input: $rev"
+#: builtin/notes.c:812
+msgid "must specify a notes ref to merge"
 msgstr ""
 
-#: git-bisect.sh:283
-#, sh-format
-msgid "'git bisect $TERM_BAD' can take only one argument."
+#: builtin/notes.c:836
+#, c-format
+msgid "unknown -s/--strategy: %s"
 msgstr ""
 
-#: git-bisect.sh:306
-#, sh-format
-msgid "Warning: bisecting only with a $TERM_BAD commit."
+#: builtin/notes.c:873
+#, c-format
+msgid "a notes merge into %s is already in-progress at %s"
 msgstr ""
 
-#. TRANSLATORS: Make sure to include [Y] and [n] in your
-#. translation. The program will only accept English input
-#. at this point.
-#: git-bisect.sh:312
-msgid "Are you sure [Y/n]? "
+#: builtin/notes.c:876
+#, c-format
+msgid "failed to store link to current notes ref (%s)"
 msgstr ""
 
-#: git-bisect.sh:324
-#, sh-format
+#: builtin/notes.c:878
+#, c-format
 msgid ""
-"You need to give me at least one $bad_syn and one $good_syn revision.\n"
-"(You can use \"git bisect $bad_syn\" and \"git bisect $good_syn\" for that.)"
+"Automatic notes merge failed. Fix conflicts in %s and commit the result with "
+"'git notes merge --commit', or abort the merge with 'git notes merge --"
+"abort'.\n"
 msgstr ""
 
-#: git-bisect.sh:327
-#, sh-format
-msgid ""
-"You need to start by \"git bisect start\".\n"
-"You then need to give me at least one $good_syn and one $bad_syn revision.\n"
-"(You can use \"git bisect $bad_syn\" and \"git bisect $good_syn\" for that.)"
+#: builtin/notes.c:897 builtin/tag.c:545
+#, c-format
+msgid "Failed to resolve '%s' as a valid ref."
 msgstr ""
 
-#: git-bisect.sh:398 git-bisect.sh:512
-msgid "We are not bisecting."
+#: builtin/notes.c:900
+#, c-format
+msgid "Object %s has no note\n"
 msgstr ""
 
-#: git-bisect.sh:405
-#, sh-format
-msgid "'$invalid' is not a valid commit"
+#: builtin/notes.c:912
+msgid "attempt to remove non-existent note is not an error"
 msgstr ""
 
-#: git-bisect.sh:414
-#, sh-format
-msgid ""
-"Could not check out original HEAD '$branch'.\n"
-"Try 'git bisect reset <commit>'."
+#: builtin/notes.c:915
+msgid "read object names from the standard input"
 msgstr ""
 
-#: git-bisect.sh:422
-msgid "No logfile given"
+#: builtin/notes.c:954 builtin/prune.c:130 builtin/worktree.c:164
+msgid "do not remove, show only"
 msgstr ""
 
-#: git-bisect.sh:423
-#, sh-format
-msgid "cannot read $file for replaying"
+#: builtin/notes.c:955
+msgid "report pruned notes"
 msgstr ""
 
-#: git-bisect.sh:444
-msgid "?? what are you talking about?"
+#: builtin/notes.c:998
+msgid "notes-ref"
 msgstr ""
 
-#: git-bisect.sh:453
-msgid "bisect run failed: no command provided."
+#: builtin/notes.c:999
+msgid "use notes from <notes-ref>"
 msgstr ""
 
-#: git-bisect.sh:458
-#, sh-format
-msgid "running $command"
+#: builtin/notes.c:1034 builtin/stash.c:1607
+#, c-format
+msgid "unknown subcommand: %s"
 msgstr ""
 
-#: git-bisect.sh:465
-#, sh-format
+#: builtin/pack-objects.c:52
 msgid ""
-"bisect run failed:\n"
-"exit code $res from '$command' is < 0 or >= 128"
+"git pack-objects --stdout [<options>...] [< <ref-list> | < <object-list>]"
 msgstr ""
 
-#: git-bisect.sh:491
-msgid "bisect run cannot continue any more"
+#: builtin/pack-objects.c:53
+msgid ""
+"git pack-objects [<options>...] <base-name> [< <ref-list> | < <object-list>]"
 msgstr ""
 
-#: git-bisect.sh:497
-#, sh-format
-msgid ""
-"bisect run failed:\n"
-"'bisect_state $state' exited with error code $res"
+#: builtin/pack-objects.c:428
+#, c-format
+msgid "bad packed object CRC for %s"
 msgstr ""
 
-#: git-bisect.sh:504
-msgid "bisect run success"
+#: builtin/pack-objects.c:439
+#, c-format
+msgid "corrupt packed object for %s"
 msgstr ""
 
-#: git-bisect.sh:533
-#, sh-format
-msgid "Invalid command: you're currently in a $TERM_BAD/$TERM_GOOD bisect."
+#: builtin/pack-objects.c:570
+#, c-format
+msgid "recursive delta detected for object %s"
 msgstr ""
 
-#: git-bisect.sh:567
-msgid "no terms defined"
+#: builtin/pack-objects.c:781
+#, c-format
+msgid "ordered %u objects, expected %<PRIu32>"
 msgstr ""
 
-#: git-bisect.sh:584
-#, sh-format
-msgid ""
-"invalid argument $arg for 'git bisect terms'.\n"
-"Supported options are: --term-good|--term-old and --term-bad|--term-new."
+#: builtin/pack-objects.c:794
+#, c-format
+msgid "packfile is invalid: %s"
 msgstr ""
 
-#: git-merge-octopus.sh:46
-msgid ""
-"Error: Your local changes to the following files would be overwritten by "
-"merge"
+#: builtin/pack-objects.c:798
+#, c-format
+msgid "unable to open packfile for reuse: %s"
 msgstr ""
 
-#: git-merge-octopus.sh:61
-msgid "Automated merge did not work."
+#: builtin/pack-objects.c:802
+msgid "unable to seek in reused packfile"
 msgstr ""
 
-#: git-merge-octopus.sh:62
-msgid "Should not be doing an octopus."
+#: builtin/pack-objects.c:813
+msgid "unable to read from reused packfile"
 msgstr ""
 
-#: git-merge-octopus.sh:73
-#, sh-format
-msgid "Unable to find common commit with $pretty_name"
+#: builtin/pack-objects.c:841
+msgid "disabling bitmap writing, packs are split due to pack.packSizeLimit"
 msgstr ""
 
-#: git-merge-octopus.sh:77
-#, sh-format
-msgid "Already up to date with $pretty_name"
+#: builtin/pack-objects.c:854
+msgid "Writing objects"
 msgstr ""
 
-#: git-merge-octopus.sh:89
-#, sh-format
-msgid "Fast-forwarding to: $pretty_name"
+#: builtin/pack-objects.c:917 builtin/update-index.c:90
+#, c-format
+msgid "failed to stat %s"
 msgstr ""
 
-#: git-merge-octopus.sh:97
-#, sh-format
-msgid "Trying simple merge with $pretty_name"
+#: builtin/pack-objects.c:970
+#, c-format
+msgid "wrote %<PRIu32> objects while expecting %<PRIu32>"
 msgstr ""
 
-#: git-merge-octopus.sh:102
-msgid "Simple merge did not work, trying automatic merge."
+#: builtin/pack-objects.c:1164
+msgid "disabling bitmap writing, as some objects are not being packed"
 msgstr ""
 
-#: git-rebase.sh:61
-msgid ""
-"Resolve all conflicts manually, mark them as resolved with\n"
-"\"git add/rm <conflicted_files>\", then run \"git rebase --continue\".\n"
-"You can instead skip this commit: run \"git rebase --skip\".\n"
-"To abort and get back to the state before \"git rebase\", run \"git rebase --"
-"abort\"."
+#: builtin/pack-objects.c:1592
+#, c-format
+msgid "delta base offset overflow in pack for %s"
 msgstr ""
 
-#: git-rebase.sh:173 git-rebase.sh:442
-#, sh-format
-msgid "Could not move back to $head_name"
+#: builtin/pack-objects.c:1601
+#, c-format
+msgid "delta base offset out of bound for %s"
 msgstr ""
 
-#: git-rebase.sh:184
-msgid "Applied autostash."
+#: builtin/pack-objects.c:1870
+msgid "Counting objects"
 msgstr ""
 
-#: git-rebase.sh:187
-#, sh-format
-msgid "Cannot store $stash_sha1"
+#: builtin/pack-objects.c:2000
+#, c-format
+msgid "unable to get size of %s"
 msgstr ""
 
-#: git-rebase.sh:229
-msgid "The pre-rebase hook refused to rebase."
+#: builtin/pack-objects.c:2015
+#, c-format
+msgid "unable to parse object header of %s"
 msgstr ""
 
-#: git-rebase.sh:234
-msgid "It looks like 'git am' is in progress. Cannot rebase."
+#: builtin/pack-objects.c:2085 builtin/pack-objects.c:2101
+#: builtin/pack-objects.c:2111
+#, c-format
+msgid "object %s cannot be read"
 msgstr ""
 
-#: git-rebase.sh:403
-msgid "No rebase in progress?"
+#: builtin/pack-objects.c:2088 builtin/pack-objects.c:2115
+#, c-format
+msgid "object %s inconsistent object length (%<PRIuMAX> vs %<PRIuMAX>)"
 msgstr ""
 
-#: git-rebase.sh:414
-msgid "The --edit-todo action can only be used during interactive rebase."
+#: builtin/pack-objects.c:2125
+msgid "suboptimal pack - out of memory"
 msgstr ""
 
-#: git-rebase.sh:421
-msgid "Cannot read HEAD"
+#: builtin/pack-objects.c:2440
+#, c-format
+msgid "Delta compression using up to %d threads"
+msgstr ""
+
+#: builtin/pack-objects.c:2572
+#, c-format
+msgid "unable to pack objects reachable from tag %s"
+msgstr ""
+
+#: builtin/pack-objects.c:2659
+msgid "Compressing objects"
 msgstr ""
 
-#: git-rebase.sh:424
+#: builtin/pack-objects.c:2665
+msgid "inconsistency with delta count"
+msgstr ""
+
+#: builtin/pack-objects.c:2742
+#, c-format
 msgid ""
-"You must edit all merge conflicts and then\n"
-"mark them as resolved using git add"
+"expected edge object ID, got garbage:\n"
+" %s"
 msgstr ""
 
-#: git-rebase.sh:468
-#, sh-format
+#: builtin/pack-objects.c:2748
+#, c-format
 msgid ""
-"It seems that there is already a $state_dir_base directory, and\n"
-"I wonder if you are in the middle of another rebase.  If that is the\n"
-"case, please try\n"
-"\t$cmd_live_rebase\n"
-"If that is not the case, please\n"
-"\t$cmd_clear_stale_rebase\n"
-"and run me again.  I am stopping in case you still have something\n"
-"valuable there."
+"expected object ID, got garbage:\n"
+" %s"
+msgstr ""
+
+#: builtin/pack-objects.c:2846
+msgid "invalid value for --missing"
+msgstr ""
+
+#: builtin/pack-objects.c:2905 builtin/pack-objects.c:3013
+msgid "cannot open pack index"
+msgstr ""
+
+#: builtin/pack-objects.c:2936
+#, c-format
+msgid "loose object at %s could not be examined"
+msgstr ""
+
+#: builtin/pack-objects.c:3021
+msgid "unable to force loose object"
+msgstr ""
+
+#: builtin/pack-objects.c:3113
+#, c-format
+msgid "not a rev '%s'"
+msgstr ""
+
+#: builtin/pack-objects.c:3116
+#, c-format
+msgid "bad revision '%s'"
 msgstr ""
 
-#: git-rebase.sh:509
-msgid "error: cannot combine '--signoff' with '--preserve-merges'"
+#: builtin/pack-objects.c:3141
+msgid "unable to add recent objects"
+msgstr ""
+
+#: builtin/pack-objects.c:3194
+#, c-format
+msgid "unsupported index version %s"
+msgstr ""
+
+#: builtin/pack-objects.c:3198
+#, c-format
+msgid "bad index version '%s'"
+msgstr ""
+
+#: builtin/pack-objects.c:3236
+msgid "<version>[,<offset>]"
+msgstr ""
+
+#: builtin/pack-objects.c:3237
+msgid "write the pack index file in the specified idx format version"
+msgstr ""
+
+#: builtin/pack-objects.c:3240
+msgid "maximum size of each output pack file"
+msgstr ""
+
+#: builtin/pack-objects.c:3242
+msgid "ignore borrowed objects from alternate object store"
+msgstr ""
+
+#: builtin/pack-objects.c:3244
+msgid "ignore packed objects"
+msgstr ""
+
+#: builtin/pack-objects.c:3246
+msgid "limit pack window by objects"
+msgstr ""
+
+#: builtin/pack-objects.c:3248
+msgid "limit pack window by memory in addition to object limit"
+msgstr ""
+
+#: builtin/pack-objects.c:3250
+msgid "maximum length of delta chain allowed in the resulting pack"
+msgstr ""
+
+#: builtin/pack-objects.c:3252
+msgid "reuse existing deltas"
+msgstr ""
+
+#: builtin/pack-objects.c:3254
+msgid "reuse existing objects"
+msgstr ""
+
+#: builtin/pack-objects.c:3256
+msgid "use OFS_DELTA objects"
+msgstr ""
+
+#: builtin/pack-objects.c:3258
+msgid "use threads when searching for best delta matches"
+msgstr ""
+
+#: builtin/pack-objects.c:3260
+msgid "do not create an empty pack output"
+msgstr ""
+
+#: builtin/pack-objects.c:3262
+msgid "read revision arguments from standard input"
+msgstr ""
+
+#: builtin/pack-objects.c:3264
+msgid "limit the objects to those that are not yet packed"
+msgstr ""
+
+#: builtin/pack-objects.c:3267
+msgid "include objects reachable from any reference"
+msgstr ""
+
+#: builtin/pack-objects.c:3270
+msgid "include objects referred by reflog entries"
+msgstr ""
+
+#: builtin/pack-objects.c:3273
+msgid "include objects referred to by the index"
+msgstr ""
+
+#: builtin/pack-objects.c:3276
+msgid "output pack to stdout"
+msgstr ""
+
+#: builtin/pack-objects.c:3278
+msgid "include tag objects that refer to objects to be packed"
+msgstr ""
+
+#: builtin/pack-objects.c:3280
+msgid "keep unreachable objects"
+msgstr ""
+
+#: builtin/pack-objects.c:3282
+msgid "pack loose unreachable objects"
+msgstr ""
+
+#: builtin/pack-objects.c:3284
+msgid "unpack unreachable objects newer than <time>"
+msgstr ""
+
+#: builtin/pack-objects.c:3287
+msgid "use the sparse reachability algorithm"
+msgstr ""
+
+#: builtin/pack-objects.c:3289
+msgid "create thin packs"
+msgstr ""
+
+#: builtin/pack-objects.c:3291
+msgid "create packs suitable for shallow fetches"
+msgstr ""
+
+#: builtin/pack-objects.c:3293
+msgid "ignore packs that have companion .keep file"
+msgstr ""
+
+#: builtin/pack-objects.c:3295
+msgid "ignore this pack"
+msgstr ""
+
+#: builtin/pack-objects.c:3297
+msgid "pack compression level"
+msgstr ""
+
+#: builtin/pack-objects.c:3299
+msgid "do not hide commits by grafts"
+msgstr ""
+
+#: builtin/pack-objects.c:3301
+msgid "use a bitmap index if available to speed up counting objects"
+msgstr ""
+
+#: builtin/pack-objects.c:3303
+msgid "write a bitmap index together with the pack index"
+msgstr ""
+
+#: builtin/pack-objects.c:3307
+msgid "write a bitmap index if possible"
+msgstr ""
+
+#: builtin/pack-objects.c:3311
+msgid "handling for missing objects"
+msgstr ""
+
+#: builtin/pack-objects.c:3314
+msgid "do not pack objects in promisor packfiles"
+msgstr ""
+
+#: builtin/pack-objects.c:3316
+msgid "respect islands during delta compression"
+msgstr ""
+
+#: builtin/pack-objects.c:3345
+#, c-format
+msgid "delta chain depth %d is too deep, forcing %d"
+msgstr ""
+
+#: builtin/pack-objects.c:3350
+#, c-format
+msgid "pack.deltaCacheLimit is too high, forcing %d"
+msgstr ""
+
+#: builtin/pack-objects.c:3404
+msgid "--max-pack-size cannot be used to build a pack for transfer"
+msgstr ""
+
+#: builtin/pack-objects.c:3406
+msgid "minimum pack size limit is 1 MiB"
+msgstr ""
+
+#: builtin/pack-objects.c:3411
+msgid "--thin cannot be used to build an indexable pack"
+msgstr ""
+
+#: builtin/pack-objects.c:3414
+msgid "--keep-unreachable and --unpack-unreachable are incompatible"
+msgstr ""
+
+#: builtin/pack-objects.c:3420
+msgid "cannot use --filter without --stdout"
+msgstr ""
+
+#: builtin/pack-objects.c:3481
+msgid "Enumerating objects"
+msgstr ""
+
+#: builtin/pack-objects.c:3511
+#, c-format
+msgid "Total %<PRIu32> (delta %<PRIu32>), reused %<PRIu32> (delta %<PRIu32>)"
+msgstr ""
+
+#: builtin/pack-refs.c:8
+msgid "git pack-refs [<options>]"
+msgstr ""
+
+#: builtin/pack-refs.c:16
+msgid "pack everything"
+msgstr ""
+
+#: builtin/pack-refs.c:17
+msgid "prune loose refs (default)"
+msgstr ""
+
+#: builtin/prune-packed.c:9
+msgid "git prune-packed [-n | --dry-run] [-q | --quiet]"
+msgstr ""
+
+#: builtin/prune-packed.c:42
+msgid "Removing duplicate objects"
+msgstr ""
+
+#: builtin/prune.c:12
+msgid "git prune [-n] [-v] [--progress] [--expire <time>] [--] [<head>...]"
+msgstr ""
+
+#: builtin/prune.c:131
+msgid "report pruned objects"
+msgstr ""
+
+#: builtin/prune.c:134
+msgid "expire objects older than <time>"
+msgstr ""
+
+#: builtin/prune.c:136
+msgid "limit traversal to objects outside promisor packfiles"
+msgstr ""
+
+#: builtin/prune.c:150
+msgid "cannot prune in a precious-objects repo"
+msgstr ""
+
+#: builtin/pull.c:66 builtin/pull.c:68
+#, c-format
+msgid "Invalid value for %s: %s"
+msgstr ""
+
+#: builtin/pull.c:88
+msgid "git pull [<options>] [<repository> [<refspec>...]]"
+msgstr ""
+
+#: builtin/pull.c:142
+msgid "control for recursive fetching of submodules"
+msgstr ""
+
+#: builtin/pull.c:146
+msgid "Options related to merging"
+msgstr ""
+
+#: builtin/pull.c:149
+msgid "incorporate changes by rebasing rather than merging"
+msgstr ""
+
+#: builtin/pull.c:177 builtin/rebase.c:467 builtin/revert.c:126
+msgid "allow fast-forward"
+msgstr ""
+
+#: builtin/pull.c:186
+msgid "automatically stash/stash pop before and after rebase"
+msgstr ""
+
+#: builtin/pull.c:202
+msgid "Options related to fetching"
+msgstr ""
+
+#: builtin/pull.c:212
+msgid "force overwrite of local branch"
+msgstr ""
+
+#: builtin/pull.c:220
+msgid "number of submodules pulled in parallel"
+msgstr ""
+
+#: builtin/pull.c:320
+#, c-format
+msgid "Invalid value for pull.ff: %s"
+msgstr ""
+
+#: builtin/pull.c:437
+msgid ""
+"There is no candidate for rebasing against among the refs that you just "
+"fetched."
+msgstr ""
+
+#: builtin/pull.c:439
+msgid ""
+"There are no candidates for merging among the refs that you just fetched."
+msgstr ""
+
+#: builtin/pull.c:440
+msgid ""
+"Generally this means that you provided a wildcard refspec which had no\n"
+"matches on the remote end."
+msgstr ""
+
+#: builtin/pull.c:443
+#, c-format
+msgid ""
+"You asked to pull from the remote '%s', but did not specify\n"
+"a branch. Because this is not the default configured remote\n"
+"for your current branch, you must specify a branch on the command line."
+msgstr ""
+
+#: builtin/pull.c:448 builtin/rebase.c:1375 git-parse-remote.sh:73
+msgid "You are not currently on a branch."
+msgstr ""
+
+#: builtin/pull.c:450 builtin/pull.c:465 git-parse-remote.sh:79
+msgid "Please specify which branch you want to rebase against."
+msgstr ""
+
+#: builtin/pull.c:452 builtin/pull.c:467 git-parse-remote.sh:82
+msgid "Please specify which branch you want to merge with."
+msgstr ""
+
+#: builtin/pull.c:453 builtin/pull.c:468
+msgid "See git-pull(1) for details."
+msgstr ""
+
+#: builtin/pull.c:455 builtin/pull.c:461 builtin/pull.c:470
+#: builtin/rebase.c:1381 git-parse-remote.sh:64
+msgid "<remote>"
+msgstr ""
+
+#: builtin/pull.c:455 builtin/pull.c:470 builtin/pull.c:475
+#: git-parse-remote.sh:65
+msgid "<branch>"
+msgstr ""
+
+#: builtin/pull.c:463 builtin/rebase.c:1373 git-parse-remote.sh:75
+msgid "There is no tracking information for the current branch."
+msgstr ""
+
+#: builtin/pull.c:472 git-parse-remote.sh:95
+msgid ""
+"If you wish to set tracking information for this branch you can do so with:"
+msgstr ""
+
+#: builtin/pull.c:477
+#, c-format
+msgid ""
+"Your configuration specifies to merge with the ref '%s'\n"
+"from the remote, but no such ref was fetched."
+msgstr ""
+
+#: builtin/pull.c:587
+#, c-format
+msgid "unable to access commit %s"
+msgstr ""
+
+#: builtin/pull.c:867
+msgid "ignoring --verify-signatures for rebase"
+msgstr ""
+
+#: builtin/pull.c:922
+msgid "--[no-]autostash option is only valid with --rebase."
+msgstr ""
+
+#: builtin/pull.c:930
+msgid "Updating an unborn branch with changes added to the index."
+msgstr ""
+
+#: builtin/pull.c:934
+msgid "pull with rebase"
+msgstr ""
+
+#: builtin/pull.c:935
+msgid "please commit or stash them."
+msgstr ""
+
+#: builtin/pull.c:960
+#, c-format
+msgid ""
+"fetch updated the current branch head.\n"
+"fast-forwarding your working tree from\n"
+"commit %s."
+msgstr ""
+
+#: builtin/pull.c:966
+#, c-format
+msgid ""
+"Cannot fast-forward your working tree.\n"
+"After making sure that you saved anything precious from\n"
+"$ git diff %s\n"
+"output, run\n"
+"$ git reset --hard\n"
+"to recover."
+msgstr ""
+
+#: builtin/pull.c:981
+msgid "Cannot merge multiple branches into empty head."
+msgstr ""
+
+#: builtin/pull.c:985
+msgid "Cannot rebase onto multiple branches."
+msgstr ""
+
+#: builtin/pull.c:992
+msgid "cannot rebase with locally recorded submodule modifications"
+msgstr ""
+
+#: builtin/push.c:19
+msgid "git push [<options>] [<repository> [<refspec>...]]"
+msgstr ""
+
+#: builtin/push.c:112
+msgid "tag shorthand without <tag>"
+msgstr ""
+
+#: builtin/push.c:122
+msgid "--delete only accepts plain target ref names"
+msgstr ""
+
+#: builtin/push.c:168
+msgid ""
+"\n"
+"To choose either option permanently, see push.default in 'git help config'."
+msgstr ""
+
+#: builtin/push.c:171
+#, c-format
+msgid ""
+"The upstream branch of your current branch does not match\n"
+"the name of your current branch.  To push to the upstream branch\n"
+"on the remote, use\n"
+"\n"
+"    git push %s HEAD:%s\n"
+"\n"
+"To push to the branch of the same name on the remote, use\n"
+"\n"
+"    git push %s HEAD\n"
+"%s"
+msgstr ""
+
+#: builtin/push.c:186
+#, c-format
+msgid ""
+"You are not currently on a branch.\n"
+"To push the history leading to the current (detached HEAD)\n"
+"state now, use\n"
+"\n"
+"    git push %s HEAD:<name-of-remote-branch>\n"
+msgstr ""
+
+#: builtin/push.c:200
+#, c-format
+msgid ""
+"The current branch %s has no upstream branch.\n"
+"To push the current branch and set the remote as upstream, use\n"
+"\n"
+"    git push --set-upstream %s %s\n"
+msgstr ""
+
+#: builtin/push.c:208
+#, c-format
+msgid "The current branch %s has multiple upstream branches, refusing to push."
+msgstr ""
+
+#: builtin/push.c:211
+#, c-format
+msgid ""
+"You are pushing to remote '%s', which is not the upstream of\n"
+"your current branch '%s', without telling me what to push\n"
+"to update which remote branch."
+msgstr ""
+
+#: builtin/push.c:270
+msgid ""
+"You didn't specify any refspecs to push, and push.default is \"nothing\"."
+msgstr ""
+
+#: builtin/push.c:277
+msgid ""
+"Updates were rejected because the tip of your current branch is behind\n"
+"its remote counterpart. Integrate the remote changes (e.g.\n"
+"'git pull ...') before pushing again.\n"
+"See the 'Note about fast-forwards' in 'git push --help' for details."
+msgstr ""
+
+#: builtin/push.c:283
+msgid ""
+"Updates were rejected because a pushed branch tip is behind its remote\n"
+"counterpart. Check out this branch and integrate the remote changes\n"
+"(e.g. 'git pull ...') before pushing again.\n"
+"See the 'Note about fast-forwards' in 'git push --help' for details."
+msgstr ""
+
+#: builtin/push.c:289
+msgid ""
+"Updates were rejected because the remote contains work that you do\n"
+"not have locally. This is usually caused by another repository pushing\n"
+"to the same ref. You may want to first integrate the remote changes\n"
+"(e.g., 'git pull ...') before pushing again.\n"
+"See the 'Note about fast-forwards' in 'git push --help' for details."
+msgstr ""
+
+#: builtin/push.c:296
+msgid "Updates were rejected because the tag already exists in the remote."
+msgstr ""
+
+#: builtin/push.c:299
+msgid ""
+"You cannot update a remote ref that points at a non-commit object,\n"
+"or update a remote ref to make it point at a non-commit object,\n"
+"without using the '--force' option.\n"
+msgstr ""
+
+#: builtin/push.c:360
+#, c-format
+msgid "Pushing to %s\n"
+msgstr ""
+
+#: builtin/push.c:367
+#, c-format
+msgid "failed to push some refs to '%s'"
+msgstr ""
+
+#: builtin/push.c:542
+msgid "repository"
+msgstr ""
+
+#: builtin/push.c:543 builtin/send-pack.c:164
+msgid "push all refs"
+msgstr ""
+
+#: builtin/push.c:544 builtin/send-pack.c:166
+msgid "mirror all refs"
+msgstr ""
+
+#: builtin/push.c:546
+msgid "delete refs"
+msgstr ""
+
+#: builtin/push.c:547
+msgid "push tags (can't be used with --all or --mirror)"
+msgstr ""
+
+#: builtin/push.c:550 builtin/send-pack.c:167
+msgid "force updates"
+msgstr ""
+
+#: builtin/push.c:552 builtin/send-pack.c:181
+msgid "<refname>:<expect>"
+msgstr ""
+
+#: builtin/push.c:553 builtin/send-pack.c:182
+msgid "require old value of ref to be at this value"
+msgstr ""
+
+#: builtin/push.c:556
+msgid "control recursive pushing of submodules"
+msgstr ""
+
+#: builtin/push.c:558 builtin/send-pack.c:175
+msgid "use thin pack"
+msgstr ""
+
+#: builtin/push.c:559 builtin/push.c:560 builtin/send-pack.c:161
+#: builtin/send-pack.c:162
+msgid "receive pack program"
+msgstr ""
+
+#: builtin/push.c:561
+msgid "set upstream for git pull/status"
+msgstr ""
+
+#: builtin/push.c:564
+msgid "prune locally removed refs"
+msgstr ""
+
+#: builtin/push.c:566
+msgid "bypass pre-push hook"
+msgstr ""
+
+#: builtin/push.c:567
+msgid "push missing but relevant tags"
+msgstr ""
+
+#: builtin/push.c:570 builtin/send-pack.c:169
+msgid "GPG sign the push"
+msgstr ""
+
+#: builtin/push.c:572 builtin/send-pack.c:176
+msgid "request atomic transaction on remote side"
+msgstr ""
+
+#: builtin/push.c:590
+msgid "--delete is incompatible with --all, --mirror and --tags"
+msgstr ""
+
+#: builtin/push.c:592
+msgid "--delete doesn't make sense without any refs"
+msgstr ""
+
+#: builtin/push.c:612
+#, c-format
+msgid "bad repository '%s'"
+msgstr ""
+
+#: builtin/push.c:613
+msgid ""
+"No configured push destination.\n"
+"Either specify the URL from the command-line or configure a remote "
+"repository using\n"
+"\n"
+"    git remote add <name> <url>\n"
+"\n"
+"and then push using the remote name\n"
+"\n"
+"    git push <name>\n"
+msgstr ""
+
+#: builtin/push.c:628
+msgid "--all and --tags are incompatible"
+msgstr ""
+
+#: builtin/push.c:630
+msgid "--all can't be combined with refspecs"
+msgstr ""
+
+#: builtin/push.c:634
+msgid "--mirror and --tags are incompatible"
+msgstr ""
+
+#: builtin/push.c:636
+msgid "--mirror can't be combined with refspecs"
+msgstr ""
+
+#: builtin/push.c:639
+msgid "--all and --mirror are incompatible"
+msgstr ""
+
+#: builtin/push.c:643
+msgid "push options must not have new line characters"
+msgstr ""
+
+#: builtin/range-diff.c:8
+msgid "git range-diff [<options>] <old-base>..<old-tip> <new-base>..<new-tip>"
+msgstr ""
+
+#: builtin/range-diff.c:9
+msgid "git range-diff [<options>] <old-tip>...<new-tip>"
+msgstr ""
+
+#: builtin/range-diff.c:10
+msgid "git range-diff [<options>] <base> <old-tip> <new-tip>"
+msgstr ""
+
+#: builtin/range-diff.c:22
+msgid "Percentage by which creation is weighted"
+msgstr ""
+
+#: builtin/range-diff.c:24
+msgid "use simple diff colors"
+msgstr ""
+
+#: builtin/range-diff.c:26
+msgid "notes"
+msgstr ""
+
+#: builtin/range-diff.c:26
+msgid "passed to 'git log'"
+msgstr ""
+
+#: builtin/range-diff.c:50 builtin/range-diff.c:54
+#, c-format
+msgid "no .. in range: '%s'"
+msgstr ""
+
+#: builtin/range-diff.c:64
+msgid "single arg format must be symmetric range"
+msgstr ""
+
+#: builtin/range-diff.c:79
+msgid "need two commit ranges"
+msgstr ""
+
+#: builtin/read-tree.c:41
+msgid ""
+"git read-tree [(-m [--trivial] [--aggressive] | --reset | --prefix=<prefix>) "
+"[-u [--exclude-per-directory=<gitignore>] | -i]] [--no-sparse-checkout] [--"
+"index-output=<file>] (--empty | <tree-ish1> [<tree-ish2> [<tree-ish3>]])"
+msgstr ""
+
+#: builtin/read-tree.c:124
+msgid "write resulting index to <file>"
+msgstr ""
+
+#: builtin/read-tree.c:127
+msgid "only empty the index"
+msgstr ""
+
+#: builtin/read-tree.c:129
+msgid "Merging"
+msgstr ""
+
+#: builtin/read-tree.c:131
+msgid "perform a merge in addition to a read"
+msgstr ""
+
+#: builtin/read-tree.c:133
+msgid "3-way merge if no file level merging required"
+msgstr ""
+
+#: builtin/read-tree.c:135
+msgid "3-way merge in presence of adds and removes"
+msgstr ""
+
+#: builtin/read-tree.c:137
+msgid "same as -m, but discard unmerged entries"
+msgstr ""
+
+#: builtin/read-tree.c:138
+msgid "<subdirectory>/"
+msgstr ""
+
+#: builtin/read-tree.c:139
+msgid "read the tree into the index under <subdirectory>/"
+msgstr ""
+
+#: builtin/read-tree.c:142
+msgid "update working tree with merge result"
+msgstr ""
+
+#: builtin/read-tree.c:144
+msgid "gitignore"
+msgstr ""
+
+#: builtin/read-tree.c:145
+msgid "allow explicitly ignored files to be overwritten"
+msgstr ""
+
+#: builtin/read-tree.c:148
+msgid "don't check the working tree after merging"
+msgstr ""
+
+#: builtin/read-tree.c:149
+msgid "don't update the index or the work tree"
+msgstr ""
+
+#: builtin/read-tree.c:151
+msgid "skip applying sparse checkout filter"
+msgstr ""
+
+#: builtin/read-tree.c:153
+msgid "debug unpack-trees"
+msgstr ""
+
+#: builtin/read-tree.c:157
+msgid "suppress feedback messages"
+msgstr ""
+
+#: builtin/read-tree.c:188
+msgid "You need to resolve your current index first"
+msgstr ""
+
+#: builtin/rebase.c:32
+msgid ""
+"git rebase [-i] [options] [--exec <cmd>] [--onto <newbase> | --keep-base] "
+"[<upstream> [<branch>]]"
+msgstr ""
+
+#: builtin/rebase.c:34
+msgid ""
+"git rebase [-i] [options] [--exec <cmd>] [--onto <newbase>] --root [<branch>]"
+msgstr ""
+
+#: builtin/rebase.c:36
+msgid "git rebase --continue | --abort | --skip | --edit-todo"
+msgstr ""
+
+#: builtin/rebase.c:177 builtin/rebase.c:201 builtin/rebase.c:228
+#, c-format
+msgid "unusable todo list: '%s'"
+msgstr ""
+
+#: builtin/rebase.c:186 builtin/rebase.c:212 builtin/rebase.c:236
+#, c-format
+msgid "could not write '%s'."
+msgstr ""
+
+#: builtin/rebase.c:271
+msgid "no HEAD?"
+msgstr ""
+
+#: builtin/rebase.c:298
+#, c-format
+msgid "could not create temporary %s"
+msgstr ""
+
+#: builtin/rebase.c:304
+msgid "could not mark as interactive"
+msgstr ""
+
+#: builtin/rebase.c:362
+msgid "could not generate todo list"
+msgstr ""
+
+#: builtin/rebase.c:402
+msgid "a base commit must be provided with --upstream or --onto"
+msgstr ""
+
+#: builtin/rebase.c:457
+msgid "git rebase--interactive [<options>]"
+msgstr ""
+
+#: builtin/rebase.c:469
+msgid "keep empty commits"
+msgstr ""
+
+#: builtin/rebase.c:471 builtin/revert.c:128
+msgid "allow commits with empty messages"
+msgstr ""
+
+#: builtin/rebase.c:472
+msgid "rebase merge commits"
+msgstr ""
+
+#: builtin/rebase.c:474
+msgid "keep original branch points of cousins"
+msgstr ""
+
+#: builtin/rebase.c:476
+msgid "move commits that begin with squash!/fixup!"
+msgstr ""
+
+#: builtin/rebase.c:477
+msgid "sign commits"
+msgstr ""
+
+#: builtin/rebase.c:479 builtin/rebase.c:1455
+msgid "display a diffstat of what changed upstream"
+msgstr ""
+
+#: builtin/rebase.c:481
+msgid "continue rebase"
+msgstr ""
+
+#: builtin/rebase.c:483
+msgid "skip commit"
+msgstr ""
+
+#: builtin/rebase.c:484
+msgid "edit the todo list"
+msgstr ""
+
+#: builtin/rebase.c:486
+msgid "show the current patch"
+msgstr ""
+
+#: builtin/rebase.c:489
+msgid "shorten commit ids in the todo list"
+msgstr ""
+
+#: builtin/rebase.c:491
+msgid "expand commit ids in the todo list"
+msgstr ""
+
+#: builtin/rebase.c:493
+msgid "check the todo list"
+msgstr ""
+
+#: builtin/rebase.c:495
+msgid "rearrange fixup/squash lines"
+msgstr ""
+
+#: builtin/rebase.c:497
+msgid "insert exec commands in todo list"
+msgstr ""
+
+#: builtin/rebase.c:498
+msgid "onto"
+msgstr ""
+
+#: builtin/rebase.c:501
+msgid "restrict-revision"
+msgstr ""
+
+#: builtin/rebase.c:501
+msgid "restrict revision"
+msgstr ""
+
+#: builtin/rebase.c:503
+msgid "squash-onto"
+msgstr ""
+
+#: builtin/rebase.c:504
+msgid "squash onto"
+msgstr ""
+
+#: builtin/rebase.c:506
+msgid "the upstream commit"
+msgstr ""
+
+#: builtin/rebase.c:508
+msgid "head-name"
+msgstr ""
+
+#: builtin/rebase.c:508
+msgid "head name"
+msgstr ""
+
+#: builtin/rebase.c:513
+msgid "rebase strategy"
+msgstr ""
+
+#: builtin/rebase.c:514
+msgid "strategy-opts"
+msgstr ""
+
+#: builtin/rebase.c:515
+msgid "strategy options"
+msgstr ""
+
+#: builtin/rebase.c:516
+msgid "switch-to"
+msgstr ""
+
+#: builtin/rebase.c:517
+msgid "the branch or commit to checkout"
+msgstr ""
+
+#: builtin/rebase.c:518
+msgid "onto-name"
+msgstr ""
+
+#: builtin/rebase.c:518
+msgid "onto name"
+msgstr ""
+
+#: builtin/rebase.c:519
+msgid "cmd"
+msgstr ""
+
+#: builtin/rebase.c:519
+msgid "the command to run"
+msgstr ""
+
+#: builtin/rebase.c:522 builtin/rebase.c:1540
+msgid "automatically re-schedule any `exec` that fails"
+msgstr ""
+
+#: builtin/rebase.c:540
+msgid "--[no-]rebase-cousins has no effect without --rebase-merges"
+msgstr ""
+
+#: builtin/rebase.c:556
+#, c-format
+msgid "%s requires an interactive rebase"
+msgstr ""
+
+#: builtin/rebase.c:608
+#, c-format
+msgid "could not get 'onto': '%s'"
+msgstr ""
+
+#: builtin/rebase.c:623
+#, c-format
+msgid "invalid orig-head: '%s'"
+msgstr ""
+
+#: builtin/rebase.c:648
+#, c-format
+msgid "ignoring invalid allow_rerere_autoupdate: '%s'"
+msgstr ""
+
+#: builtin/rebase.c:724
+#, c-format
+msgid "Could not read '%s'"
+msgstr ""
+
+#: builtin/rebase.c:742
+#, c-format
+msgid "Cannot store %s"
+msgstr ""
+
+#: builtin/rebase.c:849
+msgid "could not determine HEAD revision"
+msgstr ""
+
+#: builtin/rebase.c:972 git-rebase--preserve-merges.sh:81
+msgid ""
+"Resolve all conflicts manually, mark them as resolved with\n"
+"\"git add/rm <conflicted_files>\", then run \"git rebase --continue\".\n"
+"You can instead skip this commit: run \"git rebase --skip\".\n"
+"To abort and get back to the state before \"git rebase\", run \"git rebase --"
+"abort\"."
+msgstr ""
+
+#: builtin/rebase.c:1060
+#, c-format
+msgid ""
+"\n"
+"git encountered an error while preparing the patches to replay\n"
+"these revisions:\n"
+"\n"
+"    %s\n"
+"\n"
+"As a result, git cannot rebase them."
+msgstr ""
+
+#: builtin/rebase.c:1367
+#, c-format
+msgid ""
+"%s\n"
+"Please specify which branch you want to rebase against.\n"
+"See git-rebase(1) for details.\n"
+"\n"
+"    git rebase '<branch>'\n"
+"\n"
+msgstr ""
+
+#: builtin/rebase.c:1383
+#, c-format
+msgid ""
+"If you wish to set tracking information for this branch you can do so with:\n"
+"\n"
+"    git branch --set-upstream-to=%s/<branch> %s\n"
+"\n"
+msgstr ""
+
+#: builtin/rebase.c:1413
+msgid "exec commands cannot contain newlines"
+msgstr ""
+
+#: builtin/rebase.c:1417
+msgid "empty exec command"
+msgstr ""
+
+#: builtin/rebase.c:1446
+msgid "rebase onto given branch instead of upstream"
+msgstr ""
+
+#: builtin/rebase.c:1448
+msgid "use the merge-base of upstream and branch as the current base"
+msgstr ""
+
+#: builtin/rebase.c:1450
+msgid "allow pre-rebase hook to run"
+msgstr ""
+
+#: builtin/rebase.c:1452
+msgid "be quiet. implies --no-stat"
+msgstr ""
+
+#: builtin/rebase.c:1458
+msgid "do not show diffstat of what changed upstream"
+msgstr ""
+
+#: builtin/rebase.c:1461
+msgid "add a Signed-off-by: line to each commit"
+msgstr ""
+
+#: builtin/rebase.c:1464
+msgid "make committer date match author date"
+msgstr ""
+
+#: builtin/rebase.c:1466
+msgid "ignore author date and use current date"
+msgstr ""
+
+#: builtin/rebase.c:1468
+msgid "synonym of --reset-author-date"
+msgstr ""
+
+#: builtin/rebase.c:1470 builtin/rebase.c:1474
+msgid "passed to 'git apply'"
+msgstr ""
+
+#: builtin/rebase.c:1472
+msgid "ignore changes in whitespace"
+msgstr ""
+
+#: builtin/rebase.c:1476 builtin/rebase.c:1479
+msgid "cherry-pick all commits, even if unchanged"
+msgstr ""
+
+#: builtin/rebase.c:1481
+msgid "continue"
+msgstr ""
+
+#: builtin/rebase.c:1484
+msgid "skip current patch and continue"
+msgstr ""
+
+#: builtin/rebase.c:1486
+msgid "abort and check out the original branch"
+msgstr ""
+
+#: builtin/rebase.c:1489
+msgid "abort but keep HEAD where it is"
+msgstr ""
+
+#: builtin/rebase.c:1490
+msgid "edit the todo list during an interactive rebase"
+msgstr ""
+
+#: builtin/rebase.c:1493
+msgid "show the patch file being applied or merged"
+msgstr ""
+
+#: builtin/rebase.c:1496
+msgid "use merging strategies to rebase"
+msgstr ""
+
+#: builtin/rebase.c:1500
+msgid "let the user edit the list of commits to rebase"
+msgstr ""
+
+#: builtin/rebase.c:1504
+msgid "(DEPRECATED) try to recreate merges instead of ignoring them"
+msgstr ""
+
+#: builtin/rebase.c:1509
+msgid "preserve empty commits during rebase"
+msgstr ""
+
+#: builtin/rebase.c:1511
+msgid "move commits that begin with squash!/fixup! under -i"
+msgstr ""
+
+#: builtin/rebase.c:1517
+msgid "automatically stash/stash pop before and after"
+msgstr ""
+
+#: builtin/rebase.c:1519
+msgid "add exec lines after each commit of the editable list"
+msgstr ""
+
+#: builtin/rebase.c:1523
+msgid "allow rebasing commits with empty messages"
+msgstr ""
+
+#: builtin/rebase.c:1526
+msgid "try to rebase merges instead of skipping them"
+msgstr ""
+
+#: builtin/rebase.c:1529
+msgid "use 'merge-base --fork-point' to refine upstream"
+msgstr ""
+
+#: builtin/rebase.c:1531
+msgid "use the given merge strategy"
+msgstr ""
+
+#: builtin/rebase.c:1533 builtin/revert.c:115
+msgid "option"
+msgstr ""
+
+#: builtin/rebase.c:1534
+msgid "pass the argument through to the merge strategy"
+msgstr ""
+
+#: builtin/rebase.c:1537
+msgid "rebase all reachable commits up to the root(s)"
+msgstr ""
+
+#: builtin/rebase.c:1554
+msgid ""
+"the rebase.useBuiltin support has been removed!\n"
+"See its entry in 'git help config' for details."
+msgstr ""
+
+#: builtin/rebase.c:1560
+msgid "It looks like 'git am' is in progress. Cannot rebase."
+msgstr ""
+
+#: builtin/rebase.c:1601
+msgid ""
+"git rebase --preserve-merges is deprecated. Use --rebase-merges instead."
+msgstr ""
+
+#: builtin/rebase.c:1606
+msgid "cannot combine '--keep-base' with '--onto'"
+msgstr ""
+
+#: builtin/rebase.c:1608
+msgid "cannot combine '--keep-base' with '--root'"
+msgstr ""
+
+#: builtin/rebase.c:1612
+msgid "No rebase in progress?"
+msgstr ""
+
+#: builtin/rebase.c:1616
+msgid "The --edit-todo action can only be used during interactive rebase."
+msgstr ""
+
+#: builtin/rebase.c:1639
+msgid "Cannot read HEAD"
+msgstr ""
+
+#: builtin/rebase.c:1651
+msgid ""
+"You must edit all merge conflicts and then\n"
+"mark them as resolved using git add"
+msgstr ""
+
+#: builtin/rebase.c:1670
+msgid "could not discard worktree changes"
+msgstr ""
+
+#: builtin/rebase.c:1689
+#, c-format
+msgid "could not move back to %s"
+msgstr ""
+
+#: builtin/rebase.c:1734
+#, c-format
+msgid ""
+"It seems that there is already a %s directory, and\n"
+"I wonder if you are in the middle of another rebase.  If that is the\n"
+"case, please try\n"
+"\t%s\n"
+"If that is not the case, please\n"
+"\t%s\n"
+"and run me again.  I am stopping in case you still have something\n"
+"valuable there.\n"
+msgstr ""
+
+#: builtin/rebase.c:1757
+msgid "switch `C' expects a numerical value"
+msgstr ""
+
+#: builtin/rebase.c:1798
+#, c-format
+msgid "Unknown mode: %s"
+msgstr ""
+
+#: builtin/rebase.c:1820
+msgid "--strategy requires --merge or --interactive"
+msgstr ""
+
+#: builtin/rebase.c:1860
+msgid "--reschedule-failed-exec requires --exec or --interactive"
+msgstr ""
+
+#: builtin/rebase.c:1872
+msgid "cannot combine am options with either interactive or merge options"
+msgstr ""
+
+#: builtin/rebase.c:1891
+msgid "cannot combine '--preserve-merges' with '--rebase-merges'"
+msgstr ""
+
+#: builtin/rebase.c:1895
+msgid ""
+"error: cannot combine '--preserve-merges' with '--reschedule-failed-exec'"
+msgstr ""
+
+#: builtin/rebase.c:1919
+#, c-format
+msgid "invalid upstream '%s'"
+msgstr ""
+
+#: builtin/rebase.c:1925
+msgid "Could not create new root commit"
+msgstr ""
+
+#: builtin/rebase.c:1951
+#, c-format
+msgid "'%s': need exactly one merge base with branch"
+msgstr ""
+
+#: builtin/rebase.c:1954
+#, c-format
+msgid "'%s': need exactly one merge base"
+msgstr ""
+
+#: builtin/rebase.c:1962
+#, c-format
+msgid "Does not point to a valid commit '%s'"
+msgstr ""
+
+#: builtin/rebase.c:1987
+#, c-format
+msgid "fatal: no such branch/commit '%s'"
+msgstr ""
+
+#: builtin/rebase.c:1995 builtin/submodule--helper.c:40
+#: builtin/submodule--helper.c:1961
+#, c-format
+msgid "No such ref: %s"
+msgstr ""
+
+#: builtin/rebase.c:2006
+msgid "Could not resolve HEAD to a revision"
+msgstr ""
+
+#: builtin/rebase.c:2044
+msgid "Cannot autostash"
+msgstr ""
+
+#: builtin/rebase.c:2047
+#, c-format
+msgid "Unexpected stash response: '%s'"
+msgstr ""
+
+#: builtin/rebase.c:2053
+#, c-format
+msgid "Could not create directory for '%s'"
+msgstr ""
+
+#: builtin/rebase.c:2056
+#, c-format
+msgid "Created autostash: %s\n"
+msgstr ""
+
+#: builtin/rebase.c:2059
+msgid "could not reset --hard"
+msgstr ""
+
+#: builtin/rebase.c:2068
+msgid "Please commit or stash them."
+msgstr ""
+
+#: builtin/rebase.c:2095
+#, c-format
+msgid "could not parse '%s'"
+msgstr ""
+
+#: builtin/rebase.c:2108
+#, c-format
+msgid "could not switch to %s"
+msgstr ""
+
+#: builtin/rebase.c:2119
+msgid "HEAD is up to date."
+msgstr ""
+
+#: builtin/rebase.c:2121
+#, c-format
+msgid "Current branch %s is up to date.\n"
+msgstr ""
+
+#: builtin/rebase.c:2129
+msgid "HEAD is up to date, rebase forced."
+msgstr ""
+
+#: builtin/rebase.c:2131
+#, c-format
+msgid "Current branch %s is up to date, rebase forced.\n"
+msgstr ""
+
+#: builtin/rebase.c:2139
+msgid "The pre-rebase hook refused to rebase."
+msgstr ""
+
+#: builtin/rebase.c:2146
+#, c-format
+msgid "Changes to %s:\n"
+msgstr ""
+
+#: builtin/rebase.c:2149
+#, c-format
+msgid "Changes from %s to %s:\n"
+msgstr ""
+
+#: builtin/rebase.c:2174
+#, c-format
+msgid "First, rewinding head to replay your work on top of it...\n"
+msgstr ""
+
+#: builtin/rebase.c:2183
+msgid "Could not detach HEAD"
+msgstr ""
+
+#: builtin/rebase.c:2192
+#, c-format
+msgid "Fast-forwarded %s to %s.\n"
+msgstr ""
+
+#: builtin/receive-pack.c:32
+msgid "git receive-pack <git-dir>"
+msgstr ""
+
+#: builtin/receive-pack.c:830
+msgid ""
+"By default, updating the current branch in a non-bare repository\n"
+"is denied, because it will make the index and work tree inconsistent\n"
+"with what you pushed, and will require 'git reset --hard' to match\n"
+"the work tree to HEAD.\n"
+"\n"
+"You can set the 'receive.denyCurrentBranch' configuration variable\n"
+"to 'ignore' or 'warn' in the remote repository to allow pushing into\n"
+"its current branch; however, this is not recommended unless you\n"
+"arranged to update its work tree to match what you pushed in some\n"
+"other way.\n"
+"\n"
+"To squelch this message and still keep the default behaviour, set\n"
+"'receive.denyCurrentBranch' configuration variable to 'refuse'."
+msgstr ""
+
+#: builtin/receive-pack.c:850
+msgid ""
+"By default, deleting the current branch is denied, because the next\n"
+"'git clone' won't result in any file checked out, causing confusion.\n"
+"\n"
+"You can set 'receive.denyDeleteCurrent' configuration variable to\n"
+"'warn' or 'ignore' in the remote repository to allow deleting the\n"
+"current branch, with or without a warning message.\n"
+"\n"
+"To squelch this message, you can set it to 'refuse'."
+msgstr ""
+
+#: builtin/receive-pack.c:1936
+msgid "quiet"
+msgstr ""
+
+#: builtin/receive-pack.c:1950
+msgid "You must specify a directory."
+msgstr ""
+
+#: builtin/reflog.c:17
+msgid ""
+"git reflog expire [--expire=<time>] [--expire-unreachable=<time>] [--"
+"rewrite] [--updateref] [--stale-fix] [--dry-run | -n] [--verbose] [--all] "
+"<refs>..."
+msgstr ""
+
+#: builtin/reflog.c:22
+msgid ""
+"git reflog delete [--rewrite] [--updateref] [--dry-run | -n] [--verbose] "
+"<refs>..."
+msgstr ""
+
+#: builtin/reflog.c:25
+msgid "git reflog exists <ref>"
+msgstr ""
+
+#: builtin/reflog.c:567 builtin/reflog.c:572
+#, c-format
+msgid "'%s' is not a valid timestamp"
+msgstr ""
+
+#: builtin/reflog.c:605
+#, c-format
+msgid "Marking reachable objects..."
+msgstr ""
+
+#: builtin/reflog.c:643
+#, c-format
+msgid "%s points nowhere!"
+msgstr ""
+
+#: builtin/reflog.c:695
+msgid "no reflog specified to delete"
+msgstr ""
+
+#: builtin/reflog.c:704
+#, c-format
+msgid "not a reflog: %s"
+msgstr ""
+
+#: builtin/reflog.c:709
+#, c-format
+msgid "no reflog for '%s'"
+msgstr ""
+
+#: builtin/reflog.c:755
+#, c-format
+msgid "invalid ref format: %s"
+msgstr ""
+
+#: builtin/reflog.c:764
+msgid "git reflog [ show | expire | delete | exists ]"
+msgstr ""
+
+#: builtin/remote.c:16
+msgid "git remote [-v | --verbose]"
+msgstr ""
+
+#: builtin/remote.c:17
+msgid ""
+"git remote add [-t <branch>] [-m <master>] [-f] [--tags | --no-tags] [--"
+"mirror=<fetch|push>] <name> <url>"
+msgstr ""
+
+#: builtin/remote.c:18 builtin/remote.c:38
+msgid "git remote rename <old> <new>"
+msgstr ""
+
+#: builtin/remote.c:19 builtin/remote.c:43
+msgid "git remote remove <name>"
+msgstr ""
+
+#: builtin/remote.c:20 builtin/remote.c:48
+msgid "git remote set-head <name> (-a | --auto | -d | --delete | <branch>)"
+msgstr ""
+
+#: builtin/remote.c:21
+msgid "git remote [-v | --verbose] show [-n] <name>"
+msgstr ""
+
+#: builtin/remote.c:22
+msgid "git remote prune [-n | --dry-run] <name>"
+msgstr ""
+
+#: builtin/remote.c:23
+msgid ""
+"git remote [-v | --verbose] update [-p | --prune] [(<group> | <remote>)...]"
+msgstr ""
+
+#: builtin/remote.c:24
+msgid "git remote set-branches [--add] <name> <branch>..."
+msgstr ""
+
+#: builtin/remote.c:25 builtin/remote.c:74
+msgid "git remote get-url [--push] [--all] <name>"
+msgstr ""
+
+#: builtin/remote.c:26 builtin/remote.c:79
+msgid "git remote set-url [--push] <name> <newurl> [<oldurl>]"
+msgstr ""
+
+#: builtin/remote.c:27 builtin/remote.c:80
+msgid "git remote set-url --add <name> <newurl>"
+msgstr ""
+
+#: builtin/remote.c:28 builtin/remote.c:81
+msgid "git remote set-url --delete <name> <url>"
+msgstr ""
+
+#: builtin/remote.c:33
+msgid "git remote add [<options>] <name> <url>"
+msgstr ""
+
+#: builtin/remote.c:53
+msgid "git remote set-branches <name> <branch>..."
+msgstr ""
+
+#: builtin/remote.c:54
+msgid "git remote set-branches --add <name> <branch>..."
+msgstr ""
+
+#: builtin/remote.c:59
+msgid "git remote show [<options>] <name>"
+msgstr ""
+
+#: builtin/remote.c:64
+msgid "git remote prune [<options>] <name>"
+msgstr ""
+
+#: builtin/remote.c:69
+msgid "git remote update [<options>] [<group> | <remote>]..."
+msgstr ""
+
+#: builtin/remote.c:98
+#, c-format
+msgid "Updating %s"
+msgstr ""
+
+#: builtin/remote.c:130
+msgid ""
+"--mirror is dangerous and deprecated; please\n"
+"\t use --mirror=fetch or --mirror=push instead"
+msgstr ""
+
+#: builtin/remote.c:147
+#, c-format
+msgid "unknown mirror argument: %s"
+msgstr ""
+
+#: builtin/remote.c:163
+msgid "fetch the remote branches"
+msgstr ""
+
+#: builtin/remote.c:165
+msgid "import all tags and associated objects when fetching"
+msgstr ""
+
+#: builtin/remote.c:168
+msgid "or do not fetch any tag at all (--no-tags)"
+msgstr ""
+
+#: builtin/remote.c:170
+msgid "branch(es) to track"
+msgstr ""
+
+#: builtin/remote.c:171
+msgid "master branch"
+msgstr ""
+
+#: builtin/remote.c:173
+msgid "set up remote as a mirror to push to or fetch from"
+msgstr ""
+
+#: builtin/remote.c:185
+msgid "specifying a master branch makes no sense with --mirror"
+msgstr ""
+
+#: builtin/remote.c:187
+msgid "specifying branches to track makes sense only with fetch mirrors"
+msgstr ""
+
+#: builtin/remote.c:194 builtin/remote.c:636
+#, c-format
+msgid "remote %s already exists."
+msgstr ""
+
+#: builtin/remote.c:198 builtin/remote.c:640
+#, c-format
+msgid "'%s' is not a valid remote name"
+msgstr ""
+
+#: builtin/remote.c:238
+#, c-format
+msgid "Could not setup master '%s'"
+msgstr ""
+
+#: builtin/remote.c:344
+#, c-format
+msgid "Could not get fetch map for refspec %s"
+msgstr ""
+
+#: builtin/remote.c:443 builtin/remote.c:451
+msgid "(matching)"
+msgstr ""
+
+#: builtin/remote.c:455
+msgid "(delete)"
+msgstr ""
+
+#: builtin/remote.c:629 builtin/remote.c:764 builtin/remote.c:863
+#, c-format
+msgid "No such remote: '%s'"
+msgstr ""
+
+#: builtin/remote.c:646
+#, c-format
+msgid "Could not rename config section '%s' to '%s'"
+msgstr ""
+
+#: builtin/remote.c:666
+#, c-format
+msgid ""
+"Not updating non-default fetch refspec\n"
+"\t%s\n"
+"\tPlease update the configuration manually if necessary."
+msgstr ""
+
+#: builtin/remote.c:701
+#, c-format
+msgid "deleting '%s' failed"
+msgstr ""
+
+#: builtin/remote.c:735
+#, c-format
+msgid "creating '%s' failed"
+msgstr ""
+
+#: builtin/remote.c:801
+msgid ""
+"Note: A branch outside the refs/remotes/ hierarchy was not removed;\n"
+"to delete it, use:"
+msgid_plural ""
+"Note: Some branches outside the refs/remotes/ hierarchy were not removed;\n"
+"to delete them, use:"
+msgstr[0] ""
+msgstr[1] ""
+
+#: builtin/remote.c:815
+#, c-format
+msgid "Could not remove config section '%s'"
+msgstr ""
+
+#: builtin/remote.c:916
+#, c-format
+msgid " new (next fetch will store in remotes/%s)"
+msgstr ""
+
+#: builtin/remote.c:919
+msgid " tracked"
+msgstr ""
+
+#: builtin/remote.c:921
+msgid " stale (use 'git remote prune' to remove)"
+msgstr ""
+
+#: builtin/remote.c:923
+msgid " ???"
+msgstr ""
+
+#: builtin/remote.c:964
+#, c-format
+msgid "invalid branch.%s.merge; cannot rebase onto > 1 branch"
+msgstr ""
+
+#: builtin/remote.c:973
+#, c-format
+msgid "rebases interactively onto remote %s"
+msgstr ""
+
+#: builtin/remote.c:975
+#, c-format
+msgid "rebases interactively (with merges) onto remote %s"
+msgstr ""
+
+#: builtin/remote.c:978
+#, c-format
+msgid "rebases onto remote %s"
+msgstr ""
+
+#: builtin/remote.c:982
+#, c-format
+msgid " merges with remote %s"
+msgstr ""
+
+#: builtin/remote.c:985
+#, c-format
+msgid "merges with remote %s"
+msgstr ""
+
+#: builtin/remote.c:988
+#, c-format
+msgid "%-*s    and with remote %s\n"
+msgstr ""
+
+#: builtin/remote.c:1031
+msgid "create"
+msgstr ""
+
+#: builtin/remote.c:1034
+msgid "delete"
+msgstr ""
+
+#: builtin/remote.c:1038
+msgid "up to date"
+msgstr ""
+
+#: builtin/remote.c:1041
+msgid "fast-forwardable"
+msgstr ""
+
+#: builtin/remote.c:1044
+msgid "local out of date"
+msgstr ""
+
+#: builtin/remote.c:1051
+#, c-format
+msgid "    %-*s forces to %-*s (%s)"
+msgstr ""
+
+#: builtin/remote.c:1054
+#, c-format
+msgid "    %-*s pushes to %-*s (%s)"
+msgstr ""
+
+#: builtin/remote.c:1058
+#, c-format
+msgid "    %-*s forces to %s"
+msgstr ""
+
+#: builtin/remote.c:1061
+#, c-format
+msgid "    %-*s pushes to %s"
+msgstr ""
+
+#: builtin/remote.c:1129
+msgid "do not query remotes"
+msgstr ""
+
+#: builtin/remote.c:1156
+#, c-format
+msgid "* remote %s"
+msgstr ""
+
+#: builtin/remote.c:1157
+#, c-format
+msgid "  Fetch URL: %s"
+msgstr ""
+
+#: builtin/remote.c:1158 builtin/remote.c:1174 builtin/remote.c:1313
+msgid "(no URL)"
+msgstr ""
+
+#. TRANSLATORS: the colon ':' should align
+#. with the one in " Fetch URL: %s"
+#. translation.
+#.
+#: builtin/remote.c:1172 builtin/remote.c:1174
+#, c-format
+msgid "  Push  URL: %s"
+msgstr ""
+
+#: builtin/remote.c:1176 builtin/remote.c:1178 builtin/remote.c:1180
+#, c-format
+msgid "  HEAD branch: %s"
+msgstr ""
+
+#: builtin/remote.c:1176
+msgid "(not queried)"
+msgstr ""
+
+#: builtin/remote.c:1178
+msgid "(unknown)"
+msgstr ""
+
+#: builtin/remote.c:1182
+#, c-format
+msgid ""
+"  HEAD branch (remote HEAD is ambiguous, may be one of the following):\n"
+msgstr ""
+
+#: builtin/remote.c:1194
+#, c-format
+msgid "  Remote branch:%s"
+msgid_plural "  Remote branches:%s"
+msgstr[0] ""
+msgstr[1] ""
+
+#: builtin/remote.c:1197 builtin/remote.c:1223
+msgid " (status not queried)"
+msgstr ""
+
+#: builtin/remote.c:1206
+msgid "  Local branch configured for 'git pull':"
+msgid_plural "  Local branches configured for 'git pull':"
+msgstr[0] ""
+msgstr[1] ""
+
+#: builtin/remote.c:1214
+msgid "  Local refs will be mirrored by 'git push'"
+msgstr ""
+
+#: builtin/remote.c:1220
+#, c-format
+msgid "  Local ref configured for 'git push'%s:"
+msgid_plural "  Local refs configured for 'git push'%s:"
+msgstr[0] ""
+msgstr[1] ""
+
+#: builtin/remote.c:1241
+msgid "set refs/remotes/<name>/HEAD according to remote"
+msgstr ""
+
+#: builtin/remote.c:1243
+msgid "delete refs/remotes/<name>/HEAD"
+msgstr ""
+
+#: builtin/remote.c:1258
+msgid "Cannot determine remote HEAD"
+msgstr ""
+
+#: builtin/remote.c:1260
+msgid "Multiple remote HEAD branches. Please choose one explicitly with:"
+msgstr ""
+
+#: builtin/remote.c:1270
+#, c-format
+msgid "Could not delete %s"
+msgstr ""
+
+#: builtin/remote.c:1278
+#, c-format
+msgid "Not a valid ref: %s"
+msgstr ""
+
+#: builtin/remote.c:1280
+#, c-format
+msgid "Could not setup %s"
+msgstr ""
+
+#: builtin/remote.c:1298
+#, c-format
+msgid " %s will become dangling!"
+msgstr ""
+
+#: builtin/remote.c:1299
+#, c-format
+msgid " %s has become dangling!"
+msgstr ""
+
+#: builtin/remote.c:1309
+#, c-format
+msgid "Pruning %s"
+msgstr ""
+
+#: builtin/remote.c:1310
+#, c-format
+msgid "URL: %s"
+msgstr ""
+
+#: builtin/remote.c:1326
+#, c-format
+msgid " * [would prune] %s"
+msgstr ""
+
+#: builtin/remote.c:1329
+#, c-format
+msgid " * [pruned] %s"
+msgstr ""
+
+#: builtin/remote.c:1374
+msgid "prune remotes after fetching"
+msgstr ""
+
+#: builtin/remote.c:1437 builtin/remote.c:1491 builtin/remote.c:1559
+#, c-format
+msgid "No such remote '%s'"
+msgstr ""
+
+#: builtin/remote.c:1453
+msgid "add branch"
+msgstr ""
+
+#: builtin/remote.c:1460
+msgid "no remote specified"
+msgstr ""
+
+#: builtin/remote.c:1477
+msgid "query push URLs rather than fetch URLs"
+msgstr ""
+
+#: builtin/remote.c:1479
+msgid "return all URLs"
+msgstr ""
+
+#: builtin/remote.c:1507
+#, c-format
+msgid "no URLs configured for remote '%s'"
+msgstr ""
+
+#: builtin/remote.c:1533
+msgid "manipulate push URLs"
+msgstr ""
+
+#: builtin/remote.c:1535
+msgid "add URL"
+msgstr ""
+
+#: builtin/remote.c:1537
+msgid "delete URLs"
+msgstr ""
+
+#: builtin/remote.c:1544
+msgid "--add --delete doesn't make sense"
+msgstr ""
+
+#: builtin/remote.c:1583
+#, c-format
+msgid "Invalid old URL pattern: %s"
+msgstr ""
+
+#: builtin/remote.c:1591
+#, c-format
+msgid "No such URL found: %s"
+msgstr ""
+
+#: builtin/remote.c:1593
+msgid "Will not delete all non-push URLs"
+msgstr ""
+
+#: builtin/repack.c:23
+msgid "git repack [<options>]"
+msgstr ""
+
+#: builtin/repack.c:28
+msgid ""
+"Incremental repacks are incompatible with bitmap indexes.  Use\n"
+"--no-write-bitmap-index or disable the pack.writebitmaps configuration."
+msgstr ""
+
+#: builtin/repack.c:191
+msgid "could not start pack-objects to repack promisor objects"
+msgstr ""
+
+#: builtin/repack.c:230 builtin/repack.c:416
+msgid "repack: Expecting full hex object ID lines only from pack-objects."
+msgstr ""
+
+#: builtin/repack.c:254
+msgid "could not finish pack-objects to repack promisor objects"
+msgstr ""
+
+#: builtin/repack.c:292
+msgid "pack everything in a single pack"
+msgstr ""
+
+#: builtin/repack.c:294
+msgid "same as -a, and turn unreachable objects loose"
+msgstr ""
+
+#: builtin/repack.c:297
+msgid "remove redundant packs, and run git-prune-packed"
+msgstr ""
+
+#: builtin/repack.c:299
+msgid "pass --no-reuse-delta to git-pack-objects"
+msgstr ""
+
+#: builtin/repack.c:301
+msgid "pass --no-reuse-object to git-pack-objects"
+msgstr ""
+
+#: builtin/repack.c:303
+msgid "do not run git-update-server-info"
+msgstr ""
+
+#: builtin/repack.c:306
+msgid "pass --local to git-pack-objects"
+msgstr ""
+
+#: builtin/repack.c:308
+msgid "write bitmap index"
+msgstr ""
+
+#: builtin/repack.c:310
+msgid "pass --delta-islands to git-pack-objects"
+msgstr ""
+
+#: builtin/repack.c:311
+msgid "approxidate"
+msgstr ""
+
+#: builtin/repack.c:312
+msgid "with -A, do not loosen objects older than this"
+msgstr ""
+
+#: builtin/repack.c:314
+msgid "with -a, repack unreachable objects"
+msgstr ""
+
+#: builtin/repack.c:316
+msgid "size of the window used for delta compression"
+msgstr ""
+
+#: builtin/repack.c:317 builtin/repack.c:323
+msgid "bytes"
+msgstr ""
+
+#: builtin/repack.c:318
+msgid "same as the above, but limit memory size instead of entries count"
+msgstr ""
+
+#: builtin/repack.c:320
+msgid "limits the maximum delta depth"
+msgstr ""
+
+#: builtin/repack.c:322
+msgid "limits the maximum number of threads"
+msgstr ""
+
+#: builtin/repack.c:324
+msgid "maximum size of each packfile"
+msgstr ""
+
+#: builtin/repack.c:326
+msgid "repack objects in packs marked with .keep"
+msgstr ""
+
+#: builtin/repack.c:328
+msgid "do not repack this pack"
+msgstr ""
+
+#: builtin/repack.c:338
+msgid "cannot delete packs in a precious-objects repo"
+msgstr ""
+
+#: builtin/repack.c:342
+msgid "--keep-unreachable and -A are incompatible"
+msgstr ""
+
+#: builtin/repack.c:425
+msgid "Nothing new to pack."
+msgstr ""
+
+#: builtin/repack.c:486
+#, c-format
+msgid ""
+"WARNING: Some packs in use have been renamed by\n"
+"WARNING: prefixing old- to their name, in order to\n"
+"WARNING: replace them with the new version of the\n"
+"WARNING: file.  But the operation failed, and the\n"
+"WARNING: attempt to rename them back to their\n"
+"WARNING: original names also failed.\n"
+"WARNING: Please rename them in %s manually:\n"
+msgstr ""
+
+#: builtin/repack.c:534
+#, c-format
+msgid "failed to remove '%s'"
+msgstr ""
+
+#: builtin/replace.c:22
+msgid "git replace [-f] <object> <replacement>"
+msgstr ""
+
+#: builtin/replace.c:23
+msgid "git replace [-f] --edit <object>"
+msgstr ""
+
+#: builtin/replace.c:24
+msgid "git replace [-f] --graft <commit> [<parent>...]"
+msgstr ""
+
+#: builtin/replace.c:25
+msgid "git replace [-f] --convert-graft-file"
+msgstr ""
+
+#: builtin/replace.c:26
+msgid "git replace -d <object>..."
+msgstr ""
+
+#: builtin/replace.c:27
+msgid "git replace [--format=<format>] [-l [<pattern>]]"
+msgstr ""
+
+#: builtin/replace.c:90
+#, c-format
+msgid ""
+"invalid replace format '%s'\n"
+"valid formats are 'short', 'medium' and 'long'"
+msgstr ""
+
+#: builtin/replace.c:125
+#, c-format
+msgid "replace ref '%s' not found"
+msgstr ""
+
+#: builtin/replace.c:141
+#, c-format
+msgid "Deleted replace ref '%s'"
+msgstr ""
+
+#: builtin/replace.c:153
+#, c-format
+msgid "'%s' is not a valid ref name"
+msgstr ""
+
+#: builtin/replace.c:158
+#, c-format
+msgid "replace ref '%s' already exists"
+msgstr ""
+
+#: builtin/replace.c:178
+#, c-format
+msgid ""
+"Objects must be of the same type.\n"
+"'%s' points to a replaced object of type '%s'\n"
+"while '%s' points to a replacement object of type '%s'."
+msgstr ""
+
+#: builtin/replace.c:229
+#, c-format
+msgid "unable to open %s for writing"
+msgstr ""
+
+#: builtin/replace.c:242
+msgid "cat-file reported failure"
+msgstr ""
+
+#: builtin/replace.c:258
+#, c-format
+msgid "unable to open %s for reading"
+msgstr ""
+
+#: builtin/replace.c:272
+msgid "unable to spawn mktree"
+msgstr ""
+
+#: builtin/replace.c:276
+msgid "unable to read from mktree"
+msgstr ""
+
+#: builtin/replace.c:285
+msgid "mktree reported failure"
+msgstr ""
+
+#: builtin/replace.c:289
+msgid "mktree did not return an object name"
+msgstr ""
+
+#: builtin/replace.c:298
+#, c-format
+msgid "unable to fstat %s"
+msgstr ""
+
+#: builtin/replace.c:303
+msgid "unable to write object to database"
+msgstr ""
+
+#: builtin/replace.c:322 builtin/replace.c:378 builtin/replace.c:423
+#: builtin/replace.c:453
+#, c-format
+msgid "not a valid object name: '%s'"
+msgstr ""
+
+#: builtin/replace.c:326
+#, c-format
+msgid "unable to get object type for %s"
+msgstr ""
+
+#: builtin/replace.c:342
+msgid "editing object file failed"
+msgstr ""
+
+#: builtin/replace.c:351
+#, c-format
+msgid "new object is the same as the old one: '%s'"
+msgstr ""
+
+#: builtin/replace.c:384
+#, c-format
+msgid "could not parse %s as a commit"
+msgstr ""
+
+#: builtin/replace.c:415
+#, c-format
+msgid "bad mergetag in commit '%s'"
+msgstr ""
+
+#: builtin/replace.c:417
+#, c-format
+msgid "malformed mergetag in commit '%s'"
+msgstr ""
+
+#: builtin/replace.c:429
+#, c-format
+msgid ""
+"original commit '%s' contains mergetag '%s' that is discarded; use --edit "
+"instead of --graft"
+msgstr ""
+
+#: builtin/replace.c:468
+#, c-format
+msgid "the original commit '%s' has a gpg signature"
+msgstr ""
+
+#: builtin/replace.c:469
+msgid "the signature will be removed in the replacement commit!"
+msgstr ""
+
+#: builtin/replace.c:479
+#, c-format
+msgid "could not write replacement commit for: '%s'"
+msgstr ""
+
+#: builtin/replace.c:487
+#, c-format
+msgid "graft for '%s' unnecessary"
+msgstr ""
+
+#: builtin/replace.c:491
+#, c-format
+msgid "new commit is the same as the old one: '%s'"
+msgstr ""
+
+#: builtin/replace.c:526
+#, c-format
+msgid ""
+"could not convert the following graft(s):\n"
+"%s"
+msgstr ""
+
+#: builtin/replace.c:547
+msgid "list replace refs"
+msgstr ""
+
+#: builtin/replace.c:548
+msgid "delete replace refs"
+msgstr ""
+
+#: builtin/replace.c:549
+msgid "edit existing object"
+msgstr ""
+
+#: builtin/replace.c:550
+msgid "change a commit's parents"
+msgstr ""
+
+#: builtin/replace.c:551
+msgid "convert existing graft file"
+msgstr ""
+
+#: builtin/replace.c:552
+msgid "replace the ref if it exists"
+msgstr ""
+
+#: builtin/replace.c:554
+msgid "do not pretty-print contents for --edit"
+msgstr ""
+
+#: builtin/replace.c:555
+msgid "use this format"
+msgstr ""
+
+#: builtin/replace.c:568
+msgid "--format cannot be used when not listing"
+msgstr ""
+
+#: builtin/replace.c:576
+msgid "-f only makes sense when writing a replacement"
+msgstr ""
+
+#: builtin/replace.c:580
+msgid "--raw only makes sense with --edit"
+msgstr ""
+
+#: builtin/replace.c:586
+msgid "-d needs at least one argument"
+msgstr ""
+
+#: builtin/replace.c:592
+msgid "bad number of arguments"
+msgstr ""
+
+#: builtin/replace.c:598
+msgid "-e needs exactly one argument"
+msgstr ""
+
+#: builtin/replace.c:604
+msgid "-g needs at least one argument"
+msgstr ""
+
+#: builtin/replace.c:610
+msgid "--convert-graft-file takes no argument"
+msgstr ""
+
+#: builtin/replace.c:616
+msgid "only one pattern can be given with -l"
+msgstr ""
+
+#: builtin/rerere.c:13
+msgid "git rerere [clear | forget <path>... | status | remaining | diff | gc]"
+msgstr ""
+
+#: builtin/rerere.c:60
+msgid "register clean resolutions in index"
+msgstr ""
+
+#: builtin/rerere.c:79
+msgid "'git rerere forget' without paths is deprecated"
+msgstr ""
+
+#: builtin/rerere.c:113
+#, c-format
+msgid "unable to generate diff for '%s'"
+msgstr ""
+
+#: builtin/reset.c:32
+msgid ""
+"git reset [--mixed | --soft | --hard | --merge | --keep] [-q] [<commit>]"
+msgstr ""
+
+#: builtin/reset.c:33
+msgid "git reset [-q] [<tree-ish>] [--] <pathspec>..."
+msgstr ""
+
+#: builtin/reset.c:34
+msgid ""
+"git reset [-q] [--pathspec-from-file [--pathspec-file-nul]] [<tree-ish>]"
+msgstr ""
+
+#: builtin/reset.c:35
+msgid "git reset --patch [<tree-ish>] [--] [<pathspec>...]"
+msgstr ""
+
+#: builtin/reset.c:41
+msgid "mixed"
+msgstr ""
+
+#: builtin/reset.c:41
+msgid "soft"
+msgstr ""
+
+#: builtin/reset.c:41
+msgid "hard"
+msgstr ""
+
+#: builtin/reset.c:41
+msgid "merge"
+msgstr ""
+
+#: builtin/reset.c:41
+msgid "keep"
+msgstr ""
+
+#: builtin/reset.c:82
+msgid "You do not have a valid HEAD."
+msgstr ""
+
+#: builtin/reset.c:84
+msgid "Failed to find tree of HEAD."
+msgstr ""
+
+#: builtin/reset.c:90
+#, c-format
+msgid "Failed to find tree of %s."
+msgstr ""
+
+#: builtin/reset.c:115
+#, c-format
+msgid "HEAD is now at %s"
+msgstr ""
+
+#: builtin/reset.c:194
+#, c-format
+msgid "Cannot do a %s reset in the middle of a merge."
+msgstr ""
+
+#: builtin/reset.c:294 builtin/stash.c:519 builtin/stash.c:594
+#: builtin/stash.c:618
+msgid "be quiet, only report errors"
+msgstr ""
+
+#: builtin/reset.c:296
+msgid "reset HEAD and index"
+msgstr ""
+
+#: builtin/reset.c:297
+msgid "reset only HEAD"
+msgstr ""
+
+#: builtin/reset.c:299 builtin/reset.c:301
+msgid "reset HEAD, index and working tree"
+msgstr ""
+
+#: builtin/reset.c:303
+msgid "reset HEAD but keep local changes"
+msgstr ""
+
+#: builtin/reset.c:309
+msgid "record only the fact that removed paths will be added later"
+msgstr ""
+
+#: builtin/reset.c:343
+#, c-format
+msgid "Failed to resolve '%s' as a valid revision."
+msgstr ""
+
+#: builtin/reset.c:351
+#, c-format
+msgid "Failed to resolve '%s' as a valid tree."
+msgstr ""
+
+#: builtin/reset.c:360
+msgid "--patch is incompatible with --{hard,mixed,soft}"
+msgstr ""
+
+#: builtin/reset.c:370
+msgid "--mixed with paths is deprecated; use 'git reset -- <paths>' instead."
+msgstr ""
+
+#: builtin/reset.c:372
+#, c-format
+msgid "Cannot do %s reset with paths."
+msgstr ""
+
+#: builtin/reset.c:387
+#, c-format
+msgid "%s reset is not allowed in a bare repository"
+msgstr ""
+
+#: builtin/reset.c:391
+msgid "-N can only be used with --mixed"
+msgstr ""
+
+#: builtin/reset.c:412
+msgid "Unstaged changes after reset:"
+msgstr ""
+
+#: builtin/reset.c:415
+#, c-format
+msgid ""
+"\n"
+"It took %.2f seconds to enumerate unstaged changes after reset.  You can\n"
+"use '--quiet' to avoid this.  Set the config setting reset.quiet to true\n"
+"to make this the default.\n"
+msgstr ""
+
+#: builtin/reset.c:425
+#, c-format
+msgid "Could not reset index file to revision '%s'."
+msgstr ""
+
+#: builtin/reset.c:429
+msgid "Could not write new index file."
+msgstr ""
+
+#: builtin/rev-list.c:411
+msgid "cannot combine --exclude-promisor-objects and --missing"
+msgstr ""
+
+#: builtin/rev-list.c:472
+msgid "object filtering requires --objects"
+msgstr ""
+
+#: builtin/rev-list.c:522
+msgid "rev-list does not support display of notes"
+msgstr ""
+
+#: builtin/rev-list.c:525
+msgid "cannot combine --use-bitmap-index with object filtering"
+msgstr ""
+
+#: builtin/rev-parse.c:408
+msgid "git rev-parse --parseopt [<options>] -- [<args>...]"
+msgstr ""
+
+#: builtin/rev-parse.c:413
+msgid "keep the `--` passed as an arg"
+msgstr ""
+
+#: builtin/rev-parse.c:415
+msgid "stop parsing after the first non-option argument"
+msgstr ""
+
+#: builtin/rev-parse.c:418
+msgid "output in stuck long form"
+msgstr ""
+
+#: builtin/rev-parse.c:551
+msgid ""
+"git rev-parse --parseopt [<options>] -- [<args>...]\n"
+"   or: git rev-parse --sq-quote [<arg>...]\n"
+"   or: git rev-parse [<options>] [<arg>...]\n"
+"\n"
+"Run \"git rev-parse --parseopt -h\" for more information on the first usage."
+msgstr ""
+
+#: builtin/revert.c:24
+msgid "git revert [<options>] <commit-ish>..."
+msgstr ""
+
+#: builtin/revert.c:25
+msgid "git revert <subcommand>"
+msgstr ""
+
+#: builtin/revert.c:30
+msgid "git cherry-pick [<options>] <commit-ish>..."
+msgstr ""
+
+#: builtin/revert.c:31
+msgid "git cherry-pick <subcommand>"
+msgstr ""
+
+#: builtin/revert.c:72
+#, c-format
+msgid "option `%s' expects a number greater than zero"
+msgstr ""
+
+#: builtin/revert.c:92
+#, c-format
+msgid "%s: %s cannot be used with %s"
+msgstr ""
+
+#: builtin/revert.c:102
+msgid "end revert or cherry-pick sequence"
+msgstr ""
+
+#: builtin/revert.c:103
+msgid "resume revert or cherry-pick sequence"
+msgstr ""
+
+#: builtin/revert.c:104
+msgid "cancel revert or cherry-pick sequence"
+msgstr ""
+
+#: builtin/revert.c:105
+msgid "skip current commit and continue"
+msgstr ""
+
+#: builtin/revert.c:107
+msgid "don't automatically commit"
+msgstr ""
+
+#: builtin/revert.c:108
+msgid "edit the commit message"
+msgstr ""
+
+#: builtin/revert.c:111
+msgid "parent-number"
+msgstr ""
+
+#: builtin/revert.c:112
+msgid "select mainline parent"
+msgstr ""
+
+#: builtin/revert.c:114
+msgid "merge strategy"
+msgstr ""
+
+#: builtin/revert.c:116
+msgid "option for merge strategy"
+msgstr ""
+
+#: builtin/revert.c:125
+msgid "append commit name"
+msgstr ""
+
+#: builtin/revert.c:127
+msgid "preserve initially empty commits"
+msgstr ""
+
+#: builtin/revert.c:129
+msgid "keep redundant, empty commits"
+msgstr ""
+
+#: builtin/revert.c:232
+msgid "revert failed"
+msgstr ""
+
+#: builtin/revert.c:245
+msgid "cherry-pick failed"
+msgstr ""
+
+#: builtin/rm.c:19
+msgid "git rm [<options>] [--] <file>..."
+msgstr ""
+
+#: builtin/rm.c:207
+msgid ""
+"the following file has staged content different from both the\n"
+"file and the HEAD:"
+msgid_plural ""
+"the following files have staged content different from both the\n"
+"file and the HEAD:"
+msgstr[0] ""
+msgstr[1] ""
+
+#: builtin/rm.c:212
+msgid ""
+"\n"
+"(use -f to force removal)"
+msgstr ""
+
+#: builtin/rm.c:216
+msgid "the following file has changes staged in the index:"
+msgid_plural "the following files have changes staged in the index:"
+msgstr[0] ""
+msgstr[1] ""
+
+#: builtin/rm.c:220 builtin/rm.c:229
+msgid ""
+"\n"
+"(use --cached to keep the file, or -f to force removal)"
+msgstr ""
+
+#: builtin/rm.c:226
+msgid "the following file has local modifications:"
+msgid_plural "the following files have local modifications:"
+msgstr[0] ""
+msgstr[1] ""
+
+#: builtin/rm.c:242
+msgid "do not list removed files"
+msgstr ""
+
+#: builtin/rm.c:243
+msgid "only remove from the index"
+msgstr ""
+
+#: builtin/rm.c:244
+msgid "override the up-to-date check"
+msgstr ""
+
+#: builtin/rm.c:245
+msgid "allow recursive removal"
+msgstr ""
+
+#: builtin/rm.c:247
+msgid "exit with a zero status even if nothing matched"
+msgstr ""
+
+#: builtin/rm.c:289
+msgid "please stage your changes to .gitmodules or stash them to proceed"
+msgstr ""
+
+#: builtin/rm.c:307
+#, c-format
+msgid "not removing '%s' recursively without -r"
+msgstr ""
+
+#: builtin/rm.c:346
+#, c-format
+msgid "git rm: unable to remove %s"
+msgstr ""
+
+#: builtin/send-pack.c:20
+msgid ""
+"git send-pack [--all | --mirror] [--dry-run] [--force] [--receive-pack=<git-"
+"receive-pack>] [--verbose] [--thin] [--atomic] [<host>:]<directory> "
+"[<ref>...]\n"
+"  --all and explicit <ref> specification are mutually exclusive."
+msgstr ""
+
+#: builtin/send-pack.c:163
+msgid "remote name"
+msgstr ""
+
+#: builtin/send-pack.c:177
+msgid "use stateless RPC protocol"
+msgstr ""
+
+#: builtin/send-pack.c:178
+msgid "read refs from stdin"
+msgstr ""
+
+#: builtin/send-pack.c:179
+msgid "print status from remote helper"
+msgstr ""
+
+#: builtin/shortlog.c:14
+msgid "git shortlog [<options>] [<revision-range>] [[--] <path>...]"
+msgstr ""
+
+#: builtin/shortlog.c:15
+msgid "git log --pretty=short | git shortlog [<options>]"
+msgstr ""
+
+#: builtin/shortlog.c:264
+msgid "Group by committer rather than author"
+msgstr ""
+
+#: builtin/shortlog.c:266
+msgid "sort output according to the number of commits per author"
+msgstr ""
+
+#: builtin/shortlog.c:268
+msgid "Suppress commit descriptions, only provides commit count"
+msgstr ""
+
+#: builtin/shortlog.c:270
+msgid "Show the email address of each author"
+msgstr ""
+
+#: builtin/shortlog.c:271
+msgid "<w>[,<i1>[,<i2>]]"
+msgstr ""
+
+#: builtin/shortlog.c:272
+msgid "Linewrap output"
+msgstr ""
+
+#: builtin/shortlog.c:301
+msgid "too many arguments given outside repository"
+msgstr ""
+
+#: builtin/show-branch.c:13
+msgid ""
+"git show-branch [-a | --all] [-r | --remotes] [--topo-order | --date-order]\n"
+"\t\t[--current] [--color[=<when>] | --no-color] [--sparse]\n"
+"\t\t[--more=<n> | --list | --independent | --merge-base]\n"
+"\t\t[--no-name | --sha1-name] [--topics] [(<rev> | <glob>)...]"
+msgstr ""
+
+#: builtin/show-branch.c:17
+msgid "git show-branch (-g | --reflog)[=<n>[,<base>]] [--list] [<ref>]"
+msgstr ""
+
+#: builtin/show-branch.c:395
+#, c-format
+msgid "ignoring %s; cannot handle more than %d ref"
+msgid_plural "ignoring %s; cannot handle more than %d refs"
+msgstr[0] ""
+msgstr[1] ""
+
+#: builtin/show-branch.c:548
+#, c-format
+msgid "no matching refs with %s"
+msgstr ""
+
+#: builtin/show-branch.c:645
+msgid "show remote-tracking and local branches"
+msgstr ""
+
+#: builtin/show-branch.c:647
+msgid "show remote-tracking branches"
+msgstr ""
+
+#: builtin/show-branch.c:649
+msgid "color '*!+-' corresponding to the branch"
+msgstr ""
+
+#: builtin/show-branch.c:651
+msgid "show <n> more commits after the common ancestor"
+msgstr ""
+
+#: builtin/show-branch.c:653
+msgid "synonym to more=-1"
+msgstr ""
+
+#: builtin/show-branch.c:654
+msgid "suppress naming strings"
+msgstr ""
+
+#: builtin/show-branch.c:656
+msgid "include the current branch"
+msgstr ""
+
+#: builtin/show-branch.c:658
+msgid "name commits with their object names"
+msgstr ""
+
+#: builtin/show-branch.c:660
+msgid "show possible merge bases"
+msgstr ""
+
+#: builtin/show-branch.c:662
+msgid "show refs unreachable from any other ref"
+msgstr ""
+
+#: builtin/show-branch.c:664
+msgid "show commits in topological order"
+msgstr ""
+
+#: builtin/show-branch.c:667
+msgid "show only commits not on the first branch"
+msgstr ""
+
+#: builtin/show-branch.c:669
+msgid "show merges reachable from only one tip"
+msgstr ""
+
+#: builtin/show-branch.c:671
+msgid "topologically sort, maintaining date order where possible"
+msgstr ""
+
+#: builtin/show-branch.c:674
+msgid "<n>[,<base>]"
+msgstr ""
+
+#: builtin/show-branch.c:675
+msgid "show <n> most recent ref-log entries starting at base"
+msgstr ""
+
+#: builtin/show-branch.c:711
+msgid ""
+"--reflog is incompatible with --all, --remotes, --independent or --merge-base"
+msgstr ""
+
+#: builtin/show-branch.c:735
+msgid "no branches given, and HEAD is not valid"
+msgstr ""
+
+#: builtin/show-branch.c:738
+msgid "--reflog option needs one branch name"
+msgstr ""
+
+#: builtin/show-branch.c:741
+#, c-format
+msgid "only %d entry can be shown at one time."
+msgid_plural "only %d entries can be shown at one time."
+msgstr[0] ""
+msgstr[1] ""
+
+#: builtin/show-branch.c:745
+#, c-format
+msgid "no such ref %s"
+msgstr ""
+
+#: builtin/show-branch.c:831
+#, c-format
+msgid "cannot handle more than %d rev."
+msgid_plural "cannot handle more than %d revs."
+msgstr[0] ""
+msgstr[1] ""
+
+#: builtin/show-branch.c:835
+#, c-format
+msgid "'%s' is not a valid ref."
+msgstr ""
+
+#: builtin/show-branch.c:838
+#, c-format
+msgid "cannot find commit %s (%s)"
+msgstr ""
+
+#: builtin/show-ref.c:12
+msgid ""
+"git show-ref [-q | --quiet] [--verify] [--head] [-d | --dereference] [-s | --"
+"hash[=<n>]] [--abbrev[=<n>]] [--tags] [--heads] [--] [<pattern>...]"
+msgstr ""
+
+#: builtin/show-ref.c:13
+msgid "git show-ref --exclude-existing[=<pattern>]"
+msgstr ""
+
+#: builtin/show-ref.c:162
+msgid "only show tags (can be combined with heads)"
+msgstr ""
+
+#: builtin/show-ref.c:163
+msgid "only show heads (can be combined with tags)"
+msgstr ""
+
+#: builtin/show-ref.c:164
+msgid "stricter reference checking, requires exact ref path"
+msgstr ""
+
+#: builtin/show-ref.c:167 builtin/show-ref.c:169
+msgid "show the HEAD reference, even if it would be filtered out"
+msgstr ""
+
+#: builtin/show-ref.c:171
+msgid "dereference tags into object IDs"
+msgstr ""
+
+#: builtin/show-ref.c:173
+msgid "only show SHA1 hash using <n> digits"
+msgstr ""
+
+#: builtin/show-ref.c:177
+msgid "do not print results to stdout (useful with --verify)"
+msgstr ""
+
+#: builtin/show-ref.c:179
+msgid "show refs from stdin that aren't in local repository"
+msgstr ""
+
+#: builtin/sparse-checkout.c:20
+msgid "git sparse-checkout (init|list|set|disable) <options>"
+msgstr ""
+
+#: builtin/sparse-checkout.c:61
+msgid "this worktree is not sparse (sparse-checkout file may not exist)"
+msgstr ""
+
+#: builtin/sparse-checkout.c:220
+msgid "failed to set extensions.worktreeConfig setting"
+msgstr ""
+
+#: builtin/sparse-checkout.c:237
+msgid "git sparse-checkout init [--cone]"
+msgstr ""
+
+#: builtin/sparse-checkout.c:256
+msgid "initialize the sparse-checkout in cone mode"
+msgstr ""
+
+#: builtin/sparse-checkout.c:262
+msgid "initialize sparse-checkout"
+msgstr ""
+
+#: builtin/sparse-checkout.c:295
+#, c-format
+msgid "failed to open '%s'"
+msgstr ""
+
+#: builtin/sparse-checkout.c:361
+msgid "git sparse-checkout set (--stdin | <patterns>)"
+msgstr ""
+
+#: builtin/sparse-checkout.c:378
+msgid "read patterns from standard in"
+msgstr ""
+
+#: builtin/sparse-checkout.c:384
+msgid "set sparse-checkout patterns"
+msgstr ""
+
+#: builtin/sparse-checkout.c:447
+msgid "disable sparse-checkout"
+msgstr ""
+
+#: builtin/sparse-checkout.c:459
+msgid "error while refreshing working directory"
+msgstr ""
+
+#: builtin/stash.c:22 builtin/stash.c:37
+msgid "git stash list [<options>]"
+msgstr ""
+
+#: builtin/stash.c:23 builtin/stash.c:42
+msgid "git stash show [<options>] [<stash>]"
+msgstr ""
+
+#: builtin/stash.c:24 builtin/stash.c:47
+msgid "git stash drop [-q|--quiet] [<stash>]"
+msgstr ""
+
+#: builtin/stash.c:25
+msgid "git stash ( pop | apply ) [--index] [-q|--quiet] [<stash>]"
+msgstr ""
+
+#: builtin/stash.c:26 builtin/stash.c:62
+msgid "git stash branch <branchname> [<stash>]"
+msgstr ""
+
+#: builtin/stash.c:27 builtin/stash.c:67
+msgid "git stash clear"
+msgstr ""
+
+#: builtin/stash.c:28 builtin/stash.c:77
+msgid ""
+"git stash [push [-p|--patch] [-k|--[no-]keep-index] [-q|--quiet]\n"
+"          [-u|--include-untracked] [-a|--all] [-m|--message <message>]\n"
+"          [--] [<pathspec>...]]"
+msgstr ""
+
+#: builtin/stash.c:31 builtin/stash.c:84
+msgid ""
+"git stash save [-p|--patch] [-k|--[no-]keep-index] [-q|--quiet]\n"
+"          [-u|--include-untracked] [-a|--all] [<message>]"
+msgstr ""
+
+#: builtin/stash.c:52
+msgid "git stash pop [--index] [-q|--quiet] [<stash>]"
+msgstr ""
+
+#: builtin/stash.c:57
+msgid "git stash apply [--index] [-q|--quiet] [<stash>]"
+msgstr ""
+
+#: builtin/stash.c:72
+msgid "git stash store [-m|--message <message>] [-q|--quiet] <commit>"
+msgstr ""
+
+#: builtin/stash.c:127
+#, c-format
+msgid "'%s' is not a stash-like commit"
+msgstr ""
+
+#: builtin/stash.c:147
+#, c-format
+msgid "Too many revisions specified:%s"
+msgstr ""
+
+#: builtin/stash.c:161 git-legacy-stash.sh:549
+msgid "No stash entries found."
+msgstr ""
+
+#: builtin/stash.c:175
+#, c-format
+msgid "%s is not a valid reference"
+msgstr ""
+
+#: builtin/stash.c:224 git-legacy-stash.sh:75
+msgid "git stash clear with parameters is unimplemented"
+msgstr ""
+
+#: builtin/stash.c:403
+msgid "cannot apply a stash in the middle of a merge"
+msgstr ""
+
+#: builtin/stash.c:414
+#, c-format
+msgid "could not generate diff %s^!."
+msgstr ""
+
+#: builtin/stash.c:421
+msgid "conflicts in index.Try without --index."
+msgstr ""
+
+#: builtin/stash.c:427
+msgid "could not save index tree"
+msgstr ""
+
+#: builtin/stash.c:436
+msgid "could not restore untracked files from stash"
+msgstr ""
+
+#: builtin/stash.c:450
+#, c-format
+msgid "Merging %s with %s"
+msgstr ""
+
+#: builtin/stash.c:460 git-legacy-stash.sh:681
+msgid "Index was not unstashed."
+msgstr ""
+
+#: builtin/stash.c:521 builtin/stash.c:620
+msgid "attempt to recreate the index"
+msgstr ""
+
+#: builtin/stash.c:554
+#, c-format
+msgid "Dropped %s (%s)"
+msgstr ""
+
+#: builtin/stash.c:557
+#, c-format
+msgid "%s: Could not drop stash entry"
+msgstr ""
+
+#: builtin/stash.c:582
+#, c-format
+msgid "'%s' is not a stash reference"
+msgstr ""
+
+#: builtin/stash.c:632 git-legacy-stash.sh:695
+msgid "The stash entry is kept in case you need it again."
+msgstr ""
+
+#: builtin/stash.c:655 git-legacy-stash.sh:713
+msgid "No branch name specified"
+msgstr ""
+
+#: builtin/stash.c:795 builtin/stash.c:832
+#, c-format
+msgid "Cannot update %s with %s"
+msgstr ""
+
+#: builtin/stash.c:813 builtin/stash.c:1470 builtin/stash.c:1506
+msgid "stash message"
+msgstr ""
+
+#: builtin/stash.c:823
+msgid "\"git stash store\" requires one <commit> argument"
+msgstr ""
+
+#: builtin/stash.c:1045 git-legacy-stash.sh:218
+msgid "No changes selected"
+msgstr ""
+
+#: builtin/stash.c:1145 git-legacy-stash.sh:150
+msgid "You do not have the initial commit yet"
+msgstr ""
+
+#: builtin/stash.c:1172 git-legacy-stash.sh:165
+msgid "Cannot save the current index state"
+msgstr ""
+
+#: builtin/stash.c:1181 git-legacy-stash.sh:180
+msgid "Cannot save the untracked files"
+msgstr ""
+
+#: builtin/stash.c:1192 builtin/stash.c:1201 git-legacy-stash.sh:201
+#: git-legacy-stash.sh:214
+msgid "Cannot save the current worktree state"
+msgstr ""
+
+#: builtin/stash.c:1229 git-legacy-stash.sh:234
+msgid "Cannot record working tree state"
+msgstr ""
+
+#: builtin/stash.c:1278 git-legacy-stash.sh:338
+msgid "Can't use --patch and --include-untracked or --all at the same time"
+msgstr ""
+
+#: builtin/stash.c:1294
+msgid "Did you forget to 'git add'?"
+msgstr ""
+
+#: builtin/stash.c:1309 git-legacy-stash.sh:346
+msgid "No local changes to save"
+msgstr ""
+
+#: builtin/stash.c:1316 git-legacy-stash.sh:351
+msgid "Cannot initialize stash"
+msgstr ""
+
+#: builtin/stash.c:1331 git-legacy-stash.sh:355
+msgid "Cannot save the current status"
+msgstr ""
+
+#: builtin/stash.c:1336
+#, c-format
+msgid "Saved working directory and index state %s"
+msgstr ""
+
+#: builtin/stash.c:1426 git-legacy-stash.sh:385
+msgid "Cannot remove worktree changes"
+msgstr ""
+
+#: builtin/stash.c:1461 builtin/stash.c:1497
+msgid "keep index"
+msgstr ""
+
+#: builtin/stash.c:1463 builtin/stash.c:1499
+msgid "stash in patch mode"
+msgstr ""
+
+#: builtin/stash.c:1464 builtin/stash.c:1500
+msgid "quiet mode"
+msgstr ""
+
+#: builtin/stash.c:1466 builtin/stash.c:1502
+msgid "include untracked files in stash"
+msgstr ""
+
+#: builtin/stash.c:1468 builtin/stash.c:1504
+msgid "include ignore files"
+msgstr ""
+
+#: builtin/stash.c:1564
+#, c-format
+msgid "could not exec %s"
+msgstr ""
+
+#: builtin/stripspace.c:18
+msgid "git stripspace [-s | --strip-comments]"
+msgstr ""
+
+#: builtin/stripspace.c:19
+msgid "git stripspace [-c | --comment-lines]"
+msgstr ""
+
+#: builtin/stripspace.c:37
+msgid "skip and remove all lines starting with comment character"
+msgstr ""
+
+#: builtin/stripspace.c:40
+msgid "prepend comment character and space to each line"
+msgstr ""
+
+#: builtin/submodule--helper.c:47 builtin/submodule--helper.c:1970
+#, c-format
+msgid "Expecting a full ref name, got %s"
+msgstr ""
+
+#: builtin/submodule--helper.c:64
+msgid "submodule--helper print-default-remote takes no arguments"
+msgstr ""
+
+#: builtin/submodule--helper.c:102
+#, c-format
+msgid "cannot strip one component off url '%s'"
+msgstr ""
+
+#: builtin/submodule--helper.c:410 builtin/submodule--helper.c:1380
+msgid "alternative anchor for relative paths"
+msgstr ""
+
+#: builtin/submodule--helper.c:415
+msgid "git submodule--helper list [--prefix=<path>] [<path>...]"
+msgstr ""
+
+#: builtin/submodule--helper.c:472 builtin/submodule--helper.c:630
+#: builtin/submodule--helper.c:653
+#, c-format
+msgid "No url found for submodule path '%s' in .gitmodules"
+msgstr ""
+
+#: builtin/submodule--helper.c:524
+#, c-format
+msgid "Entering '%s'\n"
+msgstr ""
+
+#: builtin/submodule--helper.c:527
+#, c-format
+msgid ""
+"run_command returned non-zero status for %s\n"
+"."
+msgstr ""
+
+#: builtin/submodule--helper.c:549
+#, c-format
+msgid ""
+"run_command returned non-zero status while recursing in the nested "
+"submodules of %s\n"
+"."
+msgstr ""
+
+#: builtin/submodule--helper.c:565
+msgid "Suppress output of entering each submodule command"
+msgstr ""
+
+#: builtin/submodule--helper.c:567 builtin/submodule--helper.c:1053
+msgid "Recurse into nested submodules"
+msgstr ""
+
+#: builtin/submodule--helper.c:572
+msgid "git submodule--helper foreach [--quiet] [--recursive] [--] <command>"
+msgstr ""
+
+#: builtin/submodule--helper.c:599
+#, c-format
+msgid ""
+"could not look up configuration '%s'. Assuming this repository is its own "
+"authoritative upstream."
+msgstr ""
+
+#: builtin/submodule--helper.c:667
+#, c-format
+msgid "Failed to register url for submodule path '%s'"
+msgstr ""
+
+#: builtin/submodule--helper.c:671
+#, c-format
+msgid "Submodule '%s' (%s) registered for path '%s'\n"
+msgstr ""
+
+#: builtin/submodule--helper.c:681
+#, c-format
+msgid "warning: command update mode suggested for submodule '%s'\n"
+msgstr ""
+
+#: builtin/submodule--helper.c:688
+#, c-format
+msgid "Failed to register update mode for submodule path '%s'"
+msgstr ""
+
+#: builtin/submodule--helper.c:710
+msgid "Suppress output for initializing a submodule"
+msgstr ""
+
+#: builtin/submodule--helper.c:715
+msgid "git submodule--helper init [<options>] [<path>]"
+msgstr ""
+
+#: builtin/submodule--helper.c:787 builtin/submodule--helper.c:914
+#, c-format
+msgid "no submodule mapping found in .gitmodules for path '%s'"
+msgstr ""
+
+#: builtin/submodule--helper.c:827
+#, c-format
+msgid "could not resolve HEAD ref inside the submodule '%s'"
+msgstr ""
+
+#: builtin/submodule--helper.c:854 builtin/submodule--helper.c:1023
+#, c-format
+msgid "failed to recurse into submodule '%s'"
+msgstr ""
+
+#: builtin/submodule--helper.c:878 builtin/submodule--helper.c:1189
+msgid "Suppress submodule status output"
+msgstr ""
+
+#: builtin/submodule--helper.c:879
+msgid ""
+"Use commit stored in the index instead of the one stored in the submodule "
+"HEAD"
+msgstr ""
+
+#: builtin/submodule--helper.c:880
+msgid "recurse into nested submodules"
+msgstr ""
+
+#: builtin/submodule--helper.c:885
+msgid "git submodule status [--quiet] [--cached] [--recursive] [<path>...]"
+msgstr ""
+
+#: builtin/submodule--helper.c:909
+msgid "git submodule--helper name <path>"
+msgstr ""
+
+#: builtin/submodule--helper.c:973
+#, c-format
+msgid "Synchronizing submodule url for '%s'\n"
+msgstr ""
+
+#: builtin/submodule--helper.c:979
+#, c-format
+msgid "failed to register url for submodule path '%s'"
+msgstr ""
+
+#: builtin/submodule--helper.c:993
+#, c-format
+msgid "failed to get the default remote for submodule '%s'"
+msgstr ""
+
+#: builtin/submodule--helper.c:1004
+#, c-format
+msgid "failed to update remote for submodule '%s'"
+msgstr ""
+
+#: builtin/submodule--helper.c:1051
+msgid "Suppress output of synchronizing submodule url"
+msgstr ""
+
+#: builtin/submodule--helper.c:1058
+msgid "git submodule--helper sync [--quiet] [--recursive] [<path>]"
+msgstr ""
+
+#: builtin/submodule--helper.c:1112
+#, c-format
+msgid ""
+"Submodule work tree '%s' contains a .git directory (use 'rm -rf' if you "
+"really want to remove it including all of its history)"
+msgstr ""
+
+#: builtin/submodule--helper.c:1124
+#, c-format
+msgid ""
+"Submodule work tree '%s' contains local modifications; use '-f' to discard "
+"them"
+msgstr ""
+
+#: builtin/submodule--helper.c:1132
+#, c-format
+msgid "Cleared directory '%s'\n"
+msgstr ""
+
+#: builtin/submodule--helper.c:1134
+#, c-format
+msgid "Could not remove submodule work tree '%s'\n"
+msgstr ""
+
+#: builtin/submodule--helper.c:1145
+#, c-format
+msgid "could not create empty submodule directory %s"
+msgstr ""
+
+#: builtin/submodule--helper.c:1161
+#, c-format
+msgid "Submodule '%s' (%s) unregistered for path '%s'\n"
+msgstr ""
+
+#: builtin/submodule--helper.c:1190
+msgid "Remove submodule working trees even if they contain local changes"
+msgstr ""
+
+#: builtin/submodule--helper.c:1191
+msgid "Unregister all submodules"
+msgstr ""
+
+#: builtin/submodule--helper.c:1196
+msgid ""
+"git submodule deinit [--quiet] [-f | --force] [--all | [--] [<path>...]]"
+msgstr ""
+
+#: builtin/submodule--helper.c:1210
+msgid "Use '--all' if you really want to deinitialize all submodules"
+msgstr ""
+
+#: builtin/submodule--helper.c:1275
+msgid ""
+"An alternate computed from a superproject's alternate is invalid.\n"
+"To allow Git to clone without an alternate in such a case, set\n"
+"submodule.alternateErrorStrategy to 'info' or, equivalently, clone with\n"
+"'--reference-if-able' instead of '--reference'."
+msgstr ""
+
+#: builtin/submodule--helper.c:1314 builtin/submodule--helper.c:1317
+#, c-format
+msgid "submodule '%s' cannot add alternate: %s"
+msgstr ""
+
+#: builtin/submodule--helper.c:1353
+#, c-format
+msgid "Value '%s' for submodule.alternateErrorStrategy is not recognized"
+msgstr ""
+
+#: builtin/submodule--helper.c:1360
+#, c-format
+msgid "Value '%s' for submodule.alternateLocation is not recognized"
+msgstr ""
+
+#: builtin/submodule--helper.c:1383
+msgid "where the new submodule will be cloned to"
+msgstr ""
+
+#: builtin/submodule--helper.c:1386
+msgid "name of the new submodule"
+msgstr ""
+
+#: builtin/submodule--helper.c:1389
+msgid "url where to clone the submodule from"
+msgstr ""
+
+#: builtin/submodule--helper.c:1397
+msgid "depth for shallow clones"
+msgstr ""
+
+#: builtin/submodule--helper.c:1400 builtin/submodule--helper.c:1897
+msgid "force cloning progress"
+msgstr ""
+
+#: builtin/submodule--helper.c:1402 builtin/submodule--helper.c:1899
+msgid "disallow cloning into non-empty directory"
+msgstr ""
+
+#: builtin/submodule--helper.c:1407
+msgid ""
+"git submodule--helper clone [--prefix=<path>] [--quiet] [--reference "
+"<repository>] [--name <name>] [--depth <depth>] --url <url> --path <path>"
+msgstr ""
+
+#: builtin/submodule--helper.c:1431
+#, c-format
+msgid "refusing to create/use '%s' in another submodule's git dir"
+msgstr ""
+
+#: builtin/submodule--helper.c:1442
+#, c-format
+msgid "clone of '%s' into submodule path '%s' failed"
+msgstr ""
+
+#: builtin/submodule--helper.c:1446
+#, c-format
+msgid "directory not empty: '%s'"
+msgstr ""
+
+#: builtin/submodule--helper.c:1458
+#, c-format
+msgid "could not get submodule directory for '%s'"
+msgstr ""
+
+#: builtin/submodule--helper.c:1494
+#, c-format
+msgid "Invalid update mode '%s' for submodule path '%s'"
+msgstr ""
+
+#: builtin/submodule--helper.c:1498
+#, c-format
+msgid "Invalid update mode '%s' configured for submodule path '%s'"
+msgstr ""
+
+#: builtin/submodule--helper.c:1594
+#, c-format
+msgid "Submodule path '%s' not initialized"
+msgstr ""
+
+#: builtin/submodule--helper.c:1598
+msgid "Maybe you want to use 'update --init'?"
+msgstr ""
+
+#: builtin/submodule--helper.c:1628
+#, c-format
+msgid "Skipping unmerged submodule %s"
+msgstr ""
+
+#: builtin/submodule--helper.c:1657
+#, c-format
+msgid "Skipping submodule '%s'"
+msgstr ""
+
+#: builtin/submodule--helper.c:1803
+#, c-format
+msgid "Failed to clone '%s'. Retry scheduled"
+msgstr ""
+
+#: builtin/submodule--helper.c:1814
+#, c-format
+msgid "Failed to clone '%s' a second time, aborting"
+msgstr ""
+
+#: builtin/submodule--helper.c:1876 builtin/submodule--helper.c:2120
+msgid "path into the working tree"
+msgstr ""
+
+#: builtin/submodule--helper.c:1879
+msgid "path into the working tree, across nested submodule boundaries"
+msgstr ""
+
+#: builtin/submodule--helper.c:1883
+msgid "rebase, merge, checkout or none"
+msgstr ""
+
+#: builtin/submodule--helper.c:1889
+msgid "Create a shallow clone truncated to the specified number of revisions"
+msgstr ""
+
+#: builtin/submodule--helper.c:1892
+msgid "parallel jobs"
+msgstr ""
+
+#: builtin/submodule--helper.c:1894
+msgid "whether the initial clone should follow the shallow recommendation"
+msgstr ""
+
+#: builtin/submodule--helper.c:1895
+msgid "don't print cloning progress"
+msgstr ""
+
+#: builtin/submodule--helper.c:1904
+msgid "git submodule--helper update-clone [--prefix=<path>] [<path>...]"
+msgstr ""
+
+#: builtin/submodule--helper.c:1917
+msgid "bad value for update parameter"
+msgstr ""
+
+#: builtin/submodule--helper.c:1965
+#, c-format
+msgid ""
+"Submodule (%s) branch configured to inherit branch from superproject, but "
+"the superproject is not on any branch"
+msgstr ""
+
+#: builtin/submodule--helper.c:2088
+#, c-format
+msgid "could not get a repository handle for submodule '%s'"
+msgstr ""
+
+#: builtin/submodule--helper.c:2121
+msgid "recurse into submodules"
+msgstr ""
+
+#: builtin/submodule--helper.c:2127
+msgid "git submodule--helper absorb-git-dirs [<options>] [<path>...]"
+msgstr ""
+
+#: builtin/submodule--helper.c:2183
+msgid "check if it is safe to write to the .gitmodules file"
+msgstr ""
+
+#: builtin/submodule--helper.c:2186
+msgid "unset the config in the .gitmodules file"
+msgstr ""
+
+#: builtin/submodule--helper.c:2191
+msgid "git submodule--helper config <name> [<value>]"
+msgstr ""
+
+#: builtin/submodule--helper.c:2192
+msgid "git submodule--helper config --unset <name>"
+msgstr ""
+
+#: builtin/submodule--helper.c:2193
+msgid "git submodule--helper config --check-writeable"
+msgstr ""
+
+#: builtin/submodule--helper.c:2212 git-submodule.sh:173
+#, sh-format
+msgid "please make sure that the .gitmodules file is in the working tree"
+msgstr ""
+
+#: builtin/submodule--helper.c:2262 git.c:433 git.c:684
+#, c-format
+msgid "%s doesn't support --super-prefix"
+msgstr ""
+
+#: builtin/submodule--helper.c:2268
+#, c-format
+msgid "'%s' is not a valid submodule--helper subcommand"
+msgstr ""
+
+#: builtin/symbolic-ref.c:8
+msgid "git symbolic-ref [<options>] <name> [<ref>]"
+msgstr ""
+
+#: builtin/symbolic-ref.c:9
+msgid "git symbolic-ref -d [-q] <name>"
+msgstr ""
+
+#: builtin/symbolic-ref.c:40
+msgid "suppress error message for non-symbolic (detached) refs"
+msgstr ""
+
+#: builtin/symbolic-ref.c:41
+msgid "delete symbolic ref"
+msgstr ""
+
+#: builtin/symbolic-ref.c:42
+msgid "shorten ref output"
+msgstr ""
+
+#: builtin/symbolic-ref.c:43 builtin/update-ref.c:363
+msgid "reason"
+msgstr ""
+
+#: builtin/symbolic-ref.c:43 builtin/update-ref.c:363
+msgid "reason of the update"
+msgstr ""
+
+#: builtin/tag.c:25
+msgid ""
+"git tag [-a | -s | -u <key-id>] [-f] [-m <msg> | -F <file>]\n"
+"\t\t<tagname> [<head>]"
+msgstr ""
+
+#: builtin/tag.c:27
+msgid "git tag -d <tagname>..."
+msgstr ""
+
+#: builtin/tag.c:28
+msgid ""
+"git tag -l [-n[<num>]] [--contains <commit>] [--no-contains <commit>] [--"
+"points-at <object>]\n"
+"\t\t[--format=<format>] [--[no-]merged [<commit>]] [<pattern>...]"
+msgstr ""
+
+#: builtin/tag.c:30
+msgid "git tag -v [--format=<format>] <tagname>..."
+msgstr ""
+
+#: builtin/tag.c:89
+#, c-format
+msgid "tag '%s' not found."
+msgstr ""
+
+#: builtin/tag.c:105
+#, c-format
+msgid "Deleted tag '%s' (was %s)\n"
+msgstr ""
+
+#: builtin/tag.c:135
+#, c-format
+msgid ""
+"\n"
+"Write a message for tag:\n"
+"  %s\n"
+"Lines starting with '%c' will be ignored.\n"
+msgstr ""
+
+#: builtin/tag.c:139
+#, c-format
+msgid ""
+"\n"
+"Write a message for tag:\n"
+"  %s\n"
+"Lines starting with '%c' will be kept; you may remove them yourself if you "
+"want to.\n"
+msgstr ""
+
+#: builtin/tag.c:198
+msgid "unable to sign the tag"
+msgstr ""
+
+#: builtin/tag.c:200
+msgid "unable to write tag file"
+msgstr ""
+
+#: builtin/tag.c:216
+#, c-format
+msgid ""
+"You have created a nested tag. The object referred to by your new tag is\n"
+"already a tag. If you meant to tag the object that it points to, use:\n"
+"\n"
+"\tgit tag -f %s %s^{}"
+msgstr ""
+
+#: builtin/tag.c:232
+msgid "bad object type."
+msgstr ""
+
+#: builtin/tag.c:284
+msgid "no tag message?"
+msgstr ""
+
+#: builtin/tag.c:291
+#, c-format
+msgid "The tag message has been left in %s\n"
+msgstr ""
+
+#: builtin/tag.c:402
+msgid "list tag names"
+msgstr ""
+
+#: builtin/tag.c:404
+msgid "print <n> lines of each tag message"
+msgstr ""
+
+#: builtin/tag.c:406
+msgid "delete tags"
+msgstr ""
+
+#: builtin/tag.c:407
+msgid "verify tags"
+msgstr ""
+
+#: builtin/tag.c:409
+msgid "Tag creation options"
+msgstr ""
+
+#: builtin/tag.c:411
+msgid "annotated tag, needs a message"
+msgstr ""
+
+#: builtin/tag.c:413
+msgid "tag message"
+msgstr ""
+
+#: builtin/tag.c:415
+msgid "force edit of tag message"
+msgstr ""
+
+#: builtin/tag.c:416
+msgid "annotated and GPG-signed tag"
+msgstr ""
+
+#: builtin/tag.c:419
+msgid "use another key to sign the tag"
+msgstr ""
+
+#: builtin/tag.c:420
+msgid "replace the tag if exists"
+msgstr ""
+
+#: builtin/tag.c:421 builtin/update-ref.c:369
+msgid "create a reflog"
+msgstr ""
+
+#: builtin/tag.c:423
+msgid "Tag listing options"
+msgstr ""
+
+#: builtin/tag.c:424
+msgid "show tag list in columns"
+msgstr ""
+
+#: builtin/tag.c:425 builtin/tag.c:427
+msgid "print only tags that contain the commit"
+msgstr ""
+
+#: builtin/tag.c:426 builtin/tag.c:428
+msgid "print only tags that don't contain the commit"
+msgstr ""
+
+#: builtin/tag.c:429
+msgid "print only tags that are merged"
+msgstr ""
+
+#: builtin/tag.c:430
+msgid "print only tags that are not merged"
+msgstr ""
+
+#: builtin/tag.c:434
+msgid "print only tags of the object"
+msgstr ""
+
+#: builtin/tag.c:482
+msgid "--column and -n are incompatible"
+msgstr ""
+
+#: builtin/tag.c:504
+msgid "-n option is only allowed in list mode"
+msgstr ""
+
+#: builtin/tag.c:506
+msgid "--contains option is only allowed in list mode"
+msgstr ""
+
+#: builtin/tag.c:508
+msgid "--no-contains option is only allowed in list mode"
+msgstr ""
+
+#: builtin/tag.c:510
+msgid "--points-at option is only allowed in list mode"
+msgstr ""
+
+#: builtin/tag.c:512
+msgid "--merged and --no-merged options are only allowed in list mode"
+msgstr ""
+
+#: builtin/tag.c:523
+msgid "only one -F or -m option is allowed."
+msgstr ""
+
+#: builtin/tag.c:542
+msgid "too many params"
+msgstr ""
+
+#: builtin/tag.c:548
+#, c-format
+msgid "'%s' is not a valid tag name."
+msgstr ""
+
+#: builtin/tag.c:553
+#, c-format
+msgid "tag '%s' already exists"
+msgstr ""
+
+#: builtin/tag.c:584
+#, c-format
+msgid "Updated tag '%s' (was %s)\n"
+msgstr ""
+
+#: builtin/unpack-objects.c:501
+msgid "Unpacking objects"
+msgstr ""
+
+#: builtin/update-index.c:84
+#, c-format
+msgid "failed to create directory %s"
+msgstr ""
+
+#: builtin/update-index.c:100
+#, c-format
+msgid "failed to create file %s"
+msgstr ""
+
+#: builtin/update-index.c:108
+#, c-format
+msgid "failed to delete file %s"
+msgstr ""
+
+#: builtin/update-index.c:115 builtin/update-index.c:221
+#, c-format
+msgid "failed to delete directory %s"
+msgstr ""
+
+#: builtin/update-index.c:140
+#, c-format
+msgid "Testing mtime in '%s' "
+msgstr ""
+
+#: builtin/update-index.c:154
+msgid "directory stat info does not change after adding a new file"
+msgstr ""
+
+#: builtin/update-index.c:167
+msgid "directory stat info does not change after adding a new directory"
+msgstr ""
+
+#: builtin/update-index.c:180
+msgid "directory stat info changes after updating a file"
+msgstr ""
+
+#: builtin/update-index.c:191
+msgid "directory stat info changes after adding a file inside subdirectory"
+msgstr ""
+
+#: builtin/update-index.c:202
+msgid "directory stat info does not change after deleting a file"
+msgstr ""
+
+#: builtin/update-index.c:215
+msgid "directory stat info does not change after deleting a directory"
+msgstr ""
+
+#: builtin/update-index.c:222
+msgid " OK"
+msgstr ""
+
+#: builtin/update-index.c:591
+msgid "git update-index [<options>] [--] [<file>...]"
+msgstr ""
+
+#: builtin/update-index.c:974
+msgid "continue refresh even when index needs update"
+msgstr ""
+
+#: builtin/update-index.c:977
+msgid "refresh: ignore submodules"
+msgstr ""
+
+#: builtin/update-index.c:980
+msgid "do not ignore new files"
+msgstr ""
+
+#: builtin/update-index.c:982
+msgid "let files replace directories and vice-versa"
+msgstr ""
+
+#: builtin/update-index.c:984
+msgid "notice files missing from worktree"
+msgstr ""
+
+#: builtin/update-index.c:986
+msgid "refresh even if index contains unmerged entries"
+msgstr ""
+
+#: builtin/update-index.c:989
+msgid "refresh stat information"
+msgstr ""
+
+#: builtin/update-index.c:993
+msgid "like --refresh, but ignore assume-unchanged setting"
+msgstr ""
+
+#: builtin/update-index.c:997
+msgid "<mode>,<object>,<path>"
+msgstr ""
+
+#: builtin/update-index.c:998
+msgid "add the specified entry to the index"
+msgstr ""
+
+#: builtin/update-index.c:1008
+msgid "mark files as \"not changing\""
+msgstr ""
+
+#: builtin/update-index.c:1011
+msgid "clear assumed-unchanged bit"
+msgstr ""
+
+#: builtin/update-index.c:1014
+msgid "mark files as \"index-only\""
+msgstr ""
+
+#: builtin/update-index.c:1017
+msgid "clear skip-worktree bit"
+msgstr ""
+
+#: builtin/update-index.c:1020
+msgid "do not touch index-only entries"
+msgstr ""
+
+#: builtin/update-index.c:1022
+msgid "add to index only; do not add content to object database"
+msgstr ""
+
+#: builtin/update-index.c:1024
+msgid "remove named paths even if present in worktree"
+msgstr ""
+
+#: builtin/update-index.c:1026
+msgid "with --stdin: input lines are terminated by null bytes"
+msgstr ""
+
+#: builtin/update-index.c:1028
+msgid "read list of paths to be updated from standard input"
+msgstr ""
+
+#: builtin/update-index.c:1032
+msgid "add entries from standard input to the index"
+msgstr ""
+
+#: builtin/update-index.c:1036
+msgid "repopulate stages #2 and #3 for the listed paths"
+msgstr ""
+
+#: builtin/update-index.c:1040
+msgid "only update entries that differ from HEAD"
+msgstr ""
+
+#: builtin/update-index.c:1044
+msgid "ignore files missing from worktree"
+msgstr ""
+
+#: builtin/update-index.c:1047
+msgid "report actions to standard output"
+msgstr ""
+
+#: builtin/update-index.c:1049
+msgid "(for porcelains) forget saved unresolved conflicts"
+msgstr ""
+
+#: builtin/update-index.c:1053
+msgid "write index in this format"
+msgstr ""
+
+#: builtin/update-index.c:1055
+msgid "enable or disable split index"
+msgstr ""
+
+#: builtin/update-index.c:1057
+msgid "enable/disable untracked cache"
+msgstr ""
+
+#: builtin/update-index.c:1059
+msgid "test if the filesystem supports untracked cache"
+msgstr ""
+
+#: builtin/update-index.c:1061
+msgid "enable untracked cache without testing the filesystem"
+msgstr ""
+
+#: builtin/update-index.c:1063
+msgid "write out the index even if is not flagged as changed"
+msgstr ""
+
+#: builtin/update-index.c:1065
+msgid "enable or disable file system monitor"
+msgstr ""
+
+#: builtin/update-index.c:1067
+msgid "mark files as fsmonitor valid"
+msgstr ""
+
+#: builtin/update-index.c:1070
+msgid "clear fsmonitor valid bit"
+msgstr ""
+
+#: builtin/update-index.c:1173
+msgid ""
+"core.splitIndex is set to false; remove or change it, if you really want to "
+"enable split index"
+msgstr ""
+
+#: builtin/update-index.c:1182
+msgid ""
+"core.splitIndex is set to true; remove or change it, if you really want to "
+"disable split index"
+msgstr ""
+
+#: builtin/update-index.c:1194
+msgid ""
+"core.untrackedCache is set to true; remove or change it, if you really want "
+"to disable the untracked cache"
+msgstr ""
+
+#: builtin/update-index.c:1198
+msgid "Untracked cache disabled"
+msgstr ""
+
+#: builtin/update-index.c:1206
+msgid ""
+"core.untrackedCache is set to false; remove or change it, if you really want "
+"to enable the untracked cache"
+msgstr ""
+
+#: builtin/update-index.c:1210
+#, c-format
+msgid "Untracked cache enabled for '%s'"
+msgstr ""
+
+#: builtin/update-index.c:1218
+msgid "core.fsmonitor is unset; set it if you really want to enable fsmonitor"
+msgstr ""
+
+#: builtin/update-index.c:1222
+msgid "fsmonitor enabled"
+msgstr ""
+
+#: builtin/update-index.c:1225
+msgid ""
+"core.fsmonitor is set; remove it if you really want to disable fsmonitor"
+msgstr ""
+
+#: builtin/update-index.c:1229
+msgid "fsmonitor disabled"
+msgstr ""
+
+#: builtin/update-ref.c:10
+msgid "git update-ref [<options>] -d <refname> [<old-val>]"
+msgstr ""
+
+#: builtin/update-ref.c:11
+msgid "git update-ref [<options>]    <refname> <new-val> [<old-val>]"
+msgstr ""
+
+#: builtin/update-ref.c:12
+msgid "git update-ref [<options>] --stdin [-z]"
+msgstr ""
+
+#: builtin/update-ref.c:364
+msgid "delete the reference"
+msgstr ""
+
+#: builtin/update-ref.c:366
+msgid "update <refname> not the one it points to"
+msgstr ""
+
+#: builtin/update-ref.c:367
+msgid "stdin has NUL-terminated arguments"
+msgstr ""
+
+#: builtin/update-ref.c:368
+msgid "read updates from stdin"
+msgstr ""
+
+#: builtin/update-server-info.c:7
+msgid "git update-server-info [--force]"
+msgstr ""
+
+#: builtin/update-server-info.c:15
+msgid "update the info files from scratch"
+msgstr ""
+
+#: builtin/upload-pack.c:11
+msgid "git upload-pack [<options>] <dir>"
+msgstr ""
+
+#: builtin/upload-pack.c:23 t/helper/test-serve-v2.c:17
+msgid "quit after a single request/response exchange"
+msgstr ""
+
+#: builtin/upload-pack.c:25
+msgid "exit immediately after initial ref advertisement"
+msgstr ""
+
+#: builtin/upload-pack.c:27
+msgid "do not try <directory>/.git/ if <directory> is no Git directory"
+msgstr ""
+
+#: builtin/upload-pack.c:29
+msgid "interrupt transfer after <n> seconds of inactivity"
+msgstr ""
+
+#: builtin/verify-commit.c:19
+msgid "git verify-commit [-v | --verbose] <commit>..."
+msgstr ""
+
+#: builtin/verify-commit.c:68
+msgid "print commit contents"
+msgstr ""
+
+#: builtin/verify-commit.c:69 builtin/verify-tag.c:37
+msgid "print raw gpg status output"
+msgstr ""
+
+#: builtin/verify-pack.c:55
+msgid "git verify-pack [-v | --verbose] [-s | --stat-only] <pack>..."
+msgstr ""
+
+#: builtin/verify-pack.c:65
+msgid "verbose"
+msgstr ""
+
+#: builtin/verify-pack.c:67
+msgid "show statistics only"
+msgstr ""
+
+#: builtin/verify-tag.c:18
+msgid "git verify-tag [-v | --verbose] [--format=<format>] <tag>..."
+msgstr ""
+
+#: builtin/verify-tag.c:36
+msgid "print tag contents"
+msgstr ""
+
+#: builtin/worktree.c:17
+msgid "git worktree add [<options>] <path> [<commit-ish>]"
+msgstr ""
+
+#: builtin/worktree.c:18
+msgid "git worktree list [<options>]"
+msgstr ""
+
+#: builtin/worktree.c:19
+msgid "git worktree lock [<options>] <path>"
+msgstr ""
+
+#: builtin/worktree.c:20
+msgid "git worktree move <worktree> <new-path>"
+msgstr ""
+
+#: builtin/worktree.c:21
+msgid "git worktree prune [<options>]"
+msgstr ""
+
+#: builtin/worktree.c:22
+msgid "git worktree remove [<options>] <worktree>"
+msgstr ""
+
+#: builtin/worktree.c:23
+msgid "git worktree unlock <path>"
+msgstr ""
+
+#: builtin/worktree.c:60 builtin/worktree.c:898
+#, c-format
+msgid "failed to delete '%s'"
+msgstr ""
+
+#: builtin/worktree.c:79
+#, c-format
+msgid "Removing worktrees/%s: not a valid directory"
+msgstr ""
+
+#: builtin/worktree.c:85
+#, c-format
+msgid "Removing worktrees/%s: gitdir file does not exist"
+msgstr ""
+
+#: builtin/worktree.c:90 builtin/worktree.c:99
+#, c-format
+msgid "Removing worktrees/%s: unable to read gitdir file (%s)"
+msgstr ""
+
+#: builtin/worktree.c:109
+#, c-format
+msgid ""
+"Removing worktrees/%s: short read (expected %<PRIuMAX> bytes, read "
+"%<PRIuMAX>)"
+msgstr ""
+
+#: builtin/worktree.c:117
+#, c-format
+msgid "Removing worktrees/%s: invalid gitdir file"
+msgstr ""
+
+#: builtin/worktree.c:126
+#, c-format
+msgid "Removing worktrees/%s: gitdir file points to non-existent location"
+msgstr ""
+
+#: builtin/worktree.c:165
+msgid "report pruned working trees"
+msgstr ""
+
+#: builtin/worktree.c:167
+msgid "expire working trees older than <time>"
+msgstr ""
+
+#: builtin/worktree.c:234
+#, c-format
+msgid "'%s' already exists"
+msgstr ""
+
+#: builtin/worktree.c:251
+#, c-format
+msgid "unable to re-add worktree '%s'"
+msgstr ""
+
+#: builtin/worktree.c:256
+#, c-format
+msgid ""
+"'%s' is a missing but locked worktree;\n"
+"use 'add -f -f' to override, or 'unlock' and 'prune' or 'remove' to clear"
+msgstr ""
+
+#: builtin/worktree.c:258
+#, c-format
+msgid ""
+"'%s' is a missing but already registered worktree;\n"
+"use 'add -f' to override, or 'prune' or 'remove' to clear"
+msgstr ""
+
+#: builtin/worktree.c:308
+#, c-format
+msgid "could not create directory of '%s'"
+msgstr ""
+
+#: builtin/worktree.c:439 builtin/worktree.c:445
+#, c-format
+msgid "Preparing worktree (new branch '%s')"
+msgstr ""
+
+#: builtin/worktree.c:441
+#, c-format
+msgid "Preparing worktree (resetting branch '%s'; was at %s)"
+msgstr ""
+
+#: builtin/worktree.c:450
+#, c-format
+msgid "Preparing worktree (checking out '%s')"
+msgstr ""
+
+#: builtin/worktree.c:456
+#, c-format
+msgid "Preparing worktree (detached HEAD %s)"
+msgstr ""
+
+#: builtin/worktree.c:497
+msgid "checkout <branch> even if already checked out in other worktree"
+msgstr ""
+
+#: builtin/worktree.c:500
+msgid "create a new branch"
+msgstr ""
+
+#: builtin/worktree.c:502
+msgid "create or reset a branch"
+msgstr ""
+
+#: builtin/worktree.c:504
+msgid "populate the new working tree"
+msgstr ""
+
+#: builtin/worktree.c:505
+msgid "keep the new working tree locked"
+msgstr ""
+
+#: builtin/worktree.c:508
+msgid "set up tracking mode (see git-branch(1))"
+msgstr ""
+
+#: builtin/worktree.c:511
+msgid "try to match the new branch name with a remote-tracking branch"
+msgstr ""
+
+#: builtin/worktree.c:519
+msgid "-b, -B, and --detach are mutually exclusive"
+msgstr ""
+
+#: builtin/worktree.c:580
+msgid "--[no-]track can only be used if a new branch is created"
+msgstr ""
+
+#: builtin/worktree.c:680
+msgid "reason for locking"
+msgstr ""
+
+#: builtin/worktree.c:692 builtin/worktree.c:725 builtin/worktree.c:799
+#: builtin/worktree.c:926
+#, c-format
+msgid "'%s' is not a working tree"
+msgstr ""
+
+#: builtin/worktree.c:694 builtin/worktree.c:727
+msgid "The main working tree cannot be locked or unlocked"
+msgstr ""
+
+#: builtin/worktree.c:699
+#, c-format
+msgid "'%s' is already locked, reason: %s"
+msgstr ""
+
+#: builtin/worktree.c:701
+#, c-format
+msgid "'%s' is already locked"
+msgstr ""
+
+#: builtin/worktree.c:729
+#, c-format
+msgid "'%s' is not locked"
+msgstr ""
+
+#: builtin/worktree.c:770
+msgid "working trees containing submodules cannot be moved or removed"
+msgstr ""
+
+#: builtin/worktree.c:778
+msgid "force move even if worktree is dirty or locked"
+msgstr ""
+
+#: builtin/worktree.c:801 builtin/worktree.c:928
+#, c-format
+msgid "'%s' is a main working tree"
+msgstr ""
+
+#: builtin/worktree.c:806
+#, c-format
+msgid "could not figure out destination name from '%s'"
+msgstr ""
+
+#: builtin/worktree.c:812
+#, c-format
+msgid "target '%s' already exists"
+msgstr ""
+
+#: builtin/worktree.c:820
+#, c-format
+msgid ""
+"cannot move a locked working tree, lock reason: %s\n"
+"use 'move -f -f' to override or unlock first"
+msgstr ""
+
+#: builtin/worktree.c:822
+msgid ""
+"cannot move a locked working tree;\n"
+"use 'move -f -f' to override or unlock first"
+msgstr ""
+
+#: builtin/worktree.c:825
+#, c-format
+msgid "validation failed, cannot move working tree: %s"
+msgstr ""
+
+#: builtin/worktree.c:830
+#, c-format
+msgid "failed to move '%s' to '%s'"
+msgstr ""
+
+#: builtin/worktree.c:878
+#, c-format
+msgid "failed to run 'git status' on '%s'"
+msgstr ""
+
+#: builtin/worktree.c:882
+#, c-format
+msgid "'%s' contains modified or untracked files, use --force to delete it"
+msgstr ""
+
+#: builtin/worktree.c:887
+#, c-format
+msgid "failed to run 'git status' on '%s', code %d"
+msgstr ""
+
+#: builtin/worktree.c:910
+msgid "force removal even if worktree is dirty or locked"
+msgstr ""
+
+#: builtin/worktree.c:933
+#, c-format
+msgid ""
+"cannot remove a locked working tree, lock reason: %s\n"
+"use 'remove -f -f' to override or unlock first"
+msgstr ""
+
+#: builtin/worktree.c:935
+msgid ""
+"cannot remove a locked working tree;\n"
+"use 'remove -f -f' to override or unlock first"
+msgstr ""
+
+#: builtin/worktree.c:938
+#, c-format
+msgid "validation failed, cannot remove working tree: %s"
+msgstr ""
+
+#: builtin/write-tree.c:15
+msgid "git write-tree [--missing-ok] [--prefix=<prefix>/]"
+msgstr ""
+
+#: builtin/write-tree.c:28
+msgid "<prefix>/"
+msgstr ""
+
+#: builtin/write-tree.c:29
+msgid "write tree object for a subdirectory <prefix>"
+msgstr ""
+
+#: builtin/write-tree.c:31
+msgid "only useful for debugging"
+msgstr ""
+
+#: fast-import.c:3125
+#, c-format
+msgid "Expected 'mark' command, got %s"
+msgstr ""
+
+#: fast-import.c:3130
+#, c-format
+msgid "Expected 'to' command, got %s"
+msgstr ""
+
+#: fast-import.c:3254
+#, c-format
+msgid "feature '%s' forbidden in input without --allow-unsafe-features"
+msgstr ""
+
+#: credential-cache--daemon.c:223
+#, c-format
+msgid ""
+"The permissions on your socket directory are too loose; other\n"
+"users may be able to read your cached credentials. Consider running:\n"
+"\n"
+"\tchmod 0700 %s"
+msgstr ""
+
+#: credential-cache--daemon.c:272
+msgid "print debugging messages to stderr"
+msgstr ""
+
+#: t/helper/test-reach.c:152
+#, c-format
+msgid "commit %s is not marked reachable"
+msgstr ""
+
+#: t/helper/test-reach.c:162
+msgid "too many commits marked reachable"
+msgstr ""
+
+#: t/helper/test-serve-v2.c:7
+msgid "test-tool serve-v2 [<options>]"
+msgstr ""
+
+#: t/helper/test-serve-v2.c:19
+msgid "exit immediately after advertising capabilities"
+msgstr ""
+
+#: git.c:27
+msgid ""
+"git [--version] [--help] [-C <path>] [-c <name>=<value>]\n"
+"           [--exec-path[=<path>]] [--html-path] [--man-path] [--info-path]\n"
+"           [-p | --paginate | -P | --no-pager] [--no-replace-objects] [--"
+"bare]\n"
+"           [--git-dir=<path>] [--work-tree=<path>] [--namespace=<name>]\n"
+"           <command> [<args>]"
+msgstr ""
+
+#: git.c:34
+msgid ""
+"'git help -a' and 'git help -g' list available subcommands and some\n"
+"concept guides. See 'git help <command>' or 'git help <concept>'\n"
+"to read about a specific subcommand or concept.\n"
+"See 'git help git' for an overview of the system."
+msgstr ""
+
+#: git.c:186
+#, c-format
+msgid "no directory given for --git-dir\n"
+msgstr ""
+
+#: git.c:200
+#, c-format
+msgid "no namespace given for --namespace\n"
+msgstr ""
+
+#: git.c:214
+#, c-format
+msgid "no directory given for --work-tree\n"
+msgstr ""
+
+#: git.c:228
+#, c-format
+msgid "no prefix given for --super-prefix\n"
+msgstr ""
+
+#: git.c:250
+#, c-format
+msgid "-c expects a configuration string\n"
+msgstr ""
+
+#: git.c:288
+#, c-format
+msgid "no directory given for -C\n"
+msgstr ""
+
+#: git.c:314
+#, c-format
+msgid "unknown option: %s\n"
+msgstr ""
+
+#: git.c:360
+#, c-format
+msgid "while expanding alias '%s': '%s'"
+msgstr ""
+
+#: git.c:369
+#, c-format
+msgid ""
+"alias '%s' changes environment variables.\n"
+"You can use '!git' in the alias to do this"
+msgstr ""
+
+#: git.c:376
+#, c-format
+msgid "empty alias for %s"
+msgstr ""
+
+#: git.c:379
+#, c-format
+msgid "recursive alias: %s"
+msgstr ""
+
+#: git.c:459
+msgid "write failure on standard output"
+msgstr ""
+
+#: git.c:461
+msgid "unknown write failure on standard output"
+msgstr ""
+
+#: git.c:463
+msgid "close failed on standard output"
+msgstr ""
+
+#: git.c:793
+#, c-format
+msgid "alias loop detected: expansion of '%s' does not terminate:%s"
+msgstr ""
+
+#: git.c:843
+#, c-format
+msgid "cannot handle %s as a builtin"
+msgstr ""
+
+#: git.c:856
+#, c-format
+msgid ""
+"usage: %s\n"
+"\n"
+msgstr ""
+
+#: git.c:876
+#, c-format
+msgid "expansion of alias '%s' failed; '%s' is not a git command\n"
+msgstr ""
+
+#: git.c:888
+#, c-format
+msgid "failed to run command '%s': %s\n"
+msgstr ""
+
+#: http.c:378
+#, c-format
+msgid "negative value for http.postbuffer; defaulting to %d"
+msgstr ""
+
+#: http.c:399
+msgid "Delegation control is not supported with cURL < 7.22.0"
+msgstr ""
+
+#: http.c:408
+msgid "Public key pinning not supported with cURL < 7.44.0"
+msgstr ""
+
+#: http.c:876
+msgid "CURLSSLOPT_NO_REVOKE not supported with cURL < 7.44.0"
+msgstr ""
+
+#: http.c:949
+msgid "Protocol restrictions not supported with cURL < 7.19.4"
+msgstr ""
+
+#: http.c:1086
+#, c-format
+msgid "Unsupported SSL backend '%s'. Supported SSL backends:"
+msgstr ""
+
+#: http.c:1093
+#, c-format
+msgid "Could not set SSL backend to '%s': cURL was built without SSL backends"
+msgstr ""
+
+#: http.c:1097
+#, c-format
+msgid "Could not set SSL backend to '%s': already set"
+msgstr ""
+
+#: http.c:1966
+#, c-format
+msgid ""
+"unable to update url base from redirection:\n"
+"  asked for: %s\n"
+"   redirect: %s"
+msgstr ""
+
+#: remote-curl.c:166
+#, c-format
+msgid "invalid quoting in push-option value: '%s'"
+msgstr ""
+
+#: remote-curl.c:263
+#, c-format
+msgid "%sinfo/refs not valid: is this a git repository?"
+msgstr ""
+
+#: remote-curl.c:364
+msgid "invalid server response; expected service, got flush packet"
+msgstr ""
+
+#: remote-curl.c:395
+#, c-format
+msgid "invalid server response; got '%s'"
+msgstr ""
+
+#: remote-curl.c:455
+#, c-format
+msgid "repository '%s' not found"
+msgstr ""
+
+#: remote-curl.c:459
+#, c-format
+msgid "Authentication failed for '%s'"
+msgstr ""
+
+#: remote-curl.c:463
+#, c-format
+msgid "unable to access '%s': %s"
+msgstr ""
+
+#: remote-curl.c:469
+#, c-format
+msgid "redirecting to %s"
+msgstr ""
+
+#: remote-curl.c:593
+msgid "shouldn't have EOF when not gentle on EOF"
+msgstr ""
+
+#: remote-curl.c:673
+msgid "unable to rewind rpc post data - try increasing http.postBuffer"
+msgstr ""
+
+#: remote-curl.c:733
+#, c-format
+msgid "RPC failed; %s"
+msgstr ""
+
+#: remote-curl.c:773
+msgid "cannot handle pushes this big"
+msgstr ""
+
+#: remote-curl.c:888
+#, c-format
+msgid "cannot deflate request; zlib deflate error %d"
+msgstr ""
+
+#: remote-curl.c:892
+#, c-format
+msgid "cannot deflate request; zlib end error %d"
+msgstr ""
+
+#: remote-curl.c:1023
+msgid "dumb http transport does not support shallow capabilities"
+msgstr ""
+
+#: remote-curl.c:1037
+msgid "fetch failed."
+msgstr ""
+
+#: remote-curl.c:1085
+msgid "cannot fetch by sha1 over smart http"
+msgstr ""
+
+#: remote-curl.c:1129 remote-curl.c:1135
+#, c-format
+msgid "protocol error: expected sha/ref, got '%s'"
+msgstr ""
+
+#: remote-curl.c:1147 remote-curl.c:1261
+#, c-format
+msgid "http transport does not support %s"
+msgstr ""
+
+#: remote-curl.c:1183
+msgid "git-http-push failed"
+msgstr ""
+
+#: remote-curl.c:1367
+msgid "remote-curl: usage: git remote-curl <remote> [<url>]"
+msgstr ""
+
+#: remote-curl.c:1399
+msgid "remote-curl: error reading command stream from git"
+msgstr ""
+
+#: remote-curl.c:1406
+msgid "remote-curl: fetch attempted without a local repo"
+msgstr ""
+
+#: remote-curl.c:1446
+#, c-format
+msgid "remote-curl: unknown command '%s' from git"
+msgstr ""
+
+#: list-objects-filter-options.h:85
+msgid "args"
+msgstr ""
+
+#: list-objects-filter-options.h:86
+msgid "object filtering"
+msgstr ""
+
+#: parse-options.h:183
+msgid "expiry-date"
+msgstr ""
+
+#: parse-options.h:197
+msgid "no-op (backward compatibility)"
+msgstr ""
+
+#: parse-options.h:309
+msgid "be more verbose"
+msgstr ""
+
+#: parse-options.h:311
+msgid "be more quiet"
+msgstr ""
+
+#: parse-options.h:317
+msgid "use <n> digits to display SHA-1s"
+msgstr ""
+
+#: parse-options.h:336
+msgid "how to strip spaces and #comments from message"
+msgstr ""
+
+#: parse-options.h:337
+msgid "read pathspec from file"
+msgstr ""
+
+#: parse-options.h:338
+msgid ""
+"with --pathspec-from-file, pathspec elements are separated with NUL character"
+msgstr ""
+
+#: ref-filter.h:101
+msgid "key"
+msgstr ""
+
+#: ref-filter.h:101
+msgid "field name to sort on"
+msgstr ""
+
+#: rerere.h:44
+msgid "update the index with reused conflict resolution if possible"
+msgstr ""
+
+#: wt-status.h:67
+msgid "HEAD detached at "
+msgstr ""
+
+#: wt-status.h:68
+msgid "HEAD detached from "
+msgstr ""
+
+#: command-list.h:50
+msgid "Add file contents to the index"
+msgstr ""
+
+#: command-list.h:51
+msgid "Apply a series of patches from a mailbox"
+msgstr ""
+
+#: command-list.h:52
+msgid "Annotate file lines with commit information"
+msgstr ""
+
+#: command-list.h:53
+msgid "Apply a patch to files and/or to the index"
+msgstr ""
+
+#: command-list.h:54
+msgid "Import a GNU Arch repository into Git"
+msgstr ""
+
+#: command-list.h:55
+msgid "Create an archive of files from a named tree"
+msgstr ""
+
+#: command-list.h:56
+msgid "Use binary search to find the commit that introduced a bug"
+msgstr ""
+
+#: command-list.h:57
+msgid "Show what revision and author last modified each line of a file"
+msgstr ""
+
+#: command-list.h:58
+msgid "List, create, or delete branches"
+msgstr ""
+
+#: command-list.h:59
+msgid "Move objects and refs by archive"
+msgstr ""
+
+#: command-list.h:60
+msgid "Provide content or type and size information for repository objects"
+msgstr ""
+
+#: command-list.h:61
+msgid "Display gitattributes information"
+msgstr ""
+
+#: command-list.h:62
+msgid "Debug gitignore / exclude files"
+msgstr ""
+
+#: command-list.h:63
+msgid "Show canonical names and email addresses of contacts"
+msgstr ""
+
+#: command-list.h:64
+msgid "Switch branches or restore working tree files"
+msgstr ""
+
+#: command-list.h:65
+msgid "Copy files from the index to the working tree"
+msgstr ""
+
+#: command-list.h:66
+msgid "Ensures that a reference name is well formed"
+msgstr ""
+
+#: command-list.h:67
+msgid "Find commits yet to be applied to upstream"
+msgstr ""
+
+#: command-list.h:68
+msgid "Apply the changes introduced by some existing commits"
+msgstr ""
+
+#: command-list.h:69
+msgid "Graphical alternative to git-commit"
+msgstr ""
+
+#: command-list.h:70
+msgid "Remove untracked files from the working tree"
+msgstr ""
+
+#: command-list.h:71
+msgid "Clone a repository into a new directory"
+msgstr ""
+
+#: command-list.h:72
+msgid "Display data in columns"
+msgstr ""
+
+#: command-list.h:73
+msgid "Record changes to the repository"
+msgstr ""
+
+#: command-list.h:74
+msgid "Write and verify Git commit-graph files"
+msgstr ""
+
+#: command-list.h:75
+msgid "Create a new commit object"
+msgstr ""
+
+#: command-list.h:76
+msgid "Get and set repository or global options"
+msgstr ""
+
+#: command-list.h:77
+msgid "Count unpacked number of objects and their disk consumption"
+msgstr ""
+
+#: command-list.h:78
+msgid "Retrieve and store user credentials"
+msgstr ""
+
+#: command-list.h:79
+msgid "Helper to temporarily store passwords in memory"
+msgstr ""
+
+#: command-list.h:80
+msgid "Helper to store credentials on disk"
+msgstr ""
+
+#: command-list.h:81
+msgid "Export a single commit to a CVS checkout"
+msgstr ""
+
+#: command-list.h:82
+msgid "Salvage your data out of another SCM people love to hate"
+msgstr ""
+
+#: command-list.h:83
+msgid "A CVS server emulator for Git"
+msgstr ""
+
+#: command-list.h:84
+msgid "A really simple server for Git repositories"
+msgstr ""
+
+#: command-list.h:85
+msgid "Give an object a human readable name based on an available ref"
+msgstr ""
+
+#: command-list.h:86
+msgid "Show changes between commits, commit and working tree, etc"
+msgstr ""
+
+#: command-list.h:87
+msgid "Compares files in the working tree and the index"
+msgstr ""
+
+#: command-list.h:88
+msgid "Compare a tree to the working tree or index"
+msgstr ""
+
+#: command-list.h:89
+msgid "Compares the content and mode of blobs found via two tree objects"
+msgstr ""
+
+#: command-list.h:90
+msgid "Show changes using common diff tools"
+msgstr ""
+
+#: command-list.h:91
+msgid "Git data exporter"
+msgstr ""
+
+#: command-list.h:92
+msgid "Backend for fast Git data importers"
+msgstr ""
+
+#: command-list.h:93
+msgid "Download objects and refs from another repository"
+msgstr ""
+
+#: command-list.h:94
+msgid "Receive missing objects from another repository"
+msgstr ""
+
+#: command-list.h:95
+msgid "Rewrite branches"
+msgstr ""
+
+#: command-list.h:96
+msgid "Produce a merge commit message"
+msgstr ""
+
+#: command-list.h:97
+msgid "Output information on each ref"
+msgstr ""
+
+#: command-list.h:98
+msgid "Prepare patches for e-mail submission"
+msgstr ""
+
+#: command-list.h:99
+msgid "Verifies the connectivity and validity of the objects in the database"
+msgstr ""
+
+#: command-list.h:100
+msgid "Cleanup unnecessary files and optimize the local repository"
+msgstr ""
+
+#: command-list.h:101
+msgid "Extract commit ID from an archive created using git-archive"
+msgstr ""
+
+#: command-list.h:102
+msgid "Print lines matching a pattern"
+msgstr ""
+
+#: command-list.h:103
+msgid "A portable graphical interface to Git"
+msgstr ""
+
+#: command-list.h:104
+msgid "Compute object ID and optionally creates a blob from a file"
+msgstr ""
+
+#: command-list.h:105
+msgid "Display help information about Git"
+msgstr ""
+
+#: command-list.h:106
+msgid "Server side implementation of Git over HTTP"
+msgstr ""
+
+#: command-list.h:107
+msgid "Download from a remote Git repository via HTTP"
+msgstr ""
+
+#: command-list.h:108
+msgid "Push objects over HTTP/DAV to another repository"
+msgstr ""
+
+#: command-list.h:109
+msgid "Send a collection of patches from stdin to an IMAP folder"
+msgstr ""
+
+#: command-list.h:110
+msgid "Build pack index file for an existing packed archive"
+msgstr ""
+
+#: command-list.h:111
+msgid "Create an empty Git repository or reinitialize an existing one"
+msgstr ""
+
+#: command-list.h:112
+msgid "Instantly browse your working repository in gitweb"
+msgstr ""
+
+#: command-list.h:113
+msgid "Add or parse structured information in commit messages"
+msgstr ""
+
+#: command-list.h:114
+msgid "The Git repository browser"
+msgstr ""
+
+#: command-list.h:115
+msgid "Show commit logs"
+msgstr ""
+
+#: command-list.h:116
+msgid "Show information about files in the index and the working tree"
+msgstr ""
+
+#: command-list.h:117
+msgid "List references in a remote repository"
+msgstr ""
+
+#: command-list.h:118
+msgid "List the contents of a tree object"
+msgstr ""
+
+#: command-list.h:119
+msgid "Extracts patch and authorship from a single e-mail message"
+msgstr ""
+
+#: command-list.h:120
+msgid "Simple UNIX mbox splitter program"
+msgstr ""
+
+#: command-list.h:121
+msgid "Join two or more development histories together"
+msgstr ""
+
+#: command-list.h:122
+msgid "Find as good common ancestors as possible for a merge"
+msgstr ""
+
+#: command-list.h:123
+msgid "Run a three-way file merge"
+msgstr ""
+
+#: command-list.h:124
+msgid "Run a merge for files needing merging"
+msgstr ""
+
+#: command-list.h:125
+msgid "The standard helper program to use with git-merge-index"
+msgstr ""
+
+#: command-list.h:126
+msgid "Run merge conflict resolution tools to resolve merge conflicts"
+msgstr ""
+
+#: command-list.h:127
+msgid "Show three-way merge without touching index"
+msgstr ""
+
+#: command-list.h:128
+msgid "Write and verify multi-pack-indexes"
+msgstr ""
+
+#: command-list.h:129
+msgid "Creates a tag object"
+msgstr ""
+
+#: command-list.h:130
+msgid "Build a tree-object from ls-tree formatted text"
+msgstr ""
+
+#: command-list.h:131
+msgid "Move or rename a file, a directory, or a symlink"
+msgstr ""
+
+#: command-list.h:132
+msgid "Find symbolic names for given revs"
+msgstr ""
+
+#: command-list.h:133
+msgid "Add or inspect object notes"
+msgstr ""
+
+#: command-list.h:134
+msgid "Import from and submit to Perforce repositories"
+msgstr ""
+
+#: command-list.h:135
+msgid "Create a packed archive of objects"
+msgstr ""
+
+#: command-list.h:136
+msgid "Find redundant pack files"
+msgstr ""
+
+#: command-list.h:137
+msgid "Pack heads and tags for efficient repository access"
+msgstr ""
+
+#: command-list.h:138
+msgid "Routines to help parsing remote repository access parameters"
+msgstr ""
+
+#: command-list.h:139
+msgid "Compute unique ID for a patch"
+msgstr ""
+
+#: command-list.h:140
+msgid "Prune all unreachable objects from the object database"
+msgstr ""
+
+#: command-list.h:141
+msgid "Remove extra objects that are already in pack files"
+msgstr ""
+
+#: command-list.h:142
+msgid "Fetch from and integrate with another repository or a local branch"
+msgstr ""
+
+#: command-list.h:143
+msgid "Update remote refs along with associated objects"
+msgstr ""
+
+#: command-list.h:144
+msgid "Applies a quilt patchset onto the current branch"
+msgstr ""
+
+#: command-list.h:145
+msgid "Compare two commit ranges (e.g. two versions of a branch)"
+msgstr ""
+
+#: command-list.h:146
+msgid "Reads tree information into the index"
+msgstr ""
+
+#: command-list.h:147
+msgid "Reapply commits on top of another base tip"
+msgstr ""
+
+#: command-list.h:148
+msgid "Receive what is pushed into the repository"
+msgstr ""
+
+#: command-list.h:149
+msgid "Manage reflog information"
+msgstr ""
+
+#: command-list.h:150
+msgid "Manage set of tracked repositories"
+msgstr ""
+
+#: command-list.h:151
+msgid "Pack unpacked objects in a repository"
+msgstr ""
+
+#: command-list.h:152
+msgid "Create, list, delete refs to replace objects"
+msgstr ""
+
+#: command-list.h:153
+msgid "Generates a summary of pending changes"
+msgstr ""
+
+#: command-list.h:154
+msgid "Reuse recorded resolution of conflicted merges"
+msgstr ""
+
+#: command-list.h:155
+msgid "Reset current HEAD to the specified state"
+msgstr ""
+
+#: command-list.h:156
+msgid "Restore working tree files"
+msgstr ""
+
+#: command-list.h:157
+msgid "Revert some existing commits"
+msgstr ""
+
+#: command-list.h:158
+msgid "Lists commit objects in reverse chronological order"
+msgstr ""
+
+#: command-list.h:159
+msgid "Pick out and massage parameters"
+msgstr ""
+
+#: command-list.h:160
+msgid "Remove files from the working tree and from the index"
+msgstr ""
+
+#: command-list.h:161
+msgid "Send a collection of patches as emails"
+msgstr ""
+
+#: command-list.h:162
+msgid "Push objects over Git protocol to another repository"
+msgstr ""
+
+#: command-list.h:163
+msgid "Restricted login shell for Git-only SSH access"
+msgstr ""
+
+#: command-list.h:164
+msgid "Summarize 'git log' output"
+msgstr ""
+
+#: command-list.h:165
+msgid "Show various types of objects"
+msgstr ""
+
+#: command-list.h:166
+msgid "Show branches and their commits"
+msgstr ""
+
+#: command-list.h:167
+msgid "Show packed archive index"
+msgstr ""
+
+#: command-list.h:168
+msgid "List references in a local repository"
+msgstr ""
+
+#: command-list.h:169
+msgid "Git's i18n setup code for shell scripts"
+msgstr ""
+
+#: command-list.h:170
+msgid "Common Git shell script setup code"
+msgstr ""
+
+#: command-list.h:171
+msgid "Initialize and modify the sparse-checkout"
+msgstr ""
+
+#: command-list.h:172
+msgid "Stash the changes in a dirty working directory away"
+msgstr ""
+
+#: command-list.h:173
+msgid "Add file contents to the staging area"
+msgstr ""
+
+#: command-list.h:174
+msgid "Show the working tree status"
+msgstr ""
+
+#: command-list.h:175
+msgid "Remove unnecessary whitespace"
+msgstr ""
+
+#: command-list.h:176
+msgid "Initialize, update or inspect submodules"
+msgstr ""
+
+#: command-list.h:177
+msgid "Bidirectional operation between a Subversion repository and Git"
+msgstr ""
+
+#: command-list.h:178
+msgid "Switch branches"
+msgstr ""
+
+#: command-list.h:179
+msgid "Read, modify and delete symbolic refs"
+msgstr ""
+
+#: command-list.h:180
+msgid "Create, list, delete or verify a tag object signed with GPG"
+msgstr ""
+
+#: command-list.h:181
+msgid "Creates a temporary file with a blob's contents"
+msgstr ""
+
+#: command-list.h:182
+msgid "Unpack objects from a packed archive"
+msgstr ""
+
+#: command-list.h:183
+msgid "Register file contents in the working tree to the index"
+msgstr ""
+
+#: command-list.h:184
+msgid "Update the object name stored in a ref safely"
+msgstr ""
+
+#: command-list.h:185
+msgid "Update auxiliary info file to help dumb servers"
+msgstr ""
+
+#: command-list.h:186
+msgid "Send archive back to git-archive"
+msgstr ""
+
+#: command-list.h:187
+msgid "Send objects packed back to git-fetch-pack"
+msgstr ""
+
+#: command-list.h:188
+msgid "Show a Git logical variable"
+msgstr ""
+
+#: command-list.h:189
+msgid "Check the GPG signature of commits"
+msgstr ""
+
+#: command-list.h:190
+msgid "Validate packed Git archive files"
+msgstr ""
+
+#: command-list.h:191
+msgid "Check the GPG signature of tags"
+msgstr ""
+
+#: command-list.h:192
+msgid "Git web interface (web frontend to Git repositories)"
+msgstr ""
+
+#: command-list.h:193
+msgid "Show logs with difference each commit introduces"
+msgstr ""
+
+#: command-list.h:194
+msgid "Manage multiple working trees"
+msgstr ""
+
+#: command-list.h:195
+msgid "Create a tree object from the current index"
+msgstr ""
+
+#: command-list.h:196
+msgid "Defining attributes per path"
+msgstr ""
+
+#: command-list.h:197
+msgid "Git command-line interface and conventions"
+msgstr ""
+
+#: command-list.h:198
+msgid "A Git core tutorial for developers"
+msgstr ""
+
+#: command-list.h:199
+msgid "Git for CVS users"
+msgstr ""
+
+#: command-list.h:200
+msgid "Tweaking diff output"
+msgstr ""
+
+#: command-list.h:201
+msgid "A useful minimum set of commands for Everyday Git"
+msgstr ""
+
+#: command-list.h:202
+msgid "A Git Glossary"
+msgstr ""
+
+#: command-list.h:203
+msgid "Hooks used by Git"
+msgstr ""
+
+#: command-list.h:204
+msgid "Specifies intentionally untracked files to ignore"
+msgstr ""
+
+#: command-list.h:205
+msgid "Defining submodule properties"
+msgstr ""
+
+#: command-list.h:206
+msgid "Git namespaces"
+msgstr ""
+
+#: command-list.h:207
+msgid "Git Repository Layout"
+msgstr ""
+
+#: command-list.h:208
+msgid "Specifying revisions and ranges for Git"
 msgstr ""
 
-#: git-rebase.sh:537
-#, sh-format
-msgid "invalid upstream '$upstream_name'"
+#: command-list.h:209
+msgid "Mounting one repository inside another"
 msgstr ""
 
-#: git-rebase.sh:561
-#, sh-format
-msgid "$onto_name: there are more than one merge bases"
+#: command-list.h:210
+msgid "A tutorial introduction to Git: part two"
 msgstr ""
 
-#: git-rebase.sh:564 git-rebase.sh:568
-#, sh-format
-msgid "$onto_name: there is no merge base"
+#: command-list.h:211
+msgid "A tutorial introduction to Git"
 msgstr ""
 
-#: git-rebase.sh:573
-#, sh-format
-msgid "Does not point to a valid commit: $onto_name"
+#: command-list.h:212
+msgid "An overview of recommended workflows with Git"
 msgstr ""
 
-#: git-rebase.sh:599
-#, sh-format
-msgid "fatal: no such branch/commit '$branch_name'"
+#: git-bisect.sh:54
+msgid "You need to start by \"git bisect start\""
 msgstr ""
 
-#: git-rebase.sh:632
-msgid "Cannot autostash"
+#. TRANSLATORS: Make sure to include [Y] and [n] in your
+#. translation. The program will only accept English input
+#. at this point.
+#: git-bisect.sh:60
+msgid "Do you want me to do it for you [Y/n]? "
 msgstr ""
 
-#: git-rebase.sh:637
+#: git-bisect.sh:101
 #, sh-format
-msgid "Created autostash: $stash_abbrev"
+msgid "Bad rev input: $arg"
 msgstr ""
 
-#: git-rebase.sh:641
-msgid "Please commit or stash them."
+#: git-bisect.sh:121
+#, sh-format
+msgid "Bad rev input: $bisected_head"
 msgstr ""
 
-#: git-rebase.sh:664
+#: git-bisect.sh:130
 #, sh-format
-msgid "HEAD is up to date."
+msgid "Bad rev input: $rev"
 msgstr ""
 
-#: git-rebase.sh:666
+#: git-bisect.sh:139
 #, sh-format
-msgid "Current branch $branch_name is up to date."
+msgid "'git bisect $TERM_BAD' can take only one argument."
 msgstr ""
 
-#: git-rebase.sh:674
-#, sh-format
-msgid "HEAD is up to date, rebase forced."
+#: git-bisect.sh:209
+msgid "No logfile given"
 msgstr ""
 
-#: git-rebase.sh:676
+#: git-bisect.sh:210
 #, sh-format
-msgid "Current branch $branch_name is up to date, rebase forced."
+msgid "cannot read $file for replaying"
 msgstr ""
 
-#: git-rebase.sh:688
-#, sh-format
-msgid "Changes from $mb to $onto:"
+#: git-bisect.sh:232
+msgid "?? what are you talking about?"
 msgstr ""
 
-#: git-rebase.sh:697
-msgid "First, rewinding head to replay your work on top of it..."
+#: git-bisect.sh:241
+msgid "bisect run failed: no command provided."
 msgstr ""
 
-#: git-rebase.sh:707
+#: git-bisect.sh:246
 #, sh-format
-msgid "Fast-forwarded $branch_name to $onto_name."
+msgid "running $command"
 msgstr ""
 
-#: git-stash.sh:61
-msgid "git stash clear with parameters is unimplemented"
+#: git-bisect.sh:253
+#, sh-format
+msgid ""
+"bisect run failed:\n"
+"exit code $res from '$command' is < 0 or >= 128"
 msgstr ""
 
-#: git-stash.sh:108
-msgid "You do not have the initial commit yet"
+#: git-bisect.sh:279
+msgid "bisect run cannot continue any more"
 msgstr ""
 
-#: git-stash.sh:123
-msgid "Cannot save the current index state"
+#: git-bisect.sh:285
+#, sh-format
+msgid ""
+"bisect run failed:\n"
+"'bisect_state $state' exited with error code $res"
 msgstr ""
 
-#: git-stash.sh:138
-msgid "Cannot save the untracked files"
+#: git-bisect.sh:292
+msgid "bisect run success"
 msgstr ""
 
-#: git-stash.sh:158 git-stash.sh:171
-msgid "Cannot save the current worktree state"
+#: git-bisect.sh:300
+msgid "We are not bisecting."
 msgstr ""
 
-#: git-stash.sh:175
-msgid "No changes selected"
+#: git-merge-octopus.sh:46
+msgid ""
+"Error: Your local changes to the following files would be overwritten by "
+"merge"
 msgstr ""
 
-#: git-stash.sh:178
-msgid "Cannot remove temporary index (can't happen)"
+#: git-merge-octopus.sh:61
+msgid "Automated merge did not work."
 msgstr ""
 
-#: git-stash.sh:191
-msgid "Cannot record working tree state"
+#: git-merge-octopus.sh:62
+msgid "Should not be doing an octopus."
 msgstr ""
 
-#: git-stash.sh:229
+#: git-merge-octopus.sh:73
 #, sh-format
-msgid "Cannot update $ref_stash with $w_commit"
+msgid "Unable to find common commit with $pretty_name"
 msgstr ""
 
-#: git-stash.sh:281
+#: git-merge-octopus.sh:77
 #, sh-format
-msgid "error: unknown option for 'stash push': $option"
+msgid "Already up to date with $pretty_name"
 msgstr ""
 
-#: git-stash.sh:295
-msgid "Can't use --patch and --include-untracked or --all at the same time"
+#: git-merge-octopus.sh:89
+#, sh-format
+msgid "Fast-forwarding to: $pretty_name"
 msgstr ""
 
-#: git-stash.sh:303
-msgid "No local changes to save"
+#: git-merge-octopus.sh:97
+#, sh-format
+msgid "Trying simple merge with $pretty_name"
 msgstr ""
 
-#: git-stash.sh:308
-msgid "Cannot initialize stash"
+#: git-merge-octopus.sh:102
+msgid "Simple merge did not work, trying automatic merge."
 msgstr ""
 
-#: git-stash.sh:312
-msgid "Cannot save the current status"
+#: git-legacy-stash.sh:221
+msgid "Cannot remove temporary index (can't happen)"
 msgstr ""
 
-#: git-stash.sh:313
+#: git-legacy-stash.sh:272
 #, sh-format
-msgid "Saved working directory and index state $stash_msg"
+msgid "Cannot update $ref_stash with $w_commit"
 msgstr ""
 
-#: git-stash.sh:342
-msgid "Cannot remove worktree changes"
+#: git-legacy-stash.sh:324
+#, sh-format
+msgid "error: unknown option for 'stash push': $option"
 msgstr ""
 
-#: git-stash.sh:490
+#: git-legacy-stash.sh:356
 #, sh-format
-msgid "unknown option: $opt"
+msgid "Saved working directory and index state $stash_msg"
 msgstr ""
 
-#: git-stash.sh:503
-msgid "No stash entries found."
+#: git-legacy-stash.sh:536
+#, sh-format
+msgid "unknown option: $opt"
 msgstr ""
 
-#: git-stash.sh:510
+#: git-legacy-stash.sh:556
 #, sh-format
 msgid "Too many revisions specified: $REV"
 msgstr ""
 
-#: git-stash.sh:525
+#: git-legacy-stash.sh:571
 #, sh-format
 msgid "$reference is not a valid reference"
 msgstr ""
 
-#: git-stash.sh:553
+#: git-legacy-stash.sh:599
 #, sh-format
 msgid "'$args' is not a stash-like commit"
 msgstr ""
 
-#: git-stash.sh:564
+#: git-legacy-stash.sh:610
 #, sh-format
 msgid "'$args' is not a stash reference"
 msgstr ""
 
-#: git-stash.sh:572
+#: git-legacy-stash.sh:618
 msgid "unable to refresh index"
 msgstr ""
 
-#: git-stash.sh:576
+#: git-legacy-stash.sh:622
 msgid "Cannot apply a stash in the middle of a merge"
 msgstr ""
 
-#: git-stash.sh:584
+#: git-legacy-stash.sh:630
 msgid "Conflicts in index. Try without --index."
 msgstr ""
 
-#: git-stash.sh:586
+#: git-legacy-stash.sh:632
 msgid "Could not save index tree"
 msgstr ""
 
-#: git-stash.sh:595
+#: git-legacy-stash.sh:641
 msgid "Could not restore untracked files from stash entry"
 msgstr ""
 
-#: git-stash.sh:620
+#: git-legacy-stash.sh:666
 msgid "Cannot unstage modified files"
 msgstr ""
 
-#: git-stash.sh:635
-msgid "Index was not unstashed."
-msgstr ""
-
-#: git-stash.sh:649
-msgid "The stash entry is kept in case you need it again."
-msgstr ""
-
-#: git-stash.sh:658
+#: git-legacy-stash.sh:704
 #, sh-format
 msgid "Dropped ${REV} ($s)"
 msgstr ""
 
-#: git-stash.sh:659
+#: git-legacy-stash.sh:705
 #, sh-format
 msgid "${REV}: Could not drop stash entry"
 msgstr ""
 
-#: git-stash.sh:667
-msgid "No branch name specified"
-msgstr ""
-
-#: git-stash.sh:746
+#: git-legacy-stash.sh:792
 msgid "(To restore them type \"git stash apply\")"
 msgstr ""
 
-#: git-submodule.sh:188
+#: git-submodule.sh:202
 msgid "Relative path can only be used from the toplevel of the working tree"
 msgstr ""
 
-#: git-submodule.sh:198
+#: git-submodule.sh:212
 #, sh-format
 msgid "repo URL: '$repo' must be absolute or begin with ./|../"
 msgstr ""
 
-#: git-submodule.sh:217
+#: git-submodule.sh:231
 #, sh-format
 msgid "'$sm_path' already exists in the index"
 msgstr ""
 
-#: git-submodule.sh:220
+#: git-submodule.sh:234
 #, sh-format
 msgid "'$sm_path' already exists in the index and is not a submodule"
 msgstr ""
 
-#: git-submodule.sh:226
+#: git-submodule.sh:241
+#, sh-format
+msgid "'$sm_path' does not have a commit checked out"
+msgstr ""
+
+#: git-submodule.sh:247
 #, sh-format
 msgid ""
 "The following path is ignored by one of your .gitignore files:\n"
@@ -15694,22 +21520,22 @@ msgid ""
 "Use -f if you really want to add it."
 msgstr ""
 
-#: git-submodule.sh:249
+#: git-submodule.sh:270
 #, sh-format
 msgid "Adding existing repo at '$sm_path' to the index"
 msgstr ""
 
-#: git-submodule.sh:251
+#: git-submodule.sh:272
 #, sh-format
 msgid "'$sm_path' already exists and is not a valid git repo"
 msgstr ""
 
-#: git-submodule.sh:259
+#: git-submodule.sh:280
 #, sh-format
 msgid "A git directory for '$sm_name' is found locally with remote(s):"
 msgstr ""
 
-#: git-submodule.sh:261
+#: git-submodule.sh:282
 #, sh-format
 msgid ""
 "If you want to reuse this local git directory instead of cloning again from\n"
@@ -15720,130 +21546,122 @@ msgid ""
 "option."
 msgstr ""
 
-#: git-submodule.sh:267
+#: git-submodule.sh:288
 #, sh-format
 msgid "Reactivating local git directory for submodule '$sm_name'."
 msgstr ""
 
-#: git-submodule.sh:279
+#: git-submodule.sh:300
 #, sh-format
 msgid "Unable to checkout submodule '$sm_path'"
 msgstr ""
 
-#: git-submodule.sh:284
+#: git-submodule.sh:305
 #, sh-format
 msgid "Failed to add submodule '$sm_path'"
 msgstr ""
 
-#: git-submodule.sh:293
+#: git-submodule.sh:314
 #, sh-format
 msgid "Failed to register submodule '$sm_path'"
 msgstr ""
 
-#: git-submodule.sh:354
-#, sh-format
-msgid "Entering '$displaypath'"
-msgstr ""
-
-#: git-submodule.sh:374
-#, sh-format
-msgid "Stopping at '$displaypath'; script returned non-zero status."
-msgstr ""
-
-#: git-submodule.sh:600
+#: git-submodule.sh:580
 #, sh-format
 msgid "Unable to find current revision in submodule path '$displaypath'"
 msgstr ""
 
-#: git-submodule.sh:610
+#: git-submodule.sh:590
 #, sh-format
 msgid "Unable to fetch in submodule path '$sm_path'"
 msgstr ""
 
-#: git-submodule.sh:615
+#: git-submodule.sh:595
 #, sh-format
 msgid ""
 "Unable to find current ${remote_name}/${branch} revision in submodule path "
 "'$sm_path'"
 msgstr ""
 
-#: git-submodule.sh:633
+#: git-submodule.sh:613
 #, sh-format
-msgid "Unable to fetch in submodule path '$displaypath'"
+msgid ""
+"Unable to fetch in submodule path '$displaypath'; trying to directly fetch "
+"$sha1:"
 msgstr ""
 
-#: git-submodule.sh:639
+#: git-submodule.sh:619
 #, sh-format
 msgid ""
 "Fetched in submodule path '$displaypath', but it did not contain $sha1. "
 "Direct fetching of that commit failed."
 msgstr ""
 
-#: git-submodule.sh:646
+#: git-submodule.sh:626
 #, sh-format
 msgid "Unable to checkout '$sha1' in submodule path '$displaypath'"
 msgstr ""
 
-#: git-submodule.sh:647
+#: git-submodule.sh:627
 #, sh-format
 msgid "Submodule path '$displaypath': checked out '$sha1'"
 msgstr ""
 
-#: git-submodule.sh:651
+#: git-submodule.sh:631
 #, sh-format
 msgid "Unable to rebase '$sha1' in submodule path '$displaypath'"
 msgstr ""
 
-#: git-submodule.sh:652
+#: git-submodule.sh:632
 #, sh-format
 msgid "Submodule path '$displaypath': rebased into '$sha1'"
 msgstr ""
 
-#: git-submodule.sh:657
+#: git-submodule.sh:637
 #, sh-format
 msgid "Unable to merge '$sha1' in submodule path '$displaypath'"
 msgstr ""
 
-#: git-submodule.sh:658
+#: git-submodule.sh:638
 #, sh-format
 msgid "Submodule path '$displaypath': merged in '$sha1'"
 msgstr ""
 
-#: git-submodule.sh:663
+#: git-submodule.sh:643
 #, sh-format
 msgid "Execution of '$command $sha1' failed in submodule path '$displaypath'"
 msgstr ""
 
-#: git-submodule.sh:664
+#: git-submodule.sh:644
 #, sh-format
 msgid "Submodule path '$displaypath': '$command $sha1'"
 msgstr ""
 
-#: git-submodule.sh:695
+#: git-submodule.sh:675
 #, sh-format
 msgid "Failed to recurse into submodule path '$displaypath'"
 msgstr ""
 
-#: git-submodule.sh:791
+#: git-submodule.sh:886
 msgid "The --cached option cannot be used with the --files option"
 msgstr ""
 
-#: git-submodule.sh:843
+#: git-submodule.sh:938
 #, sh-format
 msgid "unexpected mode $mod_dst"
 msgstr ""
 
-#: git-submodule.sh:863
+#: git-submodule.sh:958
 #, sh-format
 msgid "  Warn: $display_name doesn't contain commit $sha1_src"
 msgstr ""
 
-#: git-submodule.sh:866
+#: git-submodule.sh:961
 #, sh-format
 msgid "  Warn: $display_name doesn't contain commit $sha1_dst"
 msgstr ""
 
-#: git-submodule.sh:869
+#: git-submodule.sh:964
 #, sh-format
 msgid "  Warn: $display_name doesn't contain commits $sha1_src and $sha1_dst"
 msgstr ""
@@ -15853,12 +21671,21 @@ msgstr ""
 msgid "See git-${cmd}(1) for details."
 msgstr ""
 
-#: git-rebase--interactive.sh:142
+#: git-rebase--preserve-merges.sh:109
+msgid "Applied autostash."
+msgstr ""
+
+#: git-rebase--preserve-merges.sh:112
+#, sh-format
+msgid "Cannot store $stash_sha1"
+msgstr ""
+
+#: git-rebase--preserve-merges.sh:191
 #, sh-format
 msgid "Rebasing ($new_count/$total)"
 msgstr ""
 
-#: git-rebase--interactive.sh:158
+#: git-rebase--preserve-merges.sh:207
 msgid ""
 "\n"
 "Commands:\n"
@@ -15867,7 +21694,7 @@ msgid ""
 "e, edit <commit> = use commit, but stop for amending\n"
 "s, squash <commit> = use commit, but meld into previous commit\n"
 "f, fixup <commit> = like \"squash\", but discard this commit's log message\n"
-"x, exec <command> = run command (the rest of the line) using shell\n"
+"x, exec <commit> = run command (the rest of the line) using shell\n"
 "d, drop <commit> = remove commit\n"
 "l, label <label> = label current HEAD with a name\n"
 "t, reset <label> = reset HEAD to a label\n"
@@ -15879,19 +21706,7 @@ msgid ""
 "These lines can be re-ordered; they are executed from top to bottom.\n"
 msgstr ""
 
-#: git-rebase--interactive.sh:179
-msgid ""
-"\n"
-"Do not remove any line. Use 'drop' explicitly to remove a commit.\n"
-msgstr ""
-
-#: git-rebase--interactive.sh:183
-msgid ""
-"\n"
-"If you remove a line here THAT COMMIT WILL BE LOST.\n"
-msgstr ""
-
-#: git-rebase--interactive.sh:221
+#: git-rebase--preserve-merges.sh:270
 #, sh-format
 msgid ""
 "You can amend the commit now, with\n"
@@ -15903,83 +21718,83 @@ msgid ""
 "\tgit rebase --continue"
 msgstr ""
 
-#: git-rebase--interactive.sh:246
+#: git-rebase--preserve-merges.sh:295
 #, sh-format
 msgid "$sha1: not a commit that can be picked"
 msgstr ""
 
-#: git-rebase--interactive.sh:285
+#: git-rebase--preserve-merges.sh:334
 #, sh-format
 msgid "Invalid commit name: $sha1"
 msgstr ""
 
-#: git-rebase--interactive.sh:325
+#: git-rebase--preserve-merges.sh:364
 msgid "Cannot write current commit's replacement sha1"
 msgstr ""
 
-#: git-rebase--interactive.sh:376
+#: git-rebase--preserve-merges.sh:415
 #, sh-format
 msgid "Fast-forward to $sha1"
 msgstr ""
 
-#: git-rebase--interactive.sh:378
+#: git-rebase--preserve-merges.sh:417
 #, sh-format
 msgid "Cannot fast-forward to $sha1"
 msgstr ""
 
-#: git-rebase--interactive.sh:387
+#: git-rebase--preserve-merges.sh:426
 #, sh-format
 msgid "Cannot move HEAD to $first_parent"
 msgstr ""
 
-#: git-rebase--interactive.sh:392
+#: git-rebase--preserve-merges.sh:431
 #, sh-format
 msgid "Refusing to squash a merge: $sha1"
 msgstr ""
 
-#: git-rebase--interactive.sh:410
+#: git-rebase--preserve-merges.sh:449
 #, sh-format
 msgid "Error redoing merge $sha1"
 msgstr ""
 
-#: git-rebase--interactive.sh:419
+#: git-rebase--preserve-merges.sh:458
 #, sh-format
 msgid "Could not pick $sha1"
 msgstr ""
 
-#: git-rebase--interactive.sh:428
+#: git-rebase--preserve-merges.sh:467
 #, sh-format
 msgid "This is the commit message #${n}:"
 msgstr ""
 
-#: git-rebase--interactive.sh:433
+#: git-rebase--preserve-merges.sh:472
 #, sh-format
 msgid "The commit message #${n} will be skipped:"
 msgstr ""
 
-#: git-rebase--interactive.sh:444
+#: git-rebase--preserve-merges.sh:483
 #, sh-format
 msgid "This is a combination of $count commit."
 msgid_plural "This is a combination of $count commits."
 msgstr[0] ""
 msgstr[1] ""
 
-#: git-rebase--interactive.sh:453
+#: git-rebase--preserve-merges.sh:492
 #, sh-format
 msgid "Cannot write $fixup_msg"
 msgstr ""
 
-#: git-rebase--interactive.sh:456
+#: git-rebase--preserve-merges.sh:495
 msgid "This is a combination of 2 commits."
 msgstr ""
 
-#: git-rebase--interactive.sh:497 git-rebase--interactive.sh:540
-#: git-rebase--interactive.sh:543
+#: git-rebase--preserve-merges.sh:536 git-rebase--preserve-merges.sh:579
+#: git-rebase--preserve-merges.sh:582
 #, sh-format
 msgid "Could not apply $sha1... $rest"
 msgstr ""
 
-#: git-rebase--interactive.sh:572
+#: git-rebase--preserve-merges.sh:611
 #, sh-format
 msgid ""
 "Could not amend commit after successfully picking $sha1... $rest\n"
@@ -15989,31 +21804,31 @@ msgid ""
 "you are able to reword the commit."
 msgstr ""
 
-#: git-rebase--interactive.sh:587
+#: git-rebase--preserve-merges.sh:626
 #, sh-format
 msgid "Stopped at $sha1_abbrev... $rest"
 msgstr ""
 
-#: git-rebase--interactive.sh:602
+#: git-rebase--preserve-merges.sh:641
 #, sh-format
 msgid "Cannot '$squash_style' without a previous commit"
 msgstr ""
 
-#: git-rebase--interactive.sh:644
+#: git-rebase--preserve-merges.sh:683
 #, sh-format
 msgid "Executing: $rest"
 msgstr ""
 
-#: git-rebase--interactive.sh:652
+#: git-rebase--preserve-merges.sh:691
 #, sh-format
 msgid "Execution failed: $rest"
 msgstr ""
 
-#: git-rebase--interactive.sh:654
+#: git-rebase--preserve-merges.sh:693
 msgid "and made changes to the index and/or the working tree"
 msgstr ""
 
-#: git-rebase--interactive.sh:656
+#: git-rebase--preserve-merges.sh:695
 msgid ""
 "You can fix the problem, and then run\n"
 "\n"
@@ -16021,7 +21836,7 @@ msgid ""
 msgstr ""
 
 #. TRANSLATORS: after these lines is a command to be issued by the user
-#: git-rebase--interactive.sh:669
+#: git-rebase--preserve-merges.sh:708
 #, sh-format
 msgid ""
 "Execution succeeded: $rest\n"
@@ -16031,29 +21846,25 @@ msgid ""
 "\tgit rebase --continue"
 msgstr ""
 
-#: git-rebase--interactive.sh:680
+#: git-rebase--preserve-merges.sh:719
 #, sh-format
 msgid "Unknown command: $command $sha1 $rest"
 msgstr ""
 
-#: git-rebase--interactive.sh:681
+#: git-rebase--preserve-merges.sh:720
 msgid "Please fix this using 'git rebase --edit-todo'."
 msgstr ""
 
-#: git-rebase--interactive.sh:716
+#: git-rebase--preserve-merges.sh:755
 #, sh-format
 msgid "Successfully rebased and updated $head_name."
 msgstr ""
 
-#: git-rebase--interactive.sh:740
-msgid "could not detach HEAD"
-msgstr ""
-
-#: git-rebase--interactive.sh:778
+#: git-rebase--preserve-merges.sh:812
 msgid "Could not remove CHERRY_PICK_HEAD"
 msgstr ""
 
-#: git-rebase--interactive.sh:783
+#: git-rebase--preserve-merges.sh:817
 #, sh-format
 msgid ""
 "You have staged changes in your working tree.\n"
@@ -16071,75 +21882,50 @@ msgid ""
 "  git rebase --continue\n"
 msgstr ""
 
-#: git-rebase--interactive.sh:800
+#: git-rebase--preserve-merges.sh:834
 msgid "Error trying to find the author identity to amend commit"
 msgstr ""
 
-#: git-rebase--interactive.sh:805
+#: git-rebase--preserve-merges.sh:839
 msgid ""
 "You have uncommitted changes in your working tree. Please commit them\n"
 "first and then run 'git rebase --continue' again."
 msgstr ""
 
-#: git-rebase--interactive.sh:810 git-rebase--interactive.sh:814
+#: git-rebase--preserve-merges.sh:844 git-rebase--preserve-merges.sh:848
 msgid "Could not commit staged changes."
 msgstr ""
 
-#: git-rebase--interactive.sh:843
-msgid ""
-"\n"
-"You are editing the todo file of an ongoing interactive rebase.\n"
-"To continue rebase after editing, run:\n"
-"    git rebase --continue\n"
-"\n"
-msgstr ""
-
-#: git-rebase--interactive.sh:851 git-rebase--interactive.sh:937
+#: git-rebase--preserve-merges.sh:879 git-rebase--preserve-merges.sh:965
 msgid "Could not execute editor"
 msgstr ""
 
-#: git-rebase--interactive.sh:872
+#: git-rebase--preserve-merges.sh:900
 #, sh-format
 msgid "Could not checkout $switch_to"
 msgstr ""
 
-#: git-rebase--interactive.sh:879
+#: git-rebase--preserve-merges.sh:907
 msgid "No HEAD?"
 msgstr ""
 
-#: git-rebase--interactive.sh:880
+#: git-rebase--preserve-merges.sh:908
 #, sh-format
 msgid "Could not create temporary $state_dir"
 msgstr ""
 
-#: git-rebase--interactive.sh:883
+#: git-rebase--preserve-merges.sh:911
 msgid "Could not mark as interactive"
 msgstr ""
 
-#: git-rebase--interactive.sh:915
+#: git-rebase--preserve-merges.sh:943
 #, sh-format
 msgid "Rebase $shortrevisions onto $shortonto ($todocount command)"
 msgid_plural "Rebase $shortrevisions onto $shortonto ($todocount commands)"
 msgstr[0] ""
 msgstr[1] ""
 
-#: git-rebase--interactive.sh:920
-msgid ""
-"\n"
-"\tHowever, if you remove everything, the rebase will be aborted.\n"
-"\n"
-"\t"
-msgstr ""
-
-#: git-rebase--interactive.sh:927
-msgid "Note that empty commits are commented out"
-msgstr ""
-
-#: git-rebase--interactive.sh:980
-msgid "Could not generate todo list"
-msgstr ""
-
-#: git-rebase--interactive.sh:1001 git-rebase--interactive.sh:1006
+#: git-rebase--preserve-merges.sh:997 git-rebase--preserve-merges.sh:1002
 msgid "Could not init rewritten commits"
 msgstr ""
 
@@ -16148,173 +21934,109 @@ msgstr ""
 msgid "usage: $dashless $USAGE"
 msgstr ""
 
-#: git-sh-setup.sh:190
+#: git-sh-setup.sh:191
 #, sh-format
 msgid "Cannot chdir to $cdup, the toplevel of the working tree"
 msgstr ""
 
-#: git-sh-setup.sh:199 git-sh-setup.sh:206
+#: git-sh-setup.sh:200 git-sh-setup.sh:207
 #, sh-format
 msgid "fatal: $program_name cannot be used without a working tree."
 msgstr ""
 
-#: git-sh-setup.sh:220
+#: git-sh-setup.sh:221
 msgid "Cannot rebase: You have unstaged changes."
 msgstr ""
 
-#: git-sh-setup.sh:223
+#: git-sh-setup.sh:224
 msgid "Cannot rewrite branches: You have unstaged changes."
 msgstr ""
 
-#: git-sh-setup.sh:226
+#: git-sh-setup.sh:227
 msgid "Cannot pull with rebase: You have unstaged changes."
 msgstr ""
 
-#: git-sh-setup.sh:229
+#: git-sh-setup.sh:230
 #, sh-format
 msgid "Cannot $action: You have unstaged changes."
 msgstr ""
 
-#: git-sh-setup.sh:242
+#: git-sh-setup.sh:243
 msgid "Cannot rebase: Your index contains uncommitted changes."
 msgstr ""
 
-#: git-sh-setup.sh:245
+#: git-sh-setup.sh:246
 msgid "Cannot pull with rebase: Your index contains uncommitted changes."
 msgstr ""
 
-#: git-sh-setup.sh:248
+#: git-sh-setup.sh:249
 #, sh-format
 msgid "Cannot $action: Your index contains uncommitted changes."
 msgstr ""
 
-#: git-sh-setup.sh:252
+#: git-sh-setup.sh:253
 msgid "Additionally, your index contains uncommitted changes."
 msgstr ""
 
-#: git-sh-setup.sh:372
+#: git-sh-setup.sh:373
 msgid "You need to run this command from the toplevel of the working tree."
 msgstr ""
 
-#: git-sh-setup.sh:377
+#: git-sh-setup.sh:378
 msgid "Unable to determine absolute path of git directory"
 msgstr ""
 
 #. TRANSLATORS: you can adjust this to align "git add -i" status menu
-#: git-add--interactive.perl:196
+#: git-add--interactive.perl:212
 #, perl-format
 msgid "%12s %12s %s"
 msgstr ""
 
-#: git-add--interactive.perl:197
-msgid "staged"
-msgstr ""
-
-#: git-add--interactive.perl:197
-msgid "unstaged"
-msgstr ""
-
-#: git-add--interactive.perl:253 git-add--interactive.perl:278
-msgid "binary"
-msgstr ""
-
-#: git-add--interactive.perl:262 git-add--interactive.perl:316
-msgid "nothing"
-msgstr ""
-
-#: git-add--interactive.perl:298 git-add--interactive.perl:313
-msgid "unchanged"
-msgstr ""
-
-#: git-add--interactive.perl:609
-#, perl-format
-msgid "added %d path\n"
-msgid_plural "added %d paths\n"
-msgstr[0] ""
-msgstr[1] ""
-
-#: git-add--interactive.perl:612
-#, perl-format
-msgid "updated %d path\n"
-msgid_plural "updated %d paths\n"
-msgstr[0] ""
-msgstr[1] ""
-
-#: git-add--interactive.perl:615
-#, perl-format
-msgid "reverted %d path\n"
-msgid_plural "reverted %d paths\n"
-msgstr[0] ""
-msgstr[1] ""
-
-#: git-add--interactive.perl:618
+#: git-add--interactive.perl:634
 #, perl-format
 msgid "touched %d path\n"
 msgid_plural "touched %d paths\n"
 msgstr[0] ""
 msgstr[1] ""
 
-#: git-add--interactive.perl:627
-msgid "Update"
-msgstr ""
-
-#: git-add--interactive.perl:639
-msgid "Revert"
-msgstr ""
-
-#: git-add--interactive.perl:662
-#, perl-format
-msgid "note: %s is untracked now.\n"
-msgstr ""
-
-#: git-add--interactive.perl:673
-msgid "Add untracked"
-msgstr ""
-
-#: git-add--interactive.perl:679
-msgid "No untracked files.\n"
-msgstr ""
-
-#: git-add--interactive.perl:1033
+#: git-add--interactive.perl:1053
 msgid ""
 "If the patch applies cleanly, the edited hunk will immediately be\n"
 "marked for staging."
 msgstr ""
 
-#: git-add--interactive.perl:1036
+#: git-add--interactive.perl:1056
 msgid ""
 "If the patch applies cleanly, the edited hunk will immediately be\n"
 "marked for stashing."
 msgstr ""
 
-#: git-add--interactive.perl:1039
+#: git-add--interactive.perl:1059
 msgid ""
 "If the patch applies cleanly, the edited hunk will immediately be\n"
 "marked for unstaging."
 msgstr ""
 
-#: git-add--interactive.perl:1042 git-add--interactive.perl:1051
+#: git-add--interactive.perl:1062 git-add--interactive.perl:1071
+#: git-add--interactive.perl:1077
 msgid ""
 "If the patch applies cleanly, the edited hunk will immediately be\n"
 "marked for applying."
 msgstr ""
 
-#: git-add--interactive.perl:1045 git-add--interactive.perl:1048
+#: git-add--interactive.perl:1065 git-add--interactive.perl:1068
+#: git-add--interactive.perl:1074
 msgid ""
 "If the patch applies cleanly, the edited hunk will immediately be\n"
 "marked for discarding."
 msgstr ""
 
-#: git-add--interactive.perl:1085
+#: git-add--interactive.perl:1111
 #, perl-format
 msgid "failed to open hunk edit file for writing: %s"
 msgstr ""
 
-#: git-add--interactive.perl:1086
-msgid "Manual hunk edit mode -- see bottom for a quick guide.\n"
-msgstr ""
-
-#: git-add--interactive.perl:1092
+#: git-add--interactive.perl:1118
 #, perl-format
 msgid ""
 "---\n"
@@ -16323,31 +22045,12 @@ msgid ""
 "Lines starting with %s will be removed.\n"
 msgstr ""
 
-#. TRANSLATORS: 'it' refers to the patch mentioned in the previous messages.
-#: git-add--interactive.perl:1100
-msgid ""
-"If it does not apply cleanly, you will be given an opportunity to\n"
-"edit again.  If all lines of the hunk are removed, then the edit is\n"
-"aborted and the hunk is left unchanged.\n"
-msgstr ""
-
-#: git-add--interactive.perl:1114
+#: git-add--interactive.perl:1140
 #, perl-format
 msgid "failed to open hunk edit file for reading: %s"
 msgstr ""
 
-#. TRANSLATORS: do not translate [y/n]
-#. The program will only accept that input
-#. at this point.
-#. Consider translating (saying "no" discards!) as
-#. (saying "n" for "no" discards!) if the translation
-#. of the word "no" does not start with n.
-#: git-add--interactive.perl:1213
-msgid ""
-"Your edited hunk does not apply. Edit again (saying \"no\" discards!) [y/n]? "
-msgstr ""
-
-#: git-add--interactive.perl:1222
+#: git-add--interactive.perl:1248
 msgid ""
 "y - stage this hunk\n"
 "n - do not stage this hunk\n"
@@ -16356,7 +22059,7 @@ msgid ""
 "d - do not stage this hunk or any of the later hunks in the file"
 msgstr ""
 
-#: git-add--interactive.perl:1228
+#: git-add--interactive.perl:1254
 msgid ""
 "y - stash this hunk\n"
 "n - do not stash this hunk\n"
@@ -16365,7 +22068,7 @@ msgid ""
 "d - do not stash this hunk or any of the later hunks in the file"
 msgstr ""
 
-#: git-add--interactive.perl:1234
+#: git-add--interactive.perl:1260
 msgid ""
 "y - unstage this hunk\n"
 "n - do not unstage this hunk\n"
@@ -16374,7 +22077,7 @@ msgid ""
 "d - do not unstage this hunk or any of the later hunks in the file"
 msgstr ""
 
-#: git-add--interactive.perl:1240
+#: git-add--interactive.perl:1266
 msgid ""
 "y - apply this hunk to index\n"
 "n - do not apply this hunk to index\n"
@@ -16383,7 +22086,7 @@ msgid ""
 "d - do not apply this hunk or any of the later hunks in the file"
 msgstr ""
 
-#: git-add--interactive.perl:1246
+#: git-add--interactive.perl:1272 git-add--interactive.perl:1290
 msgid ""
 "y - discard this hunk from worktree\n"
 "n - do not discard this hunk from worktree\n"
@@ -16392,7 +22095,7 @@ msgid ""
 "d - do not discard this hunk or any of the later hunks in the file"
 msgstr ""
 
-#: git-add--interactive.perl:1252
+#: git-add--interactive.perl:1278
 msgid ""
 "y - discard this hunk from index and worktree\n"
 "n - do not discard this hunk from index and worktree\n"
@@ -16401,7 +22104,7 @@ msgid ""
 "d - do not discard this hunk or any of the later hunks in the file"
 msgstr ""
 
-#: git-add--interactive.perl:1258
+#: git-add--interactive.perl:1284
 msgid ""
 "y - apply this hunk to index and worktree\n"
 "n - do not apply this hunk to index and worktree\n"
@@ -16410,7 +22113,16 @@ msgid ""
 "d - do not apply this hunk or any of the later hunks in the file"
 msgstr ""
 
-#: git-add--interactive.perl:1273
+#: git-add--interactive.perl:1296
+msgid ""
+"y - apply this hunk to worktree\n"
+"n - do not apply this hunk to worktree\n"
+"q - quit; do not apply this hunk or any of the remaining ones\n"
+"a - apply this hunk and all later hunks in the file\n"
+"d - do not apply this hunk or any of the later hunks in the file"
+msgstr ""
+
+#: git-add--interactive.perl:1311
 msgid ""
 "g - select a hunk to go to\n"
 "/ - search for a hunk matching the given regex\n"
@@ -16423,211 +22135,198 @@ msgid ""
 "? - print help\n"
 msgstr ""
 
-#: git-add--interactive.perl:1304
+#: git-add--interactive.perl:1342
 msgid "The selected hunks do not apply to the index!\n"
 msgstr ""
 
-#: git-add--interactive.perl:1305
+#: git-add--interactive.perl:1343
 msgid "Apply them to the worktree anyway? "
 msgstr ""
 
-#: git-add--interactive.perl:1308
+#: git-add--interactive.perl:1346
 msgid "Nothing was applied.\n"
 msgstr ""
 
-#: git-add--interactive.perl:1319
+#: git-add--interactive.perl:1357
 #, perl-format
 msgid "ignoring unmerged: %s\n"
 msgstr ""
 
-#: git-add--interactive.perl:1328
-msgid "Only binary files changed.\n"
-msgstr ""
-
-#: git-add--interactive.perl:1330
-msgid "No changes.\n"
-msgstr ""
-
-#: git-add--interactive.perl:1338
-msgid "Patch update"
-msgstr ""
-
-#: git-add--interactive.perl:1390
+#: git-add--interactive.perl:1428
 #, perl-format
 msgid "Stage mode change [y,n,q,a,d%s,?]? "
 msgstr ""
 
-#: git-add--interactive.perl:1391
+#: git-add--interactive.perl:1429
 #, perl-format
 msgid "Stage deletion [y,n,q,a,d%s,?]? "
 msgstr ""
 
-#: git-add--interactive.perl:1392
+#: git-add--interactive.perl:1430
 #, perl-format
 msgid "Stage this hunk [y,n,q,a,d%s,?]? "
 msgstr ""
 
-#: git-add--interactive.perl:1395
+#: git-add--interactive.perl:1433
 #, perl-format
 msgid "Stash mode change [y,n,q,a,d%s,?]? "
 msgstr ""
 
-#: git-add--interactive.perl:1396
+#: git-add--interactive.perl:1434
 #, perl-format
 msgid "Stash deletion [y,n,q,a,d%s,?]? "
 msgstr ""
 
-#: git-add--interactive.perl:1397
+#: git-add--interactive.perl:1435
 #, perl-format
 msgid "Stash this hunk [y,n,q,a,d%s,?]? "
 msgstr ""
 
-#: git-add--interactive.perl:1400
+#: git-add--interactive.perl:1438
 #, perl-format
 msgid "Unstage mode change [y,n,q,a,d%s,?]? "
 msgstr ""
 
-#: git-add--interactive.perl:1401
+#: git-add--interactive.perl:1439
 #, perl-format
 msgid "Unstage deletion [y,n,q,a,d%s,?]? "
 msgstr ""
 
-#: git-add--interactive.perl:1402
+#: git-add--interactive.perl:1440
 #, perl-format
 msgid "Unstage this hunk [y,n,q,a,d%s,?]? "
 msgstr ""
 
-#: git-add--interactive.perl:1405
+#: git-add--interactive.perl:1443
 #, perl-format
 msgid "Apply mode change to index [y,n,q,a,d%s,?]? "
 msgstr ""
 
-#: git-add--interactive.perl:1406
+#: git-add--interactive.perl:1444
 #, perl-format
 msgid "Apply deletion to index [y,n,q,a,d%s,?]? "
 msgstr ""
 
-#: git-add--interactive.perl:1407
+#: git-add--interactive.perl:1445
 #, perl-format
 msgid "Apply this hunk to index [y,n,q,a,d%s,?]? "
 msgstr ""
 
-#: git-add--interactive.perl:1410
+#: git-add--interactive.perl:1448 git-add--interactive.perl:1463
 #, perl-format
 msgid "Discard mode change from worktree [y,n,q,a,d%s,?]? "
 msgstr ""
 
-#: git-add--interactive.perl:1411
+#: git-add--interactive.perl:1449 git-add--interactive.perl:1464
 #, perl-format
 msgid "Discard deletion from worktree [y,n,q,a,d%s,?]? "
 msgstr ""
 
-#: git-add--interactive.perl:1412
+#: git-add--interactive.perl:1450 git-add--interactive.perl:1465
 #, perl-format
 msgid "Discard this hunk from worktree [y,n,q,a,d%s,?]? "
 msgstr ""
 
-#: git-add--interactive.perl:1415
+#: git-add--interactive.perl:1453
 #, perl-format
 msgid "Discard mode change from index and worktree [y,n,q,a,d%s,?]? "
 msgstr ""
 
-#: git-add--interactive.perl:1416
+#: git-add--interactive.perl:1454
 #, perl-format
 msgid "Discard deletion from index and worktree [y,n,q,a,d%s,?]? "
 msgstr ""
 
-#: git-add--interactive.perl:1417
+#: git-add--interactive.perl:1455
 #, perl-format
 msgid "Discard this hunk from index and worktree [y,n,q,a,d%s,?]? "
 msgstr ""
 
-#: git-add--interactive.perl:1420
+#: git-add--interactive.perl:1458
 #, perl-format
 msgid "Apply mode change to index and worktree [y,n,q,a,d%s,?]? "
 msgstr ""
 
-#: git-add--interactive.perl:1421
+#: git-add--interactive.perl:1459
 #, perl-format
 msgid "Apply deletion to index and worktree [y,n,q,a,d%s,?]? "
 msgstr ""
 
-#: git-add--interactive.perl:1422
+#: git-add--interactive.perl:1460
 #, perl-format
 msgid "Apply this hunk to index and worktree [y,n,q,a,d%s,?]? "
 msgstr ""
 
-#: git-add--interactive.perl:1522
-msgid "No other hunks to goto\n"
+#: git-add--interactive.perl:1468
+#, perl-format
+msgid "Apply mode change to worktree [y,n,q,a,d%s,?]? "
 msgstr ""
 
-#: git-add--interactive.perl:1529
-msgid "go to which hunk (<ret> to see more)? "
+#: git-add--interactive.perl:1469
+#, perl-format
+msgid "Apply deletion to worktree [y,n,q,a,d%s,?]? "
 msgstr ""
 
-#: git-add--interactive.perl:1531
-msgid "go to which hunk? "
+#: git-add--interactive.perl:1470
+#, perl-format
+msgid "Apply this hunk to worktree [y,n,q,a,d%s,?]? "
+msgstr ""
+
+#: git-add--interactive.perl:1570
+msgid "No other hunks to goto\n"
 msgstr ""
 
-#: git-add--interactive.perl:1540
+#: git-add--interactive.perl:1588
 #, perl-format
 msgid "Invalid number: '%s'\n"
 msgstr ""
 
-#: git-add--interactive.perl:1545
+#: git-add--interactive.perl:1593
 #, perl-format
 msgid "Sorry, only %d hunk available.\n"
 msgid_plural "Sorry, only %d hunks available.\n"
 msgstr[0] ""
 msgstr[1] ""
 
-#: git-add--interactive.perl:1571
+#: git-add--interactive.perl:1619
 msgid "No other hunks to search\n"
 msgstr ""
 
-#: git-add--interactive.perl:1575
-msgid "search for regex? "
-msgstr ""
-
-#: git-add--interactive.perl:1588
+#: git-add--interactive.perl:1636
 #, perl-format
 msgid "Malformed search regexp %s: %s\n"
 msgstr ""
 
-#: git-add--interactive.perl:1598
+#: git-add--interactive.perl:1646
 msgid "No hunk matches the given pattern\n"
 msgstr ""
 
-#: git-add--interactive.perl:1610 git-add--interactive.perl:1632
+#: git-add--interactive.perl:1658 git-add--interactive.perl:1680
 msgid "No previous hunk\n"
 msgstr ""
 
-#: git-add--interactive.perl:1619 git-add--interactive.perl:1638
+#: git-add--interactive.perl:1667 git-add--interactive.perl:1686
 msgid "No next hunk\n"
 msgstr ""
 
-#: git-add--interactive.perl:1644
+#: git-add--interactive.perl:1692
 msgid "Sorry, cannot split this hunk\n"
 msgstr ""
 
-#: git-add--interactive.perl:1650
+#: git-add--interactive.perl:1698
 #, perl-format
 msgid "Split into %d hunk.\n"
 msgid_plural "Split into %d hunks.\n"
 msgstr[0] ""
 msgstr[1] ""
 
-#: git-add--interactive.perl:1660
+#: git-add--interactive.perl:1708
 msgid "Sorry, cannot edit this hunk\n"
 msgstr ""
 
-#: git-add--interactive.perl:1706
-msgid "Review diff"
-msgstr ""
-
 #. TRANSLATORS: please do not translate the command names
 #. 'status', 'update', 'revert', etc.
-#: git-add--interactive.perl:1725
+#: git-add--interactive.perl:1773
 msgid ""
 "status        - show paths with changes\n"
 "update        - add working tree state to the staged set of changes\n"
@@ -16638,90 +22337,91 @@ msgid ""
 "changes\n"
 msgstr ""
 
-#: git-add--interactive.perl:1742 git-add--interactive.perl:1747
-#: git-add--interactive.perl:1750 git-add--interactive.perl:1757
-#: git-add--interactive.perl:1761 git-add--interactive.perl:1767
+#: git-add--interactive.perl:1790 git-add--interactive.perl:1795
+#: git-add--interactive.perl:1798 git-add--interactive.perl:1805
+#: git-add--interactive.perl:1808 git-add--interactive.perl:1815
+#: git-add--interactive.perl:1819 git-add--interactive.perl:1825
 msgid "missing --"
 msgstr ""
 
-#: git-add--interactive.perl:1763
+#: git-add--interactive.perl:1821
 #, perl-format
 msgid "unknown --patch mode: %s"
 msgstr ""
 
-#: git-add--interactive.perl:1769 git-add--interactive.perl:1775
+#: git-add--interactive.perl:1827 git-add--interactive.perl:1833
 #, perl-format
 msgid "invalid argument %s, expecting --"
 msgstr ""
 
-#: git-send-email.perl:130
+#: git-send-email.perl:138
 msgid "local zone differs from GMT by a non-minute interval\n"
 msgstr ""
 
-#: git-send-email.perl:137 git-send-email.perl:143
+#: git-send-email.perl:145 git-send-email.perl:151
 msgid "local time offset greater than or equal to 24 hours\n"
 msgstr ""
 
-#: git-send-email.perl:211 git-send-email.perl:217
+#: git-send-email.perl:223 git-send-email.perl:229
 msgid "the editor exited uncleanly, aborting everything"
 msgstr ""
 
-#: git-send-email.perl:294
+#: git-send-email.perl:310
 #, perl-format
 msgid ""
 "'%s' contains an intermediate version of the email you were composing.\n"
 msgstr ""
 
-#: git-send-email.perl:299
+#: git-send-email.perl:315
 #, perl-format
 msgid "'%s.final' contains the composed email.\n"
 msgstr ""
 
-#: git-send-email.perl:317
+#: git-send-email.perl:408
 msgid "--dump-aliases incompatible with other options\n"
 msgstr ""
 
-#: git-send-email.perl:383 git-send-email.perl:638
+#: git-send-email.perl:481 git-send-email.perl:683
 msgid "Cannot run git format-patch from outside a repository\n"
 msgstr ""
 
-#: git-send-email.perl:386
+#: git-send-email.perl:484
 msgid ""
 "`batch-size` and `relogin` must be specified together (via command-line or "
 "configuration option)\n"
 msgstr ""
 
-#: git-send-email.perl:456
+#: git-send-email.perl:497
 #, perl-format
 msgid "Unknown --suppress-cc field: '%s'\n"
 msgstr ""
 
-#: git-send-email.perl:485
+#: git-send-email.perl:528
 #, perl-format
 msgid "Unknown --confirm setting: '%s'\n"
 msgstr ""
 
-#: git-send-email.perl:513
+#: git-send-email.perl:556
 #, perl-format
 msgid "warning: sendmail alias with quotes is not supported: %s\n"
 msgstr ""
 
-#: git-send-email.perl:515
+#: git-send-email.perl:558
 #, perl-format
 msgid "warning: `:include:` not supported: %s\n"
 msgstr ""
 
-#: git-send-email.perl:517
+#: git-send-email.perl:560
 #, perl-format
 msgid "warning: `/file` or `|pipe` redirection not supported: %s\n"
 msgstr ""
 
-#: git-send-email.perl:522
+#: git-send-email.perl:565
 #, perl-format
 msgid "warning: sendmail line is not recognized: %s\n"
 msgstr ""
 
-#: git-send-email.perl:604
+#: git-send-email.perl:649
 #, perl-format
 msgid ""
 "File '%s' exists but it could also be the range of commits\n"
@@ -16731,36 +22431,36 @@ msgid ""
 "    * Giving --format-patch option if you mean a range.\n"
 msgstr ""
 
-#: git-send-email.perl:625
+#: git-send-email.perl:670
 #, perl-format
 msgid "Failed to opendir %s: %s"
 msgstr ""
 
-#: git-send-email.perl:649
+#: git-send-email.perl:694
 #, perl-format
 msgid ""
 "fatal: %s: %s\n"
 "warning: no patches were sent\n"
 msgstr ""
 
-#: git-send-email.perl:660
+#: git-send-email.perl:705
 msgid ""
 "\n"
 "No patch files specified!\n"
 "\n"
 msgstr ""
 
-#: git-send-email.perl:673
+#: git-send-email.perl:718
 #, perl-format
 msgid "No subject line in %s?"
 msgstr ""
 
-#: git-send-email.perl:683
+#: git-send-email.perl:728
 #, perl-format
 msgid "Failed to open for writing %s: %s"
 msgstr ""
 
-#: git-send-email.perl:694
+#: git-send-email.perl:739
 msgid ""
 "Lines beginning in \"GIT:\" will be removed.\n"
 "Consider including an overall diffstat or table of contents\n"
@@ -16769,37 +22469,37 @@ msgid ""
 "Clear the body content if you don't wish to send a summary.\n"
 msgstr ""
 
-#: git-send-email.perl:718
+#: git-send-email.perl:763
 #, perl-format
 msgid "Failed to open %s: %s"
 msgstr ""
 
-#: git-send-email.perl:735
+#: git-send-email.perl:780
 #, perl-format
 msgid "Failed to open %s.final: %s"
 msgstr ""
 
-#: git-send-email.perl:778
+#: git-send-email.perl:823
 msgid "Summary email is empty, skipping it\n"
 msgstr ""
 
 #. TRANSLATORS: please keep [y/N] as is.
-#: git-send-email.perl:813
+#: git-send-email.perl:858
 #, perl-format
 msgid "Are you sure you want to use <%s> [y/N]? "
 msgstr ""
 
-#: git-send-email.perl:868
+#: git-send-email.perl:913
 msgid ""
 "The following files are 8bit, but do not declare a Content-Transfer-"
 "Encoding.\n"
 msgstr ""
 
-#: git-send-email.perl:873
+#: git-send-email.perl:918
 msgid "Which 8bit encoding should I declare [UTF-8]? "
 msgstr ""
 
-#: git-send-email.perl:881
+#: git-send-email.perl:926
 #, perl-format
 msgid ""
 "Refusing to send because the patch\n"
@@ -16808,20 +22508,20 @@ msgid ""
 "want to send.\n"
 msgstr ""
 
-#: git-send-email.perl:900
+#: git-send-email.perl:945
 msgid "To whom should the emails be sent (if anyone)?"
 msgstr ""
 
-#: git-send-email.perl:918
+#: git-send-email.perl:963
 #, perl-format
 msgid "fatal: alias '%s' expands to itself\n"
 msgstr ""
 
-#: git-send-email.perl:930
+#: git-send-email.perl:975
 msgid "Message-ID to be used as In-Reply-To for the first email (if any)? "
 msgstr ""
 
-#: git-send-email.perl:988 git-send-email.perl:996
+#: git-send-email.perl:1033 git-send-email.perl:1041
 #, perl-format
 msgid "error: unable to extract a valid address from: %s\n"
 msgstr ""
@@ -16829,16 +22529,16 @@ msgstr ""
 #. TRANSLATORS: Make sure to include [q] [d] [e] in your
 #. translation. The program will only accept English input
 #. at this point.
-#: git-send-email.perl:1000
+#: git-send-email.perl:1045
 msgid "What to do with this address? ([q]uit|[d]rop|[e]dit): "
 msgstr ""
 
-#: git-send-email.perl:1317
+#: git-send-email.perl:1362
 #, perl-format
 msgid "CA path \"%s\" does not exist"
 msgstr ""
 
-#: git-send-email.perl:1400
+#: git-send-email.perl:1445
 msgid ""
 "    The Cc list above has been expanded by additional\n"
 "    addresses found in the patch commit message. By default\n"
@@ -16855,128 +22555,128 @@ msgstr ""
 #. TRANSLATORS: Make sure to include [y] [n] [e] [q] [a] in your
 #. translation. The program will only accept English input
 #. at this point.
-#: git-send-email.perl:1415
+#: git-send-email.perl:1460
 msgid "Send this email? ([y]es|[n]o|[e]dit|[q]uit|[a]ll): "
 msgstr ""
 
-#: git-send-email.perl:1418
+#: git-send-email.perl:1463
 msgid "Send this email reply required"
 msgstr ""
 
-#: git-send-email.perl:1446
+#: git-send-email.perl:1491
 msgid "The required SMTP server is not properly defined."
 msgstr ""
 
-#: git-send-email.perl:1493
+#: git-send-email.perl:1538
 #, perl-format
 msgid "Server does not support STARTTLS! %s"
 msgstr ""
 
-#: git-send-email.perl:1498 git-send-email.perl:1502
+#: git-send-email.perl:1543 git-send-email.perl:1547
 #, perl-format
 msgid "STARTTLS failed! %s"
 msgstr ""
 
-#: git-send-email.perl:1512
+#: git-send-email.perl:1556
 msgid "Unable to initialize SMTP properly. Check config and use --smtp-debug."
 msgstr ""
 
-#: git-send-email.perl:1530
+#: git-send-email.perl:1574
 #, perl-format
 msgid "Failed to send %s\n"
 msgstr ""
 
-#: git-send-email.perl:1533
+#: git-send-email.perl:1577
 #, perl-format
 msgid "Dry-Sent %s\n"
 msgstr ""
 
-#: git-send-email.perl:1533
+#: git-send-email.perl:1577
 #, perl-format
 msgid "Sent %s\n"
 msgstr ""
 
-#: git-send-email.perl:1535
+#: git-send-email.perl:1579
 msgid "Dry-OK. Log says:\n"
 msgstr ""
 
-#: git-send-email.perl:1535
+#: git-send-email.perl:1579
 msgid "OK. Log says:\n"
 msgstr ""
 
-#: git-send-email.perl:1547
+#: git-send-email.perl:1591
 msgid "Result: "
 msgstr ""
 
-#: git-send-email.perl:1550
+#: git-send-email.perl:1594
 msgid "Result: OK\n"
 msgstr ""
 
-#: git-send-email.perl:1568
+#: git-send-email.perl:1612
 #, perl-format
 msgid "can't open file %s"
 msgstr ""
 
-#: git-send-email.perl:1615 git-send-email.perl:1635
+#: git-send-email.perl:1659 git-send-email.perl:1679
 #, perl-format
 msgid "(mbox) Adding cc: %s from line '%s'\n"
 msgstr ""
 
-#: git-send-email.perl:1621
+#: git-send-email.perl:1665
 #, perl-format
 msgid "(mbox) Adding to: %s from line '%s'\n"
 msgstr ""
 
-#: git-send-email.perl:1674
+#: git-send-email.perl:1718
 #, perl-format
 msgid "(non-mbox) Adding cc: %s from line '%s'\n"
 msgstr ""
 
-#: git-send-email.perl:1699
+#: git-send-email.perl:1753
 #, perl-format
 msgid "(body) Adding cc: %s from line '%s'\n"
 msgstr ""
 
-#: git-send-email.perl:1817
+#: git-send-email.perl:1864
 #, perl-format
 msgid "(%s) Could not execute '%s'"
 msgstr ""
 
-#: git-send-email.perl:1824
+#: git-send-email.perl:1871
 #, perl-format
 msgid "(%s) Adding %s: %s from: '%s'\n"
 msgstr ""
 
-#: git-send-email.perl:1828
+#: git-send-email.perl:1875
 #, perl-format
 msgid "(%s) failed to close pipe to '%s'"
 msgstr ""
 
-#: git-send-email.perl:1855
+#: git-send-email.perl:1905
 msgid "cannot send message as 7bit"
 msgstr ""
 
-#: git-send-email.perl:1863
+#: git-send-email.perl:1913
 msgid "invalid transfer encoding"
 msgstr ""
 
-#: git-send-email.perl:1901 git-send-email.perl:1952 git-send-email.perl:1962
+#: git-send-email.perl:1954 git-send-email.perl:2006 git-send-email.perl:2016
 #, perl-format
 msgid "unable to open %s: %s\n"
 msgstr ""
 
-#: git-send-email.perl:1904
+#: git-send-email.perl:1957
 #, perl-format
 msgid "%s: patch contains a line longer than 998 characters"
 msgstr ""
 
-#: git-send-email.perl:1920
+#: git-send-email.perl:1974
 #, perl-format
 msgid "Skipping %s with backup suffix '%s'.\n"
 msgstr ""
 
 #. TRANSLATORS: please keep "[y|N]" as is.
-#: git-send-email.perl:1924
+#: git-send-email.perl:1978
 #, perl-format
 msgid "Do you really want to send %s? [y|N]: "
 msgstr ""
diff -pruN 1.2.1+git2.18.0-1/git/po/it.po 1.2.3+git2.25.1-1/git/po/it.po
--- 1.2.1+git2.18.0-1/git/po/it.po	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/po/it.po	2020-02-17 04:47:35.000000000 +0000
@@ -1,5362 +1,25118 @@
 # Italian translations for Git.
 # Copyright (C) 2012 Marco Paolone <marcopaolone@gmail.com>
+# Copyright © 2018-2019 Alessandro Menti <alessandro.menti@alessandromenti.it>
 # This file is distributed under the same license as the Git package.
+#
+# Thanks to the former translators, Marco Paolone <marcopaolone AT gmail.com>
+# and Stefano Lattarini <stefano.lattarini AT gmail.com>, for their
+# contributions.
+# Alessandro Menti <alessandro.menti@alessandromenti.it>, 2019.
 msgid ""
 msgstr ""
 "Project-Id-Version: Git\n"
 "Report-Msgid-Bugs-To: Git Mailing List <git@vger.kernel.org>\n"
-"POT-Creation-Date: 2012-06-08 10:20+0800\n"
-"PO-Revision-Date: 2012-06-14 14:13+0200\n"
-"Last-Translator: Marco Paolone <marcopaolone@gmail.com>\n"
-"Language-Team: Italian\n"
+"POT-Creation-Date: 2019-12-30 08:48+0800\n"
+"PO-Revision-Date: 2019-12-30 09:23+0100\n"
+"Last-Translator: Alessandro Menti <alessandro.menti@alessandromenti.it>\n"
+"Language-Team: Italian <>\n"
 "Language: it\n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
 "Plural-Forms: nplurals=2; plural=(n != 1);\n"
+"X-Generator: Lokalize 19.12.0\n"
 
-#: advice.c:40
+#: add-interactive.c:347
 #, c-format
-msgid "hint: %.*s\n"
-msgstr "suggerimento: %.*s\n"
+msgid "Huh (%s)?"
+msgstr "Eh (%s)?"
 
-#.
-#. * Message used both when 'git commit' fails and when
-#. * other commands doing a merge do.
-#.
-#: advice.c:70
-msgid ""
-"Fix them up in the work tree,\n"
-"and then use 'git add/rm <file>' as\n"
-"appropriate to mark resolution and make a commit,\n"
-"or use 'git commit -a'."
-msgstr ""
+#: add-interactive.c:500 add-interactive.c:801 sequencer.c:3216
+#: sequencer.c:3656 builtin/rebase.c:871 builtin/rebase.c:1643
+#: builtin/rebase.c:2019 builtin/rebase.c:2063
+msgid "could not read index"
+msgstr "impossibile leggere l'indice"
+
+#: add-interactive.c:555 git-add--interactive.perl:269
+#: git-add--interactive.perl:294
+msgid "binary"
+msgstr "binario"
+
+#: add-interactive.c:613 git-add--interactive.perl:278
+#: git-add--interactive.perl:332
+msgid "nothing"
+msgstr "non fare nulla"
+
+#: add-interactive.c:614 git-add--interactive.perl:314
+#: git-add--interactive.perl:329
+msgid "unchanged"
+msgstr "non modificato"
+
+#: add-interactive.c:651 git-add--interactive.perl:643
+msgid "Update"
+msgstr "Aggiorna"
+
+#: add-interactive.c:668 add-interactive.c:856
+#, c-format
+msgid "could not stage '%s'"
+msgstr "impossibile aggiungere '%s' all'area di staging"
+
+#: add-interactive.c:674 add-interactive.c:863 sequencer.c:3409
+#: builtin/rebase.c:895
+msgid "could not write index"
+msgstr "impossibile scrivere l'indice"
+
+#: add-interactive.c:677 git-add--interactive.perl:628
+#, c-format, perl-format
+msgid "updated %d path\n"
+msgid_plural "updated %d paths\n"
+msgstr[0] "aggiornato %d percorso\n"
+msgstr[1] "aggiornati %d percorsi\n"
+
+#: add-interactive.c:695 git-add--interactive.perl:678
+#, c-format, perl-format
+msgid "note: %s is untracked now.\n"
+msgstr "nota: %s ora non è tracciato.\n"
 
-#: bundle.c:36
+#: add-interactive.c:700 apply.c:4108 builtin/checkout.c:281
+#: builtin/reset.c:144
 #, c-format
-msgid "'%s' does not look like a v2 bundle file"
-msgstr ""
+msgid "make_cache_entry failed for path '%s'"
+msgstr "make_cache_entry non riuscito per il percorso '%s'"
 
-#: bundle.c:63
-#, c-format
-msgid "unrecognized header: %s%s (%d)"
-msgstr "header non riconosciuto: %s%s (%d)"
+#: add-interactive.c:730 git-add--interactive.perl:655
+msgid "Revert"
+msgstr "Esegui il revert"
+
+#: add-interactive.c:746
+msgid "Could not parse HEAD^{tree}"
+msgstr "Impossibile analizzare HEAD^{tree}"
+
+#: add-interactive.c:784 git-add--interactive.perl:631
+#, c-format, perl-format
+msgid "reverted %d path\n"
+msgid_plural "reverted %d paths\n"
+msgstr[0] "ripristinato %d percorso\n"
+msgstr[1] "ripristinati %d percorsi\n"
 
-#: bundle.c:89 builtin/commit.c:696
+#: add-interactive.c:835 git-add--interactive.perl:695
 #, c-format
-msgid "could not open '%s'"
-msgstr "non è stato possibile aprire '%s'"
+msgid "No untracked files.\n"
+msgstr "Nessun file non tracciato.\n"
 
-#: bundle.c:140
-msgid "Repository lacks these prerequisite commits:"
-msgstr ""
+#: add-interactive.c:839 git-add--interactive.perl:689
+msgid "Add untracked"
+msgstr "Aggiungi file non tracciati"
 
-#: bundle.c:164 sequencer.c:550 sequencer.c:982 builtin/log.c:289
-#: builtin/log.c:720 builtin/log.c:1309 builtin/log.c:1528 builtin/merge.c:347
-#: builtin/shortlog.c:181
-msgid "revision walk setup failed"
-msgstr ""
+#: add-interactive.c:866 git-add--interactive.perl:625
+#, c-format, perl-format
+msgid "added %d path\n"
+msgid_plural "added %d paths\n"
+msgstr[0] "aggiunto %d percorso\n"
+msgstr[1] "aggiunti %d percorsi\n"
 
-#: bundle.c:186
+#: add-interactive.c:896
 #, c-format
-msgid "The bundle contains %d ref"
-msgid_plural "The bundle contains %d refs"
-msgstr[0] ""
-msgstr[1] ""
+msgid "ignoring unmerged: %s"
+msgstr "ignoro ciò che non è stato sottoposto a merge: %s"
 
-#: bundle.c:192
+#: add-interactive.c:908 add-patch.c:1331 git-add--interactive.perl:1366
 #, c-format
-msgid "The bundle requires this ref"
-msgid_plural "The bundle requires these %d refs"
-msgstr[0] ""
-msgstr[1] ""
-
-#: bundle.c:290
-msgid "rev-list died"
-msgstr ""
+msgid "Only binary files changed.\n"
+msgstr "Sono stati modificati solo file binari.\n"
 
-#: bundle.c:296 builtin/log.c:1205 builtin/shortlog.c:284
+#: add-interactive.c:910 add-patch.c:1329 git-add--interactive.perl:1368
 #, c-format
-msgid "unrecognized argument: %s"
-msgstr "argomento non riconosciuto: %s"
+msgid "No changes.\n"
+msgstr "Nessuna modifica.\n"
 
-#: bundle.c:331
-#, c-format
-msgid "ref '%s' is excluded by the rev-list options"
-msgstr "il ref '%s' è escluso dalle opzioni di rev-list"
+#: add-interactive.c:914 git-add--interactive.perl:1376
+msgid "Patch update"
+msgstr "Aggiornamento patch"
 
-#: bundle.c:376
-msgid "Refusing to create empty bundle."
+#: add-interactive.c:953 git-add--interactive.perl:1754
+msgid "Review diff"
+msgstr "Rivedi diff"
+
+#: add-interactive.c:981
+msgid "show paths with changes"
+msgstr "visualizza i percorsi modificati"
+
+#: add-interactive.c:983
+msgid "add working tree state to the staged set of changes"
 msgstr ""
+"aggiungi lo stato dall'albero di lavoro all'insieme delle modifiche nell'area"
+" di staging"
 
-#: bundle.c:394
-msgid "Could not spawn pack-objects"
+#: add-interactive.c:985
+msgid "revert staged set of changes back to the HEAD version"
 msgstr ""
+"ripristina l'insieme delle modifiche nell'area di staging alla versione HEAD"
 
-#: bundle.c:412
-msgid "pack-objects died"
+#: add-interactive.c:987
+msgid "pick hunks and update selectively"
 msgstr ""
+"seleziona gli hunk in modalità interattiva ed esegui l'aggiornamento in modo"
+" selettivo"
 
-#: bundle.c:415
-#, c-format
-msgid "cannot create '%s'"
-msgstr "impossibile creare '%s'"
+#: add-interactive.c:989
+msgid "view diff between HEAD and index"
+msgstr "visualizza il diff fra HEAD e l'indice"
 
-#: bundle.c:437
-msgid "index-pack died"
+#: add-interactive.c:991
+msgid "add contents of untracked files to the staged set of changes"
 msgstr ""
+"aggiungi i contenuti dei file non tracciati all'insieme delle modifiche"
+" nell'area di staging"
 
-#: commit.c:48
-#, c-format
-msgid "could not parse %s"
-msgstr "non è stato possibile analizzare %s"
+#: add-interactive.c:999 add-interactive.c:1048
+msgid "Prompt help:"
+msgstr "Guida prompt:"
 
-#: commit.c:50
-#, c-format
-msgid "%s %s is not a commit!"
-msgstr "%s %s non è un commit!"
+#: add-interactive.c:1001
+msgid "select a single item"
+msgstr "seleziona un singolo elemento"
 
-#: compat/obstack.c:406 compat/obstack.c:408
-msgid "memory exhausted"
-msgstr "memoria esaurita"
+#: add-interactive.c:1003
+msgid "select a range of items"
+msgstr "seleziona un intervallo di elementi"
 
-#: connected.c:39
-msgid "Could not run 'git rev-list'"
-msgstr "Non è stato possibile eseguire 'git-rev-list'"
+#: add-interactive.c:1005
+msgid "select multiple ranges"
+msgstr "seleziona più intervalli"
 
-#: connected.c:48
-#, c-format
-msgid "failed write to rev-list: %s"
-msgstr "scrittura nella rev-list non riuscita: %s"
+#: add-interactive.c:1007 add-interactive.c:1052
+msgid "select item based on unique prefix"
+msgstr "seleziona un elemento basandoti su un prefisso univoco"
 
-#: connected.c:56
-#, c-format
-msgid "failed to close rev-list's stdin: %s"
-msgstr ""
+#: add-interactive.c:1009
+msgid "unselect specified items"
+msgstr "deseleziona gli elementi specificati"
 
-#: date.c:95
-msgid "in the future"
-msgstr "in futuro"
+#: add-interactive.c:1011
+msgid "choose all items"
+msgstr "seleziona tutti gli elementi"
 
-#: date.c:101
-#, c-format
-msgid "%lu second ago"
-msgid_plural "%lu seconds ago"
-msgstr[0] "%lu secondo fa"
-msgstr[1] "%lu secondi fa"
+#: add-interactive.c:1013
+msgid "(empty) finish selecting"
+msgstr "(vuoto) termina la selezione"
 
-#: date.c:108
-#, c-format
-msgid "%lu minute ago"
-msgid_plural "%lu minutes ago"
-msgstr[0] "%lu un minuto fa"
-msgstr[1] "%lu minuti fa"
+#: add-interactive.c:1050
+msgid "select a numbered item"
+msgstr "seleziona un elemento numerato"
 
-#: date.c:115
-#, c-format
-msgid "%lu hour ago"
-msgid_plural "%lu hours ago"
-msgstr[0] "%lu ora fa"
-msgstr[1] "%lu ore fa"
+#: add-interactive.c:1054
+msgid "(empty) select nothing"
+msgstr "(vuoto) non selezionare nulla"
 
-#: date.c:122
-#, c-format
-msgid "%lu day ago"
-msgid_plural "%lu days ago"
-msgstr[0] "%lu giorno fa"
-msgstr[1] "%lu giorni fa"
+#: add-interactive.c:1062 builtin/clean.c:822 git-add--interactive.perl:1851
+msgid "*** Commands ***"
+msgstr "*** Comandi ***"
 
-#: date.c:128
-#, c-format
-msgid "%lu week ago"
-msgid_plural "%lu weeks ago"
-msgstr[0] "%lu settimana fa"
-msgstr[1] "%lu settimane fa"
+#: add-interactive.c:1063 builtin/clean.c:823 git-add--interactive.perl:1848
+msgid "What now"
+msgstr "Cosa faccio ora"
 
-#: date.c:135
-#, c-format
-msgid "%lu month ago"
-msgid_plural "%lu months ago"
-msgstr[0] "%lu mese fa"
-msgstr[1] "%lu mesi fa"
+#: add-interactive.c:1115 git-add--interactive.perl:213
+msgid "staged"
+msgstr "nell'area di staging"
+
+#: add-interactive.c:1115 git-add--interactive.perl:213
+msgid "unstaged"
+msgstr "rimosso dall'area di staging"
+
+#: add-interactive.c:1115 apply.c:4965 apply.c:4968 builtin/am.c:2197
+#: builtin/am.c:2200 builtin/clone.c:123 builtin/fetch.c:144
+#: builtin/merge.c:273 builtin/pull.c:209 builtin/submodule--helper.c:409
+#: builtin/submodule--helper.c:1379 builtin/submodule--helper.c:1382
+#: builtin/submodule--helper.c:1875 builtin/submodule--helper.c:1878
+#: builtin/submodule--helper.c:2119 git-add--interactive.perl:213
+msgid "path"
+msgstr "percorso"
 
-#: date.c:146
+#: add-interactive.c:1122
+msgid "could not refresh index"
+msgstr "impossibile aggiornare l'indice"
+
+#: add-interactive.c:1136 builtin/clean.c:787 git-add--interactive.perl:1765
 #, c-format
-msgid "%lu year"
-msgid_plural "%lu years"
-msgstr[0] "%lu anno"
-msgstr[1] "%lu anni"
+msgid "Bye.\n"
+msgstr "Ciao.\n"
 
-#: date.c:149
+#: add-patch.c:15
 #, c-format
-msgid "%s, %lu month ago"
-msgid_plural "%s, %lu months ago"
-msgstr[0] "%s, %lu mese fa"
-msgstr[1] "%s, %lu mesi fa"
+msgid "Stage mode change [y,n,a,q,d%s,?]? "
+msgstr "Modifica modo stage [y,n,a,q,d%s,?]? "
 
-#: date.c:154 date.c:159
+#: add-patch.c:16
 #, c-format
-msgid "%lu year ago"
-msgid_plural "%lu years ago"
-msgstr[0] "%lu anno fa"
-msgstr[1] "%lu anni fa"
+msgid "Stage deletion [y,n,a,q,d%s,?]? "
+msgstr "Eliminazione stage [y,n,a,q,d%s,?]? "
 
-#: diff.c:105
+#: add-patch.c:17
 #, c-format
-msgid "  Failed to parse dirstat cut-off percentage '%.*s'\n"
-msgstr ""
+msgid "Stage this hunk [y,n,a,q,d%s,?]? "
+msgstr "Eseguire lo stage di quest'hunk [y,n,a,q,d%s,?]? "
 
-#: diff.c:110
+#: add-patch.c:111
 #, c-format
-msgid "  Unknown dirstat parameter '%.*s'\n"
-msgstr "  Parametro dirstat '%.*s' sconosciuto\n"
+msgid "could not parse hunk header '%.*s'"
+msgstr "impossibile analizzare l'header hunk '%.*s'"
 
-#: diff.c:210
+#: add-patch.c:130 add-patch.c:134
 #, c-format
-msgid ""
-"Found errors in 'diff.dirstat' config variable:\n"
-"%s"
-msgstr ""
-"Trovati errori nella variabile di configurazione 'diff.dirstat':\n"
-"%s"
+msgid "could not parse colored hunk header '%.*s'"
+msgstr "impossibile analizzare l'header hunk colorato '%.*s'"
 
-#: diff.c:1400
-msgid " 0 files changed\n"
-msgstr " 0 file modificati\n"
+#: add-patch.c:176
+msgid "could not parse diff"
+msgstr "impossibile analizzare il diff"
 
-#: diff.c:1404
-#, c-format
-msgid " %d file changed"
-msgid_plural " %d files changed"
-msgstr[0] " %d file modificato"
-msgstr[1] " %d file modificati"
+#: add-patch.c:194
+msgid "could not parse colored diff"
+msgstr "impossibile analizzare il diff colorato"
 
-#: diff.c:1421
+#: add-patch.c:508
 #, c-format
-msgid ", %d insertion(+)"
-msgid_plural ", %d insertions(+)"
-msgstr[0] ", %d inserzione(+)"
-msgstr[1] ", %d inserzioni(+)"
+msgid ""
+"expected context line #%d in\n"
+"%.*s"
+msgstr ""
+"attesa riga contesto %d in\n"
+"%.*s"
 
-#: diff.c:1432
+#: add-patch.c:523
 #, c-format
-msgid ", %d deletion(-)"
-msgid_plural ", %d deletions(-)"
-msgstr[0] ". %d rimozione(-)"
-msgstr[1] ", %d rimozioni(-)"
+msgid ""
+"hunks do not overlap:\n"
+"%.*s\n"
+"\tdoes not end with:\n"
+"%.*s"
+msgstr ""
+"gli hunk non si sovrappongono:\n"
+"%.*s\n"
+"\tnon termina con:\n"
+"%.*s"
+
+#: add-patch.c:799 git-add--interactive.perl:1112
+msgid "Manual hunk edit mode -- see bottom for a quick guide.\n"
+msgstr ""
+"Modalità manuale modifica hunt - vedi la fine del file per una guida "
+"veloce.\n"
 
-#: diff.c:3478
+#: add-patch.c:803
 #, c-format
 msgid ""
-"Failed to parse --dirstat/-X option parameter:\n"
-"%s"
+"---\n"
+"To remove '%c' lines, make them ' ' lines (context).\n"
+"To remove '%c' lines, delete them.\n"
+"Lines starting with %c will be removed.\n"
 msgstr ""
-"Analisi del parametro dell'opzione --dirstat/-X non riuscita:\n"
-"%s"
+"---\n"
+"Per rimuovere '%c' righe, rendile righe ' ' (contesto).\n"
+"Per rimuovere '%c' righe, eliminale.\n"
+"Le righe che iniziano con %c saranno rimosse.\n"
 
-#: gpg-interface.c:59
-msgid "could not run gpg."
-msgstr "non è stato possibile eseguire gpg."
-
-#: gpg-interface.c:71
-msgid "gpg did not accept the data"
-msgstr "gpg non ha accettato i dati"
+#: add-patch.c:810
+msgid ""
+"If the patch applies cleanly, the edited hunk will immediately be\n"
+"marked for staging.\n"
+msgstr ""
+"Se la patch viene applicata senza problemi, l'hunk modificato sarà\n"
+"contrassegnato immediatamente per l'aggiunta all'area di staging.\n"
 
-#: gpg-interface.c:82
-msgid "gpg failed to sign the data"
-msgstr "gpg non è riuscito a firmare i dati"
+#. TRANSLATORS: 'it' refers to the patch mentioned in the previous messages.
+#: add-patch.c:818 git-add--interactive.perl:1126
+msgid ""
+"If it does not apply cleanly, you will be given an opportunity to\n"
+"edit again.  If all lines of the hunk are removed, then the edit is\n"
+"aborted and the hunk is left unchanged.\n"
+msgstr ""
+"Se non può essere applicata senza problemi, ti sarà data la possibilità\n"
+"di modificarla di nuovo. Se tutte le righe dell'hunk saranno state\n"
+"rimosse, la modifica sarà interrotta e l'hunk non sarà modificato.\n"
 
-#: grep.c:1320
-#, c-format
-msgid "'%s': unable to read %s"
-msgstr "'%s': impossibile leggere %s"
+#: add-patch.c:851
+msgid "could not parse hunk header"
+msgstr "impossibile analizzare l'header hunk"
 
-#: grep.c:1337
-#, c-format
-msgid "'%s': %s"
-msgstr "'%s': %s"
+#: add-patch.c:895 add-patch.c:1294
+msgid "'git apply --cached' failed"
+msgstr "'git apply --cached' non riuscito"
 
-#: grep.c:1348
-#, c-format
-msgid "'%s': short read %s"
+#. TRANSLATORS: do not translate [y/n]
+#. The program will only accept that input at this point.
+#. Consider translating (saying "no" discards!) as
+#. (saying "n" for "no" discards!) if the translation
+#. of the word "no" does not start with n.
+#.
+#. TRANSLATORS: do not translate [y/n]
+#. The program will only accept that input
+#. at this point.
+#. Consider translating (saying "no" discards!) as
+#. (saying "n" for "no" discards!) if the translation
+#. of the word "no" does not start with n.
+#: add-patch.c:952 git-add--interactive.perl:1239
+msgid ""
+"Your edited hunk does not apply. Edit again (saying \"no\" discards!) [y/n]? "
+msgstr ""
+"L'hunk modificato non può essere applicato senza problemi. Modificarlo di "
+"nuovo (se rispondi \"no\", sarà eliminato!) [y/n]? "
+
+#: add-patch.c:1009
+msgid ""
+"y - stage this hunk\n"
+"n - do not stage this hunk\n"
+"q - quit; do not stage this hunk or any of the remaining ones\n"
+"a - stage this and all the remaining hunks\n"
+"d - do not stage this hunk nor any of the remaining hunks\n"
+msgstr ""
+"y - aggiungi quest'hunk all'area di staging\n"
+"n - non aggiungere quest'hunk all'area di staging\n"
+"q - esci; non aggiungere né quest'hunk né quelli rimanenti all'area di "
+"staging\n"
+"a - aggiungi quest'hunk e tutti quelli successivi nel file all'area di "
+"staging\n"
+"d - non aggiungere né quest'hunk né quelli successivi nel file all'area di "
+"staging\n"
+
+#: add-patch.c:1016
+msgid ""
+"j - leave this hunk undecided, see next undecided hunk\n"
+"J - leave this hunk undecided, see next hunk\n"
+"k - leave this hunk undecided, see previous undecided hunk\n"
+"K - leave this hunk undecided, see previous hunk\n"
+"g - select a hunk to go to\n"
+"/ - search for a hunk matching the given regex\n"
+"s - split the current hunk into smaller hunks\n"
+"e - manually edit the current hunk\n"
+"? - print help\n"
+msgstr ""
+"j - non decidere in merito a quest'hunk, vai al successivo hunk per cui non "
+"è stata presa una decisione\n"
+"J - non decidere in merito a quest'hunk, vai all'hunk successivo\n"
+"k - non decidere in merito a quest'hunk, vai al precedente hunk per cui non "
+"è stata presa una decisione\n"
+"K - non decidere in merito a quest'hunk, vai all'hunk precedente\n"
+"g - seleziona un hunk a cui andare\n"
+"/ - cerca un hunk corrispondente all'espressione regolare data\n"
+"s - suddividi l'hunk corrente in hunk più piccoli\n"
+"e - modifica manualmente l'hunk corrente\n"
+"? - stampa una guida\n"
+
+#: add-patch.c:1137 add-patch.c:1147
+msgid "No previous hunk"
+msgstr "Nessun hunk precedente"
+
+#: add-patch.c:1142 add-patch.c:1152
+msgid "No next hunk"
+msgstr "Nessun hunk successivo"
+
+#: add-patch.c:1158
+msgid "No other hunks to goto"
+msgstr "Nessun altro hunk a cui andare"
+
+#: add-patch.c:1169 git-add--interactive.perl:1577
+msgid "go to which hunk (<ret> to see more)? "
+msgstr "a quale hunk desideri andare (premi <Invio> per vederne altri)? "
+
+#: add-patch.c:1170 git-add--interactive.perl:1579
+msgid "go to which hunk? "
+msgstr "a quale hunk desideri andare? "
+
+#: add-patch.c:1181
+#, c-format
+msgid "Invalid number: '%s'"
+msgstr "Numero non valido: '%s'"
+
+#: add-patch.c:1186
+#, c-format
+msgid "Sorry, only %d hunk available."
+msgid_plural "Sorry, only %d hunks available."
+msgstr[0] "Mi dispiace, è disponibile solo %d hunk."
+msgstr[1] "Mi dispiace, sono disponibili solo %d hunk."
+
+#: add-patch.c:1195
+msgid "No other hunks to search"
+msgstr "Nessun altro hunk in cui eseguire la ricerca"
+
+#: add-patch.c:1201 git-add--interactive.perl:1623
+msgid "search for regex? "
+msgstr "cercare un'espressione regolare? "
+
+#: add-patch.c:1216
+#, c-format
+msgid "Malformed search regexp %s: %s"
+msgstr "Espressione regolare di ricerca %s malformata: %s"
+
+#: add-patch.c:1233
+msgid "No hunk matches the given pattern"
+msgstr "Nessun hunk corrisponde al pattern fornito"
+
+#: add-patch.c:1240
+msgid "Sorry, cannot split this hunk"
+msgstr "Mi dispiace, non posso suddividere quest'hunk"
+
+#: add-patch.c:1244
+#, c-format
+msgid "Split into %d hunks."
+msgstr "Suddiviso in %d hunk."
+
+#: add-patch.c:1248
+msgid "Sorry, cannot edit this hunk"
+msgstr "Mi dispiace, non posso modificare quest'hunk"
+
+#: advice.c:111
+#, c-format
+msgid "%shint: %.*s%s\n"
+msgstr "%ssuggerimento: %.*s%s\n"
+
+#: advice.c:164
+msgid "Cherry-picking is not possible because you have unmerged files."
 msgstr ""
+"Il cherry picking non è possibile perché ci sono file di cui non è stato "
+"eseguito il merge."
 
-#: help.c:207
-#, c-format
-msgid "available git commands in '%s'"
-msgstr "comandi git disponibili in '%s'"
+#: advice.c:166
+msgid "Committing is not possible because you have unmerged files."
+msgstr ""
+"Il commit non è possibile perché ci sono file di cui non è stato eseguito il "
+"merge."
 
-#: help.c:214
-msgid "git commands available from elsewhere on your $PATH"
-msgstr "comandi git disponibili altrove nel tuo $PATH"
+#: advice.c:168
+msgid "Merging is not possible because you have unmerged files."
+msgstr ""
+"Il merge non è possibile perché ci sono file di cui non è stato eseguito il "
+"merge."
 
-#: help.c:270
-#, c-format
-msgid ""
-"'%s' appears to be a git command, but we were not\n"
-"able to execute it. Maybe git-%s is broken?"
+#: advice.c:170
+msgid "Pulling is not possible because you have unmerged files."
 msgstr ""
-"'%s' sembra essere un comando git, ma non è stato\n"
-"possibile eseguirlo. Forse git-%s è corrotto?"
+"Il pull non è possibile perché ci sono file di cui non è stato eseguito il "
+"merge."
 
-#: help.c:327
-msgid "Uh oh. Your system reports no Git commands at all."
-msgstr "Oh oh. Il tuo sistema non riporta alcun comando Git."
+#: advice.c:172
+msgid "Reverting is not possible because you have unmerged files."
+msgstr ""
+"Il revert non è possibile perché ci sono file di cui non è stato eseguito il "
+"merge."
 
-#: help.c:349
+#: advice.c:174
 #, c-format
+msgid "It is not possible to %s because you have unmerged files."
+msgstr ""
+"Impossibile eseguire il %s perché ci sono file di cui non è stato eseguito "
+"il merge."
+
+#: advice.c:182
 msgid ""
-"WARNING: You called a Git command named '%s', which does not exist.\n"
-"Continuing under the assumption that you meant '%s'"
+"Fix them up in the work tree, and then use 'git add/rm <file>'\n"
+"as appropriate to mark resolution and make a commit."
 msgstr ""
+"Correggili nell'albero di lavoro, quindi usa 'git add/rm <file>...' come "
+"appropriato per risolverli ed esegui un commit."
 
-#: help.c:354
-#, c-format
-msgid "in %0.1f seconds automatically..."
-msgstr "automaticamente tra %0.1f secondi..."
+#: advice.c:190
+msgid "Exiting because of an unresolved conflict."
+msgstr "Esco a causa di un conflitto non risolto."
 
-#: help.c:361
-#, c-format
-msgid "git: '%s' is not a git command. See 'git --help'."
-msgstr "git: '%s' non è un comando git. Vedi 'git --help'."
+#: advice.c:195 builtin/merge.c:1332
+msgid "You have not concluded your merge (MERGE_HEAD exists)."
+msgstr "Il merge non è stato concluso (esiste MERGE_HEAD)."
+
+#: advice.c:197
+msgid "Please, commit your changes before merging."
+msgstr "Esegui il commit delle modifiche prima di eseguire il merge."
 
-#: help.c:365
+#: advice.c:198
+msgid "Exiting because of unfinished merge."
+msgstr "Esco a causa di un merge non terminato."
+
+#: advice.c:204
+#, c-format
 msgid ""
+"Note: switching to '%s'.\n"
 "\n"
-"Did you mean this?"
-msgid_plural ""
+"You are in 'detached HEAD' state. You can look around, make experimental\n"
+"changes and commit them, and you can discard any commits you make in this\n"
+"state without impacting any branches by switching back to a branch.\n"
 "\n"
-"Did you mean one of these?"
-msgstr[0] ""
+"If you want to create a new branch to retain commits you create, you may\n"
+"do so (now or later) by using -c with the switch command. Example:\n"
 "\n"
-"Intendevi questo?"
-msgstr[1] ""
+"  git switch -c <new-branch-name>\n"
+"\n"
+"Or undo this operation with:\n"
+"\n"
+"  git switch -\n"
+"\n"
+"Turn off this advice by setting config variable advice.detachedHead to "
+"false\n"
+"\n"
+msgstr ""
+"Nota: eseguo il checkout di '%s'.\n"
+"\n"
+"Sei nello stato 'HEAD scollegato'. Puoi dare un'occhiata, apportare "
+"modifiche\n"
+"sperimentali ed eseguirne il commit, e puoi scartare qualunque commit "
+"eseguito\n"
+"in questo stato senza che ciò abbia alcuna influenza sugli altri branch "
+"tornando\n"
+"su un branch.\n"
+"\n"
+"Se vuoi creare un nuovo branch per mantenere i commit creati, puoi farlo\n"
+"(ora o in seguito) usando l'opzione -c con il comando switch. Ad esempio:\n"
+"\n"
+"  git switch -c <nome nuovo branch>\n"
+"\n"
+"Oppure puoi annullare quest'operazione con:\n"
+"\n"
+"  git switch -\n"
+"\n"
+"Disattiva questo consiglio impostando la variabile di configurazione\n"
+"advice.detachedHead a false\n"
 "\n"
-"Intendevi uno di questi?"
 
-#: parse-options.c:493
-msgid "..."
-msgstr "..."
+#: alias.c:50
+msgid "cmdline ends with \\"
+msgstr "la riga di comando termina con \\"
+
+#: alias.c:51
+msgid "unclosed quote"
+msgstr "virgolette non chiuse"
 
-#: parse-options.c:511
+#: apply.c:69
 #, c-format
-msgid "usage: %s"
-msgstr "   uso: %s"
+msgid "unrecognized whitespace option '%s'"
+msgstr "opzione spazi bianchi '%s' non riconosciuta"
 
-#. TRANSLATORS: the colon here should align with the
-#. one in "usage: %s" translation
-#: parse-options.c:515
+#: apply.c:85
 #, c-format
-msgid "   or: %s"
-msgstr "oppure: %s"
+msgid "unrecognized whitespace ignore option '%s'"
+msgstr "opzione ignora spazi bianchi '%s' non riconosciuta"
 
-#: parse-options.c:518
-#, c-format
-msgid "    %s"
-msgstr "    %s"
+#: apply.c:135
+msgid "--reject and --3way cannot be used together."
+msgstr "--reject e --3way non possono essere usati insieme."
 
-#: remote.c:1629
-#, c-format
-msgid "Your branch is ahead of '%s' by %d commit.\n"
-msgid_plural "Your branch is ahead of '%s' by %d commits.\n"
-msgstr[0] "Il tuo branch è avanti rispetto a '%s' di %d commit.\n"
-msgstr[1] "Il tuo branch è avanti rispetto a '%s' di %d commit.\n"
+#: apply.c:137
+msgid "--cached and --3way cannot be used together."
+msgstr "--cached e --3way non possono essere usati insieme."
 
-#: remote.c:1635
-#, c-format
-msgid "Your branch is behind '%s' by %d commit, and can be fast-forwarded.\n"
-msgid_plural ""
-"Your branch is behind '%s' by %d commits, and can be fast-forwarded.\n"
-msgstr[0] ""
-msgstr[1] ""
+#: apply.c:140
+msgid "--3way outside a repository"
+msgstr "--3way al di fuori di un repository"
 
-#: remote.c:1643
-#, c-format
-msgid ""
-"Your branch and '%s' have diverged,\n"
-"and have %d and %d different commit each, respectively.\n"
-msgid_plural ""
-"Your branch and '%s' have diverged,\n"
-"and have %d and %d different commits each, respectively.\n"
-msgstr[0] ""
-msgstr[1] ""
+#: apply.c:151
+msgid "--index outside a repository"
+msgstr "--index al di fuori di un repository"
 
-#: sequencer.c:121 builtin/merge.c:865 builtin/merge.c:978
-#: builtin/merge.c:1088 builtin/merge.c:1098
-#, c-format
-msgid "Could not open '%s' for writing"
-msgstr "Non è stato possibile aprire '%s' per la scrittura"
+#: apply.c:154
+msgid "--cached outside a repository"
+msgstr "--cached al di fuori di un repository"
 
-#: sequencer.c:123 builtin/merge.c:333 builtin/merge.c:868
-#: builtin/merge.c:1090 builtin/merge.c:1103
+#: apply.c:801
 #, c-format
-msgid "Could not write to '%s'"
-msgstr "Non è stato possibile scrivere su '%s'"
-
-#: sequencer.c:144
-msgid ""
-"after resolving the conflicts, mark the corrected paths\n"
-"with 'git add <paths>' or 'git rm <paths>'"
-msgstr ""
-"dopo aver risolto i conflitti, segna i path corretti\n"
-"con 'git add <path>' o 'git rm <path>'"
-
-#: sequencer.c:147
-msgid ""
-"after resolving the conflicts, mark the corrected paths\n"
-"with 'git add <paths>' or 'git rm <paths>'\n"
-"and commit the result with 'git commit'"
-msgstr ""
-"dopo aver risolto i conflitti, segna i path corretti\n"
-"con 'git add <path>' o 'git rm <path>' ed eseguire\n"
-"il commit del risultato con 'git commit'"
+msgid "Cannot prepare timestamp regexp %s"
+msgstr "Impossibile preparare l'espressione regolare timestamp %s"
 
-#: sequencer.c:160 sequencer.c:758 sequencer.c:841
+#: apply.c:810
 #, c-format
-msgid "Could not write to %s"
-msgstr "Non è stato possibile scrivere su %s"
+msgid "regexec returned %d for input: %s"
+msgstr "regexec ha restituito %d per l'input: %s"
 
-#: sequencer.c:163
+#: apply.c:884
 #, c-format
-msgid "Error wrapping up %s"
-msgstr ""
-
-#: sequencer.c:178
-msgid "Your local changes would be overwritten by cherry-pick."
-msgstr "Le tue modifiche locali verranno sovrascritte da cherry-pick"
-
-#: sequencer.c:180
-msgid "Your local changes would be overwritten by revert."
-msgstr "Le tue modifiche locali verranno sovrascritte da revert."
-
-#: sequencer.c:183
-msgid "Commit your changes or stash them to proceed."
-msgstr ""
+msgid "unable to find filename in patch at line %d"
+msgstr "impossibile trovare il nome del file nella patch alla riga %d"
 
-#. TRANSLATORS: %s will be "revert" or "cherry-pick"
-#: sequencer.c:233
+#: apply.c:922
 #, c-format
-msgid "%s: Unable to write new index file"
-msgstr "%s: impossibile scrivere il nuovo index file"
-
-#: sequencer.c:261
-msgid "Could not resolve HEAD commit\n"
-msgstr "Non è stato possibile risolvere il commit HEAD\n"
-
-#: sequencer.c:282
-msgid "Unable to update cache tree\n"
+msgid "git apply: bad git-diff - expected /dev/null, got %s on line %d"
 msgstr ""
+"git apply: git-diff errato - atteso /dev/null, ricevuto %s alla riga %d"
 
-#: sequencer.c:324
+#: apply.c:928
 #, c-format
-msgid "Could not parse commit %s\n"
-msgstr "Non è stato possibile analizzare il commit %s\n"
-
-#: sequencer.c:329
-#, c-format
-msgid "Could not parse parent commit %s\n"
+msgid "git apply: bad git-diff - inconsistent new filename on line %d"
 msgstr ""
+"git apply: git-diff errato - nuovo nome del file inconsistente alla riga %d"
 
-#: sequencer.c:395
-msgid "Your index file is unmerged."
+#: apply.c:929
+#, c-format
+msgid "git apply: bad git-diff - inconsistent old filename on line %d"
 msgstr ""
+"git apply: git-diff errato - vecchio nome del file inconsistente alla riga %d"
 
-#: sequencer.c:398
-msgid "You do not have a valid HEAD"
-msgstr "Non hai un HEAD valido"
-
-#: sequencer.c:413
+#: apply.c:934
 #, c-format
-msgid "Commit %s is a merge but no -m option was given."
-msgstr "Il commit %s è un merge ma non è stata specificata l'opzione -m."
+msgid "git apply: bad git-diff - expected /dev/null on line %d"
+msgstr "git apply: git-diff errato - atteso /dev/null alla riga %d"
 
-#: sequencer.c:421
+#: apply.c:963
 #, c-format
-msgid "Commit %s does not have parent %d"
-msgstr ""
+msgid "invalid mode on line %d: %s"
+msgstr "modo non valido alla riga %d: %s"
 
-#: sequencer.c:425
+#: apply.c:1282
 #, c-format
-msgid "Mainline was specified but commit %s is not a merge."
-msgstr ""
+msgid "inconsistent header lines %d and %d"
+msgstr "righe di intestazione %d e %d inconsistenti"
 
-#. TRANSLATORS: The first %s will be "revert" or
-#. "cherry-pick", the second %s a SHA1
-#: sequencer.c:436
+#: apply.c:1372
 #, c-format
-msgid "%s: cannot parse parent commit %s"
-msgstr ""
+msgid ""
+"git diff header lacks filename information when removing %d leading pathname "
+"component (line %d)"
+msgid_plural ""
+"git diff header lacks filename information when removing %d leading pathname "
+"components (line %d)"
+msgstr[0] ""
+"l'intestazione git diff non riporta le informazioni sul file una volta "
+"rimosso %d componente iniziale del percorso (riga %d)"
+msgstr[1] ""
+"l'intestazione git diff non riporta le informazioni sul file una volta "
+"rimossi %d componenti iniziali del percorso (riga %d)"
 
-#: sequencer.c:440
+#: apply.c:1385
 #, c-format
-msgid "Cannot get commit message for %s"
-msgstr "Impossibile ottenere il messaggio di commit per %s"
+msgid "git diff header lacks filename information (line %d)"
+msgstr "l'intestazione git diff non riporta le informazioni sul file (riga %d)"
 
-#: sequencer.c:524
+#: apply.c:1481
 #, c-format
-msgid "could not revert %s... %s"
-msgstr "non è stato possibile eseguire il revert di %s... %s"
+msgid "recount: unexpected line: %.*s"
+msgstr "recount: riga inattesa: %.*s"
 
-#: sequencer.c:525
+#: apply.c:1550
 #, c-format
-msgid "could not apply %s... %s"
-msgstr "non è stato possibile applicare %s... %s"
+msgid "patch fragment without header at line %d: %.*s"
+msgstr "frammento di patch senza intestazione alla riga %d: %.*s"
 
-#: sequencer.c:553
-msgid "empty commit set passed"
-msgstr "è stato passato un set di commit vuoto"
+#: apply.c:1753
+msgid "new file depends on old contents"
+msgstr "il nuovo file dipende da vecchi contenuti"
 
-#: sequencer.c:561
-#, c-format
-msgid "git %s: failed to read the index"
-msgstr "git %s: lettura di index non riuscita"
+#: apply.c:1755
+msgid "deleted file still has contents"
+msgstr "il file eliminato ha ancora dei contenuti"
 
-#: sequencer.c:566
+#: apply.c:1789
 #, c-format
-msgid "git %s: failed to refresh the index"
-msgstr "git %s: aggiornamento di index non riuscito"
+msgid "corrupt patch at line %d"
+msgstr "patch corrotta alla riga %d"
 
-#: sequencer.c:624
+#: apply.c:1826
 #, c-format
-msgid "Cannot %s during a %s"
-msgstr ""
+msgid "new file %s depends on old contents"
+msgstr "il nuovo file %s dipende da vecchi contenuti"
 
-#: sequencer.c:646
+#: apply.c:1828
 #, c-format
-msgid "Could not parse line %d."
-msgstr "Non è stato possibile analizzare la riga %d."
+msgid "deleted file %s still has contents"
+msgstr "il file eliminato %s ha ancora dei contenuti"
 
-#: sequencer.c:651
-msgid "No commits parsed."
-msgstr "Nessun commit analizzato."
+#: apply.c:1831
+#, c-format
+msgid "** warning: file %s becomes empty but is not deleted"
+msgstr "** attenzione: il file %s diventa vuoto ma non è eliminato"
 
-#: sequencer.c:664
+#: apply.c:1978
 #, c-format
-msgid "Could not open %s"
-msgstr "Non è stato possibile aprire %s"
+msgid "corrupt binary patch at line %d: %.*s"
+msgstr "patch binaria corrotta alla riga %d: %.*s"
 
-#: sequencer.c:668
+#: apply.c:2015
 #, c-format
-msgid "Could not read %s."
-msgstr "Non è stato possibile leggere %s."
+msgid "unrecognized binary patch at line %d"
+msgstr "patch binaria non riconosciuta alla riga %d"
 
-#: sequencer.c:675
+#: apply.c:2177
 #, c-format
-msgid "Unusable instruction sheet: %s"
-msgstr ""
+msgid "patch with only garbage at line %d"
+msgstr "patch con soli contenuti garbage alla riga %d"
 
-#: sequencer.c:703
+#: apply.c:2263
 #, c-format
-msgid "Invalid key: %s"
-msgstr "Chiave non valida: %s"
+msgid "unable to read symlink %s"
+msgstr "impossibile leggere il collegamento simbolico %s"
 
-#: sequencer.c:706
+#: apply.c:2267
 #, c-format
-msgid "Invalid value for %s: %s"
-msgstr "Valore non valido per %s: %s"
+msgid "unable to open or read %s"
+msgstr "impossibile aprire o leggere %s"
 
-#: sequencer.c:718
+#: apply.c:2936
 #, c-format
-msgid "Malformed options sheet: %s"
-msgstr ""
-
-#: sequencer.c:739
-msgid "a cherry-pick or revert is already in progress"
-msgstr "è già in corso un'operazione di cherry-pick o di revert"
+msgid "invalid start of line: '%c'"
+msgstr "inizio della riga non valido: '%c'"
 
-#: sequencer.c:740
-msgid "try \"git cherry-pick (--continue | --quit | --abort)\""
-msgstr "prova \"git cherry-pick (--continue | --quit | -- abort)\""
+#: apply.c:3057
+#, c-format
+msgid "Hunk #%d succeeded at %d (offset %d line)."
+msgid_plural "Hunk #%d succeeded at %d (offset %d lines)."
+msgstr[0] "Applicazione frammento %d riuscita alla riga %d (offset: %d riga)."
+msgstr[1] "Applicazione frammento %d riuscita alla riga %d (offset: %d righe)."
 
-#: sequencer.c:744
+#: apply.c:3069
 #, c-format
-msgid "Could not create sequencer directory %s"
-msgstr ""
+msgid "Context reduced to (%ld/%ld) to apply fragment at %d"
+msgstr "Contesto ridotto a (%ld/%ld) per applicare il frammento alla riga %d"
 
-#: sequencer.c:760 sequencer.c:845
+#: apply.c:3075
 #, c-format
-msgid "Error wrapping up %s."
+msgid ""
+"while searching for:\n"
+"%.*s"
 msgstr ""
+"durante la ricerca di:\n"
+"%.*s"
 
-#: sequencer.c:779 sequencer.c:913
-msgid "no cherry-pick or revert in progress"
-msgstr "nessuna operazione di cherry-pick o revert in corso"
+#: apply.c:3097
+#, c-format
+msgid "missing binary patch data for '%s'"
+msgstr "dati della patch binaria mancanti per '%s'"
 
-#: sequencer.c:781
-msgid "cannot resolve HEAD"
-msgstr "impossibile risolvere HEAD"
+#: apply.c:3105
+#, c-format
+msgid "cannot reverse-apply a binary patch without the reverse hunk to '%s'"
+msgstr ""
+"impossibile applicare una patch binaria al contrario senza l'hunk contrario "
+"per '%s'"
 
-#: sequencer.c:783
-msgid "cannot abort from a branch yet to be born"
+#: apply.c:3152
+#, c-format
+msgid "cannot apply binary patch to '%s' without full index line"
 msgstr ""
+"impossibile applicare una patch binaria a '%s' senza la riga d'indice "
+"completa"
 
-#: sequencer.c:805 builtin/apply.c:3697
+#: apply.c:3162
 #, c-format
-msgid "cannot open %s: %s"
-msgstr "impossibile aprire %s: %s"
+msgid ""
+"the patch applies to '%s' (%s), which does not match the current contents."
+msgstr ""
+"la patch si applica a '%s' (%s), che non corrisponde ai contenuti correnti "
+"del file."
 
-#: sequencer.c:808
+#: apply.c:3170
 #, c-format
-msgid "cannot read %s: %s"
-msgstr "impossibile leggere %s: %s"
+msgid "the patch applies to an empty '%s' but it is not empty"
+msgstr "la patch si applica a un file vuoto '%s' ma il file non è vuoto"
 
-#: sequencer.c:809
-msgid "unexpected end of file"
-msgstr "fine del file inattesa"
+#: apply.c:3188
+#, c-format
+msgid "the necessary postimage %s for '%s' cannot be read"
+msgstr "impossibile leggere la postimmagine %s necessaria per '%s'"
 
-#: sequencer.c:815
+#: apply.c:3201
 #, c-format
-msgid "stored pre-cherry-pick HEAD file '%s' is corrupt"
-msgstr ""
+msgid "binary patch does not apply to '%s'"
+msgstr "la patch binaria non si applica correttamente a '%s'"
 
-#: sequencer.c:838
+#: apply.c:3207
 #, c-format
-msgid "Could not format %s."
+msgid "binary patch to '%s' creates incorrect result (expecting %s, got %s)"
 msgstr ""
+"la patch binaria su '%s' crea risultati non corretti (atteso %s, ricevuto %s)"
 
-#: sequencer.c:1000
-msgid "Can't revert as initial commit"
-msgstr "Impossibile eseguire il revert come commit iniziale"
-
-#: sequencer.c:1001
-msgid "Can't cherry-pick into empty head"
-msgstr ""
+#: apply.c:3228
+#, c-format
+msgid "patch failed: %s:%ld"
+msgstr "patch non riuscita: %s:%ld"
 
-#: sha1_name.c:864
-msgid "HEAD does not point to a branch"
-msgstr "HEAD non punta ad un branch"
+#: apply.c:3351
+#, c-format
+msgid "cannot checkout %s"
+msgstr "impossibile eseguire il checkout di '%s'"
 
-#: sha1_name.c:867
+#: apply.c:3403 apply.c:3414 apply.c:3460 midx.c:61 setup.c:280
 #, c-format
-msgid "No such branch: '%s'"
-msgstr "Nessun branch esistente: '%s'"
+msgid "failed to read %s"
+msgstr "lettura di %s non riuscita"
 
-#: sha1_name.c:869
+#: apply.c:3411
 #, c-format
-msgid "No upstream configured for branch '%s'"
-msgstr "Nessun upstream configurato per il branch '%s'"
+msgid "reading from '%s' beyond a symbolic link"
+msgstr "lettura di '%s' oltre un collegamento simbolico"
 
-#: sha1_name.c:872
+#: apply.c:3440 apply.c:3683
 #, c-format
-msgid "Upstream branch '%s' not stored as a remote-tracking branch"
-msgstr ""
+msgid "path %s has been renamed/deleted"
+msgstr "il percorso %s è stato rinominato/eliminato"
 
-#: wrapper.c:413
+#: apply.c:3526 apply.c:3698
 #, c-format
-msgid "unable to look up current user in the passwd file: %s"
-msgstr "impossibile trovare l'utente corrente nel file passwd: %s"
+msgid "%s: does not exist in index"
+msgstr "%s: non esiste nell'indice"
 
-#: wrapper.c:414
-msgid "no such user"
-msgstr "utente non esistente"
+#: apply.c:3535 apply.c:3706
+#, c-format
+msgid "%s: does not match index"
+msgstr "%s: non corrisponde all'indice"
 
-#: wt-status.c:135
-msgid "Unmerged paths:"
+#: apply.c:3570
+msgid "repository lacks the necessary blob to fall back on 3-way merge."
 msgstr ""
+"dal repository manca il blob necessario per ripiegare sul merge a tre vie."
 
-#: wt-status.c:141 wt-status.c:158
+#: apply.c:3573
 #, c-format
-msgid "  (use \"git reset %s <file>...\" to unstage)"
-msgstr ""
+msgid "Falling back to three-way merge...\n"
+msgstr "Ripiego sul merge a tre vie...\n"
 
-#: wt-status.c:143 wt-status.c:160
-msgid "  (use \"git rm --cached <file>...\" to unstage)"
-msgstr ""
-
-#: wt-status.c:144
-msgid "  (use \"git add/rm <file>...\" as appropriate to mark resolution)"
-msgstr "  (usa \"git add/rm <file>...\" come appropriato per la risoluzione)"
+#: apply.c:3589 apply.c:3593
+#, c-format
+msgid "cannot read the current contents of '%s'"
+msgstr "impossibile leggere i contenuti correnti di '%s'"
 
-#: wt-status.c:152
-msgid "Changes to be committed:"
-msgstr ""
+#: apply.c:3605
+#, c-format
+msgid "Failed to fall back on three-way merge...\n"
+msgstr "Ripiego sul merge a tre vie non riuscito...\n"
 
-#: wt-status.c:170
-msgid "Changes not staged for commit:"
-msgstr ""
+#: apply.c:3619
+#, c-format
+msgid "Applied patch to '%s' with conflicts.\n"
+msgstr "Patch applicata a '%s' con conflitti.\n"
 
-#: wt-status.c:174
-msgid "  (use \"git add <file>...\" to update what will be committed)"
-msgstr ""
+#: apply.c:3624
+#, c-format
+msgid "Applied patch to '%s' cleanly.\n"
+msgstr "Patch '%s' applicata correttamente.\n"
 
-#: wt-status.c:176
-msgid "  (use \"git add/rm <file>...\" to update what will be committed)"
-msgstr ""
+#: apply.c:3650
+msgid "removal patch leaves file contents"
+msgstr "la rimozione della patch lascia contenuti del file"
 
-#: wt-status.c:177
-msgid ""
-"  (use \"git checkout -- <file>...\" to discard changes in working directory)"
-msgstr ""
+#: apply.c:3723
+#, c-format
+msgid "%s: wrong type"
+msgstr "%s: tipo errato"
 
-#: wt-status.c:179
-msgid "  (commit or discard the untracked or modified content in submodules)"
-msgstr ""
+#: apply.c:3725
+#, c-format
+msgid "%s has type %o, expected %o"
+msgstr "%s ha il tipo %o, atteso %o"
 
-#: wt-status.c:188
+#: apply.c:3876 apply.c:3878 read-cache.c:830 read-cache.c:856
+#: read-cache.c:1320
 #, c-format
-msgid "%s files:"
-msgstr "%s file:"
+msgid "invalid path '%s'"
+msgstr "percorso '%s' non valido"
 
-#: wt-status.c:191
+#: apply.c:3934
 #, c-format
-msgid "  (use \"git %s <file>...\" to include in what will be committed)"
-msgstr ""
+msgid "%s: already exists in index"
+msgstr "%s: esiste già nell'indice"
 
-#: wt-status.c:208
-msgid "bug"
-msgstr "bug"
+#: apply.c:3937
+#, c-format
+msgid "%s: already exists in working directory"
+msgstr "%s: esiste già nella directory di lavoro"
 
-#: wt-status.c:213
-msgid "both deleted:"
-msgstr "entrambi eliminati:"
+#: apply.c:3957
+#, c-format
+msgid "new mode (%o) of %s does not match old mode (%o)"
+msgstr "il nuovo modo (%o) di %s non corrisponde al vecchio modo (%o)"
 
-#: wt-status.c:214
-msgid "added by us:"
-msgstr "aggiunto da noi:"
+#: apply.c:3962
+#, c-format
+msgid "new mode (%o) of %s does not match old mode (%o) of %s"
+msgstr "il nuovo modo (%o) di %s non corrisponde al vecchio modo (%o) di %s"
 
-#: wt-status.c:215
-msgid "deleted by them:"
-msgstr "eliminato da loro:"
+#: apply.c:3982
+#, c-format
+msgid "affected file '%s' is beyond a symbolic link"
+msgstr "il file interessato '%s' si trova oltre un collegamento simbolico"
 
-#: wt-status.c:216
-msgid "added by them:"
-msgstr "aggiunto da loro:"
+#: apply.c:3986
+#, c-format
+msgid "%s: patch does not apply"
+msgstr "%s: la patch non si applica correttamente"
 
-#: wt-status.c:217
-msgid "deleted by us:"
-msgstr "eliminato da noi:"
+#: apply.c:4001
+#, c-format
+msgid "Checking patch %s..."
+msgstr "Controllo della patch %s in corso..."
 
-#: wt-status.c:218
-msgid "both added:"
-msgstr "entrambi aggiunti:"
+#: apply.c:4093
+#, c-format
+msgid "sha1 information is lacking or useless for submodule %s"
+msgstr "le informazioni SHA1 per il sottomodulo %s sono mancanti o inutili"
 
-#: wt-status.c:219
-msgid "both modified:"
-msgstr "entrambi modificati:"
+#: apply.c:4100
+#, c-format
+msgid "mode change for %s, which is not in current HEAD"
+msgstr "modifica modo per %s che non è nell'HEAD corrente"
 
-#: wt-status.c:249
-msgid "new commits, "
-msgstr "nuovi commit, "
+#: apply.c:4103
+#, c-format
+msgid "sha1 information is lacking or useless (%s)."
+msgstr "le informazioni SHA1 sono mancanti o inutili (%s)."
 
-#: wt-status.c:251
-msgid "modified content, "
-msgstr "contenuto modificato, "
+#: apply.c:4112
+#, c-format
+msgid "could not add %s to temporary index"
+msgstr "impossibile aggiungere %s all'indice temporaneo"
 
-#: wt-status.c:253
-msgid "untracked content, "
-msgstr ""
+#: apply.c:4122
+#, c-format
+msgid "could not write temporary index to %s"
+msgstr "impossibile scrivere l'indice temporaneo in %s"
 
-#: wt-status.c:267
+#: apply.c:4260
 #, c-format
-msgid "new file:   %s"
-msgstr "nuovo file:   %s"
+msgid "unable to remove %s from index"
+msgstr "impossibile rimuovere %s dall'indice"
 
-#: wt-status.c:270
+#: apply.c:4294
 #, c-format
-msgid "copied:     %s -> %s"
-msgstr "copiato:     %s -> %s"
+msgid "corrupt patch for submodule %s"
+msgstr "patch corrotta per il sottomodulo %s"
 
-#: wt-status.c:273
+#: apply.c:4300
 #, c-format
-msgid "deleted:    %s"
-msgstr "eliminato:    %s"
+msgid "unable to stat newly created file '%s'"
+msgstr "impossibile eseguire lo stat del file appena creato '%s'"
 
-#: wt-status.c:276
+#: apply.c:4308
 #, c-format
-msgid "modified:   %s"
-msgstr "modificato:   %s"
+msgid "unable to create backing store for newly created file %s"
+msgstr "impossibile creare l'archivio di backup per il file appena creato %s"
 
-#: wt-status.c:279
+#: apply.c:4314 apply.c:4459
 #, c-format
-msgid "renamed:    %s -> %s"
-msgstr "rinominato:    %s -> %s"
+msgid "unable to add cache entry for %s"
+msgstr "impossibile aggiungere la voce della cache per %s"
 
-#: wt-status.c:282
+#: apply.c:4357
 #, c-format
-msgid "typechange: %s"
-msgstr ""
+msgid "failed to write to '%s'"
+msgstr "scrittura in '%s' non riuscita"
 
-#: wt-status.c:285
+#: apply.c:4361
 #, c-format
-msgid "unknown:    %s"
-msgstr "sconosciuto:    %s"
+msgid "closing file '%s'"
+msgstr "chiusura del file '%s' in corso"
 
-#: wt-status.c:288
+#: apply.c:4431
 #, c-format
-msgid "unmerged:   %s"
-msgstr ""
+msgid "unable to write file '%s' mode %o"
+msgstr "impossibile scrivere il file '%s' con modo %o"
 
-#: wt-status.c:291
+#: apply.c:4529
 #, c-format
-msgid "bug: unhandled diff status %c"
-msgstr ""
+msgid "Applied patch %s cleanly."
+msgstr "Patch %s applicata correttamente."
 
-#: wt-status.c:737
-msgid "On branch "
-msgstr "Sul branch "
+#: apply.c:4537
+msgid "internal error"
+msgstr "errore interno"
 
-#: wt-status.c:744
-msgid "Not currently on any branch."
-msgstr ""
+#: apply.c:4540
+#, c-format
+msgid "Applying patch %%s with %d reject..."
+msgid_plural "Applying patch %%s with %d rejects..."
+msgstr[0] "Applicazione della patch %%s con %d frammento respinto..."
+msgstr[1] "Applicazione della patch %%s con %d frammenti respinti..."
 
-#: wt-status.c:755
-msgid "Initial commit"
-msgstr "Commit iniziale"
+#: apply.c:4551
+#, c-format
+msgid "truncating .rej filename to %.*s.rej"
+msgstr "nome file .rej troncato a %.*s.rej"
 
-#: wt-status.c:769
-msgid "Untracked"
-msgstr ""
+#: apply.c:4559 builtin/fetch.c:901 builtin/fetch.c:1192
+#, c-format
+msgid "cannot open %s"
+msgstr "impossibile aprire %s"
 
-#: wt-status.c:771
-msgid "Ignored"
-msgstr "Ignorato"
+#: apply.c:4573
+#, c-format
+msgid "Hunk #%d applied cleanly."
+msgstr "Frammento %d applicato correttamente."
 
-#: wt-status.c:773
+#: apply.c:4577
 #, c-format
-msgid "Untracked files not listed%s"
-msgstr ""
+msgid "Rejected hunk #%d."
+msgstr "Frammento %d respinto."
 
-#: wt-status.c:775
-msgid " (use -u option to show untracked files)"
-msgstr ""
+#: apply.c:4696
+#, c-format
+msgid "Skipped patch '%s'."
+msgstr "Patch '%s' ignorata."
 
-#: wt-status.c:781
-msgid "No changes"
-msgstr "Nessuna modifica"
+#: apply.c:4704
+msgid "unrecognized input"
+msgstr "input non riconosciuto"
 
-#: wt-status.c:785
-#, c-format
-msgid "no changes added to commit%s\n"
-msgstr "nessuna modifica aggiunta al commit%s\n"
+#: apply.c:4724
+msgid "unable to read index file"
+msgstr "impossibile leggere il file index"
 
-#: wt-status.c:787
-msgid " (use \"git add\" and/or \"git commit -a\")"
-msgstr " (usa \"git add\" e/o \"git commit -a\")"
+#: apply.c:4881
+#, c-format
+msgid "can't open patch '%s': %s"
+msgstr "impossibile aprire la patch '%s': %s"
 
-#: wt-status.c:789
+#: apply.c:4908
 #, c-format
-msgid "nothing added to commit but untracked files present%s\n"
-msgstr ""
+msgid "squelched %d whitespace error"
+msgid_plural "squelched %d whitespace errors"
+msgstr[0] "%d errore di spazi bianchi soppresso"
+msgstr[1] "%d errori di spazi bianchi soppressi"
 
-#: wt-status.c:791
-msgid " (use \"git add\" to track)"
-msgstr ""
+#: apply.c:4914 apply.c:4929
+#, c-format
+msgid "%d line adds whitespace errors."
+msgid_plural "%d lines add whitespace errors."
+msgstr[0] "%d riga aggiunge errori di spazi bianchi."
+msgstr[1] "%d righe aggiungono errori di spazi bianchi."
 
-#: wt-status.c:793 wt-status.c:796 wt-status.c:799
+#: apply.c:4922
 #, c-format
-msgid "nothing to commit%s\n"
-msgstr ""
+msgid "%d line applied after fixing whitespace errors."
+msgid_plural "%d lines applied after fixing whitespace errors."
+msgstr[0] "%d riga applicata dopo la correzione di errori di spazi bianchi."
+msgstr[1] "%d righe applicate dopo la correzione di errori di spazi bianchi."
 
-#: wt-status.c:794
-msgid " (create/copy files and use \"git add\" to track)"
-msgstr ""
+#: apply.c:4938 builtin/add.c:579 builtin/mv.c:301 builtin/rm.c:390
+msgid "Unable to write new index file"
+msgstr "Impossibile scrivere il nuovo file index"
 
-#: wt-status.c:797
-msgid " (use -u to show untracked files)"
-msgstr ""
+#: apply.c:4966
+msgid "don't apply changes matching the given path"
+msgstr "non applicare le modifiche corrispondenti al percorso specificato"
 
-#: wt-status.c:800
-msgid " (working directory clean)"
-msgstr ""
+#: apply.c:4969
+msgid "apply changes matching the given path"
+msgstr "applica le modifiche corrispondenti al percorso specificato"
 
-#: wt-status.c:908
-msgid "HEAD (no branch)"
-msgstr "HEAD (nessun branch)"
+#: apply.c:4971 builtin/am.c:2206
+msgid "num"
+msgstr "num"
 
-#: wt-status.c:914
-msgid "Initial commit on "
-msgstr "Commit iniziale su "
+#: apply.c:4972
+msgid "remove <num> leading slashes from traditional diff paths"
+msgstr "rimuovi <num> barre iniziali dai percorsi diff tradizionali"
 
-#: wt-status.c:929
-msgid "behind "
-msgstr "indietro "
+#: apply.c:4975
+msgid "ignore additions made by the patch"
+msgstr "ignora le aggiunte create dalla patch"
 
-#: wt-status.c:932 wt-status.c:935
-msgid "ahead "
-msgstr "avanti "
+#: apply.c:4977
+msgid "instead of applying the patch, output diffstat for the input"
+msgstr ""
+"invece di applicare la patch, visualizza l'output di diffstat per l'input"
 
-#: wt-status.c:937
-msgid ", behind "
-msgstr ", indietro "
+#: apply.c:4981
+msgid "show number of added and deleted lines in decimal notation"
+msgstr ""
+"visualizza il numero di righe aggiunte ed eliminate in notazione decimale"
 
-#: builtin/add.c:62
-#, c-format
-msgid "unexpected diff status %c"
-msgstr "status diff %c inatteso"
+#: apply.c:4983
+msgid "instead of applying the patch, output a summary for the input"
+msgstr "invece di applicare la patch, visualizza un riassunto per l'input"
 
-#: builtin/add.c:67 builtin/commit.c:226
-msgid "updating files failed"
-msgstr "aggiornamento dei file non riuscito"
+#: apply.c:4985
+msgid "instead of applying the patch, see if the patch is applicable"
+msgstr "invece di applicare la patch, verifica se può essere applicata"
 
-#: builtin/add.c:77
-#, c-format
-msgid "remove '%s'\n"
-msgstr "elimina '%s'\n"
+#: apply.c:4987
+msgid "make sure the patch is applicable to the current index"
+msgstr "assicura che la patch sia applicabile all'indice corrente"
 
-#: builtin/add.c:176
-#, c-format
-msgid "Path '%s' is in submodule '%.*s'"
-msgstr "Il path '%s' è nel sottomodulo '%.*s'"
+#: apply.c:4989
+msgid "mark new files with `git add --intent-to-add`"
+msgstr "contrassegna i nuovi file con `git add --intent-to-add`"
 
-#: builtin/add.c:192
-msgid "Unstaged changes after refreshing the index:"
-msgstr ""
+#: apply.c:4991
+msgid "apply a patch without touching the working tree"
+msgstr "applica una patch senza modificare l'albero di lavoro"
 
-#: builtin/add.c:195 builtin/add.c:456 builtin/rm.c:186
-#, c-format
-msgid "pathspec '%s' did not match any files"
+#: apply.c:4993
+msgid "accept a patch that touches outside the working area"
 msgstr ""
+"accetta una patch che apporta modifiche al di fuori dell'area di lavoro"
 
-#: builtin/add.c:209
-#, c-format
-msgid "'%s' is beyond a symbolic link"
-msgstr "'%s' si trova oltre un link simbolico"
+#: apply.c:4996
+msgid "also apply the patch (use with --stat/--summary/--check)"
+msgstr "applica anche la patch (da usare con --stat/--summary/--check)"
 
-#: builtin/add.c:276
-msgid "Could not read the index"
-msgstr "Non è stato possibile leggere index"
+#: apply.c:4998
+msgid "attempt three-way merge if a patch does not apply"
+msgstr "prova un merge a tre vie se la patch non si applica correttamente"
 
-#: builtin/add.c:286
-#, c-format
-msgid "Could not open '%s' for writing."
-msgstr "Non è stato possibile aprire '%s' per la scrittura."
+#: apply.c:5000
+msgid "build a temporary index based on embedded index information"
+msgstr "compila un index temporaneo basato sulle informazioni indice incluse"
 
-#: builtin/add.c:290
-msgid "Could not write patch"
-msgstr "Non è stato possibile scrivere la patch"
+#: apply.c:5003 builtin/checkout-index.c:173 builtin/ls-files.c:524
+msgid "paths are separated with NUL character"
+msgstr "i percorsi sono separati con un carattere NUL"
 
-#: builtin/add.c:295
-#, c-format
-msgid "Could not stat '%s'"
-msgstr "Non è stato possibile eseguire lo stat di '%s'"
+#: apply.c:5005
+msgid "ensure at least <n> lines of context match"
+msgstr "assicura che almeno <n> righe di contesto corrispondano"
 
-#: builtin/add.c:297
-msgid "Empty patch. Aborted."
-msgstr "Patch vuota. Operazione interrotta."
+#: apply.c:5006 builtin/am.c:2185 builtin/interpret-trailers.c:98
+#: builtin/interpret-trailers.c:100 builtin/interpret-trailers.c:102
+#: builtin/pack-objects.c:3310 builtin/rebase.c:1474
+msgid "action"
+msgstr "azione"
 
-#: builtin/add.c:303
-#, c-format
-msgid "Could not apply '%s'"
-msgstr "Non è stato possibile applicare '%s'"
+#: apply.c:5007
+msgid "detect new or modified lines that have whitespace errors"
+msgstr "rileva righe nuove o modificate che hanno errori di spazi bianchi"
 
-#: builtin/add.c:312
-msgid "The following paths are ignored by one of your .gitignore files:\n"
-msgstr "I seguenti path sono stati ignorati da uno o più dei tuoi file .gitignore:\n"
+#: apply.c:5010 apply.c:5013
+msgid "ignore changes in whitespace when finding context"
+msgstr "ignora modifiche agli spazi bianchi durante la ricerca dei contesti"
 
-#: builtin/add.c:352
-#, c-format
-msgid "Use -f if you really want to add them.\n"
-msgstr "Usa -f se vuoi davvero aggiungerli.\n"
+#: apply.c:5016
+msgid "apply the patch in reverse"
+msgstr "applica la patch in maniera inversa"
 
-#: builtin/add.c:353
-msgid "no files added"
-msgstr "nessun file aggiunto"
+#: apply.c:5018
+msgid "don't expect at least one line of context"
+msgstr "non aspettare almeno una riga di contesto"
 
-#: builtin/add.c:359
-msgid "adding files failed"
-msgstr "aggiunta dei file non riuscita"
+#: apply.c:5020
+msgid "leave the rejected hunks in corresponding *.rej files"
+msgstr "lascia i frammenti respinti nei file *.rej corrispondenti"
 
-#: builtin/add.c:391
-msgid "-A and -u are mutually incompatible"
-msgstr "-A e -u sono reciprocamente incompatibili"
+#: apply.c:5022
+msgid "allow overlapping hunks"
+msgstr "consenti la sovrapposizione dei frammenti"
 
-#: builtin/add.c:393
-msgid "Option --ignore-missing can only be used together with --dry-run"
-msgstr "L'opzione --ignore-missing può essere usata solo con --dry-run"
+#: apply.c:5023 builtin/add.c:309 builtin/check-ignore.c:22
+#: builtin/commit.c:1355 builtin/count-objects.c:98 builtin/fsck.c:774
+#: builtin/log.c:2166 builtin/mv.c:123 builtin/read-tree.c:128
+msgid "be verbose"
+msgstr "visualizza ulteriori dettagli"
 
-#: builtin/add.c:413
-#, c-format
-msgid "Nothing specified, nothing added.\n"
+#: apply.c:5025
+msgid "tolerate incorrectly detected missing new-line at the end of file"
 msgstr ""
+"tollera carattere fine riga rilevato erroneamente come mancante alla fine "
+"del file"
 
-#: builtin/add.c:414
-#, c-format
-msgid "Maybe you wanted to say 'git add .'?\n"
-msgstr "Forse intendevi dire 'git add .'?\n"
+#: apply.c:5028
+msgid "do not trust the line counts in the hunk headers"
+msgstr ""
+"non fare affidamento sul numero di righe nelle intestazioni dei frammenti"
 
-#: builtin/add.c:420 builtin/clean.c:95 builtin/commit.c:286 builtin/mv.c:82
-#: builtin/rm.c:162
-msgid "index file corrupt"
-msgstr "index file corrotto"
+#: apply.c:5030 builtin/am.c:2194
+msgid "root"
+msgstr "radice"
 
-#: builtin/add.c:476 builtin/apply.c:4108 builtin/mv.c:229 builtin/rm.c:260
-msgid "Unable to write new index file"
-msgstr "Impossibile scrivere il nuovo index file"
+#: apply.c:5031
+msgid "prepend <root> to all filenames"
+msgstr "anteponi <radice> a tutti i nomi file"
 
-#: builtin/apply.c:53
-msgid "git apply [options] [<patch>...]"
-msgstr "git apply [opzioni] [<patch>...]"
+#: archive.c:14
+msgid "git archive [<options>] <tree-ish> [<path>...]"
+msgstr "git archive [<opzioni>] <albero> [<percorso>...]"
 
-#: builtin/apply.c:106
-#, c-format
-msgid "unrecognized whitespace option '%s'"
-msgstr ""
+#: archive.c:15
+msgid "git archive --list"
+msgstr "git archive --list"
 
-#: builtin/apply.c:121
-#, c-format
-msgid "unrecognized whitespace ignore option '%s'"
+#: archive.c:16
+msgid ""
+"git archive --remote <repo> [--exec <cmd>] [<options>] <tree-ish> [<path>...]"
 msgstr ""
+"git archive --remote <repository> [--exec <comando>] [<opzioni>] <albero> "
+"[<percorso>...]"
 
-#: builtin/apply.c:815
-#, c-format
-msgid "Cannot prepare timestamp regexp %s"
-msgstr ""
+#: archive.c:17
+msgid "git archive --remote <repo> [--exec <cmd>] --list"
+msgstr "git archive --remote <repository> [--exec <comando>] --list"
 
-#: builtin/apply.c:824
+#: archive.c:372 builtin/add.c:180 builtin/add.c:555 builtin/rm.c:299
 #, c-format
-msgid "regexec returned %d for input: %s"
-msgstr "regexec ha restituito %d per l'input: %s"
+msgid "pathspec '%s' did not match any files"
+msgstr "lo specificatore percorso '%s' non corrisponde ad alcun file"
 
-#: builtin/apply.c:905
+#: archive.c:396
 #, c-format
-msgid "unable to find filename in patch at line %d"
-msgstr "impossibile trovare il nome del file nella patch alla riga %d"
+msgid "no such ref: %.*s"
+msgstr "riferimento non esistente: %.*s"
 
-#: builtin/apply.c:937
+#: archive.c:401
 #, c-format
-msgid "git apply: bad git-diff - expected /dev/null, got %s on line %d"
-msgstr "git apply: git-diff errato - atteso /dev/null, ricevuto %s alla riga %d"
+msgid "not a valid object name: %s"
+msgstr "%s non è un nome oggetto valido"
 
-#: builtin/apply.c:941
+#: archive.c:414
 #, c-format
-msgid "git apply: bad git-diff - inconsistent new filename on line %d"
-msgstr "git apply: git-diff errato - nuovo nome del file inconsistente alla riga %d"
+msgid "not a tree object: %s"
+msgstr "%s non è un oggetto albero valido"
+
+#: archive.c:426
+msgid "current working directory is untracked"
+msgstr "la directory di lavoro corrente non è tracciata"
+
+#: archive.c:457
+msgid "fmt"
+msgstr "fmt"
+
+#: archive.c:457
+msgid "archive format"
+msgstr "formato archivio"
+
+#: archive.c:458 builtin/log.c:1653
+msgid "prefix"
+msgstr "prefisso"
+
+#: archive.c:459
+msgid "prepend prefix to each pathname in the archive"
+msgstr "anteponi <prefisso> a ogni nome percorso nell'archivio"
+
+#: archive.c:460 builtin/blame.c:861 builtin/blame.c:865 builtin/blame.c:866
+#: builtin/commit-tree.c:117 builtin/config.c:129 builtin/fast-export.c:1162
+#: builtin/fast-export.c:1164 builtin/fast-export.c:1168 builtin/grep.c:899
+#: builtin/hash-object.c:105 builtin/ls-files.c:560 builtin/ls-files.c:563
+#: builtin/notes.c:412 builtin/notes.c:578 builtin/read-tree.c:123
+#: parse-options.h:190
+msgid "file"
+msgstr "file"
+
+#: archive.c:461 builtin/archive.c:90
+msgid "write the archive to this file"
+msgstr "scrivi l'archivio in questo file"
+
+#: archive.c:463
+msgid "read .gitattributes in working directory"
+msgstr "leggi il file .gitattributes nella directory di lavoro"
+
+#: archive.c:464
+msgid "report archived files on stderr"
+msgstr "elenca i file archiviati sullo standard error"
+
+#: archive.c:465
+msgid "store only"
+msgstr "salva solamente"
+
+#: archive.c:466
+msgid "compress faster"
+msgstr "comprimi più velocemente"
+
+#: archive.c:474
+msgid "compress better"
+msgstr "comprimi meglio"
+
+#: archive.c:477
+msgid "list supported archive formats"
+msgstr "elenca i formati archivio supportati"
+
+#: archive.c:479 builtin/archive.c:91 builtin/clone.c:113 builtin/clone.c:116
+#: builtin/submodule--helper.c:1391 builtin/submodule--helper.c:1884
+msgid "repo"
+msgstr "repository"
+
+#: archive.c:480 builtin/archive.c:92
+msgid "retrieve the archive from remote repository <repo>"
+msgstr "recupera l'archivio dal repository remoto <repository>"
+
+#: archive.c:481 builtin/archive.c:93 builtin/difftool.c:715
+#: builtin/notes.c:498
+msgid "command"
+msgstr "comando"
+
+#: archive.c:482 builtin/archive.c:94
+msgid "path to the remote git-upload-archive command"
+msgstr "percorso al comando remoto git-upload-archive"
+
+#: archive.c:489
+msgid "Unexpected option --remote"
+msgstr "Opzione --remote inattesa"
+
+#: archive.c:491
+msgid "Option --exec can only be used together with --remote"
+msgstr "L'opzione --exec può essere usata solo con --remote"
+
+#: archive.c:493
+msgid "Unexpected option --output"
+msgstr "Opzione --output inattesa"
 
-#: builtin/apply.c:942
+#: archive.c:515
 #, c-format
-msgid "git apply: bad git-diff - inconsistent old filename on line %d"
-msgstr "git apply: git-diff errato - vecchio nome del file inconsistente alla riga %d"
+msgid "Unknown archive format '%s'"
+msgstr "Formato archivio '%s' sconosciuto"
 
-#: builtin/apply.c:949
+#: archive.c:522
 #, c-format
-msgid "git apply: bad git-diff - expected /dev/null on line %d"
-msgstr "git apply: git-diff errato - atteso /dev/nulla alla riga %d"
+msgid "Argument not supported for format '%s': -%d"
+msgstr "Argomento non supportato per il formato '%s': -%d"
 
-#: builtin/apply.c:1394
+#: archive-tar.c:125 archive-zip.c:350
 #, c-format
-msgid "recount: unexpected line: %.*s"
-msgstr "recount: riga inattesa: %.*s"
+msgid "cannot stream blob %s"
+msgstr "impossibile eseguire lo streaming del blob %s"
 
-#: builtin/apply.c:1451
+#: archive-tar.c:266 archive-zip.c:368
 #, c-format
-msgid "patch fragment without header at line %d: %.*s"
-msgstr "frammento di patch senza intestazione alla riga %d: %.*s"
+msgid "unsupported file mode: 0%o (SHA1: %s)"
+msgstr "modo file non supportato: 0%o (SHA1: %s)"
 
-#: builtin/apply.c:1468
+#: archive-tar.c:293 archive-zip.c:358
 #, c-format
-msgid ""
-"git diff header lacks filename information when removing %d leading pathname "
-"component (line %d)"
-msgid_plural ""
-"git diff header lacks filename information when removing %d leading pathname "
-"components (line %d)"
-msgstr[0] ""
-msgstr[1] ""
+msgid "cannot read %s"
+msgstr "impossibile leggere %s"
 
-#: builtin/apply.c:1628
-msgid "new file depends on old contents"
-msgstr "il nuovo file dipende da contenuti precedenti"
+#: archive-tar.c:465
+#, c-format
+msgid "unable to start '%s' filter"
+msgstr "impossibile avviare il filtro '%s'"
 
-#: builtin/apply.c:1630
-msgid "deleted file still has contents"
-msgstr "il file eliminato ha ancora dei contenuti"
+#: archive-tar.c:468
+msgid "unable to redirect descriptor"
+msgstr "impossibile ridirezionare il descrittore"
 
-#: builtin/apply.c:1656
+#: archive-tar.c:475
 #, c-format
-msgid "corrupt patch at line %d"
-msgstr ""
+msgid "'%s' filter reported error"
+msgstr "il filtro '%s' ha segnalato un errore"
 
-#: builtin/apply.c:1692
+#: archive-zip.c:319
 #, c-format
-msgid "new file %s depends on old contents"
-msgstr "il nuovo file %s dipende da contenuti precedenti"
+msgid "path is not valid UTF-8: %s"
+msgstr "il percorso non è codificato validamente in UTF-8: %s"
 
-#: builtin/apply.c:1694
+#: archive-zip.c:323
 #, c-format
-msgid "deleted file %s still has contents"
-msgstr "il file eliminato %s ha ancora dei contenuti"
+msgid "path too long (%d chars, SHA1: %s): %s"
+msgstr "percorso troppo lungo (%d caratteri, SHA1: %s): %s"
 
-#: builtin/apply.c:1697
+#: archive-zip.c:479 builtin/pack-objects.c:230 builtin/pack-objects.c:233
 #, c-format
-msgid "** warning: file %s becomes empty but is not deleted"
-msgstr "** attenzione: il file %s diventa vuoto ma non è eliminato"
+msgid "deflate error (%d)"
+msgstr "errore deflate (%d)"
 
-#: builtin/apply.c:1843
+#: archive-zip.c:614
 #, c-format
-msgid "corrupt binary patch at line %d: %.*s"
-msgstr "patch binaria corrotta alla riga %d: %.*s"
+msgid "timestamp too large for this system: %<PRIuMAX>"
+msgstr "timestamp troppo grande per questo sistema: %<PRIuMAX>"
 
-#. there has to be one hunk (forward hunk)
-#: builtin/apply.c:1872
+#: attr.c:212
 #, c-format
-msgid "unrecognized binary patch at line %d"
-msgstr "patch binaria non riconosciuta alla riga %d"
+msgid "%.*s is not a valid attribute name"
+msgstr "%.*s non è un nome attributo valido"
 
-#: builtin/apply.c:1958
+#: attr.c:369
 #, c-format
-msgid "patch with only garbage at line %d"
+msgid "%s not allowed: %s:%d"
+msgstr "%s non consentito: %s:%d"
+
+#: attr.c:409
+msgid ""
+"Negative patterns are ignored in git attributes\n"
+"Use '\\!' for literal leading exclamation."
 msgstr ""
+"I pattern negativi sono ignorati negli attributi git\n"
+"Usa '\\!' per specificare letteralmente un punto esclamativo iniziale."
 
-#: builtin/apply.c:2048
+#: bisect.c:468
 #, c-format
-msgid "unable to read symlink %s"
-msgstr "impossibile leggere il link simbolico %s"
+msgid "Badly quoted content in file '%s': %s"
+msgstr "Contenuto mal racchiuso fra virgolette nel file '%s': %s"
 
-#: builtin/apply.c:2052
+#: bisect.c:678
 #, c-format
-msgid "unable to open or read %s"
-msgstr "impossibile aprire o leggere %s"
+msgid "We cannot bisect more!\n"
+msgstr "Impossibile eseguire un'ulteriore bisezione!\n"
 
-#: builtin/apply.c:2123
-msgid "oops"
-msgstr "oops"
+#: bisect.c:733
+#, c-format
+msgid "Not a valid commit name %s"
+msgstr "%s non è un nome commit valido"
 
-#: builtin/apply.c:2645
+#: bisect.c:758
 #, c-format
-msgid "invalid start of line: '%c'"
-msgstr "inizio della riga non valido: '%c'"
+msgid ""
+"The merge base %s is bad.\n"
+"This means the bug has been fixed between %s and [%s].\n"
+msgstr ""
+"La base del merge %s non funziona.\n"
+"Ciò significa che il bug è stato corretto fra %s e [%s].\n"
 
-#: builtin/apply.c:2763
+#: bisect.c:763
 #, c-format
-msgid "Hunk #%d succeeded at %d (offset %d line)."
-msgid_plural "Hunk #%d succeeded at %d (offset %d lines)."
-msgstr[0] ""
-msgstr[1] ""
+msgid ""
+"The merge base %s is new.\n"
+"The property has changed between %s and [%s].\n"
+msgstr ""
+"La base del merge %s è nuova.\n"
+"La proprietà è stata modificata fra %s e [%s].\n"
 
-#: builtin/apply.c:2775
+#: bisect.c:768
 #, c-format
-msgid "Context reduced to (%ld/%ld) to apply fragment at %d"
+msgid ""
+"The merge base %s is %s.\n"
+"This means the first '%s' commit is between %s and [%s].\n"
 msgstr ""
+"La base del merge %s è %s.\n"
+"Ciò significa che il primo commit '%s' è fra %s e [%s].\n"
 
-#: builtin/apply.c:2781
+#: bisect.c:776
 #, c-format
 msgid ""
-"while searching for:\n"
-"%.*s"
+"Some %s revs are not ancestors of the %s rev.\n"
+"git bisect cannot work properly in this case.\n"
+"Maybe you mistook %s and %s revs?\n"
 msgstr ""
-"durante la ricerca per:\n"
-"%.*s"
+"Alcune revisioni %s non sono antenate della revisione %s.\n"
+"git bisect non può funzionare correttamente in questo caso.\n"
+"Forse hai confuso le revisioni %s con quelle %s?\n"
 
-#: builtin/apply.c:2800
+#: bisect.c:789
 #, c-format
-msgid "missing binary patch data for '%s'"
-msgstr "dati della patch binaria mancanti per '%s'"
+msgid ""
+"the merge base between %s and [%s] must be skipped.\n"
+"So we cannot be sure the first %s commit is between %s and %s.\n"
+"We continue anyway."
+msgstr ""
+"la base del merge fra %s e [%s] dev'essere saltata.\n"
+"Non è possibile essere sicuri che il primo commit %s sia fra %s e %s.\n"
+"Continuo comunque."
 
-#: builtin/apply.c:2903
+#: bisect.c:822
 #, c-format
-msgid "binary patch does not apply to '%s'"
-msgstr "la patch binaria non può essere applicata a '%s'"
+msgid "Bisecting: a merge base must be tested\n"
+msgstr "Bisezione: dev'essere testata una base del merge\n"
 
-#: builtin/apply.c:2909
+#: bisect.c:865
 #, c-format
-msgid "binary patch to '%s' creates incorrect result (expecting %s, got %s)"
-msgstr "la patch binaria su '%s' crea risultati non corretti (atteso %s, ricevuto %s)"
+msgid "a %s revision is needed"
+msgstr "è richiesta una revisione %s"
 
-#: builtin/apply.c:2930
+#: bisect.c:884 builtin/notes.c:177 builtin/tag.c:254
 #, c-format
-msgid "patch failed: %s:%ld"
-msgstr "patch non riuscita: %s:%ld"
+msgid "could not create file '%s'"
+msgstr "impossibile creare il file '%s'"
 
-#: builtin/apply.c:3045
+#: bisect.c:928 builtin/merge.c:148
 #, c-format
-msgid "patch %s has been renamed/deleted"
-msgstr "la patch %s è stata rinominata/eliminata"
+msgid "could not read file '%s'"
+msgstr "impossibile leggere il file '%s'"
 
-#: builtin/apply.c:3052 builtin/apply.c:3069
+#: bisect.c:958
+msgid "reading bisect refs failed"
+msgstr "lettura riferimenti della bisezione non riuscita"
+
+#: bisect.c:977
 #, c-format
-msgid "read of %s failed"
-msgstr "lettura di %s non riuscita"
+msgid "%s was both %s and %s\n"
+msgstr "%s era sia %s sia %s\n"
 
-#: builtin/apply.c:3084
-msgid "removal patch leaves file contents"
-msgstr "la rimozione della patch lascia contenuti del file"
+#: bisect.c:985
+#, c-format
+msgid ""
+"No testable commit found.\n"
+"Maybe you started with bad path parameters?\n"
+msgstr ""
+"Nessun commit testabile trovato.\n"
+"Forse hai iniziato il procedimento specificando parametri percorso errati?\n"
 
-#: builtin/apply.c:3105
+#: bisect.c:1004
 #, c-format
-msgid "%s: already exists in working directory"
-msgstr "%s: esiste già nella directory di lavoro"
+msgid "(roughly %d step)"
+msgid_plural "(roughly %d steps)"
+msgstr[0] "(circa %d passo)"
+msgstr[1] "(circa %d passi)"
 
-#: builtin/apply.c:3143
+#. TRANSLATORS: the last %s will be replaced with "(roughly %d
+#. steps)" translation.
+#.
+#: bisect.c:1010
 #, c-format
-msgid "%s: has been deleted/renamed"
-msgstr "%s: è stata eliminata/rinominata"
+msgid "Bisecting: %d revision left to test after this %s\n"
+msgid_plural "Bisecting: %d revisions left to test after this %s\n"
+msgstr[0] ""
+"Bisezione in corso: %d revisione rimanente da testare dopo questa %s\n"
+msgstr[1] ""
+"Bisezione in corso: %d revisioni rimanenti da testare dopo questa %s\n"
 
-#: builtin/apply.c:3148 builtin/apply.c:3179
+#: blame.c:2700
+msgid "--contents and --reverse do not blend well."
+msgstr "--contents e --reverse non sono compatibili."
+
+#: blame.c:2714
+msgid "cannot use --contents with final commit object name"
+msgstr "impossibile usare --contents con il nome oggetto del commit finale"
+
+#: blame.c:2735
+msgid "--reverse and --first-parent together require specified latest commit"
+msgstr ""
+"le opzioni --reverse e --first-parent se usate insieme richiedono che sia "
+"specificato l'ultimo commit"
+
+#: blame.c:2744 bundle.c:167 ref-filter.c:2203 remote.c:1941 sequencer.c:2093
+#: sequencer.c:4460 builtin/commit.c:1040 builtin/log.c:388 builtin/log.c:991
+#: builtin/log.c:1520 builtin/log.c:1925 builtin/log.c:2215 builtin/merge.c:411
+#: builtin/pack-objects.c:3128 builtin/pack-objects.c:3143
+#: builtin/shortlog.c:192
+msgid "revision walk setup failed"
+msgstr "impostazione percorso revisioni non riuscita"
+
+#: blame.c:2762
+msgid ""
+"--reverse --first-parent together require range along first-parent chain"
+msgstr ""
+"le opzioni --reverse e --first-parent se usate insieme richiedono che sia "
+"specificato un intervallo nella catena del primo commit genitore"
+
+#: blame.c:2773
 #, c-format
-msgid "%s: %s"
-msgstr "%s: %s"
+msgid "no such path %s in %s"
+msgstr "il percorso %s in %s non esiste"
 
-#: builtin/apply.c:3159
+#: blame.c:2784
 #, c-format
-msgid "%s: does not exist in index"
-msgstr "%s: non esiste in index"
+msgid "cannot read blob %s for path %s"
+msgstr "impossibile leggere il blob %s per il percorso %s"
 
-#: builtin/apply.c:3173
+#: branch.c:53
 #, c-format
-msgid "%s: does not match index"
-msgstr "%s: non corrisponde a index"
+msgid ""
+"\n"
+"After fixing the error cause you may try to fix up\n"
+"the remote tracking information by invoking\n"
+"\"git branch --set-upstream-to=%s%s%s\"."
+msgstr ""
+"\n"
+"Dopo aver corretto l'errore è possibile provare a correggere\n"
+"le informazioni di tracciamento remoto eseguendo\n"
+"\"git branch --set-upstream-to=%s%s%s\"."
 
-#: builtin/apply.c:3190
+#: branch.c:67
 #, c-format
-msgid "%s: wrong type"
-msgstr "%s: tipo errato"
+msgid "Not setting branch %s as its own upstream."
+msgstr "Non imposto il branch %s come upstream di sé stesso."
 
-#: builtin/apply.c:3192
+#: branch.c:93
 #, c-format
-msgid "%s has type %o, expected %o"
-msgstr "%s ha il tipo %o, atteso %o"
+msgid "Branch '%s' set up to track remote branch '%s' from '%s' by rebasing."
+msgstr ""
+"Branch '%s' impostato per tracciare il branch remoto '%s' da '%s' tramite "
+"rebase."
 
-#: builtin/apply.c:3247
+#: branch.c:94
 #, c-format
-msgid "%s: already exists in index"
-msgstr "%s: esiste già in index"
+msgid "Branch '%s' set up to track remote branch '%s' from '%s'."
+msgstr "Branch '%s' impostato per tracciare il branch remoto '%s' da '%s'."
 
-#: builtin/apply.c:3267
+#: branch.c:98
 #, c-format
-msgid "new mode (%o) of %s does not match old mode (%o)"
+msgid "Branch '%s' set up to track local branch '%s' by rebasing."
 msgstr ""
+"Branch '%s' impostato per tracciare il branch locale '%s' tramite rebase."
 
-#: builtin/apply.c:3272
+#: branch.c:99
 #, c-format
-msgid "new mode (%o) of %s does not match old mode (%o) of %s"
+msgid "Branch '%s' set up to track local branch '%s'."
+msgstr "Branch '%s' impostato per tracciare il branch locale '%s'."
+
+#: branch.c:104
+#, c-format
+msgid "Branch '%s' set up to track remote ref '%s' by rebasing."
 msgstr ""
+"Branch '%s' impostato per tracciare il riferimento remoto '%s' tramite "
+"rebase."
 
-#: builtin/apply.c:3280
+#: branch.c:105
 #, c-format
-msgid "%s: patch does not apply"
-msgstr "%s: la patch non può essere applicata"
+msgid "Branch '%s' set up to track remote ref '%s'."
+msgstr "Branch '%s' impostato per tracciare il riferimento remoto '%s'."
 
-#: builtin/apply.c:3293
+#: branch.c:109
 #, c-format
-msgid "Checking patch %s..."
-msgstr "Controllo della patch %s..."
+msgid "Branch '%s' set up to track local ref '%s' by rebasing."
+msgstr ""
+"Branch '%s' impostato per tracciare il riferimento locale '%s' tramite "
+"rebase."
 
-#: builtin/apply.c:3348 builtin/checkout.c:212 builtin/reset.c:158
+#: branch.c:110
 #, c-format
-msgid "make_cache_entry failed for path '%s'"
-msgstr "make_cache_entry non riuscito per il path '%s'"
+msgid "Branch '%s' set up to track local ref '%s'."
+msgstr "Branch '%s' impostato per tracciare il riferimento locale '%s'."
+
+#: branch.c:119
+msgid "Unable to write upstream branch configuration"
+msgstr "Impossibile scrivere la configurazione relativa al branch upstream"
 
-#: builtin/apply.c:3491
+#: branch.c:156
 #, c-format
-msgid "unable to remove %s from index"
-msgstr "impossibile rimuovere %s da index"
+msgid "Not tracking: ambiguous information for ref %s"
+msgstr ""
+"Il tracciamento non avverrà: informazioni ambigue per il riferimento %s"
 
-#: builtin/apply.c:3518
+#: branch.c:189
 #, c-format
-msgid "corrupt patch for subproject %s"
-msgstr "patch corrotta per il sottoprogetto %s"
+msgid "'%s' is not a valid branch name."
+msgstr "'%s' non è un nome branch valido."
 
-#: builtin/apply.c:3522
+#: branch.c:208
 #, c-format
-msgid "unable to stat newly created file '%s'"
-msgstr "impossibile eseguire lo stat del file appena creato '%s'"
+msgid "A branch named '%s' already exists."
+msgstr "Un branch denominato '%s' esiste già."
 
-#: builtin/apply.c:3527
+#: branch.c:213
+msgid "Cannot force update the current branch."
+msgstr "Impossibile eseguire un aggiornamento forzato del branch corrente."
+
+#: branch.c:233
 #, c-format
-msgid "unable to create backing store for newly created file %s"
+msgid "Cannot setup tracking information; starting point '%s' is not a branch."
 msgstr ""
+"Impossibile impostare le informazioni di tracciamento: il punto di partenza "
+"'%s' non è un branch."
 
-#: builtin/apply.c:3530
+#: branch.c:235
 #, c-format
-msgid "unable to add cache entry for %s"
-msgstr "impossibile aggiungere la voce della cache per %s"
+msgid "the requested upstream branch '%s' does not exist"
+msgstr "il branch upstream richiesto '%s' non esiste"
+
+#: branch.c:237
+msgid ""
+"\n"
+"If you are planning on basing your work on an upstream\n"
+"branch that already exists at the remote, you may need to\n"
+"run \"git fetch\" to retrieve it.\n"
+"\n"
+"If you are planning to push out a new local branch that\n"
+"will track its remote counterpart, you may want to use\n"
+"\"git push -u\" to set the upstream config as you push."
+msgstr ""
+"\n"
+"Se prevedi di basare il tuo lavoro su un branch\n"
+"upstream già esistente, potresti dover eseguire\n"
+"\"git fetch\" per recuperarlo.\n"
+"\n"
+"Se prevedi di eseguire il push di un nuovo branch locale\n"
+"che traccerà la sua controparte remota, potresti voler\n"
+"usare \"git push -u\" per impostare la configurazione del\n"
+"branch upstream durante il push."
 
-#: builtin/apply.c:3563
+#: branch.c:281
 #, c-format
-msgid "closing file '%s'"
-msgstr "chiusura del file '%s'"
+msgid "Not a valid object name: '%s'."
+msgstr "Nome oggetto non valido: '%s'."
 
-#: builtin/apply.c:3612
+#: branch.c:301
 #, c-format
-msgid "unable to write file '%s' mode %o"
-msgstr "impossibile scrivere il file '%s' in modalità %o"
+msgid "Ambiguous object name: '%s'."
+msgstr "Nome oggetto ambiguo: '%s'."
 
-#: builtin/apply.c:3668
+#: branch.c:306
 #, c-format
-msgid "Applied patch %s cleanly."
-msgstr "Patch %s applicata correttamente."
+msgid "Not a valid branch point: '%s'."
+msgstr "Punto di branch non valido: '%s'."
 
-#: builtin/apply.c:3676
-msgid "internal error"
-msgstr "errore interno"
+#: branch.c:364
+#, c-format
+msgid "'%s' is already checked out at '%s'"
+msgstr "Il checkout di '%s' è già stato eseguito in '%s'"
 
-#. Say this even without --verbose
-#: builtin/apply.c:3679
+#: branch.c:387
 #, c-format
-msgid "Applying patch %%s with %d reject..."
-msgid_plural "Applying patch %%s with %d rejects..."
-msgstr[0] ""
-msgstr[1] ""
+msgid "HEAD of working tree %s is not updated"
+msgstr "L'HEAD dell'albero di lavoro %s non è aggiornato"
 
-#: builtin/apply.c:3689
+#: bundle.c:36
 #, c-format
-msgid "truncating .rej filename to %.*s.rej"
-msgstr ""
+msgid "'%s' does not look like a v2 bundle file"
+msgstr "'%s' non sembra essere un file bundle v2"
 
-#: builtin/apply.c:3710
+#: bundle.c:64
 #, c-format
-msgid "Hunk #%d applied cleanly."
-msgstr "Frammento #%d applicato correttamente."
+msgid "unrecognized header: %s%s (%d)"
+msgstr "intestazione non riconosciuta: %s%s (%d)"
 
-#: builtin/apply.c:3713
+#: bundle.c:90 rerere.c:480 rerere.c:690 sequencer.c:2344 sequencer.c:3108
+#: builtin/commit.c:811
 #, c-format
-msgid "Rejected hunk #%d."
-msgstr "Frammento #%d respinto."
+msgid "could not open '%s'"
+msgstr "impossibile aprire '%s'"
 
-#: builtin/apply.c:3844
-msgid "unrecognized input"
-msgstr "input non riconosciuto"
+#: bundle.c:143
+msgid "Repository lacks these prerequisite commits:"
+msgstr "Dal repository mancano questi commit richiesti come prerequisito:"
 
-#: builtin/apply.c:3855
-msgid "unable to read index file"
-msgstr "impossibile leggere index file"
+#: bundle.c:146
+msgid "need a repository to verify a bundle"
+msgstr "è necessario un repository per verificare un bundle"
 
-#: builtin/apply.c:3970 builtin/apply.c:3973
-msgid "path"
-msgstr "path"
+#: bundle.c:197
+#, c-format
+msgid "The bundle contains this ref:"
+msgid_plural "The bundle contains these %d refs:"
+msgstr[0] "Il bundle contiene questo riferimento:"
+msgstr[1] "Il bundle contiene questi %d riferimenti:"
 
-#: builtin/apply.c:3971
-msgid "don't apply changes matching the given path"
-msgstr "non applica le modifiche corrispondenti al path specificato"
+#: bundle.c:204
+msgid "The bundle records a complete history."
+msgstr "Nel bundle è registrata una cronologia completa."
 
-#: builtin/apply.c:3974
-msgid "apply changes matching the given path"
-msgstr "applica le modifiche corrispondenti al path specificato"
+#: bundle.c:206
+#, c-format
+msgid "The bundle requires this ref:"
+msgid_plural "The bundle requires these %d refs:"
+msgstr[0] "Il bundle richiede questo riferimento:"
+msgstr[1] "Il bundle richiede questi %d riferimenti:"
 
-#: builtin/apply.c:3976
-msgid "num"
-msgstr "num"
+#: bundle.c:273
+msgid "unable to dup bundle descriptor"
+msgstr "impossibile duplicare il descrittore bundle"
 
-#: builtin/apply.c:3977
-msgid "remove <num> leading slashes from traditional diff paths"
-msgstr ""
+#: bundle.c:280
+msgid "Could not spawn pack-objects"
+msgstr "Impossibile avviare pack-objects"
 
-#: builtin/apply.c:3980
-msgid "ignore additions made by the patch"
-msgstr "ignora le aggiunte create dalla patch"
+#: bundle.c:291
+msgid "pack-objects died"
+msgstr "comando pack-objects morto"
 
-#: builtin/apply.c:3982
-msgid "instead of applying the patch, output diffstat for the input"
-msgstr "invece di applicare la patch, mostra l'output di diffstat per l'input"
+#: bundle.c:333
+msgid "rev-list died"
+msgstr "comando rev-list morto"
 
-#: builtin/apply.c:3986
-msgid "shows number of added and deleted lines in decimal notation"
-msgstr "mostra il numero di righe aggiunte e eliminate in notazione decimale"
+#: bundle.c:382
+#, c-format
+msgid "ref '%s' is excluded by the rev-list options"
+msgstr "il riferimento '%s' è escluso dalle opzioni di rev-list"
 
-#: builtin/apply.c:3988
-msgid "instead of applying the patch, output a summary for the input"
-msgstr "invece di applicare la patch, mostra un riassunto per l'input"
+#: bundle.c:461 builtin/log.c:203 builtin/log.c:1814 builtin/shortlog.c:306
+#, c-format
+msgid "unrecognized argument: %s"
+msgstr "argomento non riconosciuto: %s"
 
-#: builtin/apply.c:3990
-msgid "instead of applying the patch, see if the patch is applicable"
-msgstr "invece di applicare la patch, verifica se può essere applicata"
+#: bundle.c:469
+msgid "Refusing to create empty bundle."
+msgstr "Mi rifiuto di creare un bundle vuoto."
 
-#: builtin/apply.c:3992
-msgid "make sure the patch is applicable to the current index"
-msgstr "assicura che la patch sia applicabile all'attuale index"
+#: bundle.c:479
+#, c-format
+msgid "cannot create '%s'"
+msgstr "impossibile creare '%s'"
 
-#: builtin/apply.c:3994
-msgid "apply a patch without touching the working tree"
-msgstr ""
+#: bundle.c:504
+msgid "index-pack died"
+msgstr "comando index-pack morto"
 
-#: builtin/apply.c:3996
-msgid "also apply the patch (use with --stat/--summary/--check)"
-msgstr "applica anche la patch (da usare con --stat/--summary/--check)"
+#: color.c:296
+#, c-format
+msgid "invalid color value: %.*s"
+msgstr "valore colore non valido: %.*s"
 
-#: builtin/apply.c:3998
-msgid "build a temporary index based on embedded index information"
-msgstr ""
+#: commit.c:51 sequencer.c:2811 builtin/am.c:354 builtin/am.c:398
+#: builtin/am.c:1366 builtin/am.c:2009 builtin/replace.c:456
+#, c-format
+msgid "could not parse %s"
+msgstr "impossibile analizzare %s"
 
-#: builtin/apply.c:4000
-msgid "paths are separated with NUL character"
-msgstr "i path sono separati con un carattere NUL"
+#: commit.c:53
+#, c-format
+msgid "%s %s is not a commit!"
+msgstr "%s %s non è un commit!"
 
-#: builtin/apply.c:4003
-msgid "ensure at least <n> lines of context match"
-msgstr "assicura almeno <n> righe di contesto corrispondente"
+#: commit.c:193
+msgid ""
+"Support for <GIT_DIR>/info/grafts is deprecated\n"
+"and will be removed in a future Git version.\n"
+"\n"
+"Please use \"git replace --convert-graft-file\"\n"
+"to convert the grafts into replace refs.\n"
+"\n"
+"Turn this message off by running\n"
+"\"git config advice.graftFileDeprecated false\""
+msgstr ""
+"Il supporto per <GIT_DIR>/info/graft è deprecato\n"
+"e sarà rimosso in una versione futura di Git.\n"
+"\n"
+"Usa \"git replace --convert-graft-file\"\n"
+"per convertire i graft in ref sostitutivi.\n"
+"\n"
+"Per disabilitare questo messaggio, esegui\n"
+"\"git config advice.graftFileDeprecated false\""
 
-#: builtin/apply.c:4004
-msgid "action"
-msgstr "azione"
+#: commit.c:1152
+#, c-format
+msgid "Commit %s has an untrusted GPG signature, allegedly by %s."
+msgstr "Il commit %s ha una firma GPG non affidabile, presumibilmente di %s."
 
-#: builtin/apply.c:4005
-msgid "detect new or modified lines that have whitespace errors"
-msgstr "rileva righe nuove o modificate che hanno errori di spazi bianchi"
+#: commit.c:1155
+#, c-format
+msgid "Commit %s has a bad GPG signature allegedly by %s."
+msgstr "Il commit %s ha una firma GPG non valida presumibilmente di %s."
 
-#: builtin/apply.c:4008 builtin/apply.c:4011
-msgid "ignore changes in whitespace when finding context"
-msgstr ""
+#: commit.c:1158
+#, c-format
+msgid "Commit %s does not have a GPG signature."
+msgstr "Il commit %s non ha una firma GPG."
 
-#: builtin/apply.c:4014
-msgid "apply the patch in reverse"
-msgstr "applica la patch in maniera inversa"
+#: commit.c:1161
+#, c-format
+msgid "Commit %s has a good GPG signature by %s\n"
+msgstr "Il commit %s ha una firma GPG valida di %s\n"
 
-#: builtin/apply.c:4016
-msgid "don't expect at least one line of context"
+#: commit.c:1415
+msgid ""
+"Warning: commit message did not conform to UTF-8.\n"
+"You may want to amend it after fixing the message, or set the config\n"
+"variable i18n.commitencoding to the encoding your project uses.\n"
 msgstr ""
+"Attenzione: il messaggio di commit non è conforme alla codifica UTF-8.\n"
+"Potresti volerlo modificare dopo aver corretto il messaggio, o impostare\n"
+"la variabile di configurazione i18n.commitencoding alla codifica usata\n"
+"dal tuo progetto.\n"
 
-#: builtin/apply.c:4018
-msgid "leave the rejected hunks in corresponding *.rej files"
-msgstr "lascia i frammenti respinti nei file .rej corrispondenti"
+#: commit-graph.c:130
+msgid "commit-graph file is too small"
+msgstr "il file grafo dei commit %s è troppo piccolo"
 
-#: builtin/apply.c:4020
-msgid "allow overlapping hunks"
-msgstr "consente la sovrapposizione dei frammenti"
+#: commit-graph.c:195
+#, c-format
+msgid "commit-graph signature %X does not match signature %X"
+msgstr "la firma del grafo dei commit %X non corrisponde alla firma %X"
 
-#: builtin/apply.c:4021
-msgid "be verbose"
-msgstr "dettagliato"
+#: commit-graph.c:202
+#, c-format
+msgid "commit-graph version %X does not match version %X"
+msgstr "la versione del grafo dei commit %X non corrisponde alla versione %X"
 
-#: builtin/apply.c:4023
-msgid "tolerate incorrectly detected missing new-line at the end of file"
+#: commit-graph.c:209
+#, c-format
+msgid "commit-graph hash version %X does not match version %X"
 msgstr ""
+"la versione hash del grafo dei commit %X non corrisponde alla versione %X"
 
-#: builtin/apply.c:4026
-msgid "do not trust the line counts in the hunk headers"
+#: commit-graph.c:232
+msgid "commit-graph chunk lookup table entry missing; file may be incomplete"
 msgstr ""
+"voce blocco grafo dei commit mancante nella tabella di ricerca; il file "
+"potrebbe non essere completo"
 
-#: builtin/apply.c:4028
-msgid "root"
-msgstr "radice"
+#: commit-graph.c:243
+#, c-format
+msgid "commit-graph improper chunk offset %08x%08x"
+msgstr "offset blocco grafo dei commit improprio %08x%08x"
 
-#: builtin/apply.c:4029
-msgid "prepend <root> to all filenames"
-msgstr "antepone <root> a tutti i nomi file"
+#: commit-graph.c:286
+#, c-format
+msgid "commit-graph chunk id %08x appears multiple times"
+msgstr "l'ID del blocco grafo dei commit %08x compare più volte"
 
-#: builtin/apply.c:4050
-msgid "--index outside a repository"
-msgstr "--index al di fuori di un repository"
+#: commit-graph.c:350
+msgid "commit-graph has no base graphs chunk"
+msgstr "il grafo dei commit non ha un blocco grafi di base"
 
-#: builtin/apply.c:4053
-msgid "--cached outside a repository"
-msgstr "--cached al di fuori di un repository"
+#: commit-graph.c:360
+msgid "commit-graph chain does not match"
+msgstr "la catena del grafo dei commit non corrisponde"
 
-#: builtin/apply.c:4069
+#: commit-graph.c:407
 #, c-format
-msgid "can't open patch '%s'"
-msgstr "impossibile aprire la patch '%s'"
+msgid "invalid commit-graph chain: line '%s' not a hash"
+msgstr "catena grafo dei commit non valida: la riga '%s' non è un hash"
+
+#: commit-graph.c:433
+msgid "unable to find all commit-graph files"
+msgstr "impossibile trovare tutti i file grafo dei commit"
+
+#: commit-graph.c:564 commit-graph.c:624
+msgid "invalid commit position. commit-graph is likely corrupt"
+msgstr ""
+"posizione commit non valida. Il grafo dei commit è probabilmente corrotto"
 
-#: builtin/apply.c:4083
+#: commit-graph.c:585
 #, c-format
-msgid "squelched %d whitespace error"
-msgid_plural "squelched %d whitespace errors"
-msgstr[0] ""
-msgstr[1] ""
+msgid "could not find commit %s"
+msgstr "impossibile trovare il commit %s"
 
-#: builtin/apply.c:4089 builtin/apply.c:4099
+#: commit-graph.c:858 builtin/am.c:1287
 #, c-format
-msgid "%d line adds whitespace errors."
-msgid_plural "%d lines add whitespace errors."
-msgstr[0] "%d riga aggiunge errori di spazi bianchi."
-msgstr[1] "%d righe aggiungono errori di spazi bianchi."
+msgid "unable to parse commit %s"
+msgstr "impossibile analizzare il commit %s"
 
-#: builtin/archive.c:17
+#: commit-graph.c:1017 builtin/pack-objects.c:2641
 #, c-format
-msgid "could not create archive file '%s'"
-msgstr "non è stato possibile creare il file del repository '%s'"
+msgid "unable to get type of object %s"
+msgstr "impossibile recuperare il tipo dell'oggetto %s"
 
-#: builtin/archive.c:20
-msgid "could not redirect output"
-msgstr "non è stato possibile redirigere l'output"
+#: commit-graph.c:1049
+msgid "Loading known commits in commit graph"
+msgstr "Caricamento commit noti nel grafo dei commit in corso"
 
-#: builtin/archive.c:37
-msgid "git archive: Remote with no URL"
-msgstr "git archive: Remote non ha un URL"
+#: commit-graph.c:1066
+msgid "Expanding reachable commits in commit graph"
+msgstr "Espansione dei commit raggiungibili nel grafo dei commit in corso"
 
-#: builtin/archive.c:58
-msgid "git archive: expected ACK/NAK, got EOF"
-msgstr "git archive: atteso ACK/NAK, ricevuto EOF"
+#: commit-graph.c:1085
+msgid "Clearing commit marks in commit graph"
+msgstr "Rimozione dei contrassegni commit nel grafo dei commit in corso"
 
-#: builtin/archive.c:63
-#, c-format
-msgid "git archive: NACK %s"
-msgstr "git archive: NACK %s"
+#: commit-graph.c:1104
+msgid "Computing commit graph generation numbers"
+msgstr "Calcolo numeri generazione del grafo dei commit in corso"
 
-#: builtin/archive.c:65
+#: commit-graph.c:1179
 #, c-format
-msgid "remote error: %s"
-msgstr "errore remoto: %s"
+msgid "Finding commits for commit graph in %d pack"
+msgid_plural "Finding commits for commit graph in %d packs"
+msgstr[0] "Ricerca dei commit per il grafo dei commit in %d pack in corso"
+msgstr[1] "Ricerca dei commit per il grafo dei commit in %d pack in corso"
 
-#: builtin/archive.c:66
-msgid "git archive: protocol error"
-msgstr "git archive: errore del protocollo"
+#: commit-graph.c:1192
+#, c-format
+msgid "error adding pack %s"
+msgstr "errore durante l'aggiunta del pack %s"
 
-#: builtin/archive.c:71
-msgid "git archive: expected a flush"
-msgstr "git archive: atteso un flush"
+#: commit-graph.c:1196
+#, c-format
+msgid "error opening index for %s"
+msgstr "errore durante l'apertura dell'indice per %s"
 
-#: builtin/branch.c:144
+#: commit-graph.c:1220
 #, c-format
-msgid ""
-"deleting branch '%s' that has been merged to\n"
-"         '%s', but not yet merged to HEAD."
-msgstr ""
+msgid "Finding commits for commit graph from %d ref"
+msgid_plural "Finding commits for commit graph from %d refs"
+msgstr[0] ""
+"Ricerca dei commit per il grafo dei commit da %d riferimento in corso"
+msgstr[1] ""
+"Ricerca dei commit per il grafo dei commit da %d riferimenti in corso"
 
-#: builtin/branch.c:148
+#: commit-graph.c:1240
 #, c-format
-msgid ""
-"not deleting branch '%s' that is not yet merged to\n"
-"         '%s', even though it is merged to HEAD."
+msgid "invalid commit object id: %s"
+msgstr "ID oggetto commit non valido: %s"
+
+#: commit-graph.c:1255
+msgid "Finding commits for commit graph among packed objects"
 msgstr ""
+"Ricerca dei commit per il grafo dei commit fra gli oggetti nei pack in corso"
 
-#: builtin/branch.c:180
-msgid "cannot use -a with -d"
-msgstr "impossibile usare -a con -d"
+#: commit-graph.c:1270
+msgid "Counting distinct commits in commit graph"
+msgstr "Conteggio commit distinti nel grafo dei commit in corso"
 
-#: builtin/branch.c:186
-msgid "Couldn't look up commit object for HEAD"
-msgstr ""
+#: commit-graph.c:1300
+msgid "Finding extra edges in commit graph"
+msgstr "Ricerca degli archi aggiuntivi nel grafo dei commit in corso"
 
-#: builtin/branch.c:191
-#, c-format
-msgid "Cannot delete the branch '%s' which you are currently on."
-msgstr ""
+#: commit-graph.c:1346
+msgid "failed to write correct number of base graph ids"
+msgstr "impossibile scrivere il numero esatto degli ID grafo di base"
 
-#: builtin/branch.c:202
+#: commit-graph.c:1379 midx.c:814
 #, c-format
-msgid "remote branch '%s' not found."
-msgstr "il branch remoto '%s' non è stato trovato."
+msgid "unable to create leading directories of %s"
+msgstr "impossibile creare le prime directory di %s"
 
-#: builtin/branch.c:203
+#: commit-graph.c:1391 builtin/index-pack.c:306 builtin/repack.c:248
 #, c-format
-msgid "branch '%s' not found."
-msgstr "branch '%s' non trovato."
+msgid "unable to create '%s'"
+msgstr "impossibile creare '%s'"
 
-#: builtin/branch.c:210
+#: commit-graph.c:1451
 #, c-format
-msgid "Couldn't look up commit object for '%s'"
-msgstr ""
+msgid "Writing out commit graph in %d pass"
+msgid_plural "Writing out commit graph in %d passes"
+msgstr[0] "Scrittura in %d passaggio del grafo dei commit in corso"
+msgstr[1] "Scrittura in %d passaggi del grafo dei commit in corso"
 
-#: builtin/branch.c:216
-#, c-format
-msgid ""
-"The branch '%s' is not fully merged.\n"
-"If you are sure you want to delete it, run 'git branch -D %s'."
-msgstr ""
+#: commit-graph.c:1492
+msgid "unable to open commit-graph chain file"
+msgstr "impossibile aprire il file catena grafo dei commit"
 
-#: builtin/branch.c:225
-#, c-format
-msgid "Error deleting remote branch '%s'"
-msgstr "Errore nella rimozione del branch remoto '%s'"
+#: commit-graph.c:1504
+msgid "failed to rename base commit-graph file"
+msgstr "impossibile ridenominare il file di base grafo dei commit"
 
-#: builtin/branch.c:226
-#, c-format
-msgid "Error deleting branch '%s'"
-msgstr "Errore nella rimozione del branch '%s'"
+#: commit-graph.c:1524
+msgid "failed to rename temporary commit-graph file"
+msgstr "impossibile ridenominare il file temporaneo grafo dei commit"
 
-#: builtin/branch.c:233
-#, c-format
-msgid "Deleted remote branch %s (was %s).\n"
-msgstr "Ramo remoto %s eliminato (era %s).\n"
+#: commit-graph.c:1635
+msgid "Scanning merged commits"
+msgstr "Scansione dei commit sottoposti a merge in corso"
 
-#: builtin/branch.c:234
+#: commit-graph.c:1646
 #, c-format
-msgid "Deleted branch %s (was %s).\n"
-msgstr "Ramo %s eliminato (era %s).\n"
+msgid "unexpected duplicate commit id %s"
+msgstr "ID commit duplicato inatteso: %s"
 
-#: builtin/branch.c:239
-msgid "Update of config-file failed"
-msgstr "Aggiornamento del file di configurazione fallito"
+#: commit-graph.c:1670
+msgid "Merging commit-graph"
+msgstr "Merge del grafo dei commit in corso"
 
-#: builtin/branch.c:337
+#: commit-graph.c:1860
 #, c-format
-msgid "branch '%s' does not point at a commit"
-msgstr "il branch '%s' non punta ad un commit"
+msgid "the commit graph format cannot write %d commits"
+msgstr ""
+"il formato del grafo dei commit non può essere usato per scrivere %d commit"
 
-#: builtin/branch.c:409
-#, c-format
-msgid "[%s: behind %d]"
-msgstr "[%s: dietro %d]"
+#: commit-graph.c:1871
+msgid "too many commits to write graph"
+msgstr "troppi commit da scrivere nel grafo"
 
-#: builtin/branch.c:411
-#, c-format
-msgid "[behind %d]"
-msgstr "[dietro %d]"
+#: commit-graph.c:1961
+msgid "the commit-graph file has incorrect checksum and is likely corrupt"
+msgstr ""
+"il file del grafo dei commit ha un checksum non corretto e probabilmente è "
+"corrotto"
 
-#: builtin/branch.c:415
+#: commit-graph.c:1971
 #, c-format
-msgid "[%s: ahead %d]"
-msgstr "[%s: avanti %d]"
+msgid "commit-graph has incorrect OID order: %s then %s"
+msgstr "il grafo dei commit ha un ordine OID non corretto: %s seguito da %s"
 
-#: builtin/branch.c:417
+#: commit-graph.c:1981 commit-graph.c:1996
 #, c-format
-msgid "[ahead %d]"
+msgid "commit-graph has incorrect fanout value: fanout[%d] = %u != %u"
 msgstr ""
+"il grafo dei commit ha un valore fanout non corretto: fanout[%d] = %u != %u"
 
-#: builtin/branch.c:420
+#: commit-graph.c:1988
 #, c-format
-msgid "[%s: ahead %d, behind %d]"
-msgstr ""
+msgid "failed to parse commit %s from commit-graph"
+msgstr "impossibile analizzare il commit %s nel grafo dei commit"
 
-#: builtin/branch.c:423
+#: commit-graph.c:2006
+msgid "Verifying commits in commit graph"
+msgstr "Verifica dei commit nel grafo dei commit in corso"
+
+#: commit-graph.c:2020
 #, c-format
-msgid "[ahead %d, behind %d]"
+msgid "failed to parse commit %s from object database for commit-graph"
 msgstr ""
+"impossibile analizzare il commit %s dal database oggetti per il grafo dei "
+"commit"
 
-#: builtin/branch.c:535
-msgid "(no branch)"
-msgstr "(nessun branch)"
-
-#: builtin/branch.c:600
-msgid "some refs could not be read"
+#: commit-graph.c:2027
+#, c-format
+msgid "root tree OID for commit %s in commit-graph is %s != %s"
 msgstr ""
+"l'OID dell'albero radice per il commit %s nel grafo dei commit è %s != %s"
 
-#: builtin/branch.c:613
-msgid "cannot rename the current branch while not on any."
-msgstr ""
+#: commit-graph.c:2037
+#, c-format
+msgid "commit-graph parent list for commit %s is too long"
+msgstr "l'elenco genitori nel grafo dei commit per il commit %s è troppo lungo"
 
-#: builtin/branch.c:623
+#: commit-graph.c:2046
 #, c-format
-msgid "Invalid branch name: '%s'"
-msgstr "Nome del branch non valido: '%s'"
+msgid "commit-graph parent for %s is %s != %s"
+msgstr "il genitore nel grafo dei commit per %s è %s != %s"
 
-#: builtin/branch.c:638
-msgid "Branch rename failed"
+#: commit-graph.c:2059
+#, c-format
+msgid "commit-graph parent list for commit %s terminates early"
 msgstr ""
+"l'elenco genitori nel grafo dei commit per il commit %s è finito prima del "
+"previsto"
 
-#: builtin/branch.c:642
+#: commit-graph.c:2064
 #, c-format
-msgid "Renamed a misnamed branch '%s' away"
+msgid ""
+"commit-graph has generation number zero for commit %s, but non-zero elsewhere"
 msgstr ""
+"il grafo dei commit ha un numero generazione zero per il commit %s ma non "
+"pari a zero per gli altri"
 
-#: builtin/branch.c:646
+#: commit-graph.c:2068
 #, c-format
-msgid "Branch renamed to %s, but HEAD is not updated!"
-msgstr "Ramo rinominato in %s, ma HEAD non è aggiornato!"
-
-#: builtin/branch.c:653
-msgid "Branch is renamed, but update of config-file failed"
+msgid ""
+"commit-graph has non-zero generation number for commit %s, but zero elsewhere"
 msgstr ""
-"Il branch è stato rinominato, ma l'aggiornamento del file di configurazione "
-"è fallito"
+"il grafo dei commit ha un numero generazione non pari a zero per il commit "
+"%s ma pari a zero per gli altri"
 
-#: builtin/branch.c:668
+#: commit-graph.c:2083
 #, c-format
-msgid "malformed object name %s"
-msgstr "nome dell'oggetto %s errato"
+msgid "commit-graph generation for commit %s is %u != %u"
+msgstr "il numero generazione nel grafo dei commit per il commit %s è %u != %u"
 
-#: builtin/branch.c:692
+#: commit-graph.c:2089
 #, c-format
-msgid "could not write branch description template: %s"
+msgid "commit date for commit %s in commit-graph is %<PRIuMAX> != %<PRIuMAX>"
 msgstr ""
+"la data per il commit %s nel grafo dei commit è %<PRIuMAX> != %<PRIuMAX>"
 
-#: builtin/branch.c:783
-msgid "Failed to resolve HEAD as a valid ref."
-msgstr ""
+#: compat/obstack.c:406 compat/obstack.c:408
+msgid "memory exhausted"
+msgstr "memoria esaurita"
 
-#: builtin/branch.c:788 builtin/clone.c:558
-msgid "HEAD not found below refs/heads!"
+#: config.c:124
+#, c-format
+msgid ""
+"exceeded maximum include depth (%d) while including\n"
+"\t%s\n"
+"from\n"
+"\t%s\n"
+"This might be due to circular includes."
 msgstr ""
+"profondità massima di inclusione (%d) superata durante l'inclusione di\n"
+"\t%s\n"
+"da\n"
+"\t%s\n"
+"Ciò può essere dovuto a delle inclusioni circolari."
 
-#: builtin/branch.c:808
-msgid "--column and --verbose are incompatible"
-msgstr "--column e --verbose non sono compatibili"
+#: config.c:140
+#, c-format
+msgid "could not expand include path '%s'"
+msgstr "impossibile espandere il percorso di inclusione '%s'"
 
-#: builtin/branch.c:857
-msgid "-a and -r options to 'git branch' do not make sense with a branch name"
+#: config.c:151
+msgid "relative config includes must come from files"
+msgstr "le inclusioni configurazione relative devono provenire da file"
+
+#: config.c:197
+msgid "relative config include conditionals must come from files"
 msgstr ""
-"le opzioni -a e -r per 'git branch' non hanno senso con il nome di un branch"
+"i condizionali di inclusione configurazione relativi devono provenire da file"
 
-#: builtin/bundle.c:47
+#: config.c:376
 #, c-format
-msgid "%s is okay\n"
-msgstr "%s è corretto\n"
+msgid "key does not contain a section: %s"
+msgstr "la chiave non contiene una sezione: %s"
 
-#: builtin/bundle.c:56
-msgid "Need a repository to create a bundle."
-msgstr ""
+#: config.c:382
+#, c-format
+msgid "key does not contain variable name: %s"
+msgstr "la chiave non contiene un nome variabile: %s"
 
-#: builtin/bundle.c:60
-msgid "Need a repository to unbundle."
-msgstr ""
+#: config.c:406 sequencer.c:2530
+#, c-format
+msgid "invalid key: %s"
+msgstr "chiave non valida: %s"
 
-#: builtin/checkout.c:113 builtin/checkout.c:146
+#: config.c:412
 #, c-format
-msgid "path '%s' does not have our version"
-msgstr "il path '%s' non ha la nostra versione"
+msgid "invalid key (newline): %s"
+msgstr "chiave non valida (nuova riga): %s"
 
-#: builtin/checkout.c:115 builtin/checkout.c:148
+#: config.c:448 config.c:460
 #, c-format
-msgid "path '%s' does not have their version"
-msgstr "il path '%s' non ha la loro versione"
+msgid "bogus config parameter: %s"
+msgstr "parametro configurazione fittizio: %s"
 
-#: builtin/checkout.c:131
+#: config.c:495
 #, c-format
-msgid "path '%s' does not have all necessary versions"
-msgstr ""
+msgid "bogus format in %s"
+msgstr "formato fittizio in %s"
 
-#: builtin/checkout.c:175
+#: config.c:821
 #, c-format
-msgid "path '%s' does not have necessary versions"
-msgstr "il path '%s' non ha le versioni necessarie"
+msgid "bad config line %d in blob %s"
+msgstr "riga configurazione %d errata nel blob %s"
 
-#: builtin/checkout.c:192
+#: config.c:825
 #, c-format
-msgid "path '%s': cannot merge"
-msgstr ""
+msgid "bad config line %d in file %s"
+msgstr "riga configurazione %d errata nel file %s"
 
-#: builtin/checkout.c:209
+#: config.c:829
 #, c-format
-msgid "Unable to add merge result for '%s'"
-msgstr ""
+msgid "bad config line %d in standard input"
+msgstr "riga configurazione %d errata nello standard input"
 
-#: builtin/checkout.c:234 builtin/checkout.c:392
-msgid "corrupt index file"
-msgstr "file index corrotto"
+#: config.c:833
+#, c-format
+msgid "bad config line %d in submodule-blob %s"
+msgstr "riga configurazione %d errata nel blob sottomodulo %s"
 
-#: builtin/checkout.c:264 builtin/checkout.c:271
+#: config.c:837
 #, c-format
-msgid "path '%s' is unmerged"
-msgstr ""
+msgid "bad config line %d in command line %s"
+msgstr "riga configurazione %d errata nella riga di comando %s"
 
-#: builtin/checkout.c:302 builtin/checkout.c:498 builtin/clone.c:583
-#: builtin/merge.c:812
-msgid "unable to write new index file"
-msgstr "impossibile scrivere il nuovo file index"
+#: config.c:841
+#, c-format
+msgid "bad config line %d in %s"
+msgstr "riga configurazione %d errata in %s"
 
-#: builtin/checkout.c:319 builtin/diff.c:302 builtin/merge.c:408
-msgid "diff_setup_done failed"
-msgstr "diff_setup_done non riuscito"
+#: config.c:978
+msgid "out of range"
+msgstr "fuori intervallo"
 
-#: builtin/checkout.c:414
-msgid "you need to resolve your current index first"
-msgstr "è necessario risolvere prima l'attuale index"
+#: config.c:978
+msgid "invalid unit"
+msgstr "unità non valida"
 
-#: builtin/checkout.c:533
+#: config.c:979
 #, c-format
-msgid "Can not do reflog for '%s'\n"
-msgstr ""
-
-#: builtin/checkout.c:566
-msgid "HEAD is now at"
-msgstr "HEAD si trova ora a"
+msgid "bad numeric config value '%s' for '%s': %s"
+msgstr "valore configurazione numerico '%s' errato per '%s': %s"
 
-#: builtin/checkout.c:573
+#: config.c:998
 #, c-format
-msgid "Reset branch '%s'\n"
-msgstr "Ripristina il branch '%s'\n"
+msgid "bad numeric config value '%s' for '%s' in blob %s: %s"
+msgstr "valore configurazione numerico '%s' errato per '%s' nel blob %s: %s"
 
-#: builtin/checkout.c:576
+#: config.c:1001
 #, c-format
-msgid "Already on '%s'\n"
-msgstr "Si è già su '%s'\n"
+msgid "bad numeric config value '%s' for '%s' in file %s: %s"
+msgstr "valore configurazione numerico '%s' errato per '%s' nel file %s: %s"
 
-#: builtin/checkout.c:580
+#: config.c:1004
 #, c-format
-msgid "Switched to and reset branch '%s'\n"
+msgid "bad numeric config value '%s' for '%s' in standard input: %s"
 msgstr ""
+"valore configurazione numerico '%s' errato per '%s' nello standard input: %s"
 
-#: builtin/checkout.c:582
+#: config.c:1007
 #, c-format
-msgid "Switched to a new branch '%s'\n"
+msgid "bad numeric config value '%s' for '%s' in submodule-blob %s: %s"
 msgstr ""
+"valore configurazione numerico '%s' errato per '%s' nel blob sottomodulo %s: "
+"%s"
 
-#: builtin/checkout.c:584
+#: config.c:1010
 #, c-format
-msgid "Switched to branch '%s'\n"
-msgstr "Si è passati al branch '%s'\n"
+msgid "bad numeric config value '%s' for '%s' in command line %s: %s"
+msgstr ""
+"valore configurazione numerico '%s' errato per '%s' nella riga di comando "
+"%s: %s"
 
-#: builtin/checkout.c:640
+#: config.c:1013
 #, c-format
-msgid " ... and %d more.\n"
-msgstr " ... e %d altri.\n"
+msgid "bad numeric config value '%s' for '%s' in %s: %s"
+msgstr "valore configurazione numerico '%s' errato per '%s' in %s: %s"
 
-#. The singular version
-#: builtin/checkout.c:646
+#: config.c:1108
 #, c-format
-msgid ""
-"Warning: you are leaving %d commit behind, not connected to\n"
-"any of your branches:\n"
-"\n"
-"%s\n"
-msgid_plural ""
-"Warning: you are leaving %d commits behind, not connected to\n"
-"any of your branches:\n"
-"\n"
-"%s\n"
-msgstr[0] ""
-msgstr[1] ""
+msgid "failed to expand user dir in: '%s'"
+msgstr "espansione directory utente in '%s' non riuscita"
 
-#: builtin/checkout.c:664
+#: config.c:1117
 #, c-format
-msgid ""
-"If you want to keep them by creating a new branch, this may be a good time\n"
-"to do so with:\n"
-"\n"
-" git branch new_branch_name %s\n"
-"\n"
-msgstr ""
-"Se si vuole mantenerle creando un nuovo branch, questo potrebbe essere\n"
-"un buon momento per farlo con:\n"
-"\n"
-" git branch nuovo_nome_branch %s\n"
-"\n"
-
-#: builtin/checkout.c:694
-msgid "internal error in revision walk"
-msgstr ""
-
-#: builtin/checkout.c:698
-msgid "Previous HEAD position was"
-msgstr "La precedente posizione di HEAD era"
-
-#: builtin/checkout.c:724
-msgid "You are on a branch yet to be born"
-msgstr ""
+msgid "'%s' for '%s' is not a valid timestamp"
+msgstr "'%s' per '%s' non è un timestamp valido"
 
-#. case (1)
-#: builtin/checkout.c:855
+#: config.c:1208
 #, c-format
-msgid "invalid reference: %s"
-msgstr "riferimento non valido: %s"
+msgid "abbrev length out of range: %d"
+msgstr "lunghezza abbreviazione fuori intervallo: %d"
 
-#. case (1): want a tree
-#: builtin/checkout.c:894
+#: config.c:1222 config.c:1233
 #, c-format
-msgid "reference is not a tree: %s"
-msgstr ""
+msgid "bad zlib compression level %d"
+msgstr "livello compressione zlib %d non valido"
 
-#: builtin/checkout.c:974
-msgid "-B cannot be used with -b"
-msgstr "-B non può essere usata con -b"
-
-#: builtin/checkout.c:983
-msgid "--patch is incompatible with all other options"
-msgstr "--patch non è compatibile con tutte le altre opzioni"
-
-#: builtin/checkout.c:986
-msgid "--detach cannot be used with -b/-B/--orphan"
-msgstr "--detach non può essere usata con -b/-B/--orphan"
-
-#: builtin/checkout.c:988
-msgid "--detach cannot be used with -t"
-msgstr "--detach non può essere usata con -t"
+#: config.c:1325
+msgid "core.commentChar should only be one character"
+msgstr "core.commentChar dovrebbe essere composto da un solo carattere"
 
-#: builtin/checkout.c:994
-msgid "--track needs a branch name"
-msgstr "--track necessita del nome di un branch"
+#: config.c:1358
+#, c-format
+msgid "invalid mode for object creation: %s"
+msgstr "modalità non valida per la creazione di un oggetto: %s"
 
-#: builtin/checkout.c:1001
-msgid "Missing branch name; try -b"
-msgstr "Nome del branch mancante; prova con -b"
+#: config.c:1430
+#, c-format
+msgid "malformed value for %s"
+msgstr "valore malformato per %s"
 
-#: builtin/checkout.c:1007
-msgid "--orphan and -b|-B are mutually exclusive"
-msgstr ""
+#: config.c:1456
+#, c-format
+msgid "malformed value for %s: %s"
+msgstr "valore malformato per %s: %s"
 
-#: builtin/checkout.c:1009
-msgid "--orphan cannot be used with -t"
-msgstr "--orphan non può essere usata con -t"
+#: config.c:1457
+msgid "must be one of nothing, matching, simple, upstream or current"
+msgstr "dev'essere nothing, matching, simple, upstream o current"
 
-#: builtin/checkout.c:1019
-msgid "git checkout: -f and -m are incompatible"
-msgstr "git checkout: -f e -m non sono compatibili"
+#: config.c:1518 builtin/pack-objects.c:3394
+#, c-format
+msgid "bad pack compression level %d"
+msgstr "livello compressione pack %d non valido"
 
-#: builtin/checkout.c:1053
-msgid "invalid path specification"
-msgstr ""
+#: config.c:1639
+#, c-format
+msgid "unable to load config blob object '%s'"
+msgstr "impossibile caricare l'oggetto blob configurazione '%s'"
 
-#: builtin/checkout.c:1061
+#: config.c:1642
 #, c-format
-msgid ""
-"git checkout: updating paths is incompatible with switching branches.\n"
-"Did you intend to checkout '%s' which can not be resolved as commit?"
-msgstr ""
+msgid "reference '%s' does not point to a blob"
+msgstr "il riferimento '%s' non punta ad un blob"
 
-#: builtin/checkout.c:1063
-msgid "git checkout: updating paths is incompatible with switching branches."
-msgstr ""
+#: config.c:1659
+#, c-format
+msgid "unable to resolve config blob '%s'"
+msgstr "impossibile risolvere il blob configurazione '%s'"
 
-#: builtin/checkout.c:1068
-msgid "git checkout: --detach does not take a path argument"
-msgstr "git checkout: --detach non prende un path come argomento"
+#: config.c:1689
+#, c-format
+msgid "failed to parse %s"
+msgstr "analisi di %s non riuscita"
 
-#: builtin/checkout.c:1071
-msgid ""
-"git checkout: --ours/--theirs, --force and --merge are incompatible when\n"
-"checking out of the index."
-msgstr ""
+#: config.c:1745
+msgid "unable to parse command-line config"
+msgstr "impossibile analizzare la configurazione a riga di comando"
 
-#: builtin/checkout.c:1090
-msgid "Cannot switch branch to a non-commit."
+#: config.c:2096
+msgid "unknown error occurred while reading the configuration files"
 msgstr ""
+"si è verificato un errore imprevisto durante la lettura dei file di "
+"configurazione"
 
-#: builtin/checkout.c:1093
-msgid "--ours/--theirs is incompatible with switching branches."
-msgstr "--ours/--theirs non sono compatibili con il passaggio ai branch."
-
-#: builtin/clean.c:78
-msgid "-x and -X cannot be used together"
-msgstr "-x e -X non possono essere usati insieme"
+#: config.c:2266
+#, c-format
+msgid "Invalid %s: '%s'"
+msgstr "%s non valido: '%s'"
 
-#: builtin/clean.c:82
-msgid ""
-"clean.requireForce set to true and neither -n nor -f given; refusing to clean"
+#: config.c:2311
+#, c-format
+msgid "splitIndex.maxPercentChange value '%d' should be between 0 and 100"
 msgstr ""
-"clean.requireForce è impostato a vero, ma né -n né -f sono state specificate; "
-"clean interrotto"
+"il valore splitIndex.maxPercentChange '%d' dovrebbe essere compreso fra 0 e "
+"100"
 
-#: builtin/clean.c:85
-msgid ""
-"clean.requireForce defaults to true and neither -n nor -f given; refusing to "
-"clean"
-msgstr ""
-"clean.requireForce è vero per default, ma né -n né -f sono state specificate; "
-"clean interrotto"
+#: config.c:2357
+#, c-format
+msgid "unable to parse '%s' from command-line config"
+msgstr "impossibile analizzare '%s' dalla configurazione a riga di comando"
 
-#: builtin/clean.c:155 builtin/clean.c:176
+#: config.c:2359
 #, c-format
-msgid "Would remove %s\n"
-msgstr ""
+msgid "bad config variable '%s' in file '%s' at line %d"
+msgstr "variabile configurazione '%s' errata nel file '%s' alla riga %d"
 
-#: builtin/clean.c:159 builtin/clean.c:179
+#: config.c:2440
 #, c-format
-msgid "Removing %s\n"
-msgstr "Rimozione di %s\n"
+msgid "invalid section name '%s'"
+msgstr "nome sezione '%s' non valido"
 
-#: builtin/clean.c:162 builtin/clean.c:182
+#: config.c:2472
 #, c-format
-msgid "failed to remove %s"
-msgstr "rimozione di %s non riuscita"
+msgid "%s has multiple values"
+msgstr "%s ha più valori"
 
-#: builtin/clean.c:166
+#: config.c:2501
 #, c-format
-msgid "Would not remove %s\n"
-msgstr ""
+msgid "failed to write new configuration file %s"
+msgstr "scrittura del nuovo file di configurazione %s non riuscita"
 
-#: builtin/clean.c:168
+#: config.c:2753 config.c:3077
 #, c-format
-msgid "Not removing %s\n"
-msgstr ""
+msgid "could not lock config file %s"
+msgstr "impossibile bloccare il file di configurazione %s"
 
-#: builtin/clone.c:243
+#: config.c:2764
 #, c-format
-msgid "reference repository '%s' is not a local directory."
-msgstr "il repository di riferimento '%s' non è una directory locale."
+msgid "opening %s"
+msgstr "apertura di %s in corso"
 
-#: builtin/clone.c:302
+#: config.c:2799 builtin/config.c:328
 #, c-format
-msgid "failed to open '%s'"
-msgstr "apertura di '%s' non riuscita"
+msgid "invalid pattern: %s"
+msgstr "pattern non valido: %s"
 
-#: builtin/clone.c:306
+#: config.c:2824
 #, c-format
-msgid "failed to create directory '%s'"
-msgstr "creazione della directory '%s' non riuscita"
+msgid "invalid config file %s"
+msgstr "file di configurazione %s non valido"
 
-#: builtin/clone.c:308 builtin/diff.c:75
+#: config.c:2837 config.c:3090
 #, c-format
-msgid "failed to stat '%s'"
-msgstr "stat di '%s' non riuscito"
+msgid "fstat on %s failed"
+msgstr "fstat di %s non riuscita"
 
-#: builtin/clone.c:310
+#: config.c:2848
 #, c-format
-msgid "%s exists and is not a directory"
-msgstr "%s esiste e non è una directory"
+msgid "unable to mmap '%s'"
+msgstr "impossibile eseguire mmap su '%s'"
 
-#: builtin/clone.c:324
+#: config.c:2857 config.c:3095
 #, c-format
-msgid "failed to stat %s\n"
-msgstr "stat di %s non riuscito\n"
+msgid "chmod on %s failed"
+msgstr "esecuzione chmod su %s non riuscita"
 
-#: builtin/clone.c:341
+#: config.c:2942 config.c:3192
 #, c-format
-msgid "failed to unlink '%s'"
-msgstr "rimozione del link '%s' non riuscita"
+msgid "could not write config file %s"
+msgstr "impossibile scrivere il file di configurazione %s"
 
-#: builtin/clone.c:346
+#: config.c:2976
 #, c-format
-msgid "failed to create link '%s'"
-msgstr "creazione del link '%s' non riuscita"
+msgid "could not set '%s' to '%s'"
+msgstr "impossibile impostare '%s' a '%s'"
 
-#: builtin/clone.c:350
+#: config.c:2978 builtin/remote.c:781
 #, c-format
-msgid "failed to copy file to '%s'"
-msgstr "copia del file in '%s' non riuscita"
+msgid "could not unset '%s'"
+msgstr "impossibile eliminare l'impostazione di '%s'"
 
-#: builtin/clone.c:373
+#: config.c:3068
 #, c-format
-msgid "done.\n"
-msgstr "fatto.\n"
+msgid "invalid section name: %s"
+msgstr "nome sezione non valido: %s"
 
-#: builtin/clone.c:440
+#: config.c:3235
 #, c-format
-msgid "Could not find remote branch %s to clone."
-msgstr "Non è stato possibile trovare il branch remoto %s da clonare."
+msgid "missing value for '%s'"
+msgstr "valore mancante per '%s'"
 
-#: builtin/clone.c:549
-msgid "remote HEAD refers to nonexistent ref, unable to checkout.\n"
+#: connect.c:61
+msgid "the remote end hung up upon initial contact"
 msgstr ""
-"l'HEAD remoto si riferisce ad un ref inesistente, impossibile eseguire il "
-"checkout.\n"
-
-#: builtin/clone.c:639
-msgid "Too many arguments."
-msgstr "Troppi argomenti."
+"la controparte remota ha chiuso la connessione durante il contatto iniziale"
 
-#: builtin/clone.c:643
-msgid "You must specify a repository to clone."
-msgstr "Devi specificare un repository da clonare."
+#: connect.c:63
+msgid ""
+"Could not read from remote repository.\n"
+"\n"
+"Please make sure you have the correct access rights\n"
+"and the repository exists."
+msgstr ""
+"Impossibile leggere dal repository remoto.\n"
+"\n"
+"Assicurati di disporre dei privilegi d'accesso corretti\n"
+"e che il repository esista."
 
-#: builtin/clone.c:654
+#: connect.c:81
 #, c-format
-msgid "--bare and --origin %s options are incompatible."
-msgstr "le opzioni --bare e --origin %s non sono compatibili."
+msgid "server doesn't support '%s'"
+msgstr "il server non supporta '%s'"
 
-#: builtin/clone.c:668
+#: connect.c:103
 #, c-format
-msgid "repository '%s' does not exist"
-msgstr "il repository '%s' non esiste"
+msgid "server doesn't support feature '%s'"
+msgstr "il server non supporta la funzionalità '%s'"
 
-#: builtin/clone.c:673
-msgid "--depth is ignored in local clones; use file:// instead."
-msgstr ""
+#: connect.c:114
+msgid "expected flush after capabilities"
+msgstr "atteso flush dopo lettura funzionalità"
 
-#: builtin/clone.c:683
+#: connect.c:233
 #, c-format
-msgid "destination path '%s' already exists and is not an empty directory."
-msgstr ""
-"il path di destinazione '%s' esiste già e non è una directory vuota."
+msgid "ignoring capabilities after first line '%s'"
+msgstr "ignoro le funzionalità dopo la prima riga '%s'"
 
-#: builtin/clone.c:693
-#, c-format
-msgid "working tree '%s' already exists."
-msgstr ""
+#: connect.c:252
+msgid "protocol error: unexpected capabilities^{}"
+msgstr "errore protocollo: capabilities^{} non atteso"
 
-#: builtin/clone.c:706 builtin/clone.c:720
+#: connect.c:273
 #, c-format
-msgid "could not create leading directories of '%s'"
-msgstr ""
+msgid "protocol error: expected shallow sha-1, got '%s'"
+msgstr "errore protocollo: atteso SHA1 shallow, ricevuto '%s'"
 
-#: builtin/clone.c:709
-#, c-format
-msgid "could not create work tree dir '%s'."
-msgstr ""
+#: connect.c:275
+msgid "repository on the other end cannot be shallow"
+msgstr "il repository della controparte non può essere shallow"
 
-#: builtin/clone.c:728
-#, c-format
-msgid "Cloning into bare repository '%s'...\n"
-msgstr "Clone nel repository spoglio '%s'...\n"
+#: connect.c:313
+msgid "invalid packet"
+msgstr "pacchetto non valido"
 
-#: builtin/clone.c:730
+#: connect.c:333
 #, c-format
-msgid "Cloning into '%s'...\n"
-msgstr ""
+msgid "protocol error: unexpected '%s'"
+msgstr "errore protocollo: '%s' non atteso"
 
-#: builtin/clone.c:786
+#: connect.c:441
 #, c-format
-msgid "Don't know how to clone %s"
-msgstr "Non so come clonare %s"
+msgid "invalid ls-refs response: %s"
+msgstr "risposta ls-refs non valida: %s"
+
+#: connect.c:445
+msgid "expected flush after ref listing"
+msgstr "atteso flush dopo elenco ref"
 
-#: builtin/clone.c:835
+#: connect.c:544
 #, c-format
-msgid "Remote branch %s not found in upstream %s"
-msgstr "Il branch remoto %s non è stato trovato in upstream %s"
+msgid "protocol '%s' is not supported"
+msgstr "il protocollo '%s' non è supportato"
 
-#: builtin/clone.c:842
-msgid "You appear to have cloned an empty repository."
-msgstr "Sembra che tu abbia clonato un repository vuoto."
+#: connect.c:595
+msgid "unable to set SO_KEEPALIVE on socket"
+msgstr "impossibile impostare SO_KEEPALIVE sul socket"
 
-#: builtin/column.c:51
-msgid "--command must be the first argument"
-msgstr "--command deve essere il primo argomento"
+#: connect.c:635 connect.c:698
+#, c-format
+msgid "Looking up %s ... "
+msgstr "Risoluzione di %s in corso... "
 
-#: builtin/commit.c:43
-msgid ""
-"Your name and email address were configured automatically based\n"
-"on your username and hostname. Please check that they are accurate.\n"
-"You can suppress this message by setting them explicitly:\n"
-"\n"
-"    git config --global user.name \"Your Name\"\n"
-"    git config --global user.email you@example.com\n"
-"\n"
-"After doing this, you may fix the identity used for this commit with:\n"
-"\n"
-"    git commit --amend --reset-author\n"
-msgstr ""
-"Il tuo nome e l'indirizzo email sono stati configurati automaticamente usando\n"
-"il tuo nome utente ed il nome host. Per favore, verifica che siano esatti.\n"
-"È possibile eliminare questo messaggio impostandoli esplicitamente:\n"
-"\n"
-"    git config --global user.name \"Tuo Nome\"\n"
-"    git config --global user.email tu@esempio.com\n"
-"\n"
-"Dopo questa operazione, puoi ripristinare l'identità usata in questo commit con:\n"
-"\n"
-"    git commit --amend --reset-author\n"
+#: connect.c:639
+#, c-format
+msgid "unable to look up %s (port %s) (%s)"
+msgstr "impossibile risolvere %s (porta %s) (%s)"
 
-#: builtin/commit.c:55
+#. TRANSLATORS: this is the end of "Looking up %s ... "
+#: connect.c:643 connect.c:714
+#, c-format
 msgid ""
-"You asked to amend the most recent commit, but doing so would make\n"
-"it empty. You can repeat your command with --allow-empty, or you can\n"
-"remove the commit entirely with \"git reset HEAD^\".\n"
+"done.\n"
+"Connecting to %s (port %s) ... "
 msgstr ""
+"fatto.\n"
+"Connessione a %s (porta %s) in corso... "
 
-#: builtin/commit.c:60
+#: connect.c:665 connect.c:742
+#, c-format
 msgid ""
-"The previous cherry-pick is now empty, possibly due to conflict resolution.\n"
-"If you wish to commit it anyway, use:\n"
-"\n"
-"    git commit --allow-empty\n"
-"\n"
-"Otherwise, please use 'git reset'\n"
-msgstr ""
-
-#: builtin/commit.c:253
-msgid "failed to unpack HEAD tree object"
+"unable to connect to %s:\n"
+"%s"
 msgstr ""
+"impossibile collegarsi a %s:\n"
+"%s"
 
-#: builtin/commit.c:295
-msgid "unable to create temporary index"
-msgstr ""
+#. TRANSLATORS: this is the end of "Connecting to %s (port %s) ... "
+#: connect.c:671 connect.c:748
+msgid "done."
+msgstr "fatto."
 
-#: builtin/commit.c:301
-msgid "interactive add failed"
-msgstr "add interattivo non riuscito"
+#: connect.c:702
+#, c-format
+msgid "unable to look up %s (%s)"
+msgstr "impossibile risolvere %s (%s)"
 
-#: builtin/commit.c:334 builtin/commit.c:355 builtin/commit.c:405
-msgid "unable to write new_index file"
-msgstr "impossibile scrivere il file new_index"
+#: connect.c:708
+#, c-format
+msgid "unknown port %s"
+msgstr "porta %s sconosciuta"
 
-#: builtin/commit.c:386
-msgid "cannot do a partial commit during a merge."
-msgstr "impossibile eseguire un commit parziale durante un merge."
+#: connect.c:845 connect.c:1175
+#, c-format
+msgid "strange hostname '%s' blocked"
+msgstr "nome host strano '%s' bloccato"
 
-#: builtin/commit.c:388
-msgid "cannot do a partial commit during a cherry-pick."
-msgstr "impossibile eseguire un commit parziale durante un cherry-pick."
+#: connect.c:847
+#, c-format
+msgid "strange port '%s' blocked"
+msgstr "porta strana '%s' bloccata"
 
-#: builtin/commit.c:398
-msgid "cannot read the index"
-msgstr "impossibile leggere index"
+#: connect.c:857
+#, c-format
+msgid "cannot start proxy %s"
+msgstr "impossibile avviare il proxy %s"
 
-#: builtin/commit.c:418
-msgid "unable to write temporary index file"
+#: connect.c:928
+msgid "no path specified; see 'git help pull' for valid url syntax"
 msgstr ""
+"nessun percorso specificato; vedere 'git help pull' per le sintassi URL "
+"valide"
 
-#: builtin/commit.c:493 builtin/commit.c:499
-#, c-format
-msgid "invalid commit: %s"
-msgstr "commit non valido: %s"
-
-#: builtin/commit.c:522
-msgid "malformed --author parameter"
-msgstr "parametro --author malformato"
+#: connect.c:1123
+msgid "ssh variant 'simple' does not support -4"
+msgstr "la variante SSH 'simple' non supporta -4"
 
-#: builtin/commit.c:582
-#, c-format
-msgid "Malformed ident string: '%s'"
-msgstr ""
+#: connect.c:1135
+msgid "ssh variant 'simple' does not support -6"
+msgstr "la variante SSH 'simple' non supporta -6"
 
-#: builtin/commit.c:620 builtin/commit.c:653 builtin/commit.c:967
-#, c-format
-msgid "could not lookup commit %s"
-msgstr "non è stato possibile trovare il commit %s"
+#: connect.c:1152
+msgid "ssh variant 'simple' does not support setting port"
+msgstr "la variante SSH 'simple' non supporta l'impostazione della porta"
 
-#: builtin/commit.c:632 builtin/shortlog.c:296
+#: connect.c:1264
 #, c-format
-msgid "(reading log message from standard input)\n"
-msgstr "(lettura del messaggio di log dallo standard input)\n"
+msgid "strange pathname '%s' blocked"
+msgstr "percorso strano '%s' bloccato"
 
-#: builtin/commit.c:634
-msgid "could not read log from standard input"
-msgstr "non è stato possibile leggere il log dallo standard input"
+#: connect.c:1311
+msgid "unable to fork"
+msgstr "impossibile eseguire fork"
 
-#: builtin/commit.c:638
-#, c-format
-msgid "could not read log file '%s'"
-msgstr "non è stato possibile leggere il file di log '%s'"
+#: connected.c:89 builtin/fsck.c:208 builtin/prune.c:43
+msgid "Checking connectivity"
+msgstr "Controllo connessione in corso"
 
-#: builtin/commit.c:644
-msgid "commit has empty message"
-msgstr "il commit ha un messaggio vuoto"
+#: connected.c:101
+msgid "Could not run 'git rev-list'"
+msgstr "Impossibile eseguire 'git-rev-list'"
 
-#: builtin/commit.c:660
-msgid "could not read MERGE_MSG"
-msgstr "non è stato possibile leggere MERGE_MSG"
+#: connected.c:121
+msgid "failed write to rev-list"
+msgstr "scrittura nella rev-list non riuscita"
 
-#: builtin/commit.c:664
-msgid "could not read SQUASH_MSG"
-msgstr "non è stato possibile leggere SQUASH_MSG"
+#: connected.c:128
+msgid "failed to close rev-list's stdin"
+msgstr "chiusura standard input della rev-list non riuscita"
 
-#: builtin/commit.c:668
+#: convert.c:194
 #, c-format
-msgid "could not read '%s'"
-msgstr "non è stato possibile leggere '%s'"
-
-#: builtin/commit.c:720
-msgid "could not write commit template"
-msgstr "non è stato possibile scrivere il modello di commit"
+msgid "illegal crlf_action %d"
+msgstr "crlf_action %d illecita"
 
-#: builtin/commit.c:731
+#: convert.c:207
 #, c-format
-msgid ""
-"\n"
-"It looks like you may be committing a merge.\n"
-"If this is not correct, please remove the file\n"
-"\t%s\n"
-"and try again.\n"
-msgstr ""
-"\n"
-"Sembra che si stia eseguendo il commit di un merge.\n"
-"Se l'operazione non è corretta, per favore elimina il file\n"
-"\t%s\n"
-"e riprova.\n"
+msgid "CRLF would be replaced by LF in %s"
+msgstr "CRLF sarebbe sostituito da LF in %s"
 
-#: builtin/commit.c:736
+#: convert.c:209
 #, c-format
 msgid ""
-"\n"
-"It looks like you may be committing a cherry-pick.\n"
-"If this is not correct, please remove the file\n"
-"\t%s\n"
-"and try again.\n"
+"CRLF will be replaced by LF in %s.\n"
+"The file will have its original line endings in your working directory"
 msgstr ""
-"\n"
-"Sembra che si stia eseguendo il commit di un cherry-pick.\n"
-"Se l'operazione non è corretta, per favore rimuovi il file\n"
-"\t%s\n"
-"e riprova.\n"
+"CRLF sarà sostituito da LF in %s.\n"
+"Il file avrà i suoi fine riga originari nella propria directory di lavoro"
 
-#: builtin/commit.c:748
-msgid ""
-"Please enter the commit message for your changes. Lines starting\n"
-"with '#' will be ignored, and an empty message aborts the commit.\n"
-msgstr ""
-"Per favore inserisci il messaggio di commit per le modifiche. Le righe\n"
-"che iniziano con '#' verranno ignorate, e un messaggio vuoto annulla il commit.\n"
+#: convert.c:217
+#, c-format
+msgid "LF would be replaced by CRLF in %s"
+msgstr "LF sarebbe sostituito da CRLF in %s"
 
-#: builtin/commit.c:753
+#: convert.c:219
+#, c-format
 msgid ""
-"Please enter the commit message for your changes. Lines starting\n"
-"with '#' will be kept; you may remove them yourself if you want to.\n"
-"An empty message aborts the commit.\n"
+"LF will be replaced by CRLF in %s.\n"
+"The file will have its original line endings in your working directory"
 msgstr ""
-"Per favore inserisci il messaggio di commit per le modifiche. Le\n"
-"righe che iniziano con '#' verranno mantenute; possono comunque essere\n"
-"rimosse manualmente. Un messaggio vuoto annulla il commit.\n"
+"LF sarà sostituito da CRLF in %s.\n"
+"Il file avrà i suoi fine riga originari nella propria directory di lavoro"
 
-#: builtin/commit.c:766
+#: convert.c:284
 #, c-format
-msgid "%sAuthor:    %s"
-msgstr "%sAutore:    %s"
+msgid "BOM is prohibited in '%s' if encoded as %s"
+msgstr "Il BOM è vietato in '%s' se il file è codificato come %s"
 
-#: builtin/commit.c:773
+#: convert.c:291
 #, c-format
-msgid "%sCommitter: %s"
-msgstr "%sCommitter: %s"
-
-#: builtin/commit.c:793
-msgid "Cannot read index"
-msgstr "Impossibile leggere index"
-
-#: builtin/commit.c:830
-msgid "Error building trees"
+msgid ""
+"The file '%s' contains a byte order mark (BOM). Please use UTF-%.*s as "
+"working-tree-encoding."
 msgstr ""
+"Il file '%s' contiene un indicatore dell'ordine dei byte (BOM). Usare UTF-"
+"%.*s come codifica dell'albero di lavoro."
 
-#: builtin/commit.c:845 builtin/tag.c:361
-#, c-format
-msgid "Please supply the message using either -m or -F option.\n"
-msgstr "Per favore, specifica il messaggio usando l'opzione -m o -F.\n"
-
-#: builtin/commit.c:942
+#: convert.c:304
 #, c-format
-msgid "No existing author found with '%s'"
-msgstr "Nessun autore esistente trovato con '%s'"
+msgid "BOM is required in '%s' if encoded as %s"
+msgstr "Il BOM è richiesto in '%s' se il file è codificato come %s"
 
-#: builtin/commit.c:957 builtin/commit.c:1157
+#: convert.c:306
 #, c-format
-msgid "Invalid untracked files mode '%s'"
-msgstr ""
-
-#: builtin/commit.c:997
-msgid "Using both --reset-author and --author does not make sense"
-msgstr "L'uso di entrambe le opzioni --reset-author e --author non ha senso"
-
-#: builtin/commit.c:1008
-msgid "You have nothing to amend."
+msgid ""
+"The file '%s' is missing a byte order mark (BOM). Please use UTF-%sBE or UTF-"
+"%sLE (depending on the byte order) as working-tree-encoding."
 msgstr ""
+"Nel file '%s' manca un indicatore dell'ordine dei byte (BOM). Usare UTF-%sBE "
+"o UTF-%sLE (a seconda dell'ordine dei byte) come codifica dell'albero di "
+"lavoro."
 
-#: builtin/commit.c:1011
-msgid "You are in the middle of a merge -- cannot amend."
-msgstr ""
+#: convert.c:419 convert.c:490
+#, c-format
+msgid "failed to encode '%s' from %s to %s"
+msgstr "conversione della codifica '%s' da %s a %s non riuscita"
 
-#: builtin/commit.c:1013
-msgid "You are in the middle of a cherry-pick -- cannot amend."
+#: convert.c:462
+#, c-format
+msgid "encoding '%s' from %s to %s and back is not the same"
 msgstr ""
+"il risultato della codifica di '%s' da %s a %s e viceversa non è lo stesso"
 
-#: builtin/commit.c:1016
-msgid "Options --squash and --fixup cannot be used together"
-msgstr "Le opzioni --squash e --fixup non possono essere usate insieme"
-
-#: builtin/commit.c:1026
-msgid "Only one of -c/-C/-F/--fixup can be used."
-msgstr "Solo una delle opzioni -c/-C/-F/--fixup può essere usata."
+#: convert.c:668
+#, c-format
+msgid "cannot fork to run external filter '%s'"
+msgstr "impossibile eseguire fork per eseguire il filtro esterno '%s'"
 
-#: builtin/commit.c:1028
-msgid "Option -m cannot be combined with -c/-C/-F/--fixup."
-msgstr "L'opzione -m non può essere combinata con -c/-C/-F/--fixup."
+#: convert.c:688
+#, c-format
+msgid "cannot feed the input to external filter '%s'"
+msgstr "impossibile fornire l'input al filtro esterno '%s'"
 
-#: builtin/commit.c:1036
-msgid "--reset-author can be used only with -C, -c or --amend."
-msgstr "L'opzione --reset-author può essere usata solo con -C, -c o --amend."
+#: convert.c:695
+#, c-format
+msgid "external filter '%s' failed %d"
+msgstr "esecuzione del filtro esterno '%s' non riuscita: %d"
 
-#: builtin/commit.c:1053
-msgid "Only one of --include/--only/--all/--interactive/--patch can be used."
-msgstr ""
-"Può essere usata solo una delle opzioni --include/--only/--all/--"
-"interactive/--patch ."
+#: convert.c:730 convert.c:733
+#, c-format
+msgid "read from external filter '%s' failed"
+msgstr "lettura dal filtro esterno '%s' non riuscita"
 
-#: builtin/commit.c:1055
-msgid "No paths with --include/--only does not make sense."
-msgstr "Devi specificare un path se usi --include/--only."
+#: convert.c:736 convert.c:791
+#, c-format
+msgid "external filter '%s' failed"
+msgstr "esecuzione del filtro esterno '%s' non riuscita"
 
-#: builtin/commit.c:1057
-msgid "Clever... amending the last one with dirty index."
-msgstr ""
+#: convert.c:839
+msgid "unexpected filter type"
+msgstr "tipo filtro inatteso"
 
-#: builtin/commit.c:1059
-msgid "Explicit paths specified without -i nor -o; assuming --only paths..."
-msgstr ""
+#: convert.c:850
+msgid "path name too long for external filter"
+msgstr "nome percorso troppo lungo per il filtro esterno"
 
-#: builtin/commit.c:1069 builtin/tag.c:577
+#: convert.c:924
 #, c-format
-msgid "Invalid cleanup mode %s"
+msgid ""
+"external filter '%s' is not available anymore although not all paths have "
+"been filtered"
 msgstr ""
+"il filtro esterno '%s' non è più disponibile nonostante non tutti i percorsi "
+"siano stati filtrati"
 
-#: builtin/commit.c:1074
-msgid "Paths with -a does not make sense."
-msgstr "I path con -a non hanno senso."
-
-#: builtin/commit.c:1257
-msgid "couldn't look up newly created commit"
-msgstr "non è stato possibile trovare il commit appena creato"
+#: convert.c:1223
+msgid "true/false are no valid working-tree-encodings"
+msgstr "true/false non sono codifiche dell'albero di lavoro valide"
 
-#: builtin/commit.c:1259
-msgid "could not parse newly created commit"
-msgstr "non è stato possibile analizzare il commit appena creato"
+#: convert.c:1411 convert.c:1445
+#, c-format
+msgid "%s: clean filter '%s' failed"
+msgstr "%s: esecuzione del filtro clean '%s' non riuscita"
 
-#: builtin/commit.c:1300
-msgid "detached HEAD"
-msgstr ""
+#: convert.c:1489
+#, c-format
+msgid "%s: smudge filter %s failed"
+msgstr "%s: esecuzione del filtro smudge '%s' non riuscita"
 
-#: builtin/commit.c:1302
-msgid " (root-commit)"
-msgstr " (root-commit)"
+#: date.c:138
+msgid "in the future"
+msgstr "in futuro"
 
-#: builtin/commit.c:1446
-msgid "could not parse HEAD commit"
-msgstr "non è stato possibile analizzare il commit HEAD"
+#: date.c:144
+#, c-format
+msgid "%<PRIuMAX> second ago"
+msgid_plural "%<PRIuMAX> seconds ago"
+msgstr[0] "%<PRIuMAX> secondo fa"
+msgstr[1] "%<PRIuMAX> secondi fa"
 
-#: builtin/commit.c:1484 builtin/merge.c:509
+#: date.c:151
 #, c-format
-msgid "could not open '%s' for reading"
-msgstr "non è stato possibile aprire '%s' per la lettura"
+msgid "%<PRIuMAX> minute ago"
+msgid_plural "%<PRIuMAX> minutes ago"
+msgstr[0] "%<PRIuMAX> minuto fa"
+msgstr[1] "%<PRIuMAX> minuti fa"
 
-#: builtin/commit.c:1491
+#: date.c:158
 #, c-format
-msgid "Corrupt MERGE_HEAD file (%s)"
-msgstr "File MERGE_HEAD corrotto (%s)"
+msgid "%<PRIuMAX> hour ago"
+msgid_plural "%<PRIuMAX> hours ago"
+msgstr[0] "%<PRIuMAX> ora fa"
+msgstr[1] "%<PRIuMAX> ore fa"
 
-#: builtin/commit.c:1498
-msgid "could not read MERGE_MODE"
-msgstr "non è stato possibile leggere MERGE_MODE"
+#: date.c:165
+#, c-format
+msgid "%<PRIuMAX> day ago"
+msgid_plural "%<PRIuMAX> days ago"
+msgstr[0] "%<PRIuMAX> giorno fa"
+msgstr[1] "%<PRIuMAX> giorni fa"
 
-#: builtin/commit.c:1517
+#: date.c:171
 #, c-format
-msgid "could not read commit message: %s"
-msgstr "non è stato possibile leggere il messaggio di commit: %s"
+msgid "%<PRIuMAX> week ago"
+msgid_plural "%<PRIuMAX> weeks ago"
+msgstr[0] "%<PRIuMAX> settimana fa"
+msgstr[1] "%<PRIuMAX> settimane fa"
 
-#: builtin/commit.c:1531
+#: date.c:178
 #, c-format
-msgid "Aborting commit; you did not edit the message.\n"
-msgstr "Commit interrotto; il messaggio non è stato modificato.\n"
+msgid "%<PRIuMAX> month ago"
+msgid_plural "%<PRIuMAX> months ago"
+msgstr[0] "%<PRIuMAX> mese fa"
+msgstr[1] "%<PRIuMAX> mesi fa"
 
-#: builtin/commit.c:1536
+#: date.c:189
 #, c-format
-msgid "Aborting commit due to empty commit message.\n"
-msgstr "Interruzione del commit a causa di un messaggio di commit vuoto.\n"
+msgid "%<PRIuMAX> year"
+msgid_plural "%<PRIuMAX> years"
+msgstr[0] "%<PRIuMAX> anno"
+msgstr[1] "%<PRIuMAX> anni"
 
-#: builtin/commit.c:1551 builtin/merge.c:936 builtin/merge.c:961
-msgid "failed to write commit object"
-msgstr "scrittura dell'oggetto di commit non riuscita"
+#. TRANSLATORS: "%s" is "<n> years"
+#: date.c:192
+#, c-format
+msgid "%s, %<PRIuMAX> month ago"
+msgid_plural "%s, %<PRIuMAX> months ago"
+msgstr[0] "%s, %<PRIuMAX> mese fa"
+msgstr[1] "%s, %<PRIuMAX> mesi fa"
 
-#: builtin/commit.c:1572
-msgid "cannot lock HEAD ref"
-msgstr ""
+#: date.c:197 date.c:202
+#, c-format
+msgid "%<PRIuMAX> year ago"
+msgid_plural "%<PRIuMAX> years ago"
+msgstr[0] "%<PRIuMAX> anno fa"
+msgstr[1] "%<PRIuMAX> anni fa"
 
-#: builtin/commit.c:1576
-msgid "cannot update HEAD ref"
-msgstr ""
+#: delta-islands.c:272
+msgid "Propagating island marks"
+msgstr "Propagazione contrassegni isole in corso"
 
-#: builtin/commit.c:1587
-msgid ""
-"Repository has been updated, but unable to write\n"
-"new_index file. Check that disk is not full or quota is\n"
-"not exceeded, and then \"git reset HEAD\" to recover."
-msgstr ""
-"Il repository è stato aggiornato, ma non è stato possibile scrivere il file\n"
-"new_index. Verifica che l'unità disco non sia piena o che la quota non sia\n"
-"stata superata, ed esegui \"git reset HEAD\" per il ripristino."
+#: delta-islands.c:290
+#, c-format
+msgid "bad tree object %s"
+msgstr "oggetto albero %s non valido"
 
-#: builtin/describe.c:234
+#: delta-islands.c:334
 #, c-format
-msgid "annotated tag %s not available"
+msgid "failed to load island regex for '%s': %s"
 msgstr ""
+"caricamento dell'espressione regolare dell'isola per '%s' non riuscito: %s"
 
-#: builtin/describe.c:238
+#: delta-islands.c:390
 #, c-format
-msgid "annotated tag %s has no embedded name"
+msgid "island regex from config has too many capture groups (max=%d)"
 msgstr ""
+"l'espressione regolare dell'isola tratta dalla configurazione ha troppi "
+"gruppi cattura (massimo=%d)"
 
-#: builtin/describe.c:240
+#: delta-islands.c:467
 #, c-format
-msgid "tag '%s' is really '%s' here"
-msgstr "il tag '%s' è davvero '%s' qui"
+msgid "Marked %d islands, done.\n"
+msgstr "Contrassegnate %d isole, fatto.\n"
 
-#: builtin/describe.c:267
+#: diffcore-order.c:24
 #, c-format
-msgid "Not a valid object name %s"
-msgstr "Non è il nome di un oggetto valido %s"
+msgid "failed to read orderfile '%s'"
+msgstr "lettura dell'orderfile '%s' non riuscita"
 
-#: builtin/describe.c:270
-#, c-format
-msgid "%s is not a valid '%s' object"
-msgstr "%s non è un oggetto '%s' valido"
+#: diffcore-rename.c:543
+msgid "Performing inexact rename detection"
+msgstr "Rilevamento ridenominazione non esatta in corso"
 
-#: builtin/describe.c:287
-#, c-format
-msgid "no tag exactly matches '%s'"
-msgstr "nessun tag corrisponde esattamente a '%s'"
+#: diff-no-index.c:238
+msgid "git diff --no-index [<options>] <path> <path>"
+msgstr "git diff --no-index [<opzioni>] <percorso> <percorso>"
 
-#: builtin/describe.c:289
-#, c-format
-msgid "searching to describe %s\n"
+#: diff-no-index.c:263
+msgid ""
+"Not a git repository. Use --no-index to compare two paths outside a working "
+"tree"
 msgstr ""
+"Non è un repository Git. Usa --no-index per confrontare due percorsi al di "
+"fuori di un albero di lavoro"
 
-#: builtin/describe.c:329
+#: diff.c:155
 #, c-format
-msgid "finished search at %s\n"
+msgid "  Failed to parse dirstat cut-off percentage '%s'\n"
 msgstr ""
+"  Analisi della percentuale di cutoff statistiche directory '%s' non "
+"riuscita\n"
 
-#: builtin/describe.c:353
+#: diff.c:160
 #, c-format
+msgid "  Unknown dirstat parameter '%s'\n"
+msgstr "  Parametro statistiche directory '%s' sconosciuto\n"
+
+#: diff.c:296
 msgid ""
-"No annotated tags can describe '%s'.\n"
-"However, there were unannotated tags: try --tags."
+"color moved setting must be one of 'no', 'default', 'blocks', 'zebra', "
+"'dimmed-zebra', 'plain'"
 msgstr ""
+"l'impostazione colore per file spostati deve essere 'no', 'default', "
+"'blocks', 'zebra', 'dimmed-zebra', 'plain'"
 
-#: builtin/describe.c:357
+#: diff.c:324
 #, c-format
 msgid ""
-"No tags can describe '%s'.\n"
-"Try --always, or create some tags."
+"unknown color-moved-ws mode '%s', possible values are 'ignore-space-change', "
+"'ignore-space-at-eol', 'ignore-all-space', 'allow-indentation-change'"
 msgstr ""
-"Nessun tag può descrivere '%s'.\n"
-"Prova con --always, o crea dei tag."
+"modalità color-moved-ws '%s' sconosciuta, i valori possibili sono 'ignore-"
+"space-change', 'ignore-space-at-eol', 'ignore-all-space', 'allow-indentation-"
+"change'"
 
-#: builtin/describe.c:378
+#: diff.c:332
+msgid ""
+"color-moved-ws: allow-indentation-change cannot be combined with other "
+"whitespace modes"
+msgstr ""
+"color-moved-ws: allow-indentation-change non può essere combinata con altre "
+"modalità spazi bianchi"
+
+#: diff.c:405
 #, c-format
-msgid "traversed %lu commits\n"
+msgid "Unknown value for 'diff.submodule' config variable: '%s'"
 msgstr ""
+"Valore sconosciuto per la variabile di configurazione 'diff.submodule': '%s'"
 
-#: builtin/describe.c:381
+#: diff.c:465
 #, c-format
 msgid ""
-"more than %i tags found; listed %i most recent\n"
-"gave up search at %s\n"
+"Found errors in 'diff.dirstat' config variable:\n"
+"%s"
 msgstr ""
+"Trovati errori nella variabile di configurazione 'diff.dirstat':\n"
+"%s"
 
-#: builtin/describe.c:436
-msgid "--long is incompatible with --abbrev=0"
-msgstr "--long non è compatibile con --abbrev=0"
+#: diff.c:4202
+#, c-format
+msgid "external diff died, stopping at %s"
+msgstr "processo esterno diff morto, mi fermo a %s"
 
-#: builtin/describe.c:462
-msgid "No names found, cannot describe anything."
+#: diff.c:4547
+msgid "--name-only, --name-status, --check and -s are mutually exclusive"
 msgstr ""
+"le opzioni --name-only, --name-status, --check e -s sono mutuamente esclusive"
 
-#: builtin/describe.c:482
-msgid "--dirty is incompatible with commit-ishes"
-msgstr ""
+#: diff.c:4550
+msgid "-G, -S and --find-object are mutually exclusive"
+msgstr "le opzioni -G, -S e --find-object sono mutuamente esclusive"
 
-#: builtin/diff.c:77
-#, c-format
-msgid "'%s': not a regular file or symlink"
-msgstr "'%s': non è un file regolare o un link simbolico"
+#: diff.c:4628
+msgid "--follow requires exactly one pathspec"
+msgstr "--follow richiede esattamente uno specificatore percorso"
 
-#: builtin/diff.c:220
+#: diff.c:4676
 #, c-format
-msgid "invalid option: %s"
-msgstr "opzione non valida: %s"
-
-#: builtin/diff.c:297
-msgid "Not a git repository"
-msgstr "Non è un repository git"
+msgid "invalid --stat value: %s"
+msgstr "valore non valido per --stat: %s"
 
-#: builtin/diff.c:347
+#: diff.c:4681 diff.c:4686 diff.c:4691 diff.c:4696 diff.c:5209
+#: parse-options.c:199 parse-options.c:203
 #, c-format
-msgid "invalid object '%s' given."
-msgstr "oggetto non valido '%s' specificato."
+msgid "%s expects a numerical value"
+msgstr "%s richiede un valore numerico"
 
-#: builtin/diff.c:352
+#: diff.c:4713
 #, c-format
-msgid "more than %d trees given: '%s'"
+msgid ""
+"Failed to parse --dirstat/-X option parameter:\n"
+"%s"
 msgstr ""
+"Analisi del parametro dell'opzione --dirstat/-X non riuscita:\n"
+"%s"
 
-#: builtin/diff.c:362
+#: diff.c:4798
 #, c-format
-msgid "more than two blobs given: '%s'"
-msgstr "più di due blob specificati: '%s'"
+msgid "unknown change class '%c' in --diff-filter=%s"
+msgstr "classe modifica '%c' sconosciuta in --diff-filter=%s"
 
-#: builtin/diff.c:370
+#: diff.c:4822
 #, c-format
-msgid "unhandled object '%s' given."
-msgstr "oggetto non gestito '%s' specificato."
+msgid "unknown value after ws-error-highlight=%.*s"
+msgstr "valore sconosciuto dopo ws-error-highlight=%.*s"
 
-#: builtin/fetch.c:200
-msgid "Couldn't find remote ref HEAD"
-msgstr ""
+#: diff.c:4836
+#, c-format
+msgid "unable to resolve '%s'"
+msgstr "impossibile risolvere '%s'"
 
-#: builtin/fetch.c:253
+#: diff.c:4886 diff.c:4892
 #, c-format
-msgid "object %s not found"
-msgstr "oggetto %s non trovato"
+msgid "%s expects <n>/<m> form"
+msgstr "%s richiede il formato <n>/<m>"
 
-#: builtin/fetch.c:259
-msgid "[up to date]"
-msgstr "[aggiornato]"
+#: diff.c:4904
+#, c-format
+msgid "%s expects a character, got '%s'"
+msgstr "%s richiede un carattere, ricevuto '%s'"
 
-#: builtin/fetch.c:273
+#: diff.c:4925
 #, c-format
-msgid "! %-*s %-*s -> %s  (can't fetch in current branch)"
-msgstr ""
+msgid "bad --color-moved argument: %s"
+msgstr "argomento --color-moved errato: %s"
 
-#: builtin/fetch.c:274 builtin/fetch.c:360
-msgid "[rejected]"
-msgstr "[respinto]"
+#: diff.c:4944
+#, c-format
+msgid "invalid mode '%s' in --color-moved-ws"
+msgstr "modo non valido '%s' in --color-moved-ws"
 
-#: builtin/fetch.c:285
-msgid "[tag update]"
-msgstr "[tag aggiornata]"
+#: diff.c:4984
+msgid ""
+"option diff-algorithm accepts \"myers\", \"minimal\", \"patience\" and "
+"\"histogram\""
+msgstr ""
+"l'opzione diff-algorithm accetta i valori \"myers\", \"minimal\", \"patience"
+"\" e \"histogram\""
 
-#: builtin/fetch.c:287 builtin/fetch.c:322 builtin/fetch.c:340
-msgid "  (unable to update local ref)"
-msgstr "  (impossibile aggiornare il ref locale)"
+#: diff.c:5020 diff.c:5040
+#, c-format
+msgid "invalid argument to %s"
+msgstr "argomento non valido per %s"
 
-#: builtin/fetch.c:305
-msgid "[new tag]"
-msgstr "[nuova tag]"
+#: diff.c:5178
+#, c-format
+msgid "failed to parse --submodule option parameter: '%s'"
+msgstr "analisi del parametro dell'opzione --submodule non riuscita: '%s'"
 
-#: builtin/fetch.c:308
-msgid "[new branch]"
-msgstr "[nuovo branch]"
+#: diff.c:5234
+#, c-format
+msgid "bad --word-diff argument: %s"
+msgstr "argomento --word-diff errato: %s"
 
-#: builtin/fetch.c:311
-msgid "[new ref]"
-msgstr "[nuovo ref]"
+#: diff.c:5257
+msgid "Diff output format options"
+msgstr "Opzioni formato output diff"
 
-#: builtin/fetch.c:356
-msgid "unable to update local ref"
-msgstr "impossibile aggiornare il ref locale"
+#: diff.c:5259 diff.c:5265
+msgid "generate patch"
+msgstr "genera patch"
 
-#: builtin/fetch.c:356
-msgid "forced update"
-msgstr "aggiornamento forzato"
+#: diff.c:5262 builtin/log.c:173
+msgid "suppress diff output"
+msgstr "non visualizzare l'output del diff"
 
-#: builtin/fetch.c:362
-msgid "(non-fast-forward)"
-msgstr ""
+#: diff.c:5267 diff.c:5381 diff.c:5388
+msgid "<n>"
+msgstr "<n>"
 
-#: builtin/fetch.c:393 builtin/fetch.c:685
-#, c-format
-msgid "cannot open %s: %s\n"
-msgstr "impossibile aprire %s: %s\n"
+#: diff.c:5268 diff.c:5271
+msgid "generate diffs with <n> lines context"
+msgstr "genera diff con <n> righe di contesto"
 
-#: builtin/fetch.c:402
-#, c-format
-msgid "%s did not send all necessary objects\n"
-msgstr "%s non ha inviato tutti gli oggetti necessari\n"
+#: diff.c:5273
+msgid "generate the diff in raw format"
+msgstr "genera il diff in formato grezzo"
 
-#: builtin/fetch.c:488
-#, c-format
-msgid "From %.*s\n"
-msgstr "Da %.*s\n"
+#: diff.c:5276
+msgid "synonym for '-p --raw'"
+msgstr "sinonimo di '-p --raw'"
 
-#: builtin/fetch.c:499
-#, c-format
+#: diff.c:5280
+msgid "synonym for '-p --stat'"
+msgstr "sinonimo di '-p --stat'"
+
+#: diff.c:5284
+msgid "machine friendly --stat"
+msgstr "--stat leggibile da una macchina"
+
+#: diff.c:5287
+msgid "output only the last line of --stat"
+msgstr "emetti in output solo l'ultima riga di --stat"
+
+#: diff.c:5289 diff.c:5297
+msgid "<param1,param2>..."
+msgstr "<parametro1,parametro2>..."
+
+#: diff.c:5290
 msgid ""
-"some local refs could not be updated; try running\n"
-" 'git remote prune %s' to remove any old, conflicting branches"
+"output the distribution of relative amount of changes for each sub-directory"
 msgstr ""
-"non è stato possibile aggiornare alcuni ref locali; prova con\n"
-" 'git remote prune %s' per rimuovere ogni branch che vada in conflitto"
+"emetti in output la distribuzione del numero di modifiche relativo a ogni "
+"sottodirectory"
 
-#: builtin/fetch.c:549
-#, c-format
-msgid "   (%s will become dangling)"
+#: diff.c:5294
+msgid "synonym for --dirstat=cumulative"
+msgstr "sinonimo di --dirstat=cumulative"
+
+#: diff.c:5298
+msgid "synonym for --dirstat=files,param1,param2..."
+msgstr "sinonimo di --dirstat=files,parametro1,parametro2..."
+
+#: diff.c:5302
+msgid "warn if changes introduce conflict markers or whitespace errors"
 msgstr ""
+"avvisa se le modifiche introducono marcatori conflitto o errori spazi bianchi"
 
-#: builtin/fetch.c:550
-#, c-format
-msgid "   (%s has become dangling)"
+#: diff.c:5305
+msgid "condensed summary such as creations, renames and mode changes"
 msgstr ""
+"riassunto conciso (ad es. elementi creati, ridenominati e modifiche modi)"
 
-#: builtin/fetch.c:557
-msgid "[deleted]"
-msgstr "[eliminato]"
+#: diff.c:5308
+msgid "show only names of changed files"
+msgstr "visualizza solo i nomi dei file modificati"
 
-#: builtin/fetch.c:558 builtin/remote.c:1055
-msgid "(none)"
-msgstr "(nessuno)"
+#: diff.c:5311
+msgid "show only names and status of changed files"
+msgstr "visualizza solo i nomi e lo stato dei file modificati"
 
-#: builtin/fetch.c:675
-#, c-format
-msgid "Refusing to fetch into current branch %s of non-bare repository"
-msgstr ""
+#: diff.c:5313
+msgid "<width>[,<name-width>[,<count>]]"
+msgstr "<ampiezza>[,<ampiezza nome>[,<numero>]]"
 
-#: builtin/fetch.c:709
-#, c-format
-msgid "Don't know how to fetch from %s"
-msgstr ""
+#: diff.c:5314
+msgid "generate diffstat"
+msgstr "genera diffstat"
 
-#: builtin/fetch.c:786
-#, c-format
-msgid "Option \"%s\" value \"%s\" is not valid for %s"
-msgstr ""
+#: diff.c:5316 diff.c:5319 diff.c:5322
+msgid "<width>"
+msgstr "<ampiezza>"
 
-#: builtin/fetch.c:789
-#, c-format
-msgid "Option \"%s\" is ignored for %s\n"
-msgstr "L'opzione \"%s\" è ignorata per %s\n"
+#: diff.c:5317
+msgid "generate diffstat with a given width"
+msgstr "genera il diffstat con un'ampiezza specificata"
 
-#: builtin/fetch.c:888
-#, c-format
-msgid "Fetching %s\n"
-msgstr ""
+#: diff.c:5320
+msgid "generate diffstat with a given name width"
+msgstr "genera il diffstat con un'ampiezza nomi specificata"
 
-#: builtin/fetch.c:890 builtin/remote.c:100
-#, c-format
-msgid "Could not fetch %s"
+#: diff.c:5323
+msgid "generate diffstat with a given graph width"
+msgstr "genera il diffstat con un'ampiezza grafo specificata"
+
+#: diff.c:5325
+msgid "<count>"
+msgstr "<numero>"
+
+#: diff.c:5326
+msgid "generate diffstat with limited lines"
+msgstr "genera il diffstat con righe limitate"
+
+#: diff.c:5329
+msgid "generate compact summary in diffstat"
+msgstr "genera riassunto conciso nel diffstat"
+
+#: diff.c:5332
+msgid "output a binary diff that can be applied"
+msgstr "stampa in output un diff binario che può essere applicato"
+
+#: diff.c:5335
+msgid "show full pre- and post-image object names on the \"index\" lines"
+msgstr "visualizza i nomi oggetto pre e post immagine nelle righe \"indice\""
+
+#: diff.c:5337
+msgid "show colored diff"
+msgstr "visualizza diff colorato"
+
+#: diff.c:5338
+msgid "<kind>"
+msgstr "<tipo>"
+
+#: diff.c:5339
+msgid ""
+"highlight whitespace errors in the 'context', 'old' or 'new' lines in the "
+"diff"
 msgstr ""
+"evidenzia gli errori di spazi bianchi nelle righe 'contesto', 'vecchie' o "
+"'nuove' nel diff"
 
-#: builtin/fetch.c:907
+#: diff.c:5342
 msgid ""
-"No remote repository specified.  Please, specify either a URL or a\n"
-"remote name from which new revisions should be fetched."
+"do not munge pathnames and use NULs as output field terminators in --raw or "
+"--numstat"
 msgstr ""
-"Nessun repository remoto specificato. Per favore, specifica un URL o\n"
-"il nome di un remote da cui prelevare nuove revisioni."
+"non rimuovere i nomi percorso e usare caratteri NUL come terminatori campo "
+"in --raw o --numstat"
 
-#: builtin/fetch.c:927
-msgid "You need to specify a tag name."
-msgstr "Devi specificare il nome di un tag."
+#: diff.c:5345 diff.c:5348 diff.c:5351 diff.c:5457
+msgid "<prefix>"
+msgstr "<prefisso>"
 
-#: builtin/fetch.c:979
-msgid "fetch --all does not take a repository argument"
-msgstr "fetch --all non richiede il repository come argomento"
+#: diff.c:5346
+msgid "show the given source prefix instead of \"a/\""
+msgstr "visualizza il prefisso sorgente specificato invece di \"a/\""
 
-#: builtin/fetch.c:981
-msgid "fetch --all does not make sense with refspecs"
-msgstr ""
+#: diff.c:5349
+msgid "show the given destination prefix instead of \"b/\""
+msgstr "visualizza il prefisso destinazione specificato invece di \"b/\""
 
-#: builtin/fetch.c:992
-#, c-format
-msgid "No such remote or remote group: %s"
-msgstr ""
+#: diff.c:5352
+msgid "prepend an additional prefix to every line of output"
+msgstr "anteponi un prefisso aggiuntivo ad ogni riga dell'output"
 
-#: builtin/fetch.c:1000
-msgid "Fetching a group and specifying refspecs does not make sense"
+#: diff.c:5355
+msgid "do not show any source or destination prefix"
+msgstr "non visualizzare alcun prefisso sorgente o destinazione"
+
+#: diff.c:5358
+msgid "show context between diff hunks up to the specified number of lines"
 msgstr ""
+"visualizza il contesto tra gli hunk del diff fino al numero di righe "
+"specificato"
 
-#: builtin/gc.c:63
-#, c-format
-msgid "Invalid %s: '%s'"
-msgstr "%s non valido: '%s'"
+#: diff.c:5362 diff.c:5367 diff.c:5372
+msgid "<char>"
+msgstr "<carattere>"
 
-#: builtin/gc.c:90
-#, c-format
-msgid "insanely long object directory %.*s"
-msgstr ""
+#: diff.c:5363
+msgid "specify the character to indicate a new line instead of '+'"
+msgstr "specifica il carattere che indica una nuova riga al posto di '+'"
 
-#: builtin/gc.c:221
-#, c-format
-msgid "Auto packing the repository for optimum performance.\n"
+#: diff.c:5368
+msgid "specify the character to indicate an old line instead of '-'"
+msgstr "specifica il carattere che indica una vecchia riga al posto di '-'"
+
+#: diff.c:5373
+msgid "specify the character to indicate a context instead of ' '"
+msgstr "specifica il carattere che indica un contesto al posto di ' '"
+
+#: diff.c:5376
+msgid "Diff rename options"
+msgstr "Opzioni rinominazione diff"
+
+#: diff.c:5377
+msgid "<n>[/<m>]"
+msgstr "<n>[/<m>]"
+
+#: diff.c:5378
+msgid "break complete rewrite changes into pairs of delete and create"
 msgstr ""
+"spezza modifiche di riscrittura completa in coppie eliminazione/creazione"
 
-#: builtin/gc.c:224
-#, c-format
-msgid ""
-"Auto packing the repository for optimum performance. You may also\n"
-"run \"git gc\" manually. See \"git help gc\" for more information.\n"
+#: diff.c:5382
+msgid "detect renames"
+msgstr "rileva le ridenominazioni"
+
+#: diff.c:5386
+msgid "omit the preimage for deletes"
+msgstr "ometti la preimmagine per le eliminazioni"
+
+#: diff.c:5389
+msgid "detect copies"
+msgstr "rileva le copie"
+
+#: diff.c:5393
+msgid "use unmodified files as source to find copies"
+msgstr "usa file non modificati come sorgente per trovare copie"
+
+#: diff.c:5395
+msgid "disable rename detection"
+msgstr "disabilita rilevamento ridenominazione"
+
+#: diff.c:5398
+msgid "use empty blobs as rename source"
+msgstr "usa blob vuoti come sorgente ridenominazione"
+
+#: diff.c:5400
+msgid "continue listing the history of a file beyond renames"
 msgstr ""
+"continua a elencare la cronologia di un file al di là delle ridenominazioni"
 
-#: builtin/gc.c:251
+#: diff.c:5403
 msgid ""
-"There are too many unreachable loose objects; run 'git prune' to remove them."
+"prevent rename/copy detection if the number of rename/copy targets exceeds "
+"given limit"
 msgstr ""
+"impedisci il rilevamento ridenominazione/copia se il numero delle "
+"destinazioni ridenominazione/copia eccede il limite specificato"
 
-#: builtin/grep.c:216
-#, c-format
-msgid "grep: failed to create thread: %s"
-msgstr "grep: creazione del thread non riuscita: %s"
+#: diff.c:5405
+msgid "Diff algorithm options"
+msgstr "Opzioni algoritmo diff"
 
-#: builtin/grep.c:402
-#, c-format
-msgid "Failed to chdir: %s"
-msgstr ""
+#: diff.c:5407
+msgid "produce the smallest possible diff"
+msgstr "produci il diff più piccolo possibile"
 
-#: builtin/grep.c:478 builtin/grep.c:512
-#, c-format
-msgid "unable to read tree (%s)"
-msgstr "impossibile leggere il tree (%s)"
+#: diff.c:5410
+msgid "ignore whitespace when comparing lines"
+msgstr "ignora gli spazi bianchi durante il confronto delle righe"
 
-#: builtin/grep.c:526
-#, c-format
-msgid "unable to grep from object of type %s"
+#: diff.c:5413
+msgid "ignore changes in amount of whitespace"
+msgstr "ignora le modifiche al numero degli spazi bianchi"
+
+#: diff.c:5416
+msgid "ignore changes in whitespace at EOL"
+msgstr "ignora modifiche agli spazi bianchi a fine riga"
+
+#: diff.c:5419
+msgid "ignore carrier-return at the end of line"
+msgstr "ignora carattere ritorno a capo a fine riga"
+
+#: diff.c:5422
+msgid "ignore changes whose lines are all blank"
+msgstr "ignora modifiche che riguardano solo righe vuote"
+
+#: diff.c:5425
+msgid "heuristic to shift diff hunk boundaries for easy reading"
 msgstr ""
+"euristica per spostare i limiti degli hunk nel diff per una lettura agevole"
 
-#: builtin/grep.c:584
-#, c-format
-msgid "switch `%c' expects a numerical value"
-msgstr "switch '%c' richiede un valore numerico"
+#: diff.c:5428
+msgid "generate diff using the \"patience diff\" algorithm"
+msgstr "genera il diff usando l'algoritmo \"patience diff\""
 
-#: builtin/grep.c:601
-#, c-format
-msgid "cannot open '%s'"
-msgstr "impossibile aprire '%s'"
+#: diff.c:5432
+msgid "generate diff using the \"histogram diff\" algorithm"
+msgstr "genera il diff usando l'algoritmo \"histogram diff\""
 
-#: builtin/grep.c:885
-msgid "no pattern given."
-msgstr "nessun modello specificato."
+#: diff.c:5434
+msgid "<algorithm>"
+msgstr "<algoritmo>"
 
-#: builtin/grep.c:899
-#, c-format
-msgid "bad object %s"
-msgstr "oggetto %s errato"
+#: diff.c:5435
+msgid "choose a diff algorithm"
+msgstr "seleziona un algoritmo diff"
 
-#: builtin/grep.c:940
-msgid "--open-files-in-pager only works on the worktree"
+#: diff.c:5437
+msgid "<text>"
+msgstr "<testo>"
+
+#: diff.c:5438
+msgid "generate diff using the \"anchored diff\" algorithm"
+msgstr "genera il diff usando l'algoritmo \"anchored diff\""
+
+#: diff.c:5440 diff.c:5449 diff.c:5452
+msgid "<mode>"
+msgstr "<modalità>"
+
+#: diff.c:5441
+msgid "show word diff, using <mode> to delimit changed words"
 msgstr ""
+"visualizza il diff parola per parola usando <modalità> per delimitare le "
+"parole modificate"
 
-#: builtin/grep.c:963
-msgid "--cached or --untracked cannot be used with --no-index."
-msgstr "--cached o --untracked non può essere usato con --no-index."
+#: diff.c:5443 diff.c:5446 diff.c:5491
+msgid "<regex>"
+msgstr "<espressione regolare>"
 
-#: builtin/grep.c:968
-msgid "--no-index or --untracked cannot be used with revs."
-msgstr "--no-index o --untracked non possono essere usate con le revisioni."
+#: diff.c:5444
+msgid "use <regex> to decide what a word is"
+msgstr "usa <espressione regolare> per decidere cosa costituisce una parola"
 
-#: builtin/grep.c:971
-msgid "--[no-]exclude-standard cannot be used for tracked contents."
+#: diff.c:5447
+msgid "equivalent to --word-diff=color --word-diff-regex=<regex>"
 msgstr ""
+"equivalente di --word-diff=color --word-diff-regex=<espressione regolare>"
+
+#: diff.c:5450
+msgid "moved lines of code are colored differently"
+msgstr "le righe di codice spostate sono colorate in modo diverso"
+
+#: diff.c:5453
+msgid "how white spaces are ignored in --color-moved"
+msgstr "modo in cui sono ignorati gli spazi bianchi in --color-moved"
+
+#: diff.c:5456
+msgid "Other diff options"
+msgstr "Altre opzioni diff"
 
-#: builtin/grep.c:979
-msgid "both --cached and trees are given."
+#: diff.c:5458
+msgid "when run from subdir, exclude changes outside and show relative paths"
 msgstr ""
+"se eseguito da una sottodirectory, escludi le modifiche esterne ad essa e "
+"visualizza i percorsi relativi"
 
-#: builtin/help.c:59
-#, c-format
-msgid "unrecognized help format '%s'"
-msgstr "formato di aiuto '%s' non riconosciuto"
+#: diff.c:5462
+msgid "treat all files as text"
+msgstr "tratta tutti i file come se fossero di testo"
 
-#: builtin/help.c:87
-msgid "Failed to start emacsclient."
-msgstr "Esecuzione di emacsclient non riuscita."
+#: diff.c:5464
+msgid "swap two inputs, reverse the diff"
+msgstr "scambia i due input, genera un diff al contrario"
 
-#: builtin/help.c:100
-msgid "Failed to parse emacsclient version."
-msgstr "Verifica della versione di emacsclient non riuscita."
+#: diff.c:5466
+msgid "exit with 1 if there were differences, 0 otherwise"
+msgstr "esci con codice 1 se ci sono differenze, con 0 altrimenti"
 
-#: builtin/help.c:108
-#, c-format
-msgid "emacsclient version '%d' too old (< 22)."
-msgstr "la versione '%d' di emacsclient è troppo vecchia (<22)."
+#: diff.c:5468
+msgid "disable all output of the program"
+msgstr "disabilita l'intero output del programma"
 
-#: builtin/help.c:126 builtin/help.c:154 builtin/help.c:163 builtin/help.c:171
-#, c-format
-msgid "failed to exec '%s': %s"
-msgstr "esecuzione di '%s' non riuscita: %s"
+#: diff.c:5470
+msgid "allow an external diff helper to be executed"
+msgstr "consenti l'esecuzione di un helper diff esterno"
 
-#: builtin/help.c:211
-#, c-format
-msgid ""
-"'%s': path for unsupported man viewer.\n"
-"Please consider using 'man.<tool>.cmd' instead."
+#: diff.c:5472
+msgid "run external text conversion filters when comparing binary files"
 msgstr ""
-"'%s': path ad un visualizzatore man pages non supportato.\n"
-"Usa invece 'man.<tool>.cmd'."
+"esegui filtri di conversione in testo esterni quando si confrontano file "
+"binari"
 
-#: builtin/help.c:223
-#, c-format
-msgid ""
-"'%s': cmd for supported man viewer.\n"
-"Please consider using 'man.<tool>.path' instead."
-msgstr ""
-"'%s': comando per visualizzatore man pages supportato.\n"
-"Per favore usa 'man.<tool>.path' invece."
+#: diff.c:5474
+msgid "<when>"
+msgstr "<quando>"
 
-#: builtin/help.c:287
-msgid "The most commonly used git commands are:"
-msgstr "I comandi git usati più di frequente sono:"
+#: diff.c:5475
+msgid "ignore changes to submodules in the diff generation"
+msgstr "ignora le modifiche ai sottomoduli durante la generazione del diff"
 
-#: builtin/help.c:355
-#, c-format
-msgid "'%s': unknown man viewer."
-msgstr "'%s': visualizzatore man sconosciuto."
+#: diff.c:5478
+msgid "<format>"
+msgstr "<formato>"
 
-#: builtin/help.c:372
-msgid "no man viewer handled the request"
-msgstr "nessun visualizzatore man ha gestito la richiesta"
+#: diff.c:5479
+msgid "specify how differences in submodules are shown"
+msgstr "specifica come verranno visualizzate le differenze nei sottomoduli"
 
-#: builtin/help.c:380
-msgid "no info viewer handled the request"
-msgstr "nessun visualizzatore info ha gestito la richiesta"
+#: diff.c:5483
+msgid "hide 'git add -N' entries from the index"
+msgstr "nascondi le voci 'git add -N' nell'indice"
 
-#: builtin/help.c:391
-#, c-format
-msgid "'%s': not a documentation directory."
-msgstr "'%s': non è una directory della documentazione."
+#: diff.c:5486
+msgid "treat 'git add -N' entries as real in the index"
+msgstr "tratta le voci 'git add -N' come reali nell'indice"
 
-#: builtin/help.c:432 builtin/help.c:439
-#, c-format
-msgid "usage: %s%s"
-msgstr "uso: %s%s"
+#: diff.c:5488
+msgid "<string>"
+msgstr "<stringa>"
 
-#: builtin/help.c:453
-#, c-format
-msgid "`git %s' is aliased to `%s'"
-msgstr "'git %s è un alias di '%s'"
+#: diff.c:5489
+msgid ""
+"look for differences that change the number of occurrences of the specified "
+"string"
+msgstr ""
+"cerca differenze che modificano il numero di occorrenze della stringa "
+"specificata"
 
-#: builtin/index-pack.c:169
-#, c-format
-msgid "object type mismatch at %s"
+#: diff.c:5492
+msgid ""
+"look for differences that change the number of occurrences of the specified "
+"regex"
 msgstr ""
+"cerca differenze che modificano il numero di occorrenze dell'espressione "
+"regolare specificata"
+
+#: diff.c:5495
+msgid "show all changes in the changeset with -S or -G"
+msgstr "visualizza tutte le modifiche nel changeset con -S o -G"
 
-#: builtin/index-pack.c:189
-msgid "object of unexpected type"
+#: diff.c:5498
+msgid "treat <string> in -S as extended POSIX regular expression"
 msgstr ""
+"tratta la <stringa> nell'opzione -S come un'espressione regolare POSIX estesa"
 
-#: builtin/index-pack.c:226
-#, c-format
-msgid "cannot fill %d byte"
-msgid_plural "cannot fill %d bytes"
-msgstr[0] ""
-msgstr[1] ""
+#: diff.c:5501
+msgid "control the order in which files appear in the output"
+msgstr "controlla l'ordine con cui i file appariranno nell'output"
 
-#: builtin/index-pack.c:236
-msgid "early EOF"
-msgstr "EOF prematuro"
+#: diff.c:5502
+msgid "<object-id>"
+msgstr "<ID oggetto>"
 
-#: builtin/index-pack.c:237
-msgid "read error on input"
-msgstr "errore di lettura in input"
+#: diff.c:5503
+msgid ""
+"look for differences that change the number of occurrences of the specified "
+"object"
+msgstr ""
+"cerca differenze che modificano il numero di occorrenze dell'oggetto "
+"specificato"
 
-#: builtin/index-pack.c:249
-msgid "used more bytes than were available"
-msgstr "usati più byte di quelli disponibili"
+#: diff.c:5505
+msgid "[(A|C|D|M|R|T|U|X|B)...[*]]"
+msgstr "[(A|C|D|M|R|T|U|X|B)...[*]]"
 
-#: builtin/index-pack.c:256
-msgid "pack too large for current definition of off_t"
-msgstr "pack troppo largo per la definizione corrente di off_t"
+#: diff.c:5506
+msgid "select files by diff type"
+msgstr "seleziona file in base al tipo diff"
 
-#: builtin/index-pack.c:272
-#, c-format
-msgid "unable to create '%s'"
-msgstr "impossibile creare '%s'"
+#: diff.c:5508
+msgid "<file>"
+msgstr "<file>"
 
-#: builtin/index-pack.c:277
-#, c-format
-msgid "cannot open packfile '%s'"
-msgstr "impossibile aprire il file pack '%s'"
+#: diff.c:5509
+msgid "Output to a specific file"
+msgstr "Salva l'output in un file specifico"
 
-#: builtin/index-pack.c:291
-msgid "pack signature mismatch"
-msgstr "la firma del pack non coincide"
+#: diff.c:6164
+msgid "inexact rename detection was skipped due to too many files."
+msgstr ""
+"il rilevamento ridenominazione non esatta è stato omesso per la presenza di "
+"troppi file."
 
-#: builtin/index-pack.c:311
-#, c-format
-msgid "pack has bad object at offset %lu: %s"
+#: diff.c:6167
+msgid "only found copies from modified paths due to too many files."
 msgstr ""
+"trovate solo copie dai percorsi modificati per la presenza di troppi file."
 
-#: builtin/index-pack.c:405
+#: diff.c:6170
 #, c-format
-msgid "inflate returned %d"
+msgid ""
+"you may want to set your %s variable to at least %d and retry the command."
 msgstr ""
+"potresti voler impostare la variabile %s ad almeno %d e riprovare ad "
+"eseguire il comando."
 
-#: builtin/index-pack.c:450
-msgid "offset value overflow for delta base object"
+#: dir.c:554
+#, c-format
+msgid "pathspec '%s' did not match any file(s) known to git"
 msgstr ""
+"lo specificatore percorso '%s' non corrisponde ad alcun file noto a git"
 
-#: builtin/index-pack.c:458
-msgid "delta base offset is out of bound"
-msgstr ""
+#: dir.c:664
+#, c-format
+msgid "unrecognized pattern: '%s'"
+msgstr "pattern non riconosciuto: '%s'"
 
-#: builtin/index-pack.c:466
+#: dir.c:682 dir.c:696
 #, c-format
-msgid "unknown object type %d"
-msgstr "tipo di oggetto %d sconosciuto"
+msgid "unrecognized negative pattern: '%s'"
+msgstr "pattern negativo non riconosciuto: '%s'"
 
-#: builtin/index-pack.c:495
-msgid "cannot pread pack file"
+#: dir.c:714
+#, c-format
+msgid "your sparse-checkout file may have issues: pattern '%s' is repeated"
 msgstr ""
+"il file sparse-checkout potrebbe avere dei problemi: il pattern '%s' è"
+" ripetuto"
 
-#: builtin/index-pack.c:497
+#: dir.c:724
+msgid "disabling cone pattern matching"
+msgstr "disabilito il pattern matching di tipo cone"
+
+#: dir.c:1101
 #, c-format
-msgid "premature end of pack file, %lu byte missing"
-msgid_plural "premature end of pack file, %lu bytes missing"
-msgstr[0] ""
-msgstr[1] ""
+msgid "cannot use %s as an exclude file"
+msgstr "impossibile usare %s come file di esclusione"
 
-#: builtin/index-pack.c:510
-msgid "serious inflate inconsistency"
-msgstr ""
+#: dir.c:2078
+#, c-format
+msgid "could not open directory '%s'"
+msgstr "impossibile aprire la directory '%s'"
 
-#: builtin/index-pack.c:583
+#: dir.c:2415
+msgid "failed to get kernel name and information"
+msgstr "impossibile ottenere il nome e le informazioni sul kernel"
+
+#: dir.c:2539
+msgid "untracked cache is disabled on this system or location"
+msgstr "la cache non tracciata è disabilitata su questo sistema o percorso"
+
+#: dir.c:3343
 #, c-format
-msgid "cannot read existing object %s"
-msgstr "non è possibile leggere l'oggetto %s esistente"
+msgid "index file corrupt in repo %s"
+msgstr "file index corrotto nel repository %s"
 
-#: builtin/index-pack.c:586
+#: dir.c:3388 dir.c:3393
 #, c-format
-msgid "SHA1 COLLISION FOUND WITH %s !"
-msgstr "TROVATA COLLISIONE SHA1 CON %s !"
+msgid "could not create directories for %s"
+msgstr "impossibile creare le directory per %s"
 
-#: builtin/index-pack.c:598
+#: dir.c:3422
 #, c-format
-msgid "invalid blob object %s"
-msgstr "oggetto blob %s non valido"
+msgid "could not migrate git directory from '%s' to '%s'"
+msgstr "impossibile migrare la directory git da '%s' a '%s'"
 
-#: builtin/index-pack.c:610
+#: editor.c:73
 #, c-format
-msgid "invalid %s"
-msgstr "%s non valido"
+msgid "hint: Waiting for your editor to close the file...%c"
+msgstr ""
+"suggerimento: In attesa della chiusura del file da parte dell'editor...%c"
 
-#: builtin/index-pack.c:612
-msgid "Error in object"
-msgstr "Errore nell'oggetto"
+#: entry.c:178
+msgid "Filtering content"
+msgstr "Filtraggio contenuto in corso"
 
-#: builtin/index-pack.c:614
+#: entry.c:476
 #, c-format
-msgid "Not all child objects of %s are reachable"
-msgstr "Non tutti gli oggetti figlio di %s sono raggiungibili"
+msgid "could not stat file '%s'"
+msgstr "impossibile eseguire stat sul file '%s'"
 
-#: builtin/index-pack.c:687 builtin/index-pack.c:713
-msgid "failed to apply delta"
-msgstr "applicazione del delta non riuscita"
+#: environment.c:149
+#, c-format
+msgid "bad git namespace path \"%s\""
+msgstr "percorso spazio dei nomi git \"%s\" non valido"
 
-#: builtin/index-pack.c:850
-msgid "Receiving objects"
-msgstr "Ricezione degli oggetti"
+#: environment.c:331
+#, c-format
+msgid "could not set GIT_DIR to '%s'"
+msgstr "impossibile impostare GIT_DIR a '%s'"
 
-#: builtin/index-pack.c:850
-msgid "Indexing objects"
-msgstr "Indicizzazione degli oggetti"
+#: exec-cmd.c:363
+#, c-format
+msgid "too many args to run %s"
+msgstr "troppi argomenti per eseguire %s"
 
-#: builtin/index-pack.c:872
-msgid "pack is corrupted (SHA1 mismatch)"
-msgstr "il pack è corrotto (SHA1 non corrisponde)"
+#: fetch-pack.c:150
+msgid "git fetch-pack: expected shallow list"
+msgstr "git fetch-pack: attesa lista shallow"
 
-#: builtin/index-pack.c:877
-msgid "cannot fstat packfile"
-msgstr ""
+#: fetch-pack.c:153
+msgid "git fetch-pack: expected a flush packet after shallow list"
+msgstr "git fetch-pack: atteso pacchetto flush dopo lista shallow"
 
-#: builtin/index-pack.c:880
-msgid "pack has junk at the end"
-msgstr ""
+#: fetch-pack.c:164
+msgid "git fetch-pack: expected ACK/NAK, got a flush packet"
+msgstr "git fetch-pack: attesi ACK/NAK, ricevuto pacchetto flush"
 
-#: builtin/index-pack.c:903
-msgid "Resolving deltas"
-msgstr "Risoluzione dei delta"
+#: fetch-pack.c:184
+#, c-format
+msgid "git fetch-pack: expected ACK/NAK, got '%s'"
+msgstr "git fetch-pack: attesi ACK/NAK, ricevuto '%s'"
 
-#: builtin/index-pack.c:954
-msgid "confusion beyond insanity"
-msgstr "confusione al di là della follia"
+#: fetch-pack.c:195
+msgid "unable to write to remote"
+msgstr "impossibile scrivere sul remoto"
 
-#: builtin/index-pack.c:973
+#: fetch-pack.c:257
+msgid "--stateless-rpc requires multi_ack_detailed"
+msgstr "--stateless-rpc richiede multi_ack_detailed"
+
+#: fetch-pack.c:356 fetch-pack.c:1340
 #, c-format
-msgid "pack has %d unresolved delta"
-msgid_plural "pack has %d unresolved deltas"
-msgstr[0] "pack ha %d delta irrisolto"
-msgstr[1] "pack ha %d delta irrisolti"
+msgid "invalid shallow line: %s"
+msgstr "riga shallow non valida: '%s'"
 
-#: builtin/index-pack.c:998
+#: fetch-pack.c:362 fetch-pack.c:1346
 #, c-format
-msgid "unable to deflate appended object (%d)"
-msgstr ""
+msgid "invalid unshallow line: %s"
+msgstr "riga unshallow non valida: '%s'"
 
-#: builtin/index-pack.c:1077
+#: fetch-pack.c:364 fetch-pack.c:1348
 #, c-format
-msgid "local object %s is corrupt"
-msgstr "l'oggetto locale %s è corrotto"
+msgid "object not found: %s"
+msgstr "oggetto non trovato: %s"
 
-#: builtin/index-pack.c:1101
-msgid "error while closing pack file"
-msgstr "errore nella chiusura del file pack"
+#: fetch-pack.c:367 fetch-pack.c:1351
+#, c-format
+msgid "error in object: %s"
+msgstr "errore nell'oggetto: %s"
 
-#: builtin/index-pack.c:1114
+#: fetch-pack.c:369 fetch-pack.c:1353
 #, c-format
-msgid "cannot write keep file '%s'"
-msgstr "impossibile scrivere il file keep '%s'"
+msgid "no shallow found: %s"
+msgstr "nessuno shallow trovato: %s"
 
-#: builtin/index-pack.c:1122
+#: fetch-pack.c:372 fetch-pack.c:1357
 #, c-format
-msgid "cannot close written keep file '%s'"
-msgstr ""
+msgid "expected shallow/unshallow, got %s"
+msgstr "attesi shallow/unshallow, ricevuto %s"
 
-#: builtin/index-pack.c:1135
-msgid "cannot store pack file"
-msgstr "impossibile archiviare il file pack"
+#: fetch-pack.c:414
+#, c-format
+msgid "got %s %d %s"
+msgstr "ricevuto %s %d %s"
 
-#: builtin/index-pack.c:1146
-msgid "cannot store index file"
-msgstr "impossibile archiviare index file"
-
-#: builtin/index-pack.c:1247
+#: fetch-pack.c:431
 #, c-format
-msgid "Cannot open existing pack file '%s'"
-msgstr "Impossibile aprire il file pack '%s' esistente"
+msgid "invalid commit %s"
+msgstr "commit non valido: %s"
+
+#: fetch-pack.c:462
+msgid "giving up"
+msgstr "smetto di provare"
+
+#: fetch-pack.c:475 progress.c:323
+msgid "done"
+msgstr "fatto"
 
-#: builtin/index-pack.c:1249
+#: fetch-pack.c:487
 #, c-format
-msgid "Cannot open existing pack idx file for '%s'"
-msgstr ""
+msgid "got %s (%d) %s"
+msgstr "ricevuto %s (%d) %s"
 
-#: builtin/index-pack.c:1296
+#: fetch-pack.c:533
 #, c-format
-msgid "non delta: %d object"
-msgid_plural "non delta: %d objects"
-msgstr[0] "non delta: %d oggetto"
-msgstr[1] "non delta: %d oggetti"
+msgid "Marking %s as complete"
+msgstr "Contrassegno %s come completo"
 
-#: builtin/index-pack.c:1303
+#: fetch-pack.c:754
 #, c-format
-msgid "chain length = %d: %lu object"
-msgid_plural "chain length = %d: %lu objects"
-msgstr[0] "lunghezza della catena = %d: %lu oggetto"
-msgstr[1] "lunghezza della catena = %d: %lu oggetti"
+msgid "already have %s (%s)"
+msgstr "ho già %s (%s)"
 
-#: builtin/index-pack.c:1330
-msgid "Cannot come back to cwd"
+#: fetch-pack.c:818
+msgid "fetch-pack: unable to fork off sideband demultiplexer"
 msgstr ""
+"fetch-pack: impossibile eseguire il fork del demultiplexer della banda "
+"laterlae"
 
-#: builtin/index-pack.c:1374 builtin/index-pack.c:1377
-#: builtin/index-pack.c:1389 builtin/index-pack.c:1393
-#, c-format
-msgid "bad %s"
-msgstr "%s errato"
+#: fetch-pack.c:826
+msgid "protocol error: bad pack header"
+msgstr "errore protocollo: intestazione pack non valida"
 
-#: builtin/index-pack.c:1407
-msgid "--fix-thin cannot be used without --stdin"
-msgstr "--fix-thin non può essere usato senza --stdin"
+#: fetch-pack.c:900
+#, c-format
+msgid "fetch-pack: unable to fork off %s"
+msgstr "fetch-pack: impossibile eseguire il fork di %s"
 
-#: builtin/index-pack.c:1411 builtin/index-pack.c:1421
+#: fetch-pack.c:916
 #, c-format
-msgid "packfile name '%s' does not end with '.pack'"
-msgstr "il nome del file pack '%s' non termina con '.pack'"
+msgid "%s failed"
+msgstr "%s non riuscito"
 
-#: builtin/index-pack.c:1430
-msgid "--verify with no packfile name given"
-msgstr "--verify senza un nome del file pack specificato"
+#: fetch-pack.c:918
+msgid "error in sideband demultiplexer"
+msgstr "errore nel demultiplexer della banda laterale"
 
-#: builtin/init-db.c:35
+#: fetch-pack.c:965
 #, c-format
-msgid "Could not make %s writable by group"
-msgstr "Non è stato possible rendere %s scrivibile dal gruppo"
+msgid "Server version is %.*s"
+msgstr "La versione del server è %.*s"
 
-#: builtin/init-db.c:62
+#: fetch-pack.c:970 fetch-pack.c:976 fetch-pack.c:979 fetch-pack.c:985
+#: fetch-pack.c:989 fetch-pack.c:993 fetch-pack.c:997 fetch-pack.c:1001
+#: fetch-pack.c:1005 fetch-pack.c:1009 fetch-pack.c:1013 fetch-pack.c:1017
+#: fetch-pack.c:1023 fetch-pack.c:1029 fetch-pack.c:1034 fetch-pack.c:1039
 #, c-format
-msgid "insanely long template name %s"
-msgstr ""
+msgid "Server supports %s"
+msgstr "Il server supporta %s"
+
+#: fetch-pack.c:972
+msgid "Server does not support shallow clients"
+msgstr "Il server non supporta client shallow"
 
-#: builtin/init-db.c:67
+#: fetch-pack.c:1032
+msgid "Server does not support --shallow-since"
+msgstr "Il server non supporta --shallow-since"
+
+#: fetch-pack.c:1037
+msgid "Server does not support --shallow-exclude"
+msgstr "Il server non supporta --shallow-exclude"
+
+#: fetch-pack.c:1041
+msgid "Server does not support --deepen"
+msgstr "Il server non supporta --deepen"
+
+#: fetch-pack.c:1058
+msgid "no common commits"
+msgstr "nessun commit in comune"
+
+#: fetch-pack.c:1070 fetch-pack.c:1536
+msgid "git fetch-pack: fetch failed."
+msgstr "git fetch-pack: recupero non riuscito."
+
+#: fetch-pack.c:1209
+msgid "Server does not support shallow requests"
+msgstr "Il server non supporta le richieste shallow"
+
+#: fetch-pack.c:1216
+msgid "Server supports filter"
+msgstr "Il server supporta filter"
+
+#: fetch-pack.c:1239
+msgid "unable to write request to remote"
+msgstr "impossibile scrivere la richiesta sul remoto"
+
+#: fetch-pack.c:1257
 #, c-format
-msgid "cannot stat '%s'"
-msgstr "impossibile eseguire lo stat di '%s'"
+msgid "error reading section header '%s'"
+msgstr "errore durante la lettura dell'intestazione di sezione '%s'"
 
-#: builtin/init-db.c:73
+#: fetch-pack.c:1263
 #, c-format
-msgid "cannot stat template '%s'"
-msgstr ""
+msgid "expected '%s', received '%s'"
+msgstr "atteso '%s', ricevuto '%s'"
 
-#: builtin/init-db.c:80
+#: fetch-pack.c:1303
 #, c-format
-msgid "cannot opendir '%s'"
-msgstr ""
+msgid "unexpected acknowledgment line: '%s'"
+msgstr "riga di conferma inattesa: '%s'"
 
-#: builtin/init-db.c:97
+#: fetch-pack.c:1308
 #, c-format
-msgid "cannot readlink '%s'"
+msgid "error processing acks: %d"
+msgstr "errore durante l'elaborazione degli ack: %d"
+
+#: fetch-pack.c:1318
+msgid "expected packfile to be sent after 'ready'"
+msgstr "ci si attendeva che il packfile fosse inviato dopo 'ready'"
+
+#: fetch-pack.c:1320
+msgid "expected no other sections to be sent after no 'ready'"
 msgstr ""
+"ci si attendeva che nessun'altra sezione fosse inviata in assenza di 'ready'"
 
-#: builtin/init-db.c:99
+#: fetch-pack.c:1362
 #, c-format
-msgid "insanely long symlink %s"
-msgstr ""
+msgid "error processing shallow info: %d"
+msgstr "errore durante l'elaborazione delle informazioni shallow: %d"
 
-#: builtin/init-db.c:102
+#: fetch-pack.c:1409
 #, c-format
-msgid "cannot symlink '%s' '%s'"
-msgstr ""
+msgid "expected wanted-ref, got '%s'"
+msgstr "atteso wanted-ref, ricevuto '%s'"
 
-#: builtin/init-db.c:106
+#: fetch-pack.c:1414
 #, c-format
-msgid "cannot copy '%s' to '%s'"
-msgstr ""
+msgid "unexpected wanted-ref: '%s'"
+msgstr "wanted-ref inatteso: '%s'"
 
-#: builtin/init-db.c:110
+#: fetch-pack.c:1419
 #, c-format
-msgid "ignoring template %s"
-msgstr ""
+msgid "error processing wanted refs: %d"
+msgstr "errore durante l'elaborazione dei riferimenti desiderati: %d"
+
+#: fetch-pack.c:1762
+msgid "no matching remote head"
+msgstr "nessun head remoto corrispondente"
 
-#: builtin/init-db.c:133
+#: fetch-pack.c:1785 builtin/clone.c:688
+msgid "remote did not send all necessary objects"
+msgstr "il remoto non ha inviato tutti gli oggetti necessari"
+
+#: fetch-pack.c:1812
 #, c-format
-msgid "insanely long template path %s"
-msgstr ""
+msgid "no such remote ref %s"
+msgstr "riferimento remoto non esistente: %s"
 
-#: builtin/init-db.c:141
+#: fetch-pack.c:1815
 #, c-format
-msgid "templates not found %s"
-msgstr ""
+msgid "Server does not allow request for unadvertised object %s"
+msgstr "Il server non consente richieste per l'oggetto non pubblicizzato %s"
+
+#: gpg-interface.c:223
+msgid "could not create temporary file"
+msgstr "impossibile creare il file temporaneo"
 
-#: builtin/init-db.c:154
+#: gpg-interface.c:226
 #, c-format
-msgid "not copying templates of a wrong format version %d from '%s'"
-msgstr ""
+msgid "failed writing detached signature to '%s'"
+msgstr "scrittura della firma separata in '%s' non riuscita"
+
+#: gpg-interface.c:390
+msgid "gpg failed to sign the data"
+msgstr "gpg non è riuscito a firmare i dati"
 
-#: builtin/init-db.c:192
+#: graph.c:98
 #, c-format
-msgid "insane git directory %s"
+msgid "ignore invalid color '%.*s' in log.graphColors"
+msgstr "ignoro il colore non valido '%.*s' in log.graphColors"
+
+#: grep.c:668
+msgid ""
+"given pattern contains NULL byte (via -f <file>). This is only supported "
+"with -P under PCRE v2"
 msgstr ""
+"il pattern fornito (con -f <file>) contiene un byte NULL. Ciò è supportato "
+"solo con -P usando PCRE v2"
 
-#: builtin/init-db.c:322 builtin/init-db.c:325
+#: grep.c:2124
 #, c-format
-msgid "%s already exists"
-msgstr "%s esiste già"
+msgid "'%s': unable to read %s"
+msgstr "'%s': impossibile leggere %s"
 
-#: builtin/init-db.c:354
+#: grep.c:2141 setup.c:165 builtin/clone.c:411 builtin/diff.c:82
+#: builtin/rm.c:135
 #, c-format
-msgid "unable to handle file type %d"
-msgstr "impossibile gestire il tipo di file %d"
+msgid "failed to stat '%s'"
+msgstr "stat di '%s' non riuscito"
 
-#: builtin/init-db.c:357
+#: grep.c:2152
 #, c-format
-msgid "unable to move %s to %s"
-msgstr "impossibile spostare %s in %s"
+msgid "'%s': short read"
+msgstr "'%s': lettura troppo breve"
 
-#: builtin/init-db.c:362
-#, c-format
-msgid "Could not create git link %s"
-msgstr "Non è stato possibile creare il link git %s"
+#: help.c:23
+msgid "start a working area (see also: git help tutorial)"
+msgstr "crea un'area di lavoro (vedi anche: git help tutorial)"
 
-#.
-#. * TRANSLATORS: The first '%s' is either "Reinitialized
-#. * existing" or "Initialized empty", the second " shared" or
-#. * "", and the last '%s%s' is the verbatim directory name.
-#.
-#: builtin/init-db.c:419
-#, c-format
-msgid "%s%s Git repository in %s%s\n"
-msgstr "%s%s repository Git in %s%s\n"
+#: help.c:24
+msgid "work on the current change (see also: git help everyday)"
+msgstr "lavora sulle modifiche correnti (vedi anche: git help everyday)"
 
-#: builtin/init-db.c:420
-msgid "Reinitialized existing"
-msgstr "Reinizializzato un esistente"
+#: help.c:25
+msgid "examine the history and state (see also: git help revisions)"
+msgstr "esamina la cronologia e lo stato (vedi anche: git help revisions)"
 
-#: builtin/init-db.c:420
-msgid "Initialized empty"
-msgstr "Inizializzato un"
+#: help.c:26
+msgid "grow, mark and tweak your common history"
+msgstr "aumenta, contrassegna e metti a punto la cronologia comune"
 
-#: builtin/init-db.c:421
-msgid " shared"
-msgstr " condiviso"
+#: help.c:27
+msgid "collaborate (see also: git help workflows)"
+msgstr "collabora (vedi anche: git help workflows)"
 
-#: builtin/init-db.c:440
-msgid "cannot tell cwd"
-msgstr ""
+#: help.c:31
+msgid "Main Porcelain Commands"
+msgstr "Comandi principali di alto livello"
+
+#: help.c:32
+msgid "Ancillary Commands / Manipulators"
+msgstr "Comandi / operazioni di manipolazione ausiliari"
+
+#: help.c:33
+msgid "Ancillary Commands / Interrogators"
+msgstr "Comandi / operazioni di interrogazione ausiliari"
+
+#: help.c:34
+msgid "Interacting with Others"
+msgstr "Interazione con altri"
+
+#: help.c:35
+msgid "Low-level Commands / Manipulators"
+msgstr "Comandi / operazioni di manipolazione di basso livello"
 
-#: builtin/init-db.c:521 builtin/init-db.c:528
+#: help.c:36
+msgid "Low-level Commands / Interrogators"
+msgstr "Comandi / operazioni di interrogazione di basso livello"
+
+#: help.c:37
+msgid "Low-level Commands / Syncing Repositories"
+msgstr "Comandi di basso livello / Sincronizzazione repository"
+
+#: help.c:38
+msgid "Low-level Commands / Internal Helpers"
+msgstr "Comandi di basso livello / Funzioni helper interne"
+
+#: help.c:298
 #, c-format
-msgid "cannot mkdir %s"
-msgstr ""
+msgid "available git commands in '%s'"
+msgstr "comandi git disponibili in '%s'"
+
+#: help.c:305
+msgid "git commands available from elsewhere on your $PATH"
+msgstr "comandi git disponibili altrove nel tuo $PATH"
 
-#: builtin/init-db.c:532
+#: help.c:314
+msgid "These are common Git commands used in various situations:"
+msgstr "Questi sono i comandi Git comuni usati in varie situazioni:"
+
+#: help.c:363 git.c:98
 #, c-format
-msgid "cannot chdir to %s"
+msgid "unsupported command listing type '%s'"
+msgstr "tipo elenco comandi non supportato: '%s'"
+
+#: help.c:403
+msgid "The common Git guides are:"
+msgstr "Le guide Git comuni sono:"
+
+#: help.c:512
+msgid "See 'git help <command>' to read about a specific subcommand"
 msgstr ""
+"Vedi 'git help <comando>' per saperne di più su un sottocomando specifico"
+
+#: help.c:517
+msgid "External commands"
+msgstr "Comandi esterni"
+
+#: help.c:532
+msgid "Command aliases"
+msgstr "Alias comandi"
 
-#: builtin/init-db.c:554
+#: help.c:596
 #, c-format
 msgid ""
-"%s (or --work-tree=<directory>) not allowed without specifying %s (or --git-"
-"dir=<directory>)"
+"'%s' appears to be a git command, but we were not\n"
+"able to execute it. Maybe git-%s is broken?"
 msgstr ""
-"%s (o --work-tree=<directory>) non consentito senza specificare %s (o --git-"
-"dir=<directory>)"
+"'%s' sembra essere un comando git, ma non è stato\n"
+"possibile eseguirlo. Forse git-%s è corrotto?"
 
-#: builtin/init-db.c:578
-msgid "Cannot access current working directory"
-msgstr "Impossibile accedere alla directory di lavoro corrente"
+#: help.c:655
+msgid "Uh oh. Your system reports no Git commands at all."
+msgstr "Oh oh. Il tuo sistema non riporta alcun comando Git."
 
-#: builtin/init-db.c:585
+#: help.c:677
 #, c-format
-msgid "Cannot access work tree '%s'"
-msgstr ""
+msgid "WARNING: You called a Git command named '%s', which does not exist."
+msgstr "ATTENZIONE: hai chiamato un comando Git '%s' inesistente."
 
-#: builtin/log.c:188
+#: help.c:682
 #, c-format
-msgid "Final output: %d %s\n"
-msgstr "Output finale: %d %s\n"
+msgid "Continuing under the assumption that you meant '%s'."
+msgstr "Continuo assumendo che intendessi '%s'."
 
-#: builtin/log.c:401 builtin/log.c:489
+#: help.c:687
 #, c-format
-msgid "Could not read object %s"
-msgstr "Non è stato possibile leggere l'oggetto %s"
+msgid "Continuing in %0.1f seconds, assuming that you meant '%s'."
+msgstr "Continuo fra %0.1f secondi assumendo che intendessi '%s'."
 
-#: builtin/log.c:513
+#: help.c:695
 #, c-format
-msgid "Unknown type: %d"
-msgstr "Tipo sconosciuto: %d"
+msgid "git: '%s' is not a git command. See 'git --help'."
+msgstr "git: '%s' non è un comando git. Vedi 'git --help'."
 
-#: builtin/log.c:602
-msgid "format.headers without value"
-msgstr "format.headers non ha alcun valore"
+#: help.c:699
+msgid ""
+"\n"
+"The most similar command is"
+msgid_plural ""
+"\n"
+"The most similar commands are"
+msgstr[0] ""
+"\n"
+"Il comando maggiormente simile è"
+msgstr[1] ""
+"\n"
+"I comandi maggiormente simili sono"
 
-#: builtin/log.c:676
-msgid "name of output directory is too long"
-msgstr "il nome della directory di output è troppo lungo"
+#: help.c:714
+msgid "git version [<options>]"
+msgstr "git version [<opzioni>]"
 
-#: builtin/log.c:687
+#: help.c:783
 #, c-format
-msgid "Cannot open patch file %s"
-msgstr "Impossibile aprire il file patch %s"
+msgid "%s: %s - %s"
+msgstr "%s: %s - %s"
 
-#: builtin/log.c:701
-msgid "Need exactly one range."
-msgstr ""
+#: help.c:787
+msgid ""
+"\n"
+"Did you mean this?"
+msgid_plural ""
+"\n"
+"Did you mean one of these?"
+msgstr[0] ""
+"\n"
+"Intendevi questo?"
+msgstr[1] ""
+"\n"
+"Intendevi uno di questi?"
 
-#: builtin/log.c:709
-msgid "Not a range."
+#: ident.c:349
+msgid ""
+"\n"
+"*** Please tell me who you are.\n"
+"\n"
+"Run\n"
+"\n"
+"  git config --global user.email \"you@example.com\"\n"
+"  git config --global user.name \"Your Name\"\n"
+"\n"
+"to set your account's default identity.\n"
+"Omit --global to set the identity only in this repository.\n"
+"\n"
 msgstr ""
+"\n"
+"*** Dimmi chi sei.\n"
+"\n"
+"Esegui\n"
+"\n"
+"  git config --global user.email \"tu@esempio.com\"\n"
+"  git config --global user.name \"Il tuo nome\"\n"
+"\n"
+"per impostare l'identità predefinita del tuo account.\n"
+"Ometti --global per impostare l'identità solo in questo repository.\n"
+"\n"
 
-#: builtin/log.c:786
-msgid "Cover letter needs email format"
+#: ident.c:379
+msgid "no email was given and auto-detection is disabled"
 msgstr ""
+"nessun indirizzo e-mail specificato e rilevamento automatico disabilitato"
 
-#: builtin/log.c:859
+#: ident.c:384
 #, c-format
-msgid "insane in-reply-to: %s"
+msgid "unable to auto-detect email address (got '%s')"
 msgstr ""
+"impossibile rilevare automaticamente l'indirizzo e-mail (ho ricavato '%s')"
 
-#: builtin/log.c:932
-msgid "Two output directories?"
-msgstr "Due directory di output?"
+#: ident.c:401
+msgid "no name was given and auto-detection is disabled"
+msgstr "nessun nome specificato e rilevamento automatico disabilitato"
 
-#: builtin/log.c:1153
+#: ident.c:407
 #, c-format
-msgid "bogus committer info %s"
-msgstr ""
-
-#: builtin/log.c:1198
-msgid "-n and -k are mutually exclusive."
-msgstr ""
+msgid "unable to auto-detect name (got '%s')"
+msgstr "impossibile rilevare automaticamente il nome (ho ricavato '%s')"
 
-#: builtin/log.c:1200
-msgid "--subject-prefix and -k are mutually exclusive."
-msgstr ""
-
-#: builtin/log.c:1208
-msgid "--name-only does not make sense"
-msgstr "--name-only non ha senso"
-
-#: builtin/log.c:1210
-msgid "--name-status does not make sense"
-msgstr "--name-status non ha senso"
-
-#: builtin/log.c:1212
-msgid "--check does not make sense"
-msgstr "--check non ha senso"
-
-#: builtin/log.c:1235
-msgid "standard output, or directory, which one?"
-msgstr "standard output, o directory, quale dei due?"
-
-#: builtin/log.c:1237
+#: ident.c:415
 #, c-format
-msgid "Could not create directory '%s'"
-msgstr "Non è stato possibile creare la directory '%s'"
+msgid "empty ident name (for <%s>) not allowed"
+msgstr "nome ident vuoto (per <%s>) non consentito"
 
-#: builtin/log.c:1390
-msgid "Failed to create output files"
-msgstr "Creazione dei file di output non riuscita"
+#: ident.c:421
+#, c-format
+msgid "name consists only of disallowed characters: %s"
+msgstr "il nome è composto solo da caratteri non consentiti: %s"
 
-#: builtin/log.c:1494
+#: ident.c:436 builtin/commit.c:631
 #, c-format
-msgid ""
-"Could not find a tracked remote branch, please specify <upstream> manually.\n"
-msgstr ""
+msgid "invalid date format: %s"
+msgstr "formato data non valido: %s"
 
-#: builtin/log.c:1510 builtin/log.c:1512 builtin/log.c:1524
+#: list-objects.c:127
 #, c-format
-msgid "Unknown commit %s"
-msgstr "Commit %s sconosciuto"
+msgid "entry '%s' in tree %s has tree mode, but is not a tree"
+msgstr "la voce '%s' nell'albero %s ha la modalità albero, ma non è un albero"
 
-#: builtin/merge.c:90
-msgid "switch `m' requires a value"
-msgstr "lo switch 'm' richiede un valore"
+#: list-objects.c:140
+#, c-format
+msgid "entry '%s' in tree %s has blob mode, but is not a blob"
+msgstr "la voce '%s' nell'albero %s ha la modalità blob, ma non è un blob"
 
-#: builtin/merge.c:127
+#: list-objects.c:375
 #, c-format
-msgid "Could not find merge strategy '%s'.\n"
-msgstr "Non è stato possibile trovare la strategia di merge '%s'.\n"
+msgid "unable to load root tree for commit %s"
+msgstr "impossibile caricare l'albero radice per il commit %s"
 
-#: builtin/merge.c:128
+#: list-objects-filter.c:492
 #, c-format
-msgid "Available strategies are:"
-msgstr "Le strategie disponibili sono:"
+msgid "unable to access sparse blob in '%s'"
+msgstr "impossibile accedere al blob sparse in '%s'"
 
-#: builtin/merge.c:133
+#: list-objects-filter.c:495
 #, c-format
-msgid "Available custom strategies are:"
-msgstr "Le strategie personalizzate disponibili sono:"
+msgid "unable to parse sparse filter data in %s"
+msgstr "impossibile analizzare i dati filtro sparse in %s"
 
-#: builtin/merge.c:240
-msgid "could not run stash."
-msgstr "non è stato possibile eseguire stash."
+#: list-objects-filter-options.c:58
+msgid "expected 'tree:<depth>'"
+msgstr "atteso 'tree:<profondità>'"
 
-#: builtin/merge.c:245
-msgid "stash failed"
-msgstr "esecuzione di stash non riuscita"
+#: list-objects-filter-options.c:73
+msgid "sparse:path filters support has been dropped"
+msgstr "il supporto per i filtri sparse:percorso è stato rimosso"
 
-#: builtin/merge.c:250
+#: list-objects-filter-options.c:86
 #, c-format
-msgid "not a valid object: %s"
-msgstr "non è un oggetto valido: %s"
-
-#: builtin/merge.c:269 builtin/merge.c:286
-msgid "read-tree failed"
-msgstr "read-tree non riuscito"
+msgid "invalid filter-spec '%s'"
+msgstr "specificatore filtro '%s' non valido"
 
-#: builtin/merge.c:316
-msgid " (nothing to squash)"
-msgstr ""
-
-#: builtin/merge.c:329
+#: list-objects-filter-options.c:102
 #, c-format
-msgid "Squash commit -- not updating HEAD\n"
+msgid "must escape char in sub-filter-spec: '%c'"
 msgstr ""
+"è necessario eseguire l'escape del carattere nello specificatore del "
+"sottofiltro: '%c'"
 
-#: builtin/merge.c:361
-msgid "Writing SQUASH_MSG"
-msgstr "Scrittura di SQUASH_MSG"
-
-#: builtin/merge.c:363
-msgid "Finishing SQUASH_MSG"
-msgstr "Completamento di SQUASH_MSG"
+#: list-objects-filter-options.c:144
+msgid "expected something after combine:"
+msgstr "atteso qualcosa dopo la ricombinazione:"
 
-#: builtin/merge.c:386
-#, c-format
-msgid "No merge message -- not updating HEAD\n"
-msgstr "Nessun messaggio di merge -- HEAD non viene aggiornato\n"
+#: list-objects-filter-options.c:226
+msgid "multiple filter-specs cannot be combined"
+msgstr "non è possibile combinare più specificatori filtro"
 
-#: builtin/merge.c:437
+#: lockfile.c:151
 #, c-format
-msgid "'%s' does not point to a commit"
-msgstr "'%s' non punta ad un commit"
+msgid ""
+"Unable to create '%s.lock': %s.\n"
+"\n"
+"Another git process seems to be running in this repository, e.g.\n"
+"an editor opened by 'git commit'. Please make sure all processes\n"
+"are terminated then try again. If it still fails, a git process\n"
+"may have crashed in this repository earlier:\n"
+"remove the file manually to continue."
+msgstr ""
+"Impossibile creare '%s.lock': %s.\n"
+"\n"
+"Sembra che un altro processo git sia in esecuzione in questo repository, ad "
+"es.\n"
+"un editor aperto da 'git commit'. Assicurati che tutti i processi\n"
+"siano terminati, quindi riprova. Se l'operazione continua a non riuscire, è\n"
+"possibile che un processo git sia andato in crash in questo repository\n"
+"in precedenza: rimuovi manualmente il file per continuare."
 
-#: builtin/merge.c:536
+#: lockfile.c:159
 #, c-format
-msgid "Bad branch.%s.mergeoptions string: %s"
-msgstr "Stringa branch.%s.mergeoptions errata: %s"
+msgid "Unable to create '%s.lock': %s"
+msgstr "Impossibile creare '%s.lock': %s"
 
-#: builtin/merge.c:629
-msgid "git write-tree failed to write a tree"
-msgstr ""
-
-#: builtin/merge.c:679
+#: merge.c:41
 msgid "failed to read the cache"
 msgstr "lettura della cache non riuscita"
 
-#: builtin/merge.c:697
-msgid "Unable to write index."
-msgstr "Impossibile scrivere index."
+#: merge.c:107 rerere.c:720 builtin/am.c:1874 builtin/am.c:1908
+#: builtin/checkout.c:539 builtin/checkout.c:798 builtin/clone.c:809
+#: builtin/stash.c:264
+msgid "unable to write new index file"
+msgstr "impossibile scrivere il nuovo file index"
 
-#: builtin/merge.c:710
-msgid "Not handling anything other than two heads merge."
-msgstr ""
+#: merge-recursive.c:367
+msgid "(bad commit)\n"
+msgstr "(commit non valido)\n"
 
-#: builtin/merge.c:724
+#: merge-recursive.c:390
 #, c-format
-msgid "Unknown option for merge-recursive: -X%s"
-msgstr "Opzione per merge-recursive sconosciuta: -X%s"
+msgid "add_cacheinfo failed for path '%s'; merge aborting."
+msgstr "add_cacheinfo non riuscito per il percorso '%s'; interrompo il merge."
 
-#: builtin/merge.c:738
+#: merge-recursive.c:399
 #, c-format
-msgid "unable to write %s"
-msgstr "non è possibile scrivere %s"
+msgid "add_cacheinfo failed to refresh for path '%s'; merge aborting."
+msgstr ""
+"aggiornamento add_cacheinfo non riuscito per il percorso '%s'; interrompo il "
+"merge."
 
-#: builtin/merge.c:877
+#: merge-recursive.c:885
 #, c-format
-msgid "Could not read from '%s'"
-msgstr "Non è stato possibile leggere da '%s'"
+msgid "failed to create path '%s'%s"
+msgstr "creazione del percorso '%s' non riuscita%s"
 
-#: builtin/merge.c:886
+#: merge-recursive.c:896
 #, c-format
-msgid "Not committing merge; use 'git commit' to complete the merge.\n"
-msgstr ""
+msgid "Removing %s to make room for subdirectory\n"
+msgstr "Rimuovo %s per fare spazio alla sottodirectory\n"
 
-#: builtin/merge.c:892
-msgid ""
-"Please enter a commit message to explain why this merge is necessary,\n"
-"especially if it merges an updated upstream into a topic branch.\n"
-"\n"
-"Lines starting with '#' will be ignored, and an empty message aborts\n"
-"the commit.\n"
-msgstr ""
+#: merge-recursive.c:910 merge-recursive.c:929
+msgid ": perhaps a D/F conflict?"
+msgstr ": forse si tratta di un conflitto D/F?"
 
-#: builtin/merge.c:916
-msgid "Empty commit message."
-msgstr "Messaggio di commit vuoto."
+#: merge-recursive.c:919
+#, c-format
+msgid "refusing to lose untracked file at '%s'"
+msgstr "mi rifiuto di perdere un file non tracciato in '%s'"
 
-#: builtin/merge.c:928
+#: merge-recursive.c:960 builtin/cat-file.c:41
 #, c-format
-msgid "Wonderful.\n"
-msgstr "Splendido.\n"
+msgid "cannot read object %s '%s'"
+msgstr "impossibile leggere l'oggetto %s '%s'"
 
-#: builtin/merge.c:993
+#: merge-recursive.c:965
 #, c-format
-msgid "Automatic merge failed; fix conflicts and then commit the result.\n"
-msgstr ""
-"Merge automatico fallito; risolvi i conflitti ed eseguire il commit\n"
-"del risultato.\n"
+msgid "blob expected for %s '%s'"
+msgstr "atteso blob per %s '%s'"
 
-#: builtin/merge.c:1009
+#: merge-recursive.c:990
 #, c-format
-msgid "'%s' is not a commit"
-msgstr "'%s' non è un commit"
+msgid "failed to open '%s': %s"
+msgstr "apertura di '%s' non riuscita: %s"
 
-#: builtin/merge.c:1050
-msgid "No current branch."
-msgstr "Nessun branch corrente."
+#: merge-recursive.c:1001
+#, c-format
+msgid "failed to symlink '%s': %s"
+msgstr "creazione del collegamento simbolico '%s' non riuscita: %s"
 
-#: builtin/merge.c:1052
-msgid "No remote for the current branch."
-msgstr "Nessun remote per il branch corrente."
+#: merge-recursive.c:1006
+#, c-format
+msgid "do not know what to do with %06o %s '%s'"
+msgstr "non so che fare con %06o %s '%s'"
 
-#: builtin/merge.c:1054
-msgid "No default upstream defined for the current branch."
-msgstr "Nessun upstream di default definito per il branch corrente."
+#: merge-recursive.c:1199
+#, c-format
+msgid "Failed to merge submodule %s (not checked out)"
+msgstr "Merge del sottomodulo %s non riuscito (checkout non eseguito)"
 
-#: builtin/merge.c:1059
+#: merge-recursive.c:1206
 #, c-format
-msgid "No remote tracking branch for %s from %s"
+msgid "Failed to merge submodule %s (commits not present)"
+msgstr "Merge del sottomodulo %s non riuscito (commit non presenti)"
+
+#: merge-recursive.c:1213
+#, c-format
+msgid "Failed to merge submodule %s (commits don't follow merge-base)"
 msgstr ""
+"Merge del sottomodulo %s non riuscito (i commit non seguono la base del "
+"merge)"
 
-#: builtin/merge.c:1146 builtin/merge.c:1303
+#: merge-recursive.c:1221 merge-recursive.c:1233
 #, c-format
-msgid "%s - not something we can merge"
-msgstr "%s - non è qualcosa per cui possiamo eseguire il merge"
+msgid "Fast-forwarding submodule %s to the following commit:"
+msgstr "Eseguo il fast forward del sottomodulo %s al seguente commit:"
 
-#: builtin/merge.c:1214
-msgid "There is no merge to abort (MERGE_HEAD missing)."
-msgstr "Non c'è nessun merge da interrompere (manca MERGE_HEAD)"
+#: merge-recursive.c:1224 merge-recursive.c:1236
+#, c-format
+msgid "Fast-forwarding submodule %s"
+msgstr "Eseguo il fast forward del sottomodulo %s"
 
-#: builtin/merge.c:1230 git-pull.sh:31
-msgid ""
-"You have not concluded your merge (MERGE_HEAD exists).\n"
-"Please, commit your changes before you can merge."
+#: merge-recursive.c:1259
+#, c-format
+msgid "Failed to merge submodule %s (merge following commits not found)"
 msgstr ""
-"Il merge non è stato concluso (esiste MERGE_HEAD).\n"
-"Per favore, esegui il commit delle modifiche prima del merge."
+"Merge del sottomodulo %s non riuscito (merge dopo i commit non trovato)"
 
-#: builtin/merge.c:1233 git-pull.sh:34
-msgid "You have not concluded your merge (MERGE_HEAD exists)."
-msgstr "Il merge non è stato concluso (esiste MERGE_HEAD)."
+#: merge-recursive.c:1263
+#, c-format
+msgid "Failed to merge submodule %s (not fast-forward)"
+msgstr "Merge del sottomodulo %s non riuscito (non fast forward)"
 
-#: builtin/merge.c:1237
+#: merge-recursive.c:1264
+msgid "Found a possible merge resolution for the submodule:\n"
+msgstr "Trovata possibile risoluzione merge per il sottomodulo:\n"
+
+#: merge-recursive.c:1267
+#, c-format
 msgid ""
-"You have not concluded your cherry-pick (CHERRY_PICK_HEAD exists).\n"
-"Please, commit your changes before you can merge."
+"If this is correct simply add it to the index for example\n"
+"by using:\n"
+"\n"
+"  git update-index --cacheinfo 160000 %s \"%s\"\n"
+"\n"
+"which will accept this suggestion.\n"
 msgstr ""
-"Il cherry-pick non è stato concluso (esiste CHERRY_PICK_HEAD).\n"
-"Per favore, esegui il commit delle modifiche prima del merge."
+"Se è corretta aggiungila semplicemente all'indice, ad esempio\n"
+"usando:\n"
+"\n"
+"  git update-index --cacheinfo 160000 %s \"%s\"\n"
+"\n"
+"per accettare questo suggerimento.\n"
 
-#: builtin/merge.c:1240
-msgid "You have not concluded your cherry-pick (CHERRY_PICK_HEAD exists)."
-msgstr "Il tuo cherry-pick non è stato concluso (CHERRY_PICK_HEAD esiste)."
+#: merge-recursive.c:1276
+#, c-format
+msgid "Failed to merge submodule %s (multiple merges found)"
+msgstr "Merge del sottomodulo %s non riuscito (più merge trovati)"
 
-#: builtin/merge.c:1249
-msgid "You cannot combine --squash with --no-ff."
-msgstr "Impossibile combinare --squash con --no-off."
+#: merge-recursive.c:1349
+msgid "Failed to execute internal merge"
+msgstr "Esecuzione del merge interno non riuscita"
 
-#: builtin/merge.c:1254
-msgid "You cannot combine --no-ff with --ff-only."
-msgstr "Impossibile combinare --no-ff con --ff-only."
+#: merge-recursive.c:1354
+#, c-format
+msgid "Unable to add %s to database"
+msgstr "Impossibile aggiungere %s al database"
 
-#: builtin/merge.c:1261
-msgid "No commit specified and merge.defaultToUpstream not set."
-msgstr "Nessun commit specificato e merge.defaultToUpstream non definito."
+#: merge-recursive.c:1386
+#, c-format
+msgid "Auto-merging %s"
+msgstr "Merge automatico di %s in corso"
 
-#: builtin/merge.c:1293
-msgid "Can merge only exactly one commit into empty head"
+#: merge-recursive.c:1410
+#, c-format
+msgid "Error: Refusing to lose untracked file at %s; writing to %s instead."
 msgstr ""
+"Errore: mi rifiuto di perdere il file non tracciato %s; scrivo invece in %s."
 
-#: builtin/merge.c:1296
-msgid "Squash commit into empty head not supported yet"
+#: merge-recursive.c:1482
+#, c-format
+msgid ""
+"CONFLICT (%s/delete): %s deleted in %s and %s in %s. Version %s of %s left "
+"in tree."
 msgstr ""
+"CONFLITTO (%s/eliminazione): %s eliminato in %s e %s in %s. Versione %s di "
+"%s lasciata nell'albero."
 
-#: builtin/merge.c:1298
-msgid "Non-fast-forward commit does not make sense into an empty head"
+#: merge-recursive.c:1487
+#, c-format
+msgid ""
+"CONFLICT (%s/delete): %s deleted in %s and %s to %s in %s. Version %s of %s "
+"left in tree."
 msgstr ""
+"CONFLITTO (%s/eliminazione): %s eliminato in %s e %s come %s in %s. Versione "
+"%s di %s lasciata nell'albero."
 
-#: builtin/merge.c:1413
+#: merge-recursive.c:1494
 #, c-format
-msgid "Updating %s..%s\n"
-msgstr "Aggiornamento di %s..%s\n"
+msgid ""
+"CONFLICT (%s/delete): %s deleted in %s and %s in %s. Version %s of %s left "
+"in tree at %s."
+msgstr ""
+"CONFLITTO (%s/eliminazione): %s eliminato in %s e %s in %s. Versione %s di "
+"%s lasciata nell'albero in %s."
 
-#: builtin/merge.c:1451
+#: merge-recursive.c:1499
 #, c-format
-msgid "Trying really trivial in-index merge...\n"
+msgid ""
+"CONFLICT (%s/delete): %s deleted in %s and %s to %s in %s. Version %s of %s "
+"left in tree at %s."
 msgstr ""
+"CONFLITTO (%s/eliminazione): %s eliminato in %s e %s come %s in %s. Versione "
+"%s di %s lasciata nell'albero in %s."
 
-#: builtin/merge.c:1458
-#, c-format
-msgid "Nope.\n"
-msgstr "No.\n"
+#: merge-recursive.c:1534
+msgid "rename"
+msgstr "ridenominazione"
 
-#: builtin/merge.c:1490
-msgid "Not possible to fast-forward, aborting."
-msgstr "Fast-forward non possibile, stop."
+#: merge-recursive.c:1534
+msgid "renamed"
+msgstr "rinominato"
 
-#: builtin/merge.c:1513 builtin/merge.c:1592
+#: merge-recursive.c:1614 merge-recursive.c:2530 merge-recursive.c:3175
 #, c-format
-msgid "Rewinding the tree to pristine...\n"
+msgid "Refusing to lose dirty file at %s"
+msgstr "Mi rifiuto di perdere un file sporco in %s"
+
+#: merge-recursive.c:1624
+#, c-format
+msgid "Refusing to lose untracked file at %s, even though it's in the way."
 msgstr ""
+"Mi rifiuto di perdere un file non tracciato in %s, benché sia d'ostacolo."
 
-#: builtin/merge.c:1517
+#: merge-recursive.c:1682
 #, c-format
-msgid "Trying merge strategy %s...\n"
-msgstr "Tentativo con la strategia di merge %s...\n"
+msgid "CONFLICT (rename/add): Rename %s->%s in %s.  Added %s in %s"
+msgstr ""
+"CONFLITTO (ridenominazione/aggiunta): elemento ridenominato %s->%s in %s. %s "
+"aggiunto in %s"
 
-#: builtin/merge.c:1583
+#: merge-recursive.c:1713
 #, c-format
-msgid "No merge strategy handled the merge.\n"
-msgstr "Nessuna strategia di merge ha gestito il merge.\n"
+msgid "%s is a directory in %s adding as %s instead"
+msgstr "%s è una directory in %s; la aggiungo come %s"
 
-#: builtin/merge.c:1585
+#: merge-recursive.c:1718
 #, c-format
-msgid "Merge with strategy %s failed.\n"
-msgstr "Merge con la strategia %s fallito.\n"
+msgid "Refusing to lose untracked file at %s; adding as %s instead"
+msgstr "Mi rifiuto di perdere un file non tracciato in %s; lo aggiungo come %s"
 
-#: builtin/merge.c:1594
+#: merge-recursive.c:1737
 #, c-format
-msgid "Using the %s to prepare resolving by hand.\n"
+msgid ""
+"CONFLICT (rename/rename): Rename \"%s\"->\"%s\" in branch \"%s\" rename \"%s"
+"\"->\"%s\" in \"%s\"%s"
 msgstr ""
+"CONFLITTO (ridenominazione/ridenominazione): file ridenominato \"%s\"->\"%s"
+"\" nel branch \"%s\", ridenominato \"%s\"->\"%s\" in \"%s\"%s"
 
-#: builtin/merge.c:1606
+#: merge-recursive.c:1742
+msgid " (left unresolved)"
+msgstr " (lasciato irrisolto)"
+
+#: merge-recursive.c:1851
 #, c-format
-msgid "Automatic merge went well; stopped before committing as requested\n"
+msgid "CONFLICT (rename/rename): Rename %s->%s in %s. Rename %s->%s in %s"
 msgstr ""
-"Il merge automatico è andato a buon fine; fermato prima del commit come "
-"richiesto\n"
+"CONFLITTO (ridenominazione/ridenominazione): file ridenominato %s->%s in %s. "
+"Ridenominato %s->%s in %s"
 
-#: builtin/mv.c:108
+#: merge-recursive.c:2114
 #, c-format
-msgid "Checking rename of '%s' to '%s'\n"
+msgid ""
+"CONFLICT (directory rename split): Unclear where to place %s because "
+"directory %s was renamed to multiple other directories, with no destination "
+"getting a majority of the files."
 msgstr ""
+"CONFLITTO (split ridenominazione directory): non è chiaro dove collocare %s "
+"perché la directory %s è stata ridenominata in più directory diverse e "
+"nessuna directory di destinazione contiene la maggior parte dei file."
 
-#: builtin/mv.c:112
-msgid "bad source"
+#: merge-recursive.c:2146
+#, c-format
+msgid ""
+"CONFLICT (implicit dir rename): Existing file/dir at %s in the way of "
+"implicit directory rename(s) putting the following path(s) there: %s."
 msgstr ""
+"CONFLITTO (ridenominazione directory implicita): il file/directory esistente "
+"%s è d'ostacolo alle seguenti ridenominazioni directory che spostano in tale "
+"posizione i seguenti percorsi: %s."
 
-#: builtin/mv.c:115
-msgid "can not move directory into itself"
-msgstr "non è possibile spostare la directory in sé stessa"
+#: merge-recursive.c:2156
+#, c-format
+msgid ""
+"CONFLICT (implicit dir rename): Cannot map more than one path to %s; "
+"implicit directory renames tried to put these paths there: %s"
+msgstr ""
+"CONFLITTO (ridenominazione directory implicita): impossibile mappare più di "
+"un percorso in %s; delle ridenominazioni directory implicite hanno tentato "
+"di spostare in tale posizione i seguenti percorsi: %s"
 
-#: builtin/mv.c:118
-msgid "cannot move directory over file"
-msgstr "non è possibile spostare la directory su un file"
+#: merge-recursive.c:2248
+#, c-format
+msgid ""
+"CONFLICT (rename/rename): Rename directory %s->%s in %s. Rename directory %s-"
+">%s in %s"
+msgstr ""
+"CONFLITTO (ridenominazione/ridenominazione): directory ridenominata %s->%s "
+"in %s. Directory ridenominata %s->%s in %s"
 
-#: builtin/mv.c:128
+#: merge-recursive.c:2493
 #, c-format
-msgid "Huh? %.*s is in index?"
-msgstr "Eh? %.*s si trova in index?"
+msgid ""
+"WARNING: Avoiding applying %s -> %s rename to %s, because %s itself was "
+"renamed."
+msgstr ""
+"ATTENZIONE: evito di applicare la ridenominazione %s -> %s a %s perché %s "
+"stesso è stato ridenominato."
 
-#: builtin/mv.c:140
-msgid "source directory is empty"
-msgstr "la directory sorgente è vuota"
+#: merge-recursive.c:3019
+#, c-format
+msgid "cannot read object %s"
+msgstr "impossibile leggere l'oggetto %s"
 
-#: builtin/mv.c:171
-msgid "not under version control"
-msgstr "non è sotto controllo di versione"
+#: merge-recursive.c:3022
+#, c-format
+msgid "object %s is not a blob"
+msgstr "l'oggetto %s non è un blob"
 
-#: builtin/mv.c:173
-msgid "destination exists"
-msgstr "la destinazione esiste"
+#: merge-recursive.c:3086
+msgid "modify"
+msgstr "modifica"
 
-#: builtin/mv.c:181
-#, c-format
-msgid "overwriting '%s'"
-msgstr "sovrascrittura di %s in corso"
+#: merge-recursive.c:3086
+msgid "modified"
+msgstr "modificato"
 
-#: builtin/mv.c:184
-msgid "Cannot overwrite"
-msgstr "Impossibile sovrascrivere"
+#: merge-recursive.c:3098
+msgid "content"
+msgstr "contenuto"
 
-#: builtin/mv.c:187
-msgid "multiple sources for the same target"
-msgstr "fonti multiple per la stessa destinazione"
+#: merge-recursive.c:3102
+msgid "add/add"
+msgstr "aggiunta/aggiunta"
 
-#: builtin/mv.c:202
+#: merge-recursive.c:3125
 #, c-format
-msgid "%s, source=%s, destination=%s"
-msgstr "%s, sorgente=%s, destinazione=%s"
+msgid "Skipped %s (merged same as existing)"
+msgstr "Omesso %s (elemento sottoposto a merge uguale a quello esistente)"
 
-#: builtin/mv.c:212
+#: merge-recursive.c:3147 git-submodule.sh:993
+msgid "submodule"
+msgstr "sottomodulo"
+
+#: merge-recursive.c:3148
 #, c-format
-msgid "Renaming %s to %s\n"
-msgstr "Rinominazione di %s in %s in corso\n"
+msgid "CONFLICT (%s): Merge conflict in %s"
+msgstr "CONFLITTO (%s): conflitto di merge in %s"
 
-#: builtin/mv.c:215 builtin/remote.c:731
+#: merge-recursive.c:3178
 #, c-format
-msgid "renaming '%s' failed"
-msgstr "rinomina di '%s' non riuscita"
+msgid "Adding as %s instead"
+msgstr "Lo aggiungo come %s"
 
-#: builtin/notes.c:139
+#: merge-recursive.c:3261
 #, c-format
-msgid "unable to start 'show' for object '%s'"
-msgstr "impossibile avviare 'show' per l'oggetto '%s'"
+msgid ""
+"Path updated: %s added in %s inside a directory that was renamed in %s; "
+"moving it to %s."
+msgstr ""
+"Percorso aggiornato: %s aggiunto in %s in una directory ridenominata in %s; "
+"lo sposto in %s."
 
-#: builtin/notes.c:145
-msgid "can't fdopen 'show' output fd"
+#: merge-recursive.c:3264
+#, c-format
+msgid ""
+"CONFLICT (file location): %s added in %s inside a directory that was renamed "
+"in %s, suggesting it should perhaps be moved to %s."
 msgstr ""
+"CONFLITTO (posizione file): %s aggiunto in %s in una directory ridenominata "
+"in %s, il che suggerisce che forse dovrebbe essere spostato in %s."
 
-#: builtin/notes.c:155
+#: merge-recursive.c:3268
 #, c-format
-msgid "failed to close pipe to 'show' for object '%s'"
+msgid ""
+"Path updated: %s renamed to %s in %s, inside a directory that was renamed in "
+"%s; moving it to %s."
 msgstr ""
+"Percorso aggiornato: %s ridenominato in %s in %s in una directory "
+"ridenominata in %s; lo sposto in %s."
 
-#: builtin/notes.c:158
+#: merge-recursive.c:3271
 #, c-format
-msgid "failed to finish 'show' for object '%s'"
+msgid ""
+"CONFLICT (file location): %s renamed to %s in %s, inside a directory that "
+"was renamed in %s, suggesting it should perhaps be moved to %s."
 msgstr ""
+"CONFLITTO (posizione file): %s ridenominato in %s in %s in una directory "
+"ridenominata in %s, il che suggerisce che forse dovrebbe essere spostato in "
+"%s."
 
-#: builtin/notes.c:175 builtin/tag.c:347
+#: merge-recursive.c:3385
 #, c-format
-msgid "could not create file '%s'"
-msgstr "non è stato possibile creare il file '%s'"
+msgid "Removing %s"
+msgstr "Rimozione di %s"
+
+#: merge-recursive.c:3408
+msgid "file/directory"
+msgstr "file/directory"
 
-#: builtin/notes.c:189
-msgid "Please supply the note contents using either -m or -F option"
-msgstr "Per favore specifica il contenuto delle note usando le opzioni -m o -F"
+#: merge-recursive.c:3413
+msgid "directory/file"
+msgstr "directory/file"
 
-#: builtin/notes.c:210 builtin/notes.c:973
+#: merge-recursive.c:3420
 #, c-format
-msgid "Removing note for object %s\n"
-msgstr "Rimozione della nota per l'oggetto %s\n"
+msgid "CONFLICT (%s): There is a directory with name %s in %s. Adding %s as %s"
+msgstr ""
+"CONFLITTO (%s): una directory denominata %s esiste già in %s. Aggiungo %s "
+"come %s"
 
-#: builtin/notes.c:215
-msgid "unable to write note object"
-msgstr "impossibile scrivere l'oggetto nota"
+#: merge-recursive.c:3429
+#, c-format
+msgid "Adding %s"
+msgstr "Aggiunta %s"
 
-#: builtin/notes.c:217
+#: merge-recursive.c:3438
 #, c-format
-msgid "The note contents has been left in %s"
-msgstr "Il contenuto della nota è stato lasciato in %s"
+msgid "CONFLICT (add/add): Merge conflict in %s"
+msgstr "CONFLITTO (aggiungi/aggiungi): conflitto di merge in %s"
 
-#: builtin/notes.c:251 builtin/tag.c:542
+#: merge-recursive.c:3482
+msgid "Already up to date!"
+msgstr "Già aggiornato!"
+
+#: merge-recursive.c:3491
 #, c-format
-msgid "cannot read '%s'"
-msgstr "impossibile leggere '%s'"
+msgid "merging of trees %s and %s failed"
+msgstr "merge degli alberi %s e %s non riuscito"
+
+#: merge-recursive.c:3595
+msgid "Merging:"
+msgstr "Merge in corso:"
 
-#: builtin/notes.c:253 builtin/tag.c:545
+#: merge-recursive.c:3608
 #, c-format
-msgid "could not open or read '%s'"
-msgstr "non è stato possibile aprire o leggere '%s'"
+msgid "found %u common ancestor:"
+msgid_plural "found %u common ancestors:"
+msgstr[0] "trovato %u antenato comune:"
+msgstr[1] "trovati %u antenati comuni:"
 
-#: builtin/notes.c:272 builtin/notes.c:445 builtin/notes.c:447
-#: builtin/notes.c:507 builtin/notes.c:561 builtin/notes.c:644
-#: builtin/notes.c:649 builtin/notes.c:724 builtin/notes.c:766
-#: builtin/notes.c:968 builtin/reset.c:293 builtin/tag.c:558
+#: merge-recursive.c:3658
+msgid "merge returned no commit"
+msgstr "il merge non ha restituito alcun commit"
+
+#: merge-recursive.c:3717
 #, c-format
-msgid "Failed to resolve '%s' as a valid ref."
+msgid ""
+"Your local changes to the following files would be overwritten by merge:\n"
+"  %s"
 msgstr ""
+"Le tue modifiche locali ai seguenti file sarebbero sovrascritte dal merge:\n"
+"  %s"
 
-#: builtin/notes.c:275
+#: merge-recursive.c:3814
 #, c-format
-msgid "Failed to read object '%s'."
-msgstr "Lettura dell'oggetto '%s' non riuscita."
+msgid "Could not parse object '%s'"
+msgstr "Impossibile analizzare l'oggetto '%s'"
 
-#: builtin/notes.c:299
-msgid "Cannot commit uninitialized/unreferenced notes tree"
-msgstr ""
+#: merge-recursive.c:3832 builtin/merge.c:694 builtin/merge.c:874
+msgid "Unable to write index."
+msgstr "Impossibile scrivere l'indice."
 
-#: builtin/notes.c:340
+#: midx.c:68
 #, c-format
-msgid "Bad notes.rewriteMode value: '%s'"
-msgstr "Valore di notes.rewriteMode errato: '%s'"
+msgid "multi-pack-index file %s is too small"
+msgstr "il file multi-pack-index %s è troppo piccolo"
 
-#: builtin/notes.c:350
+#: midx.c:84
 #, c-format
-msgid "Refusing to rewrite notes in %s (outside of refs/notes/)"
-msgstr "Impossibile riscrivere le note in %s (al di fuori di refs/notes/)"
+msgid "multi-pack-index signature 0x%08x does not match signature 0x%08x"
+msgstr "la firma del multi-pack-index 0x%08x non corrisponde alla firma 0x%08x"
 
-#. TRANSLATORS: The first %s is the name of the
-#. environment variable, the second %s is its value
-#: builtin/notes.c:377
+#: midx.c:89
 #, c-format
-msgid "Bad %s value: '%s'"
-msgstr "Valore di %s errato: '%s'"
+msgid "multi-pack-index version %d not recognized"
+msgstr "versione %d multi-pack-index non riconosciuta"
 
-#: builtin/notes.c:441
+#: midx.c:94
 #, c-format
-msgid "Malformed input line: '%s'."
-msgstr "Riga di input malformata: '%s'."
+msgid "hash version %u does not match"
+msgstr "la versione dell'hash %u non corrisponde"
 
-#: builtin/notes.c:456
-#, c-format
-msgid "Failed to copy notes from '%s' to '%s'"
-msgstr "Copia delle note da '%s' a '%s' non riuscita"
+#: midx.c:108
+msgid "invalid chunk offset (too large)"
+msgstr "offset blocco non valido (troppo grande)"
 
-#: builtin/notes.c:500 builtin/notes.c:554 builtin/notes.c:627
-#: builtin/notes.c:639 builtin/notes.c:712 builtin/notes.c:759
-#: builtin/notes.c:1033
-msgid "too many parameters"
-msgstr "troppi parametri"
+#: midx.c:132
+msgid "terminating multi-pack-index chunk id appears earlier than expected"
+msgstr "l'ID blocco finale multi-pack-index compare prima di quanto previsto"
+
+#: midx.c:145
+msgid "multi-pack-index missing required pack-name chunk"
+msgstr "dal multi-pack-index manca il blocco richiesto pack-name"
+
+#: midx.c:147
+msgid "multi-pack-index missing required OID fanout chunk"
+msgstr "dal multi-pack-index manca il blocco richiesto fanout OID"
+
+#: midx.c:149
+msgid "multi-pack-index missing required OID lookup chunk"
+msgstr "dal multi-pack-index manca il blocco richiesto lookup OID"
+
+#: midx.c:151
+msgid "multi-pack-index missing required object offsets chunk"
+msgstr "dal multi-pack-index manca il blocco richiesto offset oggetti"
 
-#: builtin/notes.c:513 builtin/notes.c:772
+#: midx.c:165
 #, c-format
-msgid "No note found for object %s."
-msgstr "Nessuna nota trovata per l'oggetto %s."
+msgid "multi-pack-index pack names out of order: '%s' before '%s'"
+msgstr "nomi pack multi-pack-index in disordine: '%s' appare prima di '%s'"
 
-#: builtin/notes.c:580
+#: midx.c:210
 #, c-format
-msgid ""
-"Cannot add notes. Found existing notes for object %s. Use '-f' to overwrite "
-"existing notes"
+msgid "bad pack-int-id: %u (%u total packs)"
+msgstr "pack-int-id non valido: %u (%u pack totali)"
+
+#: midx.c:260
+msgid "multi-pack-index stores a 64-bit offset, but off_t is too small"
 msgstr ""
+"nel multi-pack-index è salvato un offset a 64 bit, ma off_t è troppo piccolo"
 
-#: builtin/notes.c:585 builtin/notes.c:662
+#: midx.c:288
+msgid "error preparing packfile from multi-pack-index"
+msgstr "errore durante la preparazione del packfile dal multi-pack-index"
+
+#: midx.c:472
 #, c-format
-msgid "Overwriting existing notes for object %s\n"
-msgstr "Sovrascrittura delle note esistenti per l'oggetto %s\n"
+msgid "failed to add packfile '%s'"
+msgstr "aggiunta del packfile '%s' non riuscita"
 
-#: builtin/notes.c:635
-msgid "too few parameters"
-msgstr "troppi pochi parametri"
+#: midx.c:478
+#, c-format
+msgid "failed to open pack-index '%s'"
+msgstr "apertura del pack-index '%s' non riuscita"
 
-#: builtin/notes.c:656
+#: midx.c:538
 #, c-format
-msgid ""
-"Cannot copy notes. Found existing notes for object %s. Use '-f' to overwrite "
-"existing notes"
-msgstr ""
-"Impossibile copiare le note. Trovate note esistenti per l'oggetto %s. Usa "
-"'-f' per sovrascrivere le note esistenti"
+msgid "failed to locate object %d in packfile"
+msgstr "ricerca dell'oggetto %d nel packfile non riuscita"
+
+#: midx.c:842
+msgid "Adding packfiles to multi-pack-index"
+msgstr "Aggiunta dei file pack al multi-pack-index in corso"
+
+#: midx.c:875
+#, c-format
+msgid "did not see pack-file %s to drop"
+msgstr "non ho visto il file pack %s da scartare"
+
+#: midx.c:973
+msgid "Writing chunks to multi-pack-index"
+msgstr "Scrittura dei chunk nel multi-pack-index in corso"
 
-#: builtin/notes.c:668
+#: midx.c:1052
 #, c-format
-msgid "Missing notes on source object %s. Cannot copy."
-msgstr "Note mancanti per l'oggetto sorgente %s. Impossibile copiare."
+msgid "failed to clear multi-pack-index at %s"
+msgstr "pulizia del multi-pack-index %s non riuscita"
 
-#: builtin/notes.c:717
+#: midx.c:1108
+msgid "Looking for referenced packfiles"
+msgstr "Ricerca di file pack referenziati in corso"
+
+#: midx.c:1123
 #, c-format
 msgid ""
-"The -m/-F/-c/-C options have been deprecated for the 'edit' subcommand.\n"
-"Please use 'git notes add -f -m/-F/-c/-C' instead.\n"
+"oid fanout out of order: fanout[%d] = %<PRIx32> > %<PRIx32> = fanout[%d]"
 msgstr ""
-"Le opzioni -m/-F/-c/-C per il sottocomando 'edit' sono deprecate.\n"
-"Per favore usa 'git notes add -f -m/-F/-c/-C' invece.\n"
+"fanout oid in disordine: fanout[%d] = %<PRIx32> > %<PRIx32> = fanout[%d]"
 
-#: builtin/notes.c:971
-#, c-format
-msgid "Object %s has no note\n"
-msgstr "L'oggetto %s non ha note.\n"
+#: midx.c:1128
+msgid "Verifying OID order in multi-pack-index"
+msgstr "Verifica ordine OID nel multi-pack-index in corso"
 
-#: builtin/notes.c:1103 builtin/remote.c:1598
+#: midx.c:1137
 #, c-format
-msgid "Unknown subcommand: %s"
-msgstr "Sottocomando sconosciuto: %s"
+msgid "oid lookup out of order: oid[%d] = %s >= %s = oid[%d]"
+msgstr "lookup oid in disordine: oid[%d] = %s >= %s = oid[%d]"
+
+#: midx.c:1157
+msgid "Sorting objects by packfile"
+msgstr "Ordinamento degli oggetti nel packfile in corso"
 
-#: builtin/pack-objects.c:2337
+#: midx.c:1164
+msgid "Verifying object offsets"
+msgstr "Verifica offset oggetti in corso"
+
+#: midx.c:1180
 #, c-format
-msgid "unsupported index version %s"
-msgstr "versione %s di index non supportata"
+msgid "failed to load pack entry for oid[%d] = %s"
+msgstr "caricamento voce pack per oid[%d] = %s non riuscito"
 
-#: builtin/pack-objects.c:2341
+#: midx.c:1186
 #, c-format
-msgid "bad index version '%s'"
-msgstr "versione '%s' di index errata"
+msgid "failed to load pack-index for packfile %s"
+msgstr "caricamento pack-index per il packfile %s non riuscito"
 
-#: builtin/pack-objects.c:2364
+#: midx.c:1195
 #, c-format
-msgid "option %s does not accept negative form"
-msgstr "l'opzione %s non accetta forme negative"
+msgid "incorrect object offset for oid[%d] = %s: %<PRIx64> != %<PRIx64>"
+msgstr "offset oggetto non corretto per oid[%d] = %s: %<PRIx64> != %<PRIx64>"
+
+#: midx.c:1220
+msgid "Counting referenced objects"
+msgstr "Conteggio degli oggetti referenziati in corso"
+
+#: midx.c:1230
+msgid "Finding and deleting unreferenced packfiles"
+msgstr "Ricerca ed eliminazione dei file pack non referenziati in corso"
+
+#: midx.c:1388
+msgid "could not start pack-objects"
+msgstr "impossibile avviare pack-objects"
 
-#: builtin/pack-objects.c:2368
+#: midx.c:1407
+msgid "could not finish pack-objects"
+msgstr "impossibile finire pack-objects"
+
+#: name-hash.c:537
 #, c-format
-msgid "unable to parse value '%s' for option %s"
-msgstr "impossibile analizzare il valore '%s' per l'opzione %s"
+msgid "unable to create lazy_dir thread: %s"
+msgstr "impossibile creare il thread lazy_dir: %s"
 
-#: builtin/push.c:45
-msgid "tag shorthand without <tag>"
-msgstr ""
+#: name-hash.c:559
+#, c-format
+msgid "unable to create lazy_name thread: %s"
+msgstr "impossibile creare il thread lazy_name: %s"
 
-#: builtin/push.c:64
-msgid "--delete only accepts plain target ref names"
-msgstr "--delete accetta solo nomi dei ref di destinazione in chiaro"
+#: name-hash.c:565
+#, c-format
+msgid "unable to join lazy_name thread: %s"
+msgstr "impossibile bloccare il thread lazy_name: %s"
 
-#: builtin/push.c:99
+#: notes-merge.c:277
+#, c-format
 msgid ""
-"\n"
-"To choose either option permanently, see push.default in 'git help config'."
+"You have not concluded your previous notes merge (%s exists).\n"
+"Please, use 'git notes merge --commit' or 'git notes merge --abort' to "
+"commit/abort the previous merge before you start a new notes merge."
 msgstr ""
+"Non hai concluso il merge delle note precedente (%s esiste).\n"
+"Usa 'git notes merge --commit' o 'git notes merge --abort' per eseguire il "
+"commit/interrompere il merge precedente prima di iniziare un nuovo merge "
+"delle note."
 
-#: builtin/push.c:102
+#: notes-merge.c:284
 #, c-format
-msgid ""
-"The upstream branch of your current branch does not match\n"
-"the name of your current branch.  To push to the upstream branch\n"
-"on the remote, use\n"
-"\n"
-"    git push %s HEAD:%s\n"
-"\n"
-"To push to the branch of the same name on the remote, use\n"
-"\n"
-"    git push %s %s\n"
-"%s"
+msgid "You have not concluded your notes merge (%s exists)."
+msgstr "Non hai concluso il merge delle note (%s esiste)."
+
+#: notes-utils.c:46
+msgid "Cannot commit uninitialized/unreferenced notes tree"
 msgstr ""
+"Impossibile eseguire il commit di un albero delle note non inizializzato/non "
+"referenziato"
 
-#: builtin/push.c:121
+#: notes-utils.c:105
 #, c-format
-msgid ""
-"You are not currently on a branch.\n"
-"To push the history leading to the current (detached HEAD)\n"
-"state now, use\n"
-"\n"
-"    git push %s HEAD:<name-of-remote-branch>\n"
-msgstr ""
+msgid "Bad notes.rewriteMode value: '%s'"
+msgstr "Valore di notes.rewriteMode errato: '%s'"
 
-#: builtin/push.c:128
+#: notes-utils.c:115
 #, c-format
-msgid ""
-"The current branch %s has no upstream branch.\n"
-"To push the current branch and set the remote as upstream, use\n"
-"\n"
-"    git push --set-upstream %s %s\n"
-msgstr ""
-"Il branch corrente %s non ha alcun branch upstream.\n"
-"Per eseguire il push del branch corrente ed impostare remote come upstream, usa\n"
-"\n"
-"    git push --set-upstream %s %s\n"
+msgid "Refusing to rewrite notes in %s (outside of refs/notes/)"
+msgstr "Mi rifiuto di riscrivere le note in %s (al di fuori di refs/notes/)"
 
-#: builtin/push.c:136
+#. TRANSLATORS: The first %s is the name of
+#. the environment variable, the second %s is
+#. its value.
+#.
+#: notes-utils.c:145
 #, c-format
-msgid "The current branch %s has multiple upstream branches, refusing to push."
-msgstr "Il branch corrente %s ha branch multipli in upstream; push non eseguito."
+msgid "Bad %s value: '%s'"
+msgstr "Valore di %s errato: '%s'"
 
-#: builtin/push.c:139
+#: object.c:53
 #, c-format
-msgid ""
-"You are pushing to remote '%s', which is not the upstream of\n"
-"your current branch '%s', without telling me what to push\n"
-"to update which remote branch."
-msgstr ""
+msgid "invalid object type \"%s\""
+msgstr "tipo oggetto \"%s\" non valido"
 
-#: builtin/push.c:174
-msgid ""
-"You didn't specify any refspecs to push, and push.default is \"nothing\"."
-msgstr ""
-"Non è stato specificato alcun refspec per il push, e push.default è \"nothing\"."
+#: object.c:173
+#, c-format
+msgid "object %s is a %s, not a %s"
+msgstr "l'oggetto %s è un %s, non un %s"
 
-#: builtin/push.c:181
-msgid ""
-"Updates were rejected because the tip of your current branch is behind\n"
-"its remote counterpart. Merge the remote changes (e.g. 'git pull')\n"
-"before pushing again.\n"
-"See the 'Note about fast-forwards' in 'git push --help' for details."
-msgstr ""
+#: object.c:233
+#, c-format
+msgid "object %s has unknown type id %d"
+msgstr "l'oggetto %s ha l'ID tipo sconosciuto %d"
 
-#: builtin/push.c:187
-msgid ""
-"Updates were rejected because a pushed branch tip is behind its remote\n"
-"counterpart. If you did not intend to push that branch, you may want to\n"
-"specify branches to push or set the 'push.default' configuration\n"
-"variable to 'current' or 'upstream' to push only the current branch."
-msgstr ""
+#: object.c:246
+#, c-format
+msgid "unable to parse object: %s"
+msgstr "impossibile analizzare l'oggetto: %s"
 
-#: builtin/push.c:193
-msgid ""
-"Updates were rejected because a pushed branch tip is behind its remote\n"
-"counterpart. Check out this branch and merge the remote changes\n"
-"(e.g. 'git pull') before pushing again.\n"
-"See the 'Note about fast-forwards' in 'git push --help' for details."
-msgstr ""
+#: object.c:266 object.c:277
+#, c-format
+msgid "hash mismatch %s"
+msgstr "hash non corrispondente: %s"
 
-#: builtin/push.c:233
+#: packfile.c:641
+msgid "offset before end of packfile (broken .idx?)"
+msgstr "offset collocato prima della fine del packfile (.idx corrotto?)"
+
+#: packfile.c:1888
 #, c-format
-msgid "Pushing to %s\n"
+msgid "offset before start of pack index for %s (corrupt index?)"
 msgstr ""
+"offset collocato prima dell'inizio dell'indice pack per %s (indice corrotto?)"
 
-#: builtin/push.c:237
+#: packfile.c:1892
 #, c-format
-msgid "failed to push some refs to '%s'"
+msgid "offset beyond end of pack index for %s (truncated index?)"
 msgstr ""
+"offset collocato dopo la fine dell'indice pack per %s (indice troncato?)"
 
-#: builtin/push.c:269
+#: parse-options.c:38
 #, c-format
-msgid "bad repository '%s'"
-msgstr "repository '%s' errato"
+msgid "%s requires a value"
+msgstr "%s richiede un valore"
 
-#: builtin/push.c:270
-msgid ""
-"No configured push destination.\n"
-"Either specify the URL from the command-line or configure a remote "
-"repository using\n"
-"\n"
-"    git remote add <name> <url>\n"
-"\n"
-"and then push using the remote name\n"
-"\n"
-"    git push <name>\n"
-msgstr ""
-"Nessuna destinazione per il push configurata.\n"
-"Specifica un URL dalla riga di comando oppure configurare un repository "
-"remoto usando\n"
-"\n"
-"    git remote add <nome> <url>\n"
-"\n"
-"e poi eseguire il push usando il nome del remote\n"
-"\n"
-"    git push <nome>\n"
+#: parse-options.c:73
+#, c-format
+msgid "%s is incompatible with %s"
+msgstr "%s non è compatibile con %s"
 
-#: builtin/push.c:285
-msgid "--all and --tags are incompatible"
-msgstr "--all e --tags non sono compatibili"
+#: parse-options.c:78
+#, c-format
+msgid "%s : incompatible with something else"
+msgstr "%s non è compatibile con qualcos'altro"
 
-#: builtin/push.c:286
-msgid "--all can't be combined with refspecs"
-msgstr ""
+#: parse-options.c:92 parse-options.c:96 parse-options.c:319
+#, c-format
+msgid "%s takes no value"
+msgstr "%s non richiede un valore"
 
-#: builtin/push.c:291
-msgid "--mirror and --tags are incompatible"
-msgstr "--mirror e --tags non sono compatibili"
+#: parse-options.c:94
+#, c-format
+msgid "%s isn't available"
+msgstr "%s non è disponibile"
 
-#: builtin/push.c:292
-msgid "--mirror can't be combined with refspecs"
+#: parse-options.c:219
+#, c-format
+msgid "%s expects a non-negative integer value with an optional k/m/g suffix"
 msgstr ""
+"%s richiede un valore intero non negativo con un suffisso k/m/g facoltativo"
 
-#: builtin/push.c:297
-msgid "--all and --mirror are incompatible"
-msgstr "--all e --mirror non sono compatibili"
+#: parse-options.c:389
+#, c-format
+msgid "ambiguous option: %s (could be --%s%s or --%s%s)"
+msgstr "opzione ambigua: %s (potrebbe essere --%s%s o --%s%s)"
 
-#: builtin/push.c:385
-msgid "--delete is incompatible with --all, --mirror and --tags"
-msgstr "--delete non è compatibile con --all, --mirror e --tags"
+#: parse-options.c:423 parse-options.c:431
+#, c-format
+msgid "did you mean `--%s` (with two dashes ?)"
+msgstr "forse intendevi `--%s` (con due trattini)?"
 
-#: builtin/push.c:387
-msgid "--delete doesn't make sense without any refs"
-msgstr "--delete non ha senso senza alcun ref"
+#: parse-options.c:860
+#, c-format
+msgid "unknown option `%s'"
+msgstr "opzione sconosciuta `%s'"
 
-#: builtin/remote.c:98
+#: parse-options.c:862
 #, c-format
-msgid "Updating %s"
-msgstr "Aggiornamento di %s"
+msgid "unknown switch `%c'"
+msgstr "opzione `%c` sconosciuta"
 
-#: builtin/remote.c:130
-msgid ""
-"--mirror is dangerous and deprecated; please\n"
-"\t use --mirror=fetch or --mirror=push instead"
-msgstr ""
-"--mirror è pericoloso e deprecato; per favore\n"
-"\t usa invece --mirror-fetch o --mirror-push"
+#: parse-options.c:864
+#, c-format
+msgid "unknown non-ascii option in string: `%s'"
+msgstr "opzione non ASCII sconosciuta presente nella stringa: `%s'"
 
-#: builtin/remote.c:147
+#: parse-options.c:888
+msgid "..."
+msgstr "..."
+
+#: parse-options.c:907
 #, c-format
-msgid "unknown mirror argument: %s"
-msgstr "argomento di mirror sconosciuto: %s"
+msgid "usage: %s"
+msgstr "uso: %s"
 
-#: builtin/remote.c:185
-msgid "specifying a master branch makes no sense with --mirror"
-msgstr "specificare un branch master con --mirror non ha senso"
+#. TRANSLATORS: the colon here should align with the
+#. one in "usage: %s" translation.
+#.
+#: parse-options.c:913
+#, c-format
+msgid "   or: %s"
+msgstr "  oppure: %s"
 
-#: builtin/remote.c:187
-msgid "specifying branches to track makes sense only with fetch mirrors"
-msgstr ""
+#: parse-options.c:916
+#, c-format
+msgid "    %s"
+msgstr "    %s"
 
-#: builtin/remote.c:195 builtin/remote.c:646
+#: parse-options.c:955
+msgid "-NUM"
+msgstr "-NUM"
+
+#: parse-options.c:969
 #, c-format
-msgid "remote %s already exists."
-msgstr "il remoto %s esiste già."
+msgid "alias of --%s"
+msgstr "alias di --%s"
 
-#: builtin/remote.c:199 builtin/remote.c:650
+#: parse-options-cb.c:20 parse-options-cb.c:24
 #, c-format
-msgid "'%s' is not a valid remote name"
-msgstr "'%s' non è un nome di remoto valido"
+msgid "option `%s' expects a numerical value"
+msgstr "l'opzione `%s' richiede un valore numerico"
 
-#: builtin/remote.c:243
+#: parse-options-cb.c:41
 #, c-format
-msgid "Could not setup master '%s'"
-msgstr "Non è stato possibile configurare il master '%s'"
+msgid "malformed expiration date '%s'"
+msgstr "data scadenza '%s' malformata"
 
-#: builtin/remote.c:299
+#: parse-options-cb.c:54
 #, c-format
-msgid "more than one %s"
-msgstr "più di un %s"
+msgid "option `%s' expects \"always\", \"auto\", or \"never\""
+msgstr "l'opzione `%s' richiede \"always\", \"auto\" o \"never\""
 
-#: builtin/remote.c:339
+#: parse-options-cb.c:130 parse-options-cb.c:147
 #, c-format
-msgid "Could not get fetch map for refspec %s"
+msgid "malformed object name '%s'"
+msgstr "nome oggetto '%s' malformato"
+
+#: path.c:915
+#, c-format
+msgid "Could not make %s writable by group"
+msgstr "Impossibile rendere %s scrivibile dal gruppo"
+
+#: pathspec.c:130
+msgid "Escape character '\\' not allowed as last character in attr value"
 msgstr ""
+"Carattere di escape '\\' non consentito come ultimo carattere del valore "
+"attributo"
 
-#: builtin/remote.c:440 builtin/remote.c:448
-msgid "(matching)"
-msgstr "(corrispondente)"
+#: pathspec.c:148
+msgid "Only one 'attr:' specification is allowed."
+msgstr "È consentita solo una specifica 'attr:'."
 
-#: builtin/remote.c:452
-msgid "(delete)"
-msgstr "(elimina)"
+#: pathspec.c:151
+msgid "attr spec must not be empty"
+msgstr "la specifica attr non deve essere vuota"
 
-#: builtin/remote.c:595 builtin/remote.c:601 builtin/remote.c:607
+#: pathspec.c:194
 #, c-format
-msgid "Could not append '%s' to '%s'"
-msgstr "Non è stato possibile aggiungere '%s' a '%s'"
+msgid "invalid attribute name %s"
+msgstr "nome attributo %s non valido"
+
+#: pathspec.c:259
+msgid "global 'glob' and 'noglob' pathspec settings are incompatible"
+msgstr ""
+"le impostazioni globali specificatore percorso 'glob' e 'noglob' non sono "
+"compatibili"
+
+#: pathspec.c:266
+msgid ""
+"global 'literal' pathspec setting is incompatible with all other global "
+"pathspec settings"
+msgstr ""
+"l'impostazione globale specificatore percorso 'literal' è incompatibile con "
+"tutte le altre impostazioni globali specificatore percorso"
 
-#: builtin/remote.c:639 builtin/remote.c:792 builtin/remote.c:890
+#: pathspec.c:306
+msgid "invalid parameter for pathspec magic 'prefix'"
+msgstr "parametro per il magic specificatore percorso 'prefix' non valido"
+
+#: pathspec.c:327
 #, c-format
-msgid "No such remote: %s"
-msgstr "Remote non esistente: %s"
+msgid "Invalid pathspec magic '%.*s' in '%s'"
+msgstr "Magic specificatore percorso '%.*s' in '%s' non valido"
 
-#: builtin/remote.c:656
+#: pathspec.c:332
 #, c-format
-msgid "Could not rename config section '%s' to '%s'"
-msgstr "Non è stato possibile rinominare la sezione di configurazione da '%s' in '%s'"
+msgid "Missing ')' at the end of pathspec magic in '%s'"
+msgstr "')' mancante alla fine del magic specificatore percorso in '%s'"
 
-#: builtin/remote.c:662 builtin/remote.c:799
+#: pathspec.c:370
 #, c-format
-msgid "Could not remove config section '%s'"
-msgstr "Non è stato possibile rimuovere la sezione di configurazione '%s'"
+msgid "Unimplemented pathspec magic '%c' in '%s'"
+msgstr "Magic specificatore percorso '%c' in '%s' non implementato"
 
-#: builtin/remote.c:677
+#: pathspec.c:429
 #, c-format
-msgid ""
-"Not updating non-default fetch refspec\n"
-"\t%s\n"
-"\tPlease update the configuration manually if necessary."
-msgstr ""
+msgid "%s: 'literal' and 'glob' are incompatible"
+msgstr "%s: 'literal' e 'glob' non sono compatibili"
 
-#: builtin/remote.c:683
+#: pathspec.c:442
 #, c-format
-msgid "Could not append '%s'"
-msgstr ""
+msgid "%s: '%s' is outside repository"
+msgstr "%s: '%s' è al di fuori del repository"
 
-#: builtin/remote.c:694
+#: pathspec.c:516
 #, c-format
-msgid "Could not set '%s'"
-msgstr "Non è stato possibile impostare '%s'"
+msgid "'%s' (mnemonic: '%c')"
+msgstr "'%s' (opzione mnemonica: '%c')"
 
-#: builtin/remote.c:716
+#: pathspec.c:526
 #, c-format
-msgid "deleting '%s' failed"
-msgstr "eliminazione di '%s' non riuscita"
+msgid "%s: pathspec magic not supported by this command: %s"
+msgstr "%s: magic specificatore percorso non supportato da questo comando: %s"
 
-#: builtin/remote.c:750
+#: pathspec.c:593
 #, c-format
-msgid "creating '%s' failed"
-msgstr "creazione di '%s' non riuscita"
+msgid "pathspec '%s' is beyond a symbolic link"
+msgstr ""
+"lo specificatore percorso '%s' si trova oltre un collegamento simbolico"
 
-#: builtin/remote.c:764
+#: pathspec.c:638
 #, c-format
-msgid "Could not remove branch %s"
-msgstr "Non è stato possibile rimuovere il branch %s"
+msgid "line is badly quoted: %s"
+msgstr "la riga non è ben racchiusa tra virgolette: %s"
 
-#: builtin/remote.c:834
-msgid ""
-"Note: A branch outside the refs/remotes/ hierarchy was not removed;\n"
-"to delete it, use:"
-msgid_plural ""
-"Note: Some branches outside the refs/remotes/ hierarchy were not removed;\n"
-"to delete them, use:"
-msgstr[0] ""
-"Nota: un branch al di fuori della gerarchia refs/remotes/ non è stato "
-"eliminato;\n"
-"per eliminarlo, usare:"
-msgstr[1] ""
-"Nota: alcuni branch al di fuori della gerarchia refs/remotes/ non sono stati "
-"eliminati;\n"
-"per eliminarli, usare:"
+#: pkt-line.c:92
+msgid "unable to write flush packet"
+msgstr "impossibile scrivere il pacchetto flush"
 
-#: builtin/remote.c:943
-#, c-format
-msgid " new (next fetch will store in remotes/%s)"
-msgstr ""
+#: pkt-line.c:99
+msgid "unable to write delim packet"
+msgstr "impossibile scrivere il pacchetto delim"
 
-#: builtin/remote.c:946
-msgid " tracked"
+#: pkt-line.c:106
+msgid "flush packet write failed"
+msgstr "scrittura con flush pacchetto non riuscita"
+
+#: pkt-line.c:146 pkt-line.c:232
+msgid "protocol error: impossibly long line"
+msgstr "errore protocollo: riga impossibilmente lunga"
+
+#: pkt-line.c:162 pkt-line.c:164
+msgid "packet write with format failed"
+msgstr "scrittura pacchetto con formato non riuscita"
+
+#: pkt-line.c:196
+msgid "packet write failed - data exceeds max packet size"
 msgstr ""
+"scrittura pacchetto non riuscita - i dati sono più della dimensione massima "
+"pacchetto"
 
-#: builtin/remote.c:948
-msgid " stale (use 'git remote prune' to remove)"
-msgstr " vecchio (usare 'git remote prune' per rimuoverlo)"
+#: pkt-line.c:203 pkt-line.c:210
+msgid "packet write failed"
+msgstr "scrittura pacchetto non riuscita"
 
-#: builtin/remote.c:950
-msgid " ???"
-msgstr "???"
+#: pkt-line.c:295
+msgid "read error"
+msgstr "errore di lettura"
+
+#: pkt-line.c:303
+msgid "the remote end hung up unexpectedly"
+msgstr "l'interlocutore remoto ha chiuso inaspettatamente la connessione"
 
-#: builtin/remote.c:991
+#: pkt-line.c:331
 #, c-format
-msgid "invalid branch.%s.merge; cannot rebase onto > 1 branch"
-msgstr ""
-"branch.%s.merge non valido; impossibile eseguire il rebase su > 1 branch"
+msgid "protocol error: bad line length character: %.4s"
+msgstr "errore protocollo: carattere lunghezza riga non valido: %.4s"
 
-#: builtin/remote.c:998
+#: pkt-line.c:341 pkt-line.c:346
 #, c-format
-msgid "rebases onto remote %s"
-msgstr ""
+msgid "protocol error: bad line length %d"
+msgstr "errore protocollo: lunghezza riga non valida: %d"
 
-#: builtin/remote.c:1001
+#: pkt-line.c:362
 #, c-format
-msgid " merges with remote %s"
-msgstr " merge con il remote %s"
+msgid "remote error: %s"
+msgstr "errore remoto: %s"
 
-#: builtin/remote.c:1002
-msgid "    and with remote"
-msgstr "    e con il remote"
+#: preload-index.c:119
+msgid "Refreshing index"
+msgstr "Aggiornamento indice in corso"
 
-#: builtin/remote.c:1004
+#: preload-index.c:138
 #, c-format
-msgid "merges with remote %s"
-msgstr "merge con il remote %s"
+msgid "unable to create threaded lstat: %s"
+msgstr "impossibile creare lstat in versione threaded: %s"
 
-#: builtin/remote.c:1005
-msgid "   and with remote"
-msgstr ""
+#: pretty.c:981
+msgid "unable to parse --pretty format"
+msgstr "impossibile analizzare il formato --pretty"
 
-#: builtin/remote.c:1051
-msgid "create"
-msgstr "crea"
+#: promisor-remote.c:23
+msgid "Remote with no URL"
+msgstr "Remoto senza URL"
 
-#: builtin/remote.c:1054
-msgid "delete"
-msgstr "elimina"
+#: promisor-remote.c:58
+#, c-format
+msgid "promisor remote name cannot begin with '/': %s"
+msgstr "il nome del remoto promettente non può iniziare con '/': %s"
 
-#: builtin/remote.c:1058
-msgid "up to date"
-msgstr "aggiornato"
+#: range-diff.c:75
+msgid "could not start `log`"
+msgstr "impossibile avviare `log`"
 
-#: builtin/remote.c:1061
-msgid "fast-forwardable"
-msgstr ""
+#: range-diff.c:77
+msgid "could not read `log` output"
+msgstr "impossibile leggere l'output di `log`"
 
-#: builtin/remote.c:1064
-msgid "local out of date"
-msgstr "locale non aggiornato"
+#: range-diff.c:96 sequencer.c:5163
+#, c-format
+msgid "could not parse commit '%s'"
+msgstr "impossibile analizzare il commit '%s'"
 
-#: builtin/remote.c:1071
+#: range-diff.c:122
 #, c-format
-msgid "    %-*s forces to %-*s (%s)"
-msgstr ""
+msgid "could not parse git header '%.*s'"
+msgstr "impossibile analizzare l'header Git '%.*s'"
+
+#: range-diff.c:285
+msgid "failed to generate diff"
+msgstr "generazione del diff non riuscita"
 
-#: builtin/remote.c:1074
+#: range-diff.c:518 range-diff.c:520
 #, c-format
-msgid "    %-*s pushes to %-*s (%s)"
-msgstr ""
+msgid "could not parse log for '%s'"
+msgstr "impossibile analizzare il registro di '%s'"
 
-#: builtin/remote.c:1078
+#: read-cache.c:680
 #, c-format
-msgid "    %-*s forces to %s"
+msgid "will not add file alias '%s' ('%s' already exists in index)"
+msgstr "non aggiungerò l'alias file '%s' ('%s' esiste già nell'indice)"
+
+#: read-cache.c:696
+msgid "cannot create an empty blob in the object database"
+msgstr "impossibile creare un blob vuoto nel database oggetti"
+
+#: read-cache.c:718
+#, c-format
+msgid "%s: can only add regular files, symbolic links or git-directories"
 msgstr ""
+"%s: è possibile aggiungere solo file regolari, collegamenti simbolici o "
+"directory Git"
 
-#: builtin/remote.c:1081
+#: read-cache.c:723
 #, c-format
-msgid "    %-*s pushes to %s"
-msgstr "    %-*s esegue il push su %s"
+msgid "'%s' does not have a commit checked out"
+msgstr "'%s' non ha un commit di cui è stato eseguito il checkout"
 
-#: builtin/remote.c:1118
+#: read-cache.c:775
 #, c-format
-msgid "* remote %s"
-msgstr "* remote %s"
+msgid "unable to index file '%s'"
+msgstr "impossibile indicizzare il file '%s'"
 
-#: builtin/remote.c:1119
+#: read-cache.c:794
 #, c-format
-msgid "  Fetch URL: %s"
-msgstr ""
+msgid "unable to add '%s' to index"
+msgstr "impossibile aggiungere '%s' all'indice"
 
-#: builtin/remote.c:1120 builtin/remote.c:1285
-msgid "(no URL)"
-msgstr "(nessun URL)"
+#: read-cache.c:805
+#, c-format
+msgid "unable to stat '%s'"
+msgstr "impossibile eseguire stat su '%s'"
 
-#: builtin/remote.c:1129 builtin/remote.c:1131
+#: read-cache.c:1325
 #, c-format
-msgid "  Push  URL: %s"
-msgstr ""
+msgid "'%s' appears as both a file and as a directory"
+msgstr "'%s' compare sia come file sia come directory"
 
-#: builtin/remote.c:1133 builtin/remote.c:1135 builtin/remote.c:1137
+#: read-cache.c:1531
+msgid "Refresh index"
+msgstr "Aggiornamento indice"
+
+#: read-cache.c:1646
 #, c-format
-msgid "  HEAD branch: %s"
-msgstr "  branch HEAD: %s"
+msgid ""
+"index.version set, but the value is invalid.\n"
+"Using version %i"
+msgstr ""
+"index.version impostato, ma il valore non è valido.\n"
+"Uso la versione %i"
 
-#: builtin/remote.c:1139
+#: read-cache.c:1656
 #, c-format
 msgid ""
-"  HEAD branch (remote HEAD is ambiguous, may be one of the following):\n"
+"GIT_INDEX_VERSION set, but the value is invalid.\n"
+"Using version %i"
 msgstr ""
-"  branch HEAD (l'HEAD remoto è ambiguo, potrebbe essere uno dei seguenti):\n"
+"GIT_INDEX_VERSION impostato, ma il valore non è valido.\n"
+"Uso la versione %i"
 
-#: builtin/remote.c:1151
+#: read-cache.c:1712
 #, c-format
-msgid "  Remote branch:%s"
-msgid_plural "  Remote branches:%s"
-msgstr[0] "  Branch remoto:%s"
-msgstr[1] "  Branch remoti:%s"
+msgid "bad signature 0x%08x"
+msgstr "firma non valida: 0x%08x"
 
-#: builtin/remote.c:1154 builtin/remote.c:1181
-msgid " (status not queried)"
-msgstr ""
+#: read-cache.c:1715
+#, c-format
+msgid "bad index version %d"
+msgstr "versione indice non valida: %d"
 
-#: builtin/remote.c:1163
-msgid "  Local branch configured for 'git pull':"
-msgid_plural "  Local branches configured for 'git pull':"
-msgstr[0] "  Branch locale configurato per 'git pull':"
-msgstr[1] "  Branch locali configurati per 'git pull':"
+#: read-cache.c:1724
+msgid "bad index file sha1 signature"
+msgstr "firma SHA1 file indice non valida"
 
-#: builtin/remote.c:1171
-msgid "  Local refs will be mirrored by 'git push'"
-msgstr ""
+#: read-cache.c:1754
+#, c-format
+msgid "index uses %.4s extension, which we do not understand"
+msgstr "l'indice usa l'estensione %.4s che non comprendiamo"
 
-#: builtin/remote.c:1178
+#: read-cache.c:1756
 #, c-format
-msgid "  Local ref configured for 'git push'%s:"
-msgid_plural "  Local refs configured for 'git push'%s:"
-msgstr[0] "  Ref locale configurato per 'git push'%s:"
-msgstr[1] "  Ref locali configurati per 'git push'%s:"
+msgid "ignoring %.4s extension"
+msgstr "estensione %.4s ignorata"
 
-#: builtin/remote.c:1216
-msgid "Cannot determine remote HEAD"
-msgstr "Impossibile determinare l'HEAD remoto"
+#: read-cache.c:1793
+#, c-format
+msgid "unknown index entry format 0x%08x"
+msgstr "formato voce indice sconosciuto: 0x%08x"
 
-#: builtin/remote.c:1218
-msgid "Multiple remote HEAD branches. Please choose one explicitly with:"
-msgstr ""
+#: read-cache.c:1809
+#, c-format
+msgid "malformed name field in the index, near path '%s'"
+msgstr "campo nome malformato nell'indice, vicino al percorso '%s'"
 
-#: builtin/remote.c:1228
+#: read-cache.c:1866
+msgid "unordered stage entries in index"
+msgstr "voci stage non ordinate nell'indice"
+
+#: read-cache.c:1869
 #, c-format
-msgid "Could not delete %s"
-msgstr "Non è stato possibile eliminare %s"
+msgid "multiple stage entries for merged file '%s'"
+msgstr "voci stage multiple per il file sottoposto a merge '%s'"
 
-#: builtin/remote.c:1236
+#: read-cache.c:1872
 #, c-format
-msgid "Not a valid ref: %s"
-msgstr "Non è un ref valido: %s"
+msgid "unordered stage entries for '%s'"
+msgstr "voci stage non ordinate per '%s'"
+
+#: read-cache.c:1978 read-cache.c:2266 rerere.c:565 rerere.c:599 rerere.c:1111
+#: builtin/add.c:499 builtin/check-ignore.c:178 builtin/checkout.c:470
+#: builtin/checkout.c:654 builtin/clean.c:967 builtin/commit.c:367
+#: builtin/diff-tree.c:120 builtin/grep.c:499 builtin/mv.c:145
+#: builtin/reset.c:246 builtin/rm.c:271 builtin/submodule--helper.c:332
+msgid "index file corrupt"
+msgstr "file indice corrotto"
 
-#: builtin/remote.c:1238
+#: read-cache.c:2119
 #, c-format
-msgid "Could not setup %s"
-msgstr "Non è stato possibile configurare %s"
+msgid "unable to create load_cache_entries thread: %s"
+msgstr "impossibile creare il thread load_cache_entries: %s"
 
-#: builtin/remote.c:1274
+#: read-cache.c:2132
 #, c-format
-msgid " %s will become dangling!"
-msgstr ""
+msgid "unable to join load_cache_entries thread: %s"
+msgstr "impossibile bloccare il thread load_cache_entries: %s"
 
-#: builtin/remote.c:1275
+#: read-cache.c:2165
 #, c-format
-msgid " %s has become dangling!"
-msgstr ""
+msgid "%s: index file open failed"
+msgstr "%s: apertura del file indice non riuscita"
 
-#: builtin/remote.c:1281
+#: read-cache.c:2169
 #, c-format
-msgid "Pruning %s"
-msgstr ""
+msgid "%s: cannot stat the open index"
+msgstr "%s: impossibile eseguire stat sull'indice aperto"
 
-#: builtin/remote.c:1282
+#: read-cache.c:2173
 #, c-format
-msgid "URL: %s"
-msgstr "URL: %s"
+msgid "%s: index file smaller than expected"
+msgstr "%s: file indice più piccolo della dimensione attesa"
 
-#: builtin/remote.c:1295
+#: read-cache.c:2177
 #, c-format
-msgid " * [would prune] %s"
-msgstr ""
+msgid "%s: unable to map index file"
+msgstr "%s: impossibile mappare il file indice"
 
-#: builtin/remote.c:1298
+#: read-cache.c:2219
 #, c-format
-msgid " * [pruned] %s"
-msgstr ""
+msgid "unable to create load_index_extensions thread: %s"
+msgstr "impossibile creare il thread load_index_extensions: %s"
 
-#: builtin/remote.c:1387 builtin/remote.c:1461
+#: read-cache.c:2246
 #, c-format
-msgid "No such remote '%s'"
-msgstr "Remote '%s' non esistente"
+msgid "unable to join load_index_extensions thread: %s"
+msgstr "impossibile bloccare il thread load_index_extensions: %s"
 
-#: builtin/remote.c:1414
-msgid "no remote specified"
-msgstr "nessun remote specificato"
+#: read-cache.c:2278
+#, c-format
+msgid "could not freshen shared index '%s'"
+msgstr "impossibile aggiornare l'indice condiviso '%s'"
 
-#: builtin/remote.c:1447
-msgid "--add --delete doesn't make sense"
-msgstr "--add --delete non ha senso"
+#: read-cache.c:2325
+#, c-format
+msgid "broken index, expect %s in %s, got %s"
+msgstr "indice corrotto, atteso %s in %s, presente %s"
 
-#: builtin/remote.c:1487
+#: read-cache.c:3021 strbuf.c:1145 wrapper.c:622 builtin/merge.c:1119
 #, c-format
-msgid "Invalid old URL pattern: %s"
-msgstr ""
+msgid "could not close '%s'"
+msgstr "impossibile chiudere '%s'"
 
-#: builtin/remote.c:1495
+#: read-cache.c:3124 sequencer.c:2429 sequencer.c:4069
 #, c-format
-msgid "No such URL found: %s"
-msgstr "Nessuna URL trovata: %s"
+msgid "could not stat '%s'"
+msgstr "impossibile eseguire lo stat di '%s'"
 
-#: builtin/remote.c:1497
-msgid "Will not delete all non-push URLs"
-msgstr ""
+#: read-cache.c:3137
+#, c-format
+msgid "unable to open git dir: %s"
+msgstr "impossibile aprire la directory git: %s"
 
-#: builtin/reset.c:33
-msgid "mixed"
-msgstr ""
+#: read-cache.c:3149
+#, c-format
+msgid "unable to unlink: %s"
+msgstr "impossibile eseguire unlink: %s"
 
-#: builtin/reset.c:33
-msgid "soft"
-msgstr ""
+#: read-cache.c:3174
+#, c-format
+msgid "cannot fix permission bits on '%s'"
+msgstr "impossibile correggere i permessi di '%s'"
 
-#: builtin/reset.c:33
-msgid "hard"
+#: read-cache.c:3323
+#, c-format
+msgid "%s: cannot drop to stage #0"
+msgstr "%s: impossibile ripiegare sullo stadio 0"
+
+#: rebase-interactive.c:26
+#, c-format
+msgid ""
+"unrecognized setting %s for option rebase.missingCommitsCheck. Ignoring."
 msgstr ""
+"impostazione %s non riconosciuta per l'opzione rebase.missingCommitsCheck. "
+"La ignoro."
 
-#: builtin/reset.c:33
-msgid "merge"
+#: rebase-interactive.c:35
+msgid ""
+"\n"
+"Commands:\n"
+"p, pick <commit> = use commit\n"
+"r, reword <commit> = use commit, but edit the commit message\n"
+"e, edit <commit> = use commit, but stop for amending\n"
+"s, squash <commit> = use commit, but meld into previous commit\n"
+"f, fixup <commit> = like \"squash\", but discard this commit's log message\n"
+"x, exec <command> = run command (the rest of the line) using shell\n"
+"b, break = stop here (continue rebase later with 'git rebase --continue')\n"
+"d, drop <commit> = remove commit\n"
+"l, label <label> = label current HEAD with a name\n"
+"t, reset <label> = reset HEAD to a label\n"
+"m, merge [-C <commit> | -c <commit>] <label> [# <oneline>]\n"
+".       create a merge commit using the original merge commit's\n"
+".       message (or the oneline, if no original merge commit was\n"
+".       specified). Use -c <commit> to reword the commit message.\n"
+"\n"
+"These lines can be re-ordered; they are executed from top to bottom.\n"
 msgstr ""
+"\n"
+"Comandi:\n"
+"p, pick <commit> = usa il commit\n"
+"r, reword <commit> = usa il commit, ma modifica il messaggio di commit\n"
+"e, edit <commit> = usa il commit, ma fermati per modificarlo\n"
+"s, squash <commit> = usa il commit, ma fondilo con il commit precedente\n"
+"f, fixup <commit> = come \"squash\", ma scarta il messaggio di log di "
+"questo\n"
+"                    commit\n"
+"x, exec <comando> = esegui il comando (il resto della riga) usando la shell\n"
+"b, break = fermati qui (continua il rebase in un secondo momento con "
+"'git           rebase --continue')\n"
+"d, drop <commit> = elimina il commit\n"
+"l, label <etichetta> = etichetta l'HEAD corrente con un nome\n"
+"t, reset <etichetta> = reimposta HEAD a un'etichetta\n"
+"m, merge [-C <commit> | -c <commit>] <etichetta> [# <oneline>]\n"
+".       crea un commit di merge usando il messaggio del commit di merge\n"
+".       originale (o la oneline se non è stato specificato un commit di "
+"merge\n"
+".       originale). Usa -c <commit> per riformulare il messaggio di commit.\n"
+"\n"
+"Queste righe possono essere riordinate; saranno eseguite dalla prima "
+"all'ultima.\n"
 
-#: builtin/reset.c:33
-msgid "keep"
+#: rebase-interactive.c:56
+#, c-format
+msgid "Rebase %s onto %s (%d command)"
+msgid_plural "Rebase %s onto %s (%d commands)"
+msgstr[0] "Rebase di %s su %s (%d comando)"
+msgstr[1] "Rebase di %s su %s (%d comandi)"
+
+#: rebase-interactive.c:65 git-rebase--preserve-merges.sh:228
+msgid ""
+"\n"
+"Do not remove any line. Use 'drop' explicitly to remove a commit.\n"
 msgstr ""
+"\n"
+"Non eliminare alcuna riga. Usa esplicitamente 'drop' per rimuovere un "
+"commit.\n"
 
-#: builtin/reset.c:77
-msgid "You do not have a valid HEAD."
+#: rebase-interactive.c:68 git-rebase--preserve-merges.sh:232
+msgid ""
+"\n"
+"If you remove a line here THAT COMMIT WILL BE LOST.\n"
 msgstr ""
+"\n"
+"Rimuovendo una riga da qui IL COMMIT CORRISPONDENTE ANDRÀ PERDUTO.\n"
 
-#: builtin/reset.c:79
-msgid "Failed to find tree of HEAD."
+#: rebase-interactive.c:74 git-rebase--preserve-merges.sh:871
+msgid ""
+"\n"
+"You are editing the todo file of an ongoing interactive rebase.\n"
+"To continue rebase after editing, run:\n"
+"    git rebase --continue\n"
+"\n"
 msgstr ""
+"\n"
+"Stai modificando il file todo di un rebase interattivo in corso.\n"
+"Per continuare il rebase dopo la modifica, esegui:\n"
+"    git rebase --continue\n"
+"\n"
 
-#: builtin/reset.c:85
-#, c-format
-msgid "Failed to find tree of %s."
+#: rebase-interactive.c:79 git-rebase--preserve-merges.sh:948
+msgid ""
+"\n"
+"However, if you remove everything, the rebase will be aborted.\n"
+"\n"
 msgstr ""
+"\n"
+"Ciò nonostante, se rimuovi tutto, il rebase sarà annullato.\n"
+"\n"
 
-#: builtin/reset.c:96
-msgid "Could not write new index file."
-msgstr "Non è stato possibile scrivere il nuovo index file."
+#: rebase-interactive.c:85 git-rebase--preserve-merges.sh:955
+msgid "Note that empty commits are commented out"
+msgstr "Nota che i commit vuoti sono commentati"
 
-#: builtin/reset.c:106
+#: rebase-interactive.c:105 rerere.c:485 rerere.c:692 sequencer.c:3536
+#: sequencer.c:3562 sequencer.c:5263 builtin/fsck.c:346 builtin/rebase.c:254
 #, c-format
-msgid "HEAD is now at %s"
-msgstr "HEAD ora si trova a %s"
+msgid "could not write '%s'"
+msgstr "impossibile scrivere '%s'"
 
-#: builtin/reset.c:130
-msgid "Could not read index"
-msgstr "Non è stato possibile leggere index"
+#: rebase-interactive.c:108
+#, c-format
+msgid "could not copy '%s' to '%s'."
+msgstr "impossibile copiare '%s' in '%s'."
 
-#: builtin/reset.c:133
-msgid "Unstaged changes after reset:"
+#: rebase-interactive.c:173
+#, c-format
+msgid ""
+"Warning: some commits may have been dropped accidentally.\n"
+"Dropped commits (newer to older):\n"
 msgstr ""
+"Attenzione: è possibile che alcuni commit siano stati scartati "
+"accidentalmente.\n"
+"Commit scartati (dal più al meno recente):\n"
 
-#: builtin/reset.c:223
+#: rebase-interactive.c:180
 #, c-format
-msgid "Cannot do a %s reset in the middle of a merge."
-msgstr "Impossibile eseguire un %s reset nel corso di un merge."
+msgid ""
+"To avoid this message, use \"drop\" to explicitly remove a commit.\n"
+"\n"
+"Use 'git config rebase.missingCommitsCheck' to change the level of "
+"warnings.\n"
+"The possible behaviours are: ignore, warn, error.\n"
+"\n"
+msgstr ""
+"Per evitare questo messaggio, usa \"drop\" per rimuovere un commit\n"
+"esplicitamente.\n"
+"\n"
+"Usa 'git config rebase.missingCommitsCheck' per modificare il livello\n"
+"degli avvisi.\n"
+"I comportamenti possibili sono ignore, warn, error.\n"
+"\n"
 
-#: builtin/reset.c:297
+#: refs.c:262
 #, c-format
-msgid "Could not parse object '%s'."
-msgstr "Non è stato possibile analizzare l'oggetto '%s'."
+msgid "%s does not point to a valid object!"
+msgstr "%s non punta a un oggetto valido!"
 
-#: builtin/reset.c:302
-msgid "--patch is incompatible with --{hard,mixed,soft}"
-msgstr "--patch non è compatibile con --{hard,mixed,soft}"
+#: refs.c:667
+#, c-format
+msgid "ignoring dangling symref %s"
+msgstr "ignoro il riferimento simbolico pendente %s"
 
-#: builtin/reset.c:311
-msgid "--mixed with paths is deprecated; use 'git reset -- <paths>' instead."
-msgstr "--mixed con i path è deprecata; usa invece 'git reset -- <path>'."
+#: refs.c:669 ref-filter.c:2098
+#, c-format
+msgid "ignoring broken ref %s"
+msgstr "ignoro il riferimento rotto %s"
 
-#: builtin/reset.c:313
+#: refs.c:804
 #, c-format
-msgid "Cannot do %s reset with paths."
-msgstr ""
+msgid "could not open '%s' for writing: %s"
+msgstr "impossibile aprire '%s' in scrittura: %s"
 
-#: builtin/reset.c:325
+#: refs.c:814 refs.c:865
 #, c-format
-msgid "%s reset is not allowed in a bare repository"
-msgstr "%s reset non è consentito in un repository spoglio"
+msgid "could not read ref '%s'"
+msgstr "impossibile leggere il riferimento '%s'"
 
-#: builtin/reset.c:341
+#: refs.c:820
 #, c-format
-msgid "Could not reset index file to revision '%s'."
-msgstr ""
-"Non è stato possibile ripristinare index file "
-"alla revisione '%s'."
+msgid "ref '%s' already exists"
+msgstr "il riferimento '%s' esiste già"
 
-#: builtin/revert.c:70 builtin/revert.c:92
+#: refs.c:825
 #, c-format
-msgid "%s: %s cannot be used with %s"
-msgstr "%s: %s non può essere usata con %s"
+msgid "unexpected object ID when writing '%s'"
+msgstr "ID oggetto inatteso durante la scrittura di '%s'"
 
-#: builtin/revert.c:131
-msgid "program error"
-msgstr "errore del programma"
+#: refs.c:833 sequencer.c:405 sequencer.c:2793 sequencer.c:2997
+#: sequencer.c:3011 sequencer.c:3269 sequencer.c:5179 strbuf.c:1142
+#: wrapper.c:620
+#, c-format
+msgid "could not write to '%s'"
+msgstr "impossibile scrivere su '%s'"
 
-#: builtin/revert.c:221
-msgid "revert failed"
-msgstr "revert non riuscito"
+#: refs.c:860 strbuf.c:1140 wrapper.c:188 wrapper.c:358 builtin/am.c:714
+#: builtin/rebase.c:1031
+#, c-format
+msgid "could not open '%s' for writing"
+msgstr "impossibile aprire '%s' in scrittura"
 
-#: builtin/revert.c:236
-msgid "cherry-pick failed"
-msgstr "cherry-pick non riuscito"
+#: refs.c:867
+#, c-format
+msgid "unexpected object ID when deleting '%s'"
+msgstr "ID oggetto inatteso durante l'eliminazione di '%s'"
 
-#: builtin/rm.c:109
+#: refs.c:998
 #, c-format
-msgid ""
-"'%s' has staged content different from both the file and the HEAD\n"
-"(use -f to force removal)"
-msgstr ""
+msgid "log for ref %s has gap after %s"
+msgstr "il registro per il riferimento %s ha delle voci mancanti dopo %s"
 
-#: builtin/rm.c:115
+#: refs.c:1004
 #, c-format
-msgid ""
-"'%s' has changes staged in the index\n"
-"(use --cached to keep the file, or -f to force removal)"
-msgstr ""
+msgid "log for ref %s unexpectedly ended on %s"
+msgstr "il registro per il riferimento %s è terminato inaspettatamente a %s"
 
-#: builtin/rm.c:119
+#: refs.c:1063
 #, c-format
-msgid ""
-"'%s' has local modifications\n"
-"(use --cached to keep the file, or -f to force removal)"
-msgstr ""
-"'%s' contiene delle modifiche locali\n"
-"(usa --cached per mantenere il file, o -f per forzare la rimozione)"
+msgid "log for %s is empty"
+msgstr "il registro per %s è vuoto"
 
-#: builtin/rm.c:194
+#: refs.c:1155
 #, c-format
-msgid "not removing '%s' recursively without -r"
-msgstr ""
+msgid "refusing to update ref with bad name '%s'"
+msgstr "mi rifiuto di aggiornare il riferimento con il nome non valido '%s'"
 
-#: builtin/rm.c:230
+#: refs.c:1231
 #, c-format
-msgid "git rm: unable to remove %s"
-msgstr "git rm: non è possibile eliminare %s"
+msgid "update_ref failed for ref '%s': %s"
+msgstr "update_ref per il riferimento '%s' non riuscita: %s"
 
-#: builtin/shortlog.c:157
+#: refs.c:2023
 #, c-format
-msgid "Missing author: %s"
-msgstr "Autore mancante: %s"
+msgid "multiple updates for ref '%s' not allowed"
+msgstr "aggiornamenti multipli per il riferimento '%s' non consentiti"
 
-#: builtin/tag.c:60
+#: refs.c:2055
+msgid "ref updates forbidden inside quarantine environment"
+msgstr "aggiornamenti riferimento vietati nell'ambiente quarantena"
+
+#: refs.c:2151 refs.c:2181
 #, c-format
-msgid "malformed object at '%s'"
-msgstr ""
+msgid "'%s' exists; cannot create '%s'"
+msgstr "'%s' esiste già; impossibile creare '%s'"
 
-#: builtin/tag.c:207
+#: refs.c:2157 refs.c:2192
 #, c-format
-msgid "tag name too long: %.*s..."
-msgstr "nome tag troppo lungo: %.*s..."
+msgid "cannot process '%s' and '%s' at the same time"
+msgstr "impossibile gestire '%s' e '%s' contemporaneamente"
 
-#: builtin/tag.c:212
+#: refs/files-backend.c:1234
 #, c-format
-msgid "tag '%s' not found."
-msgstr "tag '%s' non trovato."
+msgid "could not remove reference %s"
+msgstr "impossibile rimuovere il riferimento %s"
 
-#: builtin/tag.c:227
+#: refs/files-backend.c:1248 refs/packed-backend.c:1541
+#: refs/packed-backend.c:1551
 #, c-format
-msgid "Deleted tag '%s' (was %s)\n"
-msgstr "Tag '%s' eliminato (era %s)\n"
+msgid "could not delete reference %s: %s"
+msgstr "impossibile eliminare il riferimento %s: %s"
 
-#: builtin/tag.c:239
+#: refs/files-backend.c:1251 refs/packed-backend.c:1554
 #, c-format
-msgid "could not verify the tag '%s'"
-msgstr "non è stato possibile verificare il tag '%s'"
+msgid "could not delete references: %s"
+msgstr "impossibile eliminare i riferimenti: %s"
 
-#: builtin/tag.c:249
-msgid ""
-"\n"
-"#\n"
-"# Write a tag message\n"
-"# Lines starting with '#' will be ignored.\n"
-"#\n"
-msgstr ""
-"\n"
-"#\n"
-"# Scrivere un messaggio associato al tag\n"
-"# Le righe che iniziano con '#' verranno ignorate.\n"
-"#\n"
+#: refspec.c:137
+#, c-format
+msgid "invalid refspec '%s'"
+msgstr "specificatore riferimento '%s' non valido"
 
-#: builtin/tag.c:256
-msgid ""
-"\n"
-"#\n"
-"# Write a tag message\n"
-"# Lines starting with '#' will be kept; you may remove them yourself if you "
-"want to.\n"
-"#\n"
-msgstr ""
-"\n"
-"#\n"
-"# Scrivere un messaggio associato al tag\n"
-"# Le righe che iniziano con '#' verranno mantenute; possono essere comunque "
-"rimosse manualmente.\n"
-"#\n"
+#: ref-filter.c:42 wt-status.c:1938
+msgid "gone"
+msgstr "sparito"
 
-#: builtin/tag.c:298
-msgid "unable to sign the tag"
-msgstr "impossibile firmare il tag"
+#: ref-filter.c:43
+#, c-format
+msgid "ahead %d"
+msgstr "dopo %d"
 
-#: builtin/tag.c:300
-msgid "unable to write tag file"
-msgstr "impossibile scrivere il file di tag"
+#: ref-filter.c:44
+#, c-format
+msgid "behind %d"
+msgstr "prima di %d"
 
-#: builtin/tag.c:325
-msgid "bad object type."
-msgstr "tipo di oggetto errato."
+#: ref-filter.c:45
+#, c-format
+msgid "ahead %d, behind %d"
+msgstr "dopo %d, prima di %d"
 
-#: builtin/tag.c:338
-msgid "tag header too big."
-msgstr "intestazione del tag troppo grande."
+#: ref-filter.c:165
+#, c-format
+msgid "expected format: %%(color:<color>)"
+msgstr "formato atteso: %%(color:<colore>)"
 
-#: builtin/tag.c:370
-msgid "no tag message?"
-msgstr "nessun messaggio per il tag?"
+#: ref-filter.c:167
+#, c-format
+msgid "unrecognized color: %%(color:%s)"
+msgstr "colore non riconosciuto: %%(color:%s)"
 
-#: builtin/tag.c:376
+#: ref-filter.c:189
 #, c-format
-msgid "The tag message has been left in %s\n"
-msgstr "Il messaggio del tag è stato lasciato in %s\n"
+msgid "Integer value expected refname:lstrip=%s"
+msgstr "Atteso valore intero: refname:lstrip=%s"
 
-#: builtin/tag.c:425
-msgid "switch 'points-at' requires an object"
-msgstr "lo switch 'points-at' richiede un oggetto"
+#: ref-filter.c:193
+#, c-format
+msgid "Integer value expected refname:rstrip=%s"
+msgstr "Atteso valore intero: refname:rstrip=%s"
 
-#: builtin/tag.c:427
+#: ref-filter.c:195
 #, c-format
-msgid "malformed object name '%s'"
-msgstr "nome oggetto '%s' malformato"
+msgid "unrecognized %%(%s) argument: %s"
+msgstr "argomento %%(%s) non riconosciuto: %s"
 
-#: builtin/tag.c:506
-msgid "--column and -n are incompatible"
-msgstr "--column e -n non sono compatibili"
+#: ref-filter.c:250
+#, c-format
+msgid "%%(objecttype) does not take arguments"
+msgstr "%%(objecttype) non accetta argomenti"
 
-#: builtin/tag.c:523
-msgid "-n option is only allowed with -l."
-msgstr "l'opzione -n è consentita solo con -l."
+#: ref-filter.c:272
+#, c-format
+msgid "unrecognized %%(objectsize) argument: %s"
+msgstr "argomento %%(objectsize) non riconosciuto: %s"
 
-#: builtin/tag.c:525
-msgid "--contains option is only allowed with -l."
-msgstr "l'opzione --contains è consentita solo con -l."
-
-#: builtin/tag.c:527
-msgid "--points-at option is only allowed with -l."
-msgstr "l'opzione --points-at è consentita solo con -l."
+#: ref-filter.c:280
+#, c-format
+msgid "%%(deltabase) does not take arguments"
+msgstr "%%(deltabase) non accetta argomenti"
 
-#: builtin/tag.c:535
-msgid "only one -F or -m option is allowed."
-msgstr "è consentita una sola opzione tra -F e -m."
+#: ref-filter.c:292
+#, c-format
+msgid "%%(body) does not take arguments"
+msgstr "%%(body) non accetta argomenti"
 
-#: builtin/tag.c:555
-msgid "too many params"
-msgstr "troppi parametri"
+#: ref-filter.c:301
+#, c-format
+msgid "%%(subject) does not take arguments"
+msgstr "%%(subject) non accetta argomenti"
 
-#: builtin/tag.c:561
+#: ref-filter.c:323
 #, c-format
-msgid "'%s' is not a valid tag name."
-msgstr "'%s' non è un nome tag valido."
+msgid "unknown %%(trailers) argument: %s"
+msgstr "argomento %%(trailers) sconosciuto: %s"
 
-#: builtin/tag.c:566
+#: ref-filter.c:352
 #, c-format
-msgid "tag '%s' already exists"
-msgstr "il tag '%s' esiste già"
+msgid "positive value expected contents:lines=%s"
+msgstr "atteso valore positivo in contents:lines=%s"
 
-#: builtin/tag.c:584
+#: ref-filter.c:354
 #, c-format
-msgid "%s: cannot lock the ref"
-msgstr "%s: impossibile riservare il ref"
+msgid "unrecognized %%(contents) argument: %s"
+msgstr "argomento %%(contents) non riconosciuto: %s"
 
-#: builtin/tag.c:586
+#: ref-filter.c:369
 #, c-format
-msgid "%s: cannot update the ref"
-msgstr "%s: impossibile aggiornare il ref"
+msgid "positive value expected objectname:short=%s"
+msgstr "atteso valore positivo in objectname:short=%s"
 
-#: builtin/tag.c:588
+#: ref-filter.c:373
 #, c-format
-msgid "Updated tag '%s' (was %s)\n"
-msgstr "Tag '%s' aggiornato (era %s)\n"
+msgid "unrecognized %%(objectname) argument: %s"
+msgstr "argomento %%(objectname) non riconosciuto: %s"
 
-#: git.c:16
-msgid "See 'git help <command>' for more information on a specific command."
-msgstr ""
-"Vedi 'git help <comando> per maggiori informazioni su un comando "
-"specifico."
+#: ref-filter.c:403
+#, c-format
+msgid "expected format: %%(align:<width>,<position>)"
+msgstr "formato atteso: %%(align:<ampiezza>,<posizione>)"
 
-#: parse-options.h:133 parse-options.h:235
-msgid "n"
-msgstr "n"
+#: ref-filter.c:415
+#, c-format
+msgid "unrecognized position:%s"
+msgstr "valore non riconosciuto: position:%s"
 
-#: parse-options.h:141
-msgid "time"
-msgstr "tempo"
+#: ref-filter.c:422
+#, c-format
+msgid "unrecognized width:%s"
+msgstr "valore non riconosciuto: width:%s"
 
-#: parse-options.h:149
-msgid "file"
-msgstr "file"
+#: ref-filter.c:431
+#, c-format
+msgid "unrecognized %%(align) argument: %s"
+msgstr "argomento %%(align) non riconosciuto: %s"
 
-#: parse-options.h:151
-msgid "when"
-msgstr "quando"
+#: ref-filter.c:439
+#, c-format
+msgid "positive width expected with the %%(align) atom"
+msgstr "attesa ampiezza positiva con l'atom %%(align)"
 
-#: parse-options.h:156
-msgid "no-op (backward compatibility)"
+#: ref-filter.c:457
+#, c-format
+msgid "unrecognized %%(if) argument: %s"
+msgstr "argomento %%(if) non riconosciuto: %s"
+
+#: ref-filter.c:559
+#, c-format
+msgid "malformed field name: %.*s"
+msgstr "nome campo malformato: %.*s"
+
+#: ref-filter.c:586
+#, c-format
+msgid "unknown field name: %.*s"
+msgstr "nome campo sconosciuto: %.*s"
+
+#: ref-filter.c:590
+#, c-format
+msgid ""
+"not a git repository, but the field '%.*s' requires access to object data"
 msgstr ""
+"non è un repository git, ma il campo '%.*s' richiede l'accesso ai dati "
+"oggetto"
 
-#: parse-options.h:228
-msgid "be more verbose"
-msgstr "più dettagliato"
+#: ref-filter.c:714
+#, c-format
+msgid "format: %%(if) atom used without a %%(then) atom"
+msgstr "formato: atomo %%(if) usato senza un atomo %%(then)"
 
-#: parse-options.h:230
-msgid "be more quiet"
-msgstr "meno dettagliato"
+#: ref-filter.c:777
+#, c-format
+msgid "format: %%(then) atom used without an %%(if) atom"
+msgstr "formato: atomo %%(then) usato senza un atomo %%(if)"
 
-#: parse-options.h:236
-msgid "use <n> digits to display SHA-1s"
-msgstr "usare <n> cifre per mostrare gli hash SHA-1"
+#: ref-filter.c:779
+#, c-format
+msgid "format: %%(then) atom used more than once"
+msgstr "formato: atomo %%(then) usato più di una volta"
 
-#: common-cmds.h:8
-msgid "Add file contents to the index"
-msgstr "Aggiunge il contenuto del file a index"
+#: ref-filter.c:781
+#, c-format
+msgid "format: %%(then) atom used after %%(else)"
+msgstr "formato: atomo %%(then) usato dopo %%(else)"
 
-#: common-cmds.h:9
-msgid "Find by binary search the change that introduced a bug"
-msgstr "Cerca mediante ricerca binaria la modifica che ha introdotto un bug"
+#: ref-filter.c:809
+#, c-format
+msgid "format: %%(else) atom used without an %%(if) atom"
+msgstr "formato: atomo %%(else) usato senza un atomo %%(if)"
 
-#: common-cmds.h:10
-msgid "List, create, or delete branches"
-msgstr "Elenca, crea o elimina branch"
+#: ref-filter.c:811
+#, c-format
+msgid "format: %%(else) atom used without a %%(then) atom"
+msgstr "formato: atomo %%(else) usato senza un atomo %%(then)"
 
-#: common-cmds.h:11
-msgid "Checkout a branch or paths to the working tree"
-msgstr ""
+#: ref-filter.c:813
+#, c-format
+msgid "format: %%(else) atom used more than once"
+msgstr "formato: atomo %%(else) usato più di una volta"
 
-#: common-cmds.h:12
-msgid "Clone a repository into a new directory"
-msgstr "Clona un repository in una nuova directory"
+#: ref-filter.c:828
+#, c-format
+msgid "format: %%(end) atom used without corresponding atom"
+msgstr "formato: atomo %%(end) usato senza l'atomo corrispondente"
 
-#: common-cmds.h:13
-msgid "Record changes to the repository"
-msgstr "Registra modifiche nel repository"
+#: ref-filter.c:885
+#, c-format
+msgid "malformed format string %s"
+msgstr "stringa di formato %s malformata"
 
-#: common-cmds.h:14
-msgid "Show changes between commits, commit and working tree, etc"
-msgstr ""
+#: ref-filter.c:1488
+#, c-format
+msgid "no branch, rebasing %s"
+msgstr "nessun branch, eseguo il rebase di %s"
 
-#: common-cmds.h:15
-msgid "Download objects and refs from another repository"
-msgstr "Scarica oggetti e ref da un altro repository"
+#: ref-filter.c:1491
+#, c-format
+msgid "no branch, rebasing detached HEAD %s"
+msgstr "nessun branch, eseguo il rebase dell'HEAD scollegato %s"
 
-#: common-cmds.h:16
-msgid "Print lines matching a pattern"
-msgstr "Stampa le righe corrispondenti ad un modello"
+#: ref-filter.c:1494
+#, c-format
+msgid "no branch, bisect started on %s"
+msgstr "nessun branch, bisezione avviata su %s"
 
-#: common-cmds.h:17
-msgid "Create an empty git repository or reinitialize an existing one"
-msgstr "Crea un repository git vuoto o reinizializza uno esistente"
+#: ref-filter.c:1504
+msgid "no branch"
+msgstr "nessun branch"
 
-#: common-cmds.h:18
-msgid "Show commit logs"
-msgstr "Mostra log del commit"
+#: ref-filter.c:1540 ref-filter.c:1749
+#, c-format
+msgid "missing object %s for %s"
+msgstr "oggetto %s mancante per %s"
 
-#: common-cmds.h:19
-msgid "Join two or more development histories together"
-msgstr "Unisce due o più cronologie di sviluppo"
+#: ref-filter.c:1550
+#, c-format
+msgid "parse_object_buffer failed on %s for %s"
+msgstr "parse_object_buffer non riuscito su %s per %s"
 
-#: common-cmds.h:20
-msgid "Move or rename a file, a directory, or a symlink"
-msgstr "Sposta o rinomina un file, una directory o un link simbolico"
+#: ref-filter.c:2004
+#, c-format
+msgid "malformed object at '%s'"
+msgstr "oggetto malformato in '%s'"
 
-#: common-cmds.h:21
-msgid "Fetch from and merge with another repository or a local branch"
-msgstr "Combina fetche + merge da un altro repository o un branch locale"
+#: ref-filter.c:2093
+#, c-format
+msgid "ignoring ref with broken name %s"
+msgstr "ignoro il riferimento con il nome malformato %s"
 
-#: common-cmds.h:22
-msgid "Update remote refs along with associated objects"
-msgstr "Aggiorna i ref remoti insieme agli oggetti associati"
+#: ref-filter.c:2389
+#, c-format
+msgid "format: %%(end) atom missing"
+msgstr "formato: atomo %%(end) mancante"
 
-#: common-cmds.h:23
-msgid "Forward-port local commits to the updated upstream head"
-msgstr ""
+#: ref-filter.c:2489
+#, c-format
+msgid "option `%s' is incompatible with --merged"
+msgstr "l'opzione `%s' non è compatibile con --merged"
 
-#: common-cmds.h:24
-msgid "Reset current HEAD to the specified state"
-msgstr "Ripristina l'HEAD corrente allo stato specificato"
+#: ref-filter.c:2492
+#, c-format
+msgid "option `%s' is incompatible with --no-merged"
+msgstr "l'opzione `%s' non è compatibile con --no-merged"
 
-#: common-cmds.h:25
-msgid "Remove files from the working tree and from the index"
-msgstr ""
+#: ref-filter.c:2502
+#, c-format
+msgid "malformed object name %s"
+msgstr "nome dell'oggetto %s malformato"
 
-#: common-cmds.h:26
-msgid "Show various types of objects"
-msgstr "Mostra vari tipi di oggetti"
+#: ref-filter.c:2507
+#, c-format
+msgid "option `%s' must point to a commit"
+msgstr "l'opzione `%s' deve puntare ad un commit"
 
-#: common-cmds.h:27
-msgid "Show the working tree status"
+#: remote.c:366
+#, c-format
+msgid "config remote shorthand cannot begin with '/': %s"
 msgstr ""
+"la forma breve della configurazione del remoto non può iniziare con '/': %s"
 
-#: common-cmds.h:28
-msgid "Create, list, delete or verify a tag object signed with GPG"
-msgstr "Crea, elenca, elimina o verifica un oggetto tag firmato con GPG"
+#: remote.c:413
+msgid "more than one receivepack given, using the first"
+msgstr "è stata specificata più di una direttiva receivepack, uso la prima"
 
-#: git-am.sh:50
-msgid "You need to set your committer info first"
-msgstr "È necessario impostare le informazioni sul committer"
+#: remote.c:421
+msgid "more than one uploadpack given, using the first"
+msgstr "è stata specificata più di una direttiva uploadpack, uso la prima"
 
-#: git-am.sh:95
-msgid ""
-"You seem to have moved HEAD since the last 'am' failure.\n"
-"Not rewinding to ORIG_HEAD"
+#: remote.c:611
+#, c-format
+msgid "Cannot fetch both %s and %s to %s"
+msgstr "Impossibile recuperare sia %s sia %s in %s"
+
+#: remote.c:615
+#, c-format
+msgid "%s usually tracks %s, not %s"
+msgstr "%s solitamente traccia %s, non %s"
+
+#: remote.c:619
+#, c-format
+msgid "%s tracks both %s and %s"
+msgstr "%s traccia sia %s sia %s"
+
+#: remote.c:687
+#, c-format
+msgid "key '%s' of pattern had no '*'"
+msgstr "la chiave '%s' del pattern non aveva un '*'"
+
+#: remote.c:697
+#, c-format
+msgid "value '%s' of pattern has no '*'"
+msgstr "il valore '%s' del pattern non ha un '*'"
+
+#: remote.c:1003
+#, c-format
+msgid "src refspec %s does not match any"
+msgstr "nessuna corrispondenza per lo specificatore riferimento sorgente %s"
+
+#: remote.c:1008
+#, c-format
+msgid "src refspec %s matches more than one"
 msgstr ""
+"sono state trovate più corrispondenze per lo specificatore riferimento "
+"sorgente %s"
 
-#: git-am.sh:105
-#, sh-format
+#. TRANSLATORS: "matches '%s'%" is the <dst> part of "git push
+#. <remote> <src>:<dst>" push, and "being pushed ('%s')" is
+#. the <src>.
+#.
+#: remote.c:1023
+#, c-format
 msgid ""
-"When you have resolved this problem run \"$cmdline --resolved\".\n"
-"If you would prefer to skip this patch, instead run \"$cmdline --skip\".\n"
-"To restore the original branch and stop patching run \"$cmdline --abort\"."
+"The destination you provided is not a full refname (i.e.,\n"
+"starting with \"refs/\"). We tried to guess what you meant by:\n"
+"\n"
+"- Looking for a ref that matches '%s' on the remote side.\n"
+"- Checking if the <src> being pushed ('%s')\n"
+"  is a ref in \"refs/{heads,tags}/\". If so we add a corresponding\n"
+"  refs/{heads,tags}/ prefix on the remote side.\n"
+"\n"
+"Neither worked, so we gave up. You must fully qualify the ref."
 msgstr ""
-"Quando hai risolto il problema esegui \"$cmdline --resolved\".\n"
-"Se vuoi saltare questa patch, esegui invece \"$cmdline --skip\".\n"
-"Per ripristinare il branch originale e interrompere l'applicazione delle "
-"patch esegui \"$cmdline --abort\"."
+"La destinazione che hai fornito non è un nome riferimento\n"
+"completo (ossia che inizia con \"refs/\"). Abbiamo provato a\n"
+"indovinare ciò che intendevi dire:\n"
+"\n"
+"- cercando un riferimento corrispondente a '%s' nel remoto;\n"
+"- controllando se la <sorgente> sottoposta a push ('%s') fosse un\n"
+"  riferimento compreso fra quelli in \"refs/{heads,tags}/\". In tal\n"
+"  caso avremmo aggiunto il prefisso corrispondente\n"
+"  refs/{heads,tags}/ al remoto.\n"
+"\n"
+"Nessuna delle due opzioni ha funzionato, quindi ci siamo arresi.\n"
+"Devi specificare un riferimento completamente qualificato."
 
-#: git-am.sh:121
-msgid "Cannot fall back to three-way merge."
+#: remote.c:1043
+#, c-format
+msgid ""
+"The <src> part of the refspec is a commit object.\n"
+"Did you mean to create a new branch by pushing to\n"
+"'%s:refs/heads/%s'?"
 msgstr ""
+"La parte <sorgente> dello specificatore riferimento\n"
+"è un oggetto tag. Forse intendevi creare un nuovo\n"
+"branch eseguendo il push a '%s:refs/heads/%s'?"
 
-#: git-am.sh:137
-msgid "Repository lacks necessary blobs to fall back on 3-way merge."
+#: remote.c:1048
+#, c-format
+msgid ""
+"The <src> part of the refspec is a tag object.\n"
+"Did you mean to create a new tag by pushing to\n"
+"'%s:refs/tags/%s'?"
 msgstr ""
+"La parte <sorgente> dello specificatore riferimento\n"
+"è un oggetto tag. Forse intendevi creare un nuovo\n"
+"branch eseguendo il push a '%s:refs/tags/%s'?"
 
-#: git-am.sh:154
+#: remote.c:1053
+#, c-format
 msgid ""
-"Did you hand edit your patch?\n"
-"It does not apply to blobs recorded in its index."
+"The <src> part of the refspec is a tree object.\n"
+"Did you mean to tag a new tree by pushing to\n"
+"'%s:refs/tags/%s'?"
 msgstr ""
-"La tua patch è stata modificata manualmente?\n"
-"Non può essere applicata ai blob registrati nel proprio index."
+"La parte <sorgente> dello specificatore riferimento\n"
+"è un oggetto albero. Forse intendevi aggiungere un\n"
+"tag a un nuovo albero eseguendo il push a\n"
+"'%s:refs/tags/%s'?"
 
-#: git-am.sh:163
-msgid "Falling back to patching base and 3-way merge..."
+#: remote.c:1058
+#, c-format
+msgid ""
+"The <src> part of the refspec is a blob object.\n"
+"Did you mean to tag a new blob by pushing to\n"
+"'%s:refs/tags/%s'?"
 msgstr ""
+"La parte <sorgente> dello specificatore riferimento\n"
+"è un oggetto blob. Forse intendevi aggiungere un\n"
+"tag a un nuovo blob eseguendo il push a\n"
+"'%s:refs/tags/%s'?"
 
-#: git-am.sh:275
-msgid "Only one StGIT patch series can be applied at once"
-msgstr "Può essere applicata solo una serie di patch StGIT per volta"
-
-#: git-am.sh:362
-#, sh-format
-msgid "Patch format $patch_format is not supported."
-msgstr "Il formato patch $patch_format non è supportato."
+#: remote.c:1094
+#, c-format
+msgid "%s cannot be resolved to branch"
+msgstr "%s non può essere risolto in un branch"
 
-#: git-am.sh:364
-msgid "Patch format detection failed."
-msgstr "Rilevamento del formato della patch non riuscito."
+#: remote.c:1105
+#, c-format
+msgid "unable to delete '%s': remote ref does not exist"
+msgstr "impossibile eliminare '%s': il riferimento remoto non esiste"
 
-#: git-am.sh:418
-msgid "-d option is no longer supported.  Do not use."
-msgstr "l'opzione -d non è più supportata.  Non utilizzarla."
+#: remote.c:1117
+#, c-format
+msgid "dst refspec %s matches more than one"
+msgstr ""
+"sono state trovate più corrispondenze per lo specificatore riferimento "
+"destinazione %s"
+
+#: remote.c:1124
+#, c-format
+msgid "dst ref %s receives from more than one src"
+msgstr ""
+"lo specificatore riferimento destinazione %s riceve dati da più di una "
+"sorgente"
+
+#: remote.c:1627 remote.c:1728
+msgid "HEAD does not point to a branch"
+msgstr "HEAD non punta ad un branch"
+
+#: remote.c:1636
+#, c-format
+msgid "no such branch: '%s'"
+msgstr "branch '%s' non esistente"
+
+#: remote.c:1639
+#, c-format
+msgid "no upstream configured for branch '%s'"
+msgstr "nessun upstream configurato per il branch '%s'"
+
+#: remote.c:1645
+#, c-format
+msgid "upstream branch '%s' not stored as a remote-tracking branch"
+msgstr ""
+"branch upstream '%s' non memorizzato come branch che ne traccia uno remoto"
+
+#: remote.c:1660
+#, c-format
+msgid "push destination '%s' on remote '%s' has no local tracking branch"
+msgstr ""
+"la destinazione del push '%s' sul remoto '%s' non ha un branch locale che la "
+"traccia"
+
+#: remote.c:1672
+#, c-format
+msgid "branch '%s' has no remote for pushing"
+msgstr "il branch '%s' non ha un remoto per il push"
+
+#: remote.c:1682
+#, c-format
+msgid "push refspecs for '%s' do not include '%s'"
+msgstr "gli specificatori riferimento per '%s' non includono '%s'"
+
+#: remote.c:1695
+msgid "push has no destination (push.default is 'nothing')"
+msgstr "il push non ha una destinazione (push.default è 'nothing')"
+
+#: remote.c:1717
+msgid "cannot resolve 'simple' push to a single destination"
+msgstr "impossibile risolvere il push 'simple' a una singola destinazione"
+
+#: remote.c:1843
+#, c-format
+msgid "couldn't find remote ref %s"
+msgstr "impossibile trovare il riferimento remoto %s"
+
+#: remote.c:1856
+#, c-format
+msgid "* Ignoring funny ref '%s' locally"
+msgstr "* Ignoro localmente il riferimento strano '%s'"
+
+#: remote.c:2019
+#, c-format
+msgid "Your branch is based on '%s', but the upstream is gone.\n"
+msgstr "Il tuo branch è basato su '%s', ma l'upstream è scomparso.\n"
+
+#: remote.c:2023
+msgid "  (use \"git branch --unset-upstream\" to fixup)\n"
+msgstr "  (usa \"git branch --unset-upstream\" per correggere la situazione)\n"
+
+#: remote.c:2026
+#, c-format
+msgid "Your branch is up to date with '%s'.\n"
+msgstr "Il tuo branch è aggiornato rispetto a '%s'.\n"
+
+#: remote.c:2030
+#, c-format
+msgid "Your branch and '%s' refer to different commits.\n"
+msgstr "Il tuo branch e '%s' fanno riferimento a commit differenti.\n"
+
+#: remote.c:2033
+#, c-format
+msgid "  (use \"%s\" for details)\n"
+msgstr "  (usa \"%s\" per visualizzare i dettagli)\n"
+
+#: remote.c:2037
+#, c-format
+msgid "Your branch is ahead of '%s' by %d commit.\n"
+msgid_plural "Your branch is ahead of '%s' by %d commits.\n"
+msgstr[0] "Il tuo branch è avanti rispetto a '%s' di %d commit.\n"
+msgstr[1] "Il tuo branch è avanti rispetto a '%s' di %d commit.\n"
+
+#: remote.c:2043
+msgid "  (use \"git push\" to publish your local commits)\n"
+msgstr "  (usa \"git push\" per pubblicare i tuoi commit locali)\n"
+
+#: remote.c:2046
+#, c-format
+msgid "Your branch is behind '%s' by %d commit, and can be fast-forwarded.\n"
+msgid_plural ""
+"Your branch is behind '%s' by %d commits, and can be fast-forwarded.\n"
+msgstr[0] ""
+"Il tuo branch, rispetto a '%s', è indietro di %d commit e ne posso eseguire "
+"il fast forward.\n"
+msgstr[1] ""
+"Il tuo branch, rispetto a '%s', è indietro di %d commit e ne posso eseguire "
+"il fast forward.\n"
+
+#: remote.c:2054
+msgid "  (use \"git pull\" to update your local branch)\n"
+msgstr "  (usa \"git pull\" per aggiornare il tuo branch locale)\n"
+
+#: remote.c:2057
+#, c-format
+msgid ""
+"Your branch and '%s' have diverged,\n"
+"and have %d and %d different commit each, respectively.\n"
+msgid_plural ""
+"Your branch and '%s' have diverged,\n"
+"and have %d and %d different commits each, respectively.\n"
+msgstr[0] ""
+"Il tuo branch e '%s' sono diventati divergenti\n"
+"e hanno rispettivamente %d e %d commit differenti.\n"
+msgstr[1] ""
+"Il tuo branch e '%s' sono diventati divergenti\n"
+"e hanno rispettivamente %d e %d commit differenti.\n"
+
+#: remote.c:2067
+msgid "  (use \"git pull\" to merge the remote branch into yours)\n"
+msgstr "  (usa \"git pull\" per eseguire il merge del branch remoto nel tuo)\n"
+
+#: remote.c:2250
+#, c-format
+msgid "cannot parse expected object name '%s'"
+msgstr "impossibile analizzare il nome oggetto atteso '%s'"
+
+#: replace-object.c:21
+#, c-format
+msgid "bad replace ref name: %s"
+msgstr "nome riferimento sostitutivo non valido: %s"
+
+#: replace-object.c:30
+#, c-format
+msgid "duplicate replace ref: %s"
+msgstr "riferimento sostitutivo duplicato: %s"
+
+#: replace-object.c:73
+#, c-format
+msgid "replace depth too high for object %s"
+msgstr "profondità sostituzione troppo elevata per l'oggetto %s"
+
+#: rerere.c:217 rerere.c:226 rerere.c:229
+msgid "corrupt MERGE_RR"
+msgstr "MERGE_RR corrotta"
+
+#: rerere.c:264 rerere.c:269
+msgid "unable to write rerere record"
+msgstr "impossibile scrivere il record rerere"
+
+#: rerere.c:495
+#, c-format
+msgid "there were errors while writing '%s' (%s)"
+msgstr "si sono verificati errori durante la scrittura di '%s' (%s)"
+
+#: rerere.c:498
+#, c-format
+msgid "failed to flush '%s'"
+msgstr "flush di '%s' non riuscito"
+
+#: rerere.c:503 rerere.c:1039
+#, c-format
+msgid "could not parse conflict hunks in '%s'"
+msgstr "impossibile analizzare gli hunk conflitto in '%s'"
+
+#: rerere.c:684
+#, c-format
+msgid "failed utime() on '%s'"
+msgstr "utime() di '%s' non riuscita"
+
+#: rerere.c:694
+#, c-format
+msgid "writing '%s' failed"
+msgstr "scrittura di '%s' non riuscita"
+
+#: rerere.c:714
+#, c-format
+msgid "Staged '%s' using previous resolution."
+msgstr "'%s' aggiunto all'area di staging usando la risoluzione precedente."
+
+#: rerere.c:753
+#, c-format
+msgid "Recorded resolution for '%s'."
+msgstr "Risoluzione per '%s' registrata."
+
+#: rerere.c:788
+#, c-format
+msgid "Resolved '%s' using previous resolution."
+msgstr "Risolto conflitto in '%s' usando la risoluzione precedente."
+
+#: rerere.c:803
+#, c-format
+msgid "cannot unlink stray '%s'"
+msgstr "impossibile eseguire l'unlink dell'oggetto smarrito '%s'"
+
+#: rerere.c:807
+#, c-format
+msgid "Recorded preimage for '%s'"
+msgstr "Salvata preimmagine di '%s'"
+
+#: rerere.c:881 submodule.c:2067 builtin/log.c:1871
+#: builtin/submodule--helper.c:1436 builtin/submodule--helper.c:1448
+#, c-format
+msgid "could not create directory '%s'"
+msgstr "impossibile creare la directory '%s'"
+
+#: rerere.c:1057
+#, c-format
+msgid "failed to update conflicted state in '%s'"
+msgstr "aggiornamento dello stato conflitto per '%s' non riuscito"
+
+#: rerere.c:1068 rerere.c:1075
+#, c-format
+msgid "no remembered resolution for '%s'"
+msgstr "nessuna risoluzione presente in memoria per '%s'"
+
+#: rerere.c:1077
+#, c-format
+msgid "cannot unlink '%s'"
+msgstr "impossibile eseguire l'unlink di '%s'"
+
+#: rerere.c:1087
+#, c-format
+msgid "Updated preimage for '%s'"
+msgstr "Preimmagine di '%s' aggiornata"
+
+#: rerere.c:1096
+#, c-format
+msgid "Forgot resolution for '%s'\n"
+msgstr "Risoluzione per '%s' dimenticata\n"
+
+#: rerere.c:1199
+msgid "unable to open rr-cache directory"
+msgstr "impossibile aprire la directory cache rr"
+
+#: revision.c:2497
+msgid "your current branch appears to be broken"
+msgstr "sembra che il tuo branch corrente sia rotto"
+
+#: revision.c:2500
+#, c-format
+msgid "your current branch '%s' does not have any commits yet"
+msgstr "il tuo branch corrente '%s' non ha ancora commit"
+
+#: revision.c:2708
+msgid "--first-parent is incompatible with --bisect"
+msgstr "--first-parent non è compatibile con --bisect"
+
+#: revision.c:2712
+msgid "-L does not yet support diff formats besides -p and -s"
+msgstr "-L non supporta ancora formati diff oltre a -p e -s"
+
+#: run-command.c:762
+msgid "open /dev/null failed"
+msgstr "apertura di /dev/null non riuscita"
+
+#: run-command.c:1268
+#, c-format
+msgid "cannot create async thread: %s"
+msgstr "impossibile creare il thread async: %s"
+
+#: run-command.c:1332
+#, c-format
+msgid ""
+"The '%s' hook was ignored because it's not set as executable.\n"
+"You can disable this warning with `git config advice.ignoredHook false`."
+msgstr ""
+"L'hook '%s' è stato ignorato perché non è impostato come eseguibile.\n"
+"Puoi disabilitare quest'avviso con `git config advice.ignoredHook false`."
+
+#: send-pack.c:144
+msgid "unexpected flush packet while reading remote unpack status"
+msgstr ""
+"pacchetto flush inatteso durante la lettura dello stato decompressione del "
+"remoto"
+
+#: send-pack.c:146
+#, c-format
+msgid "unable to parse remote unpack status: %s"
+msgstr "impossibile analizzare lo stato decompressione del remoto: %s"
+
+#: send-pack.c:148
+#, c-format
+msgid "remote unpack failed: %s"
+msgstr "decompressione sul remoto non riuscita: %s"
+
+#: send-pack.c:309
+msgid "failed to sign the push certificate"
+msgstr "firma del certificato per il push non riuscita"
+
+#: send-pack.c:423
+msgid "the receiving end does not support --signed push"
+msgstr "il ricevente non supporta i push --signed"
+
+#: send-pack.c:425
+msgid ""
+"not sending a push certificate since the receiving end does not support --"
+"signed push"
+msgstr ""
+"non invio un certificato push perché il ricevente non supporta i push --"
+"signed"
+
+#: send-pack.c:437
+msgid "the receiving end does not support --atomic push"
+msgstr "il ricevente non supporta i push --atomic"
+
+#: send-pack.c:442
+msgid "the receiving end does not support push options"
+msgstr "il ricevente non supporta le opzioni push"
+
+#: sequencer.c:189
+#, c-format
+msgid "invalid commit message cleanup mode '%s'"
+msgstr "modalità pulizia messaggio commit non valida: '%s'"
+
+#: sequencer.c:294
+#, c-format
+msgid "could not delete '%s'"
+msgstr "impossibile eliminare '%s'"
+
+#: sequencer.c:313 builtin/rebase.c:781 builtin/rebase.c:1706 builtin/rm.c:369
+#, c-format
+msgid "could not remove '%s'"
+msgstr "impossibile rimuovere '%s'"
+
+#: sequencer.c:323
+msgid "revert"
+msgstr "revert"
+
+#: sequencer.c:325
+msgid "cherry-pick"
+msgstr "cherry-pick"
+
+#: sequencer.c:327
+msgid "rebase -i"
+msgstr "rebase -i"
+
+#: sequencer.c:329
+#, c-format
+msgid "unknown action: %d"
+msgstr "azione sconosciuta: %d"
+
+#: sequencer.c:387
+msgid ""
+"after resolving the conflicts, mark the corrected paths\n"
+"with 'git add <paths>' or 'git rm <paths>'"
+msgstr ""
+"dopo aver risolto i conflitti, contrassegna i percorsi corretti\n"
+"con 'git add <path>' o 'git rm <path>'"
+
+#: sequencer.c:390
+msgid ""
+"after resolving the conflicts, mark the corrected paths\n"
+"with 'git add <paths>' or 'git rm <paths>'\n"
+"and commit the result with 'git commit'"
+msgstr ""
+"dopo aver risolto i conflitti, contrassegna i percorsi corretti\n"
+"con 'git add <path>' o 'git rm <path>' ed esegui\n"
+"il commit del risultato con 'git commit'"
+
+#: sequencer.c:403 sequencer.c:2993
+#, c-format
+msgid "could not lock '%s'"
+msgstr "impossibile bloccare '%s'"
+
+#: sequencer.c:410
+#, c-format
+msgid "could not write eol to '%s'"
+msgstr "impossibile scrivere il carattere di fine riga in '%s'"
+
+#: sequencer.c:415 sequencer.c:2798 sequencer.c:2999 sequencer.c:3013
+#: sequencer.c:3277
+#, c-format
+msgid "failed to finalize '%s'"
+msgstr "finalizzazione di '%s' non riuscita"
+
+#: sequencer.c:438 sequencer.c:1707 sequencer.c:2818 sequencer.c:3259
+#: sequencer.c:3368 builtin/am.c:244 builtin/commit.c:783 builtin/merge.c:1117
+#: builtin/rebase.c:589
+#, c-format
+msgid "could not read '%s'"
+msgstr "impossibile leggere '%s'"
+
+#: sequencer.c:464
+#, c-format
+msgid "your local changes would be overwritten by %s."
+msgstr "le tue modifiche locali sarebbero sovrascritte da %s."
+
+#: sequencer.c:468
+msgid "commit your changes or stash them to proceed."
+msgstr "esegui il commit delle modifiche o lo stash per procedere."
+
+#: sequencer.c:500
+#, c-format
+msgid "%s: fast-forward"
+msgstr "%s: fast forward"
+
+#: sequencer.c:539 builtin/tag.c:565
+#, c-format
+msgid "Invalid cleanup mode %s"
+msgstr "Modalità pulizia non valida: %s"
+
+#. TRANSLATORS: %s will be "revert", "cherry-pick" or
+#. "rebase -i".
+#.
+#: sequencer.c:633
+#, c-format
+msgid "%s: Unable to write new index file"
+msgstr "%s: impossibile scrivere il nuovo file indice"
+
+#: sequencer.c:650
+msgid "unable to update cache tree"
+msgstr "impossibile aggiornare l'albero cache"
+
+#: sequencer.c:664
+msgid "could not resolve HEAD commit"
+msgstr "impossibile risolvere il commit HEAD"
+
+#: sequencer.c:744
+#, c-format
+msgid "no key present in '%.*s'"
+msgstr "nessuna chiave presente in '%.*s'"
+
+#: sequencer.c:755
+#, c-format
+msgid "unable to dequote value of '%s'"
+msgstr "impossibile rimuovere gli apici dal valore di '%s'"
+
+#: sequencer.c:792 wrapper.c:190 wrapper.c:360 builtin/am.c:705
+#: builtin/am.c:797 builtin/merge.c:1114 builtin/rebase.c:1074
+#, c-format
+msgid "could not open '%s' for reading"
+msgstr "impossibile aprire '%s' in lettura"
+
+#: sequencer.c:802
+msgid "'GIT_AUTHOR_NAME' already given"
+msgstr "'GIT_AUTHOR_NAME' già specificato"
+
+#: sequencer.c:807
+msgid "'GIT_AUTHOR_EMAIL' already given"
+msgstr "'GIT_AUTHOR_EMAIL' già specificato"
+
+#: sequencer.c:812
+msgid "'GIT_AUTHOR_DATE' already given"
+msgstr "'GIT_AUTHOR_DATE' già specificato"
+
+#: sequencer.c:816
+#, c-format
+msgid "unknown variable '%s'"
+msgstr "variabile '%s' sconosciuta"
+
+#: sequencer.c:821
+msgid "missing 'GIT_AUTHOR_NAME'"
+msgstr "'GIT_AUTHOR_NAME' mancante"
+
+#: sequencer.c:823
+msgid "missing 'GIT_AUTHOR_EMAIL'"
+msgstr "'GIT_AUTHOR_EMAIL' mancante"
+
+#: sequencer.c:825
+msgid "missing 'GIT_AUTHOR_DATE'"
+msgstr "'GIT_AUTHOR_DATE' mancante"
+
+#: sequencer.c:902 sequencer.c:1427
+msgid "malformed ident line"
+msgstr "riga ident malformata"
+
+#: sequencer.c:925
+#, c-format
+msgid ""
+"you have staged changes in your working tree\n"
+"If these changes are meant to be squashed into the previous commit, run:\n"
+"\n"
+"  git commit --amend %s\n"
+"\n"
+"If they are meant to go into a new commit, run:\n"
+"\n"
+"  git commit %s\n"
+"\n"
+"In both cases, once you're done, continue with:\n"
+"\n"
+"  git rebase --continue\n"
+msgstr ""
+"hai modifiche in staging nell'albero di lavoro\n"
+"Se queste modifiche devono essere sottoposte a squash nel commit\n"
+"precedente, esegui:\n"
+"\n"
+"  git commit --amend %s\n"
+"\n"
+"Se devono essere incluse in un nuovo commit, esegui:\n"
+"\n"
+"  git commit %s\n"
+"\n"
+"In entrambi i casi, una volta finito, continua con:\n"
+"\n"
+"  git rebase --continue\n"
+
+#: sequencer.c:1218
+msgid "'prepare-commit-msg' hook failed"
+msgstr "hook 'prepare-commit-msg' non riuscito"
+
+#: sequencer.c:1224
+msgid ""
+"Your name and email address were configured automatically based\n"
+"on your username and hostname. Please check that they are accurate.\n"
+"You can suppress this message by setting them explicitly. Run the\n"
+"following command and follow the instructions in your editor to edit\n"
+"your configuration file:\n"
+"\n"
+"    git config --global --edit\n"
+"\n"
+"After doing this, you may fix the identity used for this commit with:\n"
+"\n"
+"    git commit --amend --reset-author\n"
+msgstr ""
+"Il tuo nome e l'indirizzo e-mail sono stati configurati automaticamente "
+"usando\n"
+"il tuo nome utente ed il nome host. Per favore, verifica che siano esatti.\n"
+"È possibile eliminare questo messaggio impostandoli esplicitamente.\n"
+"Esegui il seguente comando e segui le istruzioni fornite nel tuo editor\n"
+"per modificare il file di configurazione:\n"
+"\n"
+"    git config --global --edit\n"
+"Dopo questa operazione, puoi ripristinare l'identità usata in questo commit "
+"con:\n"
+"\n"
+"    git commit --amend --reset-author\n"
+
+#: sequencer.c:1237
+msgid ""
+"Your name and email address were configured automatically based\n"
+"on your username and hostname. Please check that they are accurate.\n"
+"You can suppress this message by setting them explicitly:\n"
+"\n"
+"    git config --global user.name \"Your Name\"\n"
+"    git config --global user.email you@example.com\n"
+"\n"
+"After doing this, you may fix the identity used for this commit with:\n"
+"\n"
+"    git commit --amend --reset-author\n"
+msgstr ""
+"Il tuo nome e l'indirizzo e-mail sono stati configurati automaticamente "
+"usando\n"
+"il tuo nome utente ed il nome host. Per favore, verifica che siano esatti.\n"
+"È possibile eliminare questo messaggio impostandoli esplicitamente:\n"
+"\n"
+"    git config --global user.name \"Il tuo nome\"\n"
+"    git config --global user.email tu@esempio.com\n"
+"\n"
+"Dopo questa operazione, puoi ripristinare l'identità usata in questo commit "
+"con:\n"
+"\n"
+"    git commit --amend --reset-author\n"
+
+#: sequencer.c:1279
+msgid "couldn't look up newly created commit"
+msgstr "impossibile trovare il commit appena creato"
+
+#: sequencer.c:1281
+msgid "could not parse newly created commit"
+msgstr "impossibile analizzare il commit appena creato"
+
+#: sequencer.c:1327
+msgid "unable to resolve HEAD after creating commit"
+msgstr "impossibile risolvere HEAD dopo la creazione del commit"
+
+#: sequencer.c:1329
+msgid "detached HEAD"
+msgstr "HEAD scollegato"
+
+#: sequencer.c:1333
+msgid " (root-commit)"
+msgstr " (commit radice)"
+
+#: sequencer.c:1354
+msgid "could not parse HEAD"
+msgstr "impossibile analizzare HEAD"
+
+#: sequencer.c:1356
+#, c-format
+msgid "HEAD %s is not a commit!"
+msgstr "L'HEAD %s non è un commit!"
+
+#: sequencer.c:1360 sequencer.c:1458 builtin/commit.c:1569
+msgid "could not parse HEAD commit"
+msgstr "impossibile analizzare il commit HEAD"
+
+#: sequencer.c:1411 sequencer.c:2055
+msgid "unable to parse commit author"
+msgstr "impossibile analizzare l'autore del commit"
+
+#: sequencer.c:1431
+msgid "corrupted author without date information"
+msgstr "informazioni sull'autore corrotte (senza data)"
+
+#: sequencer.c:1447 builtin/am.c:1561 builtin/merge.c:684
+msgid "git write-tree failed to write a tree"
+msgstr "git write-tree non è riuscito a scrivere un albero"
+
+#: sequencer.c:1480 sequencer.c:1550
+#, c-format
+msgid "unable to read commit message from '%s'"
+msgstr "impossibile leggere il messaggio di commit da '%s'"
+
+#: sequencer.c:1516 builtin/am.c:1583 builtin/commit.c:1668 builtin/merge.c:883
+#: builtin/merge.c:908
+msgid "failed to write commit object"
+msgstr "scrittura dell'oggetto del commit non riuscita"
+
+#: sequencer.c:1577
+#, c-format
+msgid "could not parse commit %s"
+msgstr "impossibile analizzare il commit %s"
+
+#: sequencer.c:1582
+#, c-format
+msgid "could not parse parent commit %s"
+msgstr "impossibile analizzare il commit genitore %s"
+
+#: sequencer.c:1656 sequencer.c:1767
+#, c-format
+msgid "unknown command: %d"
+msgstr "comando sconosciuto: %d"
+
+#: sequencer.c:1714 sequencer.c:1739
+#, c-format
+msgid "This is a combination of %d commits."
+msgstr "Questa è una combinazione di %d commit."
+
+#: sequencer.c:1724
+msgid "need a HEAD to fixup"
+msgstr "è necessaria un'HEAD per il fixup"
+
+#: sequencer.c:1726 sequencer.c:3304
+msgid "could not read HEAD"
+msgstr "impossibile leggere l'HEAD"
+
+#: sequencer.c:1728
+msgid "could not read HEAD's commit message"
+msgstr "impossibile leggere il messaggio di commit dell'HEAD"
+
+#: sequencer.c:1734
+#, c-format
+msgid "cannot write '%s'"
+msgstr "impossibile scrivere '%s'"
+
+#: sequencer.c:1741 git-rebase--preserve-merges.sh:496
+msgid "This is the 1st commit message:"
+msgstr "Questo è il primo messaggio di commit:"
+
+#: sequencer.c:1749
+#, c-format
+msgid "could not read commit message of %s"
+msgstr "impossibile leggere il messaggio di commit di %s"
+
+#: sequencer.c:1756
+#, c-format
+msgid "This is the commit message #%d:"
+msgstr "Questo è il messaggio di commit numero %d:"
+
+#: sequencer.c:1762
+#, c-format
+msgid "The commit message #%d will be skipped:"
+msgstr "Il messaggio di commit numero %d sarà saltato:"
+
+#: sequencer.c:1850
+msgid "your index file is unmerged."
+msgstr "il file indice non è stato sottoposto a merge."
+
+#: sequencer.c:1857
+msgid "cannot fixup root commit"
+msgstr "impossibile eseguire il fixup sul commit radice"
+
+#: sequencer.c:1876
+#, c-format
+msgid "commit %s is a merge but no -m option was given."
+msgstr "il commit %s è un merge ma non è stata specificata l'opzione -m."
+
+#: sequencer.c:1884 sequencer.c:1892
+#, c-format
+msgid "commit %s does not have parent %d"
+msgstr "il commit %s non ha il genitore %d"
+
+#: sequencer.c:1898
+#, c-format
+msgid "cannot get commit message for %s"
+msgstr "impossibile ottenere il messaggio di commit per %s"
+
+#. TRANSLATORS: The first %s will be a "todo" command like
+#. "revert" or "pick", the second %s a SHA1.
+#: sequencer.c:1917
+#, c-format
+msgid "%s: cannot parse parent commit %s"
+msgstr "%s: impossibile analizzare il commit genitore %s"
+
+#: sequencer.c:1982
+#, c-format
+msgid "could not rename '%s' to '%s'"
+msgstr "impossibile ridenominare '%s' in '%s'"
+
+#: sequencer.c:2037
+#, c-format
+msgid "could not revert %s... %s"
+msgstr "non è stato possibile eseguire il revert di %s... %s"
+
+#: sequencer.c:2038
+#, c-format
+msgid "could not apply %s... %s"
+msgstr "non è stato possibile applicare %s... %s"
+
+#: sequencer.c:2105
+#, c-format
+msgid "git %s: failed to read the index"
+msgstr "git %s: lettura dell'indice non riuscita"
+
+#: sequencer.c:2112
+#, c-format
+msgid "git %s: failed to refresh the index"
+msgstr "git %s: aggiornamento dell'indice non riuscito"
+
+#: sequencer.c:2189
+#, c-format
+msgid "%s does not accept arguments: '%s'"
+msgstr "%s non accetta argomenti: '%s'"
+
+#: sequencer.c:2198
+#, c-format
+msgid "missing arguments for %s"
+msgstr "argomenti mancanti per %s"
+
+#: sequencer.c:2235
+#, c-format
+msgid "could not parse '%.*s'"
+msgstr "impossibile analizzare '%.*s'"
+
+#: sequencer.c:2289
+#, c-format
+msgid "invalid line %d: %.*s"
+msgstr "riga %d non valida: %.*s"
+
+#: sequencer.c:2300
+#, c-format
+msgid "cannot '%s' without a previous commit"
+msgstr "impossibile eseguire '%s' senza un commit precedente"
+
+#: sequencer.c:2348 builtin/rebase.c:172 builtin/rebase.c:197
+#: builtin/rebase.c:223 builtin/rebase.c:248
+#, c-format
+msgid "could not read '%s'."
+msgstr "impossibile leggere '%s'."
+
+#: sequencer.c:2384
+msgid "cancelling a cherry picking in progress"
+msgstr "annullo un'operazione di cherry-pick in corso"
+
+#: sequencer.c:2391
+msgid "cancelling a revert in progress"
+msgstr "annullo un'operazione di revert in corso"
+
+#: sequencer.c:2435
+msgid "please fix this using 'git rebase --edit-todo'."
+msgstr "correggi la situazione usando 'git rebase --edit-todo'."
+
+#: sequencer.c:2437
+#, c-format
+msgid "unusable instruction sheet: '%s'"
+msgstr "foglio istruzioni inutilizzabile: '%s'"
+
+#: sequencer.c:2442
+msgid "no commits parsed."
+msgstr "nessun commit analizzato."
+
+#: sequencer.c:2453
+msgid "cannot cherry-pick during a revert."
+msgstr "impossibile eseguire un cherry-pick durante un revert."
+
+#: sequencer.c:2455
+msgid "cannot revert during a cherry-pick."
+msgstr "impossibile eseguire un revert durante un cherry-pick."
+
+#: sequencer.c:2533
+#, c-format
+msgid "invalid value for %s: %s"
+msgstr "valore non valido per %s: %s"
+
+#: sequencer.c:2630
+msgid "unusable squash-onto"
+msgstr "squash-onto inutilizzabile"
+
+#: sequencer.c:2646
+#, c-format
+msgid "malformed options sheet: '%s'"
+msgstr "foglio opzioni malformati: '%s'"
+
+#: sequencer.c:2736 sequencer.c:4463
+msgid "empty commit set passed"
+msgstr "è stato passato un insieme di commit vuoto"
+
+#: sequencer.c:2752
+msgid "revert is already in progress"
+msgstr "un'operazione di revert è già in corso"
+
+#: sequencer.c:2754
+#, c-format
+msgid "try \"git revert (--continue | %s--abort | --quit)\""
+msgstr "prova \"git revert (--continue | %s--abort | --quit)\""
+
+#: sequencer.c:2757
+msgid "cherry-pick is already in progress"
+msgstr "un'operazione di cherry-pick è già in corso"
+
+#: sequencer.c:2759
+#, c-format
+msgid "try \"git cherry-pick (--continue | %s--abort | --quit)\""
+msgstr "prova \"git cherry-pick (--continue | %s--abort | --quit)\""
+
+#: sequencer.c:2773
+#, c-format
+msgid "could not create sequencer directory '%s'"
+msgstr "impossibile creare la directory sequencer '%s'"
+
+#: sequencer.c:2788
+msgid "could not lock HEAD"
+msgstr "impossibile bloccare HEAD"
+
+#: sequencer.c:2848 sequencer.c:4209
+msgid "no cherry-pick or revert in progress"
+msgstr "nessuna operazione di cherry-pick o revert in corso"
+
+#: sequencer.c:2850 sequencer.c:2861
+msgid "cannot resolve HEAD"
+msgstr "impossibile risolvere HEAD"
+
+#: sequencer.c:2852 sequencer.c:2896
+msgid "cannot abort from a branch yet to be born"
+msgstr ""
+"impossibile interrompere l'operazione da un branch che deve essere ancora "
+"creato"
+
+#: sequencer.c:2882 builtin/grep.c:736
+#, c-format
+msgid "cannot open '%s'"
+msgstr "impossibile aprire '%s'"
+
+#: sequencer.c:2884
+#, c-format
+msgid "cannot read '%s': %s"
+msgstr "impossibile leggere '%s': %s"
+
+#: sequencer.c:2885
+msgid "unexpected end of file"
+msgstr "fine del file inattesa"
+
+#: sequencer.c:2891
+#, c-format
+msgid "stored pre-cherry-pick HEAD file '%s' is corrupt"
+msgstr ""
+"il file '%s' in cui è stato salvato l'HEAD prima del cherry pick è corrotto"
+
+#: sequencer.c:2902
+msgid "You seem to have moved HEAD. Not rewinding, check your HEAD!"
+msgstr ""
+"Sembra che tu abbia spostato l'HEAD. Non eseguo il rewind, controlla l'HEAD!"
+
+#: sequencer.c:2943
+msgid "no revert in progress"
+msgstr "nessun revert in corso"
+
+#: sequencer.c:2951
+msgid "no cherry-pick in progress"
+msgstr "nessun cherry-pick in corso"
+
+#: sequencer.c:2961
+msgid "failed to skip the commit"
+msgstr "salto del commit non riuscito"
+
+#: sequencer.c:2968
+msgid "there is nothing to skip"
+msgstr "non c'è nulla da saltare"
+
+#: sequencer.c:2971
+#, c-format
+msgid ""
+"have you committed already?\n"
+"try \"git %s --continue\""
+msgstr ""
+"hai già eseguito il commit?\n"
+"prova \"git %s --continue\""
+
+#: sequencer.c:3095 sequencer.c:4121
+#, c-format
+msgid "could not update %s"
+msgstr "impossibile aggiornare %s"
+
+#: sequencer.c:3134 sequencer.c:4101
+msgid "cannot read HEAD"
+msgstr "impossibile leggere l'HEAD"
+
+#: sequencer.c:3151
+#, c-format
+msgid "unable to copy '%s' to '%s'"
+msgstr "impossibile copiare '%s' in '%s'"
+
+#: sequencer.c:3159
+#, c-format
+msgid ""
+"You can amend the commit now, with\n"
+"\n"
+"  git commit --amend %s\n"
+"\n"
+"Once you are satisfied with your changes, run\n"
+"\n"
+"  git rebase --continue\n"
+msgstr ""
+"È possibile modificare il commit ora con\n"
+"\n"
+"  git commit --amend %s\n"
+"\n"
+"Quando sei soddisfatto delle modifiche, esegui\n"
+"\n"
+"  git rebase --continue\n"
+
+#: sequencer.c:3169
+#, c-format
+msgid "Could not apply %s... %.*s"
+msgstr "Impossibile applicare %s... %.*s"
+
+#: sequencer.c:3176
+#, c-format
+msgid "Could not merge %.*s"
+msgstr "Impossibile eseguire il merge di %.*s"
+
+#: sequencer.c:3190 sequencer.c:3194 builtin/difftool.c:641
+#, c-format
+msgid "could not copy '%s' to '%s'"
+msgstr "impossibile copiare '%s' in '%s'"
+
+#: sequencer.c:3221
+#, c-format
+msgid ""
+"execution failed: %s\n"
+"%sYou can fix the problem, and then run\n"
+"\n"
+"  git rebase --continue\n"
+"\n"
+msgstr ""
+"esecuzione non riuscita: %s\n"
+"%sPuoi correggere il problema e quindi eseguire\n"
+"\n"
+"  git rebase --continue\n"
+"\n"
+
+#: sequencer.c:3227
+msgid "and made changes to the index and/or the working tree\n"
+msgstr "e sono state apportate modifiche all'indice e/o all'albero di lavoro\n"
+
+#: sequencer.c:3233
+#, c-format
+msgid ""
+"execution succeeded: %s\n"
+"but left changes to the index and/or the working tree\n"
+"Commit or stash your changes, and then run\n"
+"\n"
+"  git rebase --continue\n"
+"\n"
+msgstr ""
+"esecuzione riuscita: %s\n"
+"ma sono state mantenute modifiche all'indice e/o all'albero di lavoro\n"
+"Esegui il commit o lo stash delle modifiche, quindi esegui\n"
+"\n"
+"  git rebase --continue\n"
+"\n"
+
+#: sequencer.c:3294
+#, c-format
+msgid "illegal label name: '%.*s'"
+msgstr "nome etichetta illecito: '%.*s'"
+
+#: sequencer.c:3348
+msgid "writing fake root commit"
+msgstr "scrittura commit radice falso in corso"
+
+#: sequencer.c:3353
+msgid "writing squash-onto"
+msgstr "scrittura squash-onto in corso"
+
+#: sequencer.c:3391 builtin/rebase.c:876 builtin/rebase.c:882
+#, c-format
+msgid "failed to find tree of %s"
+msgstr "impossibile trovare l'albero di %s"
+
+#: sequencer.c:3436
+#, c-format
+msgid "could not resolve '%s'"
+msgstr "impossibile risolvere '%s'"
+
+#: sequencer.c:3467
+msgid "cannot merge without a current revision"
+msgstr "impossibile eseguire il merge senza una revisione corrente"
+
+#: sequencer.c:3489
+#, c-format
+msgid "unable to parse '%.*s'"
+msgstr "impossibile analizzare '%.*s'"
+
+#: sequencer.c:3498
+#, c-format
+msgid "nothing to merge: '%.*s'"
+msgstr "non c'è nulla di cui eseguire il merge: '%.*s'"
+
+#: sequencer.c:3510
+msgid "octopus merge cannot be executed on top of a [new root]"
+msgstr "il merge octopus non può essere eseguito su un [nuovo commit radice]"
+
+#: sequencer.c:3526
+#, c-format
+msgid "could not get commit message of '%s'"
+msgstr "impossibile ottenere il messaggio di commit per '%s'"
+
+#: sequencer.c:3688
+#, c-format
+msgid "could not even attempt to merge '%.*s'"
+msgstr "non è stato nemmeno possibile tentare di eseguire il merge di '%.*s'"
+
+#: sequencer.c:3704
+msgid "merge: Unable to write new index file"
+msgstr "merge: impossibile scrivere il nuovo file indice"
+
+#: sequencer.c:3773 builtin/rebase.c:733
+#, c-format
+msgid "Applied autostash.\n"
+msgstr "Stash automatico applicato.\n"
+
+#: sequencer.c:3785
+#, c-format
+msgid "cannot store %s"
+msgstr "impossibile memorizzare %s"
+
+#: sequencer.c:3788 builtin/rebase.c:749 git-rebase--preserve-merges.sh:113
+#, c-format
+msgid ""
+"Applying autostash resulted in conflicts.\n"
+"Your changes are safe in the stash.\n"
+"You can run \"git stash pop\" or \"git stash drop\" at any time.\n"
+msgstr ""
+"L'applicazione dello stash automatico ha generato conflitti.\n"
+"Le tue modifiche sono al sicuro nello stash.\n"
+"Puoi eseguire \"git stash pop\" o \"git stash drop\" in qualunque momento.\n"
+
+#: sequencer.c:3849
+#, c-format
+msgid "could not checkout %s"
+msgstr "impossibile eseguire il checkout di %s"
+
+#: sequencer.c:3863
+#, c-format
+msgid "%s: not a valid OID"
+msgstr "%s: non è un OID valido"
+
+#: sequencer.c:3868 git-rebase--preserve-merges.sh:779
+msgid "could not detach HEAD"
+msgstr "impossibile scollegare l'HEAD"
+
+#: sequencer.c:3883
+#, c-format
+msgid "Stopped at HEAD\n"
+msgstr "Fermato a HEAD\n"
+
+#: sequencer.c:3885
+#, c-format
+msgid "Stopped at %s\n"
+msgstr "Fermato a %s\n"
+
+#: sequencer.c:3893
+#, c-format
+msgid ""
+"Could not execute the todo command\n"
+"\n"
+"    %.*s\n"
+"It has been rescheduled; To edit the command before continuing, please\n"
+"edit the todo list first:\n"
+"\n"
+"    git rebase --edit-todo\n"
+"    git rebase --continue\n"
+msgstr ""
+"Impossibile eseguire il comando todo\n"
+"\n"
+"    %.*s\n"
+"\n"
+"Il comando è stato pianificato nuovamente. Per modificarlo prima di\n"
+"continuare, modifica prima la lista todo:\n"
+"\n"
+"    git rebase --edit-todo\n"
+"    git rebase --continue\n"
+
+#: sequencer.c:3979
+#, c-format
+msgid "Stopped at %s...  %.*s\n"
+msgstr "Fermato a %s... %.*s\n"
+
+#: sequencer.c:4050
+#, c-format
+msgid "unknown command %d"
+msgstr "comando %d sconosciuto"
+
+#: sequencer.c:4109
+msgid "could not read orig-head"
+msgstr "impossibile leggere orig-head"
+
+#: sequencer.c:4114
+msgid "could not read 'onto'"
+msgstr "impossibile leggere 'onto'"
+
+#: sequencer.c:4128
+#, c-format
+msgid "could not update HEAD to %s"
+msgstr "impossibile aggiornare l'HEAD a %s"
+
+#: sequencer.c:4221
+msgid "cannot rebase: You have unstaged changes."
+msgstr ""
+"impossibile eseguire il rebase: ci sono delle modifiche non in staging."
+
+#: sequencer.c:4230
+msgid "cannot amend non-existing commit"
+msgstr "impossibile modificare un commit inesistente"
+
+#: sequencer.c:4232
+#, c-format
+msgid "invalid file: '%s'"
+msgstr "file non valido: '%s'"
+
+#: sequencer.c:4234
+#, c-format
+msgid "invalid contents: '%s'"
+msgstr "contenuti non validi: '%s'"
+
+#: sequencer.c:4237
+msgid ""
+"\n"
+"You have uncommitted changes in your working tree. Please, commit them\n"
+"first and then run 'git rebase --continue' again."
+msgstr ""
+"\n"
+"Ci sono modifiche di cui non è stato eseguito il commit nel tuo albero\n"
+"di lavoro. Eseguine prima il commit e quindi esegui nuovamente 'git rebase\n"
+"--continue'."
+
+#: sequencer.c:4273 sequencer.c:4312
+#, c-format
+msgid "could not write file: '%s'"
+msgstr "impossibile scrivere il file: '%s'"
+
+#: sequencer.c:4327
+msgid "could not remove CHERRY_PICK_HEAD"
+msgstr "impossibile rimuovere CHERRY_PICK_HEAD"
+
+#: sequencer.c:4334
+msgid "could not commit staged changes."
+msgstr "impossibile eseguire il commit delle modifiche in staging."
+
+#: sequencer.c:4440
+#, c-format
+msgid "%s: can't cherry-pick a %s"
+msgstr "%s: impossibile eseguire il cherry pick di un %s"
+
+#: sequencer.c:4444
+#, c-format
+msgid "%s: bad revision"
+msgstr "%s: revisione non valida"
+
+#: sequencer.c:4479
+msgid "can't revert as initial commit"
+msgstr "impossibile eseguire il revert come commit iniziale"
+
+#: sequencer.c:4952
+msgid "make_script: unhandled options"
+msgstr "make_script: opzioni non gestite"
+
+#: sequencer.c:4955
+msgid "make_script: error preparing revisions"
+msgstr "make_script: errore durante la preparazione delle revisioni"
+
+#: sequencer.c:5113
+msgid ""
+"You can fix this with 'git rebase --edit-todo' and then run 'git rebase --"
+"continue'.\n"
+"Or you can abort the rebase with 'git rebase --abort'.\n"
+msgstr ""
+"Puoi correggere questa situazione con 'git rebase --edit-todo' e quindi "
+"eseguire 'git rebase --continue'.\n"
+"Oppure puoi interrompere il rebase con 'git rebase --abort'.\n"
+
+#: sequencer.c:5226 sequencer.c:5243
+msgid "nothing to do"
+msgstr "nulla da fare"
+
+#: sequencer.c:5257
+msgid "could not skip unnecessary pick commands"
+msgstr "impossibile saltare i comandi pick non necessari"
+
+#: sequencer.c:5351
+msgid "the script was already rearranged."
+msgstr "lo script è già stato riordinato."
+
+#: setup.c:124
+#, c-format
+msgid "'%s' is outside repository"
+msgstr "'%s' è al di fuori del repository"
+
+#: setup.c:174
+#, c-format
+msgid ""
+"%s: no such path in the working tree.\n"
+"Use 'git <command> -- <path>...' to specify paths that do not exist locally."
+msgstr ""
+"%s: percorso non esistente nell'albero di lavoro.\n"
+"Usa 'git <comando> -- <percorso>...' per specificare percorsi non esistenti "
+"localmente."
+
+#: setup.c:187
+#, c-format
+msgid ""
+"ambiguous argument '%s': unknown revision or path not in the working tree.\n"
+"Use '--' to separate paths from revisions, like this:\n"
+"'git <command> [<revision>...] -- [<file>...]'"
+msgstr ""
+"argomento '%s' ambiguo: revisione sconosciuta o percorso non nell'albero di "
+"lavoro.\n"
+"Usa '--' per separare i percorsi dalle revisioni, come segue:\n"
+"'git <comando> [<revisione>...] -- [<file>...]'"
+
+#: setup.c:236
+#, c-format
+msgid "option '%s' must come before non-option arguments"
+msgstr ""
+"l'opzione '%s' deve essere specificata prima degli argomenti che non "
+"costituiscono un'opzione"
+
+#: setup.c:255
+#, c-format
+msgid ""
+"ambiguous argument '%s': both revision and filename\n"
+"Use '--' to separate paths from revisions, like this:\n"
+"'git <command> [<revision>...] -- [<file>...]'"
+msgstr ""
+"argomento '%s' ambiguo: è sia una revisione sia un nome file\n"
+"Usa '--' per separare i percorsi dalle revisioni, come segue:\n"
+"'git <comando> [<revisione>...] -- [<file>...]'"
+
+#: setup.c:391
+msgid "unable to set up work tree using invalid config"
+msgstr ""
+"impossibile preparare l'albero di lavoro usando una configurazione non valida"
+
+#: setup.c:395
+msgid "this operation must be run in a work tree"
+msgstr "quest'operazione deve essere eseguita in un albero di lavoro"
+
+#: setup.c:541
+#, c-format
+msgid "Expected git repo version <= %d, found %d"
+msgstr "Attesa versione repository Git <= %d, trovata %d"
+
+#: setup.c:549
+msgid "unknown repository extensions found:"
+msgstr "trovate estensioni repository sconosciute:"
+
+#: setup.c:568
+#, c-format
+msgid "error opening '%s'"
+msgstr "errore durante l'apertura di '%s'"
+
+#: setup.c:570
+#, c-format
+msgid "too large to be a .git file: '%s'"
+msgstr "'%s' troppo grande per essere un file .git"
+
+#: setup.c:572
+#, c-format
+msgid "error reading %s"
+msgstr "errore durante la lettura di %s"
+
+#: setup.c:574
+#, c-format
+msgid "invalid gitfile format: %s"
+msgstr "formato file Git non valido: %s"
+
+#: setup.c:576
+#, c-format
+msgid "no path in gitfile: %s"
+msgstr "nessun percorso presente nel file Git: %s"
+
+#: setup.c:578
+#, c-format
+msgid "not a git repository: %s"
+msgstr "%s non è un repository Git"
+
+#: setup.c:677
+#, c-format
+msgid "'$%s' too big"
+msgstr "'$%s' è troppo grande"
+
+#: setup.c:691
+#, c-format
+msgid "not a git repository: '%s'"
+msgstr "'%s' non è un repository Git"
+
+#: setup.c:720 setup.c:722 setup.c:753
+#, c-format
+msgid "cannot chdir to '%s'"
+msgstr "impossibile modificare la directory corrente in '%s'"
+
+#: setup.c:725 setup.c:781 setup.c:791 setup.c:830 setup.c:838
+msgid "cannot come back to cwd"
+msgstr "impossibile tornare alla directory di lavoro corrente"
+
+#: setup.c:852
+#, c-format
+msgid "failed to stat '%*s%s%s'"
+msgstr "stat di '%*s%s%s' non riuscito"
+
+#: setup.c:1090
+msgid "Unable to read current working directory"
+msgstr "Impossibile leggere la directory di lavoro corrente"
+
+#: setup.c:1099 setup.c:1105
+#, c-format
+msgid "cannot change to '%s'"
+msgstr "impossibile entrare in '%s'"
+
+#: setup.c:1110
+#, c-format
+msgid "not a git repository (or any of the parent directories): %s"
+msgstr "%s non è un repository Git (né lo è alcuna delle directory genitrici)"
+
+#: setup.c:1116
+#, c-format
+msgid ""
+"not a git repository (or any parent up to mount point %s)\n"
+"Stopping at filesystem boundary (GIT_DISCOVERY_ACROSS_FILESYSTEM not set)."
+msgstr ""
+"non è un repository Git (né lo è alcun genitore fino al punto di mount %s)\n"
+"Mi fermo al limite del filesystem (l'opzione GIT_DISCOVERY_ACROSS_FILESYSTEM "
+"non è impostata)."
+
+#: setup.c:1227
+#, c-format
+msgid ""
+"problem with core.sharedRepository filemode value (0%.3o).\n"
+"The owner of files must always have read and write permissions."
+msgstr ""
+"si è verificato un problema con il valore modo file di core.sharedRepository "
+"(0%.3o).\n"
+"Il proprietario dei file deve avere sempre i permessi di lettura e scrittura."
+
+#: setup.c:1271
+msgid "open /dev/null or dup failed"
+msgstr "apertura di /dev/null o dup non riuscita"
+
+#: setup.c:1286
+msgid "fork failed"
+msgstr "fork non riuscita"
+
+#: setup.c:1291
+msgid "setsid failed"
+msgstr "setsid non riuscita"
+
+#: sha1-file.c:452
+#, c-format
+msgid "object directory %s does not exist; check .git/objects/info/alternates"
+msgstr ""
+"la directory oggetti %s non esiste; controlla .git/objects/info/alternates"
+
+#: sha1-file.c:503
+#, c-format
+msgid "unable to normalize alternate object path: %s"
+msgstr "impossibile normalizzare il percorso alternativo oggetto: %s"
+
+#: sha1-file.c:575
+#, c-format
+msgid "%s: ignoring alternate object stores, nesting too deep"
+msgstr ""
+"%s: ignoro gli archivi oggetto alternativi, la nidificazione è troppo "
+"profonda"
+
+#: sha1-file.c:582
+#, c-format
+msgid "unable to normalize object directory: %s"
+msgstr "impossibile normalizzare la directory oggetti: %s"
+
+#: sha1-file.c:625
+msgid "unable to fdopen alternates lockfile"
+msgstr "impossibile eseguire fdopen sul file di lock alternates"
+
+#: sha1-file.c:643
+msgid "unable to read alternates file"
+msgstr "impossibile leggere il file alternates"
+
+#: sha1-file.c:650
+msgid "unable to move new alternates file into place"
+msgstr "impossibile spostare il nuovo file alternates nella posizione corretta"
+
+#: sha1-file.c:685
+#, c-format
+msgid "path '%s' does not exist"
+msgstr "il percorso '%s' non esiste"
+
+#: sha1-file.c:711
+#, c-format
+msgid "reference repository '%s' as a linked checkout is not supported yet."
+msgstr ""
+"l'aggiunta del repository di riferimento '%s' come checkout collegato non è "
+"ancora supportata."
+
+#: sha1-file.c:717
+#, c-format
+msgid "reference repository '%s' is not a local repository."
+msgstr "il repository di riferimento '%s' non è un repository locale."
+
+#: sha1-file.c:723
+#, c-format
+msgid "reference repository '%s' is shallow"
+msgstr "il repository di riferimento '%s' è shallow"
+
+#: sha1-file.c:731
+#, c-format
+msgid "reference repository '%s' is grafted"
+msgstr "il repository di riferimento '%s' è un graft"
+
+#: sha1-file.c:791
+#, c-format
+msgid "invalid line while parsing alternate refs: %s"
+msgstr "riga non valida durante l'analisi dei riferimenti degli alternati: %s"
+
+#: sha1-file.c:943
+#, c-format
+msgid "attempting to mmap %<PRIuMAX> over limit %<PRIuMAX>"
+msgstr "tento di eseguire mmap %<PRIuMAX> al di sopra del limite %<PRIuMAX>"
+
+#: sha1-file.c:964
+msgid "mmap failed"
+msgstr "mmap non riuscita"
+
+#: sha1-file.c:1128
+#, c-format
+msgid "object file %s is empty"
+msgstr "l'oggetto %s è vuoto"
+
+#: sha1-file.c:1252 sha1-file.c:2392
+#, c-format
+msgid "corrupt loose object '%s'"
+msgstr "oggetto sciolto '%s' corrotto"
+
+#: sha1-file.c:1254 sha1-file.c:2396
+#, c-format
+msgid "garbage at end of loose object '%s'"
+msgstr "dati inutilizzabili presenti alla fine dell'oggetto sciolto '%s'"
+
+#: sha1-file.c:1296
+msgid "invalid object type"
+msgstr "tipo oggetto non valido"
+
+#: sha1-file.c:1380
+#, c-format
+msgid "unable to unpack %s header with --allow-unknown-type"
+msgstr "impossibile decomprimere l'intestazione %s con --allow-unknown-type"
+
+#: sha1-file.c:1383
+#, c-format
+msgid "unable to unpack %s header"
+msgstr "impossibile decomprimere l'intestazione %s"
+
+#: sha1-file.c:1389
+#, c-format
+msgid "unable to parse %s header with --allow-unknown-type"
+msgstr "impossibile analizzare l'intestazione %s con --allow-unknown-type"
+
+#: sha1-file.c:1392
+#, c-format
+msgid "unable to parse %s header"
+msgstr "impossibile analizzare l'intestazione %s"
+
+#: sha1-file.c:1584
+#, c-format
+msgid "failed to read object %s"
+msgstr "lettura dell'oggetto %s non riuscita"
+
+#: sha1-file.c:1588
+#, c-format
+msgid "replacement %s not found for %s"
+msgstr "%s sostitutivo non trovato per %s"
+
+#: sha1-file.c:1592
+#, c-format
+msgid "loose object %s (stored in %s) is corrupt"
+msgstr "l'oggetto sciolto %s (salvato in %s) è corrotto"
+
+#: sha1-file.c:1596
+#, c-format
+msgid "packed object %s (stored in %s) is corrupt"
+msgstr "l'oggetto archiviato %s (salvato in %s) è corrotto"
+
+#: sha1-file.c:1699
+#, c-format
+msgid "unable to write file %s"
+msgstr "impossibile scrivere il file %s"
+
+#: sha1-file.c:1706
+#, c-format
+msgid "unable to set permission to '%s'"
+msgstr "impossibile impostare i permessi a '%s'"
+
+#: sha1-file.c:1713
+msgid "file write error"
+msgstr "errore di scrittura del file"
+
+#: sha1-file.c:1732
+msgid "error when closing loose object file"
+msgstr "errore durante la chiusura del file oggetto sciolto"
+
+#: sha1-file.c:1797
+#, c-format
+msgid "insufficient permission for adding an object to repository database %s"
+msgstr ""
+"permessi non sufficienti per l'aggiunta di un oggetto al database repository "
+"%s"
+
+#: sha1-file.c:1799
+msgid "unable to create temporary file"
+msgstr "impossibile creare il file temporaneo"
+
+#: sha1-file.c:1823
+msgid "unable to write loose object file"
+msgstr "impossibile scrivere il file oggetto sciolto"
+
+#: sha1-file.c:1829
+#, c-format
+msgid "unable to deflate new object %s (%d)"
+msgstr "impossibile comprimere con deflate il nuovo oggetto %s (%d)"
+
+#: sha1-file.c:1833
+#, c-format
+msgid "deflateEnd on object %s failed (%d)"
+msgstr "deflateEnd non riuscita sull'oggetto %s (%d)"
+
+#: sha1-file.c:1837
+#, c-format
+msgid "confused by unstable object source data for %s"
+msgstr "sono confuso dall'origine dati oggetto non stabile per %s"
+
+#: sha1-file.c:1847 builtin/pack-objects.c:925
+#, c-format
+msgid "failed utime() on %s"
+msgstr "utime() di %s non riuscita"
+
+#: sha1-file.c:1922
+#, c-format
+msgid "cannot read object for %s"
+msgstr "impossibile leggere l'oggetto per %s"
+
+#: sha1-file.c:1962
+msgid "corrupt commit"
+msgstr "commit corrotto"
+
+#: sha1-file.c:1970
+msgid "corrupt tag"
+msgstr "tag corrotto"
+
+#: sha1-file.c:2069
+#, c-format
+msgid "read error while indexing %s"
+msgstr "errore di lettura durante l'indicizzazione di %s"
+
+#: sha1-file.c:2072
+#, c-format
+msgid "short read while indexing %s"
+msgstr "lettura troppo breve durante l'indicizzazione di %s"
+
+#: sha1-file.c:2145 sha1-file.c:2154
+#, c-format
+msgid "%s: failed to insert into database"
+msgstr "%s: inserimento del record nel database non riuscito"
+
+#: sha1-file.c:2160
+#, c-format
+msgid "%s: unsupported file type"
+msgstr "%s: tipo di file non supportato"
+
+#: sha1-file.c:2184
+#, c-format
+msgid "%s is not a valid object"
+msgstr "%s non è un oggetto valido"
+
+#: sha1-file.c:2186
+#, c-format
+msgid "%s is not a valid '%s' object"
+msgstr "%s non è un oggetto '%s' valido"
+
+#: sha1-file.c:2213 builtin/index-pack.c:155
+#, c-format
+msgid "unable to open %s"
+msgstr "impossibile aprire %s"
+
+#: sha1-file.c:2403 sha1-file.c:2455
+#, c-format
+msgid "hash mismatch for %s (expected %s)"
+msgstr "mancata corrispondenza per %s (atteso %s)"
+
+#: sha1-file.c:2427
+#, c-format
+msgid "unable to mmap %s"
+msgstr "impossibile eseguire mmap su %s"
+
+#: sha1-file.c:2432
+#, c-format
+msgid "unable to unpack header of %s"
+msgstr "impossibile decomprimere l'intestazione di %s"
+
+#: sha1-file.c:2438
+#, c-format
+msgid "unable to parse header of %s"
+msgstr "impossibile analizzare l'intestazione di %s"
+
+#: sha1-file.c:2449
+#, c-format
+msgid "unable to unpack contents of %s"
+msgstr "impossibile decomprimere i contenuti di %s"
+
+#: sha1-name.c:487
+#, c-format
+msgid "short SHA1 %s is ambiguous"
+msgstr "lo SHA1 breve %s è ambiguo"
+
+#: sha1-name.c:498
+msgid "The candidates are:"
+msgstr "I candidati sono:"
+
+#: sha1-name.c:797
+msgid ""
+"Git normally never creates a ref that ends with 40 hex characters\n"
+"because it will be ignored when you just specify 40-hex. These refs\n"
+"may be created by mistake. For example,\n"
+"\n"
+"  git switch -c $br $(git rev-parse ...)\n"
+"\n"
+"where \"$br\" is somehow empty and a 40-hex ref is created. Please\n"
+"examine these refs and maybe delete them. Turn this message off by\n"
+"running \"git config advice.objectNameWarning false\""
+msgstr ""
+"Git normalmente non crea mai un riferimento che termina con 40\n"
+"caratteri esadecimali perché sarà ignorato se si specificano\n"
+"semplicemente 40 caratteri esadecimali. Questi riferimenti\n"
+"potrebbero essere creati per errore. Ad esempio:\n"
+"\n"
+"  git switch -c $br $(git rev-parse ...)\n"
+"\n"
+"dove \"$br\" è vuoto per qualche motivo e quindi viene creato un\n"
+"riferimento con 40 caratteri esadecimali. Esamina tali\n"
+"riferimenti ed eliminali se necessario. Disabilita questo\n"
+"messaggio eseguendo \"git config advice.objectNameWarning false\""
+
+#. TRANSLATORS: IEC 80000-13:2008 gibibyte
+#: strbuf.c:822
+#, c-format
+msgid "%u.%2.2u GiB"
+msgstr "%u.%2.2u GiB"
+
+#. TRANSLATORS: IEC 80000-13:2008 gibibyte/second
+#: strbuf.c:824
+#, c-format
+msgid "%u.%2.2u GiB/s"
+msgstr "%u.%2.2u GiB/s"
+
+#. TRANSLATORS: IEC 80000-13:2008 mebibyte
+#: strbuf.c:832
+#, c-format
+msgid "%u.%2.2u MiB"
+msgstr "%u.%2.2u MiB"
+
+#. TRANSLATORS: IEC 80000-13:2008 mebibyte/second
+#: strbuf.c:834
+#, c-format
+msgid "%u.%2.2u MiB/s"
+msgstr "%u.%2.2u MiB/s"
+
+#. TRANSLATORS: IEC 80000-13:2008 kibibyte
+#: strbuf.c:841
+#, c-format
+msgid "%u.%2.2u KiB"
+msgstr "%u.%2.2u KiB"
+
+#. TRANSLATORS: IEC 80000-13:2008 kibibyte/second
+#: strbuf.c:843
+#, c-format
+msgid "%u.%2.2u KiB/s"
+msgstr "%u.%2.2u KiB/s"
+
+#. TRANSLATORS: IEC 80000-13:2008 byte
+#: strbuf.c:849
+#, c-format
+msgid "%u byte"
+msgid_plural "%u bytes"
+msgstr[0] "%u byte"
+msgstr[1] "%u byte"
+
+#. TRANSLATORS: IEC 80000-13:2008 byte/second
+#: strbuf.c:851
+#, c-format
+msgid "%u byte/s"
+msgid_plural "%u bytes/s"
+msgstr[0] "%u byte/s"
+msgstr[1] "%u byte/s"
+
+#: strbuf.c:1149
+#, c-format
+msgid "could not edit '%s'"
+msgstr "impossibile modificare '%s'"
+
+#: submodule.c:114 submodule.c:143
+msgid "Cannot change unmerged .gitmodules, resolve merge conflicts first"
+msgstr ""
+"Impossibile modificare il file .gitmodules non sottoposto a merge, risolvi "
+"prima i conflitti di merge"
+
+#: submodule.c:118 submodule.c:147
+#, c-format
+msgid "Could not find section in .gitmodules where path=%s"
+msgstr "Impossibile trovare una sezione in .gitmodules dove path=%s"
+
+#: submodule.c:154
+#, c-format
+msgid "Could not remove .gitmodules entry for %s"
+msgstr "Impossibile rimuovere la voce .gitmodules per %s"
+
+#: submodule.c:165
+msgid "staging updated .gitmodules failed"
+msgstr "staging del file .gitmodules aggiornato non riuscito"
+
+#: submodule.c:327
+#, c-format
+msgid "in unpopulated submodule '%s'"
+msgstr "nel sottomodulo non popolato '%s'"
+
+#: submodule.c:358
+#, c-format
+msgid "Pathspec '%s' is in submodule '%.*s'"
+msgstr "Lo specificatore percorso '%s' è nel sottomodulo '%.*s'"
+
+#: submodule.c:910
+#, c-format
+msgid "submodule entry '%s' (%s) is a %s, not a commit"
+msgstr "la voce sottomodulo '%s' (%s) è un %s, non un commit"
+
+#: submodule.c:1147 builtin/branch.c:680 builtin/submodule--helper.c:2016
+msgid "Failed to resolve HEAD as a valid ref."
+msgstr "Impossibile risolvere HEAD come riferimento valido."
+
+#: submodule.c:1481
+#, c-format
+msgid "Could not access submodule '%s'"
+msgstr "Impossibile accedere al sottomodulo '%s'"
+
+#: submodule.c:1651
+#, c-format
+msgid "'%s' not recognized as a git repository"
+msgstr "'%s' non riconosciuto come repository Git"
+
+#: submodule.c:1789
+#, c-format
+msgid "could not start 'git status' in submodule '%s'"
+msgstr "impossibile avviare 'git status' nel sottomodulo '%s'"
+
+#: submodule.c:1802
+#, c-format
+msgid "could not run 'git status' in submodule '%s'"
+msgstr "impossibile eseguire 'git status' nel sottomodulo '%s'"
+
+#: submodule.c:1817
+#, c-format
+msgid "Could not unset core.worktree setting in submodule '%s'"
+msgstr ""
+"Impossibile annullare l'impostazione dell'opzione core.worktree nel "
+"sottomodulo '%s'"
+
+#: submodule.c:1907
+#, c-format
+msgid "submodule '%s' has dirty index"
+msgstr "il sottomodulo '%s' ha l'indice sporco"
+
+#: submodule.c:1959
+#, c-format
+msgid "Submodule '%s' could not be updated."
+msgstr "Impossibile aggiornare il sottomodulo '%s'."
+
+#: submodule.c:2027
+#, c-format
+msgid "submodule git dir '%s' is inside git dir '%.*s'"
+msgstr ""
+"la directory Git del sottomodulo '%s' è all'interno della directory Git '%.*s'"
+
+#: submodule.c:2048
+#, c-format
+msgid ""
+"relocate_gitdir for submodule '%s' with more than one worktree not supported"
+msgstr ""
+"relocate_gitdir non è supportata per il sottomodulo '%s' con più di un "
+"albero di lavoro"
+
+#: submodule.c:2060 submodule.c:2119
+#, c-format
+msgid "could not lookup name for submodule '%s'"
+msgstr "impossibile ricercare il nome per il sottomodulo '%s'"
+
+#: submodule.c:2064
+#, c-format
+msgid "refusing to move '%s' into an existing git dir"
+msgstr "mi rifiuto di spostare '%s' in una directory Git esistente"
+
+#: submodule.c:2071
+#, c-format
+msgid ""
+"Migrating git directory of '%s%s' from\n"
+"'%s' to\n"
+"'%s'\n"
+msgstr ""
+"Sto migrando la directory Git di '%s%s' da\n"
+"'%s' a\n"
+"'%s'\n"
+
+#: submodule.c:2154
+#, c-format
+msgid "could not recurse into submodule '%s'"
+msgstr "impossibile eseguire l'azione ricorsivamente nel sottomodulo '%s'"
+
+#: submodule.c:2198
+msgid "could not start ls-files in .."
+msgstr "impossibile avviare ls-files in .."
+
+#: submodule.c:2237
+#, c-format
+msgid "ls-tree returned unexpected return code %d"
+msgstr "ls-tree ha restituito il valore di ritorno inatteso %d"
+
+#: submodule-config.c:236
+#, c-format
+msgid "ignoring suspicious submodule name: %s"
+msgstr "ignoro un nome sottomodulo sospetto: %s"
+
+#: submodule-config.c:303
+msgid "negative values not allowed for submodule.fetchjobs"
+msgstr "i valori negativi non sono consentiti per submodule.fetchjobs"
+
+#: submodule-config.c:401
+#, c-format
+msgid "ignoring '%s' which may be interpreted as a command-line option: %s"
+msgstr ""
+"ignoro '%s' che potrebbe essere interpretato come argomento della riga di "
+"comando: %s"
+
+#: submodule-config.c:498
+#, c-format
+msgid "invalid value for %s"
+msgstr "valore non valido per %s"
+
+#: submodule-config.c:769
+#, c-format
+msgid "Could not update .gitmodules entry %s"
+msgstr "Impossibile aggiornare la voce .gitmodules %s"
+
+#: trailer.c:238
+#, c-format
+msgid "running trailer command '%s' failed"
+msgstr "esecuzione del comando finale '%s' non riuscita"
+
+#: trailer.c:485 trailer.c:490 trailer.c:495 trailer.c:549 trailer.c:553
+#: trailer.c:557
+#, c-format
+msgid "unknown value '%s' for key '%s'"
+msgstr "valore '%s' sconosciuto per la chiave '%s'"
+
+#: trailer.c:539 trailer.c:544 builtin/remote.c:295
+#, c-format
+msgid "more than one %s"
+msgstr "più di un %s"
+
+#: trailer.c:730
+#, c-format
+msgid "empty trailer token in trailer '%.*s'"
+msgstr "token finale vuoto nella stringa finale '%.*s'"
+
+#: trailer.c:750
+#, c-format
+msgid "could not read input file '%s'"
+msgstr "impossibile leggere il file di input '%s'"
+
+#: trailer.c:753
+msgid "could not read from stdin"
+msgstr "impossibile leggere dallo standard input"
+
+#: trailer.c:1011 wrapper.c:665
+#, c-format
+msgid "could not stat %s"
+msgstr "impossibile eseguire lo stat di '%s'"
+
+#: trailer.c:1013
+#, c-format
+msgid "file %s is not a regular file"
+msgstr "il file %s non è un file regolare"
+
+#: trailer.c:1015
+#, c-format
+msgid "file %s is not writable by user"
+msgstr "il file %s non è scrivibile dall'utente"
+
+#: trailer.c:1027
+msgid "could not open temporary file"
+msgstr "impossibile aprire un file temporaneo"
+
+#: trailer.c:1067
+#, c-format
+msgid "could not rename temporary file to %s"
+msgstr "impossibile ridenominare il file temporaneo in %s"
+
+#: transport.c:116
+#, c-format
+msgid "Would set upstream of '%s' to '%s' of '%s'\n"
+msgstr "L'upstream di '%s' sarebbe impostato a '%s' di '%s'\n"
+
+#: transport.c:145
+#, c-format
+msgid "could not read bundle '%s'"
+msgstr "impossibile leggere il bundle '%s'"
+
+#: transport.c:214
+#, c-format
+msgid "transport: invalid depth option '%s'"
+msgstr "trasporto: opzione profondità '%s' non valida"
+
+#: transport.c:266
+msgid "see protocol.version in 'git help config' for more details"
+msgstr "vedi protocol.version in 'git help config' per maggiori dettagli"
+
+#: transport.c:267
+msgid "server options require protocol version 2 or later"
+msgstr "le opzioni server richiedono la versione 2 o successiva del protocollo"
+
+#: transport.c:632
+msgid "could not parse transport.color.* config"
+msgstr "impossibile analizzare la configurazione transport.color.*"
+
+#: transport.c:705
+msgid "support for protocol v2 not implemented yet"
+msgstr "supporto alla versione 2 del protocollo non ancora implementato"
+
+#: transport.c:831
+#, c-format
+msgid "unknown value for config '%s': %s"
+msgstr "valore sconosciuto per la configurazione '%s': %s"
+
+#: transport.c:897
+#, c-format
+msgid "transport '%s' not allowed"
+msgstr "trasporto '%s' non consentito"
+
+#: transport.c:949
+msgid "git-over-rsync is no longer supported"
+msgstr "git-over-rsync non è più supportato"
+
+#: transport.c:1044
+#, c-format
+msgid ""
+"The following submodule paths contain changes that can\n"
+"not be found on any remote:\n"
+msgstr ""
+"I seguenti percorsi sottomodulo contengono modifiche\n"
+"non trovate su nessun remoto:\n"
+
+#: transport.c:1048
+#, c-format
+msgid ""
+"\n"
+"Please try\n"
+"\n"
+"\tgit push --recurse-submodules=on-demand\n"
+"\n"
+"or cd to the path and use\n"
+"\n"
+"\tgit push\n"
+"\n"
+"to push them to a remote.\n"
+"\n"
+msgstr ""
+"\n"
+"Prova\n"
+"\n"
+"\tgit push --recurse-submodules=on-demand\n"
+"\n"
+"o esegui un cd al percorso e usa\n"
+"\n"
+"\tgit push\n"
+"\n"
+"per eseguirne il push a un remoto.\n"
+"\n"
+
+#: transport.c:1056
+msgid "Aborting."
+msgstr "Interrompo l'operazione."
+
+#: transport.c:1201
+msgid "failed to push all needed submodules"
+msgstr "push di tutti i sottomoduli richiesti non riuscito"
+
+#: transport.c:1345 transport-helper.c:656
+msgid "operation not supported by protocol"
+msgstr "operazione non supportata dal protocollo"
+
+#: transport-helper.c:61 transport-helper.c:90
+msgid "full write to remote helper failed"
+msgstr "scrittura completa verso l'helper remoto non riuscita"
+
+#: transport-helper.c:144
+#, c-format
+msgid "unable to find remote helper for '%s'"
+msgstr "impossibile trovare l'helper remoto per '%s'"
+
+#: transport-helper.c:160 transport-helper.c:570
+msgid "can't dup helper output fd"
+msgstr "impossibile duplicare il descrittore file dell'output helper"
+
+#: transport-helper.c:211
+#, c-format
+msgid ""
+"unknown mandatory capability %s; this remote helper probably needs newer "
+"version of Git"
+msgstr ""
+"capability necessaria %s sconosciuta; quest'helper remoto probabilmente "
+"richiede una versione di Git più recente"
+
+#: transport-helper.c:217
+msgid "this remote helper should implement refspec capability"
+msgstr "questo helper remoto dovrebbe implementare la capability refspec"
+
+#: transport-helper.c:284 transport-helper.c:424
+#, c-format
+msgid "%s unexpectedly said: '%s'"
+msgstr "%s ha inviato un messaggio inatteso: '%s'"
+
+#: transport-helper.c:413
+#, c-format
+msgid "%s also locked %s"
+msgstr "%s ha bloccato anche %s"
+
+#: transport-helper.c:492
+msgid "couldn't run fast-import"
+msgstr "impossibile eseguire fast-import"
+
+#: transport-helper.c:515
+msgid "error while running fast-import"
+msgstr "errore durante l'esecuzione di fast-import"
+
+#: transport-helper.c:544 transport-helper.c:1133
+#, c-format
+msgid "could not read ref %s"
+msgstr "impossibile leggere il riferimento %s"
+
+#: transport-helper.c:589
+#, c-format
+msgid "unknown response to connect: %s"
+msgstr "risposta inattesa a connect: %s"
+
+#: transport-helper.c:611
+msgid "setting remote service path not supported by protocol"
+msgstr ""
+"l'impostazione del percorso del servizio remoto non è supportata dal "
+"protocollo"
+
+#: transport-helper.c:613
+msgid "invalid remote service path"
+msgstr "percorso servizio remoto non valido"
+
+#: transport-helper.c:659
+#, c-format
+msgid "can't connect to subservice %s"
+msgstr "impossibile connettersi al sottoservizio %s"
+
+#: transport-helper.c:735
+#, c-format
+msgid "expected ok/error, helper said '%s'"
+msgstr "attesi ok/error, l'helper ha inviato '%s'"
+
+#: transport-helper.c:788
+#, c-format
+msgid "helper reported unexpected status of %s"
+msgstr "l'helper ha segnalato uno stato inatteso di %s"
+
+#: transport-helper.c:849
+#, c-format
+msgid "helper %s does not support dry-run"
+msgstr "l'helper %s non supporta dry-run"
+
+#: transport-helper.c:852
+#, c-format
+msgid "helper %s does not support --signed"
+msgstr "l'helper %s non supporta --signed"
+
+#: transport-helper.c:855
+#, c-format
+msgid "helper %s does not support --signed=if-asked"
+msgstr "l'helper %s non supporta --signed=if-asked"
+
+#: transport-helper.c:860
+#, c-format
+msgid "helper %s does not support --atomic"
+msgstr "l'helper %s non supporta --atomic"
+
+#: transport-helper.c:866
+#, c-format
+msgid "helper %s does not support 'push-option'"
+msgstr "l'helper %s non supporta 'push-option'"
+
+#: transport-helper.c:964
+msgid "remote-helper doesn't support push; refspec needed"
+msgstr ""
+"l'helper remoto non supporta il push; è necessario uno specificatore "
+"riferimento"
+
+#: transport-helper.c:969
+#, c-format
+msgid "helper %s does not support 'force'"
+msgstr "l'helper %s non supporta 'force'"
+
+#: transport-helper.c:1016
+msgid "couldn't run fast-export"
+msgstr "impossibile eseguire fast-export"
+
+#: transport-helper.c:1021
+msgid "error while running fast-export"
+msgstr "errore durante l'esecuzione di fast-export"
+
+#: transport-helper.c:1046
+#, c-format
+msgid ""
+"No refs in common and none specified; doing nothing.\n"
+"Perhaps you should specify a branch such as 'master'.\n"
+msgstr ""
+"Nessun riferimento in comune e nessuno specificato; non eseguo nulla.\n"
+"Forse dovresti specificare un branch come 'master'.\n"
+
+#: transport-helper.c:1119
+#, c-format
+msgid "malformed response in ref list: %s"
+msgstr "risposta malformata nell'elenco riferimenti: %s"
+
+#: transport-helper.c:1271
+#, c-format
+msgid "read(%s) failed"
+msgstr "read(%s) non riuscita"
+
+#: transport-helper.c:1298
+#, c-format
+msgid "write(%s) failed"
+msgstr "write(%s) non riuscita"
+
+#: transport-helper.c:1347
+#, c-format
+msgid "%s thread failed"
+msgstr "thread %s non riuscito"
+
+#: transport-helper.c:1351
+#, c-format
+msgid "%s thread failed to join: %s"
+msgstr "join non riuscita per il thread %s: %s"
+
+#: transport-helper.c:1370 transport-helper.c:1374
+#, c-format
+msgid "can't start thread for copying data: %s"
+msgstr "impossibile avviare il thread per la copia dei dati: %s"
+
+#: transport-helper.c:1411
+#, c-format
+msgid "%s process failed to wait"
+msgstr "wait non riuscita per il processo %s"
+
+#: transport-helper.c:1415
+#, c-format
+msgid "%s process failed"
+msgstr "processo %s non riuscito"
+
+#: transport-helper.c:1433 transport-helper.c:1442
+msgid "can't start thread for copying data"
+msgstr "impossibile avviare il thread per la copia dei dati"
+
+#: tree-walk.c:33
+msgid "too-short tree object"
+msgstr "oggetto albero troppo corto"
+
+#: tree-walk.c:39
+msgid "malformed mode in tree entry"
+msgstr "modo malformato nella voce dell'albero"
+
+#: tree-walk.c:43
+msgid "empty filename in tree entry"
+msgstr "nome file vuoto nella voce dell'albero"
+
+#: tree-walk.c:48
+#, c-format
+msgid "filename in tree entry contains backslash: '%s'"
+msgstr "il nome file nella voce albero contiene una barra rovesciata: '%s'"
+
+#: tree-walk.c:124
+msgid "too-short tree file"
+msgstr "file alber troppo corto"
+
+#: unpack-trees.c:110
+#, c-format
+msgid ""
+"Your local changes to the following files would be overwritten by checkout:\n"
+"%%sPlease commit your changes or stash them before you switch branches."
+msgstr ""
+"Le tue modifiche locali ai seguenti file sarebbero sovrascritte con il "
+"checkout:\n"
+"%%sEsegui il commit o lo stash delle modifiche prima di cambiare branch."
+
+#: unpack-trees.c:112
+#, c-format
+msgid ""
+"Your local changes to the following files would be overwritten by checkout:\n"
+"%%s"
+msgstr ""
+"Le tue modifiche locali ai seguenti file sarebbero sovrascritte con il "
+"checkout:\n"
+"%%s"
+
+#: unpack-trees.c:115
+#, c-format
+msgid ""
+"Your local changes to the following files would be overwritten by merge:\n"
+"%%sPlease commit your changes or stash them before you merge."
+msgstr ""
+"Le tue modifiche locali ai seguenti file sarebbero sovrascritte con il "
+"merge:\n"
+"%%sEsegui il commit o lo stash delle modifiche prima di eseguire il merge."
+
+#: unpack-trees.c:117
+#, c-format
+msgid ""
+"Your local changes to the following files would be overwritten by merge:\n"
+"%%s"
+msgstr ""
+"Le tue modifiche locali ai seguenti file sarebbero sovrascritte con il "
+"merge:\n"
+"%%s"
+
+#: unpack-trees.c:120
+#, c-format
+msgid ""
+"Your local changes to the following files would be overwritten by %s:\n"
+"%%sPlease commit your changes or stash them before you %s."
+msgstr ""
+"Le tue modifiche locali ai seguenti file sarebbero sovrascritte con "
+"l'operazione di %s:\n"
+"%%sEsegui il commit o lo stash delle modifiche prima di eseguire "
+"l'operazione di %s."
+
+#: unpack-trees.c:122
+#, c-format
+msgid ""
+"Your local changes to the following files would be overwritten by %s:\n"
+"%%s"
+msgstr ""
+"Le tue modifiche locali ai seguenti file sarebbero sovrascritte con "
+"l'operazione di %s:\n"
+"%%s"
+
+#: unpack-trees.c:127
+#, c-format
+msgid ""
+"Updating the following directories would lose untracked files in them:\n"
+"%s"
+msgstr ""
+"L'aggiornamento delle seguenti directory farebbe sì che dei file non "
+"tracciati in esse contenuti vengano persi:\n"
+"%s"
+
+#: unpack-trees.c:131
+#, c-format
+msgid ""
+"The following untracked working tree files would be removed by checkout:\n"
+"%%sPlease move or remove them before you switch branches."
+msgstr ""
+"I seguenti file non tracciati presenti nell'albero di lavoro sarebbero "
+"eliminati con il checkout:\n"
+"%%sSpostali o eliminali prima di cambiare branch."
+
+#: unpack-trees.c:133
+#, c-format
+msgid ""
+"The following untracked working tree files would be removed by checkout:\n"
+"%%s"
+msgstr ""
+"I seguenti file non tracciati presenti nell'albero di lavoro sarebbero "
+"eliminati con il checkout:\n"
+"%%s"
+
+#: unpack-trees.c:136
+#, c-format
+msgid ""
+"The following untracked working tree files would be removed by merge:\n"
+"%%sPlease move or remove them before you merge."
+msgstr ""
+"I seguenti file non tracciati presenti nell'albero di lavoro sarebbero "
+"eliminati dal merge:\n"
+"%%sSpostali o eliminali prima di eseguire il merge."
+
+#: unpack-trees.c:138
+#, c-format
+msgid ""
+"The following untracked working tree files would be removed by merge:\n"
+"%%s"
+msgstr ""
+"I seguenti file non tracciati presenti nell'albero di lavoro sarebbero "
+"eliminati dal merge:\n"
+"%%s"
+
+#: unpack-trees.c:141
+#, c-format
+msgid ""
+"The following untracked working tree files would be removed by %s:\n"
+"%%sPlease move or remove them before you %s."
+msgstr ""
+"I seguenti file non tracciati presenti nell'albero di lavoro sarebbero "
+"eliminati con l'operazione di %s:\n"
+"%%sSpostali o eliminali prima di eseguire l'operazione di %s."
+
+#: unpack-trees.c:143
+#, c-format
+msgid ""
+"The following untracked working tree files would be removed by %s:\n"
+"%%s"
+msgstr ""
+"I seguenti file non tracciati presenti nell'albero di lavoro sarebbero "
+"eliminati con l'operazione di %s:\n"
+"%%s"
+
+#: unpack-trees.c:149
+#, c-format
+msgid ""
+"The following untracked working tree files would be overwritten by "
+"checkout:\n"
+"%%sPlease move or remove them before you switch branches."
+msgstr ""
+"I seguenti file non tracciati presenti nell'albero di lavoro sarebbero "
+"sovrascritti con il checkout:\n"
+"%%sSpostali o eliminali prima di cambiare branch."
+
+#: unpack-trees.c:151
+#, c-format
+msgid ""
+"The following untracked working tree files would be overwritten by "
+"checkout:\n"
+"%%s"
+msgstr ""
+"I seguenti file non tracciati presenti nell'albero di lavoro sarebbero "
+"sovrascritti con il checkout:\n"
+"%%s"
+
+#: unpack-trees.c:154
+#, c-format
+msgid ""
+"The following untracked working tree files would be overwritten by merge:\n"
+"%%sPlease move or remove them before you merge."
+msgstr ""
+"I seguenti file non tracciati presenti nell'albero di lavoro sarebbero "
+"sovrascritti dal merge:\n"
+"%%sSpostali o eliminali prima di eseguire il merge."
+
+#: unpack-trees.c:156
+#, c-format
+msgid ""
+"The following untracked working tree files would be overwritten by merge:\n"
+"%%s"
+msgstr ""
+"I seguenti file non tracciati presenti nell'albero di lavoro sarebbero "
+"sovrascritti dal merge:\n"
+"%%s"
+
+#: unpack-trees.c:159
+#, c-format
+msgid ""
+"The following untracked working tree files would be overwritten by %s:\n"
+"%%sPlease move or remove them before you %s."
+msgstr ""
+"I seguenti file non tracciati presenti nell'albero di lavoro sarebbero "
+"sovrascritti con l'operazione di %s:\n"
+"%%sSpostali o eliminali prima di eseguire l'operazione di %s."
+
+#: unpack-trees.c:161
+#, c-format
+msgid ""
+"The following untracked working tree files would be overwritten by %s:\n"
+"%%s"
+msgstr ""
+"I seguenti file non tracciati presenti nell'albero di lavoro sarebbero "
+"sovrascritti con l'operazione di %s:\n"
+"%%s"
+
+#: unpack-trees.c:169
+#, c-format
+msgid "Entry '%s' overlaps with '%s'.  Cannot bind."
+msgstr ""
+"La voce '%s' si sovrappone a '%s'. Impossibile eseguire il collegamento."
+
+#: unpack-trees.c:172
+#, c-format
+msgid ""
+"Cannot update sparse checkout: the following entries are not up to date:\n"
+"%s"
+msgstr ""
+"Impossibile aggiornare il checkout sparse: le seguenti voci non sono "
+"aggiornate:\n"
+"%s"
+
+#: unpack-trees.c:174
+#, c-format
+msgid ""
+"The following working tree files would be overwritten by sparse checkout "
+"update:\n"
+"%s"
+msgstr ""
+"I seguenti file dell'albero di lavoro sarebbero sovrascritti con "
+"l'aggiornamento del checkout sparse:\n"
+"%s"
+
+#: unpack-trees.c:176
+#, c-format
+msgid ""
+"The following working tree files would be removed by sparse checkout "
+"update:\n"
+"%s"
+msgstr ""
+"I seguenti file dell'albero di lavoro sarebbero eliminati con "
+"l'aggiornamento del checkout sparse:\n"
+"%s"
+
+#: unpack-trees.c:178
+#, c-format
+msgid ""
+"Cannot update submodule:\n"
+"%s"
+msgstr ""
+"Impossibile aggiornare il sottomodulo:\n"
+"%s"
+
+#: unpack-trees.c:255
+#, c-format
+msgid "Aborting\n"
+msgstr "Interrompo l'operazione\n"
+
+#: unpack-trees.c:317
+msgid "Updating files"
+msgstr "Aggiornamento dei file in corso"
+
+#: unpack-trees.c:349
+msgid ""
+"the following paths have collided (e.g. case-sensitive paths\n"
+"on a case-insensitive filesystem) and only one from the same\n"
+"colliding group is in the working tree:\n"
+msgstr ""
+"i seguenti percorsi sono entrati in conflitto (ad es. se ci\n"
+"sono percorsi che differiscono solo per le maiuscole/minuscole\n"
+"su un filesystem non sensibile a tale differenza) e solo uno\n"
+"per gruppo in conflitto è nell'albero di lavoro:\n"
+
+#: unpack-trees.c:1441
+msgid "Updating index flags"
+msgstr "Aggiornamento dei contrassegni indice in corso"
+
+#: urlmatch.c:163
+msgid "invalid URL scheme name or missing '://' suffix"
+msgstr "nome schema URL non valido o suffisso '://' mancante"
+
+#: urlmatch.c:187 urlmatch.c:346 urlmatch.c:405
+#, c-format
+msgid "invalid %XX escape sequence"
+msgstr "sequenza di escape %XX non valida"
+
+#: urlmatch.c:215
+msgid "missing host and scheme is not 'file:'"
+msgstr "host mancante e lo schema non è 'file:'"
+
+#: urlmatch.c:232
+msgid "a 'file:' URL may not have a port number"
+msgstr "un URL 'file:' non può avere un numero di porta"
+
+#: urlmatch.c:247
+msgid "invalid characters in host name"
+msgstr "caratteri non validi nel nome host"
+
+#: urlmatch.c:292 urlmatch.c:303
+msgid "invalid port number"
+msgstr "numero di porta non valido"
+
+#: urlmatch.c:371
+msgid "invalid '..' path segment"
+msgstr "parte percorso '..' non valida"
+
+#: worktree.c:258 builtin/am.c:2084
+#, c-format
+msgid "failed to read '%s'"
+msgstr "lettura di '%s' non riuscita"
+
+#: worktree.c:304
+#, c-format
+msgid "'%s' at main working tree is not the repository directory"
+msgstr ""
+"'%s' nell'albero di lavoro principale non è la directory del repository"
+
+#: worktree.c:315
+#, c-format
+msgid "'%s' file does not contain absolute path to the working tree location"
+msgstr ""
+"il file '%s' non contiene il percorso assoluto alla posizione dell'albero di "
+"lavoro"
+
+#: worktree.c:327
+#, c-format
+msgid "'%s' does not exist"
+msgstr "'%s' non esiste"
+
+#: worktree.c:333
+#, c-format
+msgid "'%s' is not a .git file, error code %d"
+msgstr "'%s' non è un file .git, codice d'errore %d"
+
+#: worktree.c:341
+#, c-format
+msgid "'%s' does not point back to '%s'"
+msgstr "'%s' non punta a '%s'"
+
+#: wrapper.c:186 wrapper.c:356
+#, c-format
+msgid "could not open '%s' for reading and writing"
+msgstr "impossibile aprire '%s' in lettura e scrittura"
+
+#: wrapper.c:387 wrapper.c:588
+#, c-format
+msgid "unable to access '%s'"
+msgstr "impossibile accedere a '%s'"
+
+#: wrapper.c:596
+msgid "unable to get current working directory"
+msgstr "impossibile ottenere la directory di lavoro corrente"
+
+#: wt-status.c:158
+msgid "Unmerged paths:"
+msgstr "Percorsi non sottoposti a merge:"
+
+#: wt-status.c:187 wt-status.c:219
+msgid "  (use \"git restore --staged <file>...\" to unstage)"
+msgstr ""
+"  (usa \"git restore --staged <file>...\" per rimuovere gli elementi "
+"dall'area di staging)"
+
+#: wt-status.c:190 wt-status.c:222
+#, c-format
+msgid "  (use \"git restore --source=%s --staged <file>...\" to unstage)"
+msgstr ""
+"  (usa \"git restore --source=%s --staged <file>...\" per rimuovere gli "
+"elementi dall'area di staging)"
+
+#: wt-status.c:193 wt-status.c:225
+msgid "  (use \"git rm --cached <file>...\" to unstage)"
+msgstr ""
+"  (usa \"git rm --cached <file>...\" per rimuovere gli elementi dall'area di "
+"staging)"
+
+#: wt-status.c:197
+msgid "  (use \"git add <file>...\" to mark resolution)"
+msgstr ""
+"  (usa \"git add <file>...\" per contrassegnare il conflitto come risolto)"
+
+#: wt-status.c:199 wt-status.c:203
+msgid "  (use \"git add/rm <file>...\" as appropriate to mark resolution)"
+msgstr ""
+"  (usa \"git add/rm <file>...\" come appropriato per contrassegnare il "
+"conflitto come risolto)"
+
+#: wt-status.c:201
+msgid "  (use \"git rm <file>...\" to mark resolution)"
+msgstr ""
+"  (usa \"git rm <file>...\" per contrassegnare il conflitto come risolto)"
+
+#: wt-status.c:211 wt-status.c:1074
+msgid "Changes to be committed:"
+msgstr "Modifiche di cui verrà eseguito il commit:"
+
+#: wt-status.c:234 wt-status.c:1083
+msgid "Changes not staged for commit:"
+msgstr "Modifiche non nell'area di staging per il commit:"
+
+#: wt-status.c:238
+msgid "  (use \"git add <file>...\" to update what will be committed)"
+msgstr ""
+"  (usa \"git add <file>...\" per aggiornare gli elementi di cui sarà "
+"eseguito il commit)"
+
+#: wt-status.c:240
+msgid "  (use \"git add/rm <file>...\" to update what will be committed)"
+msgstr ""
+"  (usa \"git add/rm <file>...\" per aggiornare gli elementi di cui sarà "
+"eseguito il commit)"
+
+#: wt-status.c:241
+msgid ""
+"  (use \"git restore <file>...\" to discard changes in working directory)"
+msgstr ""
+"  (usa \"git restore <file>...\" per scartare le modifiche nella directory "
+"di lavoro)"
+
+#: wt-status.c:243
+msgid "  (commit or discard the untracked or modified content in submodules)"
+msgstr ""
+"  (esegui il commit o scarta il contenuto non tracciato o modificato nei "
+"sottomoduli)"
+
+#: wt-status.c:254
+#, c-format
+msgid "  (use \"git %s <file>...\" to include in what will be committed)"
+msgstr ""
+"  (usa \"git %s <file>...\" per includere l'elemento fra quelli di cui verrà "
+"eseguito il commit)"
+
+#: wt-status.c:268
+msgid "both deleted:"
+msgstr "entrambi eliminati:"
+
+#: wt-status.c:270
+msgid "added by us:"
+msgstr "aggiunto da noi:"
+
+#: wt-status.c:272
+msgid "deleted by them:"
+msgstr "eliminato da loro:"
+
+#: wt-status.c:274
+msgid "added by them:"
+msgstr "aggiunto da loro:"
+
+#: wt-status.c:276
+msgid "deleted by us:"
+msgstr "eliminato da noi:"
+
+#: wt-status.c:278
+msgid "both added:"
+msgstr "entrambi aggiunti:"
+
+#: wt-status.c:280
+msgid "both modified:"
+msgstr "entrambi modificati:"
+
+#: wt-status.c:290
+msgid "new file:"
+msgstr "nuovo file:"
+
+#: wt-status.c:292
+msgid "copied:"
+msgstr "copiato:"
+
+#: wt-status.c:294
+msgid "deleted:"
+msgstr "eliminato:"
+
+#: wt-status.c:296
+msgid "modified:"
+msgstr "modificato:"
+
+#: wt-status.c:298
+msgid "renamed:"
+msgstr "rinominato:"
+
+#: wt-status.c:300
+msgid "typechange:"
+msgstr "modifica tipo:"
+
+#: wt-status.c:302
+msgid "unknown:"
+msgstr "sconosciuto:"
+
+#: wt-status.c:304
+msgid "unmerged:"
+msgstr "non sottoposto a merge:"
+
+#: wt-status.c:384
+msgid "new commits, "
+msgstr "nuovi commit, "
+
+#: wt-status.c:386
+msgid "modified content, "
+msgstr "contenuto modificato, "
+
+#: wt-status.c:388
+msgid "untracked content, "
+msgstr "contenuto non tracciato, "
+
+#: wt-status.c:906
+#, c-format
+msgid "Your stash currently has %d entry"
+msgid_plural "Your stash currently has %d entries"
+msgstr[0] "Lo stash attualmente ha %d voce"
+msgstr[1] "Lo stash attualmente ha %d voci"
+
+#: wt-status.c:938
+msgid "Submodules changed but not updated:"
+msgstr "Sottomoduli modificati ma non aggiornati:"
+
+#: wt-status.c:940
+msgid "Submodule changes to be committed:"
+msgstr "Modifiche ai sottomoduli di cui verrà eseguito il commit:"
+
+#: wt-status.c:1022
+msgid ""
+"Do not modify or remove the line above.\n"
+"Everything below it will be ignored."
+msgstr ""
+"Non modificare o rimuovere la riga soprastante.\n"
+"Tutto ciò che si trova al di sotto di essa sarà ignorato."
+
+#: wt-status.c:1114
+#, c-format
+msgid ""
+"\n"
+"It took %.2f seconds to compute the branch ahead/behind values.\n"
+"You can use '--no-ahead-behind' to avoid this.\n"
+msgstr ""
+"\n"
+"Sono stati necessari %.2f secondi per calcolare il numero di commit\n"
+"precedenti/successivi nel branch.\n"
+"Puoi usare '--no-ahead-behind' per evitare il calcolo.\n"
+
+#: wt-status.c:1144
+msgid "You have unmerged paths."
+msgstr "Hai dei percorsi non sottoposti a merge."
+
+#: wt-status.c:1147
+msgid "  (fix conflicts and run \"git commit\")"
+msgstr "  (risolvi i conflitti ed esegui \"git commit\")"
+
+#: wt-status.c:1149
+msgid "  (use \"git merge --abort\" to abort the merge)"
+msgstr "  (usa \"git merge --abort\" per interrompere il merge)"
+
+#: wt-status.c:1153
+msgid "All conflicts fixed but you are still merging."
+msgstr "Tutti i conflitti sono stati risolti ma il merge è ancora in corso."
+
+#: wt-status.c:1156
+msgid "  (use \"git commit\" to conclude merge)"
+msgstr "  (usa \"git commit\" per terminare il merge)"
+
+#: wt-status.c:1165
+msgid "You are in the middle of an am session."
+msgstr "Sei nel bel mezzo di una sessione am."
+
+#: wt-status.c:1168
+msgid "The current patch is empty."
+msgstr "La patch corrente è vuota."
+
+#: wt-status.c:1172
+msgid "  (fix conflicts and then run \"git am --continue\")"
+msgstr "  (risolvi i conflitti e quindi esegui \"git am --continue\")"
+
+#: wt-status.c:1174
+msgid "  (use \"git am --skip\" to skip this patch)"
+msgstr "  (usa \"git am --skip\" per saltare questa patch)"
+
+#: wt-status.c:1176
+msgid "  (use \"git am --abort\" to restore the original branch)"
+msgstr "  (usa \"git am --abort\" per ripristinare il branch originario)"
+
+#: wt-status.c:1309
+msgid "git-rebase-todo is missing."
+msgstr "git-rebase-todo è mancante."
+
+#: wt-status.c:1311
+msgid "No commands done."
+msgstr "Nessun comando eseguito."
+
+#: wt-status.c:1314
+#, c-format
+msgid "Last command done (%d command done):"
+msgid_plural "Last commands done (%d commands done):"
+msgstr[0] "Ultimo comando eseguito (%d comando eseguito):"
+msgstr[1] "Ultimi comandi eseguiti (%d comandi eseguiti):"
+
+#: wt-status.c:1325
+#, c-format
+msgid "  (see more in file %s)"
+msgstr "  (vedi di più nel file %s)"
+
+#: wt-status.c:1330
+msgid "No commands remaining."
+msgstr "Nessun comando rimanente."
+
+#: wt-status.c:1333
+#, c-format
+msgid "Next command to do (%d remaining command):"
+msgid_plural "Next commands to do (%d remaining commands):"
+msgstr[0] "Prossimo comando da eseguire (%d comando rimanente):"
+msgstr[1] "Prossimi comandi da eseguire (%d comandi rimanenti):"
+
+#: wt-status.c:1341
+msgid "  (use \"git rebase --edit-todo\" to view and edit)"
+msgstr ""
+"  (usa \"git rebase --edit-todo\" per visualizzare e modificare le "
+"operazioni)"
+
+#: wt-status.c:1353
+#, c-format
+msgid "You are currently rebasing branch '%s' on '%s'."
+msgstr "Attualmente stai eseguendo il rebase del branch '%s' su '%s'."
+
+#: wt-status.c:1358
+msgid "You are currently rebasing."
+msgstr "Attualmente stai eseguendo un rebase."
+
+#: wt-status.c:1371
+msgid "  (fix conflicts and then run \"git rebase --continue\")"
+msgstr "  (risolvi i conflitti e quindi esegui \"git rebase --continue\")"
+
+#: wt-status.c:1373
+msgid "  (use \"git rebase --skip\" to skip this patch)"
+msgstr "  (usa \"git rebase --skip\" per saltare questa patch)"
+
+#: wt-status.c:1375
+msgid "  (use \"git rebase --abort\" to check out the original branch)"
+msgstr ""
+"  (usa \"git rebase --abort\" per eseguire il checkout del branch originario)"
+
+#: wt-status.c:1382
+msgid "  (all conflicts fixed: run \"git rebase --continue\")"
+msgstr ""
+"  (tutti i conflitti sono stati risolti: esegui \"git rebase --continue\")"
+
+#: wt-status.c:1386
+#, c-format
+msgid ""
+"You are currently splitting a commit while rebasing branch '%s' on '%s'."
+msgstr ""
+"Attualmente stai dividendo un commit durante il rebase del branch '%s' su "
+"'%s'."
+
+#: wt-status.c:1391
+msgid "You are currently splitting a commit during a rebase."
+msgstr "Attualmente stai dividendo un commit durante un rebase."
+
+#: wt-status.c:1394
+msgid "  (Once your working directory is clean, run \"git rebase --continue\")"
+msgstr ""
+"  (Una volta che la tua directory di lavoro è pulita, esegui \"git rebase --"
+"continue\")"
+
+#: wt-status.c:1398
+#, c-format
+msgid "You are currently editing a commit while rebasing branch '%s' on '%s'."
+msgstr ""
+"Attualmente stai modificando un commit durante il rebase del branch '%s' su "
+"'%s'."
+
+#: wt-status.c:1403
+msgid "You are currently editing a commit during a rebase."
+msgstr "Attualmente stai modificando un commit durante un rebase."
+
+#: wt-status.c:1406
+msgid "  (use \"git commit --amend\" to amend the current commit)"
+msgstr "  (usa \"git commit --amend\" per correggere il commit corrente)"
+
+#: wt-status.c:1408
+msgid ""
+"  (use \"git rebase --continue\" once you are satisfied with your changes)"
+msgstr ""
+"  (usa \"git rebase --continue\" una volta soddisfatto delle tue modifiche)"
+
+#: wt-status.c:1419
+msgid "Cherry-pick currently in progress."
+msgstr "Cherry-pick in corso."
+
+#: wt-status.c:1422
+#, c-format
+msgid "You are currently cherry-picking commit %s."
+msgstr "Attualmente stai eseguendo il cherry-pick del commit %s."
+
+#: wt-status.c:1429
+msgid "  (fix conflicts and run \"git cherry-pick --continue\")"
+msgstr "  (risolvi i conflitti ed esegui \"git cherry-pick --continue\")"
+
+#: wt-status.c:1432
+msgid "  (run \"git cherry-pick --continue\" to continue)"
+msgstr "  (esegui \"git cherry-pick --continue\" per continuare)"
+
+#: wt-status.c:1435
+msgid "  (all conflicts fixed: run \"git cherry-pick --continue\")"
+msgstr ""
+"  (tutti i conflitti sono stati risolti: esegui \"git cherry-pick --continue"
+"\")"
+
+#: wt-status.c:1437
+msgid "  (use \"git cherry-pick --skip\" to skip this patch)"
+msgstr "  (usa \"git cherry-pick --skip\" per saltare questa patch)"
+
+#: wt-status.c:1439
+msgid "  (use \"git cherry-pick --abort\" to cancel the cherry-pick operation)"
+msgstr ""
+"  (usa \"git cherry-pick --abort\" per annullare l'operazione di cherry-pick)"
+
+#: wt-status.c:1449
+msgid "Revert currently in progress."
+msgstr "Revert in corso."
+
+#: wt-status.c:1452
+#, c-format
+msgid "You are currently reverting commit %s."
+msgstr "Attualmente stai eseguendo il revert del commit %s."
+
+#: wt-status.c:1458
+msgid "  (fix conflicts and run \"git revert --continue\")"
+msgstr "  (risolvi i conflitti ed esegui \"git revert --continue\")"
+
+#: wt-status.c:1461
+msgid "  (run \"git revert --continue\" to continue)"
+msgstr "  (esegui \"git revert --continue\" per continuare)"
+
+#: wt-status.c:1464
+msgid "  (all conflicts fixed: run \"git revert --continue\")"
+msgstr ""
+"  (tutti i conflitti sono stati risolti: esegui \"git revert --continue\")"
+
+#: wt-status.c:1466
+msgid "  (use \"git revert --skip\" to skip this patch)"
+msgstr "  (usa \"git revert --skip\" per saltare questa patch)"
+
+#: wt-status.c:1468
+msgid "  (use \"git revert --abort\" to cancel the revert operation)"
+msgstr "  (usa \"git revert --abort\" per annullare l'operazione di revert)"
+
+#: wt-status.c:1478
+#, c-format
+msgid "You are currently bisecting, started from branch '%s'."
+msgstr "Attualmente stai eseguendo una bisezione partendo dal branch '%s'."
+
+#: wt-status.c:1482
+msgid "You are currently bisecting."
+msgstr "Attualmente stai eseguendo una bisezione."
+
+#: wt-status.c:1485
+msgid "  (use \"git bisect reset\" to get back to the original branch)"
+msgstr "  (usa \"git bisect reset\" per tornare al branch originario)"
+
+#: wt-status.c:1694
+msgid "On branch "
+msgstr "Sul branch "
+
+#: wt-status.c:1701
+msgid "interactive rebase in progress; onto "
+msgstr "rebase interattivo in corso su "
+
+#: wt-status.c:1703
+msgid "rebase in progress; onto "
+msgstr "rebase in corso su "
+
+#: wt-status.c:1713
+msgid "Not currently on any branch."
+msgstr "Attualmente non sei su alcun branch."
+
+#: wt-status.c:1730
+msgid "Initial commit"
+msgstr "Commit iniziale"
+
+#: wt-status.c:1731
+msgid "No commits yet"
+msgstr "Non ci sono ancora commit"
+
+#: wt-status.c:1745
+msgid "Untracked files"
+msgstr "File non tracciati"
+
+#: wt-status.c:1747
+msgid "Ignored files"
+msgstr "File ignorati"
+
+#: wt-status.c:1751
+#, c-format
+msgid ""
+"It took %.2f seconds to enumerate untracked files. 'status -uno'\n"
+"may speed it up, but you have to be careful not to forget to add\n"
+"new files yourself (see 'git help status')."
+msgstr ""
+"Sono stati necessari %.2f secondi per elencare i file non\n"
+"tracciati. 'status -uno' potrebbe velocizzare tale operazione,\n"
+"ma devi stare attento a non dimenticarti di aggiungere\n"
+"autonomamente i file nuovi (vedi 'git help status')."
+
+#: wt-status.c:1757
+#, c-format
+msgid "Untracked files not listed%s"
+msgstr "File non tracciati non elencati%s"
+
+#: wt-status.c:1759
+msgid " (use -u option to show untracked files)"
+msgstr " (usa l'opzione -u per visualizzare i file non tracciati)"
+
+#: wt-status.c:1765
+msgid "No changes"
+msgstr "Nessuna modifica"
+
+#: wt-status.c:1770
+#, c-format
+msgid "no changes added to commit (use \"git add\" and/or \"git commit -a\")\n"
+msgstr ""
+"nessuna modifica aggiunta al commit (usa \"git add\" e/o \"git commit -a\")\n"
+
+#: wt-status.c:1773
+#, c-format
+msgid "no changes added to commit\n"
+msgstr "nessuna modifica aggiunta al commit\n"
+
+#: wt-status.c:1776
+#, c-format
+msgid ""
+"nothing added to commit but untracked files present (use \"git add\" to "
+"track)\n"
+msgstr ""
+"non è stato aggiunto nulla al commit ma sono presenti file non tracciati "
+"(usa \"git add\" per tracciarli)\n"
+
+#: wt-status.c:1779
+#, c-format
+msgid "nothing added to commit but untracked files present\n"
+msgstr ""
+"non è stato aggiunto nulla al commit ma sono presenti file non tracciati\n"
+
+#: wt-status.c:1782
+#, c-format
+msgid "nothing to commit (create/copy files and use \"git add\" to track)\n"
+msgstr ""
+"non c'è nulla di cui eseguire il commit (crea/copia dei file e usa \"git add"
+"\" per tracciarli)\n"
+
+#: wt-status.c:1785 wt-status.c:1790
+#, c-format
+msgid "nothing to commit\n"
+msgstr "non c'è nulla di cui eseguire il commit\n"
+
+#: wt-status.c:1788
+#, c-format
+msgid "nothing to commit (use -u to show untracked files)\n"
+msgstr ""
+"non c'è nulla di cui eseguire il commit (usa -u per visualizzare i file non "
+"tracciati)\n"
+
+#: wt-status.c:1792
+#, c-format
+msgid "nothing to commit, working tree clean\n"
+msgstr "non c'è nulla di cui eseguire il commit, l'albero di lavoro è pulito\n"
+
+#: wt-status.c:1905
+msgid "No commits yet on "
+msgstr "Non ci sono ancora commit su"
+
+#: wt-status.c:1909
+msgid "HEAD (no branch)"
+msgstr "HEAD (nessun branch)"
+
+#: wt-status.c:1940
+msgid "different"
+msgstr "differente"
+
+#: wt-status.c:1942 wt-status.c:1950
+msgid "behind "
+msgstr "indietro "
+
+#: wt-status.c:1945 wt-status.c:1948
+msgid "ahead "
+msgstr "avanti "
+
+#. TRANSLATORS: the action is e.g. "pull with rebase"
+#: wt-status.c:2470
+#, c-format
+msgid "cannot %s: You have unstaged changes."
+msgstr "impossibile eseguire %s: ci sono delle modifiche non in staging."
+
+#: wt-status.c:2476
+msgid "additionally, your index contains uncommitted changes."
+msgstr ""
+"inoltre, l'indice contiene modifiche di cui non è stato eseguito il commit."
+
+#: wt-status.c:2478
+#, c-format
+msgid "cannot %s: Your index contains uncommitted changes."
+msgstr ""
+"impossibile eseguire %s: l'indice contiene modifiche di cui non è stato "
+"eseguito il commit."
+
+#: compat/precompose_utf8.c:58 builtin/clone.c:455
+#, c-format
+msgid "failed to unlink '%s'"
+msgstr "unlink di '%s' non riuscito"
+
+#: builtin/add.c:26
+msgid "git add [<options>] [--] <pathspec>..."
+msgstr "git add [<opzioni>] [--] <specificatore percorso>..."
+
+#: builtin/add.c:87
+#, c-format
+msgid "unexpected diff status %c"
+msgstr "stato diff inatteso %c"
+
+#: builtin/add.c:92 builtin/commit.c:288
+msgid "updating files failed"
+msgstr "aggiornamento dei file non riuscito"
+
+#: builtin/add.c:102
+#, c-format
+msgid "remove '%s'\n"
+msgstr "elimina '%s'\n"
+
+#: builtin/add.c:177
+msgid "Unstaged changes after refreshing the index:"
+msgstr "Modifiche non nell'area di staging dopo l'aggiornamento dell'indice:"
+
+#: builtin/add.c:252 builtin/rev-parse.c:899
+msgid "Could not read the index"
+msgstr "Impossibile leggere l'indice"
+
+#: builtin/add.c:263
+#, c-format
+msgid "Could not open '%s' for writing."
+msgstr "Impossibile aprire '%s' in scrittura."
+
+#: builtin/add.c:267
+msgid "Could not write patch"
+msgstr "Impossibile scrivere la patch"
+
+#: builtin/add.c:270
+msgid "editing patch failed"
+msgstr "modifica della patch non riuscita"
+
+#: builtin/add.c:273
+#, c-format
+msgid "Could not stat '%s'"
+msgstr "Impossibile eseguire lo stat di '%s'"
+
+#: builtin/add.c:275
+msgid "Empty patch. Aborted."
+msgstr "Patch vuota. Operazione interrotta."
+
+#: builtin/add.c:280
+#, c-format
+msgid "Could not apply '%s'"
+msgstr "Impossibile applicare '%s'"
+
+#: builtin/add.c:288
+msgid "The following paths are ignored by one of your .gitignore files:\n"
+msgstr "I seguenti percorsi sono ignorati da uno dei file .gitignore:\n"
+
+#: builtin/add.c:308 builtin/clean.c:910 builtin/fetch.c:163 builtin/mv.c:124
+#: builtin/prune-packed.c:56 builtin/pull.c:223 builtin/push.c:548
+#: builtin/remote.c:1344 builtin/rm.c:241 builtin/send-pack.c:165
+msgid "dry run"
+msgstr "test controllato"
+
+#: builtin/add.c:311
+msgid "interactive picking"
+msgstr "scelta interattiva"
+
+#: builtin/add.c:312 builtin/checkout.c:1482 builtin/reset.c:307
+msgid "select hunks interactively"
+msgstr "seleziona gli hunk in modalità interattiva"
+
+#: builtin/add.c:313
+msgid "edit current diff and apply"
+msgstr "modifica il diff corrente e applicalo"
+
+#: builtin/add.c:314
+msgid "allow adding otherwise ignored files"
+msgstr "consenti l'aggiunta di file altrimenti ignorati"
+
+#: builtin/add.c:315
+msgid "update tracked files"
+msgstr "aggiorna i file tracciati"
+
+#: builtin/add.c:316
+msgid "renormalize EOL of tracked files (implies -u)"
+msgstr "rinormalizza i fine riga dei file tracciati (implica -u)"
+
+#: builtin/add.c:317
+msgid "record only the fact that the path will be added later"
+msgstr "salva solo il fatto che il percorso sarà aggiunto successivamente"
+
+#: builtin/add.c:318
+msgid "add changes from all tracked and untracked files"
+msgstr "aggiungi le modifiche da tutti i file tracciati e non"
+
+#: builtin/add.c:321
+msgid "ignore paths removed in the working tree (same as --no-all)"
+msgstr "ignora i percorsi eliminati nell'albero di lavoro (come --no-all)"
+
+#: builtin/add.c:323
+msgid "don't add, only refresh the index"
+msgstr "non eseguire l'aggiunta, aggiorna solo l'indice"
+
+#: builtin/add.c:324
+msgid "just skip files which cannot be added because of errors"
+msgstr ""
+"salta semplicemente i file che non possono essere aggiunti a causa di errori"
+
+#: builtin/add.c:325
+msgid "check if - even missing - files are ignored in dry run"
+msgstr ""
+"controlla se i file - anche quelli mancanti - sono ignorati durante il test "
+"controllato"
+
+#: builtin/add.c:327 builtin/update-index.c:1004
+msgid "override the executable bit of the listed files"
+msgstr "esegui l'override del bit eseguibile dei file elencati"
+
+#: builtin/add.c:329
+msgid "warn when adding an embedded repository"
+msgstr "emetti un avviso quando si aggiunge un repository incorporato"
+
+#: builtin/add.c:347
+#, c-format
+msgid ""
+"You've added another git repository inside your current repository.\n"
+"Clones of the outer repository will not contain the contents of\n"
+"the embedded repository and will not know how to obtain it.\n"
+"If you meant to add a submodule, use:\n"
+"\n"
+"\tgit submodule add <url> %s\n"
+"\n"
+"If you added this path by mistake, you can remove it from the\n"
+"index with:\n"
+"\n"
+"\tgit rm --cached %s\n"
+"\n"
+"See \"git help submodule\" for more information."
+msgstr ""
+"Hai aggiunto un altro repository Git all'interno del repository\n"
+"corrente. I cloni del repository esterno non conterranno i\n"
+"contenuti del repository incorporato e non sapranno come ottenerli.\n"
+"Se intendevi aggiungere un sottomodulo, usa:\n"
+"\n"
+"\tgit submodule add <url> %s\n"
+"\n"
+"Se hai aggiunto questo percorso per errore, puoi rimuoverlo\n"
+"dall'indice con:\n"
+"\n"
+"\tgit rm --cached %s\n"
+"\n"
+"Vedi \"git help submodule\" per ulteriori informazioni."
+
+#: builtin/add.c:375
+#, c-format
+msgid "adding embedded git repository: %s"
+msgstr "aggiunta repository Git incorporato in corso: %s"
+
+#: builtin/add.c:393
+#, c-format
+msgid "Use -f if you really want to add them.\n"
+msgstr "Usa -f se vuoi davvero aggiungerli.\n"
+
+#: builtin/add.c:400
+msgid "adding files failed"
+msgstr "aggiunta dei file non riuscita"
+
+#: builtin/add.c:428 builtin/commit.c:348
+msgid "--pathspec-from-file is incompatible with --interactive/--patch"
+msgstr "--pathspec-from-file non è compatibile con --interactive/--patch"
+
+#: builtin/add.c:434
+msgid "--pathspec-from-file is incompatible with --edit"
+msgstr "--pathspec-from-file non è compatibile con --edit"
+
+#: builtin/add.c:446
+msgid "-A and -u are mutually incompatible"
+msgstr "-A e -u non sono compatibili fra loro"
+
+#: builtin/add.c:449
+msgid "Option --ignore-missing can only be used together with --dry-run"
+msgstr "L'opzione --ignore-missing può essere usata solo con --dry-run"
+
+#: builtin/add.c:453
+#, c-format
+msgid "--chmod param '%s' must be either -x or +x"
+msgstr "Il parametro --chmod '%s' deve essere -x o +x"
+
+#: builtin/add.c:471 builtin/checkout.c:1648 builtin/commit.c:354
+#: builtin/reset.c:327
+msgid "--pathspec-from-file is incompatible with pathspec arguments"
+msgstr ""
+"--pathspec-from-file non è compatibile con gli argomenti specificatore"
+" percorso"
+
+#: builtin/add.c:478 builtin/checkout.c:1660 builtin/commit.c:360
+#: builtin/reset.c:333
+msgid "--pathspec-file-nul requires --pathspec-from-file"
+msgstr "--pathspec-file-nul richiede --pathspec-from-file"
+
+#: builtin/add.c:482
+#, c-format
+msgid "Nothing specified, nothing added.\n"
+msgstr "Non è stato specificato nulla, non è stato aggiunto nulla.\n"
+
+#: builtin/add.c:483
+#, c-format
+msgid "Maybe you wanted to say 'git add .'?\n"
+msgstr "Forse intendevi dire 'git add .'?\n"
+
+#: builtin/am.c:347
+msgid "could not parse author script"
+msgstr "impossibile analizzare lo script author"
+
+#: builtin/am.c:431
+#, c-format
+msgid "'%s' was deleted by the applypatch-msg hook"
+msgstr "'%s' è stato eliminato dall'hook applypatch-msg"
+
+#: builtin/am.c:473
+#, c-format
+msgid "Malformed input line: '%s'."
+msgstr "Riga di input malformata: '%s'."
+
+#: builtin/am.c:511
+#, c-format
+msgid "Failed to copy notes from '%s' to '%s'"
+msgstr "Copia delle note da '%s' a '%s' non riuscita"
+
+#: builtin/am.c:537
+msgid "fseek failed"
+msgstr "fseek non riuscita"
+
+#: builtin/am.c:725
+#, c-format
+msgid "could not parse patch '%s'"
+msgstr "impossibile analizzare la patch '%s'"
+
+#: builtin/am.c:790
+msgid "Only one StGIT patch series can be applied at once"
+msgstr "Può essere applicata solo una serie di patch StGIT per volta"
+
+#: builtin/am.c:838
+msgid "invalid timestamp"
+msgstr "timestamp non valido"
+
+#: builtin/am.c:843 builtin/am.c:855
+msgid "invalid Date line"
+msgstr "riga Date non valida"
+
+#: builtin/am.c:850
+msgid "invalid timezone offset"
+msgstr "offset fuso orario non valido"
+
+#: builtin/am.c:943
+msgid "Patch format detection failed."
+msgstr "Rilevamento del formato della patch non riuscito."
+
+#: builtin/am.c:948 builtin/clone.c:409
+#, c-format
+msgid "failed to create directory '%s'"
+msgstr "creazione della directory '%s' non riuscita"
+
+#: builtin/am.c:953
+msgid "Failed to split patches."
+msgstr "Divisione delle patch non riuscita."
+
+#: builtin/am.c:1084
+#, c-format
+msgid "When you have resolved this problem, run \"%s --continue\"."
+msgstr "Una volta risolto questo problema, esegui \"%s --continue\"."
+
+#: builtin/am.c:1085
+#, c-format
+msgid "If you prefer to skip this patch, run \"%s --skip\" instead."
+msgstr "Se preferisci saltare questa patch, esegui invece \"%s --skip\"."
+
+#: builtin/am.c:1086
+#, c-format
+msgid "To restore the original branch and stop patching, run \"%s --abort\"."
+msgstr ""
+"Per ripristinare il branch originario e terminare il patching, esegui \"%s --"
+"abort\"."
+
+#: builtin/am.c:1169
+msgid "Patch sent with format=flowed; space at the end of lines might be lost."
+msgstr ""
+"Patch inviata con format=flowed; gli spazi al termine delle righe potrebbero "
+"essere andati perduti."
+
+#: builtin/am.c:1197
+msgid "Patch is empty."
+msgstr "La patch è vuota."
+
+#: builtin/am.c:1262
+#, c-format
+msgid "missing author line in commit %s"
+msgstr "riga autore mancante nel commit %s"
+
+#: builtin/am.c:1265
+#, c-format
+msgid "invalid ident line: %.*s"
+msgstr "riga ident non valida: %.*s"
+
+#: builtin/am.c:1484
+msgid "Repository lacks necessary blobs to fall back on 3-way merge."
+msgstr ""
+"Dal repository mancano i blob necessari per ripiegare sul merge a tre vie."
+
+#: builtin/am.c:1486
+msgid "Using index info to reconstruct a base tree..."
+msgstr ""
+"Utilizzo le informazioni dell'indice per ricostruire un albero di base..."
+
+#: builtin/am.c:1505
+msgid ""
+"Did you hand edit your patch?\n"
+"It does not apply to blobs recorded in its index."
+msgstr ""
+"Hai modificato manualmente la patch?\n"
+"Non può essere applicata ai blob registrati nel suo indice."
+
+#: builtin/am.c:1511
+msgid "Falling back to patching base and 3-way merge..."
+msgstr "Ripiego sul patching della base e sul merge a tre vie..."
+
+#: builtin/am.c:1537
+msgid "Failed to merge in the changes."
+msgstr "Merge delle modifiche non riuscito."
+
+#: builtin/am.c:1569
+msgid "applying to an empty history"
+msgstr "applicazione a una cronologia vuota"
+
+#: builtin/am.c:1616 builtin/am.c:1620
+#, c-format
+msgid "cannot resume: %s does not exist."
+msgstr "impossibile riprendere l'attività: %s non esiste."
+
+#: builtin/am.c:1638
+msgid "Commit Body is:"
+msgstr "Il corpo del commit è:"
+
+#. TRANSLATORS: Make sure to include [y], [n], [e], [v] and [a]
+#. in your translation. The program will only accept English
+#. input at this point.
+#.
+#: builtin/am.c:1648
+#, c-format
+msgid "Apply? [y]es/[n]o/[e]dit/[v]iew patch/[a]ccept all: "
+msgstr ""
+"Applico? Sì [y]/No [n]/Modifica [e]/[V]isualizza patch/[A]ccetta tutto:"
+
+#: builtin/am.c:1695 builtin/commit.c:394
+msgid "unable to write index file"
+msgstr "impossibile scrivere il file indice"
+
+#: builtin/am.c:1699
+#, c-format
+msgid "Dirty index: cannot apply patches (dirty: %s)"
+msgstr "Indice sporco: impossibile applicare le patch (elemento sporco: %s)"
+
+#: builtin/am.c:1739 builtin/am.c:1807
+#, c-format
+msgid "Applying: %.*s"
+msgstr "Applicazione in corso: %.*s"
+
+#: builtin/am.c:1756
+msgid "No changes -- Patch already applied."
+msgstr "Nessuna modifica -- patch già applicata."
+
+#: builtin/am.c:1762
+#, c-format
+msgid "Patch failed at %s %.*s"
+msgstr "Patch non riuscita a %s %.*s"
+
+#: builtin/am.c:1766
+msgid "Use 'git am --show-current-patch' to see the failed patch"
+msgstr ""
+"Usa 'git am --show-current-patch' per visualizzare la patch non riuscita"
+
+#: builtin/am.c:1810
+msgid ""
+"No changes - did you forget to use 'git add'?\n"
+"If there is nothing left to stage, chances are that something else\n"
+"already introduced the same changes; you might want to skip this patch."
+msgstr ""
+"Nessuna modifica - ti sei dimenticato di usare 'git add'?\n"
+"Se non rimane nulla da aggiungere all'area di staging, forse qualcos'altro\n"
+"ha già introdotto le stesse modifiche; potresti voler saltare questa patch."
+
+#: builtin/am.c:1817
+msgid ""
+"You still have unmerged paths in your index.\n"
+"You should 'git add' each file with resolved conflicts to mark them as "
+"such.\n"
+"You might run `git rm` on a file to accept \"deleted by them\" for it."
+msgstr ""
+"Nell'indice hai ancora dei percorsi di cui non è stato eseguito il merge.\n"
+"Dovresti eseguire 'git add' su ogni file i cui conflitti sono stati risolti "
+"per contrassegnarli come tali.\n"
+"Potresti eseguire `git rm` su un file per accettarne la risoluzione "
+"\"eliminato da loro\"."
+
+#: builtin/am.c:1924 builtin/am.c:1928 builtin/am.c:1940 builtin/reset.c:346
+#: builtin/reset.c:354
+#, c-format
+msgid "Could not parse object '%s'."
+msgstr "Impossibile analizzare l'oggetto '%s'."
+
+#: builtin/am.c:1976
+msgid "failed to clean index"
+msgstr "pulizia dell'indice non riuscita"
+
+#: builtin/am.c:2020
+msgid ""
+"You seem to have moved HEAD since the last 'am' failure.\n"
+"Not rewinding to ORIG_HEAD"
+msgstr ""
+"Sembra che tu abbia spostato HEAD dall'ultima esecuzione non riuscita di "
+"'am'.\n"
+"Non ritorno indietro a ORIG_HEAD"
+
+#: builtin/am.c:2117
+#, c-format
+msgid "Invalid value for --patch-format: %s"
+msgstr "Valore non valido per --patch-format: %s"
+
+#: builtin/am.c:2153
+msgid "git am [<options>] [(<mbox> | <Maildir>)...]"
+msgstr "git am [<opzioni>] [(<mbox> | <Maildir>)...]"
+
+#: builtin/am.c:2154
+msgid "git am [<options>] (--continue | --skip | --abort)"
+msgstr "git am [<opzioni>] (--continue | --skip | --abort)"
+
+#: builtin/am.c:2160
+msgid "run interactively"
+msgstr "esegui in modalità interattiva"
+
+#: builtin/am.c:2162
+msgid "historical option -- no-op"
+msgstr "opzione storica -- non esegue nulla"
+
+#: builtin/am.c:2164
+msgid "allow fall back on 3way merging if needed"
+msgstr "consenti il ripiego sul merge a tre vie se necessario"
+
+#: builtin/am.c:2165 builtin/init-db.c:494 builtin/prune-packed.c:58
+#: builtin/repack.c:304 builtin/stash.c:811
+msgid "be quiet"
+msgstr "non visualizzare messaggi"
+
+#: builtin/am.c:2167
+msgid "add a Signed-off-by line to the commit message"
+msgstr "aggiungi una riga Signed-off-by al messaggio di commit"
+
+#: builtin/am.c:2170
+msgid "recode into utf8 (default)"
+msgstr "converti codifica in UTF-8 (impostazione predefinita)"
+
+#: builtin/am.c:2172
+msgid "pass -k flag to git-mailinfo"
+msgstr "fornisci l'argomento -k a git-mailinfo"
+
+#: builtin/am.c:2174
+msgid "pass -b flag to git-mailinfo"
+msgstr "fornisci l'argomento -b a git-mailinfo"
+
+#: builtin/am.c:2176
+msgid "pass -m flag to git-mailinfo"
+msgstr "fornisci l'argomento -m a git-mailinfo"
+
+#: builtin/am.c:2178
+msgid "pass --keep-cr flag to git-mailsplit for mbox format"
+msgstr "fornisci a git-mailsplit l'argomento --keep-cr per il formato mbox"
+
+#: builtin/am.c:2181
+msgid "do not pass --keep-cr flag to git-mailsplit independent of am.keepcr"
+msgstr ""
+"non fornire l'argomento --keep-cr a git-mailsplit indipendentemente dal "
+"valore di am.keepcr"
+
+#: builtin/am.c:2184
+msgid "strip everything before a scissors line"
+msgstr "rimuovi tutte le righe prima di una riga \"taglia qui\""
+
+#: builtin/am.c:2186 builtin/am.c:2189 builtin/am.c:2192 builtin/am.c:2195
+#: builtin/am.c:2198 builtin/am.c:2201 builtin/am.c:2204 builtin/am.c:2207
+#: builtin/am.c:2213
+msgid "pass it through git-apply"
+msgstr "passa l'argomento a git-apply"
+
+#: builtin/am.c:2203 builtin/commit.c:1386 builtin/fmt-merge-msg.c:673
+#: builtin/fmt-merge-msg.c:676 builtin/grep.c:883 builtin/merge.c:249
+#: builtin/pull.c:160 builtin/pull.c:219 builtin/rebase.c:1469
+#: builtin/repack.c:315 builtin/repack.c:319 builtin/repack.c:321
+#: builtin/show-branch.c:650 builtin/show-ref.c:172 builtin/tag.c:403
+#: parse-options.h:154 parse-options.h:175 parse-options.h:316
+msgid "n"
+msgstr "n"
+
+#: builtin/am.c:2209 builtin/branch.c:661 builtin/for-each-ref.c:38
+#: builtin/replace.c:555 builtin/tag.c:437 builtin/verify-tag.c:38
+msgid "format"
+msgstr "formato"
+
+#: builtin/am.c:2210
+msgid "format the patch(es) are in"
+msgstr "il formato delle patch"
+
+#: builtin/am.c:2216
+msgid "override error message when patch failure occurs"
+msgstr ""
+"esegui l'override del messaggio d'errore quando si verifica un errore legato "
+"alle patch"
+
+#: builtin/am.c:2218
+msgid "continue applying patches after resolving a conflict"
+msgstr ""
+"continua l'applicazione delle patch dopo la risoluzione di un conflitto"
+
+#: builtin/am.c:2221
+msgid "synonyms for --continue"
+msgstr "sinonimi di --continue"
+
+#: builtin/am.c:2224
+msgid "skip the current patch"
+msgstr "salta la patch corrente"
+
+#: builtin/am.c:2227
+msgid "restore the original branch and abort the patching operation."
+msgstr "ripristina il branch originario e interrompi l'operazione di patching."
+
+#: builtin/am.c:2230
+msgid "abort the patching operation but keep HEAD where it is."
+msgstr "interrompi l'operazione di patching ma mantieni HEAD dov'è."
+
+#: builtin/am.c:2233
+msgid "show the patch being applied."
+msgstr "visualizza la patch in fase di applicazione."
+
+#: builtin/am.c:2237
+msgid "lie about committer date"
+msgstr "menti sulla data del commit"
+
+#: builtin/am.c:2239
+msgid "use current timestamp for author date"
+msgstr "usa il timestamp corrente come data autore"
+
+#: builtin/am.c:2241 builtin/commit-tree.c:120 builtin/commit.c:1507
+#: builtin/merge.c:286 builtin/pull.c:194 builtin/rebase.c:509
+#: builtin/rebase.c:1513 builtin/revert.c:117 builtin/tag.c:418
+msgid "key-id"
+msgstr "ID chiave"
+
+#: builtin/am.c:2242 builtin/rebase.c:510 builtin/rebase.c:1514
+msgid "GPG-sign commits"
+msgstr "firma i commit con GPG"
+
+#: builtin/am.c:2245
+msgid "(internal use for git-rebase)"
+msgstr "(a uso interno per git-rebase)"
+
+#: builtin/am.c:2263
+msgid ""
+"The -b/--binary option has been a no-op for long time, and\n"
+"it will be removed. Please do not use it anymore."
+msgstr ""
+"L'opzione -b/--binary non esegue nulla da molto tempo e\n"
+"sarà rimossa. Non usarla più."
+
+#: builtin/am.c:2270
+msgid "failed to read the index"
+msgstr "lettura dell'indice non riuscita"
+
+#: builtin/am.c:2285
+#, c-format
+msgid "previous rebase directory %s still exists but mbox given."
+msgstr ""
+"la directory di rebase precedente %s esiste ancora ma è stata specificata "
+"un'mbox."
+
+#: builtin/am.c:2309
+#, c-format
+msgid ""
+"Stray %s directory found.\n"
+"Use \"git am --abort\" to remove it."
+msgstr ""
+"Trovata directory smarrita %s.\n"
+"Usa \"git am --abort\" per eliminarla."
+
+#: builtin/am.c:2315
+msgid "Resolve operation not in progress, we are not resuming."
+msgstr "Operazione di risoluzione non in corso, non riprendiamo."
+
+#: builtin/am.c:2325
+msgid "interactive mode requires patches on the command line"
+msgstr ""
+"la modalità interattiva richiede che le patch siano fornite sulla riga di "
+"comando"
+
+#: builtin/apply.c:8
+msgid "git apply [<options>] [<patch>...]"
+msgstr "git apply [<opzioni>] [<patch>...]"
+
+#: builtin/archive.c:17
+#, c-format
+msgid "could not create archive file '%s'"
+msgstr "impossibile creare il file archivio '%s'"
+
+#: builtin/archive.c:20
+msgid "could not redirect output"
+msgstr "impossibile redirigere l'output"
+
+#: builtin/archive.c:37
+msgid "git archive: Remote with no URL"
+msgstr "git archive: il remoto non ha un URL"
+
+#: builtin/archive.c:61
+msgid "git archive: expected ACK/NAK, got a flush packet"
+msgstr "git archive: attesi ACK/NAK, ricevuto pacchetto di flush"
+
+#: builtin/archive.c:64
+#, c-format
+msgid "git archive: NACK %s"
+msgstr "git archive: NACK %s"
+
+#: builtin/archive.c:65
+msgid "git archive: protocol error"
+msgstr "git archive: errore del protocollo"
+
+#: builtin/archive.c:69
+msgid "git archive: expected a flush"
+msgstr "git archive: atteso un flush"
+
+#: builtin/bisect--helper.c:22
+msgid "git bisect--helper --next-all [--no-checkout]"
+msgstr "git bisect--helper --next-all [--no-checkout]"
+
+#: builtin/bisect--helper.c:23
+msgid "git bisect--helper --write-terms <bad_term> <good_term>"
+msgstr ""
+"git bisect--helper --write-terms <termine revisione non funzionante> "
+"<termine revisione funzionante>"
+
+#: builtin/bisect--helper.c:24
+msgid "git bisect--helper --bisect-clean-state"
+msgstr "git bisect--helper --bisect-clean-state"
+
+#: builtin/bisect--helper.c:25
+msgid "git bisect--helper --bisect-reset [<commit>]"
+msgstr "git bisect--helper --bisect-reset [<commit>]"
+
+#: builtin/bisect--helper.c:26
+msgid ""
+"git bisect--helper --bisect-write [--no-log] <state> <revision> <good_term> "
+"<bad_term>"
+msgstr ""
+"git bisect--helper --bisect-write [--no-log] <stato> <revisione> <termine "
+"revisione funzionante> <termine revisione non funzionante>"
+
+#: builtin/bisect--helper.c:27
+msgid ""
+"git bisect--helper --bisect-check-and-set-terms <command> <good_term> "
+"<bad_term>"
+msgstr ""
+"git bisect--helper --bisect-check-and-set-terms <comando> <termine revisione "
+"funzionante> <termine revisione non funzionante>"
+
+#: builtin/bisect--helper.c:28
+msgid "git bisect--helper --bisect-next-check <good_term> <bad_term> [<term>]"
+msgstr ""
+"git bisect--helper --bisect-next-check <termine revisione funzionante> "
+"<termine revisione non funzionante> [<termine>]"
+
+#: builtin/bisect--helper.c:29
+msgid ""
+"git bisect--helper --bisect-terms [--term-good | --term-old | --term-bad | --"
+"term-new]"
+msgstr ""
+"git bisect--helper --bisect-terms [--term-good | --term-old | --term-bad | --"
+"term-new]"
+
+#: builtin/bisect--helper.c:30
+msgid ""
+"git bisect--helper --bisect-start [--term-{old,good}=<term> --term-{new,bad}"
+"=<term>][--no-checkout] [<bad> [<good>...]] [--] [<paths>...]"
+msgstr ""
+"git bisect--helper --bisect-start [--term-{old,good}=<termine> --term-{new,"
+"bad}=<termine>][--no-checkout] [<non funzionante> [<funzionante>...]] [--] "
+"[<percorsi>...]"
+
+#: builtin/bisect--helper.c:86
+#, c-format
+msgid "'%s' is not a valid term"
+msgstr "'%s' non è un termine valido"
+
+#: builtin/bisect--helper.c:90
+#, c-format
+msgid "can't use the builtin command '%s' as a term"
+msgstr "impossibile usare il comando nativo '%s' come termine"
+
+#: builtin/bisect--helper.c:100
+#, c-format
+msgid "can't change the meaning of the term '%s'"
+msgstr "impossibile cambiare il significato del termine '%s'"
+
+#: builtin/bisect--helper.c:111
+msgid "please use two different terms"
+msgstr "usa due termini differenti"
+
+#: builtin/bisect--helper.c:118
+msgid "could not open the file BISECT_TERMS"
+msgstr "impossibile aprire il file BISECT_TERMS"
+
+#: builtin/bisect--helper.c:155
+#, c-format
+msgid "We are not bisecting.\n"
+msgstr "Non stiamo eseguendo un bisect.\n"
+
+#: builtin/bisect--helper.c:163
+#, c-format
+msgid "'%s' is not a valid commit"
+msgstr "'%s' non è un commit valido"
+
+#: builtin/bisect--helper.c:172
+#, c-format
+msgid ""
+"could not check out original HEAD '%s'. Try 'git bisect reset <commit>'."
+msgstr ""
+"impossibile eseguire il checkout dell'HEAD originario '%s'. Prova con 'git "
+"bisect reset <commit>'."
+
+#: builtin/bisect--helper.c:216
+#, c-format
+msgid "Bad bisect_write argument: %s"
+msgstr "Argomento bisect_write errato: %s"
+
+#: builtin/bisect--helper.c:221
+#, c-format
+msgid "couldn't get the oid of the rev '%s'"
+msgstr "impossibile recuperare l'OID della revisione '%s'"
+
+#: builtin/bisect--helper.c:233
+#, c-format
+msgid "couldn't open the file '%s'"
+msgstr "impossibile aprire il file '%s'"
+
+#: builtin/bisect--helper.c:259
+#, c-format
+msgid "Invalid command: you're currently in a %s/%s bisect"
+msgstr "Comando non valido: attualmente stai eseguendo una bisezione %s/%s"
+
+#: builtin/bisect--helper.c:286
+#, c-format
+msgid ""
+"You need to give me at least one %s and %s revision.\n"
+"You can use \"git bisect %s\" and \"git bisect %s\" for that."
+msgstr ""
+"Devi specificare almeno una revisione %s ed una %s.\n"
+"Puoi usare \"git bisect %s\" e \"git bisect %s\" per questo scopo."
+
+#: builtin/bisect--helper.c:290
+#, c-format
+msgid ""
+"You need to start by \"git bisect start\".\n"
+"You then need to give me at least one %s and %s revision.\n"
+"You can use \"git bisect %s\" and \"git bisect %s\" for that."
+msgstr ""
+"Devi iniziare con \"git bisect start\".\n"
+"Quindi devi specificare almeno una revisione %s ed una %s.\n"
+"Puoi usare \"git bisect %s\" e \"git bisect %s\" a questo scopo."
+
+#: builtin/bisect--helper.c:322
+#, c-format
+msgid "bisecting only with a %s commit"
+msgstr "eseguo la bisezione solo con un commit %s"
+
+#. TRANSLATORS: Make sure to include [Y] and [n] in your
+#. translation. The program will only accept English input
+#. at this point.
+#.
+#: builtin/bisect--helper.c:330
+msgid "Are you sure [Y/n]? "
+msgstr "Sei sicuro? [Y/n] "
+
+#: builtin/bisect--helper.c:377
+msgid "no terms defined"
+msgstr "nessun termine definito"
+
+#: builtin/bisect--helper.c:380
+#, c-format
+msgid ""
+"Your current terms are %s for the old state\n"
+"and %s for the new state.\n"
+msgstr ""
+"I tuoi termini correnti sono %s per lo stato vecchio\n"
+"e %s per lo stato nuovo.\n"
+
+#: builtin/bisect--helper.c:390
+#, c-format
+msgid ""
+"invalid argument %s for 'git bisect terms'.\n"
+"Supported options are: --term-good|--term-old and --term-bad|--term-new."
+msgstr ""
+"argomento %s non valido per 'git bisect terms'.\n"
+"Le opzioni supportate sono: --term-good|--term-old e --term-bad|--term-new."
+
+#: builtin/bisect--helper.c:476
+#, c-format
+msgid "unrecognized option: '%s'"
+msgstr "opzione non riconosciuta: '%s'"
+
+#: builtin/bisect--helper.c:480
+#, c-format
+msgid "'%s' does not appear to be a valid revision"
+msgstr "sembra che '%s' non sia una revisione valida"
+
+#: builtin/bisect--helper.c:512
+msgid "bad HEAD - I need a HEAD"
+msgstr "HEAD non valida - ho bisogno di un'HEAD"
+
+#: builtin/bisect--helper.c:527
+#, c-format
+msgid "checking out '%s' failed. Try 'git bisect start <valid-branch>'."
+msgstr ""
+"checkout di '%s' non riuscito. Prova con 'git bisect start <branch valido>'."
+
+#: builtin/bisect--helper.c:548
+msgid "won't bisect on cg-seek'ed tree"
+msgstr "non eseguirò la bisezione su un albero sottoposto a cg-seek"
+
+#: builtin/bisect--helper.c:551
+msgid "bad HEAD - strange symbolic ref"
+msgstr "head non valida - riferimento simbolico strano"
+
+#: builtin/bisect--helper.c:575
+#, c-format
+msgid "invalid ref: '%s'"
+msgstr "riferimento non valido: '%s'"
+
+#: builtin/bisect--helper.c:631
+msgid "perform 'git bisect next'"
+msgstr "esegui 'git bisect next'"
+
+#: builtin/bisect--helper.c:633
+msgid "write the terms to .git/BISECT_TERMS"
+msgstr "scrivi i termini in .git/BISECT_TERMS"
+
+#: builtin/bisect--helper.c:635
+msgid "cleanup the bisection state"
+msgstr "pulisci lo stato bisezione"
+
+#: builtin/bisect--helper.c:637
+msgid "check for expected revs"
+msgstr "controlla se le revisioni attese sono presenti"
+
+#: builtin/bisect--helper.c:639
+msgid "reset the bisection state"
+msgstr "reimposta lo stato della bisezione"
+
+#: builtin/bisect--helper.c:641
+msgid "write out the bisection state in BISECT_LOG"
+msgstr "scrivi lo stato della bisezione in BISECT_LOG"
+
+#: builtin/bisect--helper.c:643
+msgid "check and set terms in a bisection state"
+msgstr "controlla e imposta i termini in uno stato bisezione"
+
+#: builtin/bisect--helper.c:645
+msgid "check whether bad or good terms exist"
+msgstr ""
+"controlla se esistono termini per revisioni non funzionanti o funzionanti"
+
+#: builtin/bisect--helper.c:647
+msgid "print out the bisect terms"
+msgstr "stampa i termini della bisezione"
+
+#: builtin/bisect--helper.c:649
+msgid "start the bisect session"
+msgstr "inizia la sessione di bisezione"
+
+#: builtin/bisect--helper.c:651
+msgid "update BISECT_HEAD instead of checking out the current commit"
+msgstr "aggiorna BISECT_HEAD anziché eseguire il checkout del commit corrente"
+
+#: builtin/bisect--helper.c:653
+msgid "no log for BISECT_WRITE"
+msgstr "non registrare le operazioni eseguite per BISECT_WRITE"
+
+#: builtin/bisect--helper.c:670
+msgid "--write-terms requires two arguments"
+msgstr "--write-terms richiede due argomenti"
+
+#: builtin/bisect--helper.c:674
+msgid "--bisect-clean-state requires no arguments"
+msgstr "--bisect-clean-state non richiede argomenti"
+
+#: builtin/bisect--helper.c:681
+msgid "--bisect-reset requires either no argument or a commit"
+msgstr "--bisect-reset richiede o nessun argomento o un commit"
+
+#: builtin/bisect--helper.c:685
+msgid "--bisect-write requires either 4 or 5 arguments"
+msgstr "--bisect-write richiede o quattro o cinque argomenti"
+
+#: builtin/bisect--helper.c:691
+msgid "--check-and-set-terms requires 3 arguments"
+msgstr "--check-and-set-terms richiede tre argomenti"
+
+#: builtin/bisect--helper.c:697
+msgid "--bisect-next-check requires 2 or 3 arguments"
+msgstr "--bisect-next-check richiede due o tre argomenti"
+
+#: builtin/bisect--helper.c:703
+msgid "--bisect-terms requires 0 or 1 argument"
+msgstr "--bisect-terms richiede zero o un argomento"
+
+#: builtin/blame.c:31
+msgid "git blame [<options>] [<rev-opts>] [<rev>] [--] <file>"
+msgstr "git blame [<opzioni>] [<opzioni revisione>] [<revisione>] [--] <file>"
+
+#: builtin/blame.c:36
+msgid "<rev-opts> are documented in git-rev-list(1)"
+msgstr "le <opzioni revisione> sono documentate in git-rev-list(1)"
+
+#: builtin/blame.c:409
+#, c-format
+msgid "expecting a color: %s"
+msgstr "atteso colore: %s"
+
+#: builtin/blame.c:416
+msgid "must end with a color"
+msgstr "deve terminare con un colore"
+
+#: builtin/blame.c:729
+#, c-format
+msgid "invalid color '%s' in color.blame.repeatedLines"
+msgstr "colore '%s' non valido in color.blame.repeatedLines"
+
+#: builtin/blame.c:747
+msgid "invalid value for blame.coloring"
+msgstr "valore non valido per blame.coloring"
+
+#: builtin/blame.c:822
+#, c-format
+msgid "cannot find revision %s to ignore"
+msgstr "impossibile trovare la revisione %s da ignorare"
+
+#: builtin/blame.c:844
+msgid "Show blame entries as we find them, incrementally"
+msgstr ""
+"Visualizza le voci blame incrementalmente, a mano a mano che le troviamo"
+
+#: builtin/blame.c:845
+msgid "Show blank SHA-1 for boundary commits (Default: off)"
+msgstr ""
+"Visualizza un hash SHA-1 vuoto per i commit limite (impostazione "
+"predefinita: off)"
+
+#: builtin/blame.c:846
+msgid "Do not treat root commits as boundaries (Default: off)"
+msgstr ""
+"Non gestire i commit radice come commit limite (impostazione predefinita: "
+"off)"
+
+#: builtin/blame.c:847
+msgid "Show work cost statistics"
+msgstr "Visualizza le statistiche sul costo dell'operazione"
+
+#: builtin/blame.c:848
+msgid "Force progress reporting"
+msgstr "Forza l'indicazione d'avanzamento dell'operazione"
+
+#: builtin/blame.c:849
+msgid "Show output score for blame entries"
+msgstr "Visualizza il punteggio di output per le voci blame"
+
+#: builtin/blame.c:850
+msgid "Show original filename (Default: auto)"
+msgstr ""
+"Visualizza il nome file originario (impostazione predefinita: automatico)"
+
+#: builtin/blame.c:851
+msgid "Show original linenumber (Default: off)"
+msgstr ""
+"Visualizza il numero di riga originario (impostazione predefinita: off)"
+
+#: builtin/blame.c:852
+msgid "Show in a format designed for machine consumption"
+msgstr ""
+"Visualizza l'output in un formato progettato per l'utilizzo da parte di una "
+"macchina"
+
+#: builtin/blame.c:853
+msgid "Show porcelain format with per-line commit information"
+msgstr ""
+"Visualizza il formato porcelain con le informazioni sul commit per ogni riga"
+
+#: builtin/blame.c:854
+msgid "Use the same output mode as git-annotate (Default: off)"
+msgstr ""
+"Usa la stessa modalità di output di git-annotate (impostazione predefinita: "
+"off)"
+
+#: builtin/blame.c:855
+msgid "Show raw timestamp (Default: off)"
+msgstr "Visualizza il timestamp grezzo (impostazione predefinita: off)"
+
+#: builtin/blame.c:856
+msgid "Show long commit SHA1 (Default: off)"
+msgstr ""
+"Visualizza l'hash SHA1 del commit in forma lunga (impostazione predefinita: "
+"off)"
+
+#: builtin/blame.c:857
+msgid "Suppress author name and timestamp (Default: off)"
+msgstr ""
+"Non visualizzare il nome autore e il timestamp (impostazione predefinita: "
+"off)"
+
+#: builtin/blame.c:858
+msgid "Show author email instead of name (Default: off)"
+msgstr ""
+"Visualizza l'indirizzo e-mail dell'autore invece del nome (impostazione "
+"predefinita: off)"
+
+#: builtin/blame.c:859
+msgid "Ignore whitespace differences"
+msgstr "Ignora le differenze relative agli spazi bianchi"
+
+#: builtin/blame.c:860 builtin/log.c:1702
+msgid "rev"
+msgstr "revisione"
+
+#: builtin/blame.c:860
+msgid "Ignore <rev> when blaming"
+msgstr "Ignora <revisione> durante l'esecuzione del blame"
+
+#: builtin/blame.c:861
+msgid "Ignore revisions from <file>"
+msgstr "Ignora le revisioni specificate in <file>"
+
+#: builtin/blame.c:862
+msgid "color redundant metadata from previous line differently"
+msgstr "colora in modo differente i metadati ridondanti della riga precedente"
+
+#: builtin/blame.c:863
+msgid "color lines by age"
+msgstr "colora le righe in base all'età"
+
+#: builtin/blame.c:864
+msgid "Spend extra cycles to find better match"
+msgstr "Usa cicli extra per trovare una corrispondenza migliore"
+
+#: builtin/blame.c:865
+msgid "Use revisions from <file> instead of calling git-rev-list"
+msgstr "Usa le revisioni salvate in <file> anziché richiamare git-rev-list"
+
+#: builtin/blame.c:866
+msgid "Use <file>'s contents as the final image"
+msgstr "Usa i contenuti di <file> come immagine finale"
+
+#: builtin/blame.c:867 builtin/blame.c:868
+msgid "score"
+msgstr "punteggio"
+
+#: builtin/blame.c:867
+msgid "Find line copies within and across files"
+msgstr "Trova copie delle righe all'interno e fra file"
+
+#: builtin/blame.c:868
+msgid "Find line movements within and across files"
+msgstr "Trova righe spostate all'interno e fra file"
+
+#: builtin/blame.c:869
+msgid "n,m"
+msgstr "n,m"
+
+#: builtin/blame.c:869
+msgid "Process only line range n,m, counting from 1"
+msgstr "Elabora solo l'intervallo righe n,m, contandole da 1"
+
+#: builtin/blame.c:921
+msgid "--progress can't be used with --incremental or porcelain formats"
+msgstr ""
+"--progress non può essere usato con --incremental o con i formati porcelain"
+
+#. TRANSLATORS: This string is used to tell us the
+#. maximum display width for a relative timestamp in
+#. "git blame" output.  For C locale, "4 years, 11
+#. months ago", which takes 22 places, is the longest
+#. among various forms of relative timestamps, but
+#. your language may need more or fewer display
+#. columns.
+#.
+#: builtin/blame.c:972
+msgid "4 years, 11 months ago"
+msgstr "4 anni, 11 giorni fa"
+
+#: builtin/blame.c:1079
+#, c-format
+msgid "file %s has only %lu line"
+msgid_plural "file %s has only %lu lines"
+msgstr[0] "il file %s ha solo %lu riga"
+msgstr[1] "il file %s ha solo %lu righe"
+
+#: builtin/blame.c:1125
+msgid "Blaming lines"
+msgstr "Eseguo il blame sulle righe"
+
+#: builtin/branch.c:29
+msgid "git branch [<options>] [-r | -a] [--merged | --no-merged]"
+msgstr "git branch [<opzioni>] [-r | -a] [--merged | --no-merged]"
+
+#: builtin/branch.c:30
+msgid "git branch [<options>] [-l] [-f] <branch-name> [<start-point>]"
+msgstr "git branch [<opzioni>] [-l] [-f] <nome branch> [<punto di partenza>]"
+
+#: builtin/branch.c:31
+msgid "git branch [<options>] [-r] (-d | -D) <branch-name>..."
+msgstr "git branch [<opzioni>] [-r] (-d | -D) <nome branch>..."
+
+#: builtin/branch.c:32
+msgid "git branch [<options>] (-m | -M) [<old-branch>] <new-branch>"
+msgstr "git branch [<opzioni>] (-m | -M) [<vecchio branch>] <nuovo branch>"
+
+#: builtin/branch.c:33
+msgid "git branch [<options>] (-c | -C) [<old-branch>] <new-branch>"
+msgstr "git branch [<opzioni>] (-c | -C) [<vecchio branch>] <nuovo branch>"
+
+#: builtin/branch.c:34
+msgid "git branch [<options>] [-r | -a] [--points-at]"
+msgstr "git branch [<opzioni>] [-r | -a] [--points-at]"
+
+#: builtin/branch.c:35
+msgid "git branch [<options>] [-r | -a] [--format]"
+msgstr "git branch [<opzioni>] [-r | -a] [--format]"
+
+#: builtin/branch.c:154
+#, c-format
+msgid ""
+"deleting branch '%s' that has been merged to\n"
+"         '%s', but not yet merged to HEAD."
+msgstr ""
+"elimino il branch '%s' di cui è stato eseguito il merge in\n"
+"         '%s', ma di cui non è ancora stato eseguito il merge in HEAD."
+
+#: builtin/branch.c:158
+#, c-format
+msgid ""
+"not deleting branch '%s' that is not yet merged to\n"
+"         '%s', even though it is merged to HEAD."
+msgstr ""
+"non elimino il branch '%s' di cui non è ancora stato eseguito il merge in\n"
+"         '%s', benché ne sia stato eseguito il merge in HEAD."
+
+#: builtin/branch.c:172
+#, c-format
+msgid "Couldn't look up commit object for '%s'"
+msgstr "Impossibile trovare l'oggetto commit per '%s'"
+
+#: builtin/branch.c:176
+#, c-format
+msgid ""
+"The branch '%s' is not fully merged.\n"
+"If you are sure you want to delete it, run 'git branch -D %s'."
+msgstr ""
+"Il branch '%s' non è stato sottoposto completamente a un merge.\n"
+"Se sei sicuro di volerlo eliminare, esegui 'git branch -D %s'."
+
+#: builtin/branch.c:189
+msgid "Update of config-file failed"
+msgstr "Aggiornamento del file di configurazione non riuscito"
+
+#: builtin/branch.c:220
+msgid "cannot use -a with -d"
+msgstr "impossibile usare -a con -d"
+
+#: builtin/branch.c:226
+msgid "Couldn't look up commit object for HEAD"
+msgstr "Impossibile trovare l'oggetto commit per HEAD"
+
+#: builtin/branch.c:240
+#, c-format
+msgid "Cannot delete branch '%s' checked out at '%s'"
+msgstr ""
+"Impossibile eliminare il branch '%s' di cui è stato eseguito il checkout in "
+"'%s'"
+
+#: builtin/branch.c:255
+#, c-format
+msgid "remote-tracking branch '%s' not found."
+msgstr "branch remoto tracciato '%s' non trovato."
+
+#: builtin/branch.c:256
+#, c-format
+msgid "branch '%s' not found."
+msgstr "branch '%s' non trovato."
+
+#: builtin/branch.c:271
+#, c-format
+msgid "Error deleting remote-tracking branch '%s'"
+msgstr "Errore durante l'eliminazione del branch remoto tracciato '%s'"
+
+#: builtin/branch.c:272
+#, c-format
+msgid "Error deleting branch '%s'"
+msgstr "Errore durante l'eliminazione del branch '%s'"
+
+#: builtin/branch.c:279
+#, c-format
+msgid "Deleted remote-tracking branch %s (was %s).\n"
+msgstr "Branch remoto tracciato %s eliminato (era %s).\n"
+
+#: builtin/branch.c:280
+#, c-format
+msgid "Deleted branch %s (was %s).\n"
+msgstr "Branch %s eliminato (era %s).\n"
+
+#: builtin/branch.c:429 builtin/tag.c:61
+msgid "unable to parse format string"
+msgstr "impossibile analizzare la stringa di formato"
+
+#: builtin/branch.c:460
+msgid "could not resolve HEAD"
+msgstr "impossibile risolvere HEAD"
+
+#: builtin/branch.c:466
+#, c-format
+msgid "HEAD (%s) points outside of refs/heads/"
+msgstr "HEAD (%s) punta a un oggetto non in refs/heads/"
+
+#: builtin/branch.c:481
+#, c-format
+msgid "Branch %s is being rebased at %s"
+msgstr "Rebase del branch %s in corso in %s"
+
+#: builtin/branch.c:485
+#, c-format
+msgid "Branch %s is being bisected at %s"
+msgstr "Bisezione del branch %s in corso in %s"
+
+#: builtin/branch.c:502
+msgid "cannot copy the current branch while not on any."
+msgstr ""
+"impossibile copiare il branch corrente quando non si è su alcun branch."
+
+#: builtin/branch.c:504
+msgid "cannot rename the current branch while not on any."
+msgstr ""
+"impossibile ridenominare il branch corrente quando non si è su alcun branch."
+
+#: builtin/branch.c:515
+#, c-format
+msgid "Invalid branch name: '%s'"
+msgstr "Nome branch non valido: '%s'"
+
+#: builtin/branch.c:542
+msgid "Branch rename failed"
+msgstr "Ridenominazione del branch non riuscita"
+
+#: builtin/branch.c:544
+msgid "Branch copy failed"
+msgstr "Copia del branch non riuscita"
+
+#: builtin/branch.c:548
+#, c-format
+msgid "Created a copy of a misnamed branch '%s'"
+msgstr "Creata copia del branch mal denominato '%s'"
+
+#: builtin/branch.c:551
+#, c-format
+msgid "Renamed a misnamed branch '%s' away"
+msgstr "Branch mal denominato '%s' rinominato"
+
+#: builtin/branch.c:557
+#, c-format
+msgid "Branch renamed to %s, but HEAD is not updated!"
+msgstr "Branch rinominato in %s, ma HEAD non è aggiornato!"
+
+#: builtin/branch.c:566
+msgid "Branch is renamed, but update of config-file failed"
+msgstr ""
+"Il branch è stato rinominato, ma l'aggiornamento del file di configurazione "
+"non è riuscito"
+
+#: builtin/branch.c:568
+msgid "Branch is copied, but update of config-file failed"
+msgstr ""
+"Il branch è stato copiato, ma l'aggiornamento del file di configurazione non "
+"è riuscito"
+
+#: builtin/branch.c:584
+#, c-format
+msgid ""
+"Please edit the description for the branch\n"
+"  %s\n"
+"Lines starting with '%c' will be stripped.\n"
+msgstr ""
+"Modifica la descrizione del branch\n"
+"  %s\n"
+"Le righe che iniziano con '%c' saranno omesse.\n"
+
+#: builtin/branch.c:618
+msgid "Generic options"
+msgstr "Opzioni generiche"
+
+#: builtin/branch.c:620
+msgid "show hash and subject, give twice for upstream branch"
+msgstr ""
+"visualizza l'hash e l'oggetto, usa l'opzione due volte per il branch upstream"
+
+#: builtin/branch.c:621
+msgid "suppress informational messages"
+msgstr "non visualizzare i messaggi informativi"
+
+#: builtin/branch.c:622
+msgid "set up tracking mode (see git-pull(1))"
+msgstr "imposta la modalità tracking (vedi git-pull(1))"
+
+#: builtin/branch.c:624
+msgid "do not use"
+msgstr "non usare"
+
+#: builtin/branch.c:626 builtin/rebase.c:505
+msgid "upstream"
+msgstr "upstream"
+
+#: builtin/branch.c:626
+msgid "change the upstream info"
+msgstr "modifica le informazioni sull'upstream"
+
+#: builtin/branch.c:627
+msgid "unset the upstream info"
+msgstr "rimuovi le informazioni sull'upstream"
+
+#: builtin/branch.c:628
+msgid "use colored output"
+msgstr "usa l'output colorato"
+
+#: builtin/branch.c:629
+msgid "act on remote-tracking branches"
+msgstr "agisci sui branch remoti tracciati"
+
+#: builtin/branch.c:631 builtin/branch.c:633
+msgid "print only branches that contain the commit"
+msgstr "stampa solo i branch che contengono i commit"
+
+#: builtin/branch.c:632 builtin/branch.c:634
+msgid "print only branches that don't contain the commit"
+msgstr "stampa solo i branch che non contengono i commit"
+
+#: builtin/branch.c:637
+msgid "Specific git-branch actions:"
+msgstr "Azioni specifiche di git-branch:"
+
+#: builtin/branch.c:638
+msgid "list both remote-tracking and local branches"
+msgstr "elenca sia i branch remoti tracciati sia quelli locali"
+
+#: builtin/branch.c:640
+msgid "delete fully merged branch"
+msgstr "elimina il branch completamente sottoposto a merge"
+
+#: builtin/branch.c:641
+msgid "delete branch (even if not merged)"
+msgstr "elimina il branch (anche se non è stato sottoposto a merge)"
+
+#: builtin/branch.c:642
+msgid "move/rename a branch and its reflog"
+msgstr "sposta/rinomina un branch e il suo registro dei riferimenti"
+
+#: builtin/branch.c:643
+msgid "move/rename a branch, even if target exists"
+msgstr "sposta/rinomina un branch anche se la destinazione esiste"
+
+#: builtin/branch.c:644
+msgid "copy a branch and its reflog"
+msgstr "copia un branch e il suo registro dei riferimenti"
+
+#: builtin/branch.c:645
+msgid "copy a branch, even if target exists"
+msgstr "copia un branch anche se la destinazione esiste"
+
+#: builtin/branch.c:646
+msgid "list branch names"
+msgstr "elenca i nomi dei branch"
+
+#: builtin/branch.c:647
+msgid "show current branch name"
+msgstr "visualizza il nome del branch corrente"
+
+#: builtin/branch.c:648
+msgid "create the branch's reflog"
+msgstr "crea il registro dei riferimenti del branch"
+
+#: builtin/branch.c:650
+msgid "edit the description for the branch"
+msgstr "modifica la descrizione del branch"
+
+#: builtin/branch.c:651
+msgid "force creation, move/rename, deletion"
+msgstr "forza la creazione, spostamento/ridenominazione, eliminazione"
+
+#: builtin/branch.c:652
+msgid "print only branches that are merged"
+msgstr "stampa solo i branch sottoposti a merge"
+
+#: builtin/branch.c:653
+msgid "print only branches that are not merged"
+msgstr "stampa solo i branch non sottoposti a merge"
+
+#: builtin/branch.c:654
+msgid "list branches in columns"
+msgstr "elenca i branch in colonne"
+
+#: builtin/branch.c:657 builtin/for-each-ref.c:42 builtin/notes.c:415
+#: builtin/notes.c:418 builtin/notes.c:581 builtin/notes.c:584
+#: builtin/tag.c:433
+msgid "object"
+msgstr "oggetto"
+
+#: builtin/branch.c:658
+msgid "print only branches of the object"
+msgstr "stampa solo i branch dell'oggetto"
+
+#: builtin/branch.c:660 builtin/for-each-ref.c:48 builtin/tag.c:440
+msgid "sorting and filtering are case insensitive"
+msgstr ""
+"l'ordinamento e il filtraggio non fanno differenza tra maiuscole e minuscole"
+
+#: builtin/branch.c:661 builtin/for-each-ref.c:38 builtin/tag.c:438
+#: builtin/verify-tag.c:38
+msgid "format to use for the output"
+msgstr "formato da usare per l'output"
+
+#: builtin/branch.c:684 builtin/clone.c:784
+msgid "HEAD not found below refs/heads!"
+msgstr "HEAD non trovato fra i riferimenti/head!"
+
+#: builtin/branch.c:708
+msgid "--column and --verbose are incompatible"
+msgstr "--column e --verbose non sono compatibili"
+
+#: builtin/branch.c:723 builtin/branch.c:777 builtin/branch.c:786
+msgid "branch name required"
+msgstr "nome branch richiesto"
+
+#: builtin/branch.c:753
+msgid "Cannot give description to detached HEAD"
+msgstr "Impossibile fornire una descrizione per l'HEAD scollegato"
+
+#: builtin/branch.c:758
+msgid "cannot edit description of more than one branch"
+msgstr "impossibile modificare la descrizione per più di un branch"
+
+#: builtin/branch.c:765
+#, c-format
+msgid "No commit on branch '%s' yet."
+msgstr "Non esiste ancora nessun commit sul branch '%s'."
+
+#: builtin/branch.c:768
+#, c-format
+msgid "No branch named '%s'."
+msgstr "Non esiste alcun branch denominato '%s'."
+
+#: builtin/branch.c:783
+msgid "too many branches for a copy operation"
+msgstr "sono presenti troppi branch per consentire un'operazione di copia"
+
+#: builtin/branch.c:792
+msgid "too many arguments for a rename operation"
+msgstr ""
+"sono presenti troppi argomenti per consentire un'operazione di "
+"ridenominazione"
+
+#: builtin/branch.c:797
+msgid "too many arguments to set new upstream"
+msgstr ""
+"sono presenti troppi argomenti per consentire l'impostazione del nuovo "
+"upstream"
+
+#: builtin/branch.c:801
+#, c-format
+msgid ""
+"could not set upstream of HEAD to %s when it does not point to any branch."
+msgstr ""
+"impossibile impostare l'upstream di HEAD a %s quando non punta ad alcun "
+"branch."
+
+#: builtin/branch.c:804 builtin/branch.c:827
+#, c-format
+msgid "no such branch '%s'"
+msgstr "branch '%s' non esistente"
+
+#: builtin/branch.c:808
+#, c-format
+msgid "branch '%s' does not exist"
+msgstr "il branch '%s' non esiste"
+
+#: builtin/branch.c:821
+msgid "too many arguments to unset upstream"
+msgstr ""
+"sono presenti troppi argomenti per rimuovere le informazioni sull'upstream"
+
+#: builtin/branch.c:825
+msgid "could not unset upstream of HEAD when it does not point to any branch."
+msgstr ""
+"impossibile rimuovere le informazioni sull'upstream di HEAD quando non punta "
+"ad alcun branch."
+
+#: builtin/branch.c:831
+#, c-format
+msgid "Branch '%s' has no upstream information"
+msgstr "Il branch '%s' non ha informazioni sull'upstream"
+
+#: builtin/branch.c:841
+msgid ""
+"The -a, and -r, options to 'git branch' do not take a branch name.\n"
+"Did you mean to use: -a|-r --list <pattern>?"
+msgstr ""
+"Le opzioni di 'git branch' -a e -r non richiedono un nome branch.\n"
+"Forse volevi usare: -a|-r --list <pattern>?"
+
+#: builtin/branch.c:845
+msgid ""
+"the '--set-upstream' option is no longer supported. Please use '--track' or "
+"'--set-upstream-to' instead."
+msgstr ""
+"l'opzione '--set-upstream' non è più supportata. Usa '--track' o '--set-"
+"upstream-to'."
+
+#: builtin/bundle.c:15 builtin/bundle.c:23
+msgid "git bundle create [<options>] <file> <git-rev-list args>"
+msgstr "git bundle create [<opzioni>] <file> <argomenti git-rev-list>"
+
+#: builtin/bundle.c:16 builtin/bundle.c:28
+msgid "git bundle verify [<options>] <file>"
+msgstr "git bundle verify [<opzioni>] <file>"
+
+#: builtin/bundle.c:17 builtin/bundle.c:33
+msgid "git bundle list-heads <file> [<refname>...]"
+msgstr "git bundle list-heads <file> [<nome riferimento>...]"
+
+#: builtin/bundle.c:18 builtin/bundle.c:38
+msgid "git bundle unbundle <file> [<refname>...]"
+msgstr "git bundle unbundle <file> [<nome riferimento>...]"
+
+#: builtin/bundle.c:66 builtin/pack-objects.c:3228
+msgid "do not show progress meter"
+msgstr "non visualizzare la barra di avanzamento"
+
+#: builtin/bundle.c:68 builtin/pack-objects.c:3230
+msgid "show progress meter"
+msgstr "visualizza la barra di avanzamento"
+
+#: builtin/bundle.c:70 builtin/pack-objects.c:3232
+msgid "show progress meter during object writing phase"
+msgstr ""
+"visualizza la barra di avanzamento durante la fase di scrittura oggetti"
+
+#: builtin/bundle.c:73 builtin/pack-objects.c:3235
+msgid "similar to --all-progress when progress meter is shown"
+msgstr "simile a --all-progress quando è visualizzata la barra di avanzamento"
+
+#: builtin/bundle.c:93
+msgid "Need a repository to create a bundle."
+msgstr "Per creare un bundle è necessario un repository."
+
+#: builtin/bundle.c:104
+msgid "do not show bundle details"
+msgstr "non visualizzare i dettagli sul bundle"
+
+#: builtin/bundle.c:119
+#, c-format
+msgid "%s is okay\n"
+msgstr "%s è corretto\n"
+
+#: builtin/bundle.c:160
+msgid "Need a repository to unbundle."
+msgstr "Per decomprimere un bundle è necessario un repository."
+
+#: builtin/bundle.c:168 builtin/remote.c:1609
+msgid "be verbose; must be placed before a subcommand"
+msgstr ""
+"visualizza ulteriori dettagli; deve essere collocato prima di un sottocomando"
+
+#: builtin/bundle.c:190 builtin/remote.c:1640
+#, c-format
+msgid "Unknown subcommand: %s"
+msgstr "Sottocomando sconosciuto: %s"
+
+#: builtin/cat-file.c:595
+msgid ""
+"git cat-file (-t [--allow-unknown-type] | -s [--allow-unknown-type] | -e | -"
+"p | <type> | --textconv | --filters) [--path=<path>] <object>"
+msgstr ""
+"git cat-file (-t [--allow-unknown-type] | -s [--allow-unknown-type] | -e | -"
+"p | <tipo> | --textconv | --filters) [--path=<percorso>] <oggetto>"
+
+#: builtin/cat-file.c:596
+msgid ""
+"git cat-file (--batch | --batch-check) [--follow-symlinks] [--textconv | --"
+"filters]"
+msgstr ""
+"git cat-file (--batch | --batch-check) [--follow-symlinks] [--textconv | --"
+"filters]"
+
+#: builtin/cat-file.c:617
+msgid "only one batch option may be specified"
+msgstr "può essere specificata solo un'opzione batch"
+
+#: builtin/cat-file.c:635
+msgid "<type> can be one of: blob, tree, commit, tag"
+msgstr "<tipo> può essere uno fra blob, tree, commit, tag"
+
+#: builtin/cat-file.c:636
+msgid "show object type"
+msgstr "visualizza tipo oggetto"
+
+#: builtin/cat-file.c:637
+msgid "show object size"
+msgstr "visualizza dimensioni oggetto"
+
+#: builtin/cat-file.c:639
+msgid "exit with zero when there's no error"
+msgstr "esci con codice d'uscita zero se non si sono verificati errori"
+
+#: builtin/cat-file.c:640
+msgid "pretty-print object's content"
+msgstr "stampa il contenuto dell'oggetto con un formato leggibile"
+
+#: builtin/cat-file.c:642
+msgid "for blob objects, run textconv on object's content"
+msgstr "esegui textconv sul contenuto dell'oggetto (per gli oggetti blob)"
+
+#: builtin/cat-file.c:644
+msgid "for blob objects, run filters on object's content"
+msgstr "esegui i filtri sul contenuto dell'oggetto (per gli oggetti blob)"
+
+#: builtin/cat-file.c:645 git-submodule.sh:992
+msgid "blob"
+msgstr "blob"
+
+#: builtin/cat-file.c:646
+msgid "use a specific path for --textconv/--filters"
+msgstr "usa un percorso specifico per --textconv/--filters"
+
+#: builtin/cat-file.c:648
+msgid "allow -s and -t to work with broken/corrupt objects"
+msgstr "consenti a -s e -t di funzionare con oggetti malformati/corrotti"
+
+#: builtin/cat-file.c:649
+msgid "buffer --batch output"
+msgstr "esegui il buffering dell'output di --batch"
+
+#: builtin/cat-file.c:651
+msgid "show info and content of objects fed from the standard input"
+msgstr ""
+"visualizza le informazioni e il contenuto degli oggetti forniti nello "
+"standard input"
+
+#: builtin/cat-file.c:655
+msgid "show info about objects fed from the standard input"
+msgstr "visualizza le informazioni degli oggetti forniti nello standard input"
+
+#: builtin/cat-file.c:659
+msgid "follow in-tree symlinks (used with --batch or --batch-check)"
+msgstr ""
+"segui i collegamenti simbolici entro l'albero (usato con --batch o --batch-"
+"check)"
+
+#: builtin/cat-file.c:661
+msgid "show all objects with --batch or --batch-check"
+msgstr "visualizza tutti gli oggetti con --batch o --batch-check"
+
+#: builtin/cat-file.c:663
+msgid "do not order --batch-all-objects output"
+msgstr "non ordinare l'output di --batch-all-objects"
+
+#: builtin/check-attr.c:13
+msgid "git check-attr [-a | --all | <attr>...] [--] <pathname>..."
+msgstr "git check-attr [-a | --all | <attributo>...] [--] <nome percorso>..."
+
+#: builtin/check-attr.c:14
+msgid "git check-attr --stdin [-z] [-a | --all | <attr>...]"
+msgstr "git check-attr --stdin [-z] [-a | --all | <attributo>...]"
+
+#: builtin/check-attr.c:21
+msgid "report all attributes set on file"
+msgstr "indica tutti gli attributi impostati sul file"
+
+#: builtin/check-attr.c:22
+msgid "use .gitattributes only from the index"
+msgstr "usa solo il file .gitattributes dell'indice"
+
+#: builtin/check-attr.c:23 builtin/check-ignore.c:25 builtin/hash-object.c:102
+msgid "read file names from stdin"
+msgstr "leggi i nomi dei file dallo standard input"
+
+#: builtin/check-attr.c:25 builtin/check-ignore.c:27
+msgid "terminate input and output records by a NUL character"
+msgstr "termina i record di input e output con un carattere NUL"
+
+#: builtin/check-ignore.c:21 builtin/checkout.c:1435 builtin/gc.c:537
+#: builtin/worktree.c:506
+msgid "suppress progress reporting"
+msgstr "non visualizzare l'avanzamento dell'operazione"
+
+#: builtin/check-ignore.c:29
+msgid "show non-matching input paths"
+msgstr "visualizza i percorsi di input non corrispondenti"
+
+#: builtin/check-ignore.c:31
+msgid "ignore index when checking"
+msgstr "ignora l'indice durante il controllo"
+
+#: builtin/check-ignore.c:160
+msgid "cannot specify pathnames with --stdin"
+msgstr "impossibile specificare i nomi percorso con --stdin"
+
+#: builtin/check-ignore.c:163
+msgid "-z only makes sense with --stdin"
+msgstr "-z ha senso solo con --stdin"
+
+#: builtin/check-ignore.c:165
+msgid "no path specified"
+msgstr "nessun percorso specificato"
+
+#: builtin/check-ignore.c:169
+msgid "--quiet is only valid with a single pathname"
+msgstr "--quiet è valido solo con un nome percorso singolo"
+
+#: builtin/check-ignore.c:171
+msgid "cannot have both --quiet and --verbose"
+msgstr "non è possibile usare sia --quiet sia --verbose"
+
+#: builtin/check-ignore.c:174
+msgid "--non-matching is only valid with --verbose"
+msgstr "--non-matching è valido solo con --verbose"
+
+#: builtin/check-mailmap.c:9
+msgid "git check-mailmap [<options>] <contact>..."
+msgstr "git check-mailmap [<opzioni>] <contatto>..."
+
+#: builtin/check-mailmap.c:14
+msgid "also read contacts from stdin"
+msgstr "leggi i contatti anche dallo standard input"
+
+#: builtin/check-mailmap.c:25
+#, c-format
+msgid "unable to parse contact: %s"
+msgstr "impossibile analizzare il contatto: %s"
+
+#: builtin/check-mailmap.c:48
+msgid "no contacts specified"
+msgstr "nessun contatto specificato"
+
+#: builtin/checkout-index.c:131
+msgid "git checkout-index [<options>] [--] [<file>...]"
+msgstr "git checkout-index [<opzioni>] [--] [<file>...]"
+
+#: builtin/checkout-index.c:148
+msgid "stage should be between 1 and 3 or all"
+msgstr "la fase dev'essere compresa fra 1 e 3 o all"
+
+#: builtin/checkout-index.c:164
+msgid "check out all files in the index"
+msgstr "esegui il checkout di tutti i file nell'indice"
+
+#: builtin/checkout-index.c:165
+msgid "force overwrite of existing files"
+msgstr "forza la sovrascrittura dei file esistenti"
+
+#: builtin/checkout-index.c:167
+msgid "no warning for existing files and files not in index"
+msgstr "non emettere un avviso per i file esistenti e i file non nell'indice"
+
+#: builtin/checkout-index.c:169
+msgid "don't checkout new files"
+msgstr "non eseguire il checkout dei file nuovi"
+
+#: builtin/checkout-index.c:171
+msgid "update stat information in the index file"
+msgstr "aggiorna le informazioni stat nel file indice"
+
+#: builtin/checkout-index.c:175
+msgid "read list of paths from the standard input"
+msgstr "leggi l'elenco dei percorsi dallo standard input"
+
+#: builtin/checkout-index.c:177
+msgid "write the content to temporary files"
+msgstr "scrivi il contenuto in file temporanei"
+
+#: builtin/checkout-index.c:178 builtin/column.c:31
+#: builtin/submodule--helper.c:1385 builtin/submodule--helper.c:1388
+#: builtin/submodule--helper.c:1396 builtin/submodule--helper.c:1882
+#: builtin/worktree.c:679
+msgid "string"
+msgstr "stringa"
+
+#: builtin/checkout-index.c:179
+msgid "when creating files, prepend <string>"
+msgstr "aggiungi il prefisso <stringa> durante la creazione dei file"
+
+#: builtin/checkout-index.c:181
+msgid "copy out the files from named stage"
+msgstr "copia i file dalla fase specificata"
+
+#: builtin/checkout.c:31
+msgid "git checkout [<options>] <branch>"
+msgstr "git checkout [<opzioni>] <branch>"
+
+#: builtin/checkout.c:32
+msgid "git checkout [<options>] [<branch>] -- <file>..."
+msgstr "git checkout [<opzioni>] [<branch>] -- <file>..."
+
+#: builtin/checkout.c:37
+msgid "git switch [<options>] [<branch>]"
+msgstr "git switch [<opzioni>] <branch>"
+
+#: builtin/checkout.c:42
+msgid "git restore [<options>] [--source=<branch>] <file>..."
+msgstr "git restore [<opzioni>] [--source=<branch>] <file>..."
+
+#: builtin/checkout.c:175 builtin/checkout.c:214
+#, c-format
+msgid "path '%s' does not have our version"
+msgstr "il percorso '%s' non ha la nostra versione"
+
+#: builtin/checkout.c:177 builtin/checkout.c:216
+#, c-format
+msgid "path '%s' does not have their version"
+msgstr "il percorso '%s' non ha la loro versione"
+
+#: builtin/checkout.c:193
+#, c-format
+msgid "path '%s' does not have all necessary versions"
+msgstr "il percorso '%s' non ha tutte le versioni necessarie"
+
+#: builtin/checkout.c:243
+#, c-format
+msgid "path '%s' does not have necessary versions"
+msgstr "il percorso '%s' non ha le versioni necessarie"
+
+#: builtin/checkout.c:261
+#, c-format
+msgid "path '%s': cannot merge"
+msgstr "percorso '%s': impossibile eseguire il merge"
+
+#: builtin/checkout.c:277
+#, c-format
+msgid "Unable to add merge result for '%s'"
+msgstr "Impossibile aggiungere il risultato del merge per '%s'"
+
+#: builtin/checkout.c:377
+#, c-format
+msgid "Recreated %d merge conflict"
+msgid_plural "Recreated %d merge conflicts"
+msgstr[0] "Ricreato %d conflitto di merge"
+msgstr[1] "Ricreati %d conflitti di merge"
+
+#: builtin/checkout.c:382
+#, c-format
+msgid "Updated %d path from %s"
+msgid_plural "Updated %d paths from %s"
+msgstr[0] "Aggiornato %d percorso da %s"
+msgstr[1] "Aggiornati %d percorsi da %s"
+
+#: builtin/checkout.c:389
+#, c-format
+msgid "Updated %d path from the index"
+msgid_plural "Updated %d paths from the index"
+msgstr[0] "Aggiornato %d percorso dall'indice"
+msgstr[1] "Aggiornati %d percorsi dall'indice"
+
+#: builtin/checkout.c:412 builtin/checkout.c:415 builtin/checkout.c:418
+#: builtin/checkout.c:422
+#, c-format
+msgid "'%s' cannot be used with updating paths"
+msgstr "'%s' non può essere usato con i percorsi in fase di aggiornamento"
+
+#: builtin/checkout.c:425 builtin/checkout.c:428
+#, c-format
+msgid "'%s' cannot be used with %s"
+msgstr "'%s' non può essere usato con %s"
+
+#: builtin/checkout.c:432
+#, c-format
+msgid "Cannot update paths and switch to branch '%s' at the same time."
+msgstr ""
+"Impossibile aggiornare dei percorsi e passare al branch '%s' "
+"contemporaneamente."
+
+#: builtin/checkout.c:436
+#, c-format
+msgid "neither '%s' or '%s' is specified"
+msgstr "né '%s' né '%s' sono stati specificati"
+
+#: builtin/checkout.c:440
+#, c-format
+msgid "'%s' must be used when '%s' is not specified"
+msgstr "'%s' dev'essere usato quando '%s' non è specificato"
+
+#: builtin/checkout.c:445 builtin/checkout.c:450
+#, c-format
+msgid "'%s' or '%s' cannot be used with %s"
+msgstr "'%s' o '%s' non possono essere usati con %s"
+
+#: builtin/checkout.c:509 builtin/checkout.c:516
+#, c-format
+msgid "path '%s' is unmerged"
+msgstr "il percorso '%s' non è stato sottoposto a merge"
+
+#: builtin/checkout.c:682 builtin/sparse-checkout.c:82
+msgid "you need to resolve your current index first"
+msgstr "prima devi risolvere l'indice corrente"
+
+#: builtin/checkout.c:732
+#, c-format
+msgid ""
+"cannot continue with staged changes in the following files:\n"
+"%s"
+msgstr ""
+"impossibile continuare con modifiche in stage nei file seguenti:\n"
+"%s"
+
+#: builtin/checkout.c:835
+#, c-format
+msgid "Can not do reflog for '%s': %s\n"
+msgstr "Impossibile esaminare il registro dei riferimenti per '%s': %s\n"
+
+#: builtin/checkout.c:877
+msgid "HEAD is now at"
+msgstr "HEAD si trova ora a"
+
+#: builtin/checkout.c:881 builtin/clone.c:716
+msgid "unable to update HEAD"
+msgstr "impossibile aggiornare HEAD"
+
+#: builtin/checkout.c:885
+#, c-format
+msgid "Reset branch '%s'\n"
+msgstr "Ripristina il branch '%s'\n"
+
+#: builtin/checkout.c:888
+#, c-format
+msgid "Already on '%s'\n"
+msgstr "Si è già su '%s'\n"
+
+#: builtin/checkout.c:892
+#, c-format
+msgid "Switched to and reset branch '%s'\n"
+msgstr "Si è passati al branch '%s' e lo si è reimpostato\n"
+
+#: builtin/checkout.c:894 builtin/checkout.c:1291
+#, c-format
+msgid "Switched to a new branch '%s'\n"
+msgstr "Si è passati a un nuovo branch '%s'\n"
+
+#: builtin/checkout.c:896
+#, c-format
+msgid "Switched to branch '%s'\n"
+msgstr "Si è passati al branch '%s'\n"
+
+#: builtin/checkout.c:947
+#, c-format
+msgid " ... and %d more.\n"
+msgstr " ...e altri %d.\n"
+
+#: builtin/checkout.c:953
+#, c-format
+msgid ""
+"Warning: you are leaving %d commit behind, not connected to\n"
+"any of your branches:\n"
+"\n"
+"%s\n"
+msgid_plural ""
+"Warning: you are leaving %d commits behind, not connected to\n"
+"any of your branches:\n"
+"\n"
+"%s\n"
+msgstr[0] ""
+"Attenzione: stai rimuovendo %d commit non collegato ad alcun\n"
+"branch:\n"
+"\n"
+"%s\n"
+msgstr[1] ""
+"Attenzione: stai rimuovendo %d commit non collegati ad alcun\n"
+"branch:\n"
+"\n"
+"%s\n"
+
+#: builtin/checkout.c:972
+#, c-format
+msgid ""
+"If you want to keep it by creating a new branch, this may be a good time\n"
+"to do so with:\n"
+"\n"
+" git branch <new-branch-name> %s\n"
+"\n"
+msgid_plural ""
+"If you want to keep them by creating a new branch, this may be a good time\n"
+"to do so with:\n"
+"\n"
+" git branch <new-branch-name> %s\n"
+"\n"
+msgstr[0] ""
+"Se vuoi mantenerlo creando un nuovo branch, questo potrebbe essere\n"
+"un buon momento per farlo con:\n"
+"\n"
+" git branch <nome del nuovo branch> %s\n"
+"\n"
+msgstr[1] ""
+"Se vuoi mantenerli creando un nuovo branch, questo potrebbe essere\n"
+"un buon momento per farlo con:\n"
+"\n"
+" git branch <nome del nuovo branch> %s\n"
+"\n"
+
+#: builtin/checkout.c:1007
+msgid "internal error in revision walk"
+msgstr "errore interno durante la visita delle revisioni"
+
+#: builtin/checkout.c:1011
+msgid "Previous HEAD position was"
+msgstr "La precedente posizione di HEAD era"
+
+#: builtin/checkout.c:1051 builtin/checkout.c:1286
+msgid "You are on a branch yet to be born"
+msgstr "Sei su un branch che deve ancora essere creato"
+
+#: builtin/checkout.c:1178
+msgid "only one reference expected"
+msgstr "atteso solo un riferimento"
+
+#: builtin/checkout.c:1195
+#, c-format
+msgid "only one reference expected, %d given."
+msgstr "atteso solo un riferimento, %d specificati."
+
+#: builtin/checkout.c:1232
+#, c-format
+msgid ""
+"'%s' could be both a local file and a tracking branch.\n"
+"Please use -- (and optionally --no-guess) to disambiguate"
+msgstr ""
+"'%s' potrebbe essere sia un file locale, sia un branch da tracciare.\n"
+"Usa -- (e facoltativamente --no-guess) per rimuovere l'ambiguità"
+
+#: builtin/checkout.c:1245 builtin/worktree.c:290 builtin/worktree.c:455
+#, c-format
+msgid "invalid reference: %s"
+msgstr "riferimento non valido: %s"
+
+#: builtin/checkout.c:1258 builtin/checkout.c:1622
+#, c-format
+msgid "reference is not a tree: %s"
+msgstr "il riferimento non è un albero: %s"
+
+#: builtin/checkout.c:1305
+#, c-format
+msgid "a branch is expected, got tag '%s'"
+msgstr "atteso branch, ricevuto tag '%s'"
+
+#: builtin/checkout.c:1307
+#, c-format
+msgid "a branch is expected, got remote branch '%s'"
+msgstr "atteso branch, ricevuto branch remoto '%s'"
+
+#: builtin/checkout.c:1308 builtin/checkout.c:1316
+#, c-format
+msgid "a branch is expected, got '%s'"
+msgstr "atteso branch, ricevuto '%s'"
+
+#: builtin/checkout.c:1311
+#, c-format
+msgid "a branch is expected, got commit '%s'"
+msgstr "atteso branch, ricevuto commit '%s'"
+
+#: builtin/checkout.c:1327
+msgid ""
+"cannot switch branch while merging\n"
+"Consider \"git merge --quit\" or \"git worktree add\"."
+msgstr ""
+"impossibile cambiare branch durante un merge\n"
+"Considera l'uso di \"git merge --quit\" o di \"git worktree add\"."
+
+#: builtin/checkout.c:1331
+msgid ""
+"cannot switch branch in the middle of an am session\n"
+"Consider \"git am --quit\" or \"git worktree add\"."
+msgstr ""
+"impossibile cambiare branch nel bel mezzo di una sessione am\n"
+"Considera l'uso di \"git am --quit\" o di \"git worktree add\"."
+
+#: builtin/checkout.c:1335
+msgid ""
+"cannot switch branch while rebasing\n"
+"Consider \"git rebase --quit\" or \"git worktree add\"."
+msgstr ""
+"impossibile cambiare branch durante un rebase\n"
+"Considera l'uso di \"git rebase --quit\" o di \"git worktree add\"."
+
+#: builtin/checkout.c:1339
+msgid ""
+"cannot switch branch while cherry-picking\n"
+"Consider \"git cherry-pick --quit\" or \"git worktree add\"."
+msgstr ""
+"impossibile cambiare branch durante un cherry-pick\n"
+"Considera l'uso di \"git cherry-pick --quit\" o di \"git worktree add\"."
+
+#: builtin/checkout.c:1343
+msgid ""
+"cannot switch branch while reverting\n"
+"Consider \"git revert --quit\" or \"git worktree add\"."
+msgstr ""
+"impossibile cambiare branch durante un revert\n"
+"Considera l'uso di \"git revert --quit\" o di \"git worktree add\"."
+
+#: builtin/checkout.c:1347
+msgid "you are switching branch while bisecting"
+msgstr "stai cambiando branch durante una bisezione"
+
+#: builtin/checkout.c:1354
+msgid "paths cannot be used with switching branches"
+msgstr "i percorsi non possono essere usati passando da un branch a un altro"
+
+#: builtin/checkout.c:1357 builtin/checkout.c:1361 builtin/checkout.c:1365
+#, c-format
+msgid "'%s' cannot be used with switching branches"
+msgstr "'%s' non può essere usato passando da un branch a un altro"
+
+#: builtin/checkout.c:1369 builtin/checkout.c:1372 builtin/checkout.c:1375
+#: builtin/checkout.c:1380 builtin/checkout.c:1385
+#, c-format
+msgid "'%s' cannot be used with '%s'"
+msgstr "'%s' non può essere usato con '%s'"
+
+#: builtin/checkout.c:1382
+#, c-format
+msgid "'%s' cannot take <start-point>"
+msgstr "'%s' non accetta l'argomento <punto di partenza>"
+
+#: builtin/checkout.c:1390
+#, c-format
+msgid "Cannot switch branch to a non-commit '%s'"
+msgstr "Impossibile cambiare branch per passare a '%s' che non è un commit"
+
+#: builtin/checkout.c:1397
+msgid "missing branch or commit argument"
+msgstr "argomento branch o commit mancante"
+
+#: builtin/checkout.c:1439 builtin/clone.c:91 builtin/commit-graph.c:52
+#: builtin/commit-graph.c:113 builtin/fetch.c:167 builtin/merge.c:285
+#: builtin/multi-pack-index.c:27 builtin/pull.c:138 builtin/push.c:563
+#: builtin/send-pack.c:174
+msgid "force progress reporting"
+msgstr "forza l'indicazione d'avanzamento dell'operazione"
+
+#: builtin/checkout.c:1440
+msgid "perform a 3-way merge with the new branch"
+msgstr "esegui un merge a tre vie con il nuovo branch"
+
+#: builtin/checkout.c:1441 builtin/log.c:1690 parse-options.h:322
+msgid "style"
+msgstr "stile"
+
+#: builtin/checkout.c:1442
+msgid "conflict style (merge or diff3)"
+msgstr "stile conflitti (merge o diff3)"
+
+#: builtin/checkout.c:1454 builtin/worktree.c:503
+msgid "detach HEAD at named commit"
+msgstr "scollega l'HEAD al commit specificato"
+
+#: builtin/checkout.c:1455
+msgid "set upstream info for new branch"
+msgstr "imposta le informazioni sull'upstream per il nuovo branch"
+
+#: builtin/checkout.c:1457
+msgid "force checkout (throw away local modifications)"
+msgstr "esegui forzatamente il checkout (scarta le modifiche locali)"
+
+#: builtin/checkout.c:1459
+msgid "new-branch"
+msgstr "nuovo branch"
+
+#: builtin/checkout.c:1459
+msgid "new unparented branch"
+msgstr "nuovo branch senza genitore"
+
+#: builtin/checkout.c:1461 builtin/merge.c:288
+msgid "update ignored files (default)"
+msgstr "aggiorna i file ignorati (impostazione predefinita)"
+
+#: builtin/checkout.c:1464
+msgid "do not check if another worktree is holding the given ref"
+msgstr ""
+"non controllare se un altro albero di lavoro contiene il riferimento "
+"specificato"
+
+#: builtin/checkout.c:1477
+msgid "checkout our version for unmerged files"
+msgstr ""
+"esegui il checkout della nostra versione per i file non sottoposti a merge"
+
+#: builtin/checkout.c:1480
+msgid "checkout their version for unmerged files"
+msgstr ""
+"esegui il checkout della loro versione per i file non sottoposti a merge"
+
+#: builtin/checkout.c:1484
+msgid "do not limit pathspecs to sparse entries only"
+msgstr "non limitare gli specificatori percorso solo alle voci sparse"
+
+#: builtin/checkout.c:1537
+msgid "-b, -B and --orphan are mutually exclusive"
+msgstr "le opzioni -b, -B e --orphan sono mutuamente esclusive"
+
+#: builtin/checkout.c:1540
+msgid "-p and --overlay are mutually exclusive"
+msgstr "le opzioni -p e --overlay sono mutualmente esclusive"
+
+#: builtin/checkout.c:1577
+msgid "--track needs a branch name"
+msgstr "--track richiede il nome di un branch"
+
+#: builtin/checkout.c:1582
+msgid "missing branch name; try -b"
+msgstr "nome del branch mancante; prova con -b"
+
+#: builtin/checkout.c:1615
+#, c-format
+msgid "could not resolve %s"
+msgstr "impossibile risolvere %s"
+
+#: builtin/checkout.c:1631
+msgid "invalid path specification"
+msgstr "specificatore percorso non valido"
+
+#: builtin/checkout.c:1638
+#, c-format
+msgid "'%s' is not a commit and a branch '%s' cannot be created from it"
+msgstr ""
+"'%s' non è un commit e non si può creare un branch '%s' che parta da esso"
+
+#: builtin/checkout.c:1642
+#, c-format
+msgid "git checkout: --detach does not take a path argument '%s'"
+msgstr "git checkout: --detach non accetta un percorso '%s' come argomento"
+
+#: builtin/checkout.c:1651
+msgid "--pathspec-from-file is incompatible with --detach"
+msgstr "--pathspec-from-file non è compatibile con --detach"
+
+#: builtin/checkout.c:1654 builtin/reset.c:324
+msgid "--pathspec-from-file is incompatible with --patch"
+msgstr "--pathspec-from-file non è compatibile con --patch"
+
+#: builtin/checkout.c:1665
+msgid ""
+"git checkout: --ours/--theirs, --force and --merge are incompatible when\n"
+"checking out of the index."
+msgstr ""
+"git checkout: --ours/--theirs, --force e --merge sono incompatibili quando\n"
+"si esegue il checkout dell'indice."
+
+#: builtin/checkout.c:1670
+msgid "you must specify path(s) to restore"
+msgstr "devi specificare il percorso/i percorsi da ripristinare"
+
+#: builtin/checkout.c:1689
+#, c-format
+msgid ""
+"'%s' matched more than one remote tracking branch.\n"
+"We found %d remotes with a reference that matched. So we fell back\n"
+"on trying to resolve the argument as a path, but failed there too!\n"
+"\n"
+"If you meant to check out a remote tracking branch on, e.g. 'origin',\n"
+"you can do so by fully qualifying the name with the --track option:\n"
+"\n"
+"    git checkout --track origin/<name>\n"
+"\n"
+"If you'd like to always have checkouts of an ambiguous <name> prefer\n"
+"one remote, e.g. the 'origin' remote, consider setting\n"
+"checkout.defaultRemote=origin in your config."
+msgstr ""
+"'%s' corrisponde a più di un branch remoto.\n"
+"Abbiamo trovato %d remoti con un riferimento corrispondente, per cui\n"
+"abbiamo ripiegato tentando di risolvere l'argomento come percorso, ma\n"
+"non siamo riusciti nemmeno a portare a termine tale operazione!\n"
+"\n"
+"Se intendevi eseguire il checkout di un branch remoto, ad es. 'origin',\n"
+"puoi farlo usando la versione completamente qualificata del nome\n"
+"con l'opzione --track:\n"
+"\n"
+"    git checkout --track origin/<nome>\n"
+"\n"
+"Se preferisci che i checkout di un <nome> ambiguo siano sempre risolti\n"
+"rispetto a un particolare remoto, ad es. 'origin', potresti voler\n"
+"impostare checkout.defaultRemote=origin nel tuo file di configurazione."
+
+#: builtin/checkout.c:1714 builtin/checkout.c:1716 builtin/checkout.c:1765
+#: builtin/checkout.c:1767 builtin/clone.c:121 builtin/remote.c:169
+#: builtin/remote.c:171 builtin/worktree.c:499 builtin/worktree.c:501
+msgid "branch"
+msgstr "branch"
+
+#: builtin/checkout.c:1715
+msgid "create and checkout a new branch"
+msgstr "crea un nuovo branch ed eseguine il checkout"
+
+#: builtin/checkout.c:1717
+msgid "create/reset and checkout a branch"
+msgstr "crea/reimposta un branch ed eseguine il checkout"
+
+#: builtin/checkout.c:1718
+msgid "create reflog for new branch"
+msgstr "crea il registro dei riferimenti per il nuovo branch"
+
+#: builtin/checkout.c:1720
+msgid "second guess 'git checkout <no-such-branch>' (default)"
+msgstr "prevedi 'git checkout <branch inesistente>' (impostazione predefinita)"
+
+#: builtin/checkout.c:1721
+msgid "use overlay mode (default)"
+msgstr "usa modalità overlay (impostazione predefinita)"
+
+#: builtin/checkout.c:1766
+msgid "create and switch to a new branch"
+msgstr "crea un nuovo branch e passa a quest'ultimo"
+
+#: builtin/checkout.c:1768
+msgid "create/reset and switch to a branch"
+msgstr "crea/reimposta un branch e passa a quest'ultimo"
+
+#: builtin/checkout.c:1770
+msgid "second guess 'git switch <no-such-branch>'"
+msgstr "prevedi 'git switch <branch inesistente>'"
+
+#: builtin/checkout.c:1772
+msgid "throw away local modifications"
+msgstr "scarta le modifiche locali"
+
+#: builtin/checkout.c:1804
+msgid "which tree-ish to checkout from"
+msgstr "albero da cui eseguire il checkout"
+
+#: builtin/checkout.c:1806
+msgid "restore the index"
+msgstr "ripristina l'indice"
+
+#: builtin/checkout.c:1808
+msgid "restore the working tree (default)"
+msgstr "ripristina l'albero di lavoro (impostazione predefinita)"
+
+#: builtin/checkout.c:1810
+msgid "ignore unmerged entries"
+msgstr "ignora voci non sottoposte a merge"
+
+#: builtin/checkout.c:1811
+msgid "use overlay mode"
+msgstr "usa modalità overlay"
+
+#: builtin/clean.c:28
+msgid ""
+"git clean [-d] [-f] [-i] [-n] [-q] [-e <pattern>] [-x | -X] [--] <paths>..."
+msgstr ""
+"git clean [-d] [-f] [-i] [-n] [-q] [-e <pattern>] [-x | -X] [--] "
+"<percorsi>..."
+
+#: builtin/clean.c:32
+#, c-format
+msgid "Removing %s\n"
+msgstr "Eliminazione di %s in corso\n"
+
+#: builtin/clean.c:33
+#, c-format
+msgid "Would remove %s\n"
+msgstr "Eliminerei %s\n"
+
+#: builtin/clean.c:34
+#, c-format
+msgid "Skipping repository %s\n"
+msgstr "Salto il repository %s\n"
+
+#: builtin/clean.c:35
+#, c-format
+msgid "Would skip repository %s\n"
+msgstr "Salterei il repository %s\n"
+
+#: builtin/clean.c:36
+#, c-format
+msgid "failed to remove %s"
+msgstr "eliminazione di %s non riuscita"
+
+#: builtin/clean.c:37
+#, c-format
+msgid "could not lstat %s\n"
+msgstr "impossibile eseguire l'lstat di %s\n"
+
+#: builtin/clean.c:301 git-add--interactive.perl:595
+#, c-format
+msgid ""
+"Prompt help:\n"
+"1          - select a numbered item\n"
+"foo        - select item based on unique prefix\n"
+"           - (empty) select nothing\n"
+msgstr ""
+"Guida al prompt:\n"
+"1          - seleziona un elemento numerato\n"
+"pippo      - seleziona un elemento basandoti su un prefisso univoco\n"
+"           - (vuoto) non selezionare niente\n"
+
+#: builtin/clean.c:305 git-add--interactive.perl:604
+#, c-format
+msgid ""
+"Prompt help:\n"
+"1          - select a single item\n"
+"3-5        - select a range of items\n"
+"2-3,6-9    - select multiple ranges\n"
+"foo        - select item based on unique prefix\n"
+"-...       - unselect specified items\n"
+"*          - choose all items\n"
+"           - (empty) finish selecting\n"
+msgstr ""
+"Guida al prompt:\n"
+"1          - seleziona un singolo elemento\n"
+"3-5        - seleziona un intervallo di elementi\n"
+"2-3,6-9    - seleziona intervalli multipli\n"
+"pippo      - seleziona un elemento basandoti su un prefisso univoco\n"
+"-...       - deseleziona elementi specifici\n"
+"*          - seleziona tutti gli elementi\n"
+"           - (vuoto) termina il processo di selezione\n"
+
+#: builtin/clean.c:521 git-add--interactive.perl:570
+#: git-add--interactive.perl:575
+#, c-format, perl-format
+msgid "Huh (%s)?\n"
+msgstr "Eh (%s)?\n"
+
+#: builtin/clean.c:663
+#, c-format
+msgid "Input ignore patterns>> "
+msgstr "Immetti i pattern da ignorare>> "
+
+#: builtin/clean.c:700
+#, c-format
+msgid "WARNING: Cannot find items matched by: %s"
+msgstr "ATTENZIONE: Impossibile trovare elementi corrispondenti a %s"
+
+#: builtin/clean.c:721
+msgid "Select items to delete"
+msgstr "Seleziona gli elementi da eliminare"
+
+#. TRANSLATORS: Make sure to keep [y/N] as is
+#: builtin/clean.c:762
+#, c-format
+msgid "Remove %s [y/N]? "
+msgstr "Eliminare %s [y/N]? "
+
+#: builtin/clean.c:795
+msgid ""
+"clean               - start cleaning\n"
+"filter by pattern   - exclude items from deletion\n"
+"select by numbers   - select items to be deleted by numbers\n"
+"ask each            - confirm each deletion (like \"rm -i\")\n"
+"quit                - stop cleaning\n"
+"help                - this screen\n"
+"?                   - help for prompt selection"
+msgstr ""
+"clean               - inizia la pulizia\n"
+"filter by pattern   - escludi degli elementi dall'eliminazione\n"
+"select by numbers   - seleziona gli elementi da eliminare specificandoli\n"
+"                      con dei numeri\n"
+"ask each            - conferma ogni eliminazione (come \"rm -i\")\n"
+"quit                - termina la pulizia\n"
+"help                - visualizza questa schermata\n"
+"?                   - guida al prompt di selezione"
+
+#: builtin/clean.c:831
+msgid "Would remove the following item:"
+msgid_plural "Would remove the following items:"
+msgstr[0] "Eliminerei il seguente elemento:"
+msgstr[1] "Eliminerei i seguenti elementi:"
+
+#: builtin/clean.c:847
+msgid "No more files to clean, exiting."
+msgstr "Non ci sono più file da ripulire, esco."
+
+#: builtin/clean.c:909
+msgid "do not print names of files removed"
+msgstr "non stampare i nomi dei file eliminati"
+
+#: builtin/clean.c:911
+msgid "force"
+msgstr "forza l'operazione"
+
+#: builtin/clean.c:912
+msgid "interactive cleaning"
+msgstr "pulizia interattiva"
+
+#: builtin/clean.c:914
+msgid "remove whole directories"
+msgstr "rimuovi intere directory"
+
+#: builtin/clean.c:915 builtin/describe.c:548 builtin/describe.c:550
+#: builtin/grep.c:901 builtin/log.c:177 builtin/log.c:179
+#: builtin/ls-files.c:557 builtin/name-rev.c:464 builtin/name-rev.c:466
+#: builtin/show-ref.c:179
+msgid "pattern"
+msgstr "pattern"
+
+#: builtin/clean.c:916
+msgid "add <pattern> to ignore rules"
+msgstr "aggiungi <pattern> alle regole usate per ignorare i file"
+
+#: builtin/clean.c:917
+msgid "remove ignored files, too"
+msgstr "elimina anche i file ignorati"
+
+#: builtin/clean.c:919
+msgid "remove only ignored files"
+msgstr "elimina solo i file ignorati"
+
+#: builtin/clean.c:937
+msgid "-x and -X cannot be used together"
+msgstr "-x e -X non possono essere usati insieme"
+
+#: builtin/clean.c:941
+msgid ""
+"clean.requireForce set to true and neither -i, -n, nor -f given; refusing to "
+"clean"
+msgstr ""
+"clean.requireForce è impostato a true e né -i, né -n, né -f sono stati "
+"specificati; mi rifiuto di eseguire la pulizia"
+
+#: builtin/clean.c:944
+msgid ""
+"clean.requireForce defaults to true and neither -i, -n, nor -f given; "
+"refusing to clean"
+msgstr ""
+"clean.requireForce è true per impostazione predefinita e né -i, né -n, né -f "
+"sono stati specificati; mi rifiuto di eseguire la pulizia"
+
+#: builtin/clone.c:45
+msgid "git clone [<options>] [--] <repo> [<dir>]"
+msgstr "git clone [<opzioni>] [--] <repository> [<directory>]"
+
+#: builtin/clone.c:93
+msgid "don't create a checkout"
+msgstr "non creare un checkout"
+
+#: builtin/clone.c:94 builtin/clone.c:96 builtin/init-db.c:489
+msgid "create a bare repository"
+msgstr "crea un repository spoglio"
+
+#: builtin/clone.c:98
+msgid "create a mirror repository (implies bare)"
+msgstr "crea un repository mirror (implica che sia spoglio)"
+
+#: builtin/clone.c:100
+msgid "to clone from a local repository"
+msgstr "per clonare da un repository locale"
+
+#: builtin/clone.c:102
+msgid "don't use local hardlinks, always copy"
+msgstr "non usare i collegamenti reali locali, copia sempre i file"
+
+#: builtin/clone.c:104
+msgid "setup as shared repository"
+msgstr "imposta il repository come condiviso"
+
+#: builtin/clone.c:107
+msgid "pathspec"
+msgstr "specificatore percorso"
+
+#: builtin/clone.c:107
+msgid "initialize submodules in the clone"
+msgstr "inizializza sottomoduli durante la clonazione"
+
+#: builtin/clone.c:110
+msgid "number of submodules cloned in parallel"
+msgstr "numero di sottomoduli clonati in parallelo"
+
+#: builtin/clone.c:111 builtin/init-db.c:486
+msgid "template-directory"
+msgstr "directory modelli"
+
+#: builtin/clone.c:112 builtin/init-db.c:487
+msgid "directory from which templates will be used"
+msgstr "directory da cui saranno recuperati i modelli"
+
+#: builtin/clone.c:114 builtin/clone.c:116 builtin/submodule--helper.c:1392
+#: builtin/submodule--helper.c:1885
+msgid "reference repository"
+msgstr "repository di riferimento"
+
+#: builtin/clone.c:118 builtin/submodule--helper.c:1394
+#: builtin/submodule--helper.c:1887
+msgid "use --reference only while cloning"
+msgstr "usa --reference solo durante la clonazione"
+
+#: builtin/clone.c:119 builtin/column.c:27 builtin/merge-file.c:46
+#: builtin/pack-objects.c:3294 builtin/repack.c:327
+msgid "name"
+msgstr "nome"
+
+#: builtin/clone.c:120
+msgid "use <name> instead of 'origin' to track upstream"
+msgstr "usa <nome> anziché 'origin' per tracciare l'upstream"
+
+#: builtin/clone.c:122
+msgid "checkout <branch> instead of the remote's HEAD"
+msgstr "esegui il checkout di <branch> anziché dell'HEAD del remoto"
+
+#: builtin/clone.c:124
+msgid "path to git-upload-pack on the remote"
+msgstr "percorso al comando remoto git-upload-pack"
+
+#: builtin/clone.c:125 builtin/fetch.c:168 builtin/grep.c:840
+#: builtin/pull.c:227
+msgid "depth"
+msgstr "profondità"
+
+#: builtin/clone.c:126
+msgid "create a shallow clone of that depth"
+msgstr "crea un clone shallow con questa profondità"
+
+#: builtin/clone.c:127 builtin/fetch.c:170 builtin/pack-objects.c:3283
+msgid "time"
+msgstr "tempo"
+
+#: builtin/clone.c:128
+msgid "create a shallow clone since a specific time"
+msgstr "crea un clone shallow a partire dall'istante specificato"
+
+#: builtin/clone.c:129 builtin/fetch.c:172 builtin/fetch.c:195
+#: builtin/rebase.c:1445
+msgid "revision"
+msgstr "revisione"
+
+#: builtin/clone.c:130 builtin/fetch.c:173
+msgid "deepen history of shallow clone, excluding rev"
+msgstr ""
+"aumenta la profondità della cronologia del clone shallow fino alla revisione "
+"specificata esclusa"
+
+#: builtin/clone.c:132
+msgid "clone only one branch, HEAD or --branch"
+msgstr "clona solo un branch, HEAD o quello specificato con --branch"
+
+#: builtin/clone.c:134
+msgid "don't clone any tags, and make later fetches not to follow them"
+msgstr "non clonare alcun tag e fai sì che i fetch successivi non li seguano"
+
+#: builtin/clone.c:136
+msgid "any cloned submodules will be shallow"
+msgstr "tutti i sottomoduli clonati saranno shallow"
+
+#: builtin/clone.c:137 builtin/init-db.c:495
+msgid "gitdir"
+msgstr "directory Git"
+
+#: builtin/clone.c:138 builtin/init-db.c:496
+msgid "separate git dir from working tree"
+msgstr "separa la directory Git dall'albero di lavoro"
+
+#: builtin/clone.c:139
+msgid "key=value"
+msgstr "chiave=valore"
+
+#: builtin/clone.c:140
+msgid "set config inside the new repository"
+msgstr "imposta la configurazione nel nuovo repository"
+
+#: builtin/clone.c:142 builtin/fetch.c:190 builtin/ls-remote.c:76
+#: builtin/push.c:573 builtin/send-pack.c:172
+msgid "server-specific"
+msgstr "specifica del server"
+
+#: builtin/clone.c:142 builtin/fetch.c:190 builtin/ls-remote.c:76
+#: builtin/push.c:573 builtin/send-pack.c:173
+msgid "option to transmit"
+msgstr "opzione da trasmettere"
+
+#: builtin/clone.c:143 builtin/fetch.c:191 builtin/pull.c:240
+#: builtin/push.c:574
+msgid "use IPv4 addresses only"
+msgstr "usa solo indirizzi IPv4"
+
+#: builtin/clone.c:145 builtin/fetch.c:193 builtin/pull.c:243
+#: builtin/push.c:576
+msgid "use IPv6 addresses only"
+msgstr "usa solo indirizzi IPv6"
+
+#: builtin/clone.c:149
+msgid "any cloned submodules will use their remote-tracking branch"
+msgstr ""
+"tutti i sottomoduli clonati useranno il loro rispettivo branch remoto "
+"tracciato"
+
+#: builtin/clone.c:151
+msgid "initialize sparse-checkout file to include only files at root"
+msgstr ""
+"inizializza il file sparse-checkout per includere solo i file nel percorso"
+" radice"
+
+#: builtin/clone.c:287
+msgid ""
+"No directory name could be guessed.\n"
+"Please specify a directory on the command line"
+msgstr ""
+"Non è stato possibile indovinare alcun nome directory.\n"
+"Specifica una directory tramite la riga di comando"
+
+#: builtin/clone.c:340
+#, c-format
+msgid "info: Could not add alternate for '%s': %s\n"
+msgstr "informazione: Impossibile aggiungere un alternato a '%s': %s\n"
+
+#: builtin/clone.c:413
+#, c-format
+msgid "%s exists and is not a directory"
+msgstr "%s esiste e non è una directory"
+
+#: builtin/clone.c:430
+#, c-format
+msgid "failed to start iterator over '%s'"
+msgstr "impossibile avviare l'iteratore su '%s'"
+
+#: builtin/clone.c:460
+#, c-format
+msgid "failed to create link '%s'"
+msgstr "creazione del collegamento '%s' non riuscita"
+
+#: builtin/clone.c:464
+#, c-format
+msgid "failed to copy file to '%s'"
+msgstr "copia del file in '%s' non riuscita"
+
+#: builtin/clone.c:469
+#, c-format
+msgid "failed to iterate over '%s'"
+msgstr "iterazione su '%s' non riuscita"
+
+#: builtin/clone.c:494
+#, c-format
+msgid "done.\n"
+msgstr "fatto.\n"
+
+#: builtin/clone.c:508
+msgid ""
+"Clone succeeded, but checkout failed.\n"
+"You can inspect what was checked out with 'git status'\n"
+"and retry with 'git restore --source=HEAD :/'\n"
+msgstr ""
+"Clone completato con successo, ma il checkout non è riuscito.\n"
+"Puoi esaminare gli elementi di cui è stato eseguito il checkout\n"
+"con 'git status' e riprovare ad eseguire il checkout con\n"
+"'git restore --source=HEAD :/'\n"
+
+#: builtin/clone.c:585
+#, c-format
+msgid "Could not find remote branch %s to clone."
+msgstr "Impossibile trovare il branch remoto %s da clonare."
+
+#: builtin/clone.c:704
+#, c-format
+msgid "unable to update %s"
+msgstr "impossibile aggiornare %s"
+
+#: builtin/clone.c:752
+msgid "failed to initialize sparse-checkout"
+msgstr "inizializzazione del file sparse-checkout non riuscita"
+
+#: builtin/clone.c:775
+msgid "remote HEAD refers to nonexistent ref, unable to checkout.\n"
+msgstr ""
+"l'HEAD remoto fa riferimento a un riferimento inesistente, impossibile "
+"eseguire il checkout.\n"
+
+#: builtin/clone.c:806
+msgid "unable to checkout working tree"
+msgstr "impossibile eseguire il checkout dell'albero di lavoro"
+
+#: builtin/clone.c:856
+msgid "unable to write parameters to config file"
+msgstr "impossibile scrivere i parametri nel file di configurazione"
+
+#: builtin/clone.c:919
+msgid "cannot repack to clean up"
+msgstr "impossibile eseguire il repack per pulire l'area di lavoro"
+
+#: builtin/clone.c:921
+msgid "cannot unlink temporary alternates file"
+msgstr "impossibile eseguire l'unlink del file alternates temporaneo"
+
+#: builtin/clone.c:959 builtin/receive-pack.c:1948
+msgid "Too many arguments."
+msgstr "Troppi argomenti."
+
+#: builtin/clone.c:963
+msgid "You must specify a repository to clone."
+msgstr "Devi specificare un repository da clonare."
+
+#: builtin/clone.c:976
+#, c-format
+msgid "--bare and --origin %s options are incompatible."
+msgstr "le opzioni --bare e --origin %s non sono compatibili."
+
+#: builtin/clone.c:979
+msgid "--bare and --separate-git-dir are incompatible."
+msgstr "le opzioni --bare e --separate-git-dir non sono compatibili."
+
+#: builtin/clone.c:992
+#, c-format
+msgid "repository '%s' does not exist"
+msgstr "il repository '%s' non esiste"
+
+#: builtin/clone.c:998 builtin/fetch.c:1787
+#, c-format
+msgid "depth %s is not a positive number"
+msgstr "la profondità %s non è un numero positivo"
+
+#: builtin/clone.c:1008
+#, c-format
+msgid "destination path '%s' already exists and is not an empty directory."
+msgstr ""
+"il percorso di destinazione '%s' esiste già e non è una directory vuota."
+
+#: builtin/clone.c:1018
+#, c-format
+msgid "working tree '%s' already exists."
+msgstr "l'albero di lavoro '%s' esiste già."
+
+#: builtin/clone.c:1033 builtin/clone.c:1054 builtin/difftool.c:271
+#: builtin/log.c:1866 builtin/worktree.c:302 builtin/worktree.c:334
+#, c-format
+msgid "could not create leading directories of '%s'"
+msgstr "impossibile creare le prime directory di '%s'"
+
+#: builtin/clone.c:1038
+#, c-format
+msgid "could not create work tree dir '%s'"
+msgstr "impossibile creare la directory dell'albero di lavoro '%s'"
+
+#: builtin/clone.c:1058
+#, c-format
+msgid "Cloning into bare repository '%s'...\n"
+msgstr "Clone nel repository spoglio '%s' in corso...\n"
+
+#: builtin/clone.c:1060
+#, c-format
+msgid "Cloning into '%s'...\n"
+msgstr "Clone in '%s' in corso...\n"
+
+#: builtin/clone.c:1084
+msgid ""
+"clone --recursive is not compatible with both --reference and --reference-if-"
+"able"
+msgstr ""
+"il clone --recursive non è compatibile né con --reference né con --reference-"
+"if-able"
+
+#: builtin/clone.c:1148
+msgid "--depth is ignored in local clones; use file:// instead."
+msgstr "L'opzione --depth è ignorata nei cloni locali; usa file://."
+
+#: builtin/clone.c:1150
+msgid "--shallow-since is ignored in local clones; use file:// instead."
+msgstr "L'opzione --shallow-since è ignorata nei cloni locali; usa file://."
+
+#: builtin/clone.c:1152
+msgid "--shallow-exclude is ignored in local clones; use file:// instead."
+msgstr "L'opzione --shallow-exclude è ignorata nei cloni locali; usa file://."
+
+#: builtin/clone.c:1154
+msgid "--filter is ignored in local clones; use file:// instead."
+msgstr "L'opzione --filter è ignorata nei cloni locali; usa file://."
+
+#: builtin/clone.c:1157
+msgid "source repository is shallow, ignoring --local"
+msgstr "il repository sorgente è shallow, ignoro l'opzione --local"
+
+#: builtin/clone.c:1162
+msgid "--local is ignored"
+msgstr "l'opzione --local è ignorata"
+
+#: builtin/clone.c:1237 builtin/clone.c:1245
+#, c-format
+msgid "Remote branch %s not found in upstream %s"
+msgstr "Il branch remoto %s non è stato trovato nell'upstream %s"
+
+#: builtin/clone.c:1248
+msgid "You appear to have cloned an empty repository."
+msgstr "Sembra che tu abbia clonato un repository vuoto."
+
+#: builtin/column.c:10
+msgid "git column [<options>]"
+msgstr "git column [<opzioni>]"
+
+#: builtin/column.c:27
+msgid "lookup config vars"
+msgstr "recupera le variabili di configurazione da qui"
+
+#: builtin/column.c:28 builtin/column.c:29
+msgid "layout to use"
+msgstr "layout da usare"
+
+#: builtin/column.c:30
+msgid "Maximum width"
+msgstr "Larghezza massima"
+
+#: builtin/column.c:31
+msgid "Padding space on left border"
+msgstr "Spazi vuoti per il margine sinistro"
+
+#: builtin/column.c:32
+msgid "Padding space on right border"
+msgstr "Spazi vuoti per il margine destro"
+
+#: builtin/column.c:33
+msgid "Padding space between columns"
+msgstr "Spazi vuoti fra le colonne"
+
+#: builtin/column.c:51
+msgid "--command must be the first argument"
+msgstr "--command deve essere il primo argomento"
+
+#: builtin/commit-tree.c:18
+msgid ""
+"git commit-tree [(-p <parent>)...] [-S[<keyid>]] [(-m <message>)...] [(-F "
+"<file>)...] <tree>"
+msgstr ""
+"git commit-tree [(-p <genitore>)...] [-S[<ID chiave>]] [(-m <messaggio>)...] "
+"[(-F <file>)...] <albero>"
+
+#: builtin/commit-tree.c:31
+#, c-format
+msgid "duplicate parent %s ignored"
+msgstr "genitore duplicato %s ignorato"
+
+#: builtin/commit-tree.c:56 builtin/commit-tree.c:136 builtin/log.c:526
+#, c-format
+msgid "not a valid object name %s"
+msgstr "%s non è un nome oggetto valido"
+
+#: builtin/commit-tree.c:93
+#, c-format
+msgid "git commit-tree: failed to open '%s'"
+msgstr "git commit-tree: apertura di '%s' non riuscita"
+
+#: builtin/commit-tree.c:96
+#, c-format
+msgid "git commit-tree: failed to read '%s'"
+msgstr "git commit-tree: lettura di '%s' non riuscita"
+
+#: builtin/commit-tree.c:98
+#, c-format
+msgid "git commit-tree: failed to close '%s'"
+msgstr "git commit-tree: chiusura di '%s' non riuscita"
+
+#: builtin/commit-tree.c:111
+msgid "parent"
+msgstr "genitore"
+
+#: builtin/commit-tree.c:112
+msgid "id of a parent commit object"
+msgstr "ID di un oggetto commit genitore"
+
+#: builtin/commit-tree.c:114 builtin/commit.c:1496 builtin/merge.c:270
+#: builtin/notes.c:409 builtin/notes.c:575 builtin/stash.c:1469
+#: builtin/tag.c:412
+msgid "message"
+msgstr "messaggio"
+
+#: builtin/commit-tree.c:115 builtin/commit.c:1496
+msgid "commit message"
+msgstr "messaggio di commit"
+
+#: builtin/commit-tree.c:118
+msgid "read commit log message from file"
+msgstr "leggi il messaggio di log del commit da un file"
+
+#: builtin/commit-tree.c:121 builtin/commit.c:1508 builtin/merge.c:287
+#: builtin/pull.c:195 builtin/revert.c:118
+msgid "GPG sign commit"
+msgstr "firma il commit con GPG"
+
+#: builtin/commit-tree.c:133
+msgid "must give exactly one tree"
+msgstr "è necessario fornire esattamente un albero"
+
+#: builtin/commit-tree.c:140
+msgid "git commit-tree: failed to read"
+msgstr "git commit-tree: lettura non riuscita"
+
+#: builtin/commit.c:41
+msgid "git commit [<options>] [--] <pathspec>..."
+msgstr "git commit [<opzioni>] [--] <specificatore percorso>..."
+
+#: builtin/commit.c:46
+msgid "git status [<options>] [--] <pathspec>..."
+msgstr "git status [<opzioni>] [--] <specificatore percorso>..."
+
+#: builtin/commit.c:51
+msgid ""
+"You asked to amend the most recent commit, but doing so would make\n"
+"it empty. You can repeat your command with --allow-empty, or you can\n"
+"remove the commit entirely with \"git reset HEAD^\".\n"
+msgstr ""
+"Hai richiesto di modificare il commit più recente, ma eseguire tale\n"
+"operazione lo renderebbe vuoto. Puoi ripetere l'esecuzione del comando\n"
+"con --allow-empty o puoi rimuovere completamente il commit con\n"
+"\"git reset HEAD^\".\n"
+
+#: builtin/commit.c:56
+msgid ""
+"The previous cherry-pick is now empty, possibly due to conflict resolution.\n"
+"If you wish to commit it anyway, use:\n"
+"\n"
+"    git commit --allow-empty\n"
+"\n"
+msgstr ""
+"Il cherry-pick precedente ora è vuoto, probabilmente a causa di alcuni\n"
+"conflitti risolti.\n"
+"Se vuoi comunque eseguirne il commit, usa:\n"
+"\n"
+"    git commit --allow-empty\n"
+"\n"
+
+#: builtin/commit.c:63
+msgid "Otherwise, please use 'git cherry-pick --skip'\n"
+msgstr "Altrimenti, usa 'git cherry-pick --skip'\n"
+
+#: builtin/commit.c:66
+msgid ""
+"and then use:\n"
+"\n"
+"    git cherry-pick --continue\n"
+"\n"
+"to resume cherry-picking the remaining commits.\n"
+"If you wish to skip this commit, use:\n"
+"\n"
+"    git cherry-pick --skip\n"
+"\n"
+msgstr ""
+"e quindi usa:\n"
+"\n"
+"    git cherry-pick --continue\n"
+"\n"
+"per riprendere l'esecuzione il cherry-pick per i commit rimanenti.\n"
+"Se vuoi saltare questo commit, usa:\n"
+"\n"
+"    git cherry-pick --skip\n"
+"\n"
+
+#: builtin/commit.c:315
+msgid "failed to unpack HEAD tree object"
+msgstr "decompressione dell'oggetto HEAD dell'albero non riuscita"
+
+#: builtin/commit.c:351
+msgid "--pathspec-from-file with -a does not make sense"
+msgstr "l'opzione --pathspec-from-file non ha senso con -a"
+
+#: builtin/commit.c:364
+msgid "No paths with --include/--only does not make sense."
+msgstr ""
+"Non specificare un percorso con le opzioni --include/--only non ha senso."
+
+#: builtin/commit.c:376
+msgid "unable to create temporary index"
+msgstr "impossibile creare l'indice temporaneo"
+
+#: builtin/commit.c:382
+msgid "interactive add failed"
+msgstr "aggiunta interattiva non riuscita"
+
+#: builtin/commit.c:396
+msgid "unable to update temporary index"
+msgstr "impossibile aggiornare l'indice temporaneo"
+
+#: builtin/commit.c:398
+msgid "Failed to update main cache tree"
+msgstr "Impossibile aggiornare l'albero cache principale"
+
+#: builtin/commit.c:423 builtin/commit.c:446 builtin/commit.c:492
+msgid "unable to write new_index file"
+msgstr "impossibile scrivere il file new_index"
+
+#: builtin/commit.c:475
+msgid "cannot do a partial commit during a merge."
+msgstr "impossibile eseguire un commit parziale durante un merge."
+
+#: builtin/commit.c:477
+msgid "cannot do a partial commit during a cherry-pick."
+msgstr "impossibile eseguire un commit parziale durante un cherry-pick."
+
+#: builtin/commit.c:485
+msgid "cannot read the index"
+msgstr "impossibile leggere l'indice"
+
+#: builtin/commit.c:504
+msgid "unable to write temporary index file"
+msgstr "impossibile scrivere il file indice temporaneo"
+
+#: builtin/commit.c:602
+#, c-format
+msgid "commit '%s' lacks author header"
+msgstr "dal commit '%s' manca l'intestazione autore"
+
+#: builtin/commit.c:604
+#, c-format
+msgid "commit '%s' has malformed author line"
+msgstr "il commit '%s' ha una riga autore malformata"
+
+#: builtin/commit.c:623
+msgid "malformed --author parameter"
+msgstr "parametro --author malformato"
+
+#: builtin/commit.c:676
+msgid ""
+"unable to select a comment character that is not used\n"
+"in the current commit message"
+msgstr ""
+"impossibile selezionare un carattere commento non usato\n"
+"nel messaggio di commit corrente"
+
+#: builtin/commit.c:714 builtin/commit.c:747 builtin/commit.c:1092
+#, c-format
+msgid "could not lookup commit %s"
+msgstr "impossibile trovare il commit %s"
+
+#: builtin/commit.c:726 builtin/shortlog.c:319
+#, c-format
+msgid "(reading log message from standard input)\n"
+msgstr "(lettura del messaggio di log dallo standard input)\n"
+
+#: builtin/commit.c:728
+msgid "could not read log from standard input"
+msgstr "impossibile leggere il log dallo standard input"
+
+#: builtin/commit.c:732
+#, c-format
+msgid "could not read log file '%s'"
+msgstr "impossibile leggere il file di log '%s'"
+
+#: builtin/commit.c:763 builtin/commit.c:779
+msgid "could not read SQUASH_MSG"
+msgstr "impossibile leggere SQUASH_MSG"
+
+#: builtin/commit.c:770
+msgid "could not read MERGE_MSG"
+msgstr "impossibile leggere MERGE_MSG"
+
+#: builtin/commit.c:830
+msgid "could not write commit template"
+msgstr "impossibile scrivere il modello di commit"
+
+#: builtin/commit.c:849
+#, c-format
+msgid ""
+"\n"
+"It looks like you may be committing a merge.\n"
+"If this is not correct, please remove the file\n"
+"\t%s\n"
+"and try again.\n"
+msgstr ""
+"\n"
+"Sembra che tu stia eseguendo il commit di un merge.\n"
+"Se ciò non è corretto, elimina il file\n"
+"\t%s\n"
+"e riprova.\n"
+
+#: builtin/commit.c:854
+#, c-format
+msgid ""
+"\n"
+"It looks like you may be committing a cherry-pick.\n"
+"If this is not correct, please remove the file\n"
+"\t%s\n"
+"and try again.\n"
+msgstr ""
+"\n"
+"Sembra che tu stia eseguendo il commit di un merge.\n"
+"Se ciò non è corretto, elimina il file\n"
+"\t%s\n"
+"e riprova.\n"
+
+#: builtin/commit.c:867
+#, c-format
+msgid ""
+"Please enter the commit message for your changes. Lines starting\n"
+"with '%c' will be ignored, and an empty message aborts the commit.\n"
+msgstr ""
+"Immetti il messaggio di commit per le modifiche. Le righe che iniziano\n"
+"con '%c' saranno ignorate e un messaggio vuoto interromperà il commit.\n"
+
+#: builtin/commit.c:875
+#, c-format
+msgid ""
+"Please enter the commit message for your changes. Lines starting\n"
+"with '%c' will be kept; you may remove them yourself if you want to.\n"
+"An empty message aborts the commit.\n"
+msgstr ""
+"Immetti il messaggio di commit per le modifiche. Le righe che iniziano\n"
+"con '%c' saranno mantenute; puoi rimuoverle autonomamente se lo desideri.\n"
+"Un messaggio vuoto interromperà il commit.\n"
+
+#: builtin/commit.c:892
+#, c-format
+msgid "%sAuthor:    %.*s <%.*s>"
+msgstr "%sAutore:           %.*s <%.*s>"
+
+#: builtin/commit.c:900
+#, c-format
+msgid "%sDate:      %s"
+msgstr "%sData:             %s"
+
+#: builtin/commit.c:907
+#, c-format
+msgid "%sCommitter: %.*s <%.*s>"
+msgstr "%sEsecutore commit: %.*s <%.*s>"
+
+#: builtin/commit.c:925
+msgid "Cannot read index"
+msgstr "Impossibile leggere l'indice"
+
+#: builtin/commit.c:992
+msgid "Error building trees"
+msgstr "Errore durante la costruzione degli alberi"
+
+#: builtin/commit.c:1006 builtin/tag.c:275
+#, c-format
+msgid "Please supply the message using either -m or -F option.\n"
+msgstr "Fornisci il messaggio usando l'opzione -m o -F.\n"
+
+#: builtin/commit.c:1050
+#, c-format
+msgid "--author '%s' is not 'Name <email>' and matches no existing author"
+msgstr ""
+"--author '%s' non è nel formato 'Nome <e-mail>' e non corrisponde ad alcun "
+"autore esistente"
+
+#: builtin/commit.c:1064
+#, c-format
+msgid "Invalid ignored mode '%s'"
+msgstr "Modo non valido ignorato: '%s'"
+
+#: builtin/commit.c:1082 builtin/commit.c:1322
+#, c-format
+msgid "Invalid untracked files mode '%s'"
+msgstr "Modo file non tracciati non valido: '%s'"
+
+#: builtin/commit.c:1122
+msgid "--long and -z are incompatible"
+msgstr "--long e -z non sono compatibili"
+
+#: builtin/commit.c:1166
+msgid "Using both --reset-author and --author does not make sense"
+msgstr "L'uso di entrambe le opzioni --reset-author e --author non ha senso"
+
+#: builtin/commit.c:1175
+msgid "You have nothing to amend."
+msgstr "Non c'è nulla da modificare."
+
+#: builtin/commit.c:1178
+msgid "You are in the middle of a merge -- cannot amend."
+msgstr "Sei nel bel mezzo di un merge - impossibile eseguire l'amend."
+
+#: builtin/commit.c:1180
+msgid "You are in the middle of a cherry-pick -- cannot amend."
+msgstr "Sei nel bel mezzo di un cherry-pick - impossibile eseguire l'amend."
+
+#: builtin/commit.c:1183
+msgid "Options --squash and --fixup cannot be used together"
+msgstr "Le opzioni --squash e --fixup non possono essere usate insieme"
+
+#: builtin/commit.c:1193
+msgid "Only one of -c/-C/-F/--fixup can be used."
+msgstr "Solo una delle opzioni -c/-C/-F/--fixup può essere usata."
+
+#: builtin/commit.c:1195
+msgid "Option -m cannot be combined with -c/-C/-F."
+msgstr "L'opzione -m non può essere combinata con -c/-C/-F."
+
+#: builtin/commit.c:1203
+msgid "--reset-author can be used only with -C, -c or --amend."
+msgstr "L'opzione --reset-author può essere usata solo con -C, -c o --amend."
+
+#: builtin/commit.c:1220
+msgid "Only one of --include/--only/--all/--interactive/--patch can be used."
+msgstr ""
+"Può essere usata solo una delle opzioni --include/--only/--all/--"
+"interactive/--patch."
+
+#: builtin/commit.c:1226
+#, c-format
+msgid "paths '%s ...' with -a does not make sense"
+msgstr "i percorsi '%s ...' non hanno senso con -a"
+
+#: builtin/commit.c:1357 builtin/commit.c:1519
+msgid "show status concisely"
+msgstr "visualizza concisamente lo stato"
+
+#: builtin/commit.c:1359 builtin/commit.c:1521
+msgid "show branch information"
+msgstr "visualizza le informazioni sul branch"
+
+#: builtin/commit.c:1361
+msgid "show stash information"
+msgstr "visualizza le informazioni sullo stash"
+
+#: builtin/commit.c:1363 builtin/commit.c:1523
+msgid "compute full ahead/behind values"
+msgstr "calcola tutti i valori dopo/prima di"
+
+#: builtin/commit.c:1365
+msgid "version"
+msgstr "versione"
+
+#: builtin/commit.c:1365 builtin/commit.c:1525 builtin/push.c:549
+#: builtin/worktree.c:650
+msgid "machine-readable output"
+msgstr "output leggibile da una macchina"
+
+#: builtin/commit.c:1368 builtin/commit.c:1527
+msgid "show status in long format (default)"
+msgstr "visualizza lo stato in forma lunga (impostazione predefinita)"
+
+#: builtin/commit.c:1371 builtin/commit.c:1530
+msgid "terminate entries with NUL"
+msgstr "termina le voci con NUL"
+
+#: builtin/commit.c:1373 builtin/commit.c:1377 builtin/commit.c:1533
+#: builtin/fast-export.c:1153 builtin/fast-export.c:1156
+#: builtin/fast-export.c:1159 builtin/rebase.c:1525 parse-options.h:336
+msgid "mode"
+msgstr "modo"
+
+#: builtin/commit.c:1374 builtin/commit.c:1533
+msgid "show untracked files, optional modes: all, normal, no. (Default: all)"
+msgstr ""
+"visualizza file non tracciati, modalità facoltative: all, normal, no. "
+"(Impostazione predefinita: all)"
+
+#: builtin/commit.c:1378
+msgid ""
+"show ignored files, optional modes: traditional, matching, no. (Default: "
+"traditional)"
+msgstr ""
+"visualizza file ignorati, modalità facoltative: traditional, matching, no. "
+"(Impostazione predefinita: traditional)"
+
+#: builtin/commit.c:1380 parse-options.h:192
+msgid "when"
+msgstr "quando"
+
+#: builtin/commit.c:1381
+msgid ""
+"ignore changes to submodules, optional when: all, dirty, untracked. "
+"(Default: all)"
+msgstr ""
+"ignora modifiche ai sottomoduli, opzione facoltativa \"quando\": all, dirty, "
+"untracked. (Impostazione predefinita: all)"
+
+#: builtin/commit.c:1383
+msgid "list untracked files in columns"
+msgstr "elenca i file non tracciati in colonne"
+
+#: builtin/commit.c:1384
+msgid "do not detect renames"
+msgstr "non rilevare le ridenominazioni"
+
+#: builtin/commit.c:1386
+msgid "detect renames, optionally set similarity index"
+msgstr ""
+"rileva le ridenominazioni, imposta facoltativamente l'indice di similarità"
+
+#: builtin/commit.c:1406
+msgid "Unsupported combination of ignored and untracked-files arguments"
+msgstr ""
+"Combinazione di argomenti sui file ignorati e non tracciati non supportata"
+
+#: builtin/commit.c:1489
+msgid "suppress summary after successful commit"
+msgstr ""
+"ometti di visualizzare il riepilogo dopo un commit completato con successo"
+
+#: builtin/commit.c:1490
+msgid "show diff in commit message template"
+msgstr "visualizza il diff nel modello del messaggio di commit"
+
+#: builtin/commit.c:1492
+msgid "Commit message options"
+msgstr "Opzioni messaggio di commit"
+
+#: builtin/commit.c:1493 builtin/merge.c:274 builtin/tag.c:414
+msgid "read message from file"
+msgstr "leggi il messaggio da un file"
+
+#: builtin/commit.c:1494
+msgid "author"
+msgstr "autore"
+
+#: builtin/commit.c:1494
+msgid "override author for commit"
+msgstr "sovrascrivi l'autore per il commit"
+
+#: builtin/commit.c:1495 builtin/gc.c:538
+msgid "date"
+msgstr "data"
+
+#: builtin/commit.c:1495
+msgid "override date for commit"
+msgstr "sovrascrivi la data per il commit"
+
+#: builtin/commit.c:1497 builtin/commit.c:1498 builtin/commit.c:1499
+#: builtin/commit.c:1500 parse-options.h:328 ref-filter.h:92
+msgid "commit"
+msgstr "commit"
+
+#: builtin/commit.c:1497
+msgid "reuse and edit message from specified commit"
+msgstr "riusa il messaggio del commit specificato per poi modificarlo"
+
+#: builtin/commit.c:1498
+msgid "reuse message from specified commit"
+msgstr "riusa il messaggio del commit specificato"
+
+#: builtin/commit.c:1499
+msgid "use autosquash formatted message to fixup specified commit"
+msgstr ""
+"usa il messaggio in formato autosquash per correggere il commit specificato"
+
+#: builtin/commit.c:1500
+msgid "use autosquash formatted message to squash specified commit"
+msgstr ""
+"usa il messaggio in formato autosquash per eseguire lo squash del commit "
+"specificato"
+
+#: builtin/commit.c:1501
+msgid "the commit is authored by me now (used with -C/-c/--amend)"
+msgstr "il commit ora ha me come autore (opzione usata con -C/-c/--amend)"
+
+#: builtin/commit.c:1502 builtin/log.c:1634 builtin/merge.c:289
+#: builtin/pull.c:164 builtin/revert.c:110
+msgid "add Signed-off-by:"
+msgstr "aggiungi Signed-off-by:"
+
+#: builtin/commit.c:1503
+msgid "use specified template file"
+msgstr "usa il file modello specificato"
+
+#: builtin/commit.c:1504
+msgid "force edit of commit"
+msgstr "forza la modifica del commit"
+
+#: builtin/commit.c:1506
+msgid "include status in commit message template"
+msgstr "includi lo stato nel modello del messaggio di commit"
+
+#: builtin/commit.c:1511
+msgid "Commit contents options"
+msgstr "Opzioni contenuto commit"
+
+#: builtin/commit.c:1512
+msgid "commit all changed files"
+msgstr "esegui il commit di tutti i file modificati"
+
+#: builtin/commit.c:1513
+msgid "add specified files to index for commit"
+msgstr "aggiungi i file specificati all'indice per il commit"
+
+#: builtin/commit.c:1514
+msgid "interactively add files"
+msgstr "aggiungi i file in modalità interattiva"
+
+#: builtin/commit.c:1515
+msgid "interactively add changes"
+msgstr "aggiungi le modifiche in modalità interattiva"
+
+#: builtin/commit.c:1516
+msgid "commit only specified files"
+msgstr "esegui il commit solo dei file specificati"
+
+#: builtin/commit.c:1517
+msgid "bypass pre-commit and commit-msg hooks"
+msgstr "ignora gli hook pre-commit e commit-msg"
+
+#: builtin/commit.c:1518
+msgid "show what would be committed"
+msgstr "visualizza gli elementi di cui sarebbe eseguito il commit"
+
+#: builtin/commit.c:1531
+msgid "amend previous commit"
+msgstr "modifica il commit precedente"
+
+#: builtin/commit.c:1532
+msgid "bypass post-rewrite hook"
+msgstr "ignora l'hook post-rewrite"
+
+#: builtin/commit.c:1539
+msgid "ok to record an empty change"
+msgstr "accetta di registrare una modifica vuota"
+
+#: builtin/commit.c:1541
+msgid "ok to record a change with an empty message"
+msgstr "accetta di registrare una modifica con un messaggio vuoto"
+
+#: builtin/commit.c:1614
+#, c-format
+msgid "Corrupt MERGE_HEAD file (%s)"
+msgstr "File MERGE_HEAD corrotto (%s)"
+
+#: builtin/commit.c:1621
+msgid "could not read MERGE_MODE"
+msgstr "impossibile leggere MERGE_MODE"
+
+#: builtin/commit.c:1640
+#, c-format
+msgid "could not read commit message: %s"
+msgstr "impossibile leggere il messaggio di commit: %s"
+
+#: builtin/commit.c:1647
+#, c-format
+msgid "Aborting commit due to empty commit message.\n"
+msgstr "Interrompo il commit a causa di un messaggio di commit vuoto.\n"
+
+#: builtin/commit.c:1652
+#, c-format
+msgid "Aborting commit; you did not edit the message.\n"
+msgstr "Interrompo il commit; non hai modificato il messaggio.\n"
+
+#: builtin/commit.c:1686
+msgid ""
+"repository has been updated, but unable to write\n"
+"new_index file. Check that disk is not full and quota is\n"
+"not exceeded, and then \"git restore --staged :/\" to recover."
+msgstr ""
+"Il repository è stato aggiornato, ma non è stato\n"
+"possibile scrivere il file new_index. Verifica che il\n"
+"disco non sia pieno e che la quota non sia stata\n"
+"superata, quindi esegui \"git restore --staged :/\" per\n"
+"procedere al ripristino."
+
+#: builtin/commit-graph.c:11 builtin/commit-graph.c:17
+msgid ""
+"git commit-graph verify [--object-dir <objdir>] [--shallow] [--[no-]progress]"
+msgstr ""
+"git commit-graph verify [--object-dir <directory oggetti>] [--shallow] [--"
+"[no-]progress]"
+
+#: builtin/commit-graph.c:12 builtin/commit-graph.c:22
+msgid ""
+"git commit-graph write [--object-dir <objdir>] [--append|--split] [--"
+"reachable|--stdin-packs|--stdin-commits] [--[no-]progress] <split options>"
+msgstr ""
+"git commit-graph write [--object-dir <directory oggetti>] [--append|--split] "
+"[--reachable|--stdin-packs|--stdin-commits] [--[no-]progress] <opzioni split>"
+
+#: builtin/commit-graph.c:48 builtin/commit-graph.c:103
+#: builtin/commit-graph.c:187 builtin/fetch.c:179 builtin/log.c:1657
+msgid "dir"
+msgstr "directory"
+
+#: builtin/commit-graph.c:49 builtin/commit-graph.c:104
+#: builtin/commit-graph.c:188
+msgid "The object directory to store the graph"
+msgstr "La directory oggetti in cui memorizzare il grafo"
+
+#: builtin/commit-graph.c:51
+msgid "if the commit-graph is split, only verify the tip file"
+msgstr "se il grafo dei commit è diviso, verifica solo l'ultimo file"
+
+#: builtin/commit-graph.c:73 t/helper/test-read-graph.c:23
+#, c-format
+msgid "Could not open commit-graph '%s'"
+msgstr "Impossibile aprire il grafo dei commit '%s'"
+
+#: builtin/commit-graph.c:106
+msgid "start walk at all refs"
+msgstr "inizia la visita da tutti i riferimenti"
+
+#: builtin/commit-graph.c:108
+msgid "scan pack-indexes listed by stdin for commits"
+msgstr ""
+"esamina i pack-index elencati sullo standard input alla ricerca di commit"
+
+#: builtin/commit-graph.c:110
+msgid "start walk at commits listed by stdin"
+msgstr "inizia la visita ai commit elencati sullo standard input"
+
+#: builtin/commit-graph.c:112
+msgid "include all commits already in the commit-graph file"
+msgstr "includi tutti i commit già presenti nel file commit-graph"
+
+#: builtin/commit-graph.c:115
+msgid "allow writing an incremental commit-graph file"
+msgstr "consenti la scrittura di un file grafo dei commit incrementale"
+
+#: builtin/commit-graph.c:117 builtin/commit-graph.c:121
+msgid "maximum number of commits in a non-base split commit-graph"
+msgstr "numero massimo di commit in un grafo dei commit diviso non di base"
+
+#: builtin/commit-graph.c:119
+msgid "maximum ratio between two levels of a split commit-graph"
+msgstr "rapporto massimo fra due livelli di un grafo dei commit diviso"
+
+#: builtin/commit-graph.c:137
+msgid "use at most one of --reachable, --stdin-commits, or --stdin-packs"
+msgstr "usa al più un'opzione fra --reachable, --stdin-commits o --stdin-packs"
+
+#: builtin/config.c:11
+msgid "git config [<options>]"
+msgstr "git config [<opzioni>]"
+
+#: builtin/config.c:103 builtin/env--helper.c:23
+#, c-format
+msgid "unrecognized --type argument, %s"
+msgstr "argomento --type non riconosciuto: %s"
+
+#: builtin/config.c:115
+msgid "only one type at a time"
+msgstr "solo un tipo per volta"
+
+#: builtin/config.c:124
+msgid "Config file location"
+msgstr "Percorso file di configurazione"
+
+#: builtin/config.c:125
+msgid "use global config file"
+msgstr "usa il file di configurazione globale"
+
+#: builtin/config.c:126
+msgid "use system config file"
+msgstr "usa il file di configurazione di sistema"
+
+#: builtin/config.c:127
+msgid "use repository config file"
+msgstr "usa il file di configurazione del repository"
+
+#: builtin/config.c:128
+msgid "use per-worktree config file"
+msgstr "usa il file di configurazione per albero di lavoro"
+
+#: builtin/config.c:129
+msgid "use given config file"
+msgstr "usa il file di configurazione specificato"
+
+#: builtin/config.c:130
+msgid "blob-id"
+msgstr "ID blob"
+
+#: builtin/config.c:130
+msgid "read config from given blob object"
+msgstr "leggi la configurazione dall'oggetto blob specificato"
+
+#: builtin/config.c:131
+msgid "Action"
+msgstr "Azione"
+
+#: builtin/config.c:132
+msgid "get value: name [value-regex]"
+msgstr "ottieni valore: nome [espressione-regolare-valore]"
+
+#: builtin/config.c:133
+msgid "get all values: key [value-regex]"
+msgstr "ottieni tutti i valori: chiave [espressione-regolare-valore]"
+
+#: builtin/config.c:134
+msgid "get values for regexp: name-regex [value-regex]"
+msgstr ""
+"ottieni i valori in base a un'espressione regolare: espressione-regolare-"
+"nome [espressione-regolare-valore]"
+
+#: builtin/config.c:135
+msgid "get value specific for the URL: section[.var] URL"
+msgstr "ottieni il valore specifico per l'URL: sezione[.variabile] URL"
+
+#: builtin/config.c:136
+msgid "replace all matching variables: name value [value_regex]"
+msgstr ""
+"sostituisci tutte le variabili corrispondenti: nome-valore [espressione-"
+"regolare-valore]"
+
+#: builtin/config.c:137
+msgid "add a new variable: name value"
+msgstr "aggiungi una nuova variabile: nome valore"
+
+#: builtin/config.c:138
+msgid "remove a variable: name [value-regex]"
+msgstr "rimuovi una variabile: nome [espressione-regolare-valore]"
+
+#: builtin/config.c:139
+msgid "remove all matches: name [value-regex]"
+msgstr "rimuovi tutte le corrispondenze: nome [espressione-regolare-valore]"
+
+#: builtin/config.c:140
+msgid "rename section: old-name new-name"
+msgstr "rinomina sezione: vecchio-nome nuovo-nome"
+
+#: builtin/config.c:141
+msgid "remove a section: name"
+msgstr "rimuovi una sezione: nome"
+
+#: builtin/config.c:142
+msgid "list all"
+msgstr "elenca tutti"
+
+#: builtin/config.c:143
+msgid "open an editor"
+msgstr "apri un editor"
+
+#: builtin/config.c:144
+msgid "find the color configured: slot [default]"
+msgstr "trova il colore configurato: slot [valore-predefinito]"
+
+#: builtin/config.c:145
+msgid "find the color setting: slot [stdout-is-tty]"
+msgstr "trova l'impostazione colore: slot [standard-output-è-una-tty]"
+
+#: builtin/config.c:146
+msgid "Type"
+msgstr "Tipo"
+
+#: builtin/config.c:147 builtin/env--helper.c:38
+msgid "value is given this type"
+msgstr "al valore è assegnato questo tipo"
+
+#: builtin/config.c:148
+msgid "value is \"true\" or \"false\""
+msgstr "il valore è \"true\" o \"false\""
+
+#: builtin/config.c:149
+msgid "value is decimal number"
+msgstr "il valore è un numero decimale"
+
+#: builtin/config.c:150
+msgid "value is --bool or --int"
+msgstr "il valore è --bool o --int"
+
+#: builtin/config.c:151
+msgid "value is a path (file or directory name)"
+msgstr "il valore è un percorso (nome file o directory)"
+
+#: builtin/config.c:152
+msgid "value is an expiry date"
+msgstr "il valore è una data di scadenza"
+
+#: builtin/config.c:153
+msgid "Other"
+msgstr "Altro"
+
+#: builtin/config.c:154
+msgid "terminate values with NUL byte"
+msgstr "termina i valori con un byte NUL"
+
+#: builtin/config.c:155
+msgid "show variable names only"
+msgstr "visualizza solo i nomi delle variabili"
+
+#: builtin/config.c:156
+msgid "respect include directives on lookup"
+msgstr ""
+"rispetta le directory di inclusione durante il recupero delle variabili"
+
+#: builtin/config.c:157
+msgid "show origin of config (file, standard input, blob, command line)"
+msgstr ""
+"visualizza l'origine del file di configurazione (file, standard input, blob, "
+"riga di comando)"
+
+#: builtin/config.c:158 builtin/env--helper.c:40
+msgid "value"
+msgstr "valore"
+
+#: builtin/config.c:158
+msgid "with --get, use default value when missing entry"
+msgstr "con --get, usa il valore predefinito se la voce è mancante"
+
+#: builtin/config.c:172
+#, c-format
+msgid "wrong number of arguments, should be %d"
+msgstr "numero di argomenti errato, dovrebbero essere %d"
+
+#: builtin/config.c:174
+#, c-format
+msgid "wrong number of arguments, should be from %d to %d"
+msgstr "numero di argomenti errato, dovrebbero essere da %d a %d"
+
+#: builtin/config.c:308
+#, c-format
+msgid "invalid key pattern: %s"
+msgstr "pattern chiave non valido: %s"
+
+#: builtin/config.c:344
+#, c-format
+msgid "failed to format default config value: %s"
+msgstr "formattazione del valore configurazione predefinito non riuscita: %s"
+
+#: builtin/config.c:401
+#, c-format
+msgid "cannot parse color '%s'"
+msgstr "impossibile analizzare il colore '%s'"
+
+#: builtin/config.c:443
+msgid "unable to parse default color value"
+msgstr "impossibile analizzare il valore colore predefinito"
+
+#: builtin/config.c:496 builtin/config.c:742
+msgid "not in a git directory"
+msgstr "non si è in una directory git"
+
+#: builtin/config.c:499
+msgid "writing to stdin is not supported"
+msgstr "la scrittura su standard input non è supportata"
+
+#: builtin/config.c:502
+msgid "writing config blobs is not supported"
+msgstr "la scrittura di blob di configurazione non è supportata"
+
+#: builtin/config.c:587
+#, c-format
+msgid ""
+"# This is Git's per-user configuration file.\n"
+"[user]\n"
+"# Please adapt and uncomment the following lines:\n"
+"#\tname = %s\n"
+"#\temail = %s\n"
+msgstr ""
+"# Questo è il file di configurazione utente di Git.\n"
+"[user]\n"
+"# Adatta e decommenta le seguenti righe:\n"
+"#\tname = %s\n"
+"#\temail = %s\n"
+
+#: builtin/config.c:611
+msgid "only one config file at a time"
+msgstr "solo un file di configurazione per volta"
+
+#: builtin/config.c:616
+msgid "--local can only be used inside a git repository"
+msgstr "--local può essere usato solo in un repository Git"
+
+#: builtin/config.c:619
+msgid "--blob can only be used inside a git repository"
+msgstr "--blob può essere usato solo in un repository Git"
+
+#: builtin/config.c:638
+msgid "$HOME not set"
+msgstr "$HOME non impostata"
+
+#: builtin/config.c:658
+msgid ""
+"--worktree cannot be used with multiple working trees unless the config\n"
+"extension worktreeConfig is enabled. Please read \"CONFIGURATION FILE\"\n"
+"section in \"git help worktree\" for details"
+msgstr ""
+"--worktree non può essere usato con alberi di lavoro multipli a meno\n"
+"che l'estensione di configurazione worktreeConfig non sia abilitata.\n"
+"Leggi la sezione \"FILE DI CONFIGURAZIONE\" in \"git help worktree\" per\n"
+"i dettagli"
+
+#: builtin/config.c:688
+msgid "--get-color and variable type are incoherent"
+msgstr "--get-color e il tipo della variabile non sono coerenti"
+
+#: builtin/config.c:693
+msgid "only one action at a time"
+msgstr "solo un'azione per volta"
+
+#: builtin/config.c:706
+msgid "--name-only is only applicable to --list or --get-regexp"
+msgstr "--name-only è applicabile solo a --list o --get-regexp"
+
+#: builtin/config.c:712
+msgid ""
+"--show-origin is only applicable to --get, --get-all, --get-regexp, and --"
+"list"
+msgstr ""
+"--show-origin è applicabile solo a --get, --get-all, --get-regexp e --list"
+
+#: builtin/config.c:718
+msgid "--default is only applicable to --get"
+msgstr "--default è applicabile solo a --get"
+
+#: builtin/config.c:731
+#, c-format
+msgid "unable to read config file '%s'"
+msgstr "impossibile leggere il file di configurazione '%s'"
+
+#: builtin/config.c:734
+msgid "error processing config file(s)"
+msgstr "errore durante l'elaborazione del/dei file di configurazione"
+
+#: builtin/config.c:744
+msgid "editing stdin is not supported"
+msgstr "la modifica dello standard input non è supportata"
+
+#: builtin/config.c:746
+msgid "editing blobs is not supported"
+msgstr "la modifica dei blob non è supportata"
+
+#: builtin/config.c:760
+#, c-format
+msgid "cannot create configuration file %s"
+msgstr "impossibile creare il file di configurazione %s"
+
+#: builtin/config.c:773
+#, c-format
+msgid ""
+"cannot overwrite multiple values with a single value\n"
+"       Use a regexp, --add or --replace-all to change %s."
+msgstr ""
+"impossibile sovrascrivere valori multipli con un singolo valore\n"
+"       Usa un'espressione regolare, --add o --replace-all per modificare %s."
+
+#: builtin/config.c:847 builtin/config.c:858
+#, c-format
+msgid "no such section: %s"
+msgstr "sezione %s non esistente"
+
+#: builtin/count-objects.c:90
+msgid "git count-objects [-v] [-H | --human-readable]"
+msgstr "git count-objects [-v] [-H | --human-readable]"
+
+#: builtin/count-objects.c:100
+msgid "print sizes in human readable format"
+msgstr "stampa le dimensioni in un formato leggibile"
+
+#: builtin/describe.c:26
+msgid "git describe [<options>] [<commit-ish>...]"
+msgstr "git describe [<opzioni>] [<espressione commit>...]"
+
+#: builtin/describe.c:27
+msgid "git describe [<options>] --dirty"
+msgstr "git describe [<opzioni>] --dirty"
+
+#: builtin/describe.c:62
+msgid "head"
+msgstr "head"
+
+#: builtin/describe.c:62
+msgid "lightweight"
+msgstr "leggero"
+
+#: builtin/describe.c:62
+msgid "annotated"
+msgstr "annotato"
+
+#: builtin/describe.c:275
+#, c-format
+msgid "annotated tag %s not available"
+msgstr "il tag annotato %s non è disponibile"
+
+#: builtin/describe.c:279
+#, c-format
+msgid "annotated tag %s has no embedded name"
+msgstr "il tag annotato %s non ha un nome incorporato"
+
+#: builtin/describe.c:281
+#, c-format
+msgid "tag '%s' is really '%s' here"
+msgstr "il tag '%s' in realtà qui è '%s'"
+
+#: builtin/describe.c:325
+#, c-format
+msgid "no tag exactly matches '%s'"
+msgstr "nessun tag corrisponde esattamente a '%s'"
+
+#: builtin/describe.c:327
+#, c-format
+msgid "No exact match on refs or tags, searching to describe\n"
+msgstr ""
+"Nessuna corrispondenza esatta sui riferimenti o sui tag, sto eseguendo una "
+"ricerca per descrivere il commit\n"
+
+#: builtin/describe.c:381
+#, c-format
+msgid "finished search at %s\n"
+msgstr "ricerca terminata in %s\n"
+
+#: builtin/describe.c:407
+#, c-format
+msgid ""
+"No annotated tags can describe '%s'.\n"
+"However, there were unannotated tags: try --tags."
+msgstr ""
+"Nessun tag annotato può descrivere '%s'.\n"
+"Ciò nonostante, c'erano dei tag non annotati: prova con --tags."
+
+#: builtin/describe.c:411
+#, c-format
+msgid ""
+"No tags can describe '%s'.\n"
+"Try --always, or create some tags."
+msgstr ""
+"Nessun tag può descrivere '%s'.\n"
+"Prova con --always o crea dei tag."
+
+#: builtin/describe.c:441
+#, c-format
+msgid "traversed %lu commits\n"
+msgstr "ho attraversato %lu commit\n"
+
+#: builtin/describe.c:444
+#, c-format
+msgid ""
+"more than %i tags found; listed %i most recent\n"
+"gave up search at %s\n"
+msgstr ""
+"trovati più di %i tag; ho elencato i %i più recenti\n"
+"ho terminato la ricerca in %s\n"
+
+#: builtin/describe.c:512
+#, c-format
+msgid "describe %s\n"
+msgstr "descrivi %s\n"
+
+#: builtin/describe.c:515
+#, c-format
+msgid "Not a valid object name %s"
+msgstr "%s non è un nome oggetto valido"
+
+#: builtin/describe.c:523
+#, c-format
+msgid "%s is neither a commit nor blob"
+msgstr "%s non è né un commit né un blob"
+
+#: builtin/describe.c:537
+msgid "find the tag that comes after the commit"
+msgstr "trova il tag successivo al commit"
+
+#: builtin/describe.c:538
+msgid "debug search strategy on stderr"
+msgstr "esegui il debug della strategia di ricerca sullo standard error"
+
+#: builtin/describe.c:539
+msgid "use any ref"
+msgstr "usa qualunque riferimento"
+
+#: builtin/describe.c:540
+msgid "use any tag, even unannotated"
+msgstr "usa qualunque tag, anche quelli non annotati"
+
+#: builtin/describe.c:541
+msgid "always use long format"
+msgstr "usa sempre il formato lungo"
+
+#: builtin/describe.c:542
+msgid "only follow first parent"
+msgstr "segui solo il primo genitore"
+
+#: builtin/describe.c:545
+msgid "only output exact matches"
+msgstr "visualizza solo le corrispondenze esatte"
+
+#: builtin/describe.c:547
+msgid "consider <n> most recent tags (default: 10)"
+msgstr "considera gli <n> tag più recenti (impostazione predefinita: 10)"
+
+#: builtin/describe.c:549
+msgid "only consider tags matching <pattern>"
+msgstr "considera solo i tag corrispondenti al <pattern>"
+
+#: builtin/describe.c:551
+msgid "do not consider tags matching <pattern>"
+msgstr "non considerare i tag corrispondenti al <pattern>"
+
+#: builtin/describe.c:553 builtin/name-rev.c:473
+msgid "show abbreviated commit object as fallback"
+msgstr "visualizza l'oggetto commit abbreviato come fallback"
+
+#: builtin/describe.c:554 builtin/describe.c:557
+msgid "mark"
+msgstr "contrassegno"
+
+#: builtin/describe.c:555
+msgid "append <mark> on dirty working tree (default: \"-dirty\")"
+msgstr ""
+"aggiungi <contrassegno> all'albero di lavoro sporco (impostazione "
+"predefinita: \"-dirty\")"
+
+#: builtin/describe.c:558
+msgid "append <mark> on broken working tree (default: \"-broken\")"
+msgstr ""
+"aggiungi <contrassegno> all'albero di lavoro rotto (impostazione "
+"predefinita: \"-broken\")"
+
+#: builtin/describe.c:576
+msgid "--long is incompatible with --abbrev=0"
+msgstr "--long non è compatibile con --abbrev=0"
+
+#: builtin/describe.c:605
+msgid "No names found, cannot describe anything."
+msgstr "Nessun nome trovato, non è possibile descrivere nulla."
+
+#: builtin/describe.c:656
+msgid "--dirty is incompatible with commit-ishes"
+msgstr "--dirty non è compatibile con le espressioni commit"
+
+#: builtin/describe.c:658
+msgid "--broken is incompatible with commit-ishes"
+msgstr "--broken non è compatibile con le espressioni commit"
+
+#: builtin/diff.c:84
+#, c-format
+msgid "'%s': not a regular file or symlink"
+msgstr "'%s': non è un file regolare o un collegamento simbolico"
+
+#: builtin/diff.c:235
+#, c-format
+msgid "invalid option: %s"
+msgstr "opzione non valida: %s"
+
+#: builtin/diff.c:350
+msgid "Not a git repository"
+msgstr "Non è un repository Git"
+
+#: builtin/diff.c:394
+#, c-format
+msgid "invalid object '%s' given."
+msgstr "specificato oggetto non valido '%s'."
+
+#: builtin/diff.c:403
+#, c-format
+msgid "more than two blobs given: '%s'"
+msgstr "più di due blob specificati: '%s'"
+
+#: builtin/diff.c:408
+#, c-format
+msgid "unhandled object '%s' given."
+msgstr "specificato oggetto non gestito '%s'."
+
+#: builtin/difftool.c:30
+msgid "git difftool [<options>] [<commit> [<commit>]] [--] [<path>...]"
+msgstr "git difftool [<opzioni>] [<commit> [<commit>]] [--] [<percorso>...]"
+
+#: builtin/difftool.c:260
+#, c-format
+msgid "failed: %d"
+msgstr "non riuscito: %d"
+
+#: builtin/difftool.c:302
+#, c-format
+msgid "could not read symlink %s"
+msgstr "impossibile leggere il collegamento simbolico %s"
+
+#: builtin/difftool.c:304
+#, c-format
+msgid "could not read symlink file %s"
+msgstr "impossibile leggere il file collegamento simbolico %s"
+
+#: builtin/difftool.c:312
+#, c-format
+msgid "could not read object %s for symlink %s"
+msgstr "impossibile leggere l'oggetto %s per il collegamento simbolico %s"
+
+#: builtin/difftool.c:413
+msgid ""
+"combined diff formats('-c' and '--cc') are not supported in\n"
+"directory diff mode('-d' and '--dir-diff')."
+msgstr ""
+"i formati diff combinati ('-c' e '--cc') non sono supportati in\n"
+"modalità diff directory ('-d' e '--dir-diff')."
+
+#: builtin/difftool.c:634
+#, c-format
+msgid "both files modified: '%s' and '%s'."
+msgstr "entrambi i file risultano modificati: '%s' e '%s'."
+
+#: builtin/difftool.c:636
+msgid "working tree file has been left."
+msgstr "il file nell'albero di lavoro è stato mantenuto."
+
+#: builtin/difftool.c:647
+#, c-format
+msgid "temporary files exist in '%s'."
+msgstr "esistono file temporanei in '%s'."
+
+#: builtin/difftool.c:648
+msgid "you may want to cleanup or recover these."
+msgstr "potresti voler ripulirli o ripristinarli."
+
+#: builtin/difftool.c:697
+msgid "use `diff.guitool` instead of `diff.tool`"
+msgstr "usa `diff.guitool` anziché `diff.tool`"
+
+#: builtin/difftool.c:699
+msgid "perform a full-directory diff"
+msgstr "esegui un diff directory completo"
+
+#: builtin/difftool.c:701
+msgid "do not prompt before launching a diff tool"
+msgstr "non chiedere conferma prima di lanciare un tool diff"
+
+#: builtin/difftool.c:706
+msgid "use symlinks in dir-diff mode"
+msgstr "usa collegamenti simbolici in modalità diff directory"
+
+#: builtin/difftool.c:707
+msgid "tool"
+msgstr "strumento"
+
+#: builtin/difftool.c:708
+msgid "use the specified diff tool"
+msgstr "usa lo strumento diff specificato"
+
+#: builtin/difftool.c:710
+msgid "print a list of diff tools that may be used with `--tool`"
+msgstr ""
+"stampa un elenco di strumenti diff che possono essere usati con `--tool`"
+
+#: builtin/difftool.c:713
+msgid ""
+"make 'git-difftool' exit when an invoked diff tool returns a non - zero exit "
+"code"
+msgstr ""
+"fai sì che 'git-difftool' esca quando uno strumento diff invocato "
+"restituisce un codice d'uscita diverso da zero"
+
+#: builtin/difftool.c:716
+msgid "specify a custom command for viewing diffs"
+msgstr "specifica un comando personalizzato per visualizzare i diff"
+
+#: builtin/difftool.c:717
+msgid "passed to `diff`"
+msgstr "fornito a `diff`"
+
+#: builtin/difftool.c:732
+msgid "difftool requires worktree or --no-index"
+msgstr "difftool richiede un albero di lavoro o --no-index"
+
+#: builtin/difftool.c:739
+msgid "--dir-diff is incompatible with --no-index"
+msgstr "--dir-diff non è compatibile con --no-index"
+
+#: builtin/difftool.c:742
+msgid "--gui, --tool and --extcmd are mutually exclusive"
+msgstr "le opzioni --gui, --tool ed --extcmd sono mutualmente esclusive"
+
+#: builtin/difftool.c:750
+msgid "no <tool> given for --tool=<tool>"
+msgstr "nessuno <strumento> specificato per --tool=<strumento>"
+
+#: builtin/difftool.c:757
+msgid "no <cmd> given for --extcmd=<cmd>"
+msgstr "nessun <comando> specificato per --extcmd=<comando>"
+
+#: builtin/env--helper.c:6
+msgid "git env--helper --type=[bool|ulong] <options> <env-var>"
+msgstr "git env--helper --type=[bool|ulong] <opzioni> <variabile d'ambiente>"
+
+#: builtin/env--helper.c:37 builtin/hash-object.c:98
+msgid "type"
+msgstr "tipo"
+
+#: builtin/env--helper.c:41
+msgid "default for git_env_*(...) to fall back on"
+msgstr ""
+"impostazione predefinita su cui ripiegheranno le chiamate git_env_*(...)"
+
+#: builtin/env--helper.c:43
+msgid "be quiet only use git_env_*() value as exit code"
+msgstr ""
+"non visualizzare messaggi, usa solo il valore di git_env_*() come codice "
+"d'uscita"
+
+#: builtin/env--helper.c:62
+#, c-format
+msgid "option `--default' expects a boolean value with `--type=bool`, not `%s`"
+msgstr ""
+"l'opzione `--default' richiede un valore booleano con `--type=bool`, non `%s`"
+
+#: builtin/env--helper.c:77
+#, c-format
+msgid ""
+"option `--default' expects an unsigned long value with `--type=ulong`, not `"
+"%s`"
+msgstr ""
+"l'opzione `--default' richiede un valore unsigned long con `--type=ulong`, "
+"non `%s`"
+
+#: builtin/fast-export.c:29
+msgid "git fast-export [rev-list-opts]"
+msgstr "git fast-export [opzioni-elenco-rev]"
+
+#: builtin/fast-export.c:852
+msgid "Error: Cannot export nested tags unless --mark-tags is specified."
+msgstr ""
+"Errore: Impossibile esportare i tag nidificati a meno che non sia "
+"specificata l'opzione --mark-tags."
+
+#: builtin/fast-export.c:1152
+msgid "show progress after <n> objects"
+msgstr "visualizza l'avanzamento dopo <n> oggetti"
+
+#: builtin/fast-export.c:1154
+msgid "select handling of signed tags"
+msgstr "seleziona la gestione dei tag firmati"
+
+#: builtin/fast-export.c:1157
+msgid "select handling of tags that tag filtered objects"
+msgstr "seleziona la gestione dei tag che contrassegnano oggetti filtrati"
+
+#: builtin/fast-export.c:1160
+msgid "select handling of commit messages in an alternate encoding"
+msgstr ""
+"seleziona la gestione dei messaggi di commit in una codifica alternativa"
+
+#: builtin/fast-export.c:1163
+msgid "Dump marks to this file"
+msgstr "Esegui il dump dei contrassegni in questo file"
+
+#: builtin/fast-export.c:1165
+msgid "Import marks from this file"
+msgstr "Importa i contrassegni da questo file"
+
+#: builtin/fast-export.c:1169
+msgid "Import marks from this file if it exists"
+msgstr "Importa i contrassegni da questo file se esiste"
+
+#: builtin/fast-export.c:1171
+msgid "Fake a tagger when tags lack one"
+msgstr "Usa un tagger falso se i tag non ne hanno uno"
+
+#: builtin/fast-export.c:1173
+msgid "Output full tree for each commit"
+msgstr "Visualizza in output l'albero completo per ogni commit"
+
+#: builtin/fast-export.c:1175
+msgid "Use the done feature to terminate the stream"
+msgstr "Usa la funzionalità \"fatto\" per terminare il flusso"
+
+#: builtin/fast-export.c:1176
+msgid "Skip output of blob data"
+msgstr "Ometti l'output dei dati dei blob"
+
+#: builtin/fast-export.c:1177 builtin/log.c:1705
+msgid "refspec"
+msgstr "specificatore riferimento"
+
+#: builtin/fast-export.c:1178
+msgid "Apply refspec to exported refs"
+msgstr "Applica lo specificatore riferimento ai riferimenti esportati"
+
+#: builtin/fast-export.c:1179
+msgid "anonymize output"
+msgstr "rendi anonimo l'output"
+
+#: builtin/fast-export.c:1181
+msgid "Reference parents which are not in fast-export stream by object id"
+msgstr ""
+"Fai riferimento ai genitori non nel flusso fast-export tramite l'ID oggetto"
+
+#: builtin/fast-export.c:1183
+msgid "Show original object ids of blobs/commits"
+msgstr "Visualizza gli ID oggetto originari dei blob/commit"
+
+#: builtin/fast-export.c:1185
+msgid "Label tags with mark ids"
+msgstr "Etichetta i tag con ID contrassegno"
+
+#: builtin/fast-export.c:1220
+msgid "Cannot pass both --import-marks and --import-marks-if-exists"
+msgstr ""
+"Impossibile fornire entrambe le opzioni --import-marks e --import-marks-if-"
+"exists"
+
+#: builtin/fetch.c:34
+msgid "git fetch [<options>] [<repository> [<refspec>...]]"
+msgstr "git fetch [<opzioni>] [<repository> [<specificatore riferimento>...]]"
+
+#: builtin/fetch.c:35
+msgid "git fetch [<options>] <group>"
+msgstr "git fetch [<opzioni>] <gruppo>"
+
+#: builtin/fetch.c:36
+msgid "git fetch --multiple [<options>] [(<repository> | <group>)...]"
+msgstr "git fetch --multiple [<opzioni>] [(<repository> | <gruppo>)...]"
+
+#: builtin/fetch.c:37
+msgid "git fetch --all [<options>]"
+msgstr "git fetch --all [<opzioni>]"
+
+#: builtin/fetch.c:116
+msgid "fetch.parallel cannot be negative"
+msgstr "fetch.parallel non può essere negativo"
+
+#: builtin/fetch.c:139 builtin/pull.c:204
+msgid "fetch from all remotes"
+msgstr "esegui il fetch da tutti i remoti"
+
+#: builtin/fetch.c:141 builtin/pull.c:248
+msgid "set upstream for git pull/fetch"
+msgstr "imposta l'upstream per git pull/fetch"
+
+#: builtin/fetch.c:143 builtin/pull.c:207
+msgid "append to .git/FETCH_HEAD instead of overwriting"
+msgstr "aggiungi i dati a .git/FETCH_HEAD anziché sovrascriverli"
+
+#: builtin/fetch.c:145 builtin/pull.c:210
+msgid "path to upload pack on remote end"
+msgstr "percorso in cui caricare il pack sul remoto"
+
+#: builtin/fetch.c:146
+msgid "force overwrite of local reference"
+msgstr "forza la sovrascrittura del riferimento locale"
+
+#: builtin/fetch.c:148
+msgid "fetch from multiple remotes"
+msgstr "esegui il fetch da più remoti"
+
+#: builtin/fetch.c:150 builtin/pull.c:214
+msgid "fetch all tags and associated objects"
+msgstr "esegui il fetch di tutti i tag e degli oggetti associati"
+
+#: builtin/fetch.c:152
+msgid "do not fetch all tags (--no-tags)"
+msgstr "non eseguire il fetch di alcun tag (--no-tags)"
+
+#: builtin/fetch.c:154
+msgid "number of submodules fetched in parallel"
+msgstr "numero di sottomoduli recuperati in parallelo"
+
+#: builtin/fetch.c:156 builtin/pull.c:217
+msgid "prune remote-tracking branches no longer on remote"
+msgstr ""
+"elimina i branch che ne tracciano uno remoto ma non più presenti sul remoto"
+
+#: builtin/fetch.c:158
+msgid "prune local tags no longer on remote and clobber changed tags"
+msgstr ""
+"elimina i tag locali non più presenti sul remoto e sovrascrivi i tag "
+"modificati"
+
+#: builtin/fetch.c:159 builtin/fetch.c:182 builtin/pull.c:141
+msgid "on-demand"
+msgstr "a richiesta"
+
+#: builtin/fetch.c:160
+msgid "control recursive fetching of submodules"
+msgstr "controlla il recupero ricorsivo dei sottomoduli"
+
+#: builtin/fetch.c:164 builtin/pull.c:225
+msgid "keep downloaded pack"
+msgstr "mantieni il pack scaricato"
+
+#: builtin/fetch.c:166
+msgid "allow updating of HEAD ref"
+msgstr "consenti l'aggiornamento del riferimento HEAD"
+
+#: builtin/fetch.c:169 builtin/fetch.c:175 builtin/pull.c:228
+msgid "deepen history of shallow clone"
+msgstr "aumenta la profondità della cronologia di un clone shallow"
+
+#: builtin/fetch.c:171
+msgid "deepen history of shallow repository based on time"
+msgstr ""
+"aumenta la profondità della cronologia di un clone shallow in base al tempo"
+
+#: builtin/fetch.c:177 builtin/pull.c:231
+msgid "convert to a complete repository"
+msgstr "converti in un repository completo"
+
+#: builtin/fetch.c:180
+msgid "prepend this to submodule path output"
+msgstr "anteponi questo prefisso all'output del percorso del sottomodulo"
+
+#: builtin/fetch.c:183
+msgid ""
+"default for recursive fetching of submodules (lower priority than config "
+"files)"
+msgstr ""
+"impostazione predefinita per il recupero ricorsivo dei sottomoduli (a "
+"priorità minore rispetto ai file di configurazione)"
+
+#: builtin/fetch.c:187 builtin/pull.c:234
+msgid "accept refs that update .git/shallow"
+msgstr "accetta i riferimenti che aggiornano .git/shallow"
+
+#: builtin/fetch.c:188 builtin/pull.c:236
+msgid "refmap"
+msgstr "mappa riferimenti"
+
+#: builtin/fetch.c:189 builtin/pull.c:237
+msgid "specify fetch refmap"
+msgstr "specifica la mappa dei riferimenti per il fetch"
+
+#: builtin/fetch.c:196
+msgid "report that we have only objects reachable from this object"
+msgstr "segnala che abbiamo solo oggetti raggiungibili da quest'oggetto"
+
+#: builtin/fetch.c:199
+msgid "run 'gc --auto' after fetching"
+msgstr "esegui 'gc --auto' dopo il fetch"
+
+#: builtin/fetch.c:201 builtin/pull.c:246
+msgid "check for forced-updates on all updated branches"
+msgstr "controlla aggiornamenti forzati su tutti i branch aggiornati"
+
+#: builtin/fetch.c:203
+msgid "write the commit-graph after fetching"
+msgstr "scrivi il grafo dei commit dopo il fetch"
+
+#: builtin/fetch.c:513
+msgid "Couldn't find remote ref HEAD"
+msgstr "Impossibile trovare l'HEAD del riferimento remoto"
+
+#: builtin/fetch.c:653
+#, c-format
+msgid "configuration fetch.output contains invalid value %s"
+msgstr "il valore dell'opzione fetch.output contiene il valore non valido %s"
+
+#: builtin/fetch.c:751
+#, c-format
+msgid "object %s not found"
+msgstr "oggetto %s non trovato"
+
+#: builtin/fetch.c:755
+msgid "[up to date]"
+msgstr "[aggiornato]"
+
+#: builtin/fetch.c:768 builtin/fetch.c:784 builtin/fetch.c:856
+msgid "[rejected]"
+msgstr "[rifiutato]"
+
+#: builtin/fetch.c:769
+msgid "can't fetch in current branch"
+msgstr "impossibile eseguire il fetch nel branch corrente"
+
+#: builtin/fetch.c:779
+msgid "[tag update]"
+msgstr "[tag aggiornato]"
+
+#: builtin/fetch.c:780 builtin/fetch.c:817 builtin/fetch.c:839
+#: builtin/fetch.c:851
+msgid "unable to update local ref"
+msgstr "impossibile aggiornare il riferimento locale"
+
+#: builtin/fetch.c:784
+msgid "would clobber existing tag"
+msgstr "sovrascriverebbe il tag esistente"
+
+#: builtin/fetch.c:806
+msgid "[new tag]"
+msgstr "[nuovo tag]"
+
+#: builtin/fetch.c:809
+msgid "[new branch]"
+msgstr "[nuovo branch]"
+
+#: builtin/fetch.c:812
+msgid "[new ref]"
+msgstr "[nuovo riferimento]"
+
+#: builtin/fetch.c:851
+msgid "forced update"
+msgstr "aggiornamento forzato"
+
+#: builtin/fetch.c:856
+msgid "non-fast-forward"
+msgstr "non fast forward"
+
+#: builtin/fetch.c:877
+msgid ""
+"Fetch normally indicates which branches had a forced update,\n"
+"but that check has been disabled. To re-enable, use '--show-forced-updates'\n"
+"flag or run 'git config fetch.showForcedUpdates true'."
+msgstr ""
+"Il fetch normalmente indica quali branch siano stati sottoposti ad\n"
+"aggiornamento forzato, ma tale controllo è stato disabilitato. Per\n"
+"riabilitarlo, usa l'opzione '--show-forced-updates' o esegui 'git config\n"
+"fetch.showForcedUpdates true'."
+
+#: builtin/fetch.c:881
+#, c-format
+msgid ""
+"It took %.2f seconds to check forced updates. You can use\n"
+"'--no-show-forced-updates' or run 'git config fetch.showForcedUpdates "
+"false'\n"
+" to avoid this check.\n"
+msgstr ""
+"Sono stati richiesti %.2f secondi per controllare la presenza di eventuali\n"
+"aggiornamenti forzati. Puoi usare '--no-show-forced-updates' o eseguire\n"
+"'git config fetch.showForcedUpdates false' per omettere questo controllo.\n"
+
+#: builtin/fetch.c:911
+#, c-format
+msgid "%s did not send all necessary objects\n"
+msgstr "%s non ha inviato tutti gli oggetti necessari\n"
+
+#: builtin/fetch.c:932
+#, c-format
+msgid "reject %s because shallow roots are not allowed to be updated"
+msgstr "%s rifiutato perché non è consentito aggiornare radici shallow"
+
+#: builtin/fetch.c:1017 builtin/fetch.c:1155
+#, c-format
+msgid "From %.*s\n"
+msgstr "Da %.*s\n"
+
+#: builtin/fetch.c:1028
+#, c-format
+msgid ""
+"some local refs could not be updated; try running\n"
+" 'git remote prune %s' to remove any old, conflicting branches"
+msgstr ""
+"non è stato possibile aggiornare alcuni riferimenti locali; prova ad "
+"eseguire\n"
+" 'git remote prune %s' per rimuovere ogni branch vecchio in conflitto"
+
+#: builtin/fetch.c:1125
+#, c-format
+msgid "   (%s will become dangling)"
+msgstr "   (%s diventerà pendente)"
+
+#: builtin/fetch.c:1126
+#, c-format
+msgid "   (%s has become dangling)"
+msgstr "   (%s è diventato pendente)"
+
+#: builtin/fetch.c:1158
+msgid "[deleted]"
+msgstr "[eliminato]"
+
+#: builtin/fetch.c:1159 builtin/remote.c:1035
+msgid "(none)"
+msgstr "(nessuno)"
+
+#: builtin/fetch.c:1182
+#, c-format
+msgid "Refusing to fetch into current branch %s of non-bare repository"
+msgstr ""
+"Mi rifiuto di eseguire il fetch nel branch corrente %s di un repository non "
+"bare"
+
+#: builtin/fetch.c:1201
+#, c-format
+msgid "Option \"%s\" value \"%s\" is not valid for %s"
+msgstr "L'opzione \"%s\" con il valore \"%s\" non è valida per %s"
+
+#: builtin/fetch.c:1204
+#, c-format
+msgid "Option \"%s\" is ignored for %s\n"
+msgstr "L'opzione \"%s\" è ignorata per %s\n"
+
+#: builtin/fetch.c:1412
+msgid "multiple branches detected, incompatible with --set-upstream"
+msgstr "rilevati branch multipli, stato incompatibile con --set-upstream"
+
+#: builtin/fetch.c:1427
+msgid "not setting upstream for a remote remote-tracking branch"
+msgstr "non imposto l'upstream per un branch remoto che ne traccia uno remoto"
+
+#: builtin/fetch.c:1429
+msgid "not setting upstream for a remote tag"
+msgstr "non imposto l'upstream per un tag remoto"
+
+#: builtin/fetch.c:1431
+msgid "unknown branch type"
+msgstr "tipo branch sconosciuto"
+
+#: builtin/fetch.c:1433
+msgid ""
+"no source branch found.\n"
+"you need to specify exactly one branch with the --set-upstream option."
+msgstr ""
+"nessun branch sorgente trovato.\n"
+"devi specificare esattamente un branch con l'opzione --set-upstream."
+
+#: builtin/fetch.c:1559 builtin/fetch.c:1622
+#, c-format
+msgid "Fetching %s\n"
+msgstr "Recupero di %s in corso\n"
+
+#: builtin/fetch.c:1569 builtin/fetch.c:1624 builtin/remote.c:100
+#, c-format
+msgid "Could not fetch %s"
+msgstr "Impossibile recuperare %s"
+
+#: builtin/fetch.c:1581
+#, c-format
+msgid "could not fetch '%s' (exit code: %d)\n"
+msgstr "impossibile recuperare '%s' (codice di uscita: %d)\n"
+
+#: builtin/fetch.c:1684
+msgid ""
+"No remote repository specified.  Please, specify either a URL or a\n"
+"remote name from which new revisions should be fetched."
+msgstr ""
+"Non è stato specificato alcun repository remoto. Specifica un URL o il\n"
+"nome di un remoto da cui dovranno essere recuperate le nuove revisioni."
+
+#: builtin/fetch.c:1721
+msgid "You need to specify a tag name."
+msgstr "Devi specificare il nome di un tag."
+
+#: builtin/fetch.c:1771
+msgid "Negative depth in --deepen is not supported"
+msgstr "Le profondità negative in --deepen non sono supportate"
+
+#: builtin/fetch.c:1773
+msgid "--deepen and --depth are mutually exclusive"
+msgstr "le opzioni --deepen e --depth sono mutualmente esclusive"
+
+#: builtin/fetch.c:1778
+msgid "--depth and --unshallow cannot be used together"
+msgstr "--depth e --unshallow non possono essere usati insieme."
+
+#: builtin/fetch.c:1780
+msgid "--unshallow on a complete repository does not make sense"
+msgstr "--unshallow su un repository completo non ha senso"
+
+#: builtin/fetch.c:1796
+msgid "fetch --all does not take a repository argument"
+msgstr "fetch --all non richiede un repository come argomento"
+
+#: builtin/fetch.c:1798
+msgid "fetch --all does not make sense with refspecs"
+msgstr "fetch --all non ha senso con degli specificatori riferimento"
+
+#: builtin/fetch.c:1807
+#, c-format
+msgid "No such remote or remote group: %s"
+msgstr "Remoto o gruppo remoti non esistente: %s"
+
+#: builtin/fetch.c:1814
+msgid "Fetching a group and specifying refspecs does not make sense"
+msgstr ""
+"Recuperare un gruppo e specificare gli specificatori riferimento non ha senso"
+
+#: builtin/fetch.c:1832
+msgid ""
+"--filter can only be used with the remote configured in extensions."
+"partialclone"
+msgstr ""
+"--filter può essere usato solo con il remoto configurato nelle estensioni."
+"partialclone"
+
+#: builtin/fmt-merge-msg.c:18
+msgid ""
+"git fmt-merge-msg [-m <message>] [--log[=<n>] | --no-log] [--file <file>]"
+msgstr ""
+"git fmt-merge-msg [-m <messaggio>] [--log[=<n>] | --no-log] [--file <file>]"
+
+#: builtin/fmt-merge-msg.c:674
+msgid "populate log with at most <n> entries from shortlog"
+msgstr "popola il registro con al più <n> voci del registro breve"
+
+#: builtin/fmt-merge-msg.c:677
+msgid "alias for --log (deprecated)"
+msgstr "alias di --log (deprecato)"
+
+#: builtin/fmt-merge-msg.c:680
+msgid "text"
+msgstr "testo"
+
+#: builtin/fmt-merge-msg.c:681
+msgid "use <text> as start of message"
+msgstr "usa <testo> come stringa iniziale del messaggio"
+
+#: builtin/fmt-merge-msg.c:682
+msgid "file to read from"
+msgstr "file da cui leggere"
+
+#: builtin/for-each-ref.c:10
+msgid "git for-each-ref [<options>] [<pattern>]"
+msgstr "git for-each-ref [<opzioni>] [<pattern>]"
+
+#: builtin/for-each-ref.c:11
+msgid "git for-each-ref [--points-at <object>]"
+msgstr "git for-each-ref [--points-at <oggetto>]"
+
+#: builtin/for-each-ref.c:12
+msgid "git for-each-ref [(--merged | --no-merged) [<commit>]]"
+msgstr "git for-each-ref [(--merged | --no-merged) [<commit>]]"
+
+#: builtin/for-each-ref.c:13
+msgid "git for-each-ref [--contains [<commit>]] [--no-contains [<commit>]]"
+msgstr "git for-each-ref [--contains [<commit>]] [--no-contains [<commit>]]"
+
+#: builtin/for-each-ref.c:28
+msgid "quote placeholders suitably for shells"
+msgstr ""
+"racchiudi i segnaposto fra virgolette in modo da poterli usare in una shell"
+
+#: builtin/for-each-ref.c:30
+msgid "quote placeholders suitably for perl"
+msgstr ""
+"racchiudi i segnaposto fra virgolette in modo da poterli usare con Perl"
+
+#: builtin/for-each-ref.c:32
+msgid "quote placeholders suitably for python"
+msgstr ""
+"racchiudi i segnaposto fra virgolette in modo da poterli usare con Python"
+
+#: builtin/for-each-ref.c:34
+msgid "quote placeholders suitably for Tcl"
+msgstr "racchiudi i segnaposto fra virgolette in modo da poterli usare con Tcl"
+
+#: builtin/for-each-ref.c:37
+msgid "show only <n> matched refs"
+msgstr "visualizza solo <n> riferimenti corrispondenti"
+
+#: builtin/for-each-ref.c:39 builtin/tag.c:439
+msgid "respect format colors"
+msgstr "rispetta le stringhe di formato per i colori"
+
+#: builtin/for-each-ref.c:42
+msgid "print only refs which points at the given object"
+msgstr "stampa solo i riferimenti che puntano all'oggetto dato"
+
+#: builtin/for-each-ref.c:44
+msgid "print only refs that are merged"
+msgstr "stampa solo i riferimenti sottoposti a merge"
+
+#: builtin/for-each-ref.c:45
+msgid "print only refs that are not merged"
+msgstr "stampa solo i riferimenti non sottoposti a merge"
+
+#: builtin/for-each-ref.c:46
+msgid "print only refs which contain the commit"
+msgstr "stampa solo i riferimenti contenenti il commit"
+
+#: builtin/for-each-ref.c:47
+msgid "print only refs which don't contain the commit"
+msgstr "stampa solo i riferimenti che non contengono il commit"
+
+#: builtin/fsck.c:68 builtin/fsck.c:147 builtin/fsck.c:148
+msgid "unknown"
+msgstr "sconosciuto"
+
+#. TRANSLATORS: e.g. error in tree 01bfda: <more explanation>
+#: builtin/fsck.c:100 builtin/fsck.c:120
+#, c-format
+msgid "error in %s %s: %s"
+msgstr "errore in %s %s: %s"
+
+#. TRANSLATORS: e.g. warning in tree 01bfda: <more explanation>
+#: builtin/fsck.c:114
+#, c-format
+msgid "warning in %s %s: %s"
+msgstr "avviso in %s %s: %s"
+
+#: builtin/fsck.c:143 builtin/fsck.c:146
+#, c-format
+msgid "broken link from %7s %s"
+msgstr "collegamento rotto da %7s %s"
+
+#: builtin/fsck.c:155
+msgid "wrong object type in link"
+msgstr "tipo oggetto errato nel collegamento"
+
+#: builtin/fsck.c:171
+#, c-format
+msgid ""
+"broken link from %7s %s\n"
+"              to %7s %s"
+msgstr ""
+"collegamento rotto da %7s %s\n"
+"                   a %7s %s"
+
+#: builtin/fsck.c:282
+#, c-format
+msgid "missing %s %s"
+msgstr "%s mancante %s"
+
+#: builtin/fsck.c:309
+#, c-format
+msgid "unreachable %s %s"
+msgstr "%s non raggiungibile %s"
+
+#: builtin/fsck.c:329
+#, c-format
+msgid "dangling %s %s"
+msgstr "%s pendente %s"
+
+#: builtin/fsck.c:339
+msgid "could not create lost-found"
+msgstr "impossibile creare lost-found"
+
+#: builtin/fsck.c:350
+#, c-format
+msgid "could not finish '%s'"
+msgstr "impossibile terminare '%s'"
+
+#: builtin/fsck.c:367
+#, c-format
+msgid "Checking %s"
+msgstr "Controllo di %s in corso"
+
+#: builtin/fsck.c:405
+#, c-format
+msgid "Checking connectivity (%d objects)"
+msgstr "Controllo connessione in corso (%d oggetti)"
+
+#: builtin/fsck.c:424
+#, c-format
+msgid "Checking %s %s"
+msgstr "Controllo di %s in corso %s"
+
+#: builtin/fsck.c:429
+msgid "broken links"
+msgstr "collegamenti rotti"
+
+#: builtin/fsck.c:438
+#, c-format
+msgid "root %s"
+msgstr "radice %s"
+
+#: builtin/fsck.c:446
+#, c-format
+msgid "tagged %s %s (%s) in %s"
+msgstr "eseguito tag di %s %s (%s) in %s"
+
+#: builtin/fsck.c:475
+#, c-format
+msgid "%s: object corrupt or missing"
+msgstr "%s: oggetto corrotto o mancante"
+
+#: builtin/fsck.c:500
+#, c-format
+msgid "%s: invalid reflog entry %s"
+msgstr "%s: voce registro riferimenti non valida: %s"
+
+#: builtin/fsck.c:514
+#, c-format
+msgid "Checking reflog %s->%s"
+msgstr "Controllo registro riferimenti %s->%s"
+
+#: builtin/fsck.c:548
+#, c-format
+msgid "%s: invalid sha1 pointer %s"
+msgstr "%s: puntatore SHA1 non valido: %s"
+
+#: builtin/fsck.c:555
+#, c-format
+msgid "%s: not a commit"
+msgstr "%s: non è un commit"
+
+#: builtin/fsck.c:609
+msgid "notice: No default references"
+msgstr "avviso: nessun riferimento predefinito"
+
+#: builtin/fsck.c:624
+#, c-format
+msgid "%s: object corrupt or missing: %s"
+msgstr "%s: oggetto corrotto o mancante: %s"
+
+#: builtin/fsck.c:637
+#, c-format
+msgid "%s: object could not be parsed: %s"
+msgstr "%s: impossibile analizzare l'oggetto: %s"
+
+#: builtin/fsck.c:657
+#, c-format
+msgid "bad sha1 file: %s"
+msgstr "file SHA1 non valido: %s"
+
+#: builtin/fsck.c:672
+msgid "Checking object directory"
+msgstr "Controllo directory oggetti in corso"
+
+#: builtin/fsck.c:675
+msgid "Checking object directories"
+msgstr "Controllo directory oggetti in corso"
+
+#: builtin/fsck.c:690
+#, c-format
+msgid "Checking %s link"
+msgstr "Controllo collegamento %s"
+
+#: builtin/fsck.c:695 builtin/index-pack.c:842
+#, c-format
+msgid "invalid %s"
+msgstr "%s non valido"
+
+#: builtin/fsck.c:702
+#, c-format
+msgid "%s points to something strange (%s)"
+msgstr "%s punta a qualcosa di strano (%s)"
+
+#: builtin/fsck.c:708
+#, c-format
+msgid "%s: detached HEAD points at nothing"
+msgstr "%s: l'HEAD scollegato non punta a niente"
+
+#: builtin/fsck.c:712
+#, c-format
+msgid "notice: %s points to an unborn branch (%s)"
+msgstr "avviso: %s punta a un branch non nato (%s)"
+
+#: builtin/fsck.c:724
+msgid "Checking cache tree"
+msgstr "Controllo cache albero in corso"
+
+#: builtin/fsck.c:729
+#, c-format
+msgid "%s: invalid sha1 pointer in cache-tree"
+msgstr "%s: puntatore SHA1 non valido nella cache alberi"
+
+#: builtin/fsck.c:738
+msgid "non-tree in cache-tree"
+msgstr "oggetto non albero nella cache alberi"
+
+#: builtin/fsck.c:769
+msgid "git fsck [<options>] [<object>...]"
+msgstr "git fsck [<opzioni>] [<oggetto>...]"
+
+#: builtin/fsck.c:775
+msgid "show unreachable objects"
+msgstr "visualizza oggetti non raggiungibili"
+
+#: builtin/fsck.c:776
+msgid "show dangling objects"
+msgstr "visualizza oggetti pendenti"
+
+#: builtin/fsck.c:777
+msgid "report tags"
+msgstr "segnala i tag"
+
+#: builtin/fsck.c:778
+msgid "report root nodes"
+msgstr "segnala i nodi radice"
+
+#: builtin/fsck.c:779
+msgid "make index objects head nodes"
+msgstr "rendi gli oggetti indice nodi head"
+
+#: builtin/fsck.c:780
+msgid "make reflogs head nodes (default)"
+msgstr "rendi i registri dei riferimenti nodi head (impostazione predefinita)"
+
+#: builtin/fsck.c:781
+msgid "also consider packs and alternate objects"
+msgstr "considera anche i pack e gli oggetti alternativi"
+
+#: builtin/fsck.c:782
+msgid "check only connectivity"
+msgstr "controlla solo la connessione"
+
+#: builtin/fsck.c:783
+msgid "enable more strict checking"
+msgstr "abilita controlli più restrittivi"
+
+#: builtin/fsck.c:785
+msgid "write dangling objects in .git/lost-found"
+msgstr "scrivi oggetti pendenti in .git/lost-found"
+
+#: builtin/fsck.c:786 builtin/prune.c:132
+msgid "show progress"
+msgstr "visualizza l'avanzamento"
+
+#: builtin/fsck.c:787
+msgid "show verbose names for reachable objects"
+msgstr "visualizza nomi dettagliati per gli oggetti raggiungibili"
+
+#: builtin/fsck.c:846 builtin/index-pack.c:225
+msgid "Checking objects"
+msgstr "Controllo oggetti in corso"
+
+#: builtin/fsck.c:874
+#, c-format
+msgid "%s: object missing"
+msgstr "%s: oggetto mancante"
+
+#: builtin/fsck.c:885
+#, c-format
+msgid "invalid parameter: expected sha1, got '%s'"
+msgstr "parametro non valido: atteso SHA1, presente '%s'"
+
+#: builtin/gc.c:35
+msgid "git gc [<options>]"
+msgstr "git gc [<opzioni>]"
+
+#: builtin/gc.c:90
+#, c-format
+msgid "Failed to fstat %s: %s"
+msgstr "fstat di %s non riuscito: %s"
+
+#: builtin/gc.c:126
+#, c-format
+msgid "failed to parse '%s' value '%s'"
+msgstr "analisi dell'opzione '%s' con valore '%s' non riuscita"
+
+#: builtin/gc.c:475 builtin/init-db.c:55
+#, c-format
+msgid "cannot stat '%s'"
+msgstr "impossibile eseguire lo stat di '%s'"
+
+#: builtin/gc.c:484 builtin/notes.c:240 builtin/tag.c:529
+#, c-format
+msgid "cannot read '%s'"
+msgstr "impossibile leggere '%s'"
+
+#: builtin/gc.c:491
+#, c-format
+msgid ""
+"The last gc run reported the following. Please correct the root cause\n"
+"and remove %s.\n"
+"Automatic cleanup will not be performed until the file is removed.\n"
+"\n"
+"%s"
+msgstr ""
+"L'ultima esecuzione di gc ha segnalato quanto segue. Correggi la causa\n"
+"alla radice ed elimina %s.\n"
+"L'operazione di pulizia automatica non sarà eseguita fino all'eliminazione\n"
+"del file.\n"
+"\n"
+"%s"
+
+#: builtin/gc.c:539
+msgid "prune unreferenced objects"
+msgstr "elimina oggetti non referenziati"
+
+#: builtin/gc.c:541
+msgid "be more thorough (increased runtime)"
+msgstr "sii più accurato (tempi di esecuzione maggiori)"
+
+#: builtin/gc.c:542
+msgid "enable auto-gc mode"
+msgstr "abilita modalità garbage collector automatica"
+
+#: builtin/gc.c:545
+msgid "force running gc even if there may be another gc running"
+msgstr ""
+"forza l'esecuzione del garbage collector anche nel caso in cui ve ne "
+"potrebbe essere un altro in esecuzione"
+
+#: builtin/gc.c:548
+msgid "repack all other packs except the largest pack"
+msgstr ""
+"esegui il repack di tutti gli altri pack ad eccezione di quello più grande"
+
+#: builtin/gc.c:565
+#, c-format
+msgid "failed to parse gc.logexpiry value %s"
+msgstr "analisi del valore %s di gc.logexpiry non riuscita"
+
+#: builtin/gc.c:576
+#, c-format
+msgid "failed to parse prune expiry value %s"
+msgstr "analisi del valore %s per la scadenza delle eliminazioni non riuscita"
+
+#: builtin/gc.c:596
+#, c-format
+msgid "Auto packing the repository in background for optimum performance.\n"
+msgstr ""
+"Comprimo il repository in background per ottenere le migliori prestazioni.\n"
+
+#: builtin/gc.c:598
+#, c-format
+msgid "Auto packing the repository for optimum performance.\n"
+msgstr "Comprimo il repository per ottenere le migliori prestazioni.\n"
+
+#: builtin/gc.c:599
+#, c-format
+msgid "See \"git help gc\" for manual housekeeping.\n"
+msgstr "Vedi \"git help gc\" per le operazioni di manutenzione manuali.\n"
+
+#: builtin/gc.c:639
+#, c-format
+msgid ""
+"gc is already running on machine '%s' pid %<PRIuMAX> (use --force if not)"
+msgstr ""
+"gc è già in esecuzione sul computer '%s' con PID %<PRIuMAX> (usa --force se "
+"non lo è)"
+
+#: builtin/gc.c:694
+msgid ""
+"There are too many unreachable loose objects; run 'git prune' to remove them."
+msgstr ""
+"Ci sono troppi oggetti sparsi non raggiungibili; esegui 'git prune' per "
+"eliminarli."
+
+#: builtin/grep.c:29
+msgid "git grep [<options>] [-e] <pattern> [<rev>...] [[--] <path>...]"
+msgstr ""
+"git grep [<opzioni>] [-e] <pattern> [<revisione>...] [[--] <percorso>...]"
+
+#: builtin/grep.c:225
+#, c-format
+msgid "grep: failed to create thread: %s"
+msgstr "grep: creazione del thread non riuscita: %s"
+
+#: builtin/grep.c:279
+#, c-format
+msgid "invalid number of threads specified (%d) for %s"
+msgstr "specificato numero non valido di thread (%d) per %s"
+
+#. TRANSLATORS: %s is the configuration
+#. variable for tweaking threads, currently
+#. grep.threads
+#.
+#: builtin/grep.c:287 builtin/index-pack.c:1534 builtin/index-pack.c:1727
+#: builtin/pack-objects.c:2708
+#, c-format
+msgid "no threads support, ignoring %s"
+msgstr "non vi è supporto per i thread, ignoro %s"
+
+#: builtin/grep.c:467 builtin/grep.c:592 builtin/grep.c:635
+#, c-format
+msgid "unable to read tree (%s)"
+msgstr "impossibile leggere il tree (%s)"
+
+#: builtin/grep.c:650
+#, c-format
+msgid "unable to grep from object of type %s"
+msgstr "impossibile eseguire grep su un oggetto di tipo %s"
+
+#: builtin/grep.c:716
+#, c-format
+msgid "switch `%c' expects a numerical value"
+msgstr "switch '%c' richiede un valore numerico"
+
+#: builtin/grep.c:815
+msgid "search in index instead of in the work tree"
+msgstr "cerca nell'index anziché nell'albero di lavoro"
+
+#: builtin/grep.c:817
+msgid "find in contents not managed by git"
+msgstr "la ricerca nei contenuti non è gestita da Git"
+
+#: builtin/grep.c:819
+msgid "search in both tracked and untracked files"
+msgstr "cerca sia nei file tracciati sia in quelli non tracciati"
+
+#: builtin/grep.c:821
+msgid "ignore files specified via '.gitignore'"
+msgstr "ignora i file specificati in '.gitignore'"
+
+#: builtin/grep.c:823
+msgid "recursively search in each submodule"
+msgstr "cerca ricorsivamente in ogni sottomodulo"
+
+#: builtin/grep.c:826
+msgid "show non-matching lines"
+msgstr "visualizza le righe non corrispondenti"
+
+#: builtin/grep.c:828
+msgid "case insensitive matching"
+msgstr "ricerca corrispondenze senza differenze maiuscole/minuscole"
+
+#: builtin/grep.c:830
+msgid "match patterns only at word boundaries"
+msgstr "cerca corrispondenze ai pattern solo a inizio/fine parola"
+
+#: builtin/grep.c:832
+msgid "process binary files as text"
+msgstr "elabora i file binari come testuali"
+
+#: builtin/grep.c:834
+msgid "don't match patterns in binary files"
+msgstr "non cercare corrispondenze ai pattern nei file binari"
+
+#: builtin/grep.c:837
+msgid "process binary files with textconv filters"
+msgstr "elabora i file binari con filtri di conversione in testo"
+
+#: builtin/grep.c:839
+msgid "search in subdirectories (default)"
+msgstr "cerca nelle sottodirectory (impostazione predefinita)"
+
+#: builtin/grep.c:841
+msgid "descend at most <depth> levels"
+msgstr "scendi al più di <profondità> livelli"
+
+#: builtin/grep.c:845
+msgid "use extended POSIX regular expressions"
+msgstr "usa espressioni regolari POSIX estese"
+
+#: builtin/grep.c:848
+msgid "use basic POSIX regular expressions (default)"
+msgstr "usa espressioni regolari POSIX di base (impostazione predefinita)"
+
+#: builtin/grep.c:851
+msgid "interpret patterns as fixed strings"
+msgstr "interpreta i pattern come stringhe fisse"
+
+#: builtin/grep.c:854
+msgid "use Perl-compatible regular expressions"
+msgstr "usa espressioni regolari compatibili con Perl"
+
+#: builtin/grep.c:857
+msgid "show line numbers"
+msgstr "visualizza numeri di riga"
+
+#: builtin/grep.c:858
+msgid "show column number of first match"
+msgstr "visualizza il numero di colonna della prima corrispondenza"
+
+#: builtin/grep.c:859
+msgid "don't show filenames"
+msgstr "non visualizzare i nomi file"
+
+#: builtin/grep.c:860
+msgid "show filenames"
+msgstr "visualizza i nomi file"
+
+#: builtin/grep.c:862
+msgid "show filenames relative to top directory"
+msgstr "visualizza i nomi file relativi alla directory di primo livello"
+
+#: builtin/grep.c:864
+msgid "show only filenames instead of matching lines"
+msgstr "visualizza solo i nomi file anziché le righe corrispondenti"
+
+#: builtin/grep.c:866
+msgid "synonym for --files-with-matches"
+msgstr "sinonimo di --files-with-matches"
+
+#: builtin/grep.c:869
+msgid "show only the names of files without match"
+msgstr "visualizza solo i nomi dei file non corrispondenti"
+
+#: builtin/grep.c:871
+msgid "print NUL after filenames"
+msgstr "stampa NUL dopo i nomi file"
+
+#: builtin/grep.c:874
+msgid "show only matching parts of a line"
+msgstr "visualizza solo le parti corrispondenti di una riga"
+
+#: builtin/grep.c:876
+msgid "show the number of matches instead of matching lines"
+msgstr "visualizza il numero di corrispondenze anziché le righe corrispondenti"
+
+#: builtin/grep.c:877
+msgid "highlight matches"
+msgstr "evidenzia corrispondenze"
+
+#: builtin/grep.c:879
+msgid "print empty line between matches from different files"
+msgstr "stampa una riga vuota fra le corrispondenze in file differenti"
+
+#: builtin/grep.c:881
+msgid "show filename only once above matches from same file"
+msgstr ""
+"visualizza il nome file solo una volta prima delle corrispondenze nello "
+"stesso file"
+
+#: builtin/grep.c:884
+msgid "show <n> context lines before and after matches"
+msgstr "visualizza <n> righe di contesto prima e dopo le corrispondenze"
+
+#: builtin/grep.c:887
+msgid "show <n> context lines before matches"
+msgstr "visualizza <n> righe di contesto prima delle corrispondenze"
+
+#: builtin/grep.c:889
+msgid "show <n> context lines after matches"
+msgstr "visualizza <n> righe di contesto dopo le corrispondenze"
+
+#: builtin/grep.c:891
+msgid "use <n> worker threads"
+msgstr "usa <n> thread di lavoro"
+
+#: builtin/grep.c:892
+msgid "shortcut for -C NUM"
+msgstr "scorciatoia per -C NUM"
+
+#: builtin/grep.c:895
+msgid "show a line with the function name before matches"
+msgstr "visualizza una riga con il nome funzione prima delle corrispondenze"
+
+#: builtin/grep.c:897
+msgid "show the surrounding function"
+msgstr "visualizza la funzione circostante"
+
+#: builtin/grep.c:900
+msgid "read patterns from file"
+msgstr "leggi le corrispondenze da un file"
+
+#: builtin/grep.c:902
+msgid "match <pattern>"
+msgstr "cerca corrispondenze con <pattern>"
+
+#: builtin/grep.c:904
+msgid "combine patterns specified with -e"
+msgstr "combina i pattern specificati con -e"
+
+#: builtin/grep.c:916
+msgid "indicate hit with exit status without output"
+msgstr ""
+"segnala una corrispondenza con il codice di uscita senza emettere output"
+
+#: builtin/grep.c:918
+msgid "show only matches from files that match all patterns"
+msgstr ""
+"visualizza solo le corrispondenze nei file in cui vi sono corrispondenze per "
+"tutti i pattern"
+
+#: builtin/grep.c:920
+msgid "show parse tree for grep expression"
+msgstr "visualizza l'albero di analisi per l'espressione grep"
+
+#: builtin/grep.c:924
+msgid "pager"
+msgstr "pager"
+
+#: builtin/grep.c:924
+msgid "show matching files in the pager"
+msgstr "visualizza i file corrispondenti nel pager"
+
+#: builtin/grep.c:928
+msgid "allow calling of grep(1) (ignored by this build)"
+msgstr "consenti"
+
+#: builtin/grep.c:992
+msgid "no pattern given"
+msgstr "nessun pattern specificato"
+
+#: builtin/grep.c:1028
+msgid "--no-index or --untracked cannot be used with revs"
+msgstr "--no-index o --untracked non possono essere usate con le revisioni"
+
+#: builtin/grep.c:1036
+#, c-format
+msgid "unable to resolve revision: %s"
+msgstr "impossibile risolvere la revisione %s"
+
+#: builtin/grep.c:1067
+msgid "invalid option combination, ignoring --threads"
+msgstr "combinazione di opzioni non valida, ignoro --threads"
+
+#: builtin/grep.c:1070 builtin/pack-objects.c:3400
+msgid "no threads support, ignoring --threads"
+msgstr "non vi è supporto per i thread, ignoro --threads"
+
+#: builtin/grep.c:1073 builtin/index-pack.c:1531 builtin/pack-objects.c:2705
+#, c-format
+msgid "invalid number of threads specified (%d)"
+msgstr "specificato numero non valido di thread (%d)"
+
+#: builtin/grep.c:1096
+msgid "--open-files-in-pager only works on the worktree"
+msgstr "--open-files-in-pager funziona solo sull'albero di lavoro"
+
+#: builtin/grep.c:1119
+msgid "option not supported with --recurse-submodules"
+msgstr "opzione non supportata con --recurse-submodules"
+
+#: builtin/grep.c:1125
+msgid "--cached or --untracked cannot be used with --no-index"
+msgstr "--cached o --untracked non possono essere usate con --no-index"
+
+#: builtin/grep.c:1131
+msgid "--[no-]exclude-standard cannot be used for tracked contents"
+msgstr "--[no-]exclude-standard non può essere usata per i contenuti tracciati"
+
+#: builtin/grep.c:1139
+msgid "both --cached and trees are given"
+msgstr "sono specificati sia --cached sia degli alberi"
+
+#: builtin/hash-object.c:85
+msgid ""
+"git hash-object [-t <type>] [-w] [--path=<file> | --no-filters] [--stdin] "
+"[--] <file>..."
+msgstr ""
+"git hash-object [-t <tipo>] [-w] [--path=<file> | --no-filters] [--stdin] "
+"[--] <file>..."
+
+#: builtin/hash-object.c:86
+msgid "git hash-object  --stdin-paths"
+msgstr "git hash-object  --stdin-paths"
+
+#: builtin/hash-object.c:98
+msgid "object type"
+msgstr "tipo oggetto"
+
+#: builtin/hash-object.c:99
+msgid "write the object into the object database"
+msgstr "scrivi l'oggetto nel database oggetti"
+
+#: builtin/hash-object.c:101
+msgid "read the object from stdin"
+msgstr "leggi l'oggetto dallo standard input"
+
+#: builtin/hash-object.c:103
+msgid "store file as is without filters"
+msgstr "salva il file così com'è senza filtri"
+
+#: builtin/hash-object.c:104
+msgid ""
+"just hash any random garbage to create corrupt objects for debugging Git"
+msgstr ""
+"esegui semplicemente l'hash di dati inutili per creare oggetti corrotti al "
+"fine di eseguire il debug di Git"
+
+#: builtin/hash-object.c:105
+msgid "process file as it were from this path"
+msgstr "elabora i file come se fossero in questo percorso"
+
+#: builtin/help.c:46
+msgid "print all available commands"
+msgstr "stampa tutti i comandi disponibili"
+
+#: builtin/help.c:47
+msgid "exclude guides"
+msgstr "escludi le guide"
+
+#: builtin/help.c:48
+msgid "print list of useful guides"
+msgstr "stampa un elenco di guide utili"
+
+#: builtin/help.c:49
+msgid "print all configuration variable names"
+msgstr "stampa i nomi di tutte le variabili di configurazione"
+
+#: builtin/help.c:51
+msgid "show man page"
+msgstr "visualizza la pagina man"
+
+#: builtin/help.c:52
+msgid "show manual in web browser"
+msgstr "visualizza il manuale nel browser Web"
+
+#: builtin/help.c:54
+msgid "show info page"
+msgstr "visualizza la pagina info"
+
+#: builtin/help.c:56
+msgid "print command description"
+msgstr "stampa la descrizione del comando"
+
+#: builtin/help.c:61
+msgid "git help [--all] [--guides] [--man | --web | --info] [<command>]"
+msgstr "git help [--all] [--guides] [--man | --web | --info] [<comando>]"
+
+#: builtin/help.c:77
+#, c-format
+msgid "unrecognized help format '%s'"
+msgstr "formato di aiuto '%s' non riconosciuto"
+
+#: builtin/help.c:104
+msgid "Failed to start emacsclient."
+msgstr "Esecuzione di emacsclient non riuscita."
+
+#: builtin/help.c:117
+msgid "Failed to parse emacsclient version."
+msgstr "Verifica della versione di emacsclient non riuscita."
+
+#: builtin/help.c:125
+#, c-format
+msgid "emacsclient version '%d' too old (< 22)."
+msgstr "la versione '%d' di emacsclient è troppo vecchia (<22)."
+
+#: builtin/help.c:143 builtin/help.c:165 builtin/help.c:175 builtin/help.c:183
+#, c-format
+msgid "failed to exec '%s'"
+msgstr "esecuzione di '%s' non riuscita"
+
+#: builtin/help.c:221
+#, c-format
+msgid ""
+"'%s': path for unsupported man viewer.\n"
+"Please consider using 'man.<tool>.cmd' instead."
+msgstr ""
+"'%s': path ad un visualizzatore man pages non supportato.\n"
+"Usa invece 'man.<tool>.cmd'."
+
+#: builtin/help.c:233
+#, c-format
+msgid ""
+"'%s': cmd for supported man viewer.\n"
+"Please consider using 'man.<tool>.path' instead."
+msgstr ""
+"'%s': comando per visualizzatore man pages supportato.\n"
+"Per favore usa 'man.<tool>.path' invece."
+
+#: builtin/help.c:350
+#, c-format
+msgid "'%s': unknown man viewer."
+msgstr "'%s': visualizzatore man sconosciuto."
+
+#: builtin/help.c:367
+msgid "no man viewer handled the request"
+msgstr "nessun visualizzatore man ha gestito la richiesta"
+
+#: builtin/help.c:375
+msgid "no info viewer handled the request"
+msgstr "nessun visualizzatore info ha gestito la richiesta"
+
+#: builtin/help.c:434 builtin/help.c:445 git.c:336
+#, c-format
+msgid "'%s' is aliased to '%s'"
+msgstr "'%s' è un alias di '%s'"
+
+#: builtin/help.c:448 git.c:365
+#, c-format
+msgid "bad alias.%s string: %s"
+msgstr "stringa alias.%s non valida: %s"
+
+#: builtin/help.c:477 builtin/help.c:507
+#, c-format
+msgid "usage: %s%s"
+msgstr "uso: %s%s"
+
+#: builtin/help.c:491
+msgid "'git help config' for more information"
+msgstr "Vedi 'git help config' per maggiori informazioni"
+
+#: builtin/index-pack.c:185
+#, c-format
+msgid "object type mismatch at %s"
+msgstr "tipo oggetto non corrispondente in %s"
+
+#: builtin/index-pack.c:205
+#, c-format
+msgid "did not receive expected object %s"
+msgstr "non si è ricevuto l'oggetto atteso %s"
+
+#: builtin/index-pack.c:208
+#, c-format
+msgid "object %s: expected type %s, found %s"
+msgstr "oggetto %s: atteso tipo %s, trovato %s"
+
+#: builtin/index-pack.c:258
+#, c-format
+msgid "cannot fill %d byte"
+msgid_plural "cannot fill %d bytes"
+msgstr[0] "impossibile riempire %d byte"
+msgstr[1] "impossibile riempire %d byte"
+
+#: builtin/index-pack.c:268
+msgid "early EOF"
+msgstr "EOF prematuro"
+
+#: builtin/index-pack.c:269
+msgid "read error on input"
+msgstr "errore di lettura in input"
+
+#: builtin/index-pack.c:281
+msgid "used more bytes than were available"
+msgstr "usati più byte di quelli disponibili"
+
+#: builtin/index-pack.c:288 builtin/pack-objects.c:604
+msgid "pack too large for current definition of off_t"
+msgstr "pack troppo largo per la definizione corrente di off_t"
+
+#: builtin/index-pack.c:291 builtin/unpack-objects.c:95
+msgid "pack exceeds maximum allowed size"
+msgstr "il pack supera la dimensione massima consentita"
+
+#: builtin/index-pack.c:312
+#, c-format
+msgid "cannot open packfile '%s'"
+msgstr "impossibile aprire il file pack '%s'"
+
+#: builtin/index-pack.c:326
+msgid "pack signature mismatch"
+msgstr "la firma del pack non coincide"
+
+#: builtin/index-pack.c:328
+#, c-format
+msgid "pack version %<PRIu32> unsupported"
+msgstr "versione pack %<PRIu32> non supportata"
+
+#: builtin/index-pack.c:346
+#, c-format
+msgid "pack has bad object at offset %<PRIuMAX>: %s"
+msgstr "il pack ha un oggetto danneggiato all'offset %<PRIuMAX>: %s"
+
+#: builtin/index-pack.c:466
+#, c-format
+msgid "inflate returned %d"
+msgstr "inflate ha restituito il codice %d"
+
+#: builtin/index-pack.c:515
+msgid "offset value overflow for delta base object"
+msgstr "overflow del valore dell'offset base del delta"
+
+#: builtin/index-pack.c:523
+msgid "delta base offset is out of bound"
+msgstr "l'offset base del delta è fuori dall'intervallo consentito"
+
+#: builtin/index-pack.c:531
+#, c-format
+msgid "unknown object type %d"
+msgstr "tipo oggetto %d sconosciuto"
+
+#: builtin/index-pack.c:562
+msgid "cannot pread pack file"
+msgstr "impossibile eseguire pread sul file pack"
+
+#: builtin/index-pack.c:564
+#, c-format
+msgid "premature end of pack file, %<PRIuMAX> byte missing"
+msgid_plural "premature end of pack file, %<PRIuMAX> bytes missing"
+msgstr[0] "fine del file pack prematura, %<PRIuMAX> byte mancante"
+msgstr[1] "fine del file pack prematura, %<PRIuMAX> byte mancanti"
+
+#: builtin/index-pack.c:590
+msgid "serious inflate inconsistency"
+msgstr "inconsistenza grave di inflate"
+
+#: builtin/index-pack.c:735 builtin/index-pack.c:741 builtin/index-pack.c:764
+#: builtin/index-pack.c:803 builtin/index-pack.c:812
+#, c-format
+msgid "SHA1 COLLISION FOUND WITH %s !"
+msgstr "TROVATA COLLISIONE SHA1 CON %s !"
+
+#: builtin/index-pack.c:738 builtin/pack-objects.c:157
+#: builtin/pack-objects.c:217 builtin/pack-objects.c:311
+#, c-format
+msgid "unable to read %s"
+msgstr "impossibile leggere %s"
+
+#: builtin/index-pack.c:801
+#, c-format
+msgid "cannot read existing object info %s"
+msgstr "impossibile leggere le informazioni sull'oggetto esistente: %s"
+
+#: builtin/index-pack.c:809
+#, c-format
+msgid "cannot read existing object %s"
+msgstr "non è possibile leggere l'oggetto %s esistente"
+
+#: builtin/index-pack.c:823
+#, c-format
+msgid "invalid blob object %s"
+msgstr "oggetto blob %s non valido"
+
+#: builtin/index-pack.c:826 builtin/index-pack.c:845
+msgid "fsck error in packed object"
+msgstr "errore fsck nell'oggetto sottoposto a pack"
+
+#: builtin/index-pack.c:847
+#, c-format
+msgid "Not all child objects of %s are reachable"
+msgstr "Non tutti gli oggetti figlio di %s sono raggiungibili"
+
+#: builtin/index-pack.c:919 builtin/index-pack.c:950
+msgid "failed to apply delta"
+msgstr "applicazione del delta non riuscita"
+
+#: builtin/index-pack.c:1118
+msgid "Receiving objects"
+msgstr "Ricezione degli oggetti"
+
+#: builtin/index-pack.c:1118
+msgid "Indexing objects"
+msgstr "Indicizzazione degli oggetti"
+
+#: builtin/index-pack.c:1152
+msgid "pack is corrupted (SHA1 mismatch)"
+msgstr "il pack è corrotto (SHA1 non corrisponde)"
+
+#: builtin/index-pack.c:1157
+msgid "cannot fstat packfile"
+msgstr "impossibile eseguire fstat sul file pack"
+
+#: builtin/index-pack.c:1160
+msgid "pack has junk at the end"
+msgstr "il pack ha dati inutili alla fine"
+
+#: builtin/index-pack.c:1172
+msgid "confusion beyond insanity in parse_pack_objects()"
+msgstr "confusione oltre ogni follia in parse_pack_objects()"
+
+#: builtin/index-pack.c:1195
+msgid "Resolving deltas"
+msgstr "Risoluzione dei delta"
+
+#: builtin/index-pack.c:1205 builtin/pack-objects.c:2481
+#, c-format
+msgid "unable to create thread: %s"
+msgstr "impossibile creare il thread: %s"
+
+#: builtin/index-pack.c:1246
+msgid "confusion beyond insanity"
+msgstr "confusione oltre ogni follia"
+
+#: builtin/index-pack.c:1252
+#, c-format
+msgid "completed with %d local object"
+msgid_plural "completed with %d local objects"
+msgstr[0] "completato con %d oggetto locale"
+msgstr[1] "completato con %d oggetti locali"
+
+#: builtin/index-pack.c:1264
+#, c-format
+msgid "Unexpected tail checksum for %s (disk corruption?)"
+msgstr "Checksum in coda inatteso per %s (disco corrotto?)"
+
+#: builtin/index-pack.c:1268
+#, c-format
+msgid "pack has %d unresolved delta"
+msgid_plural "pack has %d unresolved deltas"
+msgstr[0] "pack ha %d delta irrisolto"
+msgstr[1] "pack ha %d delta irrisolti"
+
+#: builtin/index-pack.c:1292
+#, c-format
+msgid "unable to deflate appended object (%d)"
+msgstr "impossibile eseguire deflate sull'oggetto aggiunto alla fine (%d)"
+
+#: builtin/index-pack.c:1388
+#, c-format
+msgid "local object %s is corrupt"
+msgstr "l'oggetto locale %s è corrotto"
+
+#: builtin/index-pack.c:1402
+#, c-format
+msgid "packfile name '%s' does not end with '.pack'"
+msgstr "il nome del file pack '%s' non termina con '.pack'"
+
+#: builtin/index-pack.c:1427
+#, c-format
+msgid "cannot write %s file '%s'"
+msgstr "impossibile scrivere il file %s '%s'"
+
+#: builtin/index-pack.c:1435
+#, c-format
+msgid "cannot close written %s file '%s'"
+msgstr "impossibile chiudere il file %s scritto '%s'"
+
+#: builtin/index-pack.c:1459
+msgid "error while closing pack file"
+msgstr "errore nella chiusura del file pack"
+
+#: builtin/index-pack.c:1473
+msgid "cannot store pack file"
+msgstr "impossibile archiviare il file pack"
+
+#: builtin/index-pack.c:1481
+msgid "cannot store index file"
+msgstr "impossibile archiviare index file"
+
+#: builtin/index-pack.c:1525 builtin/pack-objects.c:2716
+#, c-format
+msgid "bad pack.indexversion=%<PRIu32>"
+msgstr "pack.indexversion=%<PRIu32> non valida"
+
+#: builtin/index-pack.c:1593
+#, c-format
+msgid "Cannot open existing pack file '%s'"
+msgstr "Impossibile aprire il file pack '%s' esistente"
+
+#: builtin/index-pack.c:1595
+#, c-format
+msgid "Cannot open existing pack idx file for '%s'"
+msgstr "Impossibile aprire il file pack idx esistente per '%s'"
+
+#: builtin/index-pack.c:1643
+#, c-format
+msgid "non delta: %d object"
+msgid_plural "non delta: %d objects"
+msgstr[0] "non delta: %d oggetto"
+msgstr[1] "non delta: %d oggetti"
+
+#: builtin/index-pack.c:1650
+#, c-format
+msgid "chain length = %d: %lu object"
+msgid_plural "chain length = %d: %lu objects"
+msgstr[0] "lunghezza della catena = %d: %lu oggetto"
+msgstr[1] "lunghezza della catena = %d: %lu oggetti"
+
+#: builtin/index-pack.c:1689
+msgid "Cannot come back to cwd"
+msgstr "impossibile tornare alla directory di lavoro corrente"
+
+#: builtin/index-pack.c:1738 builtin/index-pack.c:1741
+#: builtin/index-pack.c:1757 builtin/index-pack.c:1761
+#, c-format
+msgid "bad %s"
+msgstr "%s errato"
+
+#: builtin/index-pack.c:1777
+msgid "--fix-thin cannot be used without --stdin"
+msgstr "--fix-thin non può essere usato senza --stdin"
+
+#: builtin/index-pack.c:1779
+msgid "--stdin requires a git repository"
+msgstr "--stdin richiede un repository Git"
+
+#: builtin/index-pack.c:1785
+msgid "--verify with no packfile name given"
+msgstr "--verify senza un nome del file pack specificato"
+
+#: builtin/index-pack.c:1833 builtin/unpack-objects.c:581
+msgid "fsck error in pack objects"
+msgstr "errore fsck negli oggetti sottoposti a pack"
+
+#: builtin/init-db.c:61
+#, c-format
+msgid "cannot stat template '%s'"
+msgstr "impossibile eseguire stat sul modello '%s'"
+
+#: builtin/init-db.c:66
+#, c-format
+msgid "cannot opendir '%s'"
+msgstr "impossibile aprire la directory '%s'"
+
+#: builtin/init-db.c:78
+#, c-format
+msgid "cannot readlink '%s'"
+msgstr "impossibile leggere il link '%s'"
+
+#: builtin/init-db.c:80
+#, c-format
+msgid "cannot symlink '%s' '%s'"
+msgstr "impossibile creare il collegamento simbolico da '%s' a '%s'"
+
+#: builtin/init-db.c:86
+#, c-format
+msgid "cannot copy '%s' to '%s'"
+msgstr "impossibile copiare '%s' in '%s'"
+
+#: builtin/init-db.c:90
+#, c-format
+msgid "ignoring template %s"
+msgstr "ignoro il modello %s"
+
+#: builtin/init-db.c:121
+#, c-format
+msgid "templates not found in %s"
+msgstr "modelli non trovati in %s"
+
+#: builtin/init-db.c:136
+#, c-format
+msgid "not copying templates from '%s': %s"
+msgstr "non copio i modelli da '%s': %s"
+
+#: builtin/init-db.c:334
+#, c-format
+msgid "unable to handle file type %d"
+msgstr "impossibile gestire il tipo di file %d"
+
+#: builtin/init-db.c:337
+#, c-format
+msgid "unable to move %s to %s"
+msgstr "impossibile spostare %s in %s"
+
+#: builtin/init-db.c:354 builtin/init-db.c:357
+#, c-format
+msgid "%s already exists"
+msgstr "%s esiste già"
+
+#: builtin/init-db.c:413
+#, c-format
+msgid "Reinitialized existing shared Git repository in %s%s\n"
+msgstr "Reinizializzato repository Git condiviso esistente in %s%s\n"
+
+#: builtin/init-db.c:414
+#, c-format
+msgid "Reinitialized existing Git repository in %s%s\n"
+msgstr "Reinizializzato repository Git esistente in %s%s\n"
+
+#: builtin/init-db.c:418
+#, c-format
+msgid "Initialized empty shared Git repository in %s%s\n"
+msgstr "Inizializzato repository Git condiviso vuoto in %s%s\n"
+
+#: builtin/init-db.c:419
+#, c-format
+msgid "Initialized empty Git repository in %s%s\n"
+msgstr "Inizializzato repository Git vuoto in %s%s\n"
+
+#: builtin/init-db.c:468
+msgid ""
+"git init [-q | --quiet] [--bare] [--template=<template-directory>] [--"
+"shared[=<permissions>]] [<directory>]"
+msgstr ""
+"git init [-q | --quiet] [--bare] [--template=<directory-modello>] [--"
+"shared[=<permessi>]] [<directory>]"
+
+#: builtin/init-db.c:491
+msgid "permissions"
+msgstr "permessi"
+
+#: builtin/init-db.c:492
+msgid "specify that the git repository is to be shared amongst several users"
+msgstr "specifica che il repository Git deve essere condiviso con più utenti"
+
+#: builtin/init-db.c:529 builtin/init-db.c:534
+#, c-format
+msgid "cannot mkdir %s"
+msgstr "impossibile creare la directory %s"
+
+#: builtin/init-db.c:538
+#, c-format
+msgid "cannot chdir to %s"
+msgstr "impossibile modificare la directory corrente in %s"
+
+#: builtin/init-db.c:559
+#, c-format
+msgid ""
+"%s (or --work-tree=<directory>) not allowed without specifying %s (or --git-"
+"dir=<directory>)"
+msgstr ""
+"%s (o --work-tree=<directory>) non consentito senza specificare %s (o --git-"
+"dir=<directory>)"
+
+#: builtin/init-db.c:587
+#, c-format
+msgid "Cannot access work tree '%s'"
+msgstr "Impossibile accedere all'albero di lavoro '%s'"
+
+#: builtin/interpret-trailers.c:16
+msgid ""
+"git interpret-trailers [--in-place] [--trim-empty] [(--trailer "
+"<token>[(=|:)<value>])...] [<file>...]"
+msgstr ""
+"git interpret-trailers [--in-place] [--trim-empty] [(--trailer "
+"<token>[(=|:)<valore>])...] [<file>...]"
+
+#: builtin/interpret-trailers.c:95
+msgid "edit files in place"
+msgstr "modifica i file sul posto"
+
+#: builtin/interpret-trailers.c:96
+msgid "trim empty trailers"
+msgstr "rimuovi spazi dalle stringhe finali vuote"
+
+#: builtin/interpret-trailers.c:99
+msgid "where to place the new trailer"
+msgstr "dove collocare la nuova stringa finale"
+
+#: builtin/interpret-trailers.c:101
+msgid "action if trailer already exists"
+msgstr "azione da eseguire se la stringa finale esiste già"
+
+#: builtin/interpret-trailers.c:103
+msgid "action if trailer is missing"
+msgstr "azione da eseguire se la stringa finale è mancante"
+
+#: builtin/interpret-trailers.c:105
+msgid "output only the trailers"
+msgstr "emetti in output solo le stringhe finali"
+
+#: builtin/interpret-trailers.c:106
+msgid "do not apply config rules"
+msgstr "non applicare le regole di configurazione"
+
+#: builtin/interpret-trailers.c:107
+msgid "join whitespace-continued values"
+msgstr "unisci i valori resi contigui dagli spazi bianchi"
+
+#: builtin/interpret-trailers.c:108
+msgid "set parsing options"
+msgstr "imposta le opzioni di analisi"
+
+#: builtin/interpret-trailers.c:110
+msgid "do not treat --- specially"
+msgstr "non trattare la sequenza --- in modo speciale"
+
+#: builtin/interpret-trailers.c:111
+msgid "trailer"
+msgstr "stringa finale"
+
+#: builtin/interpret-trailers.c:112
+msgid "trailer(s) to add"
+msgstr "stringa/e finale/i da aggiungere"
+
+#: builtin/interpret-trailers.c:123
+msgid "--trailer with --only-input does not make sense"
+msgstr "--trailer con --only-input non ha senso"
+
+#: builtin/interpret-trailers.c:133
+msgid "no input file given for in-place editing"
+msgstr "nessun file di input specificato per la modifica sul posto"
+
+#: builtin/log.c:56
+msgid "git log [<options>] [<revision-range>] [[--] <path>...]"
+msgstr "git log [<opzioni>] [<intervallo-revisioni>] [[--] <percorso>...]"
+
+#: builtin/log.c:57
+msgid "git show [<options>] <object>..."
+msgstr "git show [<opzioni>] <oggetto>..."
+
+#: builtin/log.c:110
+#, c-format
+msgid "invalid --decorate option: %s"
+msgstr "opzione --decorate non valida: %s"
+
+#: builtin/log.c:174
+msgid "show source"
+msgstr "visualizza sorgente"
+
+#: builtin/log.c:175
+msgid "Use mail map file"
+msgstr "Usa il file mappatura e-mail"
+
+#: builtin/log.c:177
+msgid "only decorate refs that match <pattern>"
+msgstr "decora solo i riferimenti corrispondenti a <pattern>"
+
+#: builtin/log.c:179
+msgid "do not decorate refs that match <pattern>"
+msgstr "non decorare i riferimenti corrispondenti a <pattern>"
+
+#: builtin/log.c:180
+msgid "decorate options"
+msgstr "opzioni decorazione"
+
+#: builtin/log.c:183
+msgid "Process line range n,m in file, counting from 1"
+msgstr "Elabora l'intervallo righe n,m nel file, contandole da 1"
+
+#: builtin/log.c:281
+#, c-format
+msgid "Final output: %d %s\n"
+msgstr "Output finale: %d %s\n"
+
+#: builtin/log.c:535
+#, c-format
+msgid "git show %s: bad file"
+msgstr "git show %s: file non valido"
+
+#: builtin/log.c:550 builtin/log.c:645
+#, c-format
+msgid "could not read object %s"
+msgstr "impossibile leggere l'oggetto %s"
+
+#: builtin/log.c:670
+#, c-format
+msgid "unknown type: %d"
+msgstr "tipo sconosciuto: %d"
+
+#: builtin/log.c:814
+#, c-format
+msgid "%s: invalid cover from description mode"
+msgstr "%s: modo lettera da descrizione non valido"
+
+#: builtin/log.c:821
+msgid "format.headers without value"
+msgstr "format.headers non ha alcun valore"
+
+#: builtin/log.c:936
+msgid "name of output directory is too long"
+msgstr "il nome della directory di output è troppo lungo"
+
+#: builtin/log.c:952
+#, c-format
+msgid "cannot open patch file %s"
+msgstr "impossibile aprire il file patch %s"
+
+#: builtin/log.c:969
+msgid "need exactly one range"
+msgstr "è necessario specificare esattamente un intervallo"
+
+#: builtin/log.c:979
+msgid "not a range"
+msgstr "il valore non è un intervallo"
+
+#: builtin/log.c:1143
+msgid "cover letter needs email format"
+msgstr "la lettera di accompagnamento dev'essere in formato e-mail"
+
+#: builtin/log.c:1149
+msgid "failed to create cover-letter file"
+msgstr "creazione del file lettera di accompagnamento non riuscita"
+
+#: builtin/log.c:1228
+#, c-format
+msgid "insane in-reply-to: %s"
+msgstr "valore in-reply-to folle: %s"
+
+#: builtin/log.c:1255
+msgid "git format-patch [<options>] [<since> | <revision-range>]"
+msgstr "git format-patch [<opzioni>] [<da> | <intervallo revisioni>]"
+
+#: builtin/log.c:1313
+msgid "two output directories?"
+msgstr "due directory di output?"
+
+#: builtin/log.c:1424 builtin/log.c:2197 builtin/log.c:2199 builtin/log.c:2211
+#, c-format
+msgid "unknown commit %s"
+msgstr "commit %s sconosciuto"
+
+#: builtin/log.c:1434 builtin/replace.c:58 builtin/replace.c:207
+#: builtin/replace.c:210
+#, c-format
+msgid "failed to resolve '%s' as a valid ref"
+msgstr "impossibile risolvere '%s' come riferimento valido"
+
+#: builtin/log.c:1439
+msgid "could not find exact merge base"
+msgstr "impossibile trovare esattamente la base del merge"
+
+#: builtin/log.c:1443
+msgid ""
+"failed to get upstream, if you want to record base commit automatically,\n"
+"please use git branch --set-upstream-to to track a remote branch.\n"
+"Or you could specify base commit by --base=<base-commit-id> manually"
+msgstr ""
+"impossibile recuperare l'upstream, se vuoi registrare automaticamente\n"
+"il commit di base usa git branch --set-upstream-to per tracciare un branch\n"
+"remoto.\n"
+"In alternativa puoi specificare manualmente il commit di base con\n"
+"--base=<ID commit di base>"
+
+#: builtin/log.c:1463
+msgid "failed to find exact merge base"
+msgstr "impossibile trovare esattamente la base del merge"
+
+#: builtin/log.c:1474
+msgid "base commit should be the ancestor of revision list"
+msgstr "il commit di base dovrebbe essere l'antenato dell'elenco revisioni"
+
+#: builtin/log.c:1478
+msgid "base commit shouldn't be in revision list"
+msgstr "il commit di base non dovrebbe essere nell'elenco revisioni"
+
+#: builtin/log.c:1531
+msgid "cannot get patch id"
+msgstr "impossibile ottenere l'ID della patch"
+
+#: builtin/log.c:1583
+msgid "failed to infer range-diff ranges"
+msgstr "inferenza degli intervalli range-diff non riuscita"
+
+#: builtin/log.c:1629
+msgid "use [PATCH n/m] even with a single patch"
+msgstr "usa [PATCH n/m] anche con una singola patch"
+
+#: builtin/log.c:1632
+msgid "use [PATCH] even with multiple patches"
+msgstr "usa [PATCH] anche con più patch"
+
+#: builtin/log.c:1636
+msgid "print patches to standard out"
+msgstr "stampa le patch sullo standard output"
+
+#: builtin/log.c:1638
+msgid "generate a cover letter"
+msgstr "genera una lettera di accompagnamento"
+
+#: builtin/log.c:1640
+msgid "use simple number sequence for output file names"
+msgstr "usa una sequenza numerica semplice per i nomi file di output"
+
+#: builtin/log.c:1641
+msgid "sfx"
+msgstr "suff"
+
+#: builtin/log.c:1642
+msgid "use <sfx> instead of '.patch'"
+msgstr "usa <suff> anziché '.patch'"
+
+#: builtin/log.c:1644
+msgid "start numbering patches at <n> instead of 1"
+msgstr "inizia a numerare le patch da <n> anziché da 1"
+
+#: builtin/log.c:1646
+msgid "mark the series as Nth re-roll"
+msgstr "contrassegna la serie come l'n-esima versione revisionata"
+
+#: builtin/log.c:1648
+msgid "Use [RFC PATCH] instead of [PATCH]"
+msgstr "Usa [RFC PATCH] anziché [PATCH]"
+
+#: builtin/log.c:1651
+msgid "cover-from-description-mode"
+msgstr "modo-lettera-da-descrizione"
+
+#: builtin/log.c:1652
+msgid "generate parts of a cover letter based on a branch's description"
+msgstr ""
+"genera parti di una lettera d'accompagnamento basandosi sulla descrizione di"
+" un branch"
+
+#: builtin/log.c:1654
+msgid "Use [<prefix>] instead of [PATCH]"
+msgstr "Usa [<prefisso>] anziché [PATCH]"
+
+#: builtin/log.c:1657
+msgid "store resulting files in <dir>"
+msgstr "salva i file risultanti in <dir>"
+
+#: builtin/log.c:1660
+msgid "don't strip/add [PATCH]"
+msgstr "non eliminare/aggiungere [PATCH]"
+
+#: builtin/log.c:1663
+msgid "don't output binary diffs"
+msgstr "non mandare in output diff binari"
+
+#: builtin/log.c:1665
+msgid "output all-zero hash in From header"
+msgstr "manda in output un hash costituito da soli zeri nell'intestazione From"
+
+#: builtin/log.c:1667
+msgid "don't include a patch matching a commit upstream"
+msgstr "non includere una patch corrispondente a un commit upstream"
+
+#: builtin/log.c:1669
+msgid "show patch format instead of default (patch + stat)"
+msgstr ""
+"visualizza il formato della patch anziché l'impostazione predefinita (patch "
+"+ stat)"
+
+#: builtin/log.c:1671
+msgid "Messaging"
+msgstr "Messaggistica"
+
+#: builtin/log.c:1672
+msgid "header"
+msgstr "intestazione"
+
+#: builtin/log.c:1673
+msgid "add email header"
+msgstr "aggiungi intestazione e-mail"
+
+#: builtin/log.c:1674 builtin/log.c:1676
+msgid "email"
+msgstr "e-mail"
+
+#: builtin/log.c:1674
+msgid "add To: header"
+msgstr "aggiungi intestazione A:"
+
+#: builtin/log.c:1676
+msgid "add Cc: header"
+msgstr "aggiungi intestazione Cc:"
+
+#: builtin/log.c:1678
+msgid "ident"
+msgstr "identità"
+
+#: builtin/log.c:1679
+msgid "set From address to <ident> (or committer ident if absent)"
+msgstr ""
+"imposta l'indirizzo Da a <identità> (o all'identità di chi ha creato il "
+"commit se assente)"
+
+#: builtin/log.c:1681
+msgid "message-id"
+msgstr "ID messaggio"
+
+#: builtin/log.c:1682
+msgid "make first mail a reply to <message-id>"
+msgstr "rendi la prima e-mail una risposta a <ID messaggio>"
+
+#: builtin/log.c:1683 builtin/log.c:1686
+msgid "boundary"
+msgstr "delimitatore"
+
+#: builtin/log.c:1684
+msgid "attach the patch"
+msgstr "allega la patch"
+
+#: builtin/log.c:1687
+msgid "inline the patch"
+msgstr "includi la patch nel messaggio"
+
+#: builtin/log.c:1691
+msgid "enable message threading, styles: shallow, deep"
+msgstr ""
+"abilita il raggruppamento messaggi per conversazione, stili: superficiale, "
+"profondo"
+
+#: builtin/log.c:1693
+msgid "signature"
+msgstr "firma"
+
+#: builtin/log.c:1694
+msgid "add a signature"
+msgstr "aggiungi una firma"
+
+#: builtin/log.c:1695
+msgid "base-commit"
+msgstr "commit di base"
+
+#: builtin/log.c:1696
+msgid "add prerequisite tree info to the patch series"
+msgstr ""
+"aggiungi le informazioni prerequisito per l'albero alla serie delle patch"
+
+#: builtin/log.c:1698
+msgid "add a signature from a file"
+msgstr "aggiungi una firma da file"
+
+#: builtin/log.c:1699
+msgid "don't print the patch filenames"
+msgstr "non stampare i nomi file delle patch"
+
+#: builtin/log.c:1701
+msgid "show progress while generating patches"
+msgstr "visualizza l'avanzamento dell'operazione di generazione patch"
+
+#: builtin/log.c:1703
+msgid "show changes against <rev> in cover letter or single patch"
+msgstr ""
+"visualizza le modifiche rispetto a <revisione> nella lettera di "
+"accompagnamento o in una patch singola"
+
+#: builtin/log.c:1706
+msgid "show changes against <refspec> in cover letter or single patch"
+msgstr ""
+"visualizza le modifiche rispetto a <specificatore revisione> nella lettera "
+"di accompagnamento o in una patch singola"
+
+#: builtin/log.c:1708
+msgid "percentage by which creation is weighted"
+msgstr "percentuale in base a cui viene pesata la creazione"
+
+#: builtin/log.c:1792
+#, c-format
+msgid "invalid ident line: %s"
+msgstr "riga ident non valida: %s"
+
+#: builtin/log.c:1807
+msgid "-n and -k are mutually exclusive"
+msgstr "le opzioni -n e -k sono mutuamente esclusive"
+
+#: builtin/log.c:1809
+msgid "--subject-prefix/--rfc and -k are mutually exclusive"
+msgstr "le opzioni --subject-prefix/--rfc e -k sono mutuamente esclusive"
+
+#: builtin/log.c:1817
+msgid "--name-only does not make sense"
+msgstr "--name-only non ha senso"
+
+#: builtin/log.c:1819
+msgid "--name-status does not make sense"
+msgstr "--name-status non ha senso"
+
+#: builtin/log.c:1821
+msgid "--check does not make sense"
+msgstr "--check non ha senso"
+
+#: builtin/log.c:1854
+msgid "standard output, or directory, which one?"
+msgstr "standard output, o directory, quale dei due?"
+
+#: builtin/log.c:1958
+msgid "--interdiff requires --cover-letter or single patch"
+msgstr "--interdiff richiede --cover-letter o una singola patch"
+
+#: builtin/log.c:1962
+msgid "Interdiff:"
+msgstr "Interdiff:"
+
+#: builtin/log.c:1963
+#, c-format
+msgid "Interdiff against v%d:"
+msgstr "Interdiff rispetto alla versione %d:"
+
+#: builtin/log.c:1969
+msgid "--creation-factor requires --range-diff"
+msgstr "--creation-factor richiede --range-diff"
+
+#: builtin/log.c:1973
+msgid "--range-diff requires --cover-letter or single patch"
+msgstr "--range-diff richiede --cover-letter o una singola patch"
+
+#: builtin/log.c:1981
+msgid "Range-diff:"
+msgstr "Range-diff:"
+
+#: builtin/log.c:1982
+#, c-format
+msgid "Range-diff against v%d:"
+msgstr "Range-diff rispetto alla versione %d:"
+
+#: builtin/log.c:1993
+#, c-format
+msgid "unable to read signature file '%s'"
+msgstr "impossibile leggere il file firma '%s'"
+
+#: builtin/log.c:2029
+msgid "Generating patches"
+msgstr "Generazione delle patch in corso"
+
+#: builtin/log.c:2073
+msgid "failed to create output files"
+msgstr "creazione dei file di output non riuscita"
+
+#: builtin/log.c:2132
+msgid "git cherry [-v] [<upstream> [<head> [<limit>]]]"
+msgstr "git cherry [-v] [<upstream> [<head> [<limite>]]]"
+
+#: builtin/log.c:2186
+#, c-format
+msgid ""
+"Could not find a tracked remote branch, please specify <upstream> manually.\n"
+msgstr ""
+"Impossibile trovare un branch remoto tracciato, specifica <upstream> "
+"manualmente.\n"
+
+#: builtin/ls-files.c:470
+msgid "git ls-files [<options>] [<file>...]"
+msgstr "git ls-files [<opzioni>] [<file>...]"
+
+#: builtin/ls-files.c:526
+msgid "identify the file status with tags"
+msgstr "identifica lo stato del file con i tag"
+
+#: builtin/ls-files.c:528
+msgid "use lowercase letters for 'assume unchanged' files"
+msgstr "usa lettere minuscole per i file che si 'assumono non modificati'"
+
+#: builtin/ls-files.c:530
+msgid "use lowercase letters for 'fsmonitor clean' files"
+msgstr "usa lettere minuscole per i file 'fsmonitor clean'"
+
+#: builtin/ls-files.c:532
+msgid "show cached files in the output (default)"
+msgstr "visualizza file in cache nell'output (impostazione predefinita)"
+
+#: builtin/ls-files.c:534
+msgid "show deleted files in the output"
+msgstr "visualizza file eliminati nell'output"
+
+#: builtin/ls-files.c:536
+msgid "show modified files in the output"
+msgstr "visualizza file modificati nell'output"
+
+#: builtin/ls-files.c:538
+msgid "show other files in the output"
+msgstr "visualizza altri file nell'output"
+
+#: builtin/ls-files.c:540
+msgid "show ignored files in the output"
+msgstr "visualizza file ignorati nell'output"
+
+#: builtin/ls-files.c:543
+msgid "show staged contents' object name in the output"
+msgstr ""
+"visualizza il nome dell'oggetto \"contenuti nell'area di staging\" "
+"nell'output"
+
+#: builtin/ls-files.c:545
+msgid "show files on the filesystem that need to be removed"
+msgstr "visualizza i file nel filesystem che devono essere rimossi"
+
+#: builtin/ls-files.c:547
+msgid "show 'other' directories' names only"
+msgstr "visualizza solo i nomi delle directory 'altro'"
+
+#: builtin/ls-files.c:549
+msgid "show line endings of files"
+msgstr "visualizza i fine riga dei file"
+
+#: builtin/ls-files.c:551
+msgid "don't show empty directories"
+msgstr "non visualizzare le directory vuote"
+
+#: builtin/ls-files.c:554
+msgid "show unmerged files in the output"
+msgstr "visualizza file non sottoposti a merge nell'output"
+
+#: builtin/ls-files.c:556
+msgid "show resolve-undo information"
+msgstr "visualizza informazioni resolve-undo"
+
+#: builtin/ls-files.c:558
+msgid "skip files matching pattern"
+msgstr "salta i file corrispondenti a \"espressione regolare\""
+
+#: builtin/ls-files.c:561
+msgid "exclude patterns are read from <file>"
+msgstr "le espressioni regolari di esclusione sono lette da <file>"
+
+#: builtin/ls-files.c:564
+msgid "read additional per-directory exclude patterns in <file>"
+msgstr ""
+"leggi espressioni regolari di esclusione aggiuntive specifiche per directory "
+"da <file>"
+
+#: builtin/ls-files.c:566
+msgid "add the standard git exclusions"
+msgstr "aggiungi le esclusioni standard di Git"
+
+#: builtin/ls-files.c:570
+msgid "make the output relative to the project top directory"
+msgstr "rendi l'output relativo alla directory radice del progetto"
+
+#: builtin/ls-files.c:573
+msgid "recurse through submodules"
+msgstr "esegui ricorsivamente sui sottomoduli"
+
+#: builtin/ls-files.c:575
+msgid "if any <file> is not in the index, treat this as an error"
+msgstr "se dei <file> non sono nell'indice, consideralo un errore"
+
+#: builtin/ls-files.c:576
+msgid "tree-ish"
+msgstr "espressione albero"
+
+#: builtin/ls-files.c:577
+msgid "pretend that paths removed since <tree-ish> are still present"
+msgstr ""
+"fingi che i percorsi rimossi da <espressione albero> in poi siano ancora "
+"presenti"
+
+#: builtin/ls-files.c:579
+msgid "show debugging data"
+msgstr "visualizza informazioni di debug"
+
+#: builtin/ls-remote.c:9
+msgid ""
+"git ls-remote [--heads] [--tags] [--refs] [--upload-pack=<exec>]\n"
+"                     [-q | --quiet] [--exit-code] [--get-url]\n"
+"                     [--symref] [<repository> [<refs>...]]"
+msgstr ""
+"git ls-remote [--heads] [--tags] [--refs] [--upload-pack=<eseguibile>]\n"
+"                     [-q | --quiet] [--exit-code] [--get-url]\n"
+"                     [--symref] [<repository> [<riferimenti>...]]"
+
+#: builtin/ls-remote.c:59
+msgid "do not print remote URL"
+msgstr "non stampare l'URL del remoto"
+
+#: builtin/ls-remote.c:60 builtin/ls-remote.c:62 builtin/rebase.c:1518
+msgid "exec"
+msgstr "eseguibile"
+
+#: builtin/ls-remote.c:61 builtin/ls-remote.c:63
+msgid "path of git-upload-pack on the remote host"
+msgstr "percorso di git-upload-pack sull'host remoto"
+
+#: builtin/ls-remote.c:65
+msgid "limit to tags"
+msgstr "limitati ai tag"
+
+#: builtin/ls-remote.c:66
+msgid "limit to heads"
+msgstr "limitati alle head"
+
+#: builtin/ls-remote.c:67
+msgid "do not show peeled tags"
+msgstr "non visualizzare i tag rimossi"
+
+#: builtin/ls-remote.c:69
+msgid "take url.<base>.insteadOf into account"
+msgstr "tieni in considerazione url.<base>.insteadOf"
+
+#: builtin/ls-remote.c:72
+msgid "exit with exit code 2 if no matching refs are found"
+msgstr ""
+"esci con codice d'uscita 2 se non sono stati trovati riferimenti "
+"corrispondenti"
+
+#: builtin/ls-remote.c:75
+msgid "show underlying ref in addition to the object pointed by it"
+msgstr "visualizza riferimento sottostante oltre all'oggetto a cui punta"
+
+#: builtin/ls-tree.c:30
+msgid "git ls-tree [<options>] <tree-ish> [<path>...]"
+msgstr "git ls-tree [<opzioni>] <espressione albero> [<percorso>...]"
+
+#: builtin/ls-tree.c:128
+msgid "only show trees"
+msgstr "visualizza solo alberi"
+
+#: builtin/ls-tree.c:130
+msgid "recurse into subtrees"
+msgstr "esegui ricorsivamente nei sottoalberi"
+
+#: builtin/ls-tree.c:132
+msgid "show trees when recursing"
+msgstr "visualizza gli alberi durante la ricorsione"
+
+#: builtin/ls-tree.c:135
+msgid "terminate entries with NUL byte"
+msgstr "termina le voci con un byte NUL"
+
+#: builtin/ls-tree.c:136
+msgid "include object size"
+msgstr "includi dimensioni oggetto"
+
+#: builtin/ls-tree.c:138 builtin/ls-tree.c:140
+msgid "list only filenames"
+msgstr "elenca solo i nomi file"
+
+#: builtin/ls-tree.c:143
+msgid "use full path names"
+msgstr "usa nomi percorso completi"
+
+#: builtin/ls-tree.c:145
+msgid "list entire tree; not just current directory (implies --full-name)"
+msgstr ""
+"elenca l'intero albero; non solo la directory corrente (implica --full-name)"
+
+#: builtin/mailsplit.c:241
+#, c-format
+msgid "empty mbox: '%s'"
+msgstr "mbox vuota: '%s'"
+
+#: builtin/merge.c:55
+msgid "git merge [<options>] [<commit>...]"
+msgstr "git merge [<opzioni>] [<commit>...]"
+
+#: builtin/merge.c:56
+msgid "git merge --abort"
+msgstr "git merge --abort"
+
+#: builtin/merge.c:57
+msgid "git merge --continue"
+msgstr "git merge --continue"
+
+#: builtin/merge.c:118
+msgid "switch `m' requires a value"
+msgstr "lo switch 'm' richiede un valore"
+
+#: builtin/merge.c:141
+#, c-format
+msgid "option `%s' requires a value"
+msgstr "l'opzione `%s' richiede un valore"
+
+#: builtin/merge.c:187
+#, c-format
+msgid "Could not find merge strategy '%s'.\n"
+msgstr "Non è stato possibile trovare la strategia di merge '%s'.\n"
+
+#: builtin/merge.c:188
+#, c-format
+msgid "Available strategies are:"
+msgstr "Le strategie disponibili sono:"
+
+#: builtin/merge.c:193
+#, c-format
+msgid "Available custom strategies are:"
+msgstr "Le strategie personalizzate disponibili sono:"
+
+#: builtin/merge.c:244 builtin/pull.c:152
+msgid "do not show a diffstat at the end of the merge"
+msgstr "non visualizzare un diffstat al termine del merge"
+
+#: builtin/merge.c:247 builtin/pull.c:155
+msgid "show a diffstat at the end of the merge"
+msgstr "visualizza un diffstat al termine del merge"
+
+#: builtin/merge.c:248 builtin/pull.c:158
+msgid "(synonym to --stat)"
+msgstr "(sinonimo di --stat)"
+
+#: builtin/merge.c:250 builtin/pull.c:161
+msgid "add (at most <n>) entries from shortlog to merge commit message"
+msgstr ""
+"aggiungi (al più <n>) voci dal registro breve al messaggio di commit del "
+"merge"
+
+#: builtin/merge.c:253 builtin/pull.c:167
+msgid "create a single commit instead of doing a merge"
+msgstr "crea un singolo commit anziché eseguire un merge"
+
+#: builtin/merge.c:255 builtin/pull.c:170
+msgid "perform a commit if the merge succeeds (default)"
+msgstr "esegui un commit se il merge ha successo (impostazione predefinita)"
+
+#: builtin/merge.c:257 builtin/pull.c:173
+msgid "edit message before committing"
+msgstr "modifica il messaggio prima di eseguire il commit"
+
+#: builtin/merge.c:259
+msgid "allow fast-forward (default)"
+msgstr "consenti fast forward (impostazione predefinita)"
+
+#: builtin/merge.c:261 builtin/pull.c:180
+msgid "abort if fast-forward is not possible"
+msgstr "interrompi se il fast forward non è possibile"
+
+#: builtin/merge.c:265 builtin/pull.c:183
+msgid "verify that the named commit has a valid GPG signature"
+msgstr "verifica che il commit specificato abbia una firma GPG valida"
+
+#: builtin/merge.c:266 builtin/notes.c:787 builtin/pull.c:187
+#: builtin/rebase.c:512 builtin/rebase.c:1531 builtin/revert.c:114
+msgid "strategy"
+msgstr "strategia"
+
+#: builtin/merge.c:267 builtin/pull.c:188
+msgid "merge strategy to use"
+msgstr "strategia di merge da usare"
+
+#: builtin/merge.c:268 builtin/pull.c:191
+msgid "option=value"
+msgstr "opzione=valore"
+
+#: builtin/merge.c:269 builtin/pull.c:192
+msgid "option for selected merge strategy"
+msgstr "opzione per la strategia di merge selezionata"
+
+#: builtin/merge.c:271
+msgid "merge commit message (for a non-fast-forward merge)"
+msgstr "messaggio di commit del merge (per un merge non fast forward)"
+
+#: builtin/merge.c:278
+msgid "abort the current in-progress merge"
+msgstr "interrompi il merge attualmente in corso"
+
+#: builtin/merge.c:280
+msgid "--abort but leave index and working tree alone"
+msgstr "esegui --abort ma mantieni immutati l'indice e l'albero di lavoro"
+
+#: builtin/merge.c:282
+msgid "continue the current in-progress merge"
+msgstr "continua il merge attualmente in corso"
+
+#: builtin/merge.c:284 builtin/pull.c:199
+msgid "allow merging unrelated histories"
+msgstr "consenti di unire cronologie non correlate"
+
+#: builtin/merge.c:290
+msgid "bypass pre-merge-commit and commit-msg hooks"
+msgstr "ignora gli hook pre-merge-commit e commit-msg"
+
+#: builtin/merge.c:307
+msgid "could not run stash."
+msgstr "non è stato possibile eseguire stash."
+
+#: builtin/merge.c:312
+msgid "stash failed"
+msgstr "esecuzione di stash non riuscita"
+
+#: builtin/merge.c:317
+#, c-format
+msgid "not a valid object: %s"
+msgstr "non è un oggetto valido: %s"
+
+#: builtin/merge.c:339 builtin/merge.c:356
+msgid "read-tree failed"
+msgstr "read-tree non riuscito"
+
+#: builtin/merge.c:386
+msgid " (nothing to squash)"
+msgstr " (nulla di cui eseguire lo squash)"
+
+#: builtin/merge.c:397
+#, c-format
+msgid "Squash commit -- not updating HEAD\n"
+msgstr "Commit di squash -- non aggiorno HEAD\n"
+
+#: builtin/merge.c:447
+#, c-format
+msgid "No merge message -- not updating HEAD\n"
+msgstr "Nessun messaggio di merge -- HEAD non viene aggiornato\n"
+
+#: builtin/merge.c:498
+#, c-format
+msgid "'%s' does not point to a commit"
+msgstr "'%s' non punta ad un commit"
+
+#: builtin/merge.c:585
+#, c-format
+msgid "Bad branch.%s.mergeoptions string: %s"
+msgstr "Stringa branch.%s.mergeoptions errata: %s"
+
+#: builtin/merge.c:705
+msgid "Not handling anything other than two heads merge."
+msgstr "Non gestisco nulla che non sia il merge di due head."
+
+#: builtin/merge.c:719
+#, c-format
+msgid "Unknown option for merge-recursive: -X%s"
+msgstr "Opzione sconosciuta per merge-recursive: -X%s"
+
+#: builtin/merge.c:734
+#, c-format
+msgid "unable to write %s"
+msgstr "impossibile scrivere %s"
+
+#: builtin/merge.c:786
+#, c-format
+msgid "Could not read from '%s'"
+msgstr "Non è stato possibile leggere da '%s'"
+
+#: builtin/merge.c:795
+#, c-format
+msgid "Not committing merge; use 'git commit' to complete the merge.\n"
+msgstr ""
+"Non eseguo il commit del merge; usa 'git commit' per completare il merge.\n"
+
+#: builtin/merge.c:801
+msgid ""
+"Please enter a commit message to explain why this merge is necessary,\n"
+"especially if it merges an updated upstream into a topic branch.\n"
+"\n"
+msgstr ""
+"Inserisci un messaggio di commit per spiegare perché è necessario\n"
+"questo merge, in particolare se si esegue il merge di un upstream\n"
+"aggiornato in un topic branch.\n"
+"\n"
+
+#: builtin/merge.c:806
+msgid "An empty message aborts the commit.\n"
+msgstr "Un messaggio vuoto interromperà il commit.\n"
+
+#: builtin/merge.c:809
+#, c-format
+msgid ""
+"Lines starting with '%c' will be ignored, and an empty message aborts\n"
+"the commit.\n"
+msgstr ""
+"Le righe che iniziano con '%c' saranno ignorate e un messaggio vuoto\n"
+"interromperà il commit.\n"
+
+#: builtin/merge.c:862
+msgid "Empty commit message."
+msgstr "Messaggio di commit vuoto."
+
+#: builtin/merge.c:877
+#, c-format
+msgid "Wonderful.\n"
+msgstr "Splendido.\n"
+
+#: builtin/merge.c:938
+#, c-format
+msgid "Automatic merge failed; fix conflicts and then commit the result.\n"
+msgstr ""
+"Merge automatico fallito; risolvi i conflitti ed esegui il commit\n"
+"del risultato.\n"
+
+#: builtin/merge.c:977
+msgid "No current branch."
+msgstr "Nessun branch corrente."
+
+#: builtin/merge.c:979
+msgid "No remote for the current branch."
+msgstr "Nessun remote per il branch corrente."
+
+#: builtin/merge.c:981
+msgid "No default upstream defined for the current branch."
+msgstr "Nessun upstream di default definito per il branch corrente."
+
+#: builtin/merge.c:986
+#, c-format
+msgid "No remote-tracking branch for %s from %s"
+msgstr "Nessun branch che tracci un remoto per %s da %s"
+
+#: builtin/merge.c:1043
+#, c-format
+msgid "Bad value '%s' in environment '%s'"
+msgstr "Valore errato '%s' nell'ambiente '%s'"
+
+#: builtin/merge.c:1146
+#, c-format
+msgid "not something we can merge in %s: %s"
+msgstr "non è qualcosa di cui possiamo eseguire il merge in %s: %s"
+
+#: builtin/merge.c:1180
+msgid "not something we can merge"
+msgstr "non è qualcosa di cui possiamo eseguire il merge"
+
+#: builtin/merge.c:1283
+msgid "--abort expects no arguments"
+msgstr "--abort non richiede argomenti"
+
+#: builtin/merge.c:1287
+msgid "There is no merge to abort (MERGE_HEAD missing)."
+msgstr "Non c'è nessun merge da interrompere (MERGE_HEAD mancante)."
+
+#: builtin/merge.c:1296
+msgid "--quit expects no arguments"
+msgstr "--quit non richiede argomenti"
+
+#: builtin/merge.c:1309
+msgid "--continue expects no arguments"
+msgstr "--continue non richiede argomenti"
+
+#: builtin/merge.c:1313
+msgid "There is no merge in progress (MERGE_HEAD missing)."
+msgstr "Non c'è nessun merge in corso (MERGE_HEAD mancante)."
+
+#: builtin/merge.c:1329
+msgid ""
+"You have not concluded your merge (MERGE_HEAD exists).\n"
+"Please, commit your changes before you merge."
+msgstr ""
+"Non hai concluso il merge (MERGE_HEAD esiste).\n"
+"Esegui il commit delle modifiche prima di eseguire il merge."
+
+#: builtin/merge.c:1336
+msgid ""
+"You have not concluded your cherry-pick (CHERRY_PICK_HEAD exists).\n"
+"Please, commit your changes before you merge."
+msgstr ""
+"Non hai concluso il cherry-pick (CHERRY_PICK_HEAD esiste).\n"
+"Esegui il commit delle modifiche prima di eseguire il merge."
+
+#: builtin/merge.c:1339
+msgid "You have not concluded your cherry-pick (CHERRY_PICK_HEAD exists)."
+msgstr "Il cherry-pick non è stato concluso (CHERRY_PICK_HEAD esiste)."
+
+#: builtin/merge.c:1353
+msgid "You cannot combine --squash with --no-ff."
+msgstr "Non è possibile combinare --squash con --no-ff."
+
+#: builtin/merge.c:1355
+msgid "You cannot combine --squash with --commit."
+msgstr "Non è possibile combinare --squash con --commit."
+
+#: builtin/merge.c:1371
+msgid "No commit specified and merge.defaultToUpstream not set."
+msgstr "Nessun commit specificato e merge.defaultToUpstream non impostato."
+
+#: builtin/merge.c:1388
+msgid "Squash commit into empty head not supported yet"
+msgstr "Lo squash di un commit in un'head vuota non è ancora supportato"
+
+#: builtin/merge.c:1390
+msgid "Non-fast-forward commit does not make sense into an empty head"
+msgstr "Un commit non fast forward non ha senso in un'head vuota"
+
+#: builtin/merge.c:1395
+#, c-format
+msgid "%s - not something we can merge"
+msgstr "%s - non è qualcosa per cui possiamo eseguire il merge"
+
+#: builtin/merge.c:1397
+msgid "Can merge only exactly one commit into empty head"
+msgstr "Si può eseguire solo il merge di uno e un solo commit in un'head vuota"
+
+#: builtin/merge.c:1476
+msgid "refusing to merge unrelated histories"
+msgstr "mi rifiuto di eseguire il merge di cronologie non correlate"
+
+#: builtin/merge.c:1485
+msgid "Already up to date."
+msgstr "Già aggiornato."
+
+#: builtin/merge.c:1495
+#, c-format
+msgid "Updating %s..%s\n"
+msgstr "Aggiornamento di %s..%s\n"
+
+#: builtin/merge.c:1537
+#, c-format
+msgid "Trying really trivial in-index merge...\n"
+msgstr "Provo con un merge veramente banale dentro l'indice...\n"
+
+#: builtin/merge.c:1544
+#, c-format
+msgid "Nope.\n"
+msgstr "No.\n"
+
+#: builtin/merge.c:1569
+msgid "Already up to date. Yeeah!"
+msgstr "Già aggiornato. Oh sì!"
+
+#: builtin/merge.c:1575
+msgid "Not possible to fast-forward, aborting."
+msgstr "Fast forward non possibile, interrompo l'operazione."
+
+#: builtin/merge.c:1598 builtin/merge.c:1663
+#, c-format
+msgid "Rewinding the tree to pristine...\n"
+msgstr "Ripristino l'albero in uno stato pulito...\n"
+
+#: builtin/merge.c:1602
+#, c-format
+msgid "Trying merge strategy %s...\n"
+msgstr "Tentativo con la strategia di merge %s...\n"
+
+#: builtin/merge.c:1654
+#, c-format
+msgid "No merge strategy handled the merge.\n"
+msgstr "Nessuna strategia di merge ha gestito il merge.\n"
+
+#: builtin/merge.c:1656
+#, c-format
+msgid "Merge with strategy %s failed.\n"
+msgstr "Merge con la strategia %s fallito.\n"
+
+#: builtin/merge.c:1665
+#, c-format
+msgid "Using the %s to prepare resolving by hand.\n"
+msgstr "Uso %s per preparare una risoluzione manuale.\n"
+
+#: builtin/merge.c:1677
+#, c-format
+msgid "Automatic merge went well; stopped before committing as requested\n"
+msgstr ""
+"Il merge automatico è andato a buon fine; fermato prima del commit come "
+"richiesto\n"
+
+#: builtin/merge-base.c:32
+msgid "git merge-base [-a | --all] <commit> <commit>..."
+msgstr "git merge-base [-a | --all] <commit> <commit>..."
+
+#: builtin/merge-base.c:33
+msgid "git merge-base [-a | --all] --octopus <commit>..."
+msgstr "git merge-base [-a | --all] --octopus <commit>..."
+
+#: builtin/merge-base.c:34
+msgid "git merge-base --independent <commit>..."
+msgstr "git merge-base --independent <commit>..."
+
+#: builtin/merge-base.c:35
+msgid "git merge-base --is-ancestor <commit> <commit>"
+msgstr "git merge-base --is-ancestor <commit> <commit>"
+
+#: builtin/merge-base.c:36
+msgid "git merge-base --fork-point <ref> [<commit>]"
+msgstr "git merge-base --fork-point <riferimento> [<commit>]"
+
+#: builtin/merge-base.c:153
+msgid "output all common ancestors"
+msgstr "manda in output tutti gli antenati comuni"
+
+#: builtin/merge-base.c:155
+msgid "find ancestors for a single n-way merge"
+msgstr "trova gli antenati per un singolo merge a n vie"
+
+#: builtin/merge-base.c:157
+msgid "list revs not reachable from others"
+msgstr "elenca le revisioni non raggiungibili dalle altre"
+
+#: builtin/merge-base.c:159
+msgid "is the first one ancestor of the other?"
+msgstr "il primo argomento è antenato dell'altro?"
+
+#: builtin/merge-base.c:161
+msgid "find where <commit> forked from reflog of <ref>"
+msgstr ""
+"trova il punto di fork di <commit> dal registro dei riferimenti di "
+"<riferimento>"
+
+#: builtin/merge-file.c:9
+msgid ""
+"git merge-file [<options>] [-L <name1> [-L <orig> [-L <name2>]]] <file1> "
+"<orig-file> <file2>"
+msgstr ""
+"git merge-file [<opzioni>] [-L <nome1> [-L <originale> [-L <nome2>]]] "
+"<file1> <file originale> <file2>"
+
+#: builtin/merge-file.c:35
+msgid "send results to standard output"
+msgstr "invia i risultati allo standard output"
+
+#: builtin/merge-file.c:36
+msgid "use a diff3 based merge"
+msgstr "usa un merge basato su diff3"
+
+#: builtin/merge-file.c:37
+msgid "for conflicts, use our version"
+msgstr "per i conflitti, usa la nostra versione"
+
+#: builtin/merge-file.c:39
+msgid "for conflicts, use their version"
+msgstr "per i conflitti, usa la loro versione"
+
+#: builtin/merge-file.c:41
+msgid "for conflicts, use a union version"
+msgstr "per i conflitti, usa una versione unita"
+
+#: builtin/merge-file.c:44
+msgid "for conflicts, use this marker size"
+msgstr "per i conflitti, usa questa dimensione dei contrassegni"
+
+#: builtin/merge-file.c:45
+msgid "do not warn about conflicts"
+msgstr "non emettere avvisi in caso di conflitti"
+
+#: builtin/merge-file.c:47
+msgid "set labels for file1/orig-file/file2"
+msgstr "imposta etichette per file1/file originale/file2"
+
+#: builtin/merge-recursive.c:47
+#, c-format
+msgid "unknown option %s"
+msgstr "opzione sconosciuta %s"
+
+#: builtin/merge-recursive.c:53
+#, c-format
+msgid "could not parse object '%s'"
+msgstr "impossibile analizzare l'oggetto '%s'"
+
+#: builtin/merge-recursive.c:57
+#, c-format
+msgid "cannot handle more than %d base. Ignoring %s."
+msgid_plural "cannot handle more than %d bases. Ignoring %s."
+msgstr[0] "impossibile gestire più di %d base. Ignoro %s."
+msgstr[1] "impossibile gestire più di %d basi. Ignoro %s."
+
+#: builtin/merge-recursive.c:65
+msgid "not handling anything other than two heads merge."
+msgstr "non gestisco nulla che non sia il merge di due head."
+
+#: builtin/merge-recursive.c:74 builtin/merge-recursive.c:76
+#, c-format
+msgid "could not resolve ref '%s'"
+msgstr "impossibile risolvere il riferimento '%s'"
+
+#: builtin/merge-recursive.c:82
+#, c-format
+msgid "Merging %s with %s\n"
+msgstr "Merge di %s con %s in corso\n"
+
+#: builtin/mktree.c:66
+msgid "git mktree [-z] [--missing] [--batch]"
+msgstr "git mktree [-z] [--missing] [--batch]"
+
+#: builtin/mktree.c:154
+msgid "input is NUL terminated"
+msgstr "l'input è terminato da NUL"
+
+#: builtin/mktree.c:155 builtin/write-tree.c:26
+msgid "allow missing objects"
+msgstr "consenti oggetti mancanti"
+
+#: builtin/mktree.c:156
+msgid "allow creation of more than one tree"
+msgstr "consenti la creazione di più di un albero"
+
+#: builtin/multi-pack-index.c:9
+msgid ""
+"git multi-pack-index [<options>] (write|verify|expire|repack --batch-"
+"size=<size>)"
+msgstr ""
+"git multi-pack-index [<opzioni>] (write|verify|expire|repack --batch-size=<"
+"dimensione>)"
+
+#: builtin/multi-pack-index.c:26
+msgid "object directory containing set of packfile and pack-index pairs"
+msgstr ""
+"directory oggetti contenente un insieme di coppie packfile e pack-index"
+
+#: builtin/multi-pack-index.c:29
+msgid ""
+"during repack, collect pack-files of smaller size into a batch that is "
+"larger than this size"
+msgstr ""
+"durante il repack, raccogli i file pack di dimensioni più piccole in un "
+"gruppo più grande di queste dimensioni"
+
+#: builtin/multi-pack-index.c:50 builtin/prune-packed.c:67
+msgid "too many arguments"
+msgstr "troppi argomenti"
+
+#: builtin/multi-pack-index.c:60
+msgid "--batch-size option is only for 'repack' subcommand"
+msgstr "l'opzione --batch-size è consentita solo per il sottocomando 'repack'"
+
+#: builtin/multi-pack-index.c:69
+#, c-format
+msgid "unrecognized subcommand: %s"
+msgstr "sottocomando sconosciuto: %s"
+
+#: builtin/mv.c:18
+msgid "git mv [<options>] <source>... <destination>"
+msgstr "git mv [<opzioni>] <sorgente>... <destinazione>"
+
+#: builtin/mv.c:83
+#, c-format
+msgid "Directory %s is in index and no submodule?"
+msgstr "La directory %s è nell'indice e non è specificato un sottomodulo?"
+
+#: builtin/mv.c:85
+msgid "Please stage your changes to .gitmodules or stash them to proceed"
+msgstr ""
+"Esegui lo stage delle modifiche a .gitmodules o eseguine lo stash per "
+"procedere"
+
+#: builtin/mv.c:103
+#, c-format
+msgid "%.*s is in index"
+msgstr "%.*s è nell'indice"
+
+#: builtin/mv.c:125
+msgid "force move/rename even if target exists"
+msgstr "forza spostamento/ridenominazione anche se la destinazione esiste"
+
+#: builtin/mv.c:127
+msgid "skip move/rename errors"
+msgstr "salta errori spostamento/ridenominazione"
+
+#: builtin/mv.c:169
+#, c-format
+msgid "destination '%s' is not a directory"
+msgstr "la destinazione '%s' non è una directory"
+
+#: builtin/mv.c:180
+#, c-format
+msgid "Checking rename of '%s' to '%s'\n"
+msgstr "Controllo la ridenominazione di '%s' in '%s'\n"
+
+#: builtin/mv.c:184
+msgid "bad source"
+msgstr "sourgente errata"
+
+#: builtin/mv.c:187
+msgid "can not move directory into itself"
+msgstr "non è possibile spostare la directory in sé stessa"
+
+#: builtin/mv.c:190
+msgid "cannot move directory over file"
+msgstr "non è possibile spostare la directory su un file"
+
+#: builtin/mv.c:199
+msgid "source directory is empty"
+msgstr "la directory sorgente è vuota"
+
+#: builtin/mv.c:224
+msgid "not under version control"
+msgstr "non è sotto controllo di versione"
+
+#: builtin/mv.c:227
+msgid "destination exists"
+msgstr "la destinazione esiste"
+
+#: builtin/mv.c:235
+#, c-format
+msgid "overwriting '%s'"
+msgstr "sovrascrittura di %s in corso"
+
+#: builtin/mv.c:238
+msgid "Cannot overwrite"
+msgstr "Impossibile sovrascrivere"
+
+#: builtin/mv.c:241
+msgid "multiple sources for the same target"
+msgstr "fonti multiple per la stessa destinazione"
+
+#: builtin/mv.c:243
+msgid "destination directory does not exist"
+msgstr "la directory di destinazione non esiste"
+
+#: builtin/mv.c:250
+#, c-format
+msgid "%s, source=%s, destination=%s"
+msgstr "%s, sorgente=%s, destinazione=%s"
+
+#: builtin/mv.c:271
+#, c-format
+msgid "Renaming %s to %s\n"
+msgstr "Rinominazione di %s in %s in corso\n"
+
+#: builtin/mv.c:277 builtin/remote.c:716 builtin/repack.c:518
+#, c-format
+msgid "renaming '%s' failed"
+msgstr "rinomina di '%s' non riuscita"
+
+#: builtin/name-rev.c:403
+msgid "git name-rev [<options>] <commit>..."
+msgstr "git name-rev [<opzioni>] <commit>..."
+
+#: builtin/name-rev.c:404
+msgid "git name-rev [<options>] --all"
+msgstr "git name-rev [<opzioni>] --all"
+
+#: builtin/name-rev.c:405
+msgid "git name-rev [<options>] --stdin"
+msgstr "git name-rev [<opzioni>] --stdin"
+
+#: builtin/name-rev.c:462
+msgid "print only names (no SHA-1)"
+msgstr "stampa solo i nomi (non lo SHA-1)"
+
+#: builtin/name-rev.c:463
+msgid "only use tags to name the commits"
+msgstr "usa solo tag per denominare i commit"
+
+#: builtin/name-rev.c:465
+msgid "only use refs matching <pattern>"
+msgstr "usa solo i riferimenti corrispondenti a <pattern>"
+
+#: builtin/name-rev.c:467
+msgid "ignore refs matching <pattern>"
+msgstr "ignora i riferimenti corrispondenti a <pattern>"
+
+#: builtin/name-rev.c:469
+msgid "list all commits reachable from all refs"
+msgstr "elenca tutti i commit raggiungibili da tutti i riferimenti"
+
+#: builtin/name-rev.c:470
+msgid "read from stdin"
+msgstr "leggi dallo standard input"
+
+#: builtin/name-rev.c:471
+msgid "allow to print `undefined` names (default)"
+msgstr "consenti di stampare nomi `non definito` (impostazione predefinita)"
+
+#: builtin/name-rev.c:477
+msgid "dereference tags in the input (internal use)"
+msgstr "dereferenzia tag nell'input (uso interno)"
+
+#: builtin/notes.c:28
+msgid "git notes [--ref <notes-ref>] [list [<object>]]"
+msgstr "git notes [--ref <riferimento note>] [list [<oggetto>]]"
+
+#: builtin/notes.c:29
+msgid ""
+"git notes [--ref <notes-ref>] add [-f] [--allow-empty] [-m <msg> | -F <file> "
+"| (-c | -C) <object>] [<object>]"
+msgstr ""
+"git notes [--ref <riferimento note>] add [-f] [--allow-empty] [-m "
+"<messaggio> | -F <file> | (-c | -C) <oggetto>] [<oggetto>]"
+
+#: builtin/notes.c:30
+msgid "git notes [--ref <notes-ref>] copy [-f] <from-object> <to-object>"
+msgstr ""
+"git notes [--ref <riferimento note>] copy [-f] <oggetto sorgente> <oggetto "
+"destinazione>"
+
+#: builtin/notes.c:31
+msgid ""
+"git notes [--ref <notes-ref>] append [--allow-empty] [-m <msg> | -F <file> | "
+"(-c | -C) <object>] [<object>]"
+msgstr ""
+"git notes [--ref <riferimento note>] append [--allow-empty] [-m <messaggio> "
+"| -F <file> | (-c | -C) <oggetto>] [<oggetto>]"
+
+#: builtin/notes.c:32
+msgid "git notes [--ref <notes-ref>] edit [--allow-empty] [<object>]"
+msgstr "git notes [--ref <riferimento note>] edit [--allow-empty] [<oggetto>]"
+
+#: builtin/notes.c:33
+msgid "git notes [--ref <notes-ref>] show [<object>]"
+msgstr "git notes [--ref <riferimento note>] show [<oggetto>]"
+
+#: builtin/notes.c:34
+msgid ""
+"git notes [--ref <notes-ref>] merge [-v | -q] [-s <strategy>] <notes-ref>"
+msgstr ""
+"git notes [--ref <riferimento note>] merge [-v | -q] [-s <strategia>] "
+"<riferimento note>"
+
+#: builtin/notes.c:35
+msgid "git notes merge --commit [-v | -q]"
+msgstr "git notes merge --commit [-v | -q]"
+
+#: builtin/notes.c:36
+msgid "git notes merge --abort [-v | -q]"
+msgstr "git notes merge --abort [-v | -q]"
+
+#: builtin/notes.c:37
+msgid "git notes [--ref <notes-ref>] remove [<object>...]"
+msgstr "git notes [--ref <riferimento note>] remove [<oggetto>...]"
+
+#: builtin/notes.c:38
+msgid "git notes [--ref <notes-ref>] prune [-n] [-v]"
+msgstr "git notes [--ref <riferimento note>] prune [-n] [-v]"
+
+#: builtin/notes.c:39
+msgid "git notes [--ref <notes-ref>] get-ref"
+msgstr "git notes [--ref <riferimento note>] get-ref"
+
+#: builtin/notes.c:44
+msgid "git notes [list [<object>]]"
+msgstr "git notes [list [<oggetto>]]"
+
+#: builtin/notes.c:49
+msgid "git notes add [<options>] [<object>]"
+msgstr "git notes add [<opzioni>] [<oggetto>]"
+
+#: builtin/notes.c:54
+msgid "git notes copy [<options>] <from-object> <to-object>"
+msgstr "git notes copy [<oggetto>] <oggetto sorgente> <oggetto destinazione>"
+
+#: builtin/notes.c:55
+msgid "git notes copy --stdin [<from-object> <to-object>]..."
+msgstr "git notes copy --stdin [<oggetto sorgente> <oggetto destinazione>]..."
+
+#: builtin/notes.c:60
+msgid "git notes append [<options>] [<object>]"
+msgstr "git notes append [<opzioni>] [<oggetto>]"
+
+#: builtin/notes.c:65
+msgid "git notes edit [<object>]"
+msgstr "git notes edit [<oggetto>]"
+
+#: builtin/notes.c:70
+msgid "git notes show [<object>]"
+msgstr "git notes show [<oggetto>]"
+
+#: builtin/notes.c:75
+msgid "git notes merge [<options>] <notes-ref>"
+msgstr "git notes merge [<opzioni>] <riferimento note>"
+
+#: builtin/notes.c:76
+msgid "git notes merge --commit [<options>]"
+msgstr "git notes merge --commit [<opzioni>]"
+
+#: builtin/notes.c:77
+msgid "git notes merge --abort [<options>]"
+msgstr "git notes merge --abort [<opzioni>]"
+
+#: builtin/notes.c:82
+msgid "git notes remove [<object>]"
+msgstr "git notes remove [<oggetto>]"
+
+#: builtin/notes.c:87
+msgid "git notes prune [<options>]"
+msgstr "git notes prune [<opzioni>]"
+
+#: builtin/notes.c:92
+msgid "git notes get-ref"
+msgstr "git notes get-ref"
+
+#: builtin/notes.c:97
+msgid "Write/edit the notes for the following object:"
+msgstr "Scrivi/modifica le note per l'oggetto seguente:"
+
+#: builtin/notes.c:150
+#, c-format
+msgid "unable to start 'show' for object '%s'"
+msgstr "impossibile avviare 'show' per l'oggetto '%s'"
+
+#: builtin/notes.c:154
+msgid "could not read 'show' output"
+msgstr "impossibile leggere l'output di 'show'"
+
+#: builtin/notes.c:162
+#, c-format
+msgid "failed to finish 'show' for object '%s'"
+msgstr "impossibile terminare 'show' per l'oggetto '%s'"
+
+#: builtin/notes.c:197
+msgid "please supply the note contents using either -m or -F option"
+msgstr "fornisci i contenuti delle note usando l'opzione -m o -F"
+
+#: builtin/notes.c:206
+msgid "unable to write note object"
+msgstr "impossibile scrivere l'oggetto nota"
+
+#: builtin/notes.c:208
+#, c-format
+msgid "the note contents have been left in %s"
+msgstr "i contenuti della nota sono stati lasciati in %s"
+
+#: builtin/notes.c:242 builtin/tag.c:532
+#, c-format
+msgid "could not open or read '%s'"
+msgstr "non è stato possibile aprire o leggere '%s'"
+
+#: builtin/notes.c:263 builtin/notes.c:313 builtin/notes.c:315
+#: builtin/notes.c:383 builtin/notes.c:438 builtin/notes.c:526
+#: builtin/notes.c:531 builtin/notes.c:610 builtin/notes.c:672
+#, c-format
+msgid "failed to resolve '%s' as a valid ref."
+msgstr "impossibile risolvere '%s' come riferimento valido."
+
+#: builtin/notes.c:265
+#, c-format
+msgid "failed to read object '%s'."
+msgstr "lettura dell'oggetto '%s' non riuscita."
+
+#: builtin/notes.c:268
+#, c-format
+msgid "cannot read note data from non-blob object '%s'."
+msgstr "impossibile leggere i dati della nota dall'oggetto non blob '%s'."
+
+#: builtin/notes.c:309
+#, c-format
+msgid "malformed input line: '%s'."
+msgstr "riga di input malformata: '%s'."
+
+#: builtin/notes.c:324
+#, c-format
+msgid "failed to copy notes from '%s' to '%s'"
+msgstr "copia delle note da '%s' a '%s' non riuscita"
+
+#. TRANSLATORS: the first %s will be replaced by a git
+#. notes command: 'add', 'merge', 'remove', etc.
+#.
+#: builtin/notes.c:356
+#, c-format
+msgid "refusing to %s notes in %s (outside of refs/notes/)"
+msgstr ""
+"mi rifiuto di eseguire %s delle note in %s (al di fuori di refs/notes/)"
+
+#: builtin/notes.c:376 builtin/notes.c:431 builtin/notes.c:509
+#: builtin/notes.c:521 builtin/notes.c:598 builtin/notes.c:665
+#: builtin/notes.c:815 builtin/notes.c:963 builtin/notes.c:985
+msgid "too many parameters"
+msgstr "troppi parametri"
+
+#: builtin/notes.c:389 builtin/notes.c:678
+#, c-format
+msgid "no note found for object %s."
+msgstr "nessuna nota trovata per l'oggetto %s."
+
+#: builtin/notes.c:410 builtin/notes.c:576
+msgid "note contents as a string"
+msgstr "contenuti della nota come stringa"
+
+#: builtin/notes.c:413 builtin/notes.c:579
+msgid "note contents in a file"
+msgstr "contenuti della nota in un file"
+
+#: builtin/notes.c:416 builtin/notes.c:582
+msgid "reuse and edit specified note object"
+msgstr "riusa l'oggetto nota specificato per poi modificarlo"
+
+#: builtin/notes.c:419 builtin/notes.c:585
+msgid "reuse specified note object"
+msgstr "riusa l'oggetto nota specificato"
+
+#: builtin/notes.c:422 builtin/notes.c:588
+msgid "allow storing empty note"
+msgstr "consenti il salvataggio di una nota vuota"
+
+#: builtin/notes.c:423 builtin/notes.c:496
+msgid "replace existing notes"
+msgstr "sostituisci le note esistenti"
+
+#: builtin/notes.c:448
+#, c-format
+msgid ""
+"Cannot add notes. Found existing notes for object %s. Use '-f' to overwrite "
+"existing notes"
+msgstr ""
+"Impossibile aggiungere note. Trovate note esistenti per l'oggetto %s. Usa '-"
+"f' per sovrascrivere le note esistenti"
+
+#: builtin/notes.c:463 builtin/notes.c:544
+#, c-format
+msgid "Overwriting existing notes for object %s\n"
+msgstr "Sovrascrittura delle note esistenti per l'oggetto %s\n"
+
+#: builtin/notes.c:475 builtin/notes.c:637 builtin/notes.c:902
+#, c-format
+msgid "Removing note for object %s\n"
+msgstr "Rimozione della nota per l'oggetto %s\n"
+
+#: builtin/notes.c:497
+msgid "read objects from stdin"
+msgstr "leggi oggetti dallo standard input"
+
+#: builtin/notes.c:499
+msgid "load rewriting config for <command> (implies --stdin)"
+msgstr ""
+"carica la configurazione di riscrittura per <comando> (implica --stdin)"
+
+#: builtin/notes.c:517
+msgid "too few parameters"
+msgstr "troppi pochi parametri"
+
+#: builtin/notes.c:538
+#, c-format
+msgid ""
+"Cannot copy notes. Found existing notes for object %s. Use '-f' to overwrite "
+"existing notes"
+msgstr ""
+"Impossibile copiare le note. Trovate note esistenti per l'oggetto %s. Usa '-"
+"f' per sovrascrivere le note esistenti"
+
+#: builtin/notes.c:550
+#, c-format
+msgid "missing notes on source object %s. Cannot copy."
+msgstr "note mancanti per l'oggetto sorgente %s. Impossibile copiare."
+
+#: builtin/notes.c:603
+#, c-format
+msgid ""
+"The -m/-F/-c/-C options have been deprecated for the 'edit' subcommand.\n"
+"Please use 'git notes add -f -m/-F/-c/-C' instead.\n"
+msgstr ""
+"Le opzioni -m/-F/-c/-C per il sottocomando 'edit' sono deprecate.\n"
+"Usa 'git notes add -f -m/-F/-c/-C' al loro posto.\n"
+
+#: builtin/notes.c:698
+msgid "failed to delete ref NOTES_MERGE_PARTIAL"
+msgstr "eliminazione del riferimento NOTES_MERGE_PARTIAL non riuscita"
+
+#: builtin/notes.c:700
+msgid "failed to delete ref NOTES_MERGE_REF"
+msgstr "eliminazione del riferimento NOTES_MERGE_REF non riuscita"
+
+#: builtin/notes.c:702
+msgid "failed to remove 'git notes merge' worktree"
+msgstr "rimozione dell'albero di lavoro di 'git notes merge' non riuscita"
+
+#: builtin/notes.c:722
+msgid "failed to read ref NOTES_MERGE_PARTIAL"
+msgstr "lettura del riferimento NOTES_MERGE_PARTIAL non riuscita"
+
+#: builtin/notes.c:724
+msgid "could not find commit from NOTES_MERGE_PARTIAL."
+msgstr "impossibile trovare il commit da NOTES_MERGE_PARTIAL."
+
+#: builtin/notes.c:726
+msgid "could not parse commit from NOTES_MERGE_PARTIAL."
+msgstr "impossibile analizzare il commit da NOTES_MERGE_PARTIAL."
+
+#: builtin/notes.c:739
+msgid "failed to resolve NOTES_MERGE_REF"
+msgstr "risoluzione di NOTES_MERGE_REF non riuscita"
+
+#: builtin/notes.c:742
+msgid "failed to finalize notes merge"
+msgstr "finalizzazione del merge delle note non riuscita"
+
+#: builtin/notes.c:768
+#, c-format
+msgid "unknown notes merge strategy %s"
+msgstr "strategia di merge delle note %s sconosciuta"
+
+#: builtin/notes.c:784
+msgid "General options"
+msgstr "Opzioni generali"
+
+#: builtin/notes.c:786
+msgid "Merge options"
+msgstr "Opzioni merge"
+
+#: builtin/notes.c:788
+msgid ""
+"resolve notes conflicts using the given strategy (manual/ours/theirs/union/"
+"cat_sort_uniq)"
+msgstr ""
+"risolvi i conflitti delle note usando la strategia data (manual/ours/theirs/"
+"union/cat_sort_uniq)"
+
+#: builtin/notes.c:790
+msgid "Committing unmerged notes"
+msgstr "Commit delle note non sottoposte a merge"
+
+#: builtin/notes.c:792
+msgid "finalize notes merge by committing unmerged notes"
+msgstr ""
+"finalizza il merge delle note eseguendo il commit delle note non sottoposte "
+"a merge"
+
+#: builtin/notes.c:794
+msgid "Aborting notes merge resolution"
+msgstr "Interruzione della risoluzione del merge delle note"
+
+#: builtin/notes.c:796
+msgid "abort notes merge"
+msgstr "interrompi il merge delle note"
+
+#: builtin/notes.c:807
+msgid "cannot mix --commit, --abort or -s/--strategy"
+msgstr "impossibile usare contemporaneamente --commit, --abort o -s/--strategy"
+
+#: builtin/notes.c:812
+msgid "must specify a notes ref to merge"
+msgstr "devi specificare un riferimento note da sottoporre a merge"
+
+#: builtin/notes.c:836
+#, c-format
+msgid "unknown -s/--strategy: %s"
+msgstr "-s/--strategy sconosciuta: %s"
+
+#: builtin/notes.c:873
+#, c-format
+msgid "a notes merge into %s is already in-progress at %s"
+msgstr "è già in corso un'operazione di merge delle note in %s al percorso %s"
+
+#: builtin/notes.c:876
+#, c-format
+msgid "failed to store link to current notes ref (%s)"
+msgstr ""
+"salvataggio del collegamento al riferimento corrente delle note (%s) non "
+"riuscito"
+
+#: builtin/notes.c:878
+#, c-format
+msgid ""
+"Automatic notes merge failed. Fix conflicts in %s and commit the result with "
+"'git notes merge --commit', or abort the merge with 'git notes merge --"
+"abort'.\n"
+msgstr ""
+"Merge automatico delle note non riuscito. Risolvi i conflitti in %s ed "
+"esegui il commit del risultato con 'git notes merge --commit' o interrompi "
+"il merge con 'git notes merge --abort'.\n"
+
+#: builtin/notes.c:897 builtin/tag.c:545
+#, c-format
+msgid "Failed to resolve '%s' as a valid ref."
+msgstr "Risoluzione di '%s' come riferimento valido non riuscita."
+
+#: builtin/notes.c:900
+#, c-format
+msgid "Object %s has no note\n"
+msgstr "L'oggetto %s non ha note.\n"
+
+#: builtin/notes.c:912
+msgid "attempt to remove non-existent note is not an error"
+msgstr "il tentativo di rimuovere una nota inesistente non è un errore"
+
+#: builtin/notes.c:915
+msgid "read object names from the standard input"
+msgstr "leggi i nomi degli oggetti dallo standard input"
+
+#: builtin/notes.c:954 builtin/prune.c:130 builtin/worktree.c:164
+msgid "do not remove, show only"
+msgstr "non rimuovere, limitati a visualizzare"
+
+#: builtin/notes.c:955
+msgid "report pruned notes"
+msgstr "segnala le note eliminate"
+
+#: builtin/notes.c:998
+msgid "notes-ref"
+msgstr "riferimento note"
+
+#: builtin/notes.c:999
+msgid "use notes from <notes-ref>"
+msgstr "usa le note in <riferimento note>"
+
+#: builtin/notes.c:1034 builtin/stash.c:1607
+#, c-format
+msgid "unknown subcommand: %s"
+msgstr "sottocomando sconosciuto: %s"
+
+#: builtin/pack-objects.c:52
+msgid ""
+"git pack-objects --stdout [<options>...] [< <ref-list> | < <object-list>]"
+msgstr ""
+"git pack-objects --stdout [<opzioni>...] [< <elenco riferimenti> | < <elenco "
+"oggetti>]"
+
+#: builtin/pack-objects.c:53
+msgid ""
+"git pack-objects [<options>...] <base-name> [< <ref-list> | < <object-list>]"
+msgstr ""
+"git pack-objects [<opzioni>...] <nome base> [< <elenco riferimenti> | < "
+"<elenco oggetti>]"
+
+#: builtin/pack-objects.c:428
+#, c-format
+msgid "bad packed object CRC for %s"
+msgstr "CRC oggetto sottoposto a pack %s errato"
+
+#: builtin/pack-objects.c:439
+#, c-format
+msgid "corrupt packed object for %s"
+msgstr "oggetto sottoposto a pack %s corrotto"
+
+#: builtin/pack-objects.c:570
+#, c-format
+msgid "recursive delta detected for object %s"
+msgstr "rilevato delta ricorsivo per l'oggetto %s"
+
+#: builtin/pack-objects.c:781
+#, c-format
+msgid "ordered %u objects, expected %<PRIu32>"
+msgstr "%u oggetti ordinati, attesi %<PRIu32>"
+
+#: builtin/pack-objects.c:794
+#, c-format
+msgid "packfile is invalid: %s"
+msgstr "packfile non valido: %s"
+
+#: builtin/pack-objects.c:798
+#, c-format
+msgid "unable to open packfile for reuse: %s"
+msgstr "impossibile aprire il packfile per il suo riuso: %s"
+
+#: builtin/pack-objects.c:802
+msgid "unable to seek in reused packfile"
+msgstr "impossibile eseguire seek nel packfile riusato"
+
+#: builtin/pack-objects.c:813
+msgid "unable to read from reused packfile"
+msgstr "impossibile leggere dal packfile riusato"
+
+#: builtin/pack-objects.c:841
+msgid "disabling bitmap writing, packs are split due to pack.packSizeLimit"
+msgstr ""
+"disabilito la scrittura delle bitmap, i pack sono divisi a causa "
+"dell'impostazione pack.packSizeLimit"
+
+#: builtin/pack-objects.c:854
+msgid "Writing objects"
+msgstr "Scrittura degli oggetti in corso"
+
+#: builtin/pack-objects.c:917 builtin/update-index.c:90
+#, c-format
+msgid "failed to stat %s"
+msgstr "stat di %s non riuscito"
+
+#: builtin/pack-objects.c:970
+#, c-format
+msgid "wrote %<PRIu32> objects while expecting %<PRIu32>"
+msgstr "scritti %<PRIu32> oggetti quando me ne attendevo %<PRIu32>"
+
+#: builtin/pack-objects.c:1164
+msgid "disabling bitmap writing, as some objects are not being packed"
+msgstr ""
+"disabilito la scrittura delle bitmap perché alcuni oggetti non saranno "
+"sottoposti a pack"
+
+#: builtin/pack-objects.c:1592
+#, c-format
+msgid "delta base offset overflow in pack for %s"
+msgstr "overflow dell'offset base del delta nel pack per %s"
+
+#: builtin/pack-objects.c:1601
+#, c-format
+msgid "delta base offset out of bound for %s"
+msgstr "offset base del delta fuori dall'intervallo consentito per %s"
+
+#: builtin/pack-objects.c:1870
+msgid "Counting objects"
+msgstr "Conteggio degli oggetti in corso"
+
+#: builtin/pack-objects.c:2000
+#, c-format
+msgid "unable to get size of %s"
+msgstr "impossibile recuperare le dimensioni di %s"
+
+#: builtin/pack-objects.c:2015
+#, c-format
+msgid "unable to parse object header of %s"
+msgstr "impossibile analizzare l'intestazione oggetto di %s"
+
+#: builtin/pack-objects.c:2085 builtin/pack-objects.c:2101
+#: builtin/pack-objects.c:2111
+#, c-format
+msgid "object %s cannot be read"
+msgstr "impossibile leggere l'oggetto %s"
+
+#: builtin/pack-objects.c:2088 builtin/pack-objects.c:2115
+#, c-format
+msgid "object %s inconsistent object length (%<PRIuMAX> vs %<PRIuMAX>)"
+msgstr ""
+"oggetto %s: lunghezza oggetto inconsistente (%<PRIuMAX> contro %<PRIuMAX>)"
+
+#: builtin/pack-objects.c:2125
+msgid "suboptimal pack - out of memory"
+msgstr "pack subottimo - memoria esaurita"
+
+#: builtin/pack-objects.c:2440
+#, c-format
+msgid "Delta compression using up to %d threads"
+msgstr "Compressione delta in corso, uso fino a %d thread"
+
+#: builtin/pack-objects.c:2572
+#, c-format
+msgid "unable to pack objects reachable from tag %s"
+msgstr "impossibile eseguire il pack degli oggetti raggiungibili dal tag %s"
+
+#: builtin/pack-objects.c:2659
+msgid "Compressing objects"
+msgstr "Compressione oggetti in corso"
+
+#: builtin/pack-objects.c:2665
+msgid "inconsistency with delta count"
+msgstr "inconsistenza con il numero dei delta"
+
+#: builtin/pack-objects.c:2742
+#, c-format
+msgid ""
+"expected edge object ID, got garbage:\n"
+" %s"
+msgstr ""
+"atteso ID oggetto arco, ricevuti dati errati:\n"
+" %s"
+
+#: builtin/pack-objects.c:2748
+#, c-format
+msgid ""
+"expected object ID, got garbage:\n"
+" %s"
+msgstr ""
+"atteso ID oggetto, ricevuti dati errati:\n"
+" %s"
+
+#: builtin/pack-objects.c:2846
+msgid "invalid value for --missing"
+msgstr "valore non valido per --missing"
+
+#: builtin/pack-objects.c:2905 builtin/pack-objects.c:3013
+msgid "cannot open pack index"
+msgstr "impossibile aprire l'indice pack"
+
+#: builtin/pack-objects.c:2936
+#, c-format
+msgid "loose object at %s could not be examined"
+msgstr "impossibile esaminare l'oggetto sciolto %s"
+
+#: builtin/pack-objects.c:3021
+msgid "unable to force loose object"
+msgstr "impossibile forzare l'oggetto sciolto"
+
+#: builtin/pack-objects.c:3113
+#, c-format
+msgid "not a rev '%s'"
+msgstr "'%s' non è una revisione"
+
+#: builtin/pack-objects.c:3116
+#, c-format
+msgid "bad revision '%s'"
+msgstr "revisione '%s' errata"
+
+#: builtin/pack-objects.c:3141
+msgid "unable to add recent objects"
+msgstr "impossibile aggiungere gli oggetti recenti"
+
+#: builtin/pack-objects.c:3194
+#, c-format
+msgid "unsupported index version %s"
+msgstr "versione %s di index non supportata"
+
+#: builtin/pack-objects.c:3198
+#, c-format
+msgid "bad index version '%s'"
+msgstr "versione '%s' di index errata"
+
+#: builtin/pack-objects.c:3236
+msgid "<version>[,<offset>]"
+msgstr "<versione>[,<offset>]"
+
+#: builtin/pack-objects.c:3237
+msgid "write the pack index file in the specified idx format version"
+msgstr "scrivi il file indice pack usando la versione formato idx specificata"
+
+#: builtin/pack-objects.c:3240
+msgid "maximum size of each output pack file"
+msgstr "dimensione massima di ogni file pack in output"
+
+#: builtin/pack-objects.c:3242
+msgid "ignore borrowed objects from alternate object store"
+msgstr "ignora gli oggetti presi in prestito dallo store oggetti alternativo"
+
+#: builtin/pack-objects.c:3244
+msgid "ignore packed objects"
+msgstr "ignora gli oggetti sottoposti a pack"
+
+#: builtin/pack-objects.c:3246
+msgid "limit pack window by objects"
+msgstr "limita la finestra di pack al numero di oggetti specificato"
+
+#: builtin/pack-objects.c:3248
+msgid "limit pack window by memory in addition to object limit"
+msgstr ""
+"limita la finestra di pack alla memoria specificata in aggiunta al limite "
+"sugli oggetti"
+
+#: builtin/pack-objects.c:3250
+msgid "maximum length of delta chain allowed in the resulting pack"
+msgstr "lunghezza massima della catena di delta consentita nel pack risultante"
+
+#: builtin/pack-objects.c:3252
+msgid "reuse existing deltas"
+msgstr "riusa i delta esistenti"
+
+#: builtin/pack-objects.c:3254
+msgid "reuse existing objects"
+msgstr "riusa gli oggetti esistenti"
+
+#: builtin/pack-objects.c:3256
+msgid "use OFS_DELTA objects"
+msgstr "usa oggetti OFS_DELTA"
+
+#: builtin/pack-objects.c:3258
+msgid "use threads when searching for best delta matches"
+msgstr ""
+"usa più thread durante la ricerca delle migliori corrispondenze per i delta"
+
+#: builtin/pack-objects.c:3260
+msgid "do not create an empty pack output"
+msgstr "non creare un output pack vuoto"
+
+#: builtin/pack-objects.c:3262
+msgid "read revision arguments from standard input"
+msgstr "leggi gli argomenti revisione dallo standard input"
+
+#: builtin/pack-objects.c:3264
+msgid "limit the objects to those that are not yet packed"
+msgstr "limita gli oggetti a quelli non ancora sottoposti a pack"
+
+#: builtin/pack-objects.c:3267
+msgid "include objects reachable from any reference"
+msgstr "includi gli oggetti raggiungibili da qualunque riferimento"
+
+#: builtin/pack-objects.c:3270
+msgid "include objects referred by reflog entries"
+msgstr "includi gli oggetti referenziati da voci del log riferimenti"
+
+#: builtin/pack-objects.c:3273
+msgid "include objects referred to by the index"
+msgstr "includi gli oggetti referenziati dall'indice"
+
+#: builtin/pack-objects.c:3276
+msgid "output pack to stdout"
+msgstr "invia il pack in output sullo standard output"
+
+#: builtin/pack-objects.c:3278
+msgid "include tag objects that refer to objects to be packed"
+msgstr ""
+"includi gli oggetti tag che fanno riferimento agli oggetti da sottoporre a "
+"pack"
+
+#: builtin/pack-objects.c:3280
+msgid "keep unreachable objects"
+msgstr "mantieni gli oggetti non raggiungibili"
+
+#: builtin/pack-objects.c:3282
+msgid "pack loose unreachable objects"
+msgstr "esegui il pack degli oggetti non raggiungibili sciolti"
+
+#: builtin/pack-objects.c:3284
+msgid "unpack unreachable objects newer than <time>"
+msgstr "decomprimi gli oggetti non raggiungibili più recenti di <tempo>"
+
+#: builtin/pack-objects.c:3287
+msgid "use the sparse reachability algorithm"
+msgstr "usa l'algoritmo di raggiungibilità sparse"
+
+#: builtin/pack-objects.c:3289
+msgid "create thin packs"
+msgstr "crea pack thin"
+
+#: builtin/pack-objects.c:3291
+msgid "create packs suitable for shallow fetches"
+msgstr "crea pack adatti per fetch shallow"
+
+#: builtin/pack-objects.c:3293
+msgid "ignore packs that have companion .keep file"
+msgstr "ignora i pack che hanno un file .keep che li accompagna"
+
+#: builtin/pack-objects.c:3295
+msgid "ignore this pack"
+msgstr "ignora questo pack"
+
+#: builtin/pack-objects.c:3297
+msgid "pack compression level"
+msgstr "livello compressione pack"
+
+#: builtin/pack-objects.c:3299
+msgid "do not hide commits by grafts"
+msgstr "non nascondere i commit innestati"
+
+#: builtin/pack-objects.c:3301
+msgid "use a bitmap index if available to speed up counting objects"
+msgstr ""
+"usa un indice bitmap se disponibile per velocizzare il conteggio degli "
+"oggetti"
+
+#: builtin/pack-objects.c:3303
+msgid "write a bitmap index together with the pack index"
+msgstr "scrivi un indice bitmap insieme all'indice pack"
+
+#: builtin/pack-objects.c:3307
+msgid "write a bitmap index if possible"
+msgstr "scrivi un indice bitmap se possibile"
+
+#: builtin/pack-objects.c:3311
+msgid "handling for missing objects"
+msgstr "azione da eseguire sugli oggetti mancanti"
+
+#: builtin/pack-objects.c:3314
+msgid "do not pack objects in promisor packfiles"
+msgstr "non eseguire il pack degli oggetti nei file pack promettenti"
+
+#: builtin/pack-objects.c:3316
+msgid "respect islands during delta compression"
+msgstr "rispetta le isole durante la compressione delta"
+
+#: builtin/pack-objects.c:3345
+#, c-format
+msgid "delta chain depth %d is too deep, forcing %d"
+msgstr "la profondità della catena dei delta (%d) è troppo elevata, forzo %d"
+
+#: builtin/pack-objects.c:3350
+#, c-format
+msgid "pack.deltaCacheLimit is too high, forcing %d"
+msgstr "il valore pack.deltaCacheLimit è troppo elevato, forzo %d"
+
+#: builtin/pack-objects.c:3404
+msgid "--max-pack-size cannot be used to build a pack for transfer"
+msgstr ""
+"--max-pack-size non può essere usato per generare un pack da trasferire"
+
+#: builtin/pack-objects.c:3406
+msgid "minimum pack size limit is 1 MiB"
+msgstr "il limite minimo delle dimensioni dei pack è 1 MiB"
+
+#: builtin/pack-objects.c:3411
+msgid "--thin cannot be used to build an indexable pack"
+msgstr "--thin non può essere usato per generare un pack indicizzabile"
+
+#: builtin/pack-objects.c:3414
+msgid "--keep-unreachable and --unpack-unreachable are incompatible"
+msgstr "--keep-unreachable e --unpack-unreachable non sono compatibili"
+
+#: builtin/pack-objects.c:3420
+msgid "cannot use --filter without --stdout"
+msgstr "impossibile usare --filter senza --stdout"
+
+#: builtin/pack-objects.c:3481
+msgid "Enumerating objects"
+msgstr "Enumerazione degli oggetti in corso"
+
+#: builtin/pack-objects.c:3511
+#, c-format
+msgid "Total %<PRIu32> (delta %<PRIu32>), reused %<PRIu32> (delta %<PRIu32>)"
+msgstr ""
+"%<PRIu32> oggetti totali (%<PRIu32> delta), %<PRIu32> riutilizzati "
+"(%<PRIu32> delta)"
+
+#: builtin/pack-refs.c:8
+msgid "git pack-refs [<options>]"
+msgstr "git pack-refs [<opzioni>]"
+
+#: builtin/pack-refs.c:16
+msgid "pack everything"
+msgstr "esegui il pack di tutto"
+
+#: builtin/pack-refs.c:17
+msgid "prune loose refs (default)"
+msgstr "elimina i riferimenti sciolti (impostazione predefinita)"
+
+#: builtin/prune-packed.c:9
+msgid "git prune-packed [-n | --dry-run] [-q | --quiet]"
+msgstr "git prune-packed [-n | --dry-run] [-q | --quiet]"
+
+#: builtin/prune-packed.c:42
+msgid "Removing duplicate objects"
+msgstr "Rimozione oggetti duplicati in corso"
+
+#: builtin/prune.c:12
+msgid "git prune [-n] [-v] [--progress] [--expire <time>] [--] [<head>...]"
+msgstr "git prune [-n] [-v] [--progress] [--expire <tempo>] [--] [<head>...]"
+
+#: builtin/prune.c:131
+msgid "report pruned objects"
+msgstr "segnala gli oggetti ripuliti"
+
+#: builtin/prune.c:134
+msgid "expire objects older than <time>"
+msgstr "fai scadere oggetti più vecchi di <tempo>"
+
+#: builtin/prune.c:136
+msgid "limit traversal to objects outside promisor packfiles"
+msgstr "limita la visita agli oggetti al di fuori dei file pack promettenti"
+
+#: builtin/prune.c:150
+msgid "cannot prune in a precious-objects repo"
+msgstr ""
+"impossibile eseguire l'eliminazione in un repository 'oggetti preziosi'"
+
+#: builtin/pull.c:66 builtin/pull.c:68
+#, c-format
+msgid "Invalid value for %s: %s"
+msgstr "Valore non valido per %s: %s"
+
+#: builtin/pull.c:88
+msgid "git pull [<options>] [<repository> [<refspec>...]]"
+msgstr "git pull [<opzioni>] [<repository> [<specificatore riferimento>...]]"
+
+#: builtin/pull.c:142
+msgid "control for recursive fetching of submodules"
+msgstr "controlla il recupero ricorsivo dei sottomoduli"
+
+#: builtin/pull.c:146
+msgid "Options related to merging"
+msgstr "Opzioni relative al merge"
+
+#: builtin/pull.c:149
+msgid "incorporate changes by rebasing rather than merging"
+msgstr "incorpora le modifiche eseguendo un rebase anziché un merge"
+
+#: builtin/pull.c:177 builtin/rebase.c:467 builtin/revert.c:126
+msgid "allow fast-forward"
+msgstr "consenti fast forward"
+
+#: builtin/pull.c:186
+msgid "automatically stash/stash pop before and after rebase"
+msgstr "esegui stash/stash pop automaticamente prima e dopo il rebase"
+
+#: builtin/pull.c:202
+msgid "Options related to fetching"
+msgstr "Opzioni relative al fetch"
+
+#: builtin/pull.c:212
+msgid "force overwrite of local branch"
+msgstr "forza la sovrascrittura del branch locale"
+
+#: builtin/pull.c:220
+msgid "number of submodules pulled in parallel"
+msgstr "numero di sottomoduli recuperati in parallelo"
+
+#: builtin/pull.c:320
+#, c-format
+msgid "Invalid value for pull.ff: %s"
+msgstr "Valore non valido per pull.ff: %s"
+
+#: builtin/pull.c:437
+msgid ""
+"There is no candidate for rebasing against among the refs that you just "
+"fetched."
+msgstr ""
+"Non ci sono candidati in base ai quali eseguire il rebase fra i riferimenti "
+"appena recuperati."
+
+#: builtin/pull.c:439
+msgid ""
+"There are no candidates for merging among the refs that you just fetched."
+msgstr ""
+"Non ci sono candidati in base ai quali eseguire il merge fra i riferimenti "
+"appena recuperati."
+
+#: builtin/pull.c:440
+msgid ""
+"Generally this means that you provided a wildcard refspec which had no\n"
+"matches on the remote end."
+msgstr ""
+"In generale, questo significa che hai fornito uno specificatore\n"
+"riferimento che non aveva corrispondenze nel remoto."
+
+#: builtin/pull.c:443
+#, c-format
+msgid ""
+"You asked to pull from the remote '%s', but did not specify\n"
+"a branch. Because this is not the default configured remote\n"
+"for your current branch, you must specify a branch on the command line."
+msgstr ""
+"Hai chiesto di eseguire un pull dal remoto '%s' ma non hai\n"
+"specificato un branch. Dal momento che questo non è il remoto\n"
+"configurato come predefinito per il branch corrente, devi\n"
+"specificare un branch sulla riga di comando."
+
+#: builtin/pull.c:448 builtin/rebase.c:1375 git-parse-remote.sh:73
+msgid "You are not currently on a branch."
+msgstr "Attualmente non sei su un branch."
+
+#: builtin/pull.c:450 builtin/pull.c:465 git-parse-remote.sh:79
+msgid "Please specify which branch you want to rebase against."
+msgstr "Specifica il branch in base a cui vuoi effettuare il rebase."
+
+#: builtin/pull.c:452 builtin/pull.c:467 git-parse-remote.sh:82
+msgid "Please specify which branch you want to merge with."
+msgstr "Specifica il branch in base a cui vuoi effettuare il merge."
+
+#: builtin/pull.c:453 builtin/pull.c:468
+msgid "See git-pull(1) for details."
+msgstr "Vedi git-pull(1) per ulteriori dettagli."
+
+#: builtin/pull.c:455 builtin/pull.c:461 builtin/pull.c:470
+#: builtin/rebase.c:1381 git-parse-remote.sh:64
+msgid "<remote>"
+msgstr "<remoto>"
+
+#: builtin/pull.c:455 builtin/pull.c:470 builtin/pull.c:475
+#: git-parse-remote.sh:65
+msgid "<branch>"
+msgstr "<branch>"
+
+#: builtin/pull.c:463 builtin/rebase.c:1373 git-parse-remote.sh:75
+msgid "There is no tracking information for the current branch."
+msgstr "Non ci sono informazioni di tracciamento per il branch corrente."
+
+#: builtin/pull.c:472 git-parse-remote.sh:95
+msgid ""
+"If you wish to set tracking information for this branch you can do so with:"
+msgstr ""
+"Se vuoi impostare le informazioni di tracciamento per questo branch puoi "
+"farlo con:"
+
+#: builtin/pull.c:477
+#, c-format
+msgid ""
+"Your configuration specifies to merge with the ref '%s'\n"
+"from the remote, but no such ref was fetched."
+msgstr ""
+"La tua configurazione specifica che deve essere eseguito\n"
+"il merge con il riferimento '%s' del remoto, ma un tale\n"
+"riferimento non è stato recuperato."
+
+#: builtin/pull.c:587
+#, c-format
+msgid "unable to access commit %s"
+msgstr "impossibile accedere al commit %s"
+
+#: builtin/pull.c:867
+msgid "ignoring --verify-signatures for rebase"
+msgstr "ignoro --verify-signature per il rebase"
+
+#: builtin/pull.c:922
+msgid "--[no-]autostash option is only valid with --rebase."
+msgstr "l'opzione --[no-]autostash option è valida solo con --rebase."
+
+#: builtin/pull.c:930
+msgid "Updating an unborn branch with changes added to the index."
+msgstr "Aggiorno un branch non nato con le modifiche aggiunte all'indice."
+
+#: builtin/pull.c:934
+msgid "pull with rebase"
+msgstr "pull con rebase"
+
+#: builtin/pull.c:935
+msgid "please commit or stash them."
+msgstr "eseguine il commit o lo stash."
+
+#: builtin/pull.c:960
+#, c-format
+msgid ""
+"fetch updated the current branch head.\n"
+"fast-forwarding your working tree from\n"
+"commit %s."
+msgstr ""
+"il fetch ha aggiornato l'head del\n"
+"branch corrente.\n"
+"Eseguo il fast forward dell'albero\n"
+"di lavoro dal commit %s."
+
+#: builtin/pull.c:966
+#, c-format
+msgid ""
+"Cannot fast-forward your working tree.\n"
+"After making sure that you saved anything precious from\n"
+"$ git diff %s\n"
+"output, run\n"
+"$ git reset --hard\n"
+"to recover."
+msgstr ""
+"Impossibile eseguire il fast forward dell'albero\n"
+"di lavoro.\n"
+"Dopo esserti assicurato di aver salvato tutto ciò\n"
+"che è importante dall'output di\n"
+"$ git diff %s\n"
+"esegui\n"
+"$ git reset --hard\n"
+"per eseguire il ripristino."
+
+#: builtin/pull.c:981
+msgid "Cannot merge multiple branches into empty head."
+msgstr "Impossibile eseguire il merge di più branch in un head vuoto."
+
+#: builtin/pull.c:985
+msgid "Cannot rebase onto multiple branches."
+msgstr "Impossibile eseguire il rebase su più branch."
+
+#: builtin/pull.c:992
+msgid "cannot rebase with locally recorded submodule modifications"
+msgstr ""
+"impossibile eseguire il rebase se ci sono delle modifiche registrate "
+"localmente ai sottomoduli"
+
+#: builtin/push.c:19
+msgid "git push [<options>] [<repository> [<refspec>...]]"
+msgstr "git push [<opzioni>] [<repository> [<specificatore riferimento>...]]"
+
+#: builtin/push.c:112
+msgid "tag shorthand without <tag>"
+msgstr "esegui il tag della forma breve senza <tag>"
+
+#: builtin/push.c:122
+msgid "--delete only accepts plain target ref names"
+msgstr "--delete accetta solo nomi dei ref di destinazione in chiaro"
+
+#: builtin/push.c:168
+msgid ""
+"\n"
+"To choose either option permanently, see push.default in 'git help config'."
+msgstr ""
+"\n"
+"Per scegliere permanentemente una delle due opzioni, vedi push.default in "
+"'git help config'."
+
+#: builtin/push.c:171
+#, c-format
+msgid ""
+"The upstream branch of your current branch does not match\n"
+"the name of your current branch.  To push to the upstream branch\n"
+"on the remote, use\n"
+"\n"
+"    git push %s HEAD:%s\n"
+"\n"
+"To push to the branch of the same name on the remote, use\n"
+"\n"
+"    git push %s HEAD\n"
+"%s"
+msgstr ""
+"Il branch upstream del branch attuale non corrisponde al\n"
+"nome del branch attuale. Per eseguire il push al branch upstream\n"
+"del remoto, usa\n"
+"\n"
+"    git push %s HEAD:%s\n"
+"\n"
+"Per eseguire il push al branch con lo stesso nome del remoto, usa\n"
+"\n"
+"    git push %s HEAD\n"
+"%s"
+
+#: builtin/push.c:186
+#, c-format
+msgid ""
+"You are not currently on a branch.\n"
+"To push the history leading to the current (detached HEAD)\n"
+"state now, use\n"
+"\n"
+"    git push %s HEAD:<name-of-remote-branch>\n"
+msgstr ""
+"Attualmente non sei su un branch.\n"
+"Per eseguire ora il push della cronologia che ha condotto\n"
+"allo stato corrente (HEAD scollegato), usa\n"
+"\n"
+"    git push %s HEAD:<nome del branch remoto>\n"
+
+#: builtin/push.c:200
+#, c-format
+msgid ""
+"The current branch %s has no upstream branch.\n"
+"To push the current branch and set the remote as upstream, use\n"
+"\n"
+"    git push --set-upstream %s %s\n"
+msgstr ""
+"Il branch corrente %s non ha alcun branch upstream.\n"
+"Per eseguire il push del branch corrente ed impostare il remoto come "
+"upstream, usa\n"
+"\n"
+"    git push --set-upstream %s %s\n"
+
+#: builtin/push.c:208
+#, c-format
+msgid "The current branch %s has multiple upstream branches, refusing to push."
+msgstr ""
+"Il branch corrente %s ha più branch upstream, mi rifiuto di eseguire il push."
+
+#: builtin/push.c:211
+#, c-format
+msgid ""
+"You are pushing to remote '%s', which is not the upstream of\n"
+"your current branch '%s', without telling me what to push\n"
+"to update which remote branch."
+msgstr ""
+"Stai eseguendo il push al remoto '%s', che non è l'upstream del\n"
+"branch corrente '%s', senza dirmi di cosa devo eseguire il push\n"
+"per aggiornare quale branch remoto."
+
+#: builtin/push.c:270
+msgid ""
+"You didn't specify any refspecs to push, and push.default is \"nothing\"."
+msgstr ""
+"Non è stato specificato alcun refspec per il push, e push.default è \"nothing"
+"\"."
+
+#: builtin/push.c:277
+msgid ""
+"Updates were rejected because the tip of your current branch is behind\n"
+"its remote counterpart. Integrate the remote changes (e.g.\n"
+"'git pull ...') before pushing again.\n"
+"See the 'Note about fast-forwards' in 'git push --help' for details."
+msgstr ""
+"Gli aggiornamenti sono stati rifiutati perché l'ultimo commit del branch\n"
+"attuale è rimasto indietro rispetto alla sua controparte remota.\n"
+"Integra le modifiche remote (ad es. con 'git pull ...') prima di\n"
+"eseguire nuovamente il push.\n"
+"Vedi la 'Nota sui fast forward' in 'git push --help' per ulteriori\n"
+"dettagli."
+
+#: builtin/push.c:283
+msgid ""
+"Updates were rejected because a pushed branch tip is behind its remote\n"
+"counterpart. Check out this branch and integrate the remote changes\n"
+"(e.g. 'git pull ...') before pushing again.\n"
+"See the 'Note about fast-forwards' in 'git push --help' for details."
+msgstr ""
+"Gli aggiornamenti sono stati rifiutati perché l'ultimo commit di un\n"
+"branch di cui è stato eseguito il push è rimasto indietro rispetto\n"
+"alla sua controparte remota. Esegui il checkout di questo branch e\n"
+"integra le modifiche remote (ad es. con 'git pull ...') prima di\n"
+"eseguire nuovamente il push.\n"
+"Vedi la 'Nota sui fast forward' in 'git push --help' per ulteriori\n"
+"dettagli."
+
+#: builtin/push.c:289
+msgid ""
+"Updates were rejected because the remote contains work that you do\n"
+"not have locally. This is usually caused by another repository pushing\n"
+"to the same ref. You may want to first integrate the remote changes\n"
+"(e.g., 'git pull ...') before pushing again.\n"
+"See the 'Note about fast-forwards' in 'git push --help' for details."
+msgstr ""
+"Gli aggiornamenti sono stati rifiutati perché il remoto contiene delle\n"
+"modifiche che non hai localmente. Ciò solitamente è causato da un push\n"
+"da un altro repository allo stesso riferimento. Potresti voler integrare\n"
+"le modifiche remote (ad es. con 'git pull ...') prima di eseguire\n"
+"nuovamente il push.\n"
+"Vedi la 'Nota sui fast forward' in 'git push --help' per ulteriori\n"
+"dettagli."
+
+#: builtin/push.c:296
+msgid "Updates were rejected because the tag already exists in the remote."
+msgstr ""
+"Gli aggiornamenti sono stati rifiutati perché il tag esiste già nel remoto."
+
+#: builtin/push.c:299
+msgid ""
+"You cannot update a remote ref that points at a non-commit object,\n"
+"or update a remote ref to make it point at a non-commit object,\n"
+"without using the '--force' option.\n"
+msgstr ""
+"Non puoi aggiornare un riferimento remoto che punta a un oggetto\n"
+"diverso da un commit o aggiornare un riferimento remoto per farlo\n"
+"puntare a un oggetto diverso da un commit senza usare l'opzione\n"
+"'--force'.\n"
+
+#: builtin/push.c:360
+#, c-format
+msgid "Pushing to %s\n"
+msgstr "Push su %s in corso\n"
+
+#: builtin/push.c:367
+#, c-format
+msgid "failed to push some refs to '%s'"
+msgstr "push di alcuni riferimenti su '%s' non riuscito"
+
+#: builtin/push.c:542
+msgid "repository"
+msgstr "repository"
+
+#: builtin/push.c:543 builtin/send-pack.c:164
+msgid "push all refs"
+msgstr "esegui il push di tutti i riferimenti"
+
+#: builtin/push.c:544 builtin/send-pack.c:166
+msgid "mirror all refs"
+msgstr "esegui il mirror di tutti i riferimenti"
+
+#: builtin/push.c:546
+msgid "delete refs"
+msgstr "elimina riferimenti"
+
+#: builtin/push.c:547
+msgid "push tags (can't be used with --all or --mirror)"
+msgstr "esegui il push dei tag (non può essere usato con --all o --mirror)"
+
+#: builtin/push.c:550 builtin/send-pack.c:167
+msgid "force updates"
+msgstr "forza gli aggiornamenti"
+
+#: builtin/push.c:552 builtin/send-pack.c:181
+msgid "<refname>:<expect>"
+msgstr "<nome riferimento>:<valore atteso>"
+
+#: builtin/push.c:553 builtin/send-pack.c:182
+msgid "require old value of ref to be at this value"
+msgstr ""
+"richiedi che il vecchio valore del riferimento corrisponda a questo valore"
+
+#: builtin/push.c:556
+msgid "control recursive pushing of submodules"
+msgstr "controlla il push ricorsivo dei sottomoduli"
+
+#: builtin/push.c:558 builtin/send-pack.c:175
+msgid "use thin pack"
+msgstr "usa un thin pack"
+
+#: builtin/push.c:559 builtin/push.c:560 builtin/send-pack.c:161
+#: builtin/send-pack.c:162
+msgid "receive pack program"
+msgstr "programma ricezione pack"
+
+#: builtin/push.c:561
+msgid "set upstream for git pull/status"
+msgstr "imposta l'upstream per git pull/status"
+
+#: builtin/push.c:564
+msgid "prune locally removed refs"
+msgstr "elimina i riferimenti rimossi localmente"
+
+#: builtin/push.c:566
+msgid "bypass pre-push hook"
+msgstr "ignora l'hook pre-push"
+
+#: builtin/push.c:567
+msgid "push missing but relevant tags"
+msgstr "esegui il push dei tag mancanti ma rilevanti"
+
+#: builtin/push.c:570 builtin/send-pack.c:169
+msgid "GPG sign the push"
+msgstr "firma il push con GPG"
+
+#: builtin/push.c:572 builtin/send-pack.c:176
+msgid "request atomic transaction on remote side"
+msgstr "richiedi l'atomicità della transazione al remoto"
+
+#: builtin/push.c:590
+msgid "--delete is incompatible with --all, --mirror and --tags"
+msgstr "--delete non è compatibile con --all, --mirror e --tags"
+
+#: builtin/push.c:592
+msgid "--delete doesn't make sense without any refs"
+msgstr "--delete non ha senso senza alcun ref"
+
+#: builtin/push.c:612
+#, c-format
+msgid "bad repository '%s'"
+msgstr "repository '%s' errato"
+
+#: builtin/push.c:613
+msgid ""
+"No configured push destination.\n"
+"Either specify the URL from the command-line or configure a remote "
+"repository using\n"
+"\n"
+"    git remote add <name> <url>\n"
+"\n"
+"and then push using the remote name\n"
+"\n"
+"    git push <name>\n"
+msgstr ""
+"Nessuna destinazione per il push configurata.\n"
+"Specifica un URL dalla riga di comando oppure configurare un repository "
+"remoto usando\n"
+"\n"
+"    git remote add <nome> <url>\n"
+"\n"
+"e poi eseguire il push usando il nome del remote\n"
+"\n"
+"    git push <nome>\n"
+
+#: builtin/push.c:628
+msgid "--all and --tags are incompatible"
+msgstr "--all e --tags non sono compatibili"
+
+#: builtin/push.c:630
+msgid "--all can't be combined with refspecs"
+msgstr "--all non può essere combinato con degli specificatori riferimento"
+
+#: builtin/push.c:634
+msgid "--mirror and --tags are incompatible"
+msgstr "--mirror e --tags non sono compatibili"
+
+#: builtin/push.c:636
+msgid "--mirror can't be combined with refspecs"
+msgstr "--mirror non può essere combinato con degli specificatori riferimento"
+
+#: builtin/push.c:639
+msgid "--all and --mirror are incompatible"
+msgstr "--all e --mirror non sono compatibili"
+
+#: builtin/push.c:643
+msgid "push options must not have new line characters"
+msgstr "le opzioni push non devono avere caratteri di fine riga"
+
+#: builtin/range-diff.c:8
+msgid "git range-diff [<options>] <old-base>..<old-tip> <new-base>..<new-tip>"
+msgstr ""
+"git range-diff [<opzioni>] <vecchia base>..<vecchio ultimo commit> <nuova "
+"base>..<nuovo ultimo commit>"
+
+#: builtin/range-diff.c:9
+msgid "git range-diff [<options>] <old-tip>...<new-tip>"
+msgstr ""
+"git range-diff [<opzioni>] <vecchio ultimo commit>...<nuovo ultimo commit>"
+
+#: builtin/range-diff.c:10
+msgid "git range-diff [<options>] <base> <old-tip> <new-tip>"
+msgstr ""
+"git range-diff [<opzioni>] <base> <vecchio ultimo commit> <nuovo ultimo "
+"commit>"
+
+#: builtin/range-diff.c:22
+msgid "Percentage by which creation is weighted"
+msgstr "Percentuale in base a cui viene pesata la creazione"
+
+#: builtin/range-diff.c:24
+msgid "use simple diff colors"
+msgstr "usa colori semplici per il diff"
+
+#: builtin/range-diff.c:26
+msgid "notes"
+msgstr "note"
+
+#: builtin/range-diff.c:26
+msgid "passed to 'git log'"
+msgstr "passato a 'git log'"
+
+#: builtin/range-diff.c:50 builtin/range-diff.c:54
+#, c-format
+msgid "no .. in range: '%s'"
+msgstr "nessun .. nell'intervallo: '%s'"
+
+#: builtin/range-diff.c:64
+msgid "single arg format must be symmetric range"
+msgstr "il formato dell'unico argomento dev'essere un intervallo simmetrico"
+
+#: builtin/range-diff.c:79
+msgid "need two commit ranges"
+msgstr "devono essere specificati due intervalli commit"
+
+#: builtin/read-tree.c:41
+msgid ""
+"git read-tree [(-m [--trivial] [--aggressive] | --reset | --prefix=<prefix>) "
+"[-u [--exclude-per-directory=<gitignore>] | -i]] [--no-sparse-checkout] [--"
+"index-output=<file>] (--empty | <tree-ish1> [<tree-ish2> [<tree-ish3>]])"
+msgstr ""
+"git read-tree [(-m [--trivial] [--aggressive] | --reset | --"
+"prefix=<prefisso>) [-u [--exclude-per-directory=<gitignore>] | -i]] [--no-"
+"sparse-checkout] [--index-output=<file>] (--empty | <espressione albero 1> "
+"[<espressione albero 2> [<espressione albero 3>]])"
+
+#: builtin/read-tree.c:124
+msgid "write resulting index to <file>"
+msgstr "scrivi l'indice risultante in <file>"
+
+#: builtin/read-tree.c:127
+msgid "only empty the index"
+msgstr "svuota solo l'indice"
+
+#: builtin/read-tree.c:129
+msgid "Merging"
+msgstr "Merge"
+
+#: builtin/read-tree.c:131
+msgid "perform a merge in addition to a read"
+msgstr "esegui il merge oltre a una lettura"
+
+#: builtin/read-tree.c:133
+msgid "3-way merge if no file level merging required"
+msgstr "merge a tre vie se non sono richiesti merge a livello di file"
+
+#: builtin/read-tree.c:135
+msgid "3-way merge in presence of adds and removes"
+msgstr "merge a tre vie se sono presenti aggiunte ed eliminazioni"
+
+#: builtin/read-tree.c:137
+msgid "same as -m, but discard unmerged entries"
+msgstr "come -m, ma scarta le voci non sottoposte a merge"
+
+#: builtin/read-tree.c:138
+msgid "<subdirectory>/"
+msgstr "<sottodirectory>/"
+
+#: builtin/read-tree.c:139
+msgid "read the tree into the index under <subdirectory>/"
+msgstr "leggi l'albero nell'indice in <sottodirectory>/"
+
+#: builtin/read-tree.c:142
+msgid "update working tree with merge result"
+msgstr "aggiorna l'albero di lavoro con il risultato del merge"
+
+#: builtin/read-tree.c:144
+msgid "gitignore"
+msgstr "gitignore"
+
+#: builtin/read-tree.c:145
+msgid "allow explicitly ignored files to be overwritten"
+msgstr "consenti la sovrascrittura dei file ignorati esplicitamente"
+
+#: builtin/read-tree.c:148
+msgid "don't check the working tree after merging"
+msgstr "non controllare l'albero di lavoro dopo il merge"
+
+#: builtin/read-tree.c:149
+msgid "don't update the index or the work tree"
+msgstr "non aggiornare l'indice o l'albero di lavoro"
+
+#: builtin/read-tree.c:151
+msgid "skip applying sparse checkout filter"
+msgstr "salta l'applicazione del filtro checkout sparse"
+
+#: builtin/read-tree.c:153
+msgid "debug unpack-trees"
+msgstr "esegui il debug di unpack-trees"
+
+#: builtin/read-tree.c:157
+msgid "suppress feedback messages"
+msgstr "non visualizzare i messaggi di feedback"
+
+#: builtin/read-tree.c:188
+msgid "You need to resolve your current index first"
+msgstr "Prima devi risolvere l'indice corrente"
+
+#: builtin/rebase.c:32
+msgid ""
+"git rebase [-i] [options] [--exec <cmd>] [--onto <newbase> | --keep-base] "
+"[<upstream> [<branch>]]"
+msgstr ""
+"git rebase [-i] [opzioni] [--exec <comando>] [--onto <nuova base> | --keep-"
+"base] [<upstream> [<branch>]]"
+
+#: builtin/rebase.c:34
+msgid ""
+"git rebase [-i] [options] [--exec <cmd>] [--onto <newbase>] --root [<branch>]"
+msgstr ""
+"git rebase [-i] [options] [--exec <comando>] [--onto <nuova base>] --root "
+"[<branch>]"
+
+#: builtin/rebase.c:36
+msgid "git rebase --continue | --abort | --skip | --edit-todo"
+msgstr "git rebase --continue | --abort | --skip | --edit-todo"
+
+#: builtin/rebase.c:177 builtin/rebase.c:201 builtin/rebase.c:228
+#, c-format
+msgid "unusable todo list: '%s'"
+msgstr "elenco todo inutilizzabile: '%s'"
+
+#: builtin/rebase.c:186 builtin/rebase.c:212 builtin/rebase.c:236
+#, c-format
+msgid "could not write '%s'."
+msgstr "impossibile scrivere '%s'."
+
+#: builtin/rebase.c:271
+msgid "no HEAD?"
+msgstr "nessun'HEAD?"
+
+#: builtin/rebase.c:298
+#, c-format
+msgid "could not create temporary %s"
+msgstr "impossibile creare un %s temporaneo"
+
+#: builtin/rebase.c:304
+msgid "could not mark as interactive"
+msgstr "impossibile contrassegnare come interattivo"
+
+#: builtin/rebase.c:362
+msgid "could not generate todo list"
+msgstr "impossibile generare l'elenco todo"
+
+#: builtin/rebase.c:402
+msgid "a base commit must be provided with --upstream or --onto"
+msgstr ""
+"le opzioni --upstream o --onto richiedono che sia fornito un commit di base"
+
+#: builtin/rebase.c:457
+msgid "git rebase--interactive [<options>]"
+msgstr "git rebase --interactive [<opzioni>]"
+
+#: builtin/rebase.c:469
+msgid "keep empty commits"
+msgstr "mantieni i commit vuoti"
+
+#: builtin/rebase.c:471 builtin/revert.c:128
+msgid "allow commits with empty messages"
+msgstr "consenti commit con messaggi vuoti"
+
+#: builtin/rebase.c:472
+msgid "rebase merge commits"
+msgstr "esegui il rebase dei commit di merge"
+
+#: builtin/rebase.c:474
+msgid "keep original branch points of cousins"
+msgstr "mantieni i punti di branch originali dei cugini"
+
+#: builtin/rebase.c:476
+msgid "move commits that begin with squash!/fixup!"
+msgstr "sposta i commit che iniziano con squash!/fixup!"
+
+#: builtin/rebase.c:477
+msgid "sign commits"
+msgstr "firma i commit"
+
+#: builtin/rebase.c:479 builtin/rebase.c:1455
+msgid "display a diffstat of what changed upstream"
+msgstr "visualizza un diffstat delle modifiche upstream"
+
+#: builtin/rebase.c:481
+msgid "continue rebase"
+msgstr "continua il rebase"
+
+#: builtin/rebase.c:483
+msgid "skip commit"
+msgstr "salta il commit"
+
+#: builtin/rebase.c:484
+msgid "edit the todo list"
+msgstr "modifica l'elenco todo"
+
+#: builtin/rebase.c:486
+msgid "show the current patch"
+msgstr "visualizza la patch corrente"
+
+#: builtin/rebase.c:489
+msgid "shorten commit ids in the todo list"
+msgstr "abbrevia gli ID dei commit nell'elenco todo"
+
+#: builtin/rebase.c:491
+msgid "expand commit ids in the todo list"
+msgstr "espandi gli ID dei commit nell'elenco todo"
+
+#: builtin/rebase.c:493
+msgid "check the todo list"
+msgstr "controlla l'elenco todo"
+
+#: builtin/rebase.c:495
+msgid "rearrange fixup/squash lines"
+msgstr "ridisponi le righe fixup/squash"
+
+#: builtin/rebase.c:497
+msgid "insert exec commands in todo list"
+msgstr "inserisci i comandi exec nell'elenco todo"
+
+#: builtin/rebase.c:498
+msgid "onto"
+msgstr "su"
+
+#: builtin/rebase.c:501
+msgid "restrict-revision"
+msgstr "revisioni-limite"
+
+#: builtin/rebase.c:501
+msgid "restrict revision"
+msgstr "limita la revisione"
+
+#: builtin/rebase.c:503
+msgid "squash-onto"
+msgstr "squash-su"
+
+#: builtin/rebase.c:504
+msgid "squash onto"
+msgstr "esegui lo squash su"
+
+#: builtin/rebase.c:506
+msgid "the upstream commit"
+msgstr "il commit upstream"
+
+#: builtin/rebase.c:508
+msgid "head-name"
+msgstr "nome head"
+
+#: builtin/rebase.c:508
+msgid "head name"
+msgstr "nome head"
+
+#: builtin/rebase.c:513
+msgid "rebase strategy"
+msgstr "strategia di rebase"
+
+#: builtin/rebase.c:514
+msgid "strategy-opts"
+msgstr "opzioni strategia"
+
+#: builtin/rebase.c:515
+msgid "strategy options"
+msgstr "opzioni strategia"
+
+#: builtin/rebase.c:516
+msgid "switch-to"
+msgstr "passa a"
+
+#: builtin/rebase.c:517
+msgid "the branch or commit to checkout"
+msgstr "il branch o il commit di cui eseguire il checkout"
+
+#: builtin/rebase.c:518
+msgid "onto-name"
+msgstr "nome"
+
+#: builtin/rebase.c:518
+msgid "onto name"
+msgstr "sul nome"
+
+#: builtin/rebase.c:519
+msgid "cmd"
+msgstr "comando"
+
+#: builtin/rebase.c:519
+msgid "the command to run"
+msgstr "il comando da eseguire"
+
+#: builtin/rebase.c:522 builtin/rebase.c:1540
+msgid "automatically re-schedule any `exec` that fails"
+msgstr "schedula nuovamente le operazioni `exec` non riuscite automaticamente"
+
+#: builtin/rebase.c:540
+msgid "--[no-]rebase-cousins has no effect without --rebase-merges"
+msgstr "--[no-]rebase-cousins non ha effetto senza --rebase-merges"
+
+#: builtin/rebase.c:556
+#, c-format
+msgid "%s requires an interactive rebase"
+msgstr "%s richiede un rebase interattivo"
+
+#: builtin/rebase.c:608
+#, c-format
+msgid "could not get 'onto': '%s'"
+msgstr "impossibile ottenere 'onto': '%s'"
+
+#: builtin/rebase.c:623
+#, c-format
+msgid "invalid orig-head: '%s'"
+msgstr "orig-head non valida: '%s'"
+
+#: builtin/rebase.c:648
+#, c-format
+msgid "ignoring invalid allow_rerere_autoupdate: '%s'"
+msgstr "ignoro il valore non valido per allow_rerere_autoupdate: '%s'"
+
+#: builtin/rebase.c:724
+#, c-format
+msgid "Could not read '%s'"
+msgstr "Impossibile leggere '%s'"
+
+#: builtin/rebase.c:742
+#, c-format
+msgid "Cannot store %s"
+msgstr "Impossibile memorizzare %s"
+
+#: builtin/rebase.c:849
+msgid "could not determine HEAD revision"
+msgstr "impossibile determinare la revisione HEAD"
+
+#: builtin/rebase.c:972 git-rebase--preserve-merges.sh:81
+msgid ""
+"Resolve all conflicts manually, mark them as resolved with\n"
+"\"git add/rm <conflicted_files>\", then run \"git rebase --continue\".\n"
+"You can instead skip this commit: run \"git rebase --skip\".\n"
+"To abort and get back to the state before \"git rebase\", run \"git rebase --"
+"abort\"."
+msgstr ""
+"Risolvi manualmente tutti i conflitti, contrassegnali come\n"
+"risolti con \"git add/rm <file in conflitto>\", quindi esegui\n"
+"\"git rebase --continue\".\n"
+"In alternativa, puoi saltare questo commit: esegui \"git rebase\n"
+"--skip\".\n"
+"Per interrompere l'operazione e tornare allo stato precedente\n"
+"il \"git rebase\", esegui \"git rebase --abort\"."
+
+#: builtin/rebase.c:1060
+#, c-format
+msgid ""
+"\n"
+"git encountered an error while preparing the patches to replay\n"
+"these revisions:\n"
+"\n"
+"    %s\n"
+"\n"
+"As a result, git cannot rebase them."
+msgstr ""
+"\n"
+"Git ha riscontrato un errore durante la preparazione delle patch\n"
+"per applicare nuovamente queste revisioni:\n"
+"\n"
+"    %s\n"
+"\n"
+"Di conseguenza, Git non può eseguirne il rebase."
+
+#: builtin/rebase.c:1367
+#, c-format
+msgid ""
+"%s\n"
+"Please specify which branch you want to rebase against.\n"
+"See git-rebase(1) for details.\n"
+"\n"
+"    git rebase '<branch>'\n"
+"\n"
+msgstr ""
+"%s\n"
+"Specifica il branch su cui effettuare il rebase.\n"
+"Vedi git-rebase(1) per i dettagli.\n"
+"\n"
+"    git rebase '<branch>'\n"
+"\n"
+
+#: builtin/rebase.c:1383
+#, c-format
+msgid ""
+"If you wish to set tracking information for this branch you can do so with:\n"
+"\n"
+"    git branch --set-upstream-to=%s/<branch> %s\n"
+"\n"
+msgstr ""
+"Se vuoi impostare le informazioni di tracciamento per questo branch puoi "
+"farlo con:\n"
+"\n"
+"    git branch --set-upstream-to=%s/<branch> %s\n"
+"\n"
+
+#: builtin/rebase.c:1413
+msgid "exec commands cannot contain newlines"
+msgstr "i comandi exec non possono contenere caratteri di fine riga"
+
+#: builtin/rebase.c:1417
+msgid "empty exec command"
+msgstr "comando exec vuoto"
+
+#: builtin/rebase.c:1446
+msgid "rebase onto given branch instead of upstream"
+msgstr "esegui il rebase sul branch specificato anziché su quello upstream"
+
+#: builtin/rebase.c:1448
+msgid "use the merge-base of upstream and branch as the current base"
+msgstr "usa la base del merge dell'upstream e del branch come base corrente"
+
+#: builtin/rebase.c:1450
+msgid "allow pre-rebase hook to run"
+msgstr "consenti l'esecuzione dell'hook pre-rebase"
+
+#: builtin/rebase.c:1452
+msgid "be quiet. implies --no-stat"
+msgstr "sii silenzioso. implica --no-stat"
+
+#: builtin/rebase.c:1458
+msgid "do not show diffstat of what changed upstream"
+msgstr "non visualizzare un diffstat delle modifiche upstream"
+
+#: builtin/rebase.c:1461
+msgid "add a Signed-off-by: line to each commit"
+msgstr "aggiungi una riga Signed-off-by: a ogni commit"
+
+#: builtin/rebase.c:1464
+msgid "make committer date match author date"
+msgstr ""
+"fai corrispondere la data della persona che ha eseguito il commit alla data"
+" autore"
+
+#: builtin/rebase.c:1466
+msgid "ignore author date and use current date"
+msgstr "ignora la data autore e usa la data corrente"
+
+#: builtin/rebase.c:1468
+msgid "synonym of --reset-author-date"
+msgstr "sinonimo di --reset-author-date"
+
+#: builtin/rebase.c:1470 builtin/rebase.c:1474
+msgid "passed to 'git apply'"
+msgstr "passato a 'git apply'"
+
+#: builtin/rebase.c:1472
+msgid "ignore changes in whitespace"
+msgstr "ignora modifiche agli spazi bianchi"
+
+#: builtin/rebase.c:1476 builtin/rebase.c:1479
+msgid "cherry-pick all commits, even if unchanged"
+msgstr "esegui il cherry-pick di tutti i commit, anche se non modificati"
+
+#: builtin/rebase.c:1481
+msgid "continue"
+msgstr "continua"
+
+#: builtin/rebase.c:1484
+msgid "skip current patch and continue"
+msgstr "salta la patch corrente e continua"
+
+#: builtin/rebase.c:1486
+msgid "abort and check out the original branch"
+msgstr "interrompi ed esegui il checkout del branch originario"
+
+#: builtin/rebase.c:1489
+msgid "abort but keep HEAD where it is"
+msgstr "interrompi ma mantieni l'HEAD dov'è"
+
+#: builtin/rebase.c:1490
+msgid "edit the todo list during an interactive rebase"
+msgstr "modifica l'elenco todo durante un rebase interattivo"
+
+#: builtin/rebase.c:1493
+msgid "show the patch file being applied or merged"
+msgstr ""
+"visualizza il file patch che sta per essere applicato o sottoposto a merge"
+
+#: builtin/rebase.c:1496
+msgid "use merging strategies to rebase"
+msgstr "usa le strategie di merge per eseguire il rebase"
+
+#: builtin/rebase.c:1500
+msgid "let the user edit the list of commits to rebase"
+msgstr ""
+"consenti all'utente di modificare l'elenco dei commit di cui eseguire il "
+"rebase"
+
+#: builtin/rebase.c:1504
+msgid "(DEPRECATED) try to recreate merges instead of ignoring them"
+msgstr "(DEPRECATO) prova a ricreare i merge anziché ignorarli"
+
+#: builtin/rebase.c:1509
+msgid "preserve empty commits during rebase"
+msgstr "mantieni i commit vuoti durante il rebase"
+
+#: builtin/rebase.c:1511
+msgid "move commits that begin with squash!/fixup! under -i"
+msgstr "sposta i commit che iniziano con squash!/fixup! in -i"
+
+#: builtin/rebase.c:1517
+msgid "automatically stash/stash pop before and after"
+msgstr "esegui stash/stash pop automaticamente prima e dopo"
+
+#: builtin/rebase.c:1519
+msgid "add exec lines after each commit of the editable list"
+msgstr "aggiungi righe exec dopo ogni commit della lista modificabile"
+
+#: builtin/rebase.c:1523
+msgid "allow rebasing commits with empty messages"
+msgstr "consenti il rebase di commit con messaggi vuoti"
+
+#: builtin/rebase.c:1526
+msgid "try to rebase merges instead of skipping them"
+msgstr "prova ad eseguire il rebase dei merge anziché saltarli"
+
+#: builtin/rebase.c:1529
+msgid "use 'merge-base --fork-point' to refine upstream"
+msgstr ""
+"usa 'merge-base --fork-point' per ridefinire più precisamente l'upstream"
+
+#: builtin/rebase.c:1531
+msgid "use the given merge strategy"
+msgstr "usa la strategia di merge specificata"
+
+#: builtin/rebase.c:1533 builtin/revert.c:115
+msgid "option"
+msgstr "opzione"
+
+#: builtin/rebase.c:1534
+msgid "pass the argument through to the merge strategy"
+msgstr "passa l'argomento alla strategia di merge"
+
+#: builtin/rebase.c:1537
+msgid "rebase all reachable commits up to the root(s)"
+msgstr "esegui il rebase di tutti i commit raggiungibili fino a quelli radice"
+
+#: builtin/rebase.c:1554
+msgid ""
+"the rebase.useBuiltin support has been removed!\n"
+"See its entry in 'git help config' for details."
+msgstr ""
+"il supporto per rebase.useBuiltin è stato rimosso!\n"
+"Vedi la voce relativa in 'git help config' per i dettagli."
+
+#: builtin/rebase.c:1560
+msgid "It looks like 'git am' is in progress. Cannot rebase."
+msgstr "Sembra che 'git am' sia in corso. Impossibile eseguire il rebase."
+
+#: builtin/rebase.c:1601
+msgid ""
+"git rebase --preserve-merges is deprecated. Use --rebase-merges instead."
+msgstr "git rebase --preserve-merges è deprecato. Usa --rebase-merges."
+
+#: builtin/rebase.c:1606
+msgid "cannot combine '--keep-base' with '--onto'"
+msgstr "impossibile combinare '--keep-base' con '--onto'"
+
+#: builtin/rebase.c:1608
+msgid "cannot combine '--keep-base' with '--root'"
+msgstr "impossibile combinare '--keep-base' con '--root'"
+
+#: builtin/rebase.c:1612
+msgid "No rebase in progress?"
+msgstr "Nessun rebase in corso?"
+
+#: builtin/rebase.c:1616
+msgid "The --edit-todo action can only be used during interactive rebase."
+msgstr ""
+"L'azione --edit-todo può essere usata solo durante un rebase interattivo."
+
+#: builtin/rebase.c:1639
+msgid "Cannot read HEAD"
+msgstr "Impossibile leggere l'HEAD"
+
+#: builtin/rebase.c:1651
+msgid ""
+"You must edit all merge conflicts and then\n"
+"mark them as resolved using git add"
+msgstr ""
+"Devi modificare tutti i conflitti di merge e\n"
+"quindi contrassegnarli come risolti usando\n"
+"git add"
+
+#: builtin/rebase.c:1670
+msgid "could not discard worktree changes"
+msgstr "impossibile scartare le modifiche all'albero di lavoro"
+
+#: builtin/rebase.c:1689
+#, c-format
+msgid "could not move back to %s"
+msgstr "impossibile ritornare a %s"
+
+#: builtin/rebase.c:1734
+#, c-format
+msgid ""
+"It seems that there is already a %s directory, and\n"
+"I wonder if you are in the middle of another rebase.  If that is the\n"
+"case, please try\n"
+"\t%s\n"
+"If that is not the case, please\n"
+"\t%s\n"
+"and run me again.  I am stopping in case you still have something\n"
+"valuable there.\n"
+msgstr ""
+"Sembra che esista già una directory %s e mi domando\n"
+"se tu sia già nel bel mezzo di un altro rebase. Se questo è il caso,\n"
+"prova con il comando\n"
+"\t%s\n"
+"Se questo non è il caso, esegui\n"
+"\t%s\n"
+"ed eseguimi di nuovo. Mi fermo nel caso in cui tu abbia ancora\n"
+"salvato qualcosa di importante lì.\n"
+
+#: builtin/rebase.c:1757
+msgid "switch `C' expects a numerical value"
+msgstr "l'opzione `C` richiede un valore numerico"
+
+#: builtin/rebase.c:1798
+#, c-format
+msgid "Unknown mode: %s"
+msgstr "Modo sconosciuto: %s"
+
+#: builtin/rebase.c:1820
+msgid "--strategy requires --merge or --interactive"
+msgstr "--strategy richiede --merge o --interactive"
+
+#: builtin/rebase.c:1860
+msgid "--reschedule-failed-exec requires --exec or --interactive"
+msgstr "--reschedule-failed-exec richiede --exec o --interactive"
+
+#: builtin/rebase.c:1872
+msgid "cannot combine am options with either interactive or merge options"
+msgstr "non è possibile combinare le opzioni am con quelle interactive o merge"
+
+#: builtin/rebase.c:1891
+msgid "cannot combine '--preserve-merges' with '--rebase-merges'"
+msgstr "impossibile combinare '--preserve-merges' con '--rebase-merges'"
+
+#: builtin/rebase.c:1895
+msgid ""
+"error: cannot combine '--preserve-merges' with '--reschedule-failed-exec'"
+msgstr ""
+"errore: impossibile combinare '--preserve-merges' con '--reschedule-failed-"
+"exec'"
+
+#: builtin/rebase.c:1919
+#, c-format
+msgid "invalid upstream '%s'"
+msgstr "upstream non valido: '%s'"
+
+#: builtin/rebase.c:1925
+msgid "Could not create new root commit"
+msgstr "Impossibile creare il nuovo commit radice"
+
+#: builtin/rebase.c:1951
+#, c-format
+msgid "'%s': need exactly one merge base with branch"
+msgstr ""
+"'%s': è necessario specificare esattamente una base per il merge con il "
+"branch"
+
+#: builtin/rebase.c:1954
+#, c-format
+msgid "'%s': need exactly one merge base"
+msgstr "'%s': è necessario specificare esattamente una base per il merge"
+
+#: builtin/rebase.c:1962
+#, c-format
+msgid "Does not point to a valid commit '%s'"
+msgstr "'%s' non punta a un commit valido"
+
+#: builtin/rebase.c:1987
+#, c-format
+msgid "fatal: no such branch/commit '%s'"
+msgstr "errore fatale: branch/commit '%s' inesistente"
+
+#: builtin/rebase.c:1995 builtin/submodule--helper.c:40
+#: builtin/submodule--helper.c:1961
+#, c-format
+msgid "No such ref: %s"
+msgstr "Riferimento non esistente: %s"
+
+#: builtin/rebase.c:2006
+msgid "Could not resolve HEAD to a revision"
+msgstr "Impossibile risolvere HEAD come revisione"
+
+#: builtin/rebase.c:2044
+msgid "Cannot autostash"
+msgstr "Impossibile eseguire lo stash automatico"
+
+#: builtin/rebase.c:2047
+#, c-format
+msgid "Unexpected stash response: '%s'"
+msgstr "Risposta stash non attesa: '%s'"
+
+#: builtin/rebase.c:2053
+#, c-format
+msgid "Could not create directory for '%s'"
+msgstr "Impossibile creare la directory '%s'"
+
+#: builtin/rebase.c:2056
+#, c-format
+msgid "Created autostash: %s\n"
+msgstr "Stash automatico creato: %s\n"
+
+#: builtin/rebase.c:2059
+msgid "could not reset --hard"
+msgstr "impossibile eseguire reset --hard"
+
+#: builtin/rebase.c:2068
+msgid "Please commit or stash them."
+msgstr "Eseguine il commit o lo stash."
+
+#: builtin/rebase.c:2095
+#, c-format
+msgid "could not parse '%s'"
+msgstr "impossibile analizzare '%s'"
+
+#: builtin/rebase.c:2108
+#, c-format
+msgid "could not switch to %s"
+msgstr "impossibile passare a %s"
+
+#: builtin/rebase.c:2119
+msgid "HEAD is up to date."
+msgstr "HEAD è aggiornato."
+
+#: builtin/rebase.c:2121
+#, c-format
+msgid "Current branch %s is up to date.\n"
+msgstr "Il branch corrente %s è aggiornato.\n"
+
+#: builtin/rebase.c:2129
+msgid "HEAD is up to date, rebase forced."
+msgstr "HEAD è aggiornato, forzo il rebase."
+
+#: builtin/rebase.c:2131
+#, c-format
+msgid "Current branch %s is up to date, rebase forced.\n"
+msgstr "Il branch corrente %s è aggiornato, forzo il rebase.\n"
+
+#: builtin/rebase.c:2139
+msgid "The pre-rebase hook refused to rebase."
+msgstr "L'hook pre-rebase ha rifiutato di consentire il rebase."
+
+#: builtin/rebase.c:2146
+#, c-format
+msgid "Changes to %s:\n"
+msgstr "Modifiche a %s:\n"
+
+#: builtin/rebase.c:2149
+#, c-format
+msgid "Changes from %s to %s:\n"
+msgstr "Modifiche da %s a %s:\n"
+
+#: builtin/rebase.c:2174
+#, c-format
+msgid "First, rewinding head to replay your work on top of it...\n"
+msgstr ""
+"Per prima cosa, ripristino l'head per riapplicare le tue modifiche su di "
+"esso...\n"
+
+#: builtin/rebase.c:2183
+msgid "Could not detach HEAD"
+msgstr "Impossibile scollegare l'HEAD"
+
+#: builtin/rebase.c:2192
+#, c-format
+msgid "Fast-forwarded %s to %s.\n"
+msgstr "Fast forward da %s a %s eseguito.\n"
+
+#: builtin/receive-pack.c:32
+msgid "git receive-pack <git-dir>"
+msgstr "git receive-pack <directory Git>"
+
+#: builtin/receive-pack.c:830
+msgid ""
+"By default, updating the current branch in a non-bare repository\n"
+"is denied, because it will make the index and work tree inconsistent\n"
+"with what you pushed, and will require 'git reset --hard' to match\n"
+"the work tree to HEAD.\n"
+"\n"
+"You can set the 'receive.denyCurrentBranch' configuration variable\n"
+"to 'ignore' or 'warn' in the remote repository to allow pushing into\n"
+"its current branch; however, this is not recommended unless you\n"
+"arranged to update its work tree to match what you pushed in some\n"
+"other way.\n"
+"\n"
+"To squelch this message and still keep the default behaviour, set\n"
+"'receive.denyCurrentBranch' configuration variable to 'refuse'."
+msgstr ""
+"Per impostazione predefinita, l'aggiornamento del branch corrente\n"
+"in un repository non spoglio è negato, perché renderebbe l'indice\n"
+"e l'albero di lavoro inconsistenti con i dati di cui si è eseguito\n"
+"il push e richiederebbe 'git reset --hard' per ripristinare la\n"
+"corrispondenza dell'albero di lavoro con HEAD.\n"
+"\n"
+"Puoi impostare la variabile di configurazione\n"
+"'receive.denyCurrentBranch' a 'ignore' o 'warn' nel repository\n"
+"remoto per consentire il push nel branch corrente; ciò nonostante,\n"
+"questo non è raccomandato a meno che tu non provveda ad aggiornare\n"
+"il suo albero di lavoro in modo che corrisponda a ciò di cui hai\n"
+"eseguito il push in qualche altro modo.\n"
+"\n"
+"Per non visualizzare più questo messaggio e mantenere comunque\n"
+"il comportamento predefinito, imposta la variabile di\n"
+"configurazione 'receive.denyCurrentBranch' a 'refuse'."
+
+#: builtin/receive-pack.c:850
+msgid ""
+"By default, deleting the current branch is denied, because the next\n"
+"'git clone' won't result in any file checked out, causing confusion.\n"
+"\n"
+"You can set 'receive.denyDeleteCurrent' configuration variable to\n"
+"'warn' or 'ignore' in the remote repository to allow deleting the\n"
+"current branch, with or without a warning message.\n"
+"\n"
+"To squelch this message, you can set it to 'refuse'."
+msgstr ""
+"Per impostazione predefinita, l'eliminazione del branch corrente\n"
+"è negata, perché il prossimo 'git clone' farebbe sì che non venga\n"
+"eseguito il checkout di nessun file, causando confusione.\n"
+"\n"
+"Puoi impostare la variabile di configurazione\n"
+"'receive.denyDeleteCurrent' a 'warn' o 'ignore' nel repository\n"
+"remoto per consentire l'eliminazione del branch corrente, con o\n"
+"senza un messaggio d'avviso.\n"
+"\n"
+"Per non visualizzare più questo messaggio, puoi impostarla a\n"
+"'refuse'."
+
+#: builtin/receive-pack.c:1936
+msgid "quiet"
+msgstr "non visualizzare messaggi"
+
+#: builtin/receive-pack.c:1950
+msgid "You must specify a directory."
+msgstr "Devi specificare una directory."
+
+#: builtin/reflog.c:17
+msgid ""
+"git reflog expire [--expire=<time>] [--expire-unreachable=<time>] [--"
+"rewrite] [--updateref] [--stale-fix] [--dry-run | -n] [--verbose] [--all] "
+"<refs>..."
+msgstr ""
+"git reflog expire [--expire=<tempo>] [--expire-unreachable=<tempo>] [--"
+"rewrite] [--updateref] [--stale-fix] [--dry-run | -n] [--verbose] [--all] "
+"<riferimenti>..."
+
+#: builtin/reflog.c:22
+msgid ""
+"git reflog delete [--rewrite] [--updateref] [--dry-run | -n] [--verbose] "
+"<refs>..."
+msgstr ""
+"git reflog delete [--rewrite] [--updateref] [--dry-run | -n] [--verbose] "
+"<riferimenti>..."
+
+#: builtin/reflog.c:25
+msgid "git reflog exists <ref>"
+msgstr "git reflog exists <riferimento>"
+
+#: builtin/reflog.c:567 builtin/reflog.c:572
+#, c-format
+msgid "'%s' is not a valid timestamp"
+msgstr "'%s' non è un timestamp valido"
+
+#: builtin/reflog.c:605
+#, c-format
+msgid "Marking reachable objects..."
+msgstr "Contrassegno gli oggetti raggiungibili..."
+
+#: builtin/reflog.c:643
+#, c-format
+msgid "%s points nowhere!"
+msgstr "%s non punta a niente!"
+
+#: builtin/reflog.c:695
+msgid "no reflog specified to delete"
+msgstr "nessun registro riferimenti da eliminare specificato"
+
+#: builtin/reflog.c:704
+#, c-format
+msgid "not a reflog: %s"
+msgstr "non è un registro riferimenti: %s"
+
+#: builtin/reflog.c:709
+#, c-format
+msgid "no reflog for '%s'"
+msgstr "log riferimenti non esistente per '%s'"
+
+#: builtin/reflog.c:755
+#, c-format
+msgid "invalid ref format: %s"
+msgstr "formato riferimento non valido: %s"
+
+#: builtin/reflog.c:764
+msgid "git reflog [ show | expire | delete | exists ]"
+msgstr "git reflog [ show | expire | delete | exists ]"
+
+#: builtin/remote.c:16
+msgid "git remote [-v | --verbose]"
+msgstr "git remote [-v | --verbose]"
+
+#: builtin/remote.c:17
+msgid ""
+"git remote add [-t <branch>] [-m <master>] [-f] [--tags | --no-tags] [--"
+"mirror=<fetch|push>] <name> <url>"
+msgstr ""
+"git remote add [-t <branch>] [-m <master>] [-f] [--tags | --no-tags] [--"
+"mirror=<fetch|push>] <nome> <URL>"
+
+#: builtin/remote.c:18 builtin/remote.c:38
+msgid "git remote rename <old> <new>"
+msgstr "git remote rename <vecchio> <nuovo>"
+
+#: builtin/remote.c:19 builtin/remote.c:43
+msgid "git remote remove <name>"
+msgstr "git remote remove <nome>"
+
+#: builtin/remote.c:20 builtin/remote.c:48
+msgid "git remote set-head <name> (-a | --auto | -d | --delete | <branch>)"
+msgstr "git remote set-head <nome> (-a | --auto | -d | --delete | <branch>)"
+
+#: builtin/remote.c:21
+msgid "git remote [-v | --verbose] show [-n] <name>"
+msgstr "git remote [-v | --verbose] show [-n] <nome>"
+
+#: builtin/remote.c:22
+msgid "git remote prune [-n | --dry-run] <name>"
+msgstr "git remote prune [-n | --dry-run] <nome>"
+
+#: builtin/remote.c:23
+msgid ""
+"git remote [-v | --verbose] update [-p | --prune] [(<group> | <remote>)...]"
+msgstr ""
+"git remote [-v | --verbose] update [-p | --prune] [(<gruppo> | <remoto>)...]"
+
+#: builtin/remote.c:24
+msgid "git remote set-branches [--add] <name> <branch>..."
+msgstr "git remote set-branches [--add] <nome> <branch>..."
+
+#: builtin/remote.c:25 builtin/remote.c:74
+msgid "git remote get-url [--push] [--all] <name>"
+msgstr "git remote get-url [--push] [--all] <nome>"
+
+#: builtin/remote.c:26 builtin/remote.c:79
+msgid "git remote set-url [--push] <name> <newurl> [<oldurl>]"
+msgstr "git remote set-url [--push] <nome> <nuovo URL> [<vecchio URL>]"
+
+#: builtin/remote.c:27 builtin/remote.c:80
+msgid "git remote set-url --add <name> <newurl>"
+msgstr "git remote set-url --add <nome> <nuovo URL>"
+
+#: builtin/remote.c:28 builtin/remote.c:81
+msgid "git remote set-url --delete <name> <url>"
+msgstr "git remote set-url --delete <nome> <URL>"
+
+#: builtin/remote.c:33
+msgid "git remote add [<options>] <name> <url>"
+msgstr "git remote add [<opzioni>] <nome> <URL>"
+
+#: builtin/remote.c:53
+msgid "git remote set-branches <name> <branch>..."
+msgstr "git remote set-branches <nome> <branch>..."
+
+#: builtin/remote.c:54
+msgid "git remote set-branches --add <name> <branch>..."
+msgstr "git remote set-branches --add <nome> <branch>..."
+
+#: builtin/remote.c:59
+msgid "git remote show [<options>] <name>"
+msgstr "git remote show [<opzioni>] <nome>"
+
+#: builtin/remote.c:64
+msgid "git remote prune [<options>] <name>"
+msgstr "git remote prune [<opzioni>] <nome>"
+
+#: builtin/remote.c:69
+msgid "git remote update [<options>] [<group> | <remote>]..."
+msgstr "git remote update [<opzioni>] [<gruppo> | <remoto>]..."
+
+#: builtin/remote.c:98
+#, c-format
+msgid "Updating %s"
+msgstr "Aggiornamento di %s"
+
+#: builtin/remote.c:130
+msgid ""
+"--mirror is dangerous and deprecated; please\n"
+"\t use --mirror=fetch or --mirror=push instead"
+msgstr ""
+"--mirror è pericoloso e deprecato; per favore\n"
+"\t usa invece --mirror-fetch o --mirror-push"
+
+#: builtin/remote.c:147
+#, c-format
+msgid "unknown mirror argument: %s"
+msgstr "argomento di mirror sconosciuto: %s"
+
+#: builtin/remote.c:163
+msgid "fetch the remote branches"
+msgstr "recupera i branch remoti"
+
+#: builtin/remote.c:165
+msgid "import all tags and associated objects when fetching"
+msgstr "importa tutti i tag e gli oggetti associati durante il recupero"
+
+#: builtin/remote.c:168
+msgid "or do not fetch any tag at all (--no-tags)"
+msgstr "o non recuperare alcun tag (--no-tags)"
+
+#: builtin/remote.c:170
+msgid "branch(es) to track"
+msgstr "branch da tracciare"
+
+#: builtin/remote.c:171
+msgid "master branch"
+msgstr "branch master"
+
+#: builtin/remote.c:173
+msgid "set up remote as a mirror to push to or fetch from"
+msgstr ""
+"imposta il remoto come mirror su cui eseguire push o da cui recuperare dati"
+
+#: builtin/remote.c:185
+msgid "specifying a master branch makes no sense with --mirror"
+msgstr "specificare un branch master con --mirror non ha senso"
+
+#: builtin/remote.c:187
+msgid "specifying branches to track makes sense only with fetch mirrors"
+msgstr ""
+"specificare i branch da tracciare ha senso solo con i mirror da cui "
+"recuperare dati"
+
+#: builtin/remote.c:194 builtin/remote.c:636
+#, c-format
+msgid "remote %s already exists."
+msgstr "il remoto %s esiste già."
+
+#: builtin/remote.c:198 builtin/remote.c:640
+#, c-format
+msgid "'%s' is not a valid remote name"
+msgstr "'%s' non è un nome di remoto valido"
+
+#: builtin/remote.c:238
+#, c-format
+msgid "Could not setup master '%s'"
+msgstr "Impossibile configurare il master '%s'"
+
+#: builtin/remote.c:344
+#, c-format
+msgid "Could not get fetch map for refspec %s"
+msgstr ""
+"Impossibile ottenere la mappa di recupero per lo specificatore riferimento %s"
+
+#: builtin/remote.c:443 builtin/remote.c:451
+msgid "(matching)"
+msgstr "(corrispondente)"
+
+#: builtin/remote.c:455
+msgid "(delete)"
+msgstr "(elimina)"
+
+#: builtin/remote.c:629 builtin/remote.c:764 builtin/remote.c:863
+#, c-format
+msgid "No such remote: '%s'"
+msgstr "Remoto non esistente: '%s'"
+
+#: builtin/remote.c:646
+#, c-format
+msgid "Could not rename config section '%s' to '%s'"
+msgstr ""
+"Non è stato possibile ridenominare la sezione di configurazione da '%s' in "
+"'%s'"
+
+#: builtin/remote.c:666
+#, c-format
+msgid ""
+"Not updating non-default fetch refspec\n"
+"\t%s\n"
+"\tPlease update the configuration manually if necessary."
+msgstr ""
+"Non aggiorno lo specificatore riferimento di recupero non predefinito\n"
+"\t%s\n"
+"\tAggiorna la configurazione manualmente se necessario."
+
+#: builtin/remote.c:701
+#, c-format
+msgid "deleting '%s' failed"
+msgstr "eliminazione di '%s' non riuscita"
+
+#: builtin/remote.c:735
+#, c-format
+msgid "creating '%s' failed"
+msgstr "creazione di '%s' non riuscita"
+
+#: builtin/remote.c:801
+msgid ""
+"Note: A branch outside the refs/remotes/ hierarchy was not removed;\n"
+"to delete it, use:"
+msgid_plural ""
+"Note: Some branches outside the refs/remotes/ hierarchy were not removed;\n"
+"to delete them, use:"
+msgstr[0] ""
+"Nota: un branch al di fuori della gerarchia refs/remotes/ non è stato "
+"eliminato;\n"
+"per eliminarlo, usa:"
+msgstr[1] ""
+"Nota: alcuni branch al di fuori della gerarchia refs/remotes/ non sono stati "
+"eliminati;\n"
+"per eliminarli, usa:"
+
+#: builtin/remote.c:815
+#, c-format
+msgid "Could not remove config section '%s'"
+msgstr "Impossibile rimuovere la sezione di configurazione '%s'"
+
+#: builtin/remote.c:916
+#, c-format
+msgid " new (next fetch will store in remotes/%s)"
+msgstr " nuovo (il prossimo fetch lo salverà in remotes/%s)"
+
+#: builtin/remote.c:919
+msgid " tracked"
+msgstr " tracciato"
+
+#: builtin/remote.c:921
+msgid " stale (use 'git remote prune' to remove)"
+msgstr " vecchio (usa 'git remote prune' per rimuoverlo)"
+
+#: builtin/remote.c:923
+msgid " ???"
+msgstr " ???"
+
+#: builtin/remote.c:964
+#, c-format
+msgid "invalid branch.%s.merge; cannot rebase onto > 1 branch"
+msgstr ""
+"valore branch.%s.merge non valido; impossibile eseguire il rebase su più di "
+"un branch"
+
+#: builtin/remote.c:973
+#, c-format
+msgid "rebases interactively onto remote %s"
+msgstr "rebase interattivo sul remoto %s"
+
+#: builtin/remote.c:975
+#, c-format
+msgid "rebases interactively (with merges) onto remote %s"
+msgstr "rebase interattivo (con merge) sul remoto %s"
+
+#: builtin/remote.c:978
+#, c-format
+msgid "rebases onto remote %s"
+msgstr "rebase sul remoto %s"
+
+#: builtin/remote.c:982
+#, c-format
+msgid " merges with remote %s"
+msgstr " merge con il remote %s"
+
+#: builtin/remote.c:985
+#, c-format
+msgid "merges with remote %s"
+msgstr "merge con il remote %s"
+
+#: builtin/remote.c:988
+#, c-format
+msgid "%-*s    and with remote %s\n"
+msgstr "%-*s    e con il remoto %s\n"
+
+#: builtin/remote.c:1031
+msgid "create"
+msgstr "crea"
+
+#: builtin/remote.c:1034
+msgid "delete"
+msgstr "elimina"
+
+#: builtin/remote.c:1038
+msgid "up to date"
+msgstr "aggiornato"
+
+#: builtin/remote.c:1041
+msgid "fast-forwardable"
+msgstr "fast forward possibile"
+
+#: builtin/remote.c:1044
+msgid "local out of date"
+msgstr "locale non aggiornato"
+
+#: builtin/remote.c:1051
+#, c-format
+msgid "    %-*s forces to %-*s (%s)"
+msgstr "    %-*s esegue un aggiornamento forzato su %-*s (%s)"
+
+#: builtin/remote.c:1054
+#, c-format
+msgid "    %-*s pushes to %-*s (%s)"
+msgstr "    %-*s esegue il push su %-*s (%s)"
+
+#: builtin/remote.c:1058
+#, c-format
+msgid "    %-*s forces to %s"
+msgstr "    %-*s esegue un aggiornamento forzato su %s"
+
+#: builtin/remote.c:1061
+#, c-format
+msgid "    %-*s pushes to %s"
+msgstr "    %-*s esegue il push su %s"
+
+#: builtin/remote.c:1129
+msgid "do not query remotes"
+msgstr "non interrogare i remoti"
+
+#: builtin/remote.c:1156
+#, c-format
+msgid "* remote %s"
+msgstr "* remoto %s"
+
+#: builtin/remote.c:1157
+#, c-format
+msgid "  Fetch URL: %s"
+msgstr "  URL recupero: %s"
+
+#: builtin/remote.c:1158 builtin/remote.c:1174 builtin/remote.c:1313
+msgid "(no URL)"
+msgstr "(nessun URL)"
+
+#. TRANSLATORS: the colon ':' should align
+#. with the one in " Fetch URL: %s"
+#. translation.
+#.
+#: builtin/remote.c:1172 builtin/remote.c:1174
+#, c-format
+msgid "  Push  URL: %s"
+msgstr "      URL push: %s"
+
+#: builtin/remote.c:1176 builtin/remote.c:1178 builtin/remote.c:1180
+#, c-format
+msgid "  HEAD branch: %s"
+msgstr "  branch HEAD: %s"
+
+#: builtin/remote.c:1176
+msgid "(not queried)"
+msgstr "(non interrogato)"
+
+#: builtin/remote.c:1178
+msgid "(unknown)"
+msgstr "(sconosciuto)"
+
+#: builtin/remote.c:1182
+#, c-format
+msgid ""
+"  HEAD branch (remote HEAD is ambiguous, may be one of the following):\n"
+msgstr ""
+"  branch HEAD (l'HEAD remoto è ambiguo, potrebbe essere uno dei seguenti):\n"
+
+#: builtin/remote.c:1194
+#, c-format
+msgid "  Remote branch:%s"
+msgid_plural "  Remote branches:%s"
+msgstr[0] "  Branch remoto:%s"
+msgstr[1] "  Branch remoti:%s"
+
+#: builtin/remote.c:1197 builtin/remote.c:1223
+msgid " (status not queried)"
+msgstr " (stato non richiesto)"
+
+#: builtin/remote.c:1206
+msgid "  Local branch configured for 'git pull':"
+msgid_plural "  Local branches configured for 'git pull':"
+msgstr[0] "  Branch locale configurato per 'git pull':"
+msgstr[1] "  Branch locali configurati per 'git pull':"
+
+#: builtin/remote.c:1214
+msgid "  Local refs will be mirrored by 'git push'"
+msgstr "  I riferimenti locali saranno copiati da 'git push'"
+
+#: builtin/remote.c:1220
+#, c-format
+msgid "  Local ref configured for 'git push'%s:"
+msgid_plural "  Local refs configured for 'git push'%s:"
+msgstr[0] "  Ref locale configurato per 'git push'%s:"
+msgstr[1] "  Ref locali configurati per 'git push'%s:"
+
+#: builtin/remote.c:1241
+msgid "set refs/remotes/<name>/HEAD according to remote"
+msgstr "imposta refs/remotes/<nome>/HEAD in base al remoto"
+
+#: builtin/remote.c:1243
+msgid "delete refs/remotes/<name>/HEAD"
+msgstr "elimina refs/remotes/<nome>/HEAD"
+
+#: builtin/remote.c:1258
+msgid "Cannot determine remote HEAD"
+msgstr "Impossibile determinare l'HEAD remoto"
+
+#: builtin/remote.c:1260
+msgid "Multiple remote HEAD branches. Please choose one explicitly with:"
+msgstr "Branch HEAD remoti multipli. Scegline uno esplicitamente con:"
+
+#: builtin/remote.c:1270
+#, c-format
+msgid "Could not delete %s"
+msgstr "Non è stato possibile eliminare %s"
+
+#: builtin/remote.c:1278
+#, c-format
+msgid "Not a valid ref: %s"
+msgstr "Non è un ref valido: %s"
+
+#: builtin/remote.c:1280
+#, c-format
+msgid "Could not setup %s"
+msgstr "Non è stato possibile configurare %s"
+
+#: builtin/remote.c:1298
+#, c-format
+msgid " %s will become dangling!"
+msgstr " %s diventerà pendente!"
+
+#: builtin/remote.c:1299
+#, c-format
+msgid " %s has become dangling!"
+msgstr " %s è diventato pendente!"
+
+#: builtin/remote.c:1309
+#, c-format
+msgid "Pruning %s"
+msgstr "Eliminazione di %s in corso"
+
+#: builtin/remote.c:1310
+#, c-format
+msgid "URL: %s"
+msgstr "URL: %s"
+
+#: builtin/remote.c:1326
+#, c-format
+msgid " * [would prune] %s"
+msgstr " * [sarebbe eliminato] %s"
+
+#: builtin/remote.c:1329
+#, c-format
+msgid " * [pruned] %s"
+msgstr " * [eliminato] %s"
+
+#: builtin/remote.c:1374
+msgid "prune remotes after fetching"
+msgstr "elimina remoti dopo il fetch"
+
+#: builtin/remote.c:1437 builtin/remote.c:1491 builtin/remote.c:1559
+#, c-format
+msgid "No such remote '%s'"
+msgstr "Remote '%s' non esistente"
+
+#: builtin/remote.c:1453
+msgid "add branch"
+msgstr "aggiungi branch"
+
+#: builtin/remote.c:1460
+msgid "no remote specified"
+msgstr "nessun remote specificato"
+
+#: builtin/remote.c:1477
+msgid "query push URLs rather than fetch URLs"
+msgstr "interroga gli URL per il push anziché gli URL per il fetch"
+
+#: builtin/remote.c:1479
+msgid "return all URLs"
+msgstr "restituisci tutti gli URL"
+
+#: builtin/remote.c:1507
+#, c-format
+msgid "no URLs configured for remote '%s'"
+msgstr "nessun URL configurato per il remoto '%s'"
+
+#: builtin/remote.c:1533
+msgid "manipulate push URLs"
+msgstr "manipola gli URL per il push"
+
+#: builtin/remote.c:1535
+msgid "add URL"
+msgstr "aggiungi URL"
+
+#: builtin/remote.c:1537
+msgid "delete URLs"
+msgstr "elimina URL"
+
+#: builtin/remote.c:1544
+msgid "--add --delete doesn't make sense"
+msgstr "--add --delete non ha senso"
+
+#: builtin/remote.c:1583
+#, c-format
+msgid "Invalid old URL pattern: %s"
+msgstr "Pattern URL vecchio non valido: %s"
+
+#: builtin/remote.c:1591
+#, c-format
+msgid "No such URL found: %s"
+msgstr "Nessuna URL trovata: %s"
+
+#: builtin/remote.c:1593
+msgid "Will not delete all non-push URLs"
+msgstr "Non eliminerò tutti gli URL non push"
+
+#: builtin/repack.c:23
+msgid "git repack [<options>]"
+msgstr "git repack [<opzioni>]"
+
+#: builtin/repack.c:28
+msgid ""
+"Incremental repacks are incompatible with bitmap indexes.  Use\n"
+"--no-write-bitmap-index or disable the pack.writebitmaps configuration."
+msgstr ""
+"I repack incrementali non sono compatibili con gli indici bitmap.\n"
+"Usa --no-write-bitmap-index o disabilita l'opzione di configurazione\n"
+"pack.writebitmaps."
+
+#: builtin/repack.c:191
+msgid "could not start pack-objects to repack promisor objects"
+msgstr ""
+"impossibile avviare pack-objects per eseguire il repack degli oggetti "
+"promettenti"
+
+#: builtin/repack.c:230 builtin/repack.c:416
+msgid "repack: Expecting full hex object ID lines only from pack-objects."
+msgstr ""
+"repack: Da pack-objects mi attendevo solo righe con gli ID completi "
+"esadecimali degli oggetti."
+
+#: builtin/repack.c:254
+msgid "could not finish pack-objects to repack promisor objects"
+msgstr ""
+"impossibile portare a termine pack-objects per eseguire il repack degli "
+"oggetti promettenti"
+
+#: builtin/repack.c:292
+msgid "pack everything in a single pack"
+msgstr "esegui il pack di tutto in un singolo pack"
+
+#: builtin/repack.c:294
+msgid "same as -a, and turn unreachable objects loose"
+msgstr "come -a e rendi sciolti gli oggetti non raggiungibili"
+
+#: builtin/repack.c:297
+msgid "remove redundant packs, and run git-prune-packed"
+msgstr "rimuovi i pack ridondanti ed esegui git-prune-packed"
+
+#: builtin/repack.c:299
+msgid "pass --no-reuse-delta to git-pack-objects"
+msgstr "fornisci l'opzione --no-reuse-delta a git-pack-objects"
+
+#: builtin/repack.c:301
+msgid "pass --no-reuse-object to git-pack-objects"
+msgstr "fornisci l'opzione --no-reuse-object a git-pack-objects"
+
+#: builtin/repack.c:303
+msgid "do not run git-update-server-info"
+msgstr "non eseguire git-update-server-info"
+
+#: builtin/repack.c:306
+msgid "pass --local to git-pack-objects"
+msgstr "fornisci l'opzione --local a git-pack-objects"
+
+#: builtin/repack.c:308
+msgid "write bitmap index"
+msgstr "scrivi l'indice bitmap"
+
+#: builtin/repack.c:310
+msgid "pass --delta-islands to git-pack-objects"
+msgstr "fornisci l'opzione --delta-islands a git-pack-objects"
+
+#: builtin/repack.c:311
+msgid "approxidate"
+msgstr "data approssimativa"
+
+#: builtin/repack.c:312
+msgid "with -A, do not loosen objects older than this"
+msgstr "con -A, non rendere sciolti gli oggetti meno recenti di questa data"
+
+#: builtin/repack.c:314
+msgid "with -a, repack unreachable objects"
+msgstr "con -a, esegui il repack degli oggetti non raggiungibili"
+
+#: builtin/repack.c:316
+msgid "size of the window used for delta compression"
+msgstr "dimensione della finestra usata per la compressione delta"
+
+#: builtin/repack.c:317 builtin/repack.c:323
+msgid "bytes"
+msgstr "byte"
+
+#: builtin/repack.c:318
+msgid "same as the above, but limit memory size instead of entries count"
+msgstr ""
+"come sopra, ma limita le dimensioni della memoria invece del numero di voci"
+
+#: builtin/repack.c:320
+msgid "limits the maximum delta depth"
+msgstr "limita la profondità massima dei delta"
+
+#: builtin/repack.c:322
+msgid "limits the maximum number of threads"
+msgstr "limita il numero massimo di thread"
+
+#: builtin/repack.c:324
+msgid "maximum size of each packfile"
+msgstr "dimensione massima di ogni file pack"
+
+#: builtin/repack.c:326
+msgid "repack objects in packs marked with .keep"
+msgstr "esegui il repack degli oggetti nei pack contrassegnati con .keep"
+
+#: builtin/repack.c:328
+msgid "do not repack this pack"
+msgstr "non eseguire il repack di questo pack"
+
+#: builtin/repack.c:338
+msgid "cannot delete packs in a precious-objects repo"
+msgstr "impossibile eliminare i pack in un repository 'oggetti preziosi'"
+
+#: builtin/repack.c:342
+msgid "--keep-unreachable and -A are incompatible"
+msgstr "--keep-unreachable e -A non sono compatibili"
+
+#: builtin/repack.c:425
+msgid "Nothing new to pack."
+msgstr "Non ci sono oggetti nuovi di cui eseguire il pack."
+
+#: builtin/repack.c:486
+#, c-format
+msgid ""
+"WARNING: Some packs in use have been renamed by\n"
+"WARNING: prefixing old- to their name, in order to\n"
+"WARNING: replace them with the new version of the\n"
+"WARNING: file.  But the operation failed, and the\n"
+"WARNING: attempt to rename them back to their\n"
+"WARNING: original names also failed.\n"
+"WARNING: Please rename them in %s manually:\n"
+msgstr ""
+"AVVISO: Alcuni pack in uso sono stati ridenominati\n"
+"AVVISO: aggiungendo il prefisso old- al loro nome\n"
+"AVVISO: per consentirne la sostituzione con la\n"
+"AVVISO: nuova versione del file. Ma l'operazione\n"
+"AVVISO: non è riuscita e anche il tentativo di\n"
+"AVVISO: ridenominarli con il loro nome originale\n"
+"AVVISO: non è riuscito. Ridenominali manualmente\n"
+"AVVISO: entro %s:\n"
+
+#: builtin/repack.c:534
+#, c-format
+msgid "failed to remove '%s'"
+msgstr "eliminazione di '%s' non riuscita"
+
+#: builtin/replace.c:22
+msgid "git replace [-f] <object> <replacement>"
+msgstr "git replace [-f] <oggetto> <oggetto sostitutivo>"
+
+#: builtin/replace.c:23
+msgid "git replace [-f] --edit <object>"
+msgstr "git replace [-f] --edit <oggetto>"
+
+#: builtin/replace.c:24
+msgid "git replace [-f] --graft <commit> [<parent>...]"
+msgstr "git replace [-f] --graft <commit> [<genitore>...]"
+
+#: builtin/replace.c:25
+msgid "git replace [-f] --convert-graft-file"
+msgstr "git replace [-f] --convert-graft-file"
+
+#: builtin/replace.c:26
+msgid "git replace -d <object>..."
+msgstr "git replace -d <oggetto>..."
+
+#: builtin/replace.c:27
+msgid "git replace [--format=<format>] [-l [<pattern>]]"
+msgstr "git replace [--format=<formato>] [-l [<pattern>]]"
+
+#: builtin/replace.c:90
+#, c-format
+msgid ""
+"invalid replace format '%s'\n"
+"valid formats are 'short', 'medium' and 'long'"
+msgstr ""
+"formato sostituzione non valido: '%s'\n"
+"i formati validi sono 'short', 'medium' e 'long'"
+
+#: builtin/replace.c:125
+#, c-format
+msgid "replace ref '%s' not found"
+msgstr "riferimento sostitutivo '%s' non trovato"
+
+#: builtin/replace.c:141
+#, c-format
+msgid "Deleted replace ref '%s'"
+msgstr "Eliminato riferimento sostitutivo '%s'"
+
+#: builtin/replace.c:153
+#, c-format
+msgid "'%s' is not a valid ref name"
+msgstr "'%s' non è un nome riferimento valido"
+
+#: builtin/replace.c:158
+#, c-format
+msgid "replace ref '%s' already exists"
+msgstr "il riferimento sostitutivo '%s' esiste già"
+
+#: builtin/replace.c:178
+#, c-format
+msgid ""
+"Objects must be of the same type.\n"
+"'%s' points to a replaced object of type '%s'\n"
+"while '%s' points to a replacement object of type '%s'."
+msgstr ""
+"Gli oggetti devono essere dello stesso tipo.\n"
+"'%s' punta a un oggetto sostituito di tipo '%s'\n"
+"mentre '%s' punta a un oggetto sostitutivo di tipo '%s'."
+
+#: builtin/replace.c:229
+#, c-format
+msgid "unable to open %s for writing"
+msgstr "impossibile aprire '%s' in scrittura"
+
+#: builtin/replace.c:242
+msgid "cat-file reported failure"
+msgstr "cat-file ha segnalato un errore"
+
+#: builtin/replace.c:258
+#, c-format
+msgid "unable to open %s for reading"
+msgstr "impossibile aprire %s in lettura"
+
+#: builtin/replace.c:272
+msgid "unable to spawn mktree"
+msgstr "impossibile lanciare mktree"
+
+#: builtin/replace.c:276
+msgid "unable to read from mktree"
+msgstr "impossibile leggere da mktree"
+
+#: builtin/replace.c:285
+msgid "mktree reported failure"
+msgstr "mktree ha segnalato un errore"
+
+#: builtin/replace.c:289
+msgid "mktree did not return an object name"
+msgstr "mktree non ha restituito un nome oggetto"
+
+#: builtin/replace.c:298
+#, c-format
+msgid "unable to fstat %s"
+msgstr "impossibile eseguire fstat su %s"
+
+#: builtin/replace.c:303
+msgid "unable to write object to database"
+msgstr "impossibile scrivere l'oggetto nel database"
+
+#: builtin/replace.c:322 builtin/replace.c:378 builtin/replace.c:423
+#: builtin/replace.c:453
+#, c-format
+msgid "not a valid object name: '%s'"
+msgstr "nome oggetto non valido: '%s'"
+
+#: builtin/replace.c:326
+#, c-format
+msgid "unable to get object type for %s"
+msgstr "impossibile recuperare il tipo dell'oggetto %s"
+
+#: builtin/replace.c:342
+msgid "editing object file failed"
+msgstr "modifica del file oggetto non riuscita"
+
+#: builtin/replace.c:351
+#, c-format
+msgid "new object is the same as the old one: '%s'"
+msgstr "il nuovo oggetto è lo stesso di quello vecchio: '%s'"
+
+#: builtin/replace.c:384
+#, c-format
+msgid "could not parse %s as a commit"
+msgstr "impossibile analizzare %s come commit"
+
+#: builtin/replace.c:415
+#, c-format
+msgid "bad mergetag in commit '%s'"
+msgstr "tag merge non valido nel commit '%s'"
+
+#: builtin/replace.c:417
+#, c-format
+msgid "malformed mergetag in commit '%s'"
+msgstr "tag merge malformato nel commit '%s'"
+
+#: builtin/replace.c:429
+#, c-format
+msgid ""
+"original commit '%s' contains mergetag '%s' that is discarded; use --edit "
+"instead of --graft"
+msgstr ""
+"il commit originario '%s' contiene il tag merge '%s' che è stato scartato; "
+"usa --edit anziché --graft"
+
+#: builtin/replace.c:468
+#, c-format
+msgid "the original commit '%s' has a gpg signature"
+msgstr "il commit originario '%s' ha una firma GPG"
+
+#: builtin/replace.c:469
+msgid "the signature will be removed in the replacement commit!"
+msgstr "la firma sarà rimossa nel commit sostitutivo!"
+
+#: builtin/replace.c:479
+#, c-format
+msgid "could not write replacement commit for: '%s'"
+msgstr "impossibile scrivere il commit sostitutivo per '%s'"
+
+#: builtin/replace.c:487
+#, c-format
+msgid "graft for '%s' unnecessary"
+msgstr "graft per '%s' non necessario"
+
+#: builtin/replace.c:491
+#, c-format
+msgid "new commit is the same as the old one: '%s'"
+msgstr "il nuovo commit è lo stesso di quello vecchio: '%s'"
+
+#: builtin/replace.c:526
+#, c-format
+msgid ""
+"could not convert the following graft(s):\n"
+"%s"
+msgstr ""
+"impossibile convertire i seguenti graft:\n"
+"%s"
+
+#: builtin/replace.c:547
+msgid "list replace refs"
+msgstr "elenca i riferimenti sostitutivi"
+
+#: builtin/replace.c:548
+msgid "delete replace refs"
+msgstr "elimina i riferimenti sostitutivi"
+
+#: builtin/replace.c:549
+msgid "edit existing object"
+msgstr "modifica l'oggetto esistente"
+
+#: builtin/replace.c:550
+msgid "change a commit's parents"
+msgstr "cambia i genitori di un commit"
+
+#: builtin/replace.c:551
+msgid "convert existing graft file"
+msgstr "converti un file graft esistente"
+
+#: builtin/replace.c:552
+msgid "replace the ref if it exists"
+msgstr "sostituisci il riferimento se esiste"
+
+#: builtin/replace.c:554
+msgid "do not pretty-print contents for --edit"
+msgstr "non stampare i contenuti in un formato leggibile (per --edit)"
+
+#: builtin/replace.c:555
+msgid "use this format"
+msgstr "usa questo formato"
+
+#: builtin/replace.c:568
+msgid "--format cannot be used when not listing"
+msgstr "--format non può essere usato quando non si elencano voci"
+
+#: builtin/replace.c:576
+msgid "-f only makes sense when writing a replacement"
+msgstr "-f ha senso solo se si sta scrivendo un oggetto sostitutivo"
+
+#: builtin/replace.c:580
+msgid "--raw only makes sense with --edit"
+msgstr "--raw ha senso solo con --edit"
+
+#: builtin/replace.c:586
+msgid "-d needs at least one argument"
+msgstr "-d richiede almeno un argomento"
+
+#: builtin/replace.c:592
+msgid "bad number of arguments"
+msgstr "numero di argomenti errato"
+
+#: builtin/replace.c:598
+msgid "-e needs exactly one argument"
+msgstr "-e richiede esattamente un argomento"
+
+#: builtin/replace.c:604
+msgid "-g needs at least one argument"
+msgstr "-g richiede almeno un argomento"
+
+#: builtin/replace.c:610
+msgid "--convert-graft-file takes no argument"
+msgstr "--convert-graft-file non richiede argomenti"
+
+#: builtin/replace.c:616
+msgid "only one pattern can be given with -l"
+msgstr "con -l può essere specificato solo un pattern"
+
+#: builtin/rerere.c:13
+msgid "git rerere [clear | forget <path>... | status | remaining | diff | gc]"
+msgstr ""
+"git rerere [clear | forget <percorso>... | status | remaining | diff | gc]"
+
+#: builtin/rerere.c:60
+msgid "register clean resolutions in index"
+msgstr "registra le risoluzioni pulite nell'indice"
+
+#: builtin/rerere.c:79
+msgid "'git rerere forget' without paths is deprecated"
+msgstr "'git rerere forget' senza percorsi è deprecato"
+
+#: builtin/rerere.c:113
+#, c-format
+msgid "unable to generate diff for '%s'"
+msgstr "impossibile generare il diff per '%s'"
+
+#: builtin/reset.c:32
+msgid ""
+"git reset [--mixed | --soft | --hard | --merge | --keep] [-q] [<commit>]"
+msgstr ""
+"git reset [--mixed | --soft | --hard | --merge | --keep] [-q] [<commit>]"
+
+#: builtin/reset.c:33
+msgid "git reset [-q] [<tree-ish>] [--] <pathspec>..."
+msgstr "git reset [-q] [<espressione albero>] [--] <specificatore percorso>..."
+
+#: builtin/reset.c:34
+msgid ""
+"git reset [-q] [--pathspec-from-file [--pathspec-file-nul]] [<tree-ish>]"
+msgstr ""
+"git reset [-q] [--pathspec-from-file [--pathspec-file-nul]] [<espressione"
+" albero>]"
+
+#: builtin/reset.c:35
+msgid "git reset --patch [<tree-ish>] [--] [<pathspec>...]"
+msgstr ""
+"git reset --patch [<espressione albero>] [--] [<specificatore percorso>...]"
+
+#: builtin/reset.c:41
+msgid "mixed"
+msgstr "misto"
+
+#: builtin/reset.c:41
+msgid "soft"
+msgstr "soft"
+
+#: builtin/reset.c:41
+msgid "hard"
+msgstr "hard"
+
+#: builtin/reset.c:41
+msgid "merge"
+msgstr "merge"
+
+#: builtin/reset.c:41
+msgid "keep"
+msgstr "keep"
+
+#: builtin/reset.c:82
+msgid "You do not have a valid HEAD."
+msgstr "Non hai un HEAD valido."
+
+#: builtin/reset.c:84
+msgid "Failed to find tree of HEAD."
+msgstr "Impossibile trovare l'albero di HEAD."
+
+#: builtin/reset.c:90
+#, c-format
+msgid "Failed to find tree of %s."
+msgstr "Impossibile trovare l'albero di %s."
+
+#: builtin/reset.c:115
+#, c-format
+msgid "HEAD is now at %s"
+msgstr "HEAD ora si trova a %s"
+
+#: builtin/reset.c:194
+#, c-format
+msgid "Cannot do a %s reset in the middle of a merge."
+msgstr "Impossibile eseguire un %s reset nel corso di un merge."
+
+#: builtin/reset.c:294 builtin/stash.c:519 builtin/stash.c:594
+#: builtin/stash.c:618
+msgid "be quiet, only report errors"
+msgstr "non visualizzare messaggi, segnala solo gli errori"
+
+#: builtin/reset.c:296
+msgid "reset HEAD and index"
+msgstr "reimposta l'HEAD e l'indice"
+
+#: builtin/reset.c:297
+msgid "reset only HEAD"
+msgstr "reimposta solo l'HEAD"
+
+#: builtin/reset.c:299 builtin/reset.c:301
+msgid "reset HEAD, index and working tree"
+msgstr "reimposta l'HEAD, l'indice e l'albero di lavoro"
+
+#: builtin/reset.c:303
+msgid "reset HEAD but keep local changes"
+msgstr "reimposta l'HEAD ma mantieni le modifiche locali"
+
+#: builtin/reset.c:309
+msgid "record only the fact that removed paths will be added later"
+msgstr ""
+"salva solo il fatto che i percorsi rimossi saranno aggiunti successivamente"
+
+#: builtin/reset.c:343
+#, c-format
+msgid "Failed to resolve '%s' as a valid revision."
+msgstr "Risoluzione di '%s' come revisione valida non riuscita."
+
+#: builtin/reset.c:351
+#, c-format
+msgid "Failed to resolve '%s' as a valid tree."
+msgstr "Risoluzione di '%s' come albero valido non riuscita."
+
+#: builtin/reset.c:360
+msgid "--patch is incompatible with --{hard,mixed,soft}"
+msgstr "--patch non è compatibile con --{hard,mixed,soft}"
+
+#: builtin/reset.c:370
+msgid "--mixed with paths is deprecated; use 'git reset -- <paths>' instead."
+msgstr "--mixed con i path è deprecata; usa invece 'git reset -- <path>'."
+
+#: builtin/reset.c:372
+#, c-format
+msgid "Cannot do %s reset with paths."
+msgstr "Impossibile eseguire un %s reset con dei percorsi."
+
+#: builtin/reset.c:387
+#, c-format
+msgid "%s reset is not allowed in a bare repository"
+msgstr "%s reset non è consentito in un repository spoglio"
+
+#: builtin/reset.c:391
+msgid "-N can only be used with --mixed"
+msgstr "-N può essere usato solo con --mixed"
+
+#: builtin/reset.c:412
+msgid "Unstaged changes after reset:"
+msgstr "Modifiche non nell'area di staging dopo il reset:"
+
+#: builtin/reset.c:415
+#, c-format
+msgid ""
+"\n"
+"It took %.2f seconds to enumerate unstaged changes after reset.  You can\n"
+"use '--quiet' to avoid this.  Set the config setting reset.quiet to true\n"
+"to make this the default.\n"
+msgstr ""
+"\n"
+"Ci sono voluti %.2f secondi per elencare le modifiche non nell'area di\n"
+"staging dopo il reset. Puoi usare '--quiet' per non visualizzare questo\n"
+"messaggio. Imposta l'opzione di configurazione reset.quiet a true per\n"
+"rendere tale comportamento quello predefinito.\n"
+
+#: builtin/reset.c:425
+#, c-format
+msgid "Could not reset index file to revision '%s'."
+msgstr "Impossibile ripristinare il file indice alla revisione '%s'."
+
+#: builtin/reset.c:429
+msgid "Could not write new index file."
+msgstr "Impossibile scrivere il nuovo file indice."
+
+#: builtin/rev-list.c:411
+msgid "cannot combine --exclude-promisor-objects and --missing"
+msgstr "impossibile combinare --exclude-promisor-objects e --missing"
+
+#: builtin/rev-list.c:472
+msgid "object filtering requires --objects"
+msgstr "il filtraggio oggetti richiede --objects"
+
+#: builtin/rev-list.c:522
+msgid "rev-list does not support display of notes"
+msgstr "rev-list non supporta la visualizzazione delle note"
+
+#: builtin/rev-list.c:525
+msgid "cannot combine --use-bitmap-index with object filtering"
+msgstr "impossibile combinare --use-bitmap-index con il filtraggio oggetti"
+
+#: builtin/rev-parse.c:408
+msgid "git rev-parse --parseopt [<options>] -- [<args>...]"
+msgstr "git rev-parse --parseopt [<opzioni>] -- [<argomenti>...]"
+
+#: builtin/rev-parse.c:413
+msgid "keep the `--` passed as an arg"
+msgstr "mantieni la stringa passata `--` come argomento"
+
+#: builtin/rev-parse.c:415
+msgid "stop parsing after the first non-option argument"
+msgstr ""
+"termina l'analisi dopo il primo argomento non corrispondente a un'opzione"
+
+#: builtin/rev-parse.c:418
+msgid "output in stuck long form"
+msgstr "emetti l'output in forma \"stuck long\""
+
+#: builtin/rev-parse.c:551
+msgid ""
+"git rev-parse --parseopt [<options>] -- [<args>...]\n"
+"   or: git rev-parse --sq-quote [<arg>...]\n"
+"   or: git rev-parse [<options>] [<arg>...]\n"
+"\n"
+"Run \"git rev-parse --parseopt -h\" for more information on the first usage."
+msgstr ""
+"git rev-parse --parseopt [<opzioni>] -- [<argomenti>...]\n"
+"   o: git rev-parse --sq-quote [<argomento>...]\n"
+"   o: git rev-parse [<opzioni>] [<argomento>...]\n"
+"\n"
+"Esegui \"git rev-parse --parseopt -h\" per ulteriori informazioni sulla "
+"prima\n"
+"modalità d'uso."
+
+#: builtin/revert.c:24
+msgid "git revert [<options>] <commit-ish>..."
+msgstr "git revert [<opzioni>] <espressione commit>..."
+
+#: builtin/revert.c:25
+msgid "git revert <subcommand>"
+msgstr "git revert <sottocomando>"
+
+#: builtin/revert.c:30
+msgid "git cherry-pick [<options>] <commit-ish>..."
+msgstr "git cherry-pick [<opzioni>] <espressione commit>..."
+
+#: builtin/revert.c:31
+msgid "git cherry-pick <subcommand>"
+msgstr "git cherry-pick <sottocomando>"
+
+#: builtin/revert.c:72
+#, c-format
+msgid "option `%s' expects a number greater than zero"
+msgstr "l'opzione `%s' richiede un numero maggiore di zero"
+
+#: builtin/revert.c:92
+#, c-format
+msgid "%s: %s cannot be used with %s"
+msgstr "%s: %s non può essere usata con %s"
+
+#: builtin/revert.c:102
+msgid "end revert or cherry-pick sequence"
+msgstr "termina la sequenza revert o cherry-pick"
+
+#: builtin/revert.c:103
+msgid "resume revert or cherry-pick sequence"
+msgstr "riprendi la sequenza revert o cherry-pick"
+
+#: builtin/revert.c:104
+msgid "cancel revert or cherry-pick sequence"
+msgstr "annulla la sequenza revert o cherry-pick"
+
+#: builtin/revert.c:105
+msgid "skip current commit and continue"
+msgstr "salta il commit corrente e continua"
+
+#: builtin/revert.c:107
+msgid "don't automatically commit"
+msgstr "non eseguire il commit automaticamente"
+
+#: builtin/revert.c:108
+msgid "edit the commit message"
+msgstr "modifica il messaggio di commit"
+
+#: builtin/revert.c:111
+msgid "parent-number"
+msgstr "numero-genitore"
+
+#: builtin/revert.c:112
+msgid "select mainline parent"
+msgstr "seleziona il genitore mainline"
+
+#: builtin/revert.c:114
+msgid "merge strategy"
+msgstr "strategia di merge"
+
+#: builtin/revert.c:116
+msgid "option for merge strategy"
+msgstr "opzione per la strategia di merge"
+
+#: builtin/revert.c:125
+msgid "append commit name"
+msgstr "aggiungi il nome del commit alla fine"
+
+#: builtin/revert.c:127
+msgid "preserve initially empty commits"
+msgstr "mantieni i commit inizialmente vuoti"
+
+#: builtin/revert.c:129
+msgid "keep redundant, empty commits"
+msgstr "mantieni i commit ridondanti e vuoti"
+
+#: builtin/revert.c:232
+msgid "revert failed"
+msgstr "revert non riuscito"
+
+#: builtin/revert.c:245
+msgid "cherry-pick failed"
+msgstr "cherry-pick non riuscito"
+
+#: builtin/rm.c:19
+msgid "git rm [<options>] [--] <file>..."
+msgstr "git rm [<opzioni>] [--] <file>..."
+
+#: builtin/rm.c:207
+msgid ""
+"the following file has staged content different from both the\n"
+"file and the HEAD:"
+msgid_plural ""
+"the following files have staged content different from both the\n"
+"file and the HEAD:"
+msgstr[0] ""
+"il seguente file ha contenuti nell'area di staging che\n"
+"differiscono sia rispetto a quelli del file sia rispetto a HEAD:"
+msgstr[1] ""
+"i seguenti file hanno contenuti nell'area di staging che\n"
+"differiscono sia rispetto a quelli del file sia rispetto a HEAD:"
+
+#: builtin/rm.c:212
+msgid ""
+"\n"
+"(use -f to force removal)"
+msgstr ""
+"\n"
+"(usa -f per forzarne la rimozione)"
+
+#: builtin/rm.c:216
+msgid "the following file has changes staged in the index:"
+msgid_plural "the following files have changes staged in the index:"
+msgstr[0] "il seguente file ha delle modifiche in staging nell'indice:"
+msgstr[1] "i seguenti file hanno delle modifiche in staging nell'indice:"
+
+#: builtin/rm.c:220 builtin/rm.c:229
+msgid ""
+"\n"
+"(use --cached to keep the file, or -f to force removal)"
+msgstr ""
+"\n"
+"(usa --cached per mantenere il file o -f per forzarne la rimozione)"
+
+#: builtin/rm.c:226
+msgid "the following file has local modifications:"
+msgid_plural "the following files have local modifications:"
+msgstr[0] "il seguente file ha delle modifiche locali:"
+msgstr[1] "i seguenti file hanno delle modifiche locali:"
+
+#: builtin/rm.c:242
+msgid "do not list removed files"
+msgstr "non elencare i file rimossi"
+
+#: builtin/rm.c:243
+msgid "only remove from the index"
+msgstr "rimuovi solo dall'indice"
+
+#: builtin/rm.c:244
+msgid "override the up-to-date check"
+msgstr "ignora il controllo sullo stato di aggiornamento"
+
+#: builtin/rm.c:245
+msgid "allow recursive removal"
+msgstr "consenti rimozioni ricorsive"
+
+#: builtin/rm.c:247
+msgid "exit with a zero status even if nothing matched"
+msgstr ""
+"esci con codice d'uscita zero anche nel caso in cui non vi siano "
+"corrispondenze"
+
+#: builtin/rm.c:289
+msgid "please stage your changes to .gitmodules or stash them to proceed"
+msgstr ""
+"esegui lo stage delle modifiche a .gitmodules o eseguine lo stash per "
+"procedere"
+
+#: builtin/rm.c:307
+#, c-format
+msgid "not removing '%s' recursively without -r"
+msgstr "non rimuovo '%s' ricorsivamente senza -r"
+
+#: builtin/rm.c:346
+#, c-format
+msgid "git rm: unable to remove %s"
+msgstr "git rm: non è possibile eliminare %s"
+
+#: builtin/send-pack.c:20
+msgid ""
+"git send-pack [--all | --mirror] [--dry-run] [--force] [--receive-pack=<git-"
+"receive-pack>] [--verbose] [--thin] [--atomic] [<host>:]<directory> "
+"[<ref>...]\n"
+"  --all and explicit <ref> specification are mutually exclusive."
+msgstr ""
+"git send-pack [--all | --mirror] [--dry-run] [--force] [--receive-pack=<git-"
+"receive-pack>] [--verbose] [--thin] [--atomic] [<host>:]<directory> "
+"[<riferimento>...]\n"
+"  --all e uno specificatore <riferimento> sono mutualmente esclusivi."
+
+#: builtin/send-pack.c:163
+msgid "remote name"
+msgstr "nome remoto"
+
+#: builtin/send-pack.c:177
+msgid "use stateless RPC protocol"
+msgstr "usa protocollo RPC senza stato"
+
+#: builtin/send-pack.c:178
+msgid "read refs from stdin"
+msgstr "leggi i riferimento dallo standard input"
+
+#: builtin/send-pack.c:179
+msgid "print status from remote helper"
+msgstr "stampa lo stato dell'helper remoto"
+
+#: builtin/shortlog.c:14
+msgid "git shortlog [<options>] [<revision-range>] [[--] <path>...]"
+msgstr "git shortlog [<opzioni>] [<intervallo revisioni>] [[--] <percorso>...]"
+
+#: builtin/shortlog.c:15
+msgid "git log --pretty=short | git shortlog [<options>]"
+msgstr "git log --pretty=short | git shortlog [<opzioni>]"
+
+#: builtin/shortlog.c:264
+msgid "Group by committer rather than author"
+msgstr "Raggruppa per persona che ha eseguito il commit anziché per autore"
+
+#: builtin/shortlog.c:266
+msgid "sort output according to the number of commits per author"
+msgstr "ordina l'output in base al numero di commit per autore"
+
+#: builtin/shortlog.c:268
+msgid "Suppress commit descriptions, only provides commit count"
+msgstr "Ometti le descrizioni dei commit, fornisci solo il numero dei commit"
+
+#: builtin/shortlog.c:270
+msgid "Show the email address of each author"
+msgstr "Visualizza l'indirizzo e-mail di ogni autore"
+
+#: builtin/shortlog.c:271
+msgid "<w>[,<i1>[,<i2>]]"
+msgstr "<w>[,<i1>[,<i2>]]"
+
+#: builtin/shortlog.c:272
+msgid "Linewrap output"
+msgstr "Output a capo automatico"
+
+#: builtin/shortlog.c:301
+msgid "too many arguments given outside repository"
+msgstr "troppi argomenti forniti oltre al repository"
+
+#: builtin/show-branch.c:13
+msgid ""
+"git show-branch [-a | --all] [-r | --remotes] [--topo-order | --date-order]\n"
+"\t\t[--current] [--color[=<when>] | --no-color] [--sparse]\n"
+"\t\t[--more=<n> | --list | --independent | --merge-base]\n"
+"\t\t[--no-name | --sha1-name] [--topics] [(<rev> | <glob>)...]"
+msgstr ""
+"git show-branch [-a | --all] [-r | --remotes] [--topo-order | --date-order]\n"
+"\t\t[--current] [--color[=<quando>] | --no-color] [--sparse]\n"
+"\t\t[--more=<n> | --list | --independent | --merge-base]\n"
+"\t\t[--no-name | --sha1-name] [--topics] [(<revisione> | <glob>)...]"
+
+#: builtin/show-branch.c:17
+msgid "git show-branch (-g | --reflog)[=<n>[,<base>]] [--list] [<ref>]"
+msgstr ""
+"git show-branch (-g | --reflog)[=<n>[,<base>]] [--list] [<riferimento>]"
+
+#: builtin/show-branch.c:395
+#, c-format
+msgid "ignoring %s; cannot handle more than %d ref"
+msgid_plural "ignoring %s; cannot handle more than %d refs"
+msgstr[0] "ignoro %s; non posso gestire più di %d riferimento"
+msgstr[1] "ignoro %s; non posso gestire più di %d riferimenti"
+
+#: builtin/show-branch.c:548
+#, c-format
+msgid "no matching refs with %s"
+msgstr "nessun riferimento corrispondente a %s"
+
+#: builtin/show-branch.c:645
+msgid "show remote-tracking and local branches"
+msgstr "visualizza i branch che ne tracciano uno remoto e quelli locali"
+
+#: builtin/show-branch.c:647
+msgid "show remote-tracking branches"
+msgstr "visualizza i branch che ne tracciano uno remoto"
+
+#: builtin/show-branch.c:649
+msgid "color '*!+-' corresponding to the branch"
+msgstr "colore '*!+-' corrispondente al branch"
+
+#: builtin/show-branch.c:651
+msgid "show <n> more commits after the common ancestor"
+msgstr "visualizza <n> commit ulteriori rispetto all'antenato comune"
+
+#: builtin/show-branch.c:653
+msgid "synonym to more=-1"
+msgstr "sinonimo di more=-1"
+
+#: builtin/show-branch.c:654
+msgid "suppress naming strings"
+msgstr "non visualizzare le stringhe di denominazione"
+
+#: builtin/show-branch.c:656
+msgid "include the current branch"
+msgstr "includi il branch corrente"
+
+#: builtin/show-branch.c:658
+msgid "name commits with their object names"
+msgstr "denomina i commit con i loro nomi oggetto"
+
+#: builtin/show-branch.c:660
+msgid "show possible merge bases"
+msgstr "visualizza le basi merge possibili"
+
+#: builtin/show-branch.c:662
+msgid "show refs unreachable from any other ref"
+msgstr "visualizza i riferimenti non raggiungibili da nessun altro"
+
+#: builtin/show-branch.c:664
+msgid "show commits in topological order"
+msgstr "visualizza i commit in ordine topologico"
+
+#: builtin/show-branch.c:667
+msgid "show only commits not on the first branch"
+msgstr "visualizza solo i commit non sul primo branch"
+
+#: builtin/show-branch.c:669
+msgid "show merges reachable from only one tip"
+msgstr "visualizza i merge raggiungibili solo dall'ultimo commit di un branch"
+
+#: builtin/show-branch.c:671
+msgid "topologically sort, maintaining date order where possible"
+msgstr ""
+"esegui un ordinamento topologico mantenendo l'ordine delle date ove possibile"
+
+#: builtin/show-branch.c:674
+msgid "<n>[,<base>]"
+msgstr "<n>[,<base>]"
+
+#: builtin/show-branch.c:675
+msgid "show <n> most recent ref-log entries starting at base"
+msgstr ""
+"visualizza le <n> voci più recenti del log dei riferimenti partendo da base"
+
+#: builtin/show-branch.c:711
+msgid ""
+"--reflog is incompatible with --all, --remotes, --independent or --merge-base"
+msgstr ""
+"--reflog non è compatibile con --all, --remotes, --independent o --merge-base"
+
+#: builtin/show-branch.c:735
+msgid "no branches given, and HEAD is not valid"
+msgstr "nessun branch fornito e l'HEAD non è valido"
+
+#: builtin/show-branch.c:738
+msgid "--reflog option needs one branch name"
+msgstr "l'opzione --reflog richiede il nome di un branch"
+
+#: builtin/show-branch.c:741
+#, c-format
+msgid "only %d entry can be shown at one time."
+msgid_plural "only %d entries can be shown at one time."
+msgstr[0] "può essere visualizzata solo %d voce per volta."
+msgstr[1] "possono essere visualizzate solo %d voci per volta."
+
+#: builtin/show-branch.c:745
+#, c-format
+msgid "no such ref %s"
+msgstr "riferimento non esistente: %s"
+
+#: builtin/show-branch.c:831
+#, c-format
+msgid "cannot handle more than %d rev."
+msgid_plural "cannot handle more than %d revs."
+msgstr[0] "impossibile gestire più di %d revisione."
+msgstr[1] "impossibile gestire più di %d revisioni."
+
+#: builtin/show-branch.c:835
+#, c-format
+msgid "'%s' is not a valid ref."
+msgstr "'%s' non è un riferimento valido."
+
+#: builtin/show-branch.c:838
+#, c-format
+msgid "cannot find commit %s (%s)"
+msgstr "impossibile trovare il commit %s (%s)"
+
+#: builtin/show-ref.c:12
+msgid ""
+"git show-ref [-q | --quiet] [--verify] [--head] [-d | --dereference] [-s | --"
+"hash[=<n>]] [--abbrev[=<n>]] [--tags] [--heads] [--] [<pattern>...]"
+msgstr ""
+"git show-ref [-q | --quiet] [--verify] [--head] [-d | --dereference] [-s | --"
+"hash[=<n>]] [--abbrev[=<n>]] [--tags] [--heads] [--] [<pattern>...]"
+
+#: builtin/show-ref.c:13
+msgid "git show-ref --exclude-existing[=<pattern>]"
+msgstr "git show-ref --exclude-existing[=<pattern>]"
+
+#: builtin/show-ref.c:162
+msgid "only show tags (can be combined with heads)"
+msgstr "visualizza solo i tag (l'opzione può essere combinata con heads)"
+
+#: builtin/show-ref.c:163
+msgid "only show heads (can be combined with tags)"
+msgstr "visualizza solo le head (l'opzione può essere combinata con tags)"
+
+#: builtin/show-ref.c:164
+msgid "stricter reference checking, requires exact ref path"
+msgstr ""
+"controllo più stringente dei riferimenti, richiede un percorso esatto al "
+"riferimento"
+
+#: builtin/show-ref.c:167 builtin/show-ref.c:169
+msgid "show the HEAD reference, even if it would be filtered out"
+msgstr "visualizza il riferimento HEAD anche se filtrato"
+
+#: builtin/show-ref.c:171
+msgid "dereference tags into object IDs"
+msgstr "dereferenzia i tag in ID oggetto"
+
+#: builtin/show-ref.c:173
+msgid "only show SHA1 hash using <n> digits"
+msgstr "visualizza l'hash SHA1 usando solo <n> caratteri"
+
+#: builtin/show-ref.c:177
+msgid "do not print results to stdout (useful with --verify)"
+msgstr "non stampare i risultati sullo standard output (utile con --verify)"
+
+#: builtin/show-ref.c:179
+msgid "show refs from stdin that aren't in local repository"
+msgstr ""
+"visualizza i riferimenti dati sullo standard input che non sono nel "
+"repository locale"
+
+#: builtin/sparse-checkout.c:20
+msgid "git sparse-checkout (init|list|set|disable) <options>"
+msgstr "git sparse-checkout (init|list|set|disable) <opzioni>"
+
+#: builtin/sparse-checkout.c:61
+msgid "this worktree is not sparse (sparse-checkout file may not exist)"
+msgstr ""
+"questo albero di lavoro non è sparse (il file sparse-checkout potrebbe non"
+" esistere)"
+
+#: builtin/sparse-checkout.c:220
+msgid "failed to set extensions.worktreeConfig setting"
+msgstr "impostazione dell'opzione extensions.worktreeConfig non riuscita"
+
+#: builtin/sparse-checkout.c:237
+msgid "git sparse-checkout init [--cone]"
+msgstr "git sparse-checkout init [--cone]"
+
+#: builtin/sparse-checkout.c:256
+msgid "initialize the sparse-checkout in cone mode"
+msgstr "inizializza il checkout sparse in modalità cone"
+
+#: builtin/sparse-checkout.c:262
+msgid "initialize sparse-checkout"
+msgstr "inizializza sparse-checkout"
+
+#: builtin/sparse-checkout.c:295
+#, c-format
+msgid "failed to open '%s'"
+msgstr "apertura di '%s' non riuscita"
+
+#: builtin/sparse-checkout.c:361
+msgid "git sparse-checkout set (--stdin | <patterns>)"
+msgstr "git sparse-checkout set (--stdin | <pattern>)"
+
+#: builtin/sparse-checkout.c:378
+msgid "read patterns from standard in"
+msgstr "leggi i pattern dallo standard input"
+
+#: builtin/sparse-checkout.c:384
+msgid "set sparse-checkout patterns"
+msgstr "imposta i pattern sparse-checkout"
+
+#: builtin/sparse-checkout.c:447
+msgid "disable sparse-checkout"
+msgstr "disabilita sparse-checkout"
+
+#: builtin/sparse-checkout.c:459
+msgid "error while refreshing working directory"
+msgstr "errore durante l'aggiornamento della directory di lavoro"
+
+#: builtin/stash.c:22 builtin/stash.c:37
+msgid "git stash list [<options>]"
+msgstr "git stash list [<opzioni>]"
+
+#: builtin/stash.c:23 builtin/stash.c:42
+msgid "git stash show [<options>] [<stash>]"
+msgstr "git stash show [<opzioni>] [<stash>]"
+
+#: builtin/stash.c:24 builtin/stash.c:47
+msgid "git stash drop [-q|--quiet] [<stash>]"
+msgstr "git stash drop [-q|--quiet] [<stash>]"
+
+#: builtin/stash.c:25
+msgid "git stash ( pop | apply ) [--index] [-q|--quiet] [<stash>]"
+msgstr "git stash ( pop | apply ) [--index] [-q|--quiet] [<stash>]"
+
+#: builtin/stash.c:26 builtin/stash.c:62
+msgid "git stash branch <branchname> [<stash>]"
+msgstr "git stash branch <nome branch> [<stash>]"
+
+#: builtin/stash.c:27 builtin/stash.c:67
+msgid "git stash clear"
+msgstr "git stash clear"
+
+#: builtin/stash.c:28 builtin/stash.c:77
+msgid ""
+"git stash [push [-p|--patch] [-k|--[no-]keep-index] [-q|--quiet]\n"
+"          [-u|--include-untracked] [-a|--all] [-m|--message <message>]\n"
+"          [--] [<pathspec>...]]"
+msgstr ""
+"git stash [push [-p|--patch] [-k|--[no-]keep-index] [-q|--quiet]\n"
+"          [-u|--include-untracked] [-a|--all] [-m|--message <messaggio>]\n"
+"          [--] [<specificatore percorso>...]]"
+
+#: builtin/stash.c:31 builtin/stash.c:84
+msgid ""
+"git stash save [-p|--patch] [-k|--[no-]keep-index] [-q|--quiet]\n"
+"          [-u|--include-untracked] [-a|--all] [<message>]"
+msgstr ""
+"git stash save [-p|--patch] [-k|--[no-]keep-index] [-q|--quiet]\n"
+"          [-u|--include-untracked] [-a|--all] [<messaggio>]"
+
+#: builtin/stash.c:52
+msgid "git stash pop [--index] [-q|--quiet] [<stash>]"
+msgstr "git stash pop [--index] [-q|--quiet] [<stash>]"
+
+#: builtin/stash.c:57
+msgid "git stash apply [--index] [-q|--quiet] [<stash>]"
+msgstr "git stash apply [--index] [-q|--quiet] [<stash>]"
+
+#: builtin/stash.c:72
+msgid "git stash store [-m|--message <message>] [-q|--quiet] <commit>"
+msgstr "git stash store [-m|--message <messaggio>] [-q|--quiet] <commit>"
+
+#: builtin/stash.c:127
+#, c-format
+msgid "'%s' is not a stash-like commit"
+msgstr "'%s' non è un commit simile a uno stash"
+
+#: builtin/stash.c:147
+#, c-format
+msgid "Too many revisions specified:%s"
+msgstr "Troppe revisioni specificate:%s"
+
+#: builtin/stash.c:161 git-legacy-stash.sh:549
+msgid "No stash entries found."
+msgstr "Nessuna voce di stash trovata."
+
+#: builtin/stash.c:175
+#, c-format
+msgid "%s is not a valid reference"
+msgstr "%s non è un riferimento valido"
+
+#: builtin/stash.c:224 git-legacy-stash.sh:75
+msgid "git stash clear with parameters is unimplemented"
+msgstr "git stash clear con parametri non è implementato"
+
+#: builtin/stash.c:403
+msgid "cannot apply a stash in the middle of a merge"
+msgstr "impossibile applicare uno stash nel mezzo di un merge"
+
+#: builtin/stash.c:414
+#, c-format
+msgid "could not generate diff %s^!."
+msgstr "impossibile generare il diff %s^!"
+
+#: builtin/stash.c:421
+msgid "conflicts in index.Try without --index."
+msgstr "ci sono conflitti nell'indice. Prova senza --index."
+
+#: builtin/stash.c:427
+msgid "could not save index tree"
+msgstr "impossibile salvare l'albero indice"
+
+#: builtin/stash.c:436
+msgid "could not restore untracked files from stash"
+msgstr "non è stato possibile ripristinare i file non tracciati dallo stash"
+
+#: builtin/stash.c:450
+#, c-format
+msgid "Merging %s with %s"
+msgstr "Merge di %s con %s in corso"
+
+#: builtin/stash.c:460 git-legacy-stash.sh:681
+msgid "Index was not unstashed."
+msgstr "L'indice non è stato rimosso dallo stash."
+
+#: builtin/stash.c:521 builtin/stash.c:620
+msgid "attempt to recreate the index"
+msgstr "tenta di ricreare l'indice"
+
+#: builtin/stash.c:554
+#, c-format
+msgid "Dropped %s (%s)"
+msgstr "Ho scartato %s (%s)"
+
+#: builtin/stash.c:557
+#, c-format
+msgid "%s: Could not drop stash entry"
+msgstr "%s: Impossibile scartare la voce di stash"
+
+#: builtin/stash.c:582
+#, c-format
+msgid "'%s' is not a stash reference"
+msgstr "'%s' non è un riferimento stash"
+
+#: builtin/stash.c:632 git-legacy-stash.sh:695
+msgid "The stash entry is kept in case you need it again."
+msgstr ""
+"La voce di stash è mantenuta nel caso in cui tu ne abbia nuovamente bisogno."
+
+#: builtin/stash.c:655 git-legacy-stash.sh:713
+msgid "No branch name specified"
+msgstr "Nome del branch non specificato"
+
+#: builtin/stash.c:795 builtin/stash.c:832
+#, c-format
+msgid "Cannot update %s with %s"
+msgstr "Impossibile aggiornare %s con %s"
+
+#: builtin/stash.c:813 builtin/stash.c:1470 builtin/stash.c:1506
+msgid "stash message"
+msgstr "messaggio di stash"
+
+#: builtin/stash.c:823
+msgid "\"git stash store\" requires one <commit> argument"
+msgstr "\"git stash store\" richiede un argomento <commit>"
+
+#: builtin/stash.c:1045 git-legacy-stash.sh:218
+msgid "No changes selected"
+msgstr "Nessuna modifica selezionata"
+
+#: builtin/stash.c:1145 git-legacy-stash.sh:150
+msgid "You do not have the initial commit yet"
+msgstr "Non hai ancora un commit iniziale"
+
+#: builtin/stash.c:1172 git-legacy-stash.sh:165
+msgid "Cannot save the current index state"
+msgstr "Impossibile salvare lo stato corrente di index"
+
+#: builtin/stash.c:1181 git-legacy-stash.sh:180
+msgid "Cannot save the untracked files"
+msgstr "Impossibile salvare i file non tracciati"
+
+#: builtin/stash.c:1192 builtin/stash.c:1201 git-legacy-stash.sh:201
+#: git-legacy-stash.sh:214
+msgid "Cannot save the current worktree state"
+msgstr "Impossibile salvare lo stato corrente dell'albero di lavoro"
+
+#: builtin/stash.c:1229 git-legacy-stash.sh:234
+msgid "Cannot record working tree state"
+msgstr "Impossibile registrare lo stato dell'albero di lavoro"
+
+#: builtin/stash.c:1278 git-legacy-stash.sh:338
+msgid "Can't use --patch and --include-untracked or --all at the same time"
+msgstr ""
+"Impossibile usare --patch e --include-untracked o --all allo stesso tempo"
+
+#: builtin/stash.c:1294
+msgid "Did you forget to 'git add'?"
+msgstr "Ti sei scordato di eseguire 'git add'?"
+
+#: builtin/stash.c:1309 git-legacy-stash.sh:346
+msgid "No local changes to save"
+msgstr "Nessuna modifica locale da salvare"
+
+#: builtin/stash.c:1316 git-legacy-stash.sh:351
+msgid "Cannot initialize stash"
+msgstr "Impossibile inizializzare stash"
+
+#: builtin/stash.c:1331 git-legacy-stash.sh:355
+msgid "Cannot save the current status"
+msgstr "Impossibile salvare lo stato attuale"
+
+#: builtin/stash.c:1336
+#, c-format
+msgid "Saved working directory and index state %s"
+msgstr "Directory di lavoro e stato indice salvati: %s"
+
+#: builtin/stash.c:1426 git-legacy-stash.sh:385
+msgid "Cannot remove worktree changes"
+msgstr "Impossibile rimuovere le modifiche all'albero di lavoro"
+
+#: builtin/stash.c:1461 builtin/stash.c:1497
+msgid "keep index"
+msgstr "mantieni l'indice"
+
+#: builtin/stash.c:1463 builtin/stash.c:1499
+msgid "stash in patch mode"
+msgstr "esegui lo stash in modalità patch"
+
+#: builtin/stash.c:1464 builtin/stash.c:1500
+msgid "quiet mode"
+msgstr "modalità silenziosa"
+
+#: builtin/stash.c:1466 builtin/stash.c:1502
+msgid "include untracked files in stash"
+msgstr "includi i file non tracciati nello stash"
+
+#: builtin/stash.c:1468 builtin/stash.c:1504
+msgid "include ignore files"
+msgstr "includi i file ignorati"
+
+#: builtin/stash.c:1564
+#, c-format
+msgid "could not exec %s"
+msgstr "impossibile eseguire %s"
+
+#: builtin/stripspace.c:18
+msgid "git stripspace [-s | --strip-comments]"
+msgstr "git stripspace [-s | --strip-comments]"
+
+#: builtin/stripspace.c:19
+msgid "git stripspace [-c | --comment-lines]"
+msgstr "git stripspace [-c | --comment-lines]"
+
+#: builtin/stripspace.c:37
+msgid "skip and remove all lines starting with comment character"
+msgstr "salta e rimuovi tutte le righe che iniziano con un carattere commento"
+
+#: builtin/stripspace.c:40
+msgid "prepend comment character and space to each line"
+msgstr "anteponi il carattere commento e uno spazio a ogni riga"
+
+#: builtin/submodule--helper.c:47 builtin/submodule--helper.c:1970
+#, c-format
+msgid "Expecting a full ref name, got %s"
+msgstr "Atteso nome riferimento completo, ricevuto %s"
+
+#: builtin/submodule--helper.c:64
+msgid "submodule--helper print-default-remote takes no arguments"
+msgstr "submodule--helper print-default-remote non richiede argomenti"
+
+#: builtin/submodule--helper.c:102
+#, c-format
+msgid "cannot strip one component off url '%s'"
+msgstr "impossibile rimuovere un componente dall'URL '%s'"
+
+#: builtin/submodule--helper.c:410 builtin/submodule--helper.c:1380
+msgid "alternative anchor for relative paths"
+msgstr "ancoraggio alternativo per i percorsi relativi"
+
+#: builtin/submodule--helper.c:415
+msgid "git submodule--helper list [--prefix=<path>] [<path>...]"
+msgstr "git submodule--helper list [--prefix=<percorso>] [<percorso>...]"
+
+#: builtin/submodule--helper.c:472 builtin/submodule--helper.c:630
+#: builtin/submodule--helper.c:653
+#, c-format
+msgid "No url found for submodule path '%s' in .gitmodules"
+msgstr "Nessun URL trovato in .gitmodules per il percorso del sottomodulo '%s'"
+
+#: builtin/submodule--helper.c:524
+#, c-format
+msgid "Entering '%s'\n"
+msgstr "Entro in '%s'\n"
+
+#: builtin/submodule--helper.c:527
+#, c-format
+msgid ""
+"run_command returned non-zero status for %s\n"
+"."
+msgstr ""
+"run_command ha restituito un codice diverso da zero per %s\n"
+"."
+
+#: builtin/submodule--helper.c:549
+#, c-format
+msgid ""
+"run_command returned non-zero status while recursing in the nested "
+"submodules of %s\n"
+"."
+msgstr ""
+"run_command ha restituito un codice diverso da zero durante la ricorsione "
+"nei sottomoduli innestati di %s\n"
+"."
+
+#: builtin/submodule--helper.c:565
+msgid "Suppress output of entering each submodule command"
+msgstr "Non visualizzare l'output dei comandi eseguiti in ogni sottomodulo"
+
+#: builtin/submodule--helper.c:567 builtin/submodule--helper.c:1053
+msgid "Recurse into nested submodules"
+msgstr "Esegui ricorsivamente sui sottomoduli innestati"
+
+#: builtin/submodule--helper.c:572
+msgid "git submodule--helper foreach [--quiet] [--recursive] [--] <command>"
+msgstr "git submodule--helper foreach [--quiet] [--recursive] [--] <comando>"
+
+#: builtin/submodule--helper.c:599
+#, c-format
+msgid ""
+"could not look up configuration '%s'. Assuming this repository is its own "
+"authoritative upstream."
+msgstr ""
+"impossibile trovare la configurazione '%s'. Assumo che questo repository sia "
+"il proprio repository autoritativo upstream."
+
+#: builtin/submodule--helper.c:667
+#, c-format
+msgid "Failed to register url for submodule path '%s'"
+msgstr "Registrazione dell'URL per il percorso sottomodulo '%s' non riuscita"
+
+#: builtin/submodule--helper.c:671
+#, c-format
+msgid "Submodule '%s' (%s) registered for path '%s'\n"
+msgstr "Sottomodulo '%s' (%s) registrato per il percorso '%s'\n"
+
+#: builtin/submodule--helper.c:681
+#, c-format
+msgid "warning: command update mode suggested for submodule '%s'\n"
+msgstr ""
+"avviso: suggerita modalità comando aggiornamento per il sottomodulo '%s'\n"
+
+#: builtin/submodule--helper.c:688
+#, c-format
+msgid "Failed to register update mode for submodule path '%s'"
+msgstr ""
+"Registrazione della modalità aggiornamento per il percorso sottomodulo '%s'"
+
+#: builtin/submodule--helper.c:710
+msgid "Suppress output for initializing a submodule"
+msgstr "Non visualizzare l'output dell'inizializzazione del sottomodulo"
+
+#: builtin/submodule--helper.c:715
+msgid "git submodule--helper init [<options>] [<path>]"
+msgstr "git submodule--helper init [<opzioni>] [<percorso>]"
+
+#: builtin/submodule--helper.c:787 builtin/submodule--helper.c:914
+#, c-format
+msgid "no submodule mapping found in .gitmodules for path '%s'"
+msgstr "mapping sottomodulo per il percorso '%s' non trovato in .gitmodules"
+
+#: builtin/submodule--helper.c:827
+#, c-format
+msgid "could not resolve HEAD ref inside the submodule '%s'"
+msgstr "impossibile risolvere il riferimento HEAD nel sottomodulo '%s'"
+
+#: builtin/submodule--helper.c:854 builtin/submodule--helper.c:1023
+#, c-format
+msgid "failed to recurse into submodule '%s'"
+msgstr "ricorsione nel sottomodulo '%s' non riuscita"
+
+#: builtin/submodule--helper.c:878 builtin/submodule--helper.c:1189
+msgid "Suppress submodule status output"
+msgstr "Non visualizzare l'output dello stato del sottomodulo"
+
+#: builtin/submodule--helper.c:879
+msgid ""
+"Use commit stored in the index instead of the one stored in the submodule "
+"HEAD"
+msgstr ""
+"Usa il commit salvato nell'indice anziché quello salvato nell'HEAD del "
+"sottomodulo"
+
+#: builtin/submodule--helper.c:880
+msgid "recurse into nested submodules"
+msgstr "esegui ricorsivamente sui sottomoduli innestati"
+
+#: builtin/submodule--helper.c:885
+msgid "git submodule status [--quiet] [--cached] [--recursive] [<path>...]"
+msgstr ""
+"git submodule status [--quiet] [--cached] [--recursive] [<percorso>...]"
+
+#: builtin/submodule--helper.c:909
+msgid "git submodule--helper name <path>"
+msgstr "git submodule--helper name <percorso>"
+
+#: builtin/submodule--helper.c:973
+#, c-format
+msgid "Synchronizing submodule url for '%s'\n"
+msgstr "Sincronizzazione URL sottomodulo per '%s' in corso\n"
+
+#: builtin/submodule--helper.c:979
+#, c-format
+msgid "failed to register url for submodule path '%s'"
+msgstr "registrazione dell'URL per il percorso sottomodulo '%s' non riuscita"
+
+#: builtin/submodule--helper.c:993
+#, c-format
+msgid "failed to get the default remote for submodule '%s'"
+msgstr "recupero del remoto predefinito per il sottomodulo '%s' non riuscito"
+
+#: builtin/submodule--helper.c:1004
+#, c-format
+msgid "failed to update remote for submodule '%s'"
+msgstr "aggiornamento del remoto per il sottomodulo '%s' non riuscito"
+
+#: builtin/submodule--helper.c:1051
+msgid "Suppress output of synchronizing submodule url"
+msgstr ""
+"Non visualizzare l'output della sincronizzazione dell'URL del sottomodulo"
+
+#: builtin/submodule--helper.c:1058
+msgid "git submodule--helper sync [--quiet] [--recursive] [<path>]"
+msgstr "git submodule--helper sync [--quiet] [--recursive] [<percorso>]"
+
+#: builtin/submodule--helper.c:1112
+#, c-format
+msgid ""
+"Submodule work tree '%s' contains a .git directory (use 'rm -rf' if you "
+"really want to remove it including all of its history)"
+msgstr ""
+"L'albero di lavoro del sottomodulo ('%s') contiene una directory .git (usa "
+"'rm -rf' se vuoi veramente rimuoverla, inclusa l'intera sua cronologia)"
+
+#: builtin/submodule--helper.c:1124
+#, c-format
+msgid ""
+"Submodule work tree '%s' contains local modifications; use '-f' to discard "
+"them"
+msgstr ""
+"L'albero di lavoro del sottomodulo ('%s') contiene modifiche locali; usa '-"
+"f' per scartarle"
+
+#: builtin/submodule--helper.c:1132
+#, c-format
+msgid "Cleared directory '%s'\n"
+msgstr "Directory '%s' ripulita\n"
+
+#: builtin/submodule--helper.c:1134
+#, c-format
+msgid "Could not remove submodule work tree '%s'\n"
+msgstr "Impossibile rimuovere l'albero di lavoro del sottomodulo '%s'\n"
+
+#: builtin/submodule--helper.c:1145
+#, c-format
+msgid "could not create empty submodule directory %s"
+msgstr "impossibile creare la directory vuota del sottomodulo %s"
+
+#: builtin/submodule--helper.c:1161
+#, c-format
+msgid "Submodule '%s' (%s) unregistered for path '%s'\n"
+msgstr "Rimossa registrazione sottomodulo '%s' (%s) per il percorso '%s'\n"
+
+#: builtin/submodule--helper.c:1190
+msgid "Remove submodule working trees even if they contain local changes"
+msgstr ""
+"Rimuovi gli alberi di lavoro dei sottomoduli anche se contengono modifiche "
+"locali"
+
+#: builtin/submodule--helper.c:1191
+msgid "Unregister all submodules"
+msgstr "Annulla la registrazione di tutti i sottomoduli"
+
+#: builtin/submodule--helper.c:1196
+msgid ""
+"git submodule deinit [--quiet] [-f | --force] [--all | [--] [<path>...]]"
+msgstr ""
+"git submodule deinit [--quiet] [-f | --force] [--all | [--] [<percorso>...]]"
+
+#: builtin/submodule--helper.c:1210
+msgid "Use '--all' if you really want to deinitialize all submodules"
+msgstr "Usa '--all' se vuoi veramente deinizializzare tutti i sottomoduli"
+
+#: builtin/submodule--helper.c:1275
+msgid ""
+"An alternate computed from a superproject's alternate is invalid.\n"
+"To allow Git to clone without an alternate in such a case, set\n"
+"submodule.alternateErrorStrategy to 'info' or, equivalently, clone with\n"
+"'--reference-if-able' instead of '--reference'."
+msgstr ""
+"Un alternato calcolato a partire dall'alternato di un progetto di livello\n"
+"superiore non è valido.\n"
+"Per consentire a Git di eseguire il clone senza alternati in tal caso,"
+" imposta\n"
+"submodule.alternateErrorStrategy a 'info' o, equivalentemente, esegui il"
+" clone\n"
+"con l'opzione '--reference-if-able' anziché '--reference'."
+
+#: builtin/submodule--helper.c:1314 builtin/submodule--helper.c:1317
+#, c-format
+msgid "submodule '%s' cannot add alternate: %s"
+msgstr "non è possibile aggiungere un alternato per il sottomodulo '%s': %s"
+
+#: builtin/submodule--helper.c:1353
+#, c-format
+msgid "Value '%s' for submodule.alternateErrorStrategy is not recognized"
+msgstr "Valore '%s' per submodule.alternateErrorStrategy non riconosciuto"
+
+#: builtin/submodule--helper.c:1360
+#, c-format
+msgid "Value '%s' for submodule.alternateLocation is not recognized"
+msgstr "Valore '%s' per submodule.alternateLocation non riconosciuto"
+
+#: builtin/submodule--helper.c:1383
+msgid "where the new submodule will be cloned to"
+msgstr "percorso in cui sarà clonato il nuovo sottomodulo"
+
+#: builtin/submodule--helper.c:1386
+msgid "name of the new submodule"
+msgstr "nome del nuovo sottomodulo"
+
+#: builtin/submodule--helper.c:1389
+msgid "url where to clone the submodule from"
+msgstr "URL da cui clonare il sottomodulo"
+
+#: builtin/submodule--helper.c:1397
+msgid "depth for shallow clones"
+msgstr "profondità per i cloni shallow"
+
+#: builtin/submodule--helper.c:1400 builtin/submodule--helper.c:1897
+msgid "force cloning progress"
+msgstr "forza l'indicazione d'avanzamento della clonazione"
+
+#: builtin/submodule--helper.c:1402 builtin/submodule--helper.c:1899
+msgid "disallow cloning into non-empty directory"
+msgstr "disabilita il clone in una directory non vuota"
+
+#: builtin/submodule--helper.c:1407
+msgid ""
+"git submodule--helper clone [--prefix=<path>] [--quiet] [--reference "
+"<repository>] [--name <name>] [--depth <depth>] --url <url> --path <path>"
+msgstr ""
+"git submodule--helper clone [--prefix=<percorso>] [--quiet] [--reference "
+"<repository>] [--name <nome>] [--depth <profondità>] --url <URL> --path "
+"<percorso>"
+
+#: builtin/submodule--helper.c:1431
+#, c-format
+msgid "refusing to create/use '%s' in another submodule's git dir"
+msgstr ""
+"mi rifiuto di creare/usare '%s' nella directory Git di un altro sottomodulo"
+
+#: builtin/submodule--helper.c:1442
+#, c-format
+msgid "clone of '%s' into submodule path '%s' failed"
+msgstr "clone di '%s' nel percorso del sottomodulo ('%s') non riuscito"
+
+#: builtin/submodule--helper.c:1446
+#, c-format
+msgid "directory not empty: '%s'"
+msgstr "directory non vuota: '%s'"
+
+#: builtin/submodule--helper.c:1458
+#, c-format
+msgid "could not get submodule directory for '%s'"
+msgstr "impossibile recuperare la directory del sottomodulo per '%s'"
+
+#: builtin/submodule--helper.c:1494
+#, c-format
+msgid "Invalid update mode '%s' for submodule path '%s'"
+msgstr ""
+"Modalità aggiornamento '%s' non valida per il percorso del sottomodulo ('%s')"
+
+#: builtin/submodule--helper.c:1498
+#, c-format
+msgid "Invalid update mode '%s' configured for submodule path '%s'"
+msgstr ""
+"È stata configurata una modalità aggiornamento '%s' non valida per il "
+"percorso del sottomodulo ('%s')"
+
+#: builtin/submodule--helper.c:1594
+#, c-format
+msgid "Submodule path '%s' not initialized"
+msgstr "Percorso del sottomodulo ('%s') non inizializzato"
+
+#: builtin/submodule--helper.c:1598
+msgid "Maybe you want to use 'update --init'?"
+msgstr "Potresti voler usare 'update --init'."
+
+#: builtin/submodule--helper.c:1628
+#, c-format
+msgid "Skipping unmerged submodule %s"
+msgstr "Ignoro il sottomodulo %s non sottoposto a merge"
+
+#: builtin/submodule--helper.c:1657
+#, c-format
+msgid "Skipping submodule '%s'"
+msgstr "Ignoro il sottomodulo '%s'"
+
+#: builtin/submodule--helper.c:1803
+#, c-format
+msgid "Failed to clone '%s'. Retry scheduled"
+msgstr "Clone di '%s' non riuscito. Nuovo tentativo programmato"
+
+#: builtin/submodule--helper.c:1814
+#, c-format
+msgid "Failed to clone '%s' a second time, aborting"
+msgstr ""
+"Clone di '%s' non riuscito per la seconda volta, interrompo l'operazione"
+
+#: builtin/submodule--helper.c:1876 builtin/submodule--helper.c:2120
+msgid "path into the working tree"
+msgstr "percorso nell'albero di lavoro"
+
+#: builtin/submodule--helper.c:1879
+msgid "path into the working tree, across nested submodule boundaries"
+msgstr ""
+"percorso nell'albero di lavoro attraverso i confini dei sottomoduli innestati"
+
+#: builtin/submodule--helper.c:1883
+msgid "rebase, merge, checkout or none"
+msgstr "rebase, merge, checkout o none"
+
+#: builtin/submodule--helper.c:1889
+msgid "Create a shallow clone truncated to the specified number of revisions"
+msgstr "Crea un clone shallow limitato al numero di revisioni specificato"
+
+#: builtin/submodule--helper.c:1892
+msgid "parallel jobs"
+msgstr "processi da eseguire in parallelo"
+
+#: builtin/submodule--helper.c:1894
+msgid "whether the initial clone should follow the shallow recommendation"
+msgstr "determina se il clone iniziale sarà shallow come raccomandato"
+
+#: builtin/submodule--helper.c:1895
+msgid "don't print cloning progress"
+msgstr "non stampare l'indicazione di avanzamento della clonazione"
+
+#: builtin/submodule--helper.c:1904
+msgid "git submodule--helper update-clone [--prefix=<path>] [<path>...]"
+msgstr ""
+"git submodule--helper update-clone [--prefix=<percorso>] [<percorso>...]"
+
+#: builtin/submodule--helper.c:1917
+msgid "bad value for update parameter"
+msgstr "valore parametro aggiornamento errato"
+
+#: builtin/submodule--helper.c:1965
+#, c-format
+msgid ""
+"Submodule (%s) branch configured to inherit branch from superproject, but "
+"the superproject is not on any branch"
+msgstr ""
+"Il branch del sottomodulo (%s) è configurato in modo da ereditare il branch "
+"dal progetto al livello superiore, ma questo non è su alcun branch"
+
+#: builtin/submodule--helper.c:2088
+#, c-format
+msgid "could not get a repository handle for submodule '%s'"
+msgstr "impossibile recuperare un handle repository per il sottomodulo '%s'"
+
+#: builtin/submodule--helper.c:2121
+msgid "recurse into submodules"
+msgstr "esegui ricorsivamente sui sottomoduli"
+
+#: builtin/submodule--helper.c:2127
+msgid "git submodule--helper absorb-git-dirs [<options>] [<path>...]"
+msgstr "git submodule--helper absorb-git-dirs [<opzioni>] [<percorso>...]"
+
+#: builtin/submodule--helper.c:2183
+msgid "check if it is safe to write to the .gitmodules file"
+msgstr "controlla se è sicuro scrivere sul file .gitmodules"
+
+#: builtin/submodule--helper.c:2186
+msgid "unset the config in the .gitmodules file"
+msgstr "rimuovi la configurazione nel file .gitmodules"
+
+#: builtin/submodule--helper.c:2191
+msgid "git submodule--helper config <name> [<value>]"
+msgstr "git submodule--helper config <nome> [<valore>]"
+
+#: builtin/submodule--helper.c:2192
+msgid "git submodule--helper config --unset <name>"
+msgstr "git submodule--helper config --unset <nome>"
+
+#: builtin/submodule--helper.c:2193
+msgid "git submodule--helper config --check-writeable"
+msgstr "git submodule--helper config --check-writeable"
+
+#: builtin/submodule--helper.c:2212 git-submodule.sh:173
+#, sh-format
+msgid "please make sure that the .gitmodules file is in the working tree"
+msgstr "assicurati che il file .gitmodules sia nell'albero di lavoro"
+
+#: builtin/submodule--helper.c:2262 git.c:433 git.c:684
+#, c-format
+msgid "%s doesn't support --super-prefix"
+msgstr "%s non supporta --super-prefix"
+
+#: builtin/submodule--helper.c:2268
+#, c-format
+msgid "'%s' is not a valid submodule--helper subcommand"
+msgstr "'%s' non è un sottocomando submodule--helper valido"
+
+#: builtin/symbolic-ref.c:8
+msgid "git symbolic-ref [<options>] <name> [<ref>]"
+msgstr "git symbolic-ref [<opzioni>] <nome> [<riferimento>]"
+
+#: builtin/symbolic-ref.c:9
+msgid "git symbolic-ref -d [-q] <name>"
+msgstr "git symbolic-ref -d [-q] <nome>"
+
+#: builtin/symbolic-ref.c:40
+msgid "suppress error message for non-symbolic (detached) refs"
+msgstr ""
+"non visualizzare messaggi d'errore se ci sono riferimenti non simbolici "
+"(scollegati)"
+
+#: builtin/symbolic-ref.c:41
+msgid "delete symbolic ref"
+msgstr "elimina riferimento simbolico"
+
+#: builtin/symbolic-ref.c:42
+msgid "shorten ref output"
+msgstr "abbrevia il riferimento nell'output"
+
+#: builtin/symbolic-ref.c:43 builtin/update-ref.c:363
+msgid "reason"
+msgstr "motivo"
+
+#: builtin/symbolic-ref.c:43 builtin/update-ref.c:363
+msgid "reason of the update"
+msgstr "motivo dell'aggiornamento"
+
+#: builtin/tag.c:25
+msgid ""
+"git tag [-a | -s | -u <key-id>] [-f] [-m <msg> | -F <file>]\n"
+"\t\t<tagname> [<head>]"
+msgstr ""
+"git tag [-a | -s | -u <ID chiave>] [-f] [-m <messaggio> | -F <file>]\n"
+"\t\t<nome tag> [<head>]"
+
+#: builtin/tag.c:27
+msgid "git tag -d <tagname>..."
+msgstr "git tag -d <nome tag>..."
+
+#: builtin/tag.c:28
+msgid ""
+"git tag -l [-n[<num>]] [--contains <commit>] [--no-contains <commit>] [--"
+"points-at <object>]\n"
+"\t\t[--format=<format>] [--[no-]merged [<commit>]] [<pattern>...]"
+msgstr ""
+"git tag -l [-n[<numero>]] [--contains <commit>] [--no-contains <commit>] [--"
+"points-at <oggetto>]\n"
+"\t\t[--format=<formato>] [--[no-]merged [<commit>]] [<pattern>...]"
+
+#: builtin/tag.c:30
+msgid "git tag -v [--format=<format>] <tagname>..."
+msgstr "git tag -v [--format=<formato>] <nome tag>..."
+
+#: builtin/tag.c:89
+#, c-format
+msgid "tag '%s' not found."
+msgstr "tag '%s' non trovato."
+
+#: builtin/tag.c:105
+#, c-format
+msgid "Deleted tag '%s' (was %s)\n"
+msgstr "Tag '%s' eliminato (era %s)\n"
+
+#: builtin/tag.c:135
+#, c-format
+msgid ""
+"\n"
+"Write a message for tag:\n"
+"  %s\n"
+"Lines starting with '%c' will be ignored.\n"
+msgstr ""
+"\n"
+"Scrivi un messaggio per il tag:\n"
+"  %s\n"
+"Le righe che iniziano con '%c' saranno ignorate.\n"
+
+#: builtin/tag.c:139
+#, c-format
+msgid ""
+"\n"
+"Write a message for tag:\n"
+"  %s\n"
+"Lines starting with '%c' will be kept; you may remove them yourself if you "
+"want to.\n"
+msgstr ""
+"\n"
+"Scrivi un messaggio per il tag:\n"
+"  %s\n"
+"Le righe che iniziano con '%c' saranno mantenute; puoi rimuoverle "
+"autonomamente se lo desideri.\n"
+
+#: builtin/tag.c:198
+msgid "unable to sign the tag"
+msgstr "impossibile firmare il tag"
+
+#: builtin/tag.c:200
+msgid "unable to write tag file"
+msgstr "impossibile scrivere il file tag"
+
+#: builtin/tag.c:216
+#, c-format
+msgid ""
+"You have created a nested tag. The object referred to by your new tag is\n"
+"already a tag. If you meant to tag the object that it points to, use:\n"
+"\n"
+"\tgit tag -f %s %s^{}"
+msgstr ""
+"Hai creato un tag innestato. L'oggetto a cui si riferisce il tuo nuovo\n"
+"tag è già un tag. Se intendevi aggiungere un tag all'oggetto a cui\n"
+"punta, usa:\n"
+"\n"
+"\tgit tag -f %s %s^{}"
+
+#: builtin/tag.c:232
+msgid "bad object type."
+msgstr "tipo oggetto errato."
+
+#: builtin/tag.c:284
+msgid "no tag message?"
+msgstr "nessun messaggio per il tag?"
+
+#: builtin/tag.c:291
+#, c-format
+msgid "The tag message has been left in %s\n"
+msgstr "Il messaggio del tag è stato lasciato in %s\n"
+
+#: builtin/tag.c:402
+msgid "list tag names"
+msgstr "elenca i nomi dei tag"
+
+#: builtin/tag.c:404
+msgid "print <n> lines of each tag message"
+msgstr "stampa le prime <n> righe di ogni messaggio tag"
+
+#: builtin/tag.c:406
+msgid "delete tags"
+msgstr "elimina tag"
+
+#: builtin/tag.c:407
+msgid "verify tags"
+msgstr "verifica tag"
+
+#: builtin/tag.c:409
+msgid "Tag creation options"
+msgstr "Opzioni creazione tag"
+
+#: builtin/tag.c:411
+msgid "annotated tag, needs a message"
+msgstr "tag annotato, richiede un messaggio"
+
+#: builtin/tag.c:413
+msgid "tag message"
+msgstr "messaggio tag"
+
+#: builtin/tag.c:415
+msgid "force edit of tag message"
+msgstr "forza modifica del messaggio tag"
+
+#: builtin/tag.c:416
+msgid "annotated and GPG-signed tag"
+msgstr "tag annotato e firmato con GPG"
+
+#: builtin/tag.c:419
+msgid "use another key to sign the tag"
+msgstr "usa un'altra chiave per firmare il tag"
+
+#: builtin/tag.c:420
+msgid "replace the tag if exists"
+msgstr "sostituisci il tag se esiste"
+
+#: builtin/tag.c:421 builtin/update-ref.c:369
+msgid "create a reflog"
+msgstr "crea un registro riferimenti"
+
+#: builtin/tag.c:423
+msgid "Tag listing options"
+msgstr "Opzioni elenco tag"
+
+#: builtin/tag.c:424
+msgid "show tag list in columns"
+msgstr "visualizza l'elenco dei tag in colonne"
+
+#: builtin/tag.c:425 builtin/tag.c:427
+msgid "print only tags that contain the commit"
+msgstr "stampa solo i tag che contengono il commit"
+
+#: builtin/tag.c:426 builtin/tag.c:428
+msgid "print only tags that don't contain the commit"
+msgstr "stampa solo i tag che non contengono i commit"
+
+#: builtin/tag.c:429
+msgid "print only tags that are merged"
+msgstr "stampa solo i tag sottoposti a merge"
+
+#: builtin/tag.c:430
+msgid "print only tags that are not merged"
+msgstr "stampa solo i tag non sottoposti a merge"
+
+#: builtin/tag.c:434
+msgid "print only tags of the object"
+msgstr "stampa solo i tag dell'oggetto"
+
+#: builtin/tag.c:482
+msgid "--column and -n are incompatible"
+msgstr "--column e -n non sono compatibili"
+
+#: builtin/tag.c:504
+msgid "-n option is only allowed in list mode"
+msgstr "l'opzione -n è consentita solo in modalità elenco"
+
+#: builtin/tag.c:506
+msgid "--contains option is only allowed in list mode"
+msgstr "l'opzione --contains è consentita solo in modalità elenco"
+
+#: builtin/tag.c:508
+msgid "--no-contains option is only allowed in list mode"
+msgstr "l'opzione --no-contains è consentita solo in modalità elenco"
+
+#: builtin/tag.c:510
+msgid "--points-at option is only allowed in list mode"
+msgstr "l'opzione --points-at è consentita solo in modalità elenco"
+
+#: builtin/tag.c:512
+msgid "--merged and --no-merged options are only allowed in list mode"
+msgstr ""
+"le opzioni --merged e --no-merged sono consentite solo in modalità elenco"
+
+#: builtin/tag.c:523
+msgid "only one -F or -m option is allowed."
+msgstr "è consentita una sola opzione tra -F e -m."
+
+#: builtin/tag.c:542
+msgid "too many params"
+msgstr "troppi parametri"
+
+#: builtin/tag.c:548
+#, c-format
+msgid "'%s' is not a valid tag name."
+msgstr "'%s' non è un nome tag valido."
+
+#: builtin/tag.c:553
+#, c-format
+msgid "tag '%s' already exists"
+msgstr "il tag '%s' esiste già"
+
+#: builtin/tag.c:584
+#, c-format
+msgid "Updated tag '%s' (was %s)\n"
+msgstr "Tag '%s' aggiornato (era %s)\n"
+
+#: builtin/unpack-objects.c:501
+msgid "Unpacking objects"
+msgstr "Decompressione degli oggetti in corso"
+
+#: builtin/update-index.c:84
+#, c-format
+msgid "failed to create directory %s"
+msgstr "creazione della directory %s non riuscita"
+
+#: builtin/update-index.c:100
+#, c-format
+msgid "failed to create file %s"
+msgstr "creazione del file %s non riuscita"
+
+#: builtin/update-index.c:108
+#, c-format
+msgid "failed to delete file %s"
+msgstr "eliminazione del file %s non riuscita"
+
+#: builtin/update-index.c:115 builtin/update-index.c:221
+#, c-format
+msgid "failed to delete directory %s"
+msgstr "eliminazione della directory %s non riuscita"
+
+#: builtin/update-index.c:140
+#, c-format
+msgid "Testing mtime in '%s' "
+msgstr "Test di mtime in '%s' in corso "
+
+#: builtin/update-index.c:154
+msgid "directory stat info does not change after adding a new file"
+msgstr ""
+"le informazioni stat della directory non cambiano dopo l'aggiunta di un "
+"nuovo file"
+
+#: builtin/update-index.c:167
+msgid "directory stat info does not change after adding a new directory"
+msgstr ""
+"le informazioni stat della directory non cambiano dopo l'aggiunta di una "
+"nuova directory"
+
+#: builtin/update-index.c:180
+msgid "directory stat info changes after updating a file"
+msgstr ""
+"le informazioni stat della directory cambiano dopo l'aggiornamento di un file"
+
+#: builtin/update-index.c:191
+msgid "directory stat info changes after adding a file inside subdirectory"
+msgstr ""
+"le informazioni stat della directory cambiano dopo l'aggiunta di un file in "
+"una sottodirectory"
+
+#: builtin/update-index.c:202
+msgid "directory stat info does not change after deleting a file"
+msgstr ""
+"le informazioni stat della directory non cambiano dopo l'eliminazione di un "
+"file"
+
+#: builtin/update-index.c:215
+msgid "directory stat info does not change after deleting a directory"
+msgstr ""
+"le informazioni stat della directory non cambiano dopo l'eliminazione di una "
+"directory"
+
+#: builtin/update-index.c:222
+msgid " OK"
+msgstr " OK"
+
+#: builtin/update-index.c:591
+msgid "git update-index [<options>] [--] [<file>...]"
+msgstr "git update-index [<opzioni>] [--] [<file>...]"
+
+#: builtin/update-index.c:974
+msgid "continue refresh even when index needs update"
+msgstr ""
+"continua l'aggiornamento anche nel caso in cui l'indice richieda di essere "
+"aggiornato"
+
+#: builtin/update-index.c:977
+msgid "refresh: ignore submodules"
+msgstr "aggiornamento: ignora i sottomoduli"
+
+#: builtin/update-index.c:980
+msgid "do not ignore new files"
+msgstr "non ignorare i nuovi file"
+
+#: builtin/update-index.c:982
+msgid "let files replace directories and vice-versa"
+msgstr "consenti che dei file sostituiscano delle directory e viceversa"
+
+#: builtin/update-index.c:984
+msgid "notice files missing from worktree"
+msgstr "nota se dei file mancano dall'albero di lavoro"
+
+#: builtin/update-index.c:986
+msgid "refresh even if index contains unmerged entries"
+msgstr ""
+"esegui l'aggiornamento anche se l'indice contiene delle voci non sottoposte "
+"a merge"
+
+#: builtin/update-index.c:989
+msgid "refresh stat information"
+msgstr "aggiorna le informazioni stat"
+
+#: builtin/update-index.c:993
+msgid "like --refresh, but ignore assume-unchanged setting"
+msgstr "come --refresh, ma ignora l'impostazione assume-unchanged"
+
+#: builtin/update-index.c:997
+msgid "<mode>,<object>,<path>"
+msgstr "<modo>,<oggetto>,<percorso>"
+
+#: builtin/update-index.c:998
+msgid "add the specified entry to the index"
+msgstr "aggiunge la voce specificata all'indice"
+
+#: builtin/update-index.c:1008
+msgid "mark files as \"not changing\""
+msgstr "contrassegna i file come \"non saranno modificati\""
+
+#: builtin/update-index.c:1011
+msgid "clear assumed-unchanged bit"
+msgstr "reimposta a zero il bit \"non saranno modificati\""
+
+#: builtin/update-index.c:1014
+msgid "mark files as \"index-only\""
+msgstr "contrassegna i file come \"solamente da indicizzare\""
+
+#: builtin/update-index.c:1017
+msgid "clear skip-worktree bit"
+msgstr "reimposta a zero il bit \"solamente da indicizzare\""
+
+#: builtin/update-index.c:1020
+msgid "do not touch index-only entries"
+msgstr "non eseguire il touch di voci presenti solo nell'indice"
+
+#: builtin/update-index.c:1022
+msgid "add to index only; do not add content to object database"
+msgstr ""
+"aggiungi solo all'indice; non aggiungere il contenuto al database oggetti"
+
+#: builtin/update-index.c:1024
+msgid "remove named paths even if present in worktree"
+msgstr "rimuovi i percorsi specificati anche se presenti nell'albero di lavoro"
+
+#: builtin/update-index.c:1026
+msgid "with --stdin: input lines are terminated by null bytes"
+msgstr "con --stdin: le righe di input sono terminate da byte NULL"
+
+#: builtin/update-index.c:1028
+msgid "read list of paths to be updated from standard input"
+msgstr "leggi l'elenco dei percorsi da aggiornare dallo standard input"
+
+#: builtin/update-index.c:1032
+msgid "add entries from standard input to the index"
+msgstr "aggiungi le voci specificate sullo standard input all'indice"
+
+#: builtin/update-index.c:1036
+msgid "repopulate stages #2 and #3 for the listed paths"
+msgstr "ripopola le fasi 2 e 3 per i percorsi elencati"
+
+#: builtin/update-index.c:1040
+msgid "only update entries that differ from HEAD"
+msgstr "aggiorna solo le voci differenti rispetto all'HEAD"
+
+#: builtin/update-index.c:1044
+msgid "ignore files missing from worktree"
+msgstr "ignora i file mancanti nell'albero di lavoro"
+
+#: builtin/update-index.c:1047
+msgid "report actions to standard output"
+msgstr "stampa le azioni sullo standard output"
+
+#: builtin/update-index.c:1049
+msgid "(for porcelains) forget saved unresolved conflicts"
+msgstr ""
+"(per i comandi ad alto livello) dimentica i conflitti non risolti salvati"
+
+#: builtin/update-index.c:1053
+msgid "write index in this format"
+msgstr "scrivi l'indice in questo formato"
+
+#: builtin/update-index.c:1055
+msgid "enable or disable split index"
+msgstr "abilita o disabilita l'indice suddiviso"
+
+#: builtin/update-index.c:1057
+msgid "enable/disable untracked cache"
+msgstr "abilita/disabilita la cache non tracciata"
+
+#: builtin/update-index.c:1059
+msgid "test if the filesystem supports untracked cache"
+msgstr "verifica se il filesystem supporta la cache non tracciata"
+
+#: builtin/update-index.c:1061
+msgid "enable untracked cache without testing the filesystem"
+msgstr "abilita la cache non tracciata senza testare il filesystem"
+
+#: builtin/update-index.c:1063
+msgid "write out the index even if is not flagged as changed"
+msgstr "scrivi l'indice anche se non è stato contrassegnato come modificato"
+
+#: builtin/update-index.c:1065
+msgid "enable or disable file system monitor"
+msgstr "abilita o disabilita il monitor del filesystem"
+
+#: builtin/update-index.c:1067
+msgid "mark files as fsmonitor valid"
+msgstr "contrassegna i file come validi rispetto al monitor del filesystem"
+
+#: builtin/update-index.c:1070
+msgid "clear fsmonitor valid bit"
+msgstr ""
+"reimposta a zero il bit \"file validi rispetto al monitor del filesystem\""
+
+#: builtin/update-index.c:1173
+msgid ""
+"core.splitIndex is set to false; remove or change it, if you really want to "
+"enable split index"
+msgstr ""
+"core.splitIndex è impostato a false; rimuovilo o modificalo se vuoi "
+"veramente abilitare l'indice suddiviso"
+
+#: builtin/update-index.c:1182
+msgid ""
+"core.splitIndex is set to true; remove or change it, if you really want to "
+"disable split index"
+msgstr ""
+"core.splitIndex è impostato a true; rimuovilo o modificalo se vuoi veramente "
+"disabilitare l'indice suddiviso"
+
+#: builtin/update-index.c:1194
+msgid ""
+"core.untrackedCache is set to true; remove or change it, if you really want "
+"to disable the untracked cache"
+msgstr ""
+"core.untrackedCache è impostato a true; rimuovilo o modificalo se vuoi "
+"veramente disabilitare la cache non tracciata"
+
+#: builtin/update-index.c:1198
+msgid "Untracked cache disabled"
+msgstr "Cache non tracciata disabilitata"
+
+#: builtin/update-index.c:1206
+msgid ""
+"core.untrackedCache is set to false; remove or change it, if you really want "
+"to enable the untracked cache"
+msgstr ""
+"core.untrackedCache è impostato a false; rimuovilo o modificalo se vuoi "
+"veramente abilitare la cache non tracciata"
+
+#: builtin/update-index.c:1210
+#, c-format
+msgid "Untracked cache enabled for '%s'"
+msgstr "Cache non tracciata abilitata per '%s'"
+
+#: builtin/update-index.c:1218
+msgid "core.fsmonitor is unset; set it if you really want to enable fsmonitor"
+msgstr ""
+"core.fsmonitor non è impostato; impostalo se vuoi veramente abilitare il "
+"monitor del filesystem"
+
+#: builtin/update-index.c:1222
+msgid "fsmonitor enabled"
+msgstr "monitor filesystem abilitato"
+
+#: builtin/update-index.c:1225
+msgid ""
+"core.fsmonitor is set; remove it if you really want to disable fsmonitor"
+msgstr ""
+"core.fsmonitor è impostato; rimuovi tale impostazione se vuoi veramente "
+"disabilitare il monitor del filesystem"
+
+#: builtin/update-index.c:1229
+msgid "fsmonitor disabled"
+msgstr "monitor filesystem disabilitato"
+
+#: builtin/update-ref.c:10
+msgid "git update-ref [<options>] -d <refname> [<old-val>]"
+msgstr "git update-ref [<opzioni>] -d <nome riferimento> [<vecchio valore>]"
+
+#: builtin/update-ref.c:11
+msgid "git update-ref [<options>]    <refname> <new-val> [<old-val>]"
+msgstr ""
+"git update-ref [<opzioni>]    <nome riferimento> <nuovo valore> [<vecchio "
+"valore>]"
+
+#: builtin/update-ref.c:12
+msgid "git update-ref [<options>] --stdin [-z]"
+msgstr "git update-ref [<opzioni>] --stdin [-z]"
+
+#: builtin/update-ref.c:364
+msgid "delete the reference"
+msgstr "elimina il riferimento"
+
+#: builtin/update-ref.c:366
+msgid "update <refname> not the one it points to"
+msgstr "aggiorna <nome riferimento>, non ciò a cui punta"
+
+#: builtin/update-ref.c:367
+msgid "stdin has NUL-terminated arguments"
+msgstr "lo standard input ha argomenti terminati da NUL"
+
+#: builtin/update-ref.c:368
+msgid "read updates from stdin"
+msgstr "leggi aggiornamenti dallo standard input"
+
+#: builtin/update-server-info.c:7
+msgid "git update-server-info [--force]"
+msgstr "git update-server-info [--force]"
+
+#: builtin/update-server-info.c:15
+msgid "update the info files from scratch"
+msgstr "aggiorna i file informazioni partendo da zero"
+
+#: builtin/upload-pack.c:11
+msgid "git upload-pack [<options>] <dir>"
+msgstr "git upload-pack [<opzioni>] <directory>"
+
+#: builtin/upload-pack.c:23 t/helper/test-serve-v2.c:17
+msgid "quit after a single request/response exchange"
+msgstr "esci dopo un solo scambio richiesta/risposta"
+
+#: builtin/upload-pack.c:25
+msgid "exit immediately after initial ref advertisement"
+msgstr "esci subito dopo l'annuncio iniziale del riferimento"
+
+#: builtin/upload-pack.c:27
+msgid "do not try <directory>/.git/ if <directory> is no Git directory"
+msgstr ""
+"non provare a utilizzare <directory>/.git/ se <directory> non è una "
+"directory Git"
+
+#: builtin/upload-pack.c:29
+msgid "interrupt transfer after <n> seconds of inactivity"
+msgstr "interrompi il trasferimento dopo <n> secondi di inattività"
+
+#: builtin/verify-commit.c:19
+msgid "git verify-commit [-v | --verbose] <commit>..."
+msgstr "git verify-commit [-v | --verbose] <commit>..."
+
+#: builtin/verify-commit.c:68
+msgid "print commit contents"
+msgstr "stampa i contenuti del commit"
+
+#: builtin/verify-commit.c:69 builtin/verify-tag.c:37
+msgid "print raw gpg status output"
+msgstr "stampa l'output grezzo dello stato di GPG"
+
+#: builtin/verify-pack.c:55
+msgid "git verify-pack [-v | --verbose] [-s | --stat-only] <pack>..."
+msgstr "git verify-pack [-v | --verbose] [-s | --stat-only] <pack>..."
+
+#: builtin/verify-pack.c:65
+msgid "verbose"
+msgstr "dettagliato"
+
+#: builtin/verify-pack.c:67
+msgid "show statistics only"
+msgstr "visualizza solo le statistiche"
+
+#: builtin/verify-tag.c:18
+msgid "git verify-tag [-v | --verbose] [--format=<format>] <tag>..."
+msgstr "git verify-tag [-v | --verbose] [--format=<formato>] <tag>..."
+
+#: builtin/verify-tag.c:36
+msgid "print tag contents"
+msgstr "stampa i contenuti del tag"
+
+#: builtin/worktree.c:17
+msgid "git worktree add [<options>] <path> [<commit-ish>]"
+msgstr "git worktree add [<opzioni>] <percorso> [<espressione commit>]"
+
+#: builtin/worktree.c:18
+msgid "git worktree list [<options>]"
+msgstr "git worktree list [<opzioni>]"
+
+#: builtin/worktree.c:19
+msgid "git worktree lock [<options>] <path>"
+msgstr "git worktree lock [<opzioni>] <percorso>"
+
+#: builtin/worktree.c:20
+msgid "git worktree move <worktree> <new-path>"
+msgstr "git worktree move <albero di lavoro> <nuovo percorso>"
+
+#: builtin/worktree.c:21
+msgid "git worktree prune [<options>]"
+msgstr "git worktree prune [<opzioni>]"
+
+#: builtin/worktree.c:22
+msgid "git worktree remove [<options>] <worktree>"
+msgstr "git worktree remove [<opzioni>] <albero di lavoro>"
+
+#: builtin/worktree.c:23
+msgid "git worktree unlock <path>"
+msgstr "git worktree unlock <percorso>"
+
+#: builtin/worktree.c:60 builtin/worktree.c:898
+#, c-format
+msgid "failed to delete '%s'"
+msgstr "eliminazione di '%s' non riuscita"
+
+#: builtin/worktree.c:79
+#, c-format
+msgid "Removing worktrees/%s: not a valid directory"
+msgstr "Rimuovo worktrees/%s: non è una directory valida"
+
+#: builtin/worktree.c:85
+#, c-format
+msgid "Removing worktrees/%s: gitdir file does not exist"
+msgstr "Rimuovo worktrees/%s: il file gitdir non esiste"
+
+#: builtin/worktree.c:90 builtin/worktree.c:99
+#, c-format
+msgid "Removing worktrees/%s: unable to read gitdir file (%s)"
+msgstr "Rimuovo worktrees/%s: impossibile leggere il file gitdir (%s)"
+
+#: builtin/worktree.c:109
+#, c-format
+msgid ""
+"Removing worktrees/%s: short read (expected %<PRIuMAX> bytes, read "
+"%<PRIuMAX>)"
+msgstr ""
+"Rimuovo worktrees/%s: letti meno dati del previsto (attesi %<PRIuMAX>byte, "
+"%<PRIuMAX> letti)"
+
+#: builtin/worktree.c:117
+#, c-format
+msgid "Removing worktrees/%s: invalid gitdir file"
+msgstr "Rimuovo worktrees/%s: file gitdir non valido"
+
+#: builtin/worktree.c:126
+#, c-format
+msgid "Removing worktrees/%s: gitdir file points to non-existent location"
+msgstr "Rimuovo worktrees/%s: il file gitdir punta a un percorso non esistente"
+
+#: builtin/worktree.c:165
+msgid "report pruned working trees"
+msgstr "segnala gli alberi di lavoro eliminati"
+
+#: builtin/worktree.c:167
+msgid "expire working trees older than <time>"
+msgstr "fai scadere gli alberi di lavoro più vecchi di <tempo>"
+
+#: builtin/worktree.c:234
+#, c-format
+msgid "'%s' already exists"
+msgstr "'%s' esiste già"
+
+#: builtin/worktree.c:251
+#, c-format
+msgid "unable to re-add worktree '%s'"
+msgstr "impossibile aggiungere nuovamente l'albero di lavoro '%s'"
+
+#: builtin/worktree.c:256
+#, c-format
+msgid ""
+"'%s' is a missing but locked worktree;\n"
+"use 'add -f -f' to override, or 'unlock' and 'prune' or 'remove' to clear"
+msgstr ""
+"'%s' è un albero di lavoro mancante ma bloccato;\n"
+"usa 'add -f -f' per eseguire l'override, o 'unlock' e 'prune' o 'remove' per "
+"rimuoverlo"
+
+#: builtin/worktree.c:258
+#, c-format
+msgid ""
+"'%s' is a missing but already registered worktree;\n"
+"use 'add -f' to override, or 'prune' or 'remove' to clear"
+msgstr ""
+"'%s' è un albero di lavoro mancante ma già registrato;\n"
+"usa 'add -f' per eseguire l'override, o 'prune' o 'remove' per rimuoverlo"
+
+#: builtin/worktree.c:308
+#, c-format
+msgid "could not create directory of '%s'"
+msgstr "impossibile creare la directory di '%s'"
+
+#: builtin/worktree.c:439 builtin/worktree.c:445
+#, c-format
+msgid "Preparing worktree (new branch '%s')"
+msgstr "Preparazione dell'albero di lavoro in corso (nuovo branch '%s')"
+
+#: builtin/worktree.c:441
+#, c-format
+msgid "Preparing worktree (resetting branch '%s'; was at %s)"
+msgstr ""
+"Preparazione dell'albero di lavoro in corso (reimposto il branch '%s'; era a "
+"%s)"
+
+#: builtin/worktree.c:450
+#, c-format
+msgid "Preparing worktree (checking out '%s')"
+msgstr "Preparazione dell'albero di lavoro in corso (checkout di '%s')"
+
+#: builtin/worktree.c:456
+#, c-format
+msgid "Preparing worktree (detached HEAD %s)"
+msgstr "Preparazione dell'albero di lavoro in corso (HEAD scollegato %s)"
+
+#: builtin/worktree.c:497
+msgid "checkout <branch> even if already checked out in other worktree"
+msgstr ""
+"esegui il checkout di <branch> anche se tale operazione è stata eseguita in "
+"un altro albero di lavoro"
+
+#: builtin/worktree.c:500
+msgid "create a new branch"
+msgstr "crea un nuovo branch"
+
+#: builtin/worktree.c:502
+msgid "create or reset a branch"
+msgstr "crea o reimposta un branch"
+
+#: builtin/worktree.c:504
+msgid "populate the new working tree"
+msgstr "popola il nuovo albero di lavoro"
+
+#: builtin/worktree.c:505
+msgid "keep the new working tree locked"
+msgstr "mantieni bloccato il nuovo albero di lavoro"
+
+#: builtin/worktree.c:508
+msgid "set up tracking mode (see git-branch(1))"
+msgstr "imposta la modalità tracking (vedi git-branch(1))"
+
+#: builtin/worktree.c:511
+msgid "try to match the new branch name with a remote-tracking branch"
+msgstr ""
+"tenta di cercare una corrispondenza fra il nome del nuovo branch e un branch "
+"remoto da tracciare"
+
+#: builtin/worktree.c:519
+msgid "-b, -B, and --detach are mutually exclusive"
+msgstr "le opzioni -b, -B e --detach sono mutualmente esclusive"
+
+#: builtin/worktree.c:580
+msgid "--[no-]track can only be used if a new branch is created"
+msgstr ""
+"l'opzione --[no-]track può essere usata solo se viene creato un nuovo branch"
+
+#: builtin/worktree.c:680
+msgid "reason for locking"
+msgstr "motivo di blocco"
+
+#: builtin/worktree.c:692 builtin/worktree.c:725 builtin/worktree.c:799
+#: builtin/worktree.c:926
+#, c-format
+msgid "'%s' is not a working tree"
+msgstr "'%s' non è un albero di lavoro"
+
+#: builtin/worktree.c:694 builtin/worktree.c:727
+msgid "The main working tree cannot be locked or unlocked"
+msgstr "Non è possibile bloccare o sbloccare l'albero di lavoro principale"
+
+#: builtin/worktree.c:699
+#, c-format
+msgid "'%s' is already locked, reason: %s"
+msgstr "'%s' è già bloccato per questo motivo: %s"
+
+#: builtin/worktree.c:701
+#, c-format
+msgid "'%s' is already locked"
+msgstr "'%s' è già bloccato"
+
+#: builtin/worktree.c:729
+#, c-format
+msgid "'%s' is not locked"
+msgstr "'%s' non è bloccato"
+
+#: builtin/worktree.c:770
+msgid "working trees containing submodules cannot be moved or removed"
+msgstr ""
+"gli alberi di lavoro contenenti sottomoduli non possono essere spostati o "
+"rimossi"
+
+#: builtin/worktree.c:778
+msgid "force move even if worktree is dirty or locked"
+msgstr "forza lo spostamento anche se l'albero di lavoro è sporco o bloccato"
+
+#: builtin/worktree.c:801 builtin/worktree.c:928
+#, c-format
+msgid "'%s' is a main working tree"
+msgstr "'%s' è un albero di lavoro principale"
+
+#: builtin/worktree.c:806
+#, c-format
+msgid "could not figure out destination name from '%s'"
+msgstr "impossibile determinare il nome destinazione da '%s'"
+
+#: builtin/worktree.c:812
+#, c-format
+msgid "target '%s' already exists"
+msgstr "la destinazione '%s' esiste già"
+
+#: builtin/worktree.c:820
+#, c-format
+msgid ""
+"cannot move a locked working tree, lock reason: %s\n"
+"use 'move -f -f' to override or unlock first"
+msgstr ""
+"impossibile spostare un albero di lavoro bloccato, motivazione blocco: %s\n"
+"usa 'move -f -f' per eseguirne l'override o sbloccalo prima di eseguire "
+"l'operazione"
+
+#: builtin/worktree.c:822
+msgid ""
+"cannot move a locked working tree;\n"
+"use 'move -f -f' to override or unlock first"
+msgstr ""
+"impossibile spostare un albero di lavoro bloccato;\n"
+"usa 'move -f -f' per eseguirne l'override o sbloccalo prima di eseguire "
+"l'operazione"
+
+#: builtin/worktree.c:825
+#, c-format
+msgid "validation failed, cannot move working tree: %s"
+msgstr "validazione non riuscita, impossibile spostare l'albero di lavoro: %s"
+
+#: builtin/worktree.c:830
+#, c-format
+msgid "failed to move '%s' to '%s'"
+msgstr "spostamento di '%s' in '%s' non riuscito"
+
+#: builtin/worktree.c:878
+#, c-format
+msgid "failed to run 'git status' on '%s'"
+msgstr "esecuzione di 'git status' su '%s' non riuscita"
+
+#: builtin/worktree.c:882
+#, c-format
+msgid "'%s' contains modified or untracked files, use --force to delete it"
+msgstr ""
+"'%s' contiene file modificati o non tracciati, usa --force per eliminarlo"
+
+#: builtin/worktree.c:887
+#, c-format
+msgid "failed to run 'git status' on '%s', code %d"
+msgstr "esecuzione di 'git status' su '%s' non riuscita, codice %d"
+
+#: builtin/worktree.c:910
+msgid "force removal even if worktree is dirty or locked"
+msgstr "forza la rimozione anche se l'albero di lavoro è sporco o bloccato"
+
+#: builtin/worktree.c:933
+#, c-format
+msgid ""
+"cannot remove a locked working tree, lock reason: %s\n"
+"use 'remove -f -f' to override or unlock first"
+msgstr ""
+"impossibile rimuovere un albero di lavoro bloccato, motivazione blocco: %s\n"
+"usa 'remove -f -f' per eseguirne l'override o sbloccalo prima di eseguire "
+"l'operazione"
+
+#: builtin/worktree.c:935
+msgid ""
+"cannot remove a locked working tree;\n"
+"use 'remove -f -f' to override or unlock first"
+msgstr ""
+"impossibile rimuovere un albero di lavoro bloccato;\n"
+"usa 'remove -f -f' per eseguirne l'override o sbloccalo prima di eseguire "
+"l'operazione"
+
+#: builtin/worktree.c:938
+#, c-format
+msgid "validation failed, cannot remove working tree: %s"
+msgstr "validazione non riuscita, impossibile rimuovere l'albero di lavoro: %s"
+
+#: builtin/write-tree.c:15
+msgid "git write-tree [--missing-ok] [--prefix=<prefix>/]"
+msgstr "git write-tree [--missing-ok] [--prefix=<prefisso>/]"
+
+#: builtin/write-tree.c:28
+msgid "<prefix>/"
+msgstr "<prefisso>/"
+
+#: builtin/write-tree.c:29
+msgid "write tree object for a subdirectory <prefix>"
+msgstr "scrivi l'oggetto albero per una sottodirectory <prefisso>"
+
+#: builtin/write-tree.c:31
+msgid "only useful for debugging"
+msgstr "utile solo per il debug"
+
+#: fast-import.c:3125
+#, c-format
+msgid "Expected 'mark' command, got %s"
+msgstr "Atteso comando 'mark', ricevuto %s"
+
+#: fast-import.c:3130
+#, c-format
+msgid "Expected 'to' command, got %s"
+msgstr "Atteso comando 'to', ricevuto %s"
+
+#: fast-import.c:3254
+#, c-format
+msgid "feature '%s' forbidden in input without --allow-unsafe-features"
+msgstr "funzionalità '%s' vietata nell'input senza --allow-unsafe-features"
+
+#: credential-cache--daemon.c:223
+#, c-format
+msgid ""
+"The permissions on your socket directory are too loose; other\n"
+"users may be able to read your cached credentials. Consider running:\n"
+"\n"
+"\tchmod 0700 %s"
+msgstr ""
+"I permessi sulla directory del socket sono troppo laschi; altri\n"
+"utenti potrebbero essere in grado di leggere le credenziali nella\n"
+"cache. Valuta di eseguire:\n"
+"\n"
+"\tchmod 0700 %s"
+
+#: credential-cache--daemon.c:272
+msgid "print debugging messages to stderr"
+msgstr "stampa i messaggi di debug sullo standard error"
+
+#: t/helper/test-reach.c:152
+#, c-format
+msgid "commit %s is not marked reachable"
+msgstr "il commit %s non è contrassegnato come raggiungibile"
+
+#: t/helper/test-reach.c:162
+msgid "too many commits marked reachable"
+msgstr "troppi commit contrassegnati come raggiungibili"
+
+#: t/helper/test-serve-v2.c:7
+msgid "test-tool serve-v2 [<options>]"
+msgstr "test-tool serve-v2 [<opzioni>]"
+
+#: t/helper/test-serve-v2.c:19
+msgid "exit immediately after advertising capabilities"
+msgstr "esci subito dopo aver annunciato le funzionalità"
+
+#: git.c:27
+msgid ""
+"git [--version] [--help] [-C <path>] [-c <name>=<value>]\n"
+"           [--exec-path[=<path>]] [--html-path] [--man-path] [--info-path]\n"
+"           [-p | --paginate | -P | --no-pager] [--no-replace-objects] [--"
+"bare]\n"
+"           [--git-dir=<path>] [--work-tree=<path>] [--namespace=<name>]\n"
+"           <command> [<args>]"
+msgstr ""
+"git [--version] [--help] [-C <percorso>] [-c <nome>=<valore>]\n"
+"           [--exec-path[=<percorso>]] [--html-path] [--man-path] [--info-"
+"path]\n"
+"           [-p | --paginate | -P | --no-pager] [--no-replace-objects] [--"
+"bare]\n"
+"           [--git-dir=<percorso>] [--work-tree=<percorso>] [--"
+"namespace=<nome>]\n"
+"           <comando> [<argomenti>]"
+
+#: git.c:34
+msgid ""
+"'git help -a' and 'git help -g' list available subcommands and some\n"
+"concept guides. See 'git help <command>' or 'git help <concept>'\n"
+"to read about a specific subcommand or concept.\n"
+"See 'git help git' for an overview of the system."
+msgstr ""
+"'git help -a' e 'git help -g' elencano i sottocomandi disponibili e\n"
+"alcune guide concettuali. Vedi 'git help <comando>' o 'git help <concetto>'\n"
+"per leggere ulteriori informazioni su un sottocomando o su un concetto\n"
+"specifici.\n"
+"Vedi 'git help git' per una panoramica del sistema."
+
+#: git.c:186
+#, c-format
+msgid "no directory given for --git-dir\n"
+msgstr "nessuna directory specificata per --git-dir\n"
+
+#: git.c:200
+#, c-format
+msgid "no namespace given for --namespace\n"
+msgstr "nessuno spazio dei nomi specificato per --namespace\n"
+
+#: git.c:214
+#, c-format
+msgid "no directory given for --work-tree\n"
+msgstr "nessuna directory specificata per --work-tree\n"
+
+#: git.c:228
+#, c-format
+msgid "no prefix given for --super-prefix\n"
+msgstr "nessun prefisso specificato per --super-prefix\n"
+
+#: git.c:250
+#, c-format
+msgid "-c expects a configuration string\n"
+msgstr "-c: attesa stringa di configurazione\n"
+
+#: git.c:288
+#, c-format
+msgid "no directory given for -C\n"
+msgstr "nessuna directory specificata per -C\n"
+
+#: git.c:314
+#, c-format
+msgid "unknown option: %s\n"
+msgstr "opzione sconosciuta: %s\n"
+
+#: git.c:360
+#, c-format
+msgid "while expanding alias '%s': '%s'"
+msgstr "durante l'espansione dell'alias '%s': '%s'"
+
+#: git.c:369
+#, c-format
+msgid ""
+"alias '%s' changes environment variables.\n"
+"You can use '!git' in the alias to do this"
+msgstr ""
+"l'alias '%s' modifica le variabili d'ambiente.\n"
+"Puoi usare '!git' nell'alias per farlo"
+
+#: git.c:376
+#, c-format
+msgid "empty alias for %s"
+msgstr "alias vuoto per %s"
+
+#: git.c:379
+#, c-format
+msgid "recursive alias: %s"
+msgstr "alias ricorsivo: %s"
+
+#: git.c:459
+msgid "write failure on standard output"
+msgstr "errore di scrittura sullo standard output"
+
+#: git.c:461
+msgid "unknown write failure on standard output"
+msgstr "errore di scrittura sconosciuto sullo standard output"
+
+#: git.c:463
+msgid "close failed on standard output"
+msgstr "chiusura dello standard output non riuscita"
+
+#: git.c:793
+#, c-format
+msgid "alias loop detected: expansion of '%s' does not terminate:%s"
+msgstr "rilevato ciclo alias: l'espansione di '%s' non termina:%s"
+
+#: git.c:843
+#, c-format
+msgid "cannot handle %s as a builtin"
+msgstr "impossibile gestire %s come comando incorporato"
+
+#: git.c:856
+#, c-format
+msgid ""
+"usage: %s\n"
+"\n"
+msgstr ""
+"uso: %s\n"
+"\n"
+
+#: git.c:876
+#, c-format
+msgid "expansion of alias '%s' failed; '%s' is not a git command\n"
+msgstr "espansione dell'alias '%s' non riuscita; '%s' non è un comando Git\n"
+
+#: git.c:888
+#, c-format
+msgid "failed to run command '%s': %s\n"
+msgstr "esecuzione del comando '%s' non riuscita: %s\n"
+
+#: http.c:378
+#, c-format
+msgid "negative value for http.postbuffer; defaulting to %d"
+msgstr "valore negativo per http.postbuffer; uso l'impostazione predefinita %d"
+
+#: http.c:399
+msgid "Delegation control is not supported with cURL < 7.22.0"
+msgstr "Il controllo delegazione non è supportato con cURL < 7.22.0"
+
+#: http.c:408
+msgid "Public key pinning not supported with cURL < 7.44.0"
+msgstr "Il pinning delle chiavi pubbliche non è supportato con cURL < 7.44.0"
+
+#: http.c:876
+msgid "CURLSSLOPT_NO_REVOKE not supported with cURL < 7.44.0"
+msgstr "CURLSSLOPT_NO_REVOKE non è supportato con cURL < 7.44.0"
+
+#: http.c:949
+msgid "Protocol restrictions not supported with cURL < 7.19.4"
+msgstr "Le restrizioni protocollo non sono supportate con cURL < 7.19.4"
+
+#: http.c:1086
+#, c-format
+msgid "Unsupported SSL backend '%s'. Supported SSL backends:"
+msgstr "Backend SSL '%s' non supportato. Backend SSL supportati:"
+
+#: http.c:1093
+#, c-format
+msgid "Could not set SSL backend to '%s': cURL was built without SSL backends"
+msgstr ""
+"Impossibile impostare il backend SSL a '%s': cURL è stato compilato senza "
+"backend SSL"
+
+#: http.c:1097
+#, c-format
+msgid "Could not set SSL backend to '%s': already set"
+msgstr "Impossibile impostare il backend SSL a '%s': già impostato"
+
+#: http.c:1966
+#, c-format
+msgid ""
+"unable to update url base from redirection:\n"
+"  asked for: %s\n"
+"   redirect: %s"
+msgstr ""
+"impossibile aggiornare l'URL di base dalla redirezione:\n"
+"  richiesta: %s\n"
+"   redirect: %s"
+
+#: remote-curl.c:166
+#, c-format
+msgid "invalid quoting in push-option value: '%s'"
+msgstr "virgolette non valide nel valore push-option: '%s'"
+
+#: remote-curl.c:263
+#, c-format
+msgid "%sinfo/refs not valid: is this a git repository?"
+msgstr "%sinfo/refs non valido: è un repository Git?"
+
+#: remote-curl.c:364
+msgid "invalid server response; expected service, got flush packet"
+msgstr ""
+"risposta del server non valida; atteso servizio, ricevuto pacchetto flush"
+
+#: remote-curl.c:395
+#, c-format
+msgid "invalid server response; got '%s'"
+msgstr "risposta del server non valida; ricevuto '%s'"
+
+#: remote-curl.c:455
+#, c-format
+msgid "repository '%s' not found"
+msgstr "repository '%s' non trovato"
+
+#: remote-curl.c:459
+#, c-format
+msgid "Authentication failed for '%s'"
+msgstr "Autenticazione non riuscita per '%s'"
+
+#: remote-curl.c:463
+#, c-format
+msgid "unable to access '%s': %s"
+msgstr "impossibile accedere a '%s': %s"
+
+#: remote-curl.c:469
+#, c-format
+msgid "redirecting to %s"
+msgstr "redirezione a %s in corso"
+
+#: remote-curl.c:593
+msgid "shouldn't have EOF when not gentle on EOF"
+msgstr ""
+"non dovrebbe esserci un pacchetto fine file se non si è accomodanti con "
+"questi ultimi"
+
+#: remote-curl.c:673
+msgid "unable to rewind rpc post data - try increasing http.postBuffer"
+msgstr ""
+"impossibile ritornare a un punto precedente dei dati POST RPC - prova ad "
+"aumentare il valore di http.postBuffer"
+
+#: remote-curl.c:733
+#, c-format
+msgid "RPC failed; %s"
+msgstr "RPC non riuscita; %s"
+
+#: remote-curl.c:773
+msgid "cannot handle pushes this big"
+msgstr "impossibile gestire push così grandi"
+
+#: remote-curl.c:888
+#, c-format
+msgid "cannot deflate request; zlib deflate error %d"
+msgstr ""
+"impossibile eseguire il deflate della richiesta; errore deflate zlib %d"
+
+#: remote-curl.c:892
+#, c-format
+msgid "cannot deflate request; zlib end error %d"
+msgstr "impossibile eseguire il deflate della richiesta; errore fine zlib %d"
+
+#: remote-curl.c:1023
+msgid "dumb http transport does not support shallow capabilities"
+msgstr "il trasporto http stupido non supporta le funzionalità shallow"
+
+#: remote-curl.c:1037
+msgid "fetch failed."
+msgstr "recupero non riuscito."
+
+#: remote-curl.c:1085
+msgid "cannot fetch by sha1 over smart http"
+msgstr ""
+"impossibile recuperare i dati in base allo SHA1 con il trasporto HTTP "
+"intelligente"
+
+#: remote-curl.c:1129 remote-curl.c:1135
+#, c-format
+msgid "protocol error: expected sha/ref, got '%s'"
+msgstr "errore protocollo: atteso SHA/riferimento, ricevuto '%s'"
+
+#: remote-curl.c:1147 remote-curl.c:1261
+#, c-format
+msgid "http transport does not support %s"
+msgstr "il trasporto HTTP non supporta %s"
+
+#: remote-curl.c:1183
+msgid "git-http-push failed"
+msgstr "git-http-push non riuscito"
+
+#: remote-curl.c:1367
+msgid "remote-curl: usage: git remote-curl <remote> [<url>]"
+msgstr "remote-curl: uso: git remote-curl <remoto> [<URL>]"
+
+#: remote-curl.c:1399
+msgid "remote-curl: error reading command stream from git"
+msgstr "remote-curl: errore durante la lettura del flusso dei comandi da Git"
+
+#: remote-curl.c:1406
+msgid "remote-curl: fetch attempted without a local repo"
+msgstr "remote-curl: tentato un fetch senza un repository locale"
+
+#: remote-curl.c:1446
+#, c-format
+msgid "remote-curl: unknown command '%s' from git"
+msgstr "remote-curl: ricevuto comando sconosciuto '%s' da Git"
+
+#: list-objects-filter-options.h:85
+msgid "args"
+msgstr "argomenti"
+
+#: list-objects-filter-options.h:86
+msgid "object filtering"
+msgstr "filtraggio oggetti"
+
+#: parse-options.h:183
+msgid "expiry-date"
+msgstr "data-scadenza"
+
+#: parse-options.h:197
+msgid "no-op (backward compatibility)"
+msgstr "no-op (retrocompatibilità)"
+
+#: parse-options.h:309
+msgid "be more verbose"
+msgstr "visualizza più dettagli"
+
+#: parse-options.h:311
+msgid "be more quiet"
+msgstr "visualizza meno dettagli"
+
+#: parse-options.h:317
+msgid "use <n> digits to display SHA-1s"
+msgstr "usa <n> cifre per mostrare gli hash SHA-1"
+
+#: parse-options.h:336
+msgid "how to strip spaces and #comments from message"
+msgstr "come rimuovere gli spazi e i #commenti dal messaggio"
+
+#: parse-options.h:337
+msgid "read pathspec from file"
+msgstr "leggi gli specificatori percorso da un file"
+
+#: parse-options.h:338
+msgid ""
+"with --pathspec-from-file, pathspec elements are separated with NUL character"
+msgstr ""
+"con --pathspec-from-file gli elementi specificatori percorso sono separati da"
+" un carattere NUL"
+
+#: ref-filter.h:101
+msgid "key"
+msgstr "chiave"
+
+#: ref-filter.h:101
+msgid "field name to sort on"
+msgstr "nome campo in base a cui ordinare"
+
+#: rerere.h:44
+msgid "update the index with reused conflict resolution if possible"
+msgstr ""
+"aggiorna l'indice con la tecnica di risoluzione conflitti riutilizzata se "
+"possibile"
+
+#: wt-status.h:67
+msgid "HEAD detached at "
+msgstr "HEAD scollegato su "
+
+#: wt-status.h:68
+msgid "HEAD detached from "
+msgstr "HEAD scollegato da "
+
+#: command-list.h:50
+msgid "Add file contents to the index"
+msgstr "Aggiunge i contenuti del file all'indice"
+
+#: command-list.h:51
+msgid "Apply a series of patches from a mailbox"
+msgstr "Applica una serie di patch da una casella di posta"
+
+#: command-list.h:52
+msgid "Annotate file lines with commit information"
+msgstr "Annota le righe dei file con le informazioni sui commit"
+
+#: command-list.h:53
+msgid "Apply a patch to files and/or to the index"
+msgstr "Applica una patch ai file e/o all'indice"
+
+#: command-list.h:54
+msgid "Import a GNU Arch repository into Git"
+msgstr "Importa un repository GNU Arch in Git"
+
+#: command-list.h:55
+msgid "Create an archive of files from a named tree"
+msgstr "Crea un archivio di file da un albero con nome"
+
+#: command-list.h:56
+msgid "Use binary search to find the commit that introduced a bug"
+msgstr "Usa la ricerca binaria per trovare il commit che ha introdotto un bug"
+
+#: command-list.h:57
+msgid "Show what revision and author last modified each line of a file"
+msgstr ""
+"Visualizza quali revisione e autore hanno modificato ogni singola riga di un "
+"file per ultimi"
+
+#: command-list.h:58
+msgid "List, create, or delete branches"
+msgstr "Elenca, crea o elimina branch"
+
+#: command-list.h:59
+msgid "Move objects and refs by archive"
+msgstr "Sposta oggetti e riferimenti in base a un archivio"
+
+#: command-list.h:60
+msgid "Provide content or type and size information for repository objects"
+msgstr ""
+"Fornisci informazioni sul contenuto o sul tipo e sulle dimensioni per gli "
+"oggetti di un repository"
+
+#: command-list.h:61
+msgid "Display gitattributes information"
+msgstr "Visualizza le informazioni sugli attributi Git"
+
+#: command-list.h:62
+msgid "Debug gitignore / exclude files"
+msgstr "Esegui il debug dei file gitignore/escludi file"
+
+#: command-list.h:63
+msgid "Show canonical names and email addresses of contacts"
+msgstr "Visualizza i nomi canonici e gli indirizzi e-mail dei contatti"
+
+#: command-list.h:64
+msgid "Switch branches or restore working tree files"
+msgstr ""
+"Passa da un branch a un altro o ripristina i file nell'albero di lavoro"
+
+#: command-list.h:65
+msgid "Copy files from the index to the working tree"
+msgstr "Copia dei file dall'indice all'albero di lavoro"
+
+#: command-list.h:66
+msgid "Ensures that a reference name is well formed"
+msgstr "Si assicura che un nome riferimento sia ben formato"
+
+#: command-list.h:67
+msgid "Find commits yet to be applied to upstream"
+msgstr "Trova commit che devono essere ancora applicati upstream"
+
+#: command-list.h:68
+msgid "Apply the changes introduced by some existing commits"
+msgstr "Applica le modifiche introdotte da alcuni commit esistenti"
+
+#: command-list.h:69
+msgid "Graphical alternative to git-commit"
+msgstr "Alternativa grafica a git-commit"
+
+#: command-list.h:70
+msgid "Remove untracked files from the working tree"
+msgstr "Rimuove i file non tracciati dall'albero di lavoro"
+
+#: command-list.h:71
+msgid "Clone a repository into a new directory"
+msgstr "Clona un repository in una nuova directory"
+
+#: command-list.h:72
+msgid "Display data in columns"
+msgstr "Visualizza i dati in colonne"
+
+#: command-list.h:73
+msgid "Record changes to the repository"
+msgstr "Registra modifiche al repository"
+
+#: command-list.h:74
+msgid "Write and verify Git commit-graph files"
+msgstr "Scrive e verifica i file grafo dei commit di Git"
+
+#: command-list.h:75
+msgid "Create a new commit object"
+msgstr "Crea un nuovo oggetto commit"
+
+#: command-list.h:76
+msgid "Get and set repository or global options"
+msgstr "Ottiene e imposta le opzioni a livello di repository o globali"
+
+#: command-list.h:77
+msgid "Count unpacked number of objects and their disk consumption"
+msgstr ""
+"Conta il numero di oggetti non in un pack e la loro occupazione di spazio su "
+"disco"
+
+#: command-list.h:78
+msgid "Retrieve and store user credentials"
+msgstr "Recupera e salva credenziali utente"
+
+#: command-list.h:79
+msgid "Helper to temporarily store passwords in memory"
+msgstr "Helper per salvare temporaneamente password in memoria"
+
+#: command-list.h:80
+msgid "Helper to store credentials on disk"
+msgstr "Helper per salvare credenziali su disco"
+
+#: command-list.h:81
+msgid "Export a single commit to a CVS checkout"
+msgstr "Esporta un singolo commit in un checkout CVS"
+
+#: command-list.h:82
+msgid "Salvage your data out of another SCM people love to hate"
+msgstr ""
+"Recupera i dati da un sistema di controllo di versione che le persone "
+"adorano odiare"
+
+#: command-list.h:83
+msgid "A CVS server emulator for Git"
+msgstr "Un emulatore di server CVS per Git"
+
+#: command-list.h:84
+msgid "A really simple server for Git repositories"
+msgstr "Un server veramente semplice per repository Git"
+
+#: command-list.h:85
+msgid "Give an object a human readable name based on an available ref"
+msgstr ""
+"Attribuisce un nome leggibile a un oggetto basandosi su un riferimento "
+"disponibile"
+
+#: command-list.h:86
+msgid "Show changes between commits, commit and working tree, etc"
+msgstr ""
+"Visualizza le modifiche fra commit, un commit e l'albero di lavoro, ecc."
+
+#: command-list.h:87
+msgid "Compares files in the working tree and the index"
+msgstr "Confronta file nell'albero di lavoro e nell'indice"
+
+#: command-list.h:88
+msgid "Compare a tree to the working tree or index"
+msgstr "Confronta un albero con l'albero di lavoro o l'indice"
+
+#: command-list.h:89
+msgid "Compares the content and mode of blobs found via two tree objects"
+msgstr ""
+"Confronta il contenuto e i mode dei blob trovati tramite due oggetti albero"
+
+#: command-list.h:90
+msgid "Show changes using common diff tools"
+msgstr ""
+"Visualizza le modifiche usando tool comuni per la visualizzazione dei diff"
+
+#: command-list.h:91
+msgid "Git data exporter"
+msgstr "Esportatore di dati Git"
+
+#: command-list.h:92
+msgid "Backend for fast Git data importers"
+msgstr "Backend per importatori di dati Git veloci"
+
+#: command-list.h:93
+msgid "Download objects and refs from another repository"
+msgstr "Scarica oggetti e riferimenti da un altro repository"
+
+#: command-list.h:94
+msgid "Receive missing objects from another repository"
+msgstr "Riceve oggetti mancanti da un altro repository"
+
+#: command-list.h:95
+msgid "Rewrite branches"
+msgstr "Riscrive branch"
+
+#: command-list.h:96
+msgid "Produce a merge commit message"
+msgstr "Genera un messaggio di commit del merge"
+
+#: command-list.h:97
+msgid "Output information on each ref"
+msgstr "Visualizza in output le informazioni su ogni riferimento"
+
+#: command-list.h:98
+msgid "Prepare patches for e-mail submission"
+msgstr "Prepara patch per il loro invio tramite e-mail"
+
+#: command-list.h:99
+msgid "Verifies the connectivity and validity of the objects in the database"
+msgstr "Verifica la connessione e la validità degli oggetti nel database"
+
+#: command-list.h:100
+msgid "Cleanup unnecessary files and optimize the local repository"
+msgstr "Ripulisce file non necessari e ottimizza il repository locale"
+
+#: command-list.h:101
+msgid "Extract commit ID from an archive created using git-archive"
+msgstr "Estrae l'ID del commit da un archivio creato usando git-archive"
+
+#: command-list.h:102
+msgid "Print lines matching a pattern"
+msgstr "Stampa le righe corrispondenti a un'espressione regolare"
+
+#: command-list.h:103
+msgid "A portable graphical interface to Git"
+msgstr "Un'interfaccia grafica portabile per Git"
+
+#: command-list.h:104
+msgid "Compute object ID and optionally creates a blob from a file"
+msgstr "Calcola l'ID oggetto e crea facoltativamente un blob da un file"
+
+#: command-list.h:105
+msgid "Display help information about Git"
+msgstr "Visualizza una guida a Git"
+
+#: command-list.h:106
+msgid "Server side implementation of Git over HTTP"
+msgstr "Implementazione lato server di Git su HTTP"
+
+#: command-list.h:107
+msgid "Download from a remote Git repository via HTTP"
+msgstr "Scarica dati da un repository Git remoto tramite HTTP"
+
+#: command-list.h:108
+msgid "Push objects over HTTP/DAV to another repository"
+msgstr "Esegue il push di oggetti su un altro repository tramite HTTP/DAV"
+
+#: command-list.h:109
+msgid "Send a collection of patches from stdin to an IMAP folder"
+msgstr "Invia un insieme di patch dallo standard input a una cartella IMAP"
+
+#: command-list.h:110
+msgid "Build pack index file for an existing packed archive"
+msgstr "Genera il file indice pack per un archivio esistente sottoposto a pack"
+
+#: command-list.h:111
+msgid "Create an empty Git repository or reinitialize an existing one"
+msgstr "Crea un repository Git vuoto o ne reinizializza uno esistente"
+
+#: command-list.h:112
+msgid "Instantly browse your working repository in gitweb"
+msgstr "Sfoglia istantaneamente il tuo repository di lavoro su gitweb"
+
+#: command-list.h:113
+msgid "Add or parse structured information in commit messages"
+msgstr "Aggiunge o analizza informazioni strutturate nei messaggi di commit"
+
+#: command-list.h:114
+msgid "The Git repository browser"
+msgstr "Il browser per i repository Git"
+
+#: command-list.h:115
+msgid "Show commit logs"
+msgstr "Visualizza i log dei commit"
+
+#: command-list.h:116
+msgid "Show information about files in the index and the working tree"
+msgstr "Visualizza informazioni sui file nell'indice e nell'albero di lavoro"
+
+#: command-list.h:117
+msgid "List references in a remote repository"
+msgstr "Elenca i riferimenti in un repository remoto"
+
+#: command-list.h:118
+msgid "List the contents of a tree object"
+msgstr "Elenca i contenuti di un oggetto albero"
+
+#: command-list.h:119
+msgid "Extracts patch and authorship from a single e-mail message"
+msgstr ""
+"Estrae la patch e le informazioni sull'autore da un singolo messaggio e-mail"
+
+#: command-list.h:120
+msgid "Simple UNIX mbox splitter program"
+msgstr "Un semplice programma per suddividere i file UNIX mbox"
+
+#: command-list.h:121
+msgid "Join two or more development histories together"
+msgstr "Unisce due o più cronologie di sviluppo"
+
+#: command-list.h:122
+msgid "Find as good common ancestors as possible for a merge"
+msgstr "Trova il maggior numero possibile di antenati comuni per un merge"
+
+#: command-list.h:123
+msgid "Run a three-way file merge"
+msgstr "Esegue un merge a tre vie su file"
+
+#: command-list.h:124
+msgid "Run a merge for files needing merging"
+msgstr "Esegue un merge per i file che lo richiedono"
+
+#: command-list.h:125
+msgid "The standard helper program to use with git-merge-index"
+msgstr "Il programma helper standard da usare con git-merge-index"
+
+#: command-list.h:126
+msgid "Run merge conflict resolution tools to resolve merge conflicts"
+msgstr ""
+"Esegue gli strumenti di risoluzione conflitti di merge per risolvere i "
+"conflitti di merge"
+
+#: command-list.h:127
+msgid "Show three-way merge without touching index"
+msgstr "Visualizza un merge a tre vie senza modificare l'indice"
+
+#: command-list.h:128
+msgid "Write and verify multi-pack-indexes"
+msgstr "Scrive e verifica indici multi-pack"
+
+#: command-list.h:129
+msgid "Creates a tag object"
+msgstr "Crea un oggetto tag"
+
+#: command-list.h:130
+msgid "Build a tree-object from ls-tree formatted text"
+msgstr "Genera un oggetto albero da testo in formato ls-tree"
+
+#: command-list.h:131
+msgid "Move or rename a file, a directory, or a symlink"
+msgstr "Sposta o rinomina un file, una directory o un collegamento simbolico"
+
+#: command-list.h:132
+msgid "Find symbolic names for given revs"
+msgstr "Trova i nomi simbolici per le revisioni date"
+
+#: command-list.h:133
+msgid "Add or inspect object notes"
+msgstr "Aggiunge o esamina le note agli oggetti"
+
+#: command-list.h:134
+msgid "Import from and submit to Perforce repositories"
+msgstr "Importa dati da, o invia dati a, repository Perforce"
+
+#: command-list.h:135
+msgid "Create a packed archive of objects"
+msgstr "Crea un archivio di oggetti sottoposto a pack"
+
+#: command-list.h:136
+msgid "Find redundant pack files"
+msgstr "Trova file pack ridondanti"
+
+#: command-list.h:137
+msgid "Pack heads and tags for efficient repository access"
+msgstr "Esegue il pack di head e tag per un accesso efficiente al repository"
+
+#: command-list.h:138
+msgid "Routines to help parsing remote repository access parameters"
+msgstr ""
+"Routine che aiutano ad analizzare i parametri di accesso ai repository remoti"
+
+#: command-list.h:139
+msgid "Compute unique ID for a patch"
+msgstr "Calcola l'ID univoco per una patch"
+
+#: command-list.h:140
+msgid "Prune all unreachable objects from the object database"
+msgstr "Elimina tutti gli oggetti non raggiungibili dal database oggetti"
+
+#: command-list.h:141
+msgid "Remove extra objects that are already in pack files"
+msgstr "Rimuove gli oggetti aggiuntivi già presenti nei file pack"
+
+#: command-list.h:142
+msgid "Fetch from and integrate with another repository or a local branch"
+msgstr ""
+"Esegue il fetch e l'integrazione con un altro repository o un branch locale"
+
+#: command-list.h:143
+msgid "Update remote refs along with associated objects"
+msgstr "Aggiorna i riferimenti remoti insieme agli oggetti associati"
+
+#: command-list.h:144
+msgid "Applies a quilt patchset onto the current branch"
+msgstr "Applica un insieme di patch quilt sul branch corrente"
+
+#: command-list.h:145
+msgid "Compare two commit ranges (e.g. two versions of a branch)"
+msgstr "Compara due intervalli di commit (ad es. due versioni di un branch)"
+
+#: command-list.h:146
+msgid "Reads tree information into the index"
+msgstr "Legge le informazioni su un albero dall'indice"
+
+#: command-list.h:147
+msgid "Reapply commits on top of another base tip"
+msgstr "Riapplica dei commit dopo l'ultimo commit di un branch"
+
+#: command-list.h:148
+msgid "Receive what is pushed into the repository"
+msgstr "Riceve quanto sottoposto a push nel repository"
+
+#: command-list.h:149
+msgid "Manage reflog information"
+msgstr "Gestisce le informazioni del registro dei riferimenti"
+
+#: command-list.h:150
+msgid "Manage set of tracked repositories"
+msgstr "Gestisce l'insieme dei repository tracciati"
+
+#: command-list.h:151
+msgid "Pack unpacked objects in a repository"
+msgstr "Esegue il pack degli oggetti non sottoposti a pack in un repository"
+
+#: command-list.h:152
+msgid "Create, list, delete refs to replace objects"
+msgstr "Crea, elenca, elimina i riferimenti per sostituire oggetti"
+
+#: command-list.h:153
+msgid "Generates a summary of pending changes"
+msgstr "Genera un riassunto delle modifiche in sospeso"
+
+#: command-list.h:154
+msgid "Reuse recorded resolution of conflicted merges"
+msgstr "Riusa la risoluzione registrata dei merge che hanno generato conflitti"
+
+#: command-list.h:155
+msgid "Reset current HEAD to the specified state"
+msgstr "Ripristina l'HEAD corrente allo stato specificato"
+
+#: command-list.h:156
+msgid "Restore working tree files"
+msgstr "Ripristina i file nell'albero di lavoro"
+
+#: command-list.h:157
+msgid "Revert some existing commits"
+msgstr "Esegue il revert di alcuni commit esistenti"
+
+#: command-list.h:158
+msgid "Lists commit objects in reverse chronological order"
+msgstr "Elenca gli oggetti commit in ordine cronologico inverso"
+
+#: command-list.h:159
+msgid "Pick out and massage parameters"
+msgstr "Sceglie e altera i parametri"
+
+#: command-list.h:160
+msgid "Remove files from the working tree and from the index"
+msgstr "Rimuove file dall'albero di lavoro e dall'indice"
+
+#: command-list.h:161
+msgid "Send a collection of patches as emails"
+msgstr "Invia un insieme di patch come e-mail"
+
+#: command-list.h:162
+msgid "Push objects over Git protocol to another repository"
+msgstr ""
+"Esegue il push di oggetti su un altro repository tramite il protocollo Git"
+
+#: command-list.h:163
+msgid "Restricted login shell for Git-only SSH access"
+msgstr "Shell di login limitata per concedere accesso SSH solo per Git"
+
+#: command-list.h:164
+msgid "Summarize 'git log' output"
+msgstr "Riassume l'output di 'git log'"
+
+#: command-list.h:165
+msgid "Show various types of objects"
+msgstr "Visualizza vari tipi di oggetti"
+
+#: command-list.h:166
+msgid "Show branches and their commits"
+msgstr "Visualizza i branch e i loro commit"
+
+#: command-list.h:167
+msgid "Show packed archive index"
+msgstr "Visualizza l'indice di un archivio sottoposto a pack"
+
+#: command-list.h:168
+msgid "List references in a local repository"
+msgstr "Elenca i riferimenti in un repository locale"
+
+#: command-list.h:169
+msgid "Git's i18n setup code for shell scripts"
+msgstr ""
+"Codice di inizializzazione dell'internazionalizzazione di Git per gli script "
+"shell"
+
+#: command-list.h:170
+msgid "Common Git shell script setup code"
+msgstr "Codice comune di inizializzazione di Git per gli script shell"
+
+#: command-list.h:171
+msgid "Initialize and modify the sparse-checkout"
+msgstr "Inizializza e modifica sparse-checkout"
+
+#: command-list.h:172
+msgid "Stash the changes in a dirty working directory away"
+msgstr "Mette da parte le modifiche in una directory di lavoro sporca"
+
+#: command-list.h:173
+msgid "Add file contents to the staging area"
+msgstr "Aggiunge i contenuti dei file all'area di staging"
+
+#: command-list.h:174
+msgid "Show the working tree status"
+msgstr "Visualizza lo stato dell'albero di lavoro"
+
+#: command-list.h:175
+msgid "Remove unnecessary whitespace"
+msgstr "Rimuove spazi bianchi non necessari"
+
+#: command-list.h:176
+msgid "Initialize, update or inspect submodules"
+msgstr "Inizializza, aggiorna o esamina sottomoduli"
+
+#: command-list.h:177
+msgid "Bidirectional operation between a Subversion repository and Git"
+msgstr "Operatività bidirezionale tra un repository Subversion e Git"
+
+#: command-list.h:178
+msgid "Switch branches"
+msgstr "Passa da un branch a un altro"
+
+#: command-list.h:179
+msgid "Read, modify and delete symbolic refs"
+msgstr "Legge, modifica ed elimina riferimenti simbolici"
+
+#: command-list.h:180
+msgid "Create, list, delete or verify a tag object signed with GPG"
+msgstr "Crea, elenca, elimina o verifica un oggetto tag firmato con GPG"
+
+#: command-list.h:181
+msgid "Creates a temporary file with a blob's contents"
+msgstr "Crea un file temporaneo con i contenuti di un blob"
+
+#: command-list.h:182
+msgid "Unpack objects from a packed archive"
+msgstr "Decomprime gli oggetti da un archivio sottoposto a pack"
+
+#: command-list.h:183
+msgid "Register file contents in the working tree to the index"
+msgstr "Registra i contenuti dei file dell'albero di lavoro nell'indice"
+
+#: command-list.h:184
+msgid "Update the object name stored in a ref safely"
+msgstr "Aggiorna in modo sicuro il nome oggetto salvato in un riferimento"
+
+#: command-list.h:185
+msgid "Update auxiliary info file to help dumb servers"
+msgstr "Aggiorna il file informazioni aggiuntive per aiutare i server stupidi"
+
+#: command-list.h:186
+msgid "Send archive back to git-archive"
+msgstr "Reinvia l'archivio a git-archive"
+
+#: command-list.h:187
+msgid "Send objects packed back to git-fetch-pack"
+msgstr "Reinvia gli oggetti sottoposti a pack a git-fetch-pack"
+
+#: command-list.h:188
+msgid "Show a Git logical variable"
+msgstr "Visualizza una variabile logica di Git"
+
+#: command-list.h:189
+msgid "Check the GPG signature of commits"
+msgstr "Verifica la firma GPG dei commit"
+
+#: command-list.h:190
+msgid "Validate packed Git archive files"
+msgstr "Convalida i file archivio sottoposti a pack di Git"
+
+#: command-list.h:191
+msgid "Check the GPG signature of tags"
+msgstr "Verifica la firma GPG dei tag"
+
+#: command-list.h:192
+msgid "Git web interface (web frontend to Git repositories)"
+msgstr "Interfaccia Web per Git (frontend Web ai repository Git)"
+
+#: command-list.h:193
+msgid "Show logs with difference each commit introduces"
+msgstr ""
+"Visualizza i registri insieme alle differenze introdotte da ciascun commit"
+
+#: command-list.h:194
+msgid "Manage multiple working trees"
+msgstr "Gestisce alberi di lavoro multipli"
+
+#: command-list.h:195
+msgid "Create a tree object from the current index"
+msgstr "Crea un oggetto albero dall'indice corrente"
+
+#: command-list.h:196
+msgid "Defining attributes per path"
+msgstr "Definizione di attributi per percorso"
+
+#: command-list.h:197
+msgid "Git command-line interface and conventions"
+msgstr "Interfaccia a riga di comando di Git e convenzioni"
+
+#: command-list.h:198
+msgid "A Git core tutorial for developers"
+msgstr "Un tutorial Git di base per gli sviluppatori"
+
+#: command-list.h:199
+msgid "Git for CVS users"
+msgstr "Git per utenti CVS"
+
+#: command-list.h:200
+msgid "Tweaking diff output"
+msgstr "Messa a punto dell'output di diff"
+
+#: command-list.h:201
+msgid "A useful minimum set of commands for Everyday Git"
+msgstr "Un insieme di comandi utile e minimale per l'uso quotidiano di Git"
+
+#: command-list.h:202
+msgid "A Git Glossary"
+msgstr "Un glossario di Git"
+
+#: command-list.h:203
+msgid "Hooks used by Git"
+msgstr "Hook usati da Git"
+
+#: command-list.h:204
+msgid "Specifies intentionally untracked files to ignore"
+msgstr "Specifica i file intenzionalmente non tracciati da ignorare"
+
+#: command-list.h:205
+msgid "Defining submodule properties"
+msgstr "Definizione proprietà sottomodulo"
+
+#: command-list.h:206
+msgid "Git namespaces"
+msgstr "Spazi dei nomi Git"
+
+#: command-list.h:207
+msgid "Git Repository Layout"
+msgstr "Struttura repository Git"
+
+#: command-list.h:208
+msgid "Specifying revisions and ranges for Git"
+msgstr "Come specificare revisioni e intervalli in Git"
+
+#: command-list.h:209
+msgid "Mounting one repository inside another"
+msgstr "Monto un repository dentro un altro"
+
+#: command-list.h:210
+msgid "A tutorial introduction to Git: part two"
+msgstr "Un tutorial introduttivo per Git: seconda parte"
+
+#: command-list.h:211
+msgid "A tutorial introduction to Git"
+msgstr "Un tutorial introduttivo per Git"
+
+#: command-list.h:212
+msgid "An overview of recommended workflows with Git"
+msgstr "Una panoramica dei flussi di lavoro raccomandati in Git"
+
+#: git-bisect.sh:54
+msgid "You need to start by \"git bisect start\""
+msgstr "Devi iniziare con \"git bisect start\""
+
+#. TRANSLATORS: Make sure to include [Y] and [n] in your
+#. translation. The program will only accept English input
+#. at this point.
+#: git-bisect.sh:60
+msgid "Do you want me to do it for you [Y/n]? "
+msgstr "Vuoi che me ne occupi io [Y/n]? "
+
+#: git-bisect.sh:101
+#, sh-format
+msgid "Bad rev input: $arg"
+msgstr "Revisione fornita non valida: $arg"
+
+#: git-bisect.sh:121
+#, sh-format
+msgid "Bad rev input: $bisected_head"
+msgstr "Revisione fornita non valida: $bisected_head"
+
+#: git-bisect.sh:130
+#, sh-format
+msgid "Bad rev input: $rev"
+msgstr "Revisione fornita non valida: $rev"
+
+#: git-bisect.sh:139
+#, sh-format
+msgid "'git bisect $TERM_BAD' can take only one argument."
+msgstr "'git bisect $TERM_BAD' richiede un solo argomento."
+
+#: git-bisect.sh:209
+msgid "No logfile given"
+msgstr "Nessun file di log specificato"
+
+#: git-bisect.sh:210
+#, sh-format
+msgid "cannot read $file for replaying"
+msgstr "impossibile leggere $file per rieseguire i comandi contenuti"
+
+#: git-bisect.sh:232
+msgid "?? what are you talking about?"
+msgstr "?? di cosa stai parlando?"
+
+#: git-bisect.sh:241
+msgid "bisect run failed: no command provided."
+msgstr "esecuzione di bisect non riuscita: nessun comando fornito."
+
+#: git-bisect.sh:246
+#, sh-format
+msgid "running $command"
+msgstr "esecuzione di $command in corso"
+
+#: git-bisect.sh:253
+#, sh-format
+msgid ""
+"bisect run failed:\n"
+"exit code $res from '$command' is < 0 or >= 128"
+msgstr ""
+"esecuzione di bisect non riuscita:\n"
+"il codice di uscita $res da '$command' è < 0 oppure >= 128"
+
+#: git-bisect.sh:279
+msgid "bisect run cannot continue any more"
+msgstr "l'esecuzione di bisect non può più proseguire"
+
+#: git-bisect.sh:285
+#, sh-format
+msgid ""
+"bisect run failed:\n"
+"'bisect_state $state' exited with error code $res"
+msgstr ""
+"esecuzione di bisect non riuscita:\n"
+"'bisect_state $state' è uscito con il codice di errore $res"
+
+#: git-bisect.sh:292
+msgid "bisect run success"
+msgstr "esecuzione di bisect completata con successo"
+
+#: git-bisect.sh:300
+msgid "We are not bisecting."
+msgstr "Non stiamo eseguendo una bisezione."
+
+#: git-merge-octopus.sh:46
+msgid ""
+"Error: Your local changes to the following files would be overwritten by "
+"merge"
+msgstr ""
+"Errore: le tue modifiche locali ai seguenti file sarebbero sovrascritte dal "
+"merge"
+
+#: git-merge-octopus.sh:61
+msgid "Automated merge did not work."
+msgstr "Il merge automatico non ha funzionato."
+
+#: git-merge-octopus.sh:62
+msgid "Should not be doing an octopus."
+msgstr "Non dovrebbe essere eseguito un merge octopus."
+
+#: git-merge-octopus.sh:73
+#, sh-format
+msgid "Unable to find common commit with $pretty_name"
+msgstr "Impossibile trovare un commit comune con $pretty_name"
+
+#: git-merge-octopus.sh:77
+#, sh-format
+msgid "Already up to date with $pretty_name"
+msgstr "Già aggiornato rispetto a $pretty_name"
+
+#: git-merge-octopus.sh:89
+#, sh-format
+msgid "Fast-forwarding to: $pretty_name"
+msgstr "Eseguo il fast forward a: $pretty_name"
+
+#: git-merge-octopus.sh:97
+#, sh-format
+msgid "Trying simple merge with $pretty_name"
+msgstr "Provo un merge semplice con $pretty_name"
+
+#: git-merge-octopus.sh:102
+msgid "Simple merge did not work, trying automatic merge."
+msgstr "Il merge semplice non ha funzionato, provo il merge automatico."
+
+#: git-legacy-stash.sh:221
+msgid "Cannot remove temporary index (can't happen)"
+msgstr "Impossibile rimuovere l'indice temporaneo (non può succedere)"
+
+#: git-legacy-stash.sh:272
+#, sh-format
+msgid "Cannot update $ref_stash with $w_commit"
+msgstr "Impossibile aggiornare $ref_stash con $w_commit"
+
+#: git-legacy-stash.sh:324
+#, sh-format
+msgid "error: unknown option for 'stash push': $option"
+msgstr "errore: opzione sconosciuta per 'stash push': $option"
+
+#: git-legacy-stash.sh:356
+#, sh-format
+msgid "Saved working directory and index state $stash_msg"
+msgstr "Directory di lavoro e stato indice salvati: $stash_msg"
+
+#: git-legacy-stash.sh:536
+#, sh-format
+msgid "unknown option: $opt"
+msgstr "opzione sconosciuta: $opt"
+
+#: git-legacy-stash.sh:556
+#, sh-format
+msgid "Too many revisions specified: $REV"
+msgstr "Troppe revisioni specificate: $REV"
+
+#: git-legacy-stash.sh:571
+#, sh-format
+msgid "$reference is not a valid reference"
+msgstr "$reference non è un riferimento valido"
+
+#: git-legacy-stash.sh:599
+#, sh-format
+msgid "'$args' is not a stash-like commit"
+msgstr "'$args' non è un commit di tipo stash"
+
+#: git-legacy-stash.sh:610
+#, sh-format
+msgid "'$args' is not a stash reference"
+msgstr "'$args' non è un riferimento a uno stash"
+
+#: git-legacy-stash.sh:618
+msgid "unable to refresh index"
+msgstr "impossibile aggiornare l'indice"
+
+#: git-legacy-stash.sh:622
+msgid "Cannot apply a stash in the middle of a merge"
+msgstr "Impossibile applicare uno stash nel mezzo di un merge"
+
+#: git-legacy-stash.sh:630
+msgid "Conflicts in index. Try without --index."
+msgstr "Ci sono conflitti in index. Prova senza --index."
+
+#: git-legacy-stash.sh:632
+msgid "Could not save index tree"
+msgstr "Non è stato possibile salvare l'albero indice"
+
+#: git-legacy-stash.sh:641
+msgid "Could not restore untracked files from stash entry"
+msgstr ""
+"Non è stato possibile ripristinare i file non tracciati dalla voce stash"
+
+#: git-legacy-stash.sh:666
+msgid "Cannot unstage modified files"
+msgstr "Non è stato possibile rimuovere i file modificati dall'area di staging"
+
+#: git-legacy-stash.sh:704
+#, sh-format
+msgid "Dropped ${REV} ($s)"
+msgstr "${REV} eliminata ($s)"
+
+#: git-legacy-stash.sh:705
+#, sh-format
+msgid "${REV}: Could not drop stash entry"
+msgstr "${REV}: non è stato possibile rimuovere la voce di stash"
+
+#: git-legacy-stash.sh:792
+msgid "(To restore them type \"git stash apply\")"
+msgstr "(Per ripristinarli digita \"git stash apply\")"
+
+#: git-submodule.sh:202
+msgid "Relative path can only be used from the toplevel of the working tree"
+msgstr ""
+"Il percorso relativo può essere usato solo dal primo livello dell'albero di "
+"lavoro"
+
+#: git-submodule.sh:212
+#, sh-format
+msgid "repo URL: '$repo' must be absolute or begin with ./|../"
+msgstr "URL repository:: '$repo' deve essere assoluto o iniziare con ./|../"
+
+#: git-submodule.sh:231
+#, sh-format
+msgid "'$sm_path' already exists in the index"
+msgstr "'$sm_path' esiste già nell'indice"
+
+#: git-submodule.sh:234
+#, sh-format
+msgid "'$sm_path' already exists in the index and is not a submodule"
+msgstr "'$sm_path' esiste già nell'indice e non è un sottomodulo"
+
+#: git-submodule.sh:241
+#, sh-format
+msgid "'$sm_path' does not have a commit checked out"
+msgstr "'$sm_path' non ha un commit di cui è stato eseguito il checkout"
+
+#: git-submodule.sh:247
+#, sh-format
+msgid ""
+"The following path is ignored by one of your .gitignore files:\n"
+"$sm_path\n"
+"Use -f if you really want to add it."
+msgstr ""
+"Il seguente percorso è ignorato da uno dei tuoi file .gitignore:\n"
+"$sm_path\n"
+"Usa -f se vuoi davvero aggiungerlo."
+
+#: git-submodule.sh:270
+#, sh-format
+msgid "Adding existing repo at '$sm_path' to the index"
+msgstr "Aggiunta del repository esistente in '$sm_path' all'indice"
+
+#: git-submodule.sh:272
+#, sh-format
+msgid "'$sm_path' already exists and is not a valid git repo"
+msgstr "'$sm_path' esiste già e non è un repository Git valido"
+
+#: git-submodule.sh:280
+#, sh-format
+msgid "A git directory for '$sm_name' is found locally with remote(s):"
+msgstr ""
+"È stata trovata localmente una directory Git per '$sm_name' con i seguenti "
+"remoti:"
+
+#: git-submodule.sh:282
+#, sh-format
+msgid ""
+"If you want to reuse this local git directory instead of cloning again from\n"
+"  $realrepo\n"
+"use the '--force' option. If the local git directory is not the correct "
+"repo\n"
+"or you are unsure what this means choose another name with the '--name' "
+"option."
+msgstr ""
+"Se vuoi riusare questa directory Git locale anziché clonarla nuovamente da\n"
+"  $realrepo\n"
+"usa l'opzione '--force'. Se la directory Git locale non è il repository\n"
+"corretto, o se non sei sicuro di ciò che questo voglia dire, scegli un "
+"altro\n"
+"nome con l'opzione '--name'."
+
+#: git-submodule.sh:288
+#, sh-format
+msgid "Reactivating local git directory for submodule '$sm_name'."
+msgstr "Riattivo la directory Git locale per il sottomodulo '$sm_name'."
+
+#: git-submodule.sh:300
+#, sh-format
+msgid "Unable to checkout submodule '$sm_path'"
+msgstr "Impossibile eseguire il checkout del sottomodulo '$sm_path'"
+
+#: git-submodule.sh:305
+#, sh-format
+msgid "Failed to add submodule '$sm_path'"
+msgstr "Aggiunta del sottomodulo '$sm_path' non riuscita"
+
+#: git-submodule.sh:314
+#, sh-format
+msgid "Failed to register submodule '$sm_path'"
+msgstr "Registrazione del sottomodulo '$sm_path' non riuscita"
+
+#: git-submodule.sh:580
+#, sh-format
+msgid "Unable to find current revision in submodule path '$displaypath'"
+msgstr ""
+"Impossibile trovare la revisione corrente nel percorso del sottomodulo "
+"'$displaypath'"
+
+#: git-submodule.sh:590
+#, sh-format
+msgid "Unable to fetch in submodule path '$sm_path'"
+msgstr "Impossibile eseguire il fetch nel percorso del sottomodulo '$sm_path'"
+
+#: git-submodule.sh:595
+#, sh-format
+msgid ""
+"Unable to find current ${remote_name}/${branch} revision in submodule path "
+"'$sm_path'"
+msgstr ""
+"Impossibile trovare la revisione corrente per ${remote_name}/${branch} nel "
+"percorso del sottomodulo '$sm_path'"
+
+#: git-submodule.sh:613
+#, sh-format
+msgid ""
+"Unable to fetch in submodule path '$displaypath'; trying to directly fetch "
+"$sha1:"
+msgstr ""
+"Impossibile eseguire il fetch nel percorso del sottomodulo '$displaypath'; "
+"provo a recuperare direttamente $sha1:"
+
+#: git-submodule.sh:619
+#, sh-format
+msgid ""
+"Fetched in submodule path '$displaypath', but it did not contain $sha1. "
+"Direct fetching of that commit failed."
+msgstr ""
+"Fetch eseguito nel percorso del sottomodulo '$displaypath', ma non conteneva "
+"$sha1. Fetch diretto di tale commit non riuscito."
+
+#: git-submodule.sh:626
+#, sh-format
+msgid "Unable to checkout '$sha1' in submodule path '$displaypath'"
+msgstr ""
+"Impossibile eseguire il checkout di '$sha1' nel percorso del sottomodulo "
+"'$displaypath'"
+
+#: git-submodule.sh:627
+#, sh-format
+msgid "Submodule path '$displaypath': checked out '$sha1'"
+msgstr "Percorso del sottomodulo '$displaypath': eseguito checkout di '$sha1'"
+
+#: git-submodule.sh:631
+#, sh-format
+msgid "Unable to rebase '$sha1' in submodule path '$displaypath'"
+msgstr ""
+"Impossibile eseguire il rebase di '$sha1' nel percorso del sottomodulo "
+"'$displaypath'"
+
+#: git-submodule.sh:632
+#, sh-format
+msgid "Submodule path '$displaypath': rebased into '$sha1'"
+msgstr "Percorso del sottomodulo '$displaypath': eseguito rebase su '$sha1'"
+
+#: git-submodule.sh:637
+#, sh-format
+msgid "Unable to merge '$sha1' in submodule path '$displaypath'"
+msgstr ""
+"Impossibile eseguire il merge di '$sha1' nel percorso del sottomodulo "
+"'$displaypath'"
+
+#: git-submodule.sh:638
+#, sh-format
+msgid "Submodule path '$displaypath': merged in '$sha1'"
+msgstr "Percorso del sottomodulo '$displaypath': eseguito merge in '$sha1'"
+
+#: git-submodule.sh:643
+#, sh-format
+msgid "Execution of '$command $sha1' failed in submodule path '$displaypath'"
+msgstr ""
+"Esecuzione di '$command $sha1' non riuscita nel percorso del sottomodulo "
+"'$displaypath'"
+
+#: git-submodule.sh:644
+#, sh-format
+msgid "Submodule path '$displaypath': '$command $sha1'"
+msgstr "Percorso del sottomodulo '$displaypath': '$command $sha1'"
+
+#: git-submodule.sh:675
+#, sh-format
+msgid "Failed to recurse into submodule path '$displaypath'"
+msgstr "Ricorsione nel percorso del sottomodulo '$displaypath' non riuscita"
+
+#: git-submodule.sh:886
+msgid "The --cached option cannot be used with the --files option"
+msgstr "L'opzione --cached non può essere usata con l'opzione --files"
+
+#: git-submodule.sh:938
+#, sh-format
+msgid "unexpected mode $mod_dst"
+msgstr "modalità $mod_dst inattesa"
+
+#: git-submodule.sh:958
+#, sh-format
+msgid "  Warn: $display_name doesn't contain commit $sha1_src"
+msgstr "  Attenzione: $display_name non contiene il commit $sha1_src"
+
+#: git-submodule.sh:961
+#, sh-format
+msgid "  Warn: $display_name doesn't contain commit $sha1_dst"
+msgstr "  Attenzione: $display_name non contiene il commit $sha1_dst"
+
+#: git-submodule.sh:964
+#, sh-format
+msgid "  Warn: $display_name doesn't contain commits $sha1_src and $sha1_dst"
+msgstr ""
+"  Attenzione: $display_name non contiene i commit $sha1_src e $sha1_dst"
+
+#: git-parse-remote.sh:89
+#, sh-format
+msgid "See git-${cmd}(1) for details."
+msgstr "Vedi git-${cmd}(1) per ulteriori dettagli."
+
+#: git-rebase--preserve-merges.sh:109
+msgid "Applied autostash."
+msgstr "Stash automatico applicato."
+
+#: git-rebase--preserve-merges.sh:112
+#, sh-format
+msgid "Cannot store $stash_sha1"
+msgstr "Impossibile memorizzare $stash_sha1"
+
+#: git-rebase--preserve-merges.sh:191
+#, sh-format
+msgid "Rebasing ($new_count/$total)"
+msgstr "Rebase in corso ($new_count/$total)"
+
+#: git-rebase--preserve-merges.sh:207
+msgid ""
+"\n"
+"Commands:\n"
+"p, pick <commit> = use commit\n"
+"r, reword <commit> = use commit, but edit the commit message\n"
+"e, edit <commit> = use commit, but stop for amending\n"
+"s, squash <commit> = use commit, but meld into previous commit\n"
+"f, fixup <commit> = like \"squash\", but discard this commit's log message\n"
+"x, exec <commit> = run command (the rest of the line) using shell\n"
+"d, drop <commit> = remove commit\n"
+"l, label <label> = label current HEAD with a name\n"
+"t, reset <label> = reset HEAD to a label\n"
+"m, merge [-C <commit> | -c <commit>] <label> [# <oneline>]\n"
+".       create a merge commit using the original merge commit's\n"
+".       message (or the oneline, if no original merge commit was\n"
+".       specified). Use -c <commit> to reword the commit message.\n"
+"\n"
+"These lines can be re-ordered; they are executed from top to bottom.\n"
+msgstr ""
+"\n"
+"Comandi:\n"
+"p, pick <commit> = usa il commit\n"
+"r, reword <commit> = usa il commit, ma modifica il messaggio di commit\n"
+"e, edit <commit> = usa il commit, ma fermati per modificarlo\n"
+"s, squash <commit> = usa il commit, ma fondilo con il commit precedente\n"
+"f, fixup <commit> = come \"squash\", ma scarta il messaggio di log di "
+"questo\n"
+"                    commit\n"
+"x, exec <comando> = esegui il comando (il resto della riga) usando la shell\n"
+"d, drop <commit> = elimina il commit\n"
+"l, label <etichetta> = etichetta l'HEAD corrente con un nome\n"
+"t, reset <etichetta> = reimposta HEAD a un'etichetta\n"
+"m, merge [-C <commit> | -c <commit>] <etichetta> [# <oneline>]\n"
+".       crea un commit di merge usando il messaggio del commit di merge\n"
+".       originale (o la oneline se non è stato specificato un commit di "
+"merge\n"
+".       originale). Usa -c <commit> per riformulare il messaggio di commit.\n"
+"\n"
+"Queste righe possono essere riordinate; saranno eseguite dalla prima "
+"all'ultima.\n"
+
+#: git-rebase--preserve-merges.sh:270
+#, sh-format
+msgid ""
+"You can amend the commit now, with\n"
+"\n"
+"\tgit commit --amend $gpg_sign_opt_quoted\n"
+"\n"
+"Once you are satisfied with your changes, run\n"
+"\n"
+"\tgit rebase --continue"
+msgstr ""
+"È possibile modificare il commit ora con\n"
+"\n"
+"\tgit commit --amend $gpg_sign_opt_quoted\n"
+"\n"
+"Quando sei soddisfatto delle modifiche, esegui\n"
+"\n"
+"\tgit rebase --continue"
+
+#: git-rebase--preserve-merges.sh:295
+#, sh-format
+msgid "$sha1: not a commit that can be picked"
+msgstr "$sha1: non è un commit che possa essere scelto"
+
+#: git-rebase--preserve-merges.sh:334
+#, sh-format
+msgid "Invalid commit name: $sha1"
+msgstr "Nome commit non valido: $sha1"
+
+#: git-rebase--preserve-merges.sh:364
+msgid "Cannot write current commit's replacement sha1"
+msgstr ""
+"Impossibile scrivere lo SHA1 del commit che dovrebbe sostituire quello "
+"corrente"
+
+#: git-rebase--preserve-merges.sh:415
+#, sh-format
+msgid "Fast-forward to $sha1"
+msgstr "Fast forward a $sha1"
+
+#: git-rebase--preserve-merges.sh:417
+#, sh-format
+msgid "Cannot fast-forward to $sha1"
+msgstr "Impossibile eseguire il fast forward a $sha1"
+
+#: git-rebase--preserve-merges.sh:426
+#, sh-format
+msgid "Cannot move HEAD to $first_parent"
+msgstr "Impossibile spostare l'HEAD a $first_parent"
+
+#: git-rebase--preserve-merges.sh:431
+#, sh-format
+msgid "Refusing to squash a merge: $sha1"
+msgstr "Mi rifiuto di eseguire lo squash di un merge: $sha1"
+
+#: git-rebase--preserve-merges.sh:449
+#, sh-format
+msgid "Error redoing merge $sha1"
+msgstr "Errore durante la riesecuzione del merge di $sha1"
+
+#: git-rebase--preserve-merges.sh:458
+#, sh-format
+msgid "Could not pick $sha1"
+msgstr "Impossibile scegliere $sha1"
+
+#: git-rebase--preserve-merges.sh:467
+#, sh-format
+msgid "This is the commit message #${n}:"
+msgstr "Questo è il messaggio di commit numero ${n}:"
+
+#: git-rebase--preserve-merges.sh:472
+#, sh-format
+msgid "The commit message #${n} will be skipped:"
+msgstr "Il messaggio di commit numero ${n} sarà saltato:"
+
+#: git-rebase--preserve-merges.sh:483
+#, sh-format
+msgid "This is a combination of $count commit."
+msgid_plural "This is a combination of $count commits."
+msgstr[0] "Questa è una combinazione di $count commit."
+msgstr[1] "Questa è una combinazione di $count commit."
+
+#: git-rebase--preserve-merges.sh:492
+#, sh-format
+msgid "Cannot write $fixup_msg"
+msgstr "Impossibile scrivere $fixup_msg"
+
+#: git-rebase--preserve-merges.sh:495
+msgid "This is a combination of 2 commits."
+msgstr "Questa è una combinazione di 2 commit."
+
+#: git-rebase--preserve-merges.sh:536 git-rebase--preserve-merges.sh:579
+#: git-rebase--preserve-merges.sh:582
+#, sh-format
+msgid "Could not apply $sha1... $rest"
+msgstr "Impossibile applicare $sha1... $rest"
+
+#: git-rebase--preserve-merges.sh:611
+#, sh-format
+msgid ""
+"Could not amend commit after successfully picking $sha1... $rest\n"
+"This is most likely due to an empty commit message, or the pre-commit hook\n"
+"failed. If the pre-commit hook failed, you may need to resolve the issue "
+"before\n"
+"you are able to reword the commit."
+msgstr ""
+"Impossibile modificare il commit dopo la scelta di $sha1... $rest\n"
+"Molto probabilmente questo è dovuto a un messaggio di commit vuoto, oppure\n"
+"l'esecuzione dell'hook di pre-commit non è riuscita. In quest'ultimo caso,\n"
+"potrebbe essere necessario risolvere il problema evidenziato per essere in\n"
+"grado di modificare il messaggio di commit."
+
+#: git-rebase--preserve-merges.sh:626
+#, sh-format
+msgid "Stopped at $sha1_abbrev... $rest"
+msgstr "Fermato a $sha1_abbrev... $rest"
+
+#: git-rebase--preserve-merges.sh:641
+#, sh-format
+msgid "Cannot '$squash_style' without a previous commit"
+msgstr "Impossibile eseguire '$squash_style' senza un commit precedente"
+
+#: git-rebase--preserve-merges.sh:683
+#, sh-format
+msgid "Executing: $rest"
+msgstr "Eseguo $rest"
+
+#: git-rebase--preserve-merges.sh:691
+#, sh-format
+msgid "Execution failed: $rest"
+msgstr "Esecuzione non riuscita: $rest"
+
+#: git-rebase--preserve-merges.sh:693
+msgid "and made changes to the index and/or the working tree"
+msgstr "e sono state apportate modifiche all'indice e/o all'albero di lavoro"
+
+#: git-rebase--preserve-merges.sh:695
+msgid ""
+"You can fix the problem, and then run\n"
+"\n"
+"\tgit rebase --continue"
+msgstr ""
+"Puoi correggere il problema e quindi eseguire\n"
+"\n"
+"\tgit rebase --continue"
+
+#. TRANSLATORS: after these lines is a command to be issued by the user
+#: git-rebase--preserve-merges.sh:708
+#, sh-format
+msgid ""
+"Execution succeeded: $rest\n"
+"but left changes to the index and/or the working tree\n"
+"Commit or stash your changes, and then run\n"
+"\n"
+"\tgit rebase --continue"
+msgstr ""
+"Esecuzione riuscita: $rest\n"
+"ma sono state mantenute modifiche all'indice e/o all'albero di lavoro\n"
+"Esegui il commit o lo stash delle modifiche, quindi esegui\n"
+"\n"
+"\tgit rebase --continue"
+
+#: git-rebase--preserve-merges.sh:719
+#, sh-format
+msgid "Unknown command: $command $sha1 $rest"
+msgstr "Comando sconosciuto: $command $sha1 $rest"
+
+#: git-rebase--preserve-merges.sh:720
+msgid "Please fix this using 'git rebase --edit-todo'."
+msgstr "Correggi la situazione usando 'git rebase --edit-todo'."
+
+#: git-rebase--preserve-merges.sh:755
+#, sh-format
+msgid "Successfully rebased and updated $head_name."
+msgstr "Rebase e aggiornamento di $head_name eseguiti con successo."
+
+#: git-rebase--preserve-merges.sh:812
+msgid "Could not remove CHERRY_PICK_HEAD"
+msgstr "impossibile rimuovere CHERRY_PICK_HEAD"
+
+#: git-rebase--preserve-merges.sh:817
+#, sh-format
+msgid ""
+"You have staged changes in your working tree.\n"
+"If these changes are meant to be\n"
+"squashed into the previous commit, run:\n"
+"\n"
+"  git commit --amend $gpg_sign_opt_quoted\n"
+"\n"
+"If they are meant to go into a new commit, run:\n"
+"\n"
+"  git commit $gpg_sign_opt_quoted\n"
+"\n"
+"In both cases, once you're done, continue with:\n"
+"\n"
+"  git rebase --continue\n"
+msgstr ""
+"Hai modifiche in staging nell'albero di lavoro.\n"
+"Se queste modifiche devono essere sottoposte a squash nel commit\n"
+"precedente, esegui:\n"
+"\n"
+"  git commit --amend $gpg_sign_opt_quoted\n"
+"\n"
+"Se devono essere incluse in un nuovo commit, esegui:\n"
+"\n"
+"  git commit $gpg_sign_opt_quoted\n"
+"\n"
+"In entrambi i casi, una volta finito, continua con:\n"
+"\n"
+"  git rebase --continue\n"
+
+#: git-rebase--preserve-merges.sh:834
+msgid "Error trying to find the author identity to amend commit"
+msgstr ""
+"Errore durante la ricerca dell'identità dell'autore per la modifica del "
+"commit"
+
+#: git-rebase--preserve-merges.sh:839
+msgid ""
+"You have uncommitted changes in your working tree. Please commit them\n"
+"first and then run 'git rebase --continue' again."
+msgstr ""
+"Ci sono modifiche di cui non è stato eseguito il commit nel tuo albero\n"
+"di lavoro. Eseguine prima il commit e quindi esegui nuovamente 'git rebase\n"
+"--continue'."
+
+#: git-rebase--preserve-merges.sh:844 git-rebase--preserve-merges.sh:848
+msgid "Could not commit staged changes."
+msgstr "Impossibile eseguire il commit delle modifiche in staging."
+
+#: git-rebase--preserve-merges.sh:879 git-rebase--preserve-merges.sh:965
+msgid "Could not execute editor"
+msgstr "Impossibile eseguire l'editor"
+
+#: git-rebase--preserve-merges.sh:900
+#, sh-format
+msgid "Could not checkout $switch_to"
+msgstr "Impossibile eseguire il checkout di $switch_to"
+
+#: git-rebase--preserve-merges.sh:907
+msgid "No HEAD?"
+msgstr "Nessun'HEAD?"
+
+#: git-rebase--preserve-merges.sh:908
+#, sh-format
+msgid "Could not create temporary $state_dir"
+msgstr "Impossibile creare la directory temporanea $state_dir"
+
+#: git-rebase--preserve-merges.sh:911
+msgid "Could not mark as interactive"
+msgstr "Impossibile contrassegnare come interattivo"
+
+#: git-rebase--preserve-merges.sh:943
+#, sh-format
+msgid "Rebase $shortrevisions onto $shortonto ($todocount command)"
+msgid_plural "Rebase $shortrevisions onto $shortonto ($todocount commands)"
+msgstr[0] "Rebase di $shortrevisions su $shortonto ($todocount comando)"
+msgstr[1] "Rebase di $shortrevisions su $shortonto ($todocount comandi)"
+
+#: git-rebase--preserve-merges.sh:997 git-rebase--preserve-merges.sh:1002
+msgid "Could not init rewritten commits"
+msgstr "Impossibile inizializzare i commit riscritti"
+
+#: git-sh-setup.sh:89 git-sh-setup.sh:94
+#, sh-format
+msgid "usage: $dashless $USAGE"
+msgstr "uso: $dashless $USAGE"
+
+#: git-sh-setup.sh:191
+#, sh-format
+msgid "Cannot chdir to $cdup, the toplevel of the working tree"
+msgstr ""
+"Impossibile modificare la directory corrente in $cdup, il primo livello "
+"dell'albero di lavoro"
+
+#: git-sh-setup.sh:200 git-sh-setup.sh:207
+#, sh-format
+msgid "fatal: $program_name cannot be used without a working tree."
+msgstr ""
+"errore fatale: $program_name non può essere usato senza un albero di lavoro."
+
+#: git-sh-setup.sh:221
+msgid "Cannot rebase: You have unstaged changes."
+msgstr ""
+"Impossibile eseguire il rebase: ci sono delle modifiche non in staging."
+
+#: git-sh-setup.sh:224
+msgid "Cannot rewrite branches: You have unstaged changes."
+msgstr ""
+"Impossibile riscrivere i branch: ci sono delle modifiche non in staging."
+
+#: git-sh-setup.sh:227
+msgid "Cannot pull with rebase: You have unstaged changes."
+msgstr ""
+"Impossibile eseguire un pull seguito da un rebase: ci sono delle modifiche "
+"non in staging."
+
+#: git-sh-setup.sh:230
+#, sh-format
+msgid "Cannot $action: You have unstaged changes."
+msgstr "Impossibile eseguire $action: ci sono delle modifiche non in staging."
+
+#: git-sh-setup.sh:243
+msgid "Cannot rebase: Your index contains uncommitted changes."
+msgstr ""
+"Impossibile eseguire un rebase:: l'indice contiene modifiche di cui non è "
+"stato eseguito il commit."
+
+#: git-sh-setup.sh:246
+msgid "Cannot pull with rebase: Your index contains uncommitted changes."
+msgstr ""
+"Impossibile eseguire un pull seguito da un rebase: l'indice contiene "
+"modifiche di cui non è stato eseguito il commit."
+
+#: git-sh-setup.sh:249
+#, sh-format
+msgid "Cannot $action: Your index contains uncommitted changes."
+msgstr ""
+"Impossibile eseguire $action: l'indice contiene modifiche di cui non è stato "
+"eseguito il commit."
+
+#: git-sh-setup.sh:253
+msgid "Additionally, your index contains uncommitted changes."
+msgstr ""
+"Inoltre, l'indice contiene modifiche di cui non è stato eseguito il commit."
+
+#: git-sh-setup.sh:373
+msgid "You need to run this command from the toplevel of the working tree."
+msgstr "Devi eseguire questo comando dal primo livello dell'albero di lavoro."
+
+#: git-sh-setup.sh:378
+msgid "Unable to determine absolute path of git directory"
+msgstr "Impossibile determinare il percorso assoluto della directory Git"
+
+#. TRANSLATORS: you can adjust this to align "git add -i" status menu
+#: git-add--interactive.perl:212
+#, perl-format
+msgid "%12s %12s %s"
+msgstr "%20s %32s %s"
+
+#: git-add--interactive.perl:634
+#, perl-format
+msgid "touched %d path\n"
+msgid_plural "touched %d paths\n"
+msgstr[0] "eseguito touch su %d percorso\n"
+msgstr[1] "eseguito touch su %d percorsi\n"
+
+#: git-add--interactive.perl:1053
+msgid ""
+"If the patch applies cleanly, the edited hunk will immediately be\n"
+"marked for staging."
+msgstr ""
+"Se la patch viene applicata senza problemi, l'hunk modificato sarà\n"
+"contrassegnato immediatamente per l'aggiunta all'area di staging."
+
+#: git-add--interactive.perl:1056
+msgid ""
+"If the patch applies cleanly, the edited hunk will immediately be\n"
+"marked for stashing."
+msgstr ""
+"Se la patch viene applicata senza problemi, l'hunk modificato sarà\n"
+"contrassegnato immediatamente per lo stash."
+
+#: git-add--interactive.perl:1059
+msgid ""
+"If the patch applies cleanly, the edited hunk will immediately be\n"
+"marked for unstaging."
+msgstr ""
+"Se la patch viene applicata senza problemi, l'hunk modificato sarà\n"
+"contrassegnato immediatamente per la rimozione dall'area di staging."
+
+#: git-add--interactive.perl:1062 git-add--interactive.perl:1071
+#: git-add--interactive.perl:1077
+msgid ""
+"If the patch applies cleanly, the edited hunk will immediately be\n"
+"marked for applying."
+msgstr ""
+"Se la patch viene applicata senza problemi, l'hunk modificato sarà\n"
+"contrassegnato immediatamente per l'applicazione."
+
+#: git-add--interactive.perl:1065 git-add--interactive.perl:1068
+#: git-add--interactive.perl:1074
+msgid ""
+"If the patch applies cleanly, the edited hunk will immediately be\n"
+"marked for discarding."
+msgstr ""
+"Se la patch viene applicata senza problemi, l'hunk modificato sarà\n"
+"contrassegnato immediatamente per la rimozione."
+
+#: git-add--interactive.perl:1111
+#, perl-format
+msgid "failed to open hunk edit file for writing: %s"
+msgstr "apertura del file di modifica hunk in scrittura non riuscita: %s"
+
+#: git-add--interactive.perl:1118
+#, perl-format
+msgid ""
+"---\n"
+"To remove '%s' lines, make them ' ' lines (context).\n"
+"To remove '%s' lines, delete them.\n"
+"Lines starting with %s will be removed.\n"
+msgstr ""
+"---\n"
+"Per rimuovere '%s' righe, rendile righe ' ' (contesto).\n"
+"Per rimuovere '%s' righe, eliminale.\n"
+"Le righe che iniziano con %s saranno rimosse.\n"
+
+#: git-add--interactive.perl:1140
+#, perl-format
+msgid "failed to open hunk edit file for reading: %s"
+msgstr "apertura del file di modifica hunk in lettura non riuscita: %s"
+
+#: git-add--interactive.perl:1248
+msgid ""
+"y - stage this hunk\n"
+"n - do not stage this hunk\n"
+"q - quit; do not stage this hunk or any of the remaining ones\n"
+"a - stage this hunk and all later hunks in the file\n"
+"d - do not stage this hunk or any of the later hunks in the file"
+msgstr ""
+"y - aggiungi quest'hunk all'area di staging\n"
+"n - non aggiungere quest'hunk all'area di staging\n"
+"q - esci; non aggiungere né quest'hunk né quelli rimanenti all'area di "
+"staging\n"
+"a - aggiungi quest'hunk e tutti quelli successivi nel file all'area di "
+"staging\n"
+"d - non aggiungere né quest'hunk né quelli successivi nel file all'area di "
+"staging"
+
+#: git-add--interactive.perl:1254
+msgid ""
+"y - stash this hunk\n"
+"n - do not stash this hunk\n"
+"q - quit; do not stash this hunk or any of the remaining ones\n"
+"a - stash this hunk and all later hunks in the file\n"
+"d - do not stash this hunk or any of the later hunks in the file"
+msgstr ""
+"y - esegui lo stash di quest'hunk\n"
+"n - non eseguire lo stash di quest'hunk\n"
+"q - esci; non eseguire lo stash di quest'hunk né di quelli rimanenti\n"
+"a - esegui lo stash di quest'hunk e di tutti quelli successivi nel file\n"
+"d - non eseguire lo stash né di quest'hunk né di quelli successivi nel file"
+
+#: git-add--interactive.perl:1260
+msgid ""
+"y - unstage this hunk\n"
+"n - do not unstage this hunk\n"
+"q - quit; do not unstage this hunk or any of the remaining ones\n"
+"a - unstage this hunk and all later hunks in the file\n"
+"d - do not unstage this hunk or any of the later hunks in the file"
+msgstr ""
+"y - rimuovi quest'hunk dall'area di staging\n"
+"n - non rimuovere quest'hunk dall'area di staging\n"
+"q - esci; non rimuovere né quest'hunk né quelli rimanenti dall'area di "
+"staging\n"
+"a - rimuovi quest'hunk e tutti quelli successivi nel file dall'area di "
+"staging\n"
+"d - non rimuovere né quest'hunk né quelli successivi nel file dall'area di "
+"staging"
+
+#: git-add--interactive.perl:1266
+msgid ""
+"y - apply this hunk to index\n"
+"n - do not apply this hunk to index\n"
+"q - quit; do not apply this hunk or any of the remaining ones\n"
+"a - apply this hunk and all later hunks in the file\n"
+"d - do not apply this hunk or any of the later hunks in the file"
+msgstr ""
+"y - applica quest'hunk all'indice\n"
+"n - non applicare quest'hunk all'indice\n"
+"q - esci; non applicare né quest'hunk né quelli rimanenti\n"
+"a - applica quest'hunk e tutti quelli successivi nel file\n"
+"d - non applicare né quest'hunk né quelli successivi nel file"
+
+#: git-add--interactive.perl:1272 git-add--interactive.perl:1290
+msgid ""
+"y - discard this hunk from worktree\n"
+"n - do not discard this hunk from worktree\n"
+"q - quit; do not discard this hunk or any of the remaining ones\n"
+"a - discard this hunk and all later hunks in the file\n"
+"d - do not discard this hunk or any of the later hunks in the file"
+msgstr ""
+"y - rimuovi quest'hunk dall'albero di lavoro\n"
+"n - non rimuovere quest'hunk dall'albero di lavoro\n"
+"q - esci; non rimuovere né quest'hunk né quelli rimanenti\n"
+"a - rimuovi quest'hunk e tutti quelli successivi nel file\n"
+"d - non rimuovere né quest'hunk né quelli successivi nel file"
+
+#: git-add--interactive.perl:1278
+msgid ""
+"y - discard this hunk from index and worktree\n"
+"n - do not discard this hunk from index and worktree\n"
+"q - quit; do not discard this hunk or any of the remaining ones\n"
+"a - discard this hunk and all later hunks in the file\n"
+"d - do not discard this hunk or any of the later hunks in the file"
+msgstr ""
+"y - rimuovi quest'hunk dall'indice e dall'albero di lavoro\n"
+"n - non rimuovere quest'hunk dall'indice e dall'albero di lavoro\n"
+"q - esci; non rimuovere né quest'hunk né quelli rimanenti\n"
+"a - rimuovi quest'hunk e tutti quelli successivi nel file\n"
+"d - non rimuovere né quest'hunk né quelli successivi nel file"
+
+#: git-add--interactive.perl:1284
+msgid ""
+"y - apply this hunk to index and worktree\n"
+"n - do not apply this hunk to index and worktree\n"
+"q - quit; do not apply this hunk or any of the remaining ones\n"
+"a - apply this hunk and all later hunks in the file\n"
+"d - do not apply this hunk or any of the later hunks in the file"
+msgstr ""
+"y - applica quest'hunk all'indice e all'albero di lavoro\n"
+"n - non applicare quest'hunk all'indice e all'albero di lavoro\n"
+"q - esci; non applicare né quest'hunk né quelli rimanenti\n"
+"a - applica quest'hunk e tutti quelli successivi nel file\n"
+"d - non applicare né quest'hunk né quelli successivi nel file"
+
+#: git-add--interactive.perl:1296
+msgid ""
+"y - apply this hunk to worktree\n"
+"n - do not apply this hunk to worktree\n"
+"q - quit; do not apply this hunk or any of the remaining ones\n"
+"a - apply this hunk and all later hunks in the file\n"
+"d - do not apply this hunk or any of the later hunks in the file"
+msgstr ""
+"y - applica quest'hunk all'albero di lavoro\n"
+"n - non applicare quest'hunk all'albero di lavoro\n"
+"q - esci; non applicare né quest'hunk né quelli rimanenti\n"
+"a - applica quest'hunk e tutti quelli successivi nel file\n"
+"d - non applicare né quest'hunk né quelli successivi nel file"
+
+#: git-add--interactive.perl:1311
+msgid ""
+"g - select a hunk to go to\n"
+"/ - search for a hunk matching the given regex\n"
+"j - leave this hunk undecided, see next undecided hunk\n"
+"J - leave this hunk undecided, see next hunk\n"
+"k - leave this hunk undecided, see previous undecided hunk\n"
+"K - leave this hunk undecided, see previous hunk\n"
+"s - split the current hunk into smaller hunks\n"
+"e - manually edit the current hunk\n"
+"? - print help\n"
+msgstr ""
+"g - seleziona un hunk a cui andare\n"
+"/ - cerca un hunk corrispondente all'espressione regolare data\n"
+"j - non decidere in merito a quest'hunk, vai al successivo hunk per cui non "
+"è stata presa una decisione\n"
+"J - non decidere in merito a quest'hunk, vai all'hunk successivo\n"
+"k - non decidere in merito a quest'hunk, vai al precedente hunk per cui non "
+"è stata presa una decisione\n"
+"K - non decidere in merito a quest'hunk, vai all'hunk precedente\n"
+"s - suddividi l'hunk corrente in hunk più piccoli\n"
+"e - modifica manualmente l'hunk corrente\n"
+"? - stampa una guida\n"
+
+#: git-add--interactive.perl:1342
+msgid "The selected hunks do not apply to the index!\n"
+msgstr "Gli hunk selezionati non si applicano senza problemi all'indice!\n"
+
+#: git-add--interactive.perl:1343
+msgid "Apply them to the worktree anyway? "
+msgstr "Vuoi comunque applicarli all'albero di lavoro? "
+
+#: git-add--interactive.perl:1346
+msgid "Nothing was applied.\n"
+msgstr "Non è stato applicato nulla.\n"
+
+#: git-add--interactive.perl:1357
+#, perl-format
+msgid "ignoring unmerged: %s\n"
+msgstr "ignoro ciò che non è stato sottoposto a merge: %s\n"
+
+#: git-add--interactive.perl:1428
+#, perl-format
+msgid "Stage mode change [y,n,q,a,d%s,?]? "
+msgstr "Modifica modo stage [y,n,q,a,d%s,?]? "
+
+#: git-add--interactive.perl:1429
+#, perl-format
+msgid "Stage deletion [y,n,q,a,d%s,?]? "
+msgstr "Eliminazione stage [y,n,q,a,d%s,?]? "
+
+#: git-add--interactive.perl:1430
+#, perl-format
+msgid "Stage this hunk [y,n,q,a,d%s,?]? "
+msgstr "Eseguire lo stage di quest'hunk [y,n,q,a,d%s,?]? "
+
+#: git-add--interactive.perl:1433
+#, perl-format
+msgid "Stash mode change [y,n,q,a,d%s,?]? "
+msgstr "Modifica modo stash [y,n,q,a,d%s,?]? "
+
+#: git-add--interactive.perl:1434
+#, perl-format
+msgid "Stash deletion [y,n,q,a,d%s,?]? "
+msgstr "Eliminazione stash [y,n,q,a,d%s,?]? "
+
+#: git-add--interactive.perl:1435
+#, perl-format
+msgid "Stash this hunk [y,n,q,a,d%s,?]? "
+msgstr "Eseguire lo stash di quest'hunk [y,n,q,a,d%s,?]? "
+
+#: git-add--interactive.perl:1438
+#, perl-format
+msgid "Unstage mode change [y,n,q,a,d%s,?]? "
+msgstr "Rimozione modifica modo dall'area di staging [y,n,q,a,d%s,?]? "
+
+#: git-add--interactive.perl:1439
+#, perl-format
+msgid "Unstage deletion [y,n,q,a,d%s,?]? "
+msgstr "Rimozione eliminazione dall'area di staging [y,n,q,a,d%s,?]? "
+
+#: git-add--interactive.perl:1440
+#, perl-format
+msgid "Unstage this hunk [y,n,q,a,d%s,?]? "
+msgstr "Rimuovere quest'hunk dall'area di staging [y,n,q,a,d%s,?]? "
+
+#: git-add--interactive.perl:1443
+#, perl-format
+msgid "Apply mode change to index [y,n,q,a,d%s,?]? "
+msgstr "Applicare la modifica modo all'indice [y,n,q,a,d%s,?]? "
+
+#: git-add--interactive.perl:1444
+#, perl-format
+msgid "Apply deletion to index [y,n,q,a,d%s,?]? "
+msgstr "Applicare l'eliminazione all'indice [y,n,q,a,d%s,?]? "
+
+#: git-add--interactive.perl:1445
+#, perl-format
+msgid "Apply this hunk to index [y,n,q,a,d%s,?]? "
+msgstr "Applicare quest'hunk all'indice [y,n,q,a,d%s,?]? "
+
+#: git-add--interactive.perl:1448 git-add--interactive.perl:1463
+#, perl-format
+msgid "Discard mode change from worktree [y,n,q,a,d%s,?]? "
+msgstr "Scartare le modifiche modo dall'albero di lavoro [y,n,q,a,d%s,?]? "
+
+#: git-add--interactive.perl:1449 git-add--interactive.perl:1464
+#, perl-format
+msgid "Discard deletion from worktree [y,n,q,a,d%s,?]? "
+msgstr "Scartare l'eliminazione dall'albero di lavoro [y,n,q,a,d%s,?]? "
+
+#: git-add--interactive.perl:1450 git-add--interactive.perl:1465
+#, perl-format
+msgid "Discard this hunk from worktree [y,n,q,a,d%s,?]? "
+msgstr "Scartare quest'hunk dall'albero di lavoro [y,n,q,a,d%s,?]? "
+
+#: git-add--interactive.perl:1453
+#, perl-format
+msgid "Discard mode change from index and worktree [y,n,q,a,d%s,?]? "
+msgstr ""
+"Scartare la modifica modo dall'indice e dall'albero di lavoro [y,n,q,a,d"
+"%s,?]? "
+
+#: git-add--interactive.perl:1454
+#, perl-format
+msgid "Discard deletion from index and worktree [y,n,q,a,d%s,?]? "
+msgstr ""
+"Scartare l'eliminazione dall'indice e dall'albero di lavoro [y,n,q,a,d%s,?]? "
+
+#: git-add--interactive.perl:1455
+#, perl-format
+msgid "Discard this hunk from index and worktree [y,n,q,a,d%s,?]? "
+msgstr ""
+"Scartare quest'hunk dall'indice e dall'albero di lavoro [y,n,q,a,d%s,?]? "
+
+#: git-add--interactive.perl:1458
+#, perl-format
+msgid "Apply mode change to index and worktree [y,n,q,a,d%s,?]? "
+msgstr ""
+"Applicare la modifica modo all'indice e all'albero di lavoro [y,n,q,a,d"
+"%s,?]? "
+
+#: git-add--interactive.perl:1459
+#, perl-format
+msgid "Apply deletion to index and worktree [y,n,q,a,d%s,?]? "
+msgstr ""
+"Applicare l'eliminazione all'indice e all'albero di lavoro [y,n,q,a,d%s,?]? "
+
+#: git-add--interactive.perl:1460
+#, perl-format
+msgid "Apply this hunk to index and worktree [y,n,q,a,d%s,?]? "
+msgstr ""
+"Applicare quest'hunk all'indice e all'albero di lavoro [y,n,q,a,d%s,?]? "
+
+#: git-add--interactive.perl:1468
+#, perl-format
+msgid "Apply mode change to worktree [y,n,q,a,d%s,?]? "
+msgstr "Applicare la modifica modo all'albero di lavoro [y,n,q,a,d%s,?]? "
+
+#: git-add--interactive.perl:1469
+#, perl-format
+msgid "Apply deletion to worktree [y,n,q,a,d%s,?]? "
+msgstr "Applicare l'eliminazione all'albero di lavoro [y,n,q,a,d%s,?]? "
+
+#: git-add--interactive.perl:1470
+#, perl-format
+msgid "Apply this hunk to worktree [y,n,q,a,d%s,?]? "
+msgstr "Applicare quest'hunk all'albero di lavoro [y,n,q,a,d%s,?]? "
+
+#: git-add--interactive.perl:1570
+msgid "No other hunks to goto\n"
+msgstr "Nessun altro hunk a cui andare\n"
+
+#: git-add--interactive.perl:1588
+#, perl-format
+msgid "Invalid number: '%s'\n"
+msgstr "Numero non valido: '%s'\n"
+
+#: git-add--interactive.perl:1593
+#, perl-format
+msgid "Sorry, only %d hunk available.\n"
+msgid_plural "Sorry, only %d hunks available.\n"
+msgstr[0] "Mi dispiace, è disponibile solo %d hunk.\n"
+msgstr[1] "Mi dispiace, sono disponibili solo %d hunk.\n"
+
+#: git-add--interactive.perl:1619
+msgid "No other hunks to search\n"
+msgstr "Nessun altro hunk in cui ricercare\n"
+
+#: git-add--interactive.perl:1636
+#, perl-format
+msgid "Malformed search regexp %s: %s\n"
+msgstr "Espressione regolare di ricerca %s malformata: %s\n"
+
+#: git-add--interactive.perl:1646
+msgid "No hunk matches the given pattern\n"
+msgstr "Nessun hunk corrisponde al pattern fornito\n"
+
+#: git-add--interactive.perl:1658 git-add--interactive.perl:1680
+msgid "No previous hunk\n"
+msgstr "Nessun hunk precedente\n"
+
+#: git-add--interactive.perl:1667 git-add--interactive.perl:1686
+msgid "No next hunk\n"
+msgstr "Nessun hunk successivo\n"
+
+#: git-add--interactive.perl:1692
+msgid "Sorry, cannot split this hunk\n"
+msgstr "Mi dispiace, non posso suddividere quest'hunk\n"
+
+#: git-add--interactive.perl:1698
+#, perl-format
+msgid "Split into %d hunk.\n"
+msgid_plural "Split into %d hunks.\n"
+msgstr[0] "Suddiviso in %d hunk.\n"
+msgstr[1] "Suddiviso in %d hunk.\n"
+
+#: git-add--interactive.perl:1708
+msgid "Sorry, cannot edit this hunk\n"
+msgstr "Mi dispiace, non posso modificare quest'hunk\n"
+
+#. TRANSLATORS: please do not translate the command names
+#. 'status', 'update', 'revert', etc.
+#: git-add--interactive.perl:1773
+msgid ""
+"status        - show paths with changes\n"
+"update        - add working tree state to the staged set of changes\n"
+"revert        - revert staged set of changes back to the HEAD version\n"
+"patch         - pick hunks and update selectively\n"
+"diff          - view diff between HEAD and index\n"
+"add untracked - add contents of untracked files to the staged set of "
+"changes\n"
+msgstr ""
+"status        - visualizza i percorsi con modifiche\n"
+"update        - aggiunge lo stato dell'albero di lavoro all'insieme delle\n"
+"                modifiche nell'area di staging\n"
+"revert        - ripristina l'insieme delle modifiche nell'area di staging\n"
+"                alla versione HEAD\n"
+"patch         - seleziona e aggiorna gli hunk in modo selettivo\n"
+"diff          - visualizza le differenze fra HEAD e l'indice\n"
+"add untracked - aggiunge i contenuti dei file non tracciati all'insieme di\n"
+"                modifiche nell'area di staging\n"
+
+#: git-add--interactive.perl:1790 git-add--interactive.perl:1795
+#: git-add--interactive.perl:1798 git-add--interactive.perl:1805
+#: git-add--interactive.perl:1808 git-add--interactive.perl:1815
+#: git-add--interactive.perl:1819 git-add--interactive.perl:1825
+msgid "missing --"
+msgstr "-- mancante"
+
+#: git-add--interactive.perl:1821
+#, perl-format
+msgid "unknown --patch mode: %s"
+msgstr "modalità --patch sconosciuta: %s"
+
+#: git-add--interactive.perl:1827 git-add--interactive.perl:1833
+#, perl-format
+msgid "invalid argument %s, expecting --"
+msgstr "argomento %s non valido, atteso --"
+
+#: git-send-email.perl:138
+msgid "local zone differs from GMT by a non-minute interval\n"
+msgstr ""
+"il fuso orario locale differisce da GMT di un intervallo non multiplo di un "
+"minuto\n"
+
+#: git-send-email.perl:145 git-send-email.perl:151
+msgid "local time offset greater than or equal to 24 hours\n"
+msgstr "l'offset del fuso orario locale è maggiore o uguale a 24 ore\n"
+
+#: git-send-email.perl:223 git-send-email.perl:229
+msgid "the editor exited uncleanly, aborting everything"
+msgstr "l'editor non è terminato regolarmente, interrompo tutte le operazioni"
+
+#: git-send-email.perl:310
+#, perl-format
+msgid ""
+"'%s' contains an intermediate version of the email you were composing.\n"
+msgstr ""
+"'%s' contiene una versione intermedia dell'e-mail che stavi componendo.\n"
+
+#: git-send-email.perl:315
+#, perl-format
+msgid "'%s.final' contains the composed email.\n"
+msgstr "'%s.final' contiene l'e-mail composta.\n"
+
+#: git-send-email.perl:408
+msgid "--dump-aliases incompatible with other options\n"
+msgstr "--dump-aliases non è compatibile con altre opzioni\n"
+
+#: git-send-email.perl:481 git-send-email.perl:683
+msgid "Cannot run git format-patch from outside a repository\n"
+msgstr "Impossibile eseguire git format-patch al di fuori di un repository\n"
+
+#: git-send-email.perl:484
+msgid ""
+"`batch-size` and `relogin` must be specified together (via command-line or "
+"configuration option)\n"
+msgstr ""
+"`batch-size` e `relogin` devono essere specificati insieme (sulla riga di "
+"comando o tramite un'opzione di configurazione)\n"
+
+#: git-send-email.perl:497
+#, perl-format
+msgid "Unknown --suppress-cc field: '%s'\n"
+msgstr "Campo --suppress-cc sconosciuto: '%s'\n"
+
+#: git-send-email.perl:528
+#, perl-format
+msgid "Unknown --confirm setting: '%s'\n"
+msgstr "Impostazione --confirm sconosciuta: '%s'\n"
+
+#: git-send-email.perl:556
+#, perl-format
+msgid "warning: sendmail alias with quotes is not supported: %s\n"
+msgstr "attenzione: non sono supportati alias sendmail con virgolette: %s\n"
+
+#: git-send-email.perl:558
+#, perl-format
+msgid "warning: `:include:` not supported: %s\n"
+msgstr "attenzione: `:include:` non supportato: %s\n"
+
+#: git-send-email.perl:560
+#, perl-format
+msgid "warning: `/file` or `|pipe` redirection not supported: %s\n"
+msgstr "attenzione: redirezioni `/file` o `|pipe` non supportate: %s\n"
+
+#: git-send-email.perl:565
+#, perl-format
+msgid "warning: sendmail line is not recognized: %s\n"
+msgstr "attenzione: riga sendmail non riconosciuta: %s\n"
+
+#: git-send-email.perl:649
+#, perl-format
+msgid ""
+"File '%s' exists but it could also be the range of commits\n"
+"to produce patches for.  Please disambiguate by...\n"
+"\n"
+"    * Saying \"./%s\" if you mean a file; or\n"
+"    * Giving --format-patch option if you mean a range.\n"
+msgstr ""
+"Il file '%s' esiste ma tale stringa potrebbe corrispondere\n"
+"anche all'intervallo di commit per cui generare delle patch.\n"
+"Specifica qual è il caso corretto...\n"
+"\n"
+"    * ...usando \"./%s\" se intendi riferirti al file, o...\n"
+"    * ...fornendo l'opzione --format-patch se ti riferisci\n"
+"      a un intervallo.\n"
+
+#: git-send-email.perl:670
+#, perl-format
+msgid "Failed to opendir %s: %s"
+msgstr "opendir di %s non riuscita: %s"
+
+#: git-send-email.perl:694
+#, perl-format
+msgid ""
+"fatal: %s: %s\n"
+"warning: no patches were sent\n"
+msgstr ""
+"errore fatale: %s: %s\n"
+"attenzione: non è stata inviata alcuna patch\n"
+
+#: git-send-email.perl:705
+msgid ""
+"\n"
+"No patch files specified!\n"
+"\n"
+msgstr ""
+"\n"
+"Nessun file patch specificato!\n"
+"\n"
+
+#: git-send-email.perl:718
+#, perl-format
+msgid "No subject line in %s?"
+msgstr "Riga oggetto assente in %s?"
+
+#: git-send-email.perl:728
+#, perl-format
+msgid "Failed to open for writing %s: %s"
+msgstr "Apertura di %s in scrittura non riuscita: %s"
+
+#: git-send-email.perl:739
+msgid ""
+"Lines beginning in \"GIT:\" will be removed.\n"
+"Consider including an overall diffstat or table of contents\n"
+"for the patch you are writing.\n"
+"\n"
+"Clear the body content if you don't wish to send a summary.\n"
+msgstr ""
+"Le righe che iniziano con \"GIT:\" saranno rimosse.\n"
+"Valuta di includere un diffstat globale o un sommario per\n"
+"la patch che stai scrivendo.\n"
+"\n"
+"Rimuovi il corpo se non vuoi inviare un sommario.\n"
+
+#: git-send-email.perl:763
+#, perl-format
+msgid "Failed to open %s: %s"
+msgstr "Apertura di %s non riuscita: %s"
+
+#: git-send-email.perl:780
+#, perl-format
+msgid "Failed to open %s.final: %s"
+msgstr "Apertura di %s.final non riuscita: %s"
 
-#: git-am.sh:481
-#, sh-format
-msgid "previous rebase directory $dotest still exists but mbox given."
-msgstr ""
+#: git-send-email.perl:823
+msgid "Summary email is empty, skipping it\n"
+msgstr "E-mail riassuntiva vuota, la ometto\n"
 
-#: git-am.sh:486
-msgid "Please make up your mind. --skip or --abort?"
-msgstr "Per favore, deciditi. --skip o --abort?"
+#. TRANSLATORS: please keep [y/N] as is.
+#: git-send-email.perl:858
+#, perl-format
+msgid "Are you sure you want to use <%s> [y/N]? "
+msgstr "Usare <%s> [y/N]? "
 
-#: git-am.sh:513
-msgid "Resolve operation not in progress, we are not resuming."
+#: git-send-email.perl:913
+msgid ""
+"The following files are 8bit, but do not declare a Content-Transfer-"
+"Encoding.\n"
 msgstr ""
+"I seguenti file sono codificati a 8 bit ma non dichiarano un Content-"
+"Transfer-Encoding.\n"
 
-#: git-am.sh:579
-#, sh-format
-msgid "Dirty index: cannot apply patches (dirty: $files)"
-msgstr ""
+#: git-send-email.perl:918
+msgid "Which 8bit encoding should I declare [UTF-8]? "
+msgstr "Che codifica a 8 bit devo dichiarare [UTF-8]? "
 
-#: git-am.sh:671
-#, sh-format
+#: git-send-email.perl:926
+#, perl-format
 msgid ""
-"Patch is empty.  Was it split wrong?\n"
-"If you would prefer to skip this patch, instead run \"$cmdline --skip\".\n"
-"To restore the original branch and stop patching run \"$cmdline --abort\"."
+"Refusing to send because the patch\n"
+"\t%s\n"
+"has the template subject '*** SUBJECT HERE ***'. Pass --force if you really "
+"want to send.\n"
 msgstr ""
+"Mi rifiuto di eseguire l'invio perché la patch\n"
+"\t%s\n"
+"ha come oggetto nel modello '*** SUBJECT HERE ***'. Fornisci l'opzione --"
+"force se vuoi veramente procedere con l'invio.\n"
 
-#: git-am.sh:708
-msgid "Patch does not have a valid e-mail address."
-msgstr "La patch non contiene un indirizzo email valido."
-
-#: git-am.sh:755
-msgid "cannot be interactive without stdin connected to a terminal."
+#: git-send-email.perl:945
+msgid "To whom should the emails be sent (if anyone)?"
 msgstr ""
+"A chi dovranno essere inviate le e-mail (se devono essere inviate a "
+"qualcuno)?"
 
-#: git-am.sh:759
-msgid "Commit Body is:"
+#: git-send-email.perl:963
+#, perl-format
+msgid "fatal: alias '%s' expands to itself\n"
+msgstr "errore fatale: l'alias '%s' si espande in se stesso\n"
+
+#: git-send-email.perl:975
+msgid "Message-ID to be used as In-Reply-To for the first email (if any)? "
 msgstr ""
+"Message-ID da usare nell'intestazione In-Reply-To per la prima e-mail (se "
+"dev'essere usato)? "
 
-#. TRANSLATORS: Make sure to include [y], [n], [e], [v] and [a]
-#. in your translation. The program will only accept English
-#. input at this point.
-#: git-am.sh:766
-msgid "Apply? [y]es/[n]o/[e]dit/[v]iew patch/[a]ccept all "
-msgstr "Applicare? sì[y]/no[n]/modifica[e]/visualizza patch[v]/accetta tutto[a] "
+#: git-send-email.perl:1033 git-send-email.perl:1041
+#, perl-format
+msgid "error: unable to extract a valid address from: %s\n"
+msgstr "errore: impossibile estrarre un indirizzo valido da %s\n"
 
-#: git-am.sh:802
-#, sh-format
-msgid "Applying: $FIRSTLINE"
+#. TRANSLATORS: Make sure to include [q] [d] [e] in your
+#. translation. The program will only accept English input
+#. at this point.
+#: git-send-email.perl:1045
+msgid "What to do with this address? ([q]uit|[d]rop|[e]dit): "
 msgstr ""
+"Cosa devo fare con quest'indirizzo? (Esci [q]|scarta [d]|modifica [e]): "
 
-#: git-am.sh:823
-msgid ""
-"No changes - did you forget to use 'git add'?\n"
-"If there is nothing left to stage, chances are that something else\n"
-"already introduced the same changes; you might want to skip this patch."
+#: git-send-email.perl:1362
+#, perl-format
+msgid "CA path \"%s\" does not exist"
+msgstr "Il percorso CA \"%s\" non esiste"
+
+#: git-send-email.perl:1445
+msgid ""
+"    The Cc list above has been expanded by additional\n"
+"    addresses found in the patch commit message. By default\n"
+"    send-email prompts before sending whenever this occurs.\n"
+"    This behavior is controlled by the sendemail.confirm\n"
+"    configuration setting.\n"
+"\n"
+"    For additional information, run 'git send-email --help'.\n"
+"    To retain the current behavior, but squelch this message,\n"
+"    run 'git config --global sendemail.confirm auto'.\n"
+"\n"
 msgstr ""
+"    L'elenco Cc di cui sopra è stato espanso aggiungendo\n"
+"    indirizzi aggiuntivi trovati nel messaggio di commit della\n"
+"    patch. Per impostazione predefinita send-email richiede\n"
+"    come procedere prima dell'invio ogniqualvolta si verifichi\n"
+"    tale evenienza. Questo comportamento è controllato\n"
+"    dall'impostazione di configurazione sendemail.confirm.\n"
+"\n"
+"    Per ulteriori informazioni, esegui 'git send-email --help'.\n"
+"    Per mantenere il comportamento corrente, ma non\n"
+"    visualizzare più questo messaggio, esegui 'git config\n"
+"    --global sendemail.confirm auto'.\n"
+"\n"
 
-#: git-am.sh:831
-msgid ""
-"You still have unmerged paths in your index\n"
-"did you forget to use 'git add'?"
+#. TRANSLATORS: Make sure to include [y] [n] [e] [q] [a] in your
+#. translation. The program will only accept English input
+#. at this point.
+#: git-send-email.perl:1460
+msgid "Send this email? ([y]es|[n]o|[e]dit|[q]uit|[a]ll): "
 msgstr ""
+"Inviare quest'e-mail? (Sì [y]|[n]o|modifica [e]|esci [q]|invia tutte [a]): "
 
-#: git-am.sh:847
-msgid "No changes -- Patch already applied."
-msgstr "Nessuna modifica -- patch già applicata."
+#: git-send-email.perl:1463
+msgid "Send this email reply required"
+msgstr "È richiesta una risposta alla richiesta di invio e-mail"
+
+#: git-send-email.perl:1491
+msgid "The required SMTP server is not properly defined."
+msgstr "Il server SMTP richiesto non è definito in modo adeguato."
+
+#: git-send-email.perl:1538
+#, perl-format
+msgid "Server does not support STARTTLS! %s"
+msgstr "Il server non supporta STARTTLS! %s"
+
+#: git-send-email.perl:1543 git-send-email.perl:1547
+#, perl-format
+msgid "STARTTLS failed! %s"
+msgstr "STARTTLS non riuscito! %s"
+
+#: git-send-email.perl:1556
+msgid "Unable to initialize SMTP properly. Check config and use --smtp-debug."
+msgstr ""
+"Impossibile inizializzare SMTP in modo adeguato. Controlla la configurazione "
+"e usa --smtp-debug."
+
+#: git-send-email.perl:1574
+#, perl-format
+msgid "Failed to send %s\n"
+msgstr "Invio di %s non riuscito\n"
+
+#: git-send-email.perl:1577
+#, perl-format
+msgid "Dry-Sent %s\n"
+msgstr "Test invio %s riuscito\n"
+
+#: git-send-email.perl:1577
+#, perl-format
+msgid "Sent %s\n"
+msgstr "%s inviato\n"
+
+#: git-send-email.perl:1579
+msgid "Dry-OK. Log says:\n"
+msgstr "Esecuzione di prova riuscita. Il registro è il seguente:\n"
+
+#: git-send-email.perl:1579
+msgid "OK. Log says:\n"
+msgstr "Operazione riuscita. Il registro è il seguente:\n"
+
+#: git-send-email.perl:1591
+msgid "Result: "
+msgstr "Risultato: "
+
+#: git-send-email.perl:1594
+msgid "Result: OK\n"
+msgstr "Risultato: OK\n"
+
+#: git-send-email.perl:1612
+#, perl-format
+msgid "can't open file %s"
+msgstr "impossibile aprire il file %s"
+
+#: git-send-email.perl:1659 git-send-email.perl:1679
+#, perl-format
+msgid "(mbox) Adding cc: %s from line '%s'\n"
+msgstr "(mbox) Aggiungo cc: %s dalla riga '%s'\n"
+
+#: git-send-email.perl:1665
+#, perl-format
+msgid "(mbox) Adding to: %s from line '%s'\n"
+msgstr "(mbox) Aggiungo to: %s dalla riga '%s'\n"
+
+#: git-send-email.perl:1718
+#, perl-format
+msgid "(non-mbox) Adding cc: %s from line '%s'\n"
+msgstr "(non mbox) Aggiungo cc: %s dalla riga '%s'\n"
+
+#: git-send-email.perl:1753
+#, perl-format
+msgid "(body) Adding cc: %s from line '%s'\n"
+msgstr "(corpo) Aggiungo cc: %s dalla riga '%s'\n"
+
+#: git-send-email.perl:1864
+#, perl-format
+msgid "(%s) Could not execute '%s'"
+msgstr "(%s) Impossibile eseguire '%s'"
+
+#: git-send-email.perl:1871
+#, perl-format
+msgid "(%s) Adding %s: %s from: '%s'\n"
+msgstr "(%s) Aggiungo %s: %s da: '%s'\n"
+
+#: git-send-email.perl:1875
+#, perl-format
+msgid "(%s) failed to close pipe to '%s'"
+msgstr "(%s) chiusura della pipe a '%s' non riuscita"
+
+#: git-send-email.perl:1905
+msgid "cannot send message as 7bit"
+msgstr "impossibile inviare il messaggio con codifica a 7 bit"
+
+#: git-send-email.perl:1913
+msgid "invalid transfer encoding"
+msgstr "codifica di trasferimento non valida"
+
+#: git-send-email.perl:1954 git-send-email.perl:2006 git-send-email.perl:2016
+#, perl-format
+msgid "unable to open %s: %s\n"
+msgstr "impossibile aprire %s: %s\n"
 
-#: git-am.sh:857
-#, sh-format
-msgid "Patch failed at $msgnum $FIRSTLINE"
-msgstr "Patch non riuscita a $msgnum $FIRSTLINE"
+#: git-send-email.perl:1957
+#, perl-format
+msgid "%s: patch contains a line longer than 998 characters"
+msgstr "%s: la patch contiene una riga più lunga di 998 caratteri"
 
-#: git-am.sh:873
-msgid "applying to an empty history"
-msgstr ""
+#: git-send-email.perl:1974
+#, perl-format
+msgid "Skipping %s with backup suffix '%s'.\n"
+msgstr "Salto %s con il suffisso di backup '%s'.\n"
 
-#: git-bisect.sh:48
-msgid "You need to start by \"git bisect start\""
-msgstr "Devi iniziare con \"git bisect start\""
+#. TRANSLATORS: please keep "[y|N]" as is.
+#: git-send-email.perl:1978
+#, perl-format
+msgid "Do you really want to send %s? [y|N]: "
+msgstr "Inviare %s? [y|N]: "
 
-#. TRANSLATORS: Make sure to include [Y] and [n] in your
-#. translation. The program will only accept English input
-#. at this point.
-#: git-bisect.sh:54
-msgid "Do you want me to do it for you [Y/n]? "
-msgstr "Vuoi che me ne occupi io [Y/n]? "
+#, c-format
+#~ msgid "unable to get tree for %s"
+#~ msgstr "impossibile recuperare l'albero per %s"
 
-#: git-bisect.sh:95
-#, sh-format
-msgid "unrecognised option: '$arg'"
-msgstr "opzione non riconosciuta: '$arg'"
+#~ msgid "Use an experimental heuristic to improve diffs"
+#~ msgstr "Usa un'euristica sperimentale per migliorare i diff"
 
-#: git-bisect.sh:99
-#, sh-format
-msgid "'$arg' does not appear to be a valid revision"
-msgstr "'$arg' non sembra essere una revisione valida"
+#~ msgid "git commit-graph [--object-dir <objdir>]"
+#~ msgstr "git commit-graph [--object-dir <directory oggetti>]"
 
-#: git-bisect.sh:117
-msgid "Bad HEAD - I need a HEAD"
-msgstr ""
+#~ msgid "git commit-graph read [--object-dir <objdir>]"
+#~ msgstr "git commit-graph read [--object-dir <directory oggetti>]"
 
-#: git-bisect.sh:130
-#, sh-format
-msgid ""
-"Checking out '$start_head' failed. Try 'git bisect reset <validbranch>'."
-msgstr ""
-"Checkout di '$start_head' non riuscito. Prova 'git bisect reset "
-"<branch-valido>'."
+#, c-format
+#~ msgid "unknown core.untrackedCache value '%s'; using 'keep' default value"
+#~ msgstr ""
+#~ "valore core.untrackedCache '%s' non valido; utilizzerò il valore "
+#~ "predefinito 'keep'"
 
-#: git-bisect.sh:140
-msgid "won't bisect on seeked tree"
-msgstr ""
+#~ msgid "cannot change partial clone promisor remote"
+#~ msgstr "impossibile modificare il remoto promettente del clone parziale"
 
-#: git-bisect.sh:144
-msgid "Bad HEAD - strange symbolic ref"
-msgstr "HEAD errato - strano ref simbolico"
+#~ msgid "error building trees"
+#~ msgstr "errore durante la costruzione degli alberi"
 
-#: git-bisect.sh:189
-#, sh-format
-msgid "Bad bisect_write argument: $state"
-msgstr "Argomento bisect_write errato: $state"
+#, c-format
+#~ msgid "invalid date format '%s' in '%s'"
+#~ msgstr "formato data '%s' non valido in '%s'"
 
-#: git-bisect.sh:218
-#, sh-format
-msgid "Bad rev input: $arg"
-msgstr ""
+#~ msgid "writing root commit"
+#~ msgstr "scrittura commit radice in corso"
 
-#: git-bisect.sh:232
-msgid "Please call 'bisect_state' with at least one argument."
-msgstr "Per favore, chiama 'bisect_state' con almeno un argomento."
+#, c-format
+#~ msgid "staged changes in the following files may be lost: %s"
+#~ msgstr ""
+#~ "le modifiche in stage nei seguenti file potrebbero andare perdute: %s"
 
-#: git-bisect.sh:244
-#, sh-format
-msgid "Bad rev input: $rev"
-msgstr ""
+#~ msgid ""
+#~ "--filter can only be used with the remote configured in extensions."
+#~ "partialClone"
+#~ msgstr ""
+#~ "--filter può essere usato solo con il remoto configurato nelle estensioni."
+#~ "partialClone"
 
-#: git-bisect.sh:250
-msgid "'git bisect bad' can take only one argument."
-msgstr "'git bisect bad' può prendere un solo argomento."
-
-#. have bad but not good.  we could bisect although
-#. this is less optimum.
-#: git-bisect.sh:273
-msgid "Warning: bisecting only with a bad commit."
-msgstr ""
+#~ msgid "verify commit-msg hook"
+#~ msgstr "verifica hook commit-msg"
 
-#. TRANSLATORS: Make sure to include [Y] and [n] in your
-#. translation. The program will only accept English input
-#. at this point.
-#: git-bisect.sh:279
-msgid "Are you sure [Y/n]? "
-msgstr "Sei sicuro? [Y/n] "
+#~ msgid "cannot combine '--rebase-merges' with '--strategy-option'"
+#~ msgstr "impossibile combinare '--rebase-merges' con '--strategy-option'"
 
-#: git-bisect.sh:289
-msgid ""
-"You need to give me at least one good and one bad revisions.\n"
-"(You can use \"git bisect bad\" and \"git bisect good\" for that.)"
-msgstr ""
-"Devi specificare almeno una revisione corretta ed una errata.\n"
-"(Puoi usare \"git bisect bad\" e \"git bisect good\" per questo scopo.)"
+#, c-format
+#~ msgid "invalid sparse value '%s'"
+#~ msgstr "valore sparse non valido: '%s'"
 
-#: git-bisect.sh:292
-msgid ""
-"You need to start by \"git bisect start\".\n"
-"You then need to give me at least one good and one bad revisions.\n"
-"(You can use \"git bisect bad\" and \"git bisect good\" for that.)"
-msgstr ""
+#~ msgid ""
+#~ "Fetch normally indicates which branches had a forced update, but that "
+#~ "check has been disabled."
+#~ msgstr ""
+#~ "Il fetch normalmente indica quali branch siano stati sottoposti ad "
+#~ "aggiornamento forzato, ma tale controllo è stato disabilitato."
 
-#: git-bisect.sh:347 git-bisect.sh:474
-msgid "We are not bisecting."
-msgstr "Non stiamo eseguendo un bisect."
+#~ msgid ""
+#~ "or run 'git config fetch.showForcedUpdates false' to avoid this check.\n"
+#~ msgstr ""
+#~ "o eseguire 'git config fetch.showForcedUpdates false' per omettere "
+#~ "questo\n"
+#~ "controllo.\n"
 
-#: git-bisect.sh:354
-#, sh-format
-msgid "'$invalid' is not a valid commit"
-msgstr "'$invalid' non è un commit valido"
+#~ msgid ""
+#~ "log.mailmap is not set; its implicit value will change in an\n"
+#~ "upcoming release. To squelch this message and preserve current\n"
+#~ "behaviour, set the log.mailmap configuration value to false.\n"
+#~ "\n"
+#~ "To squelch this message and adopt the new behaviour now, set the\n"
+#~ "log.mailmap configuration value to true.\n"
+#~ "\n"
+#~ "See 'git help config' and search for 'log.mailmap' for further "
+#~ "information."
+#~ msgstr ""
+#~ "log.mailmap non è impostato; il suo valore implicito sarà modificato\n"
+#~ "in una prossima versione. Per eliminare questo messaggio e mantenere\n"
+#~ "il comportamento attuale, imposta il valore di configurazione\n"
+#~ "log.mailmap a false.\n"
+#~ "\n"
+#~ "Per eliminare questo messaggio e adottare il nuovo comportamento ora,\n"
+#~ "imposta il valore di configurazione log.mailmap a true.\n"
+#~ "\n"
+#~ "Vedi 'git help config' e cerca 'log.mailmap' per ulteriori informazioni."
 
-#: git-bisect.sh:363
-#, sh-format
-msgid ""
-"Could not check out original HEAD '$branch'.\n"
-"Try 'git bisect reset <commit>'."
-msgstr ""
+#~ msgid "Server supports multi_ack_detailed"
+#~ msgstr "Il server supporta multi_ack_detailes"
 
-#: git-bisect.sh:390
-msgid "No logfile given"
-msgstr "Nessun file di log specificato"
+#~ msgid "Server supports no-done"
+#~ msgstr "Il server supporta no-done"
 
-#: git-bisect.sh:391
-#, sh-format
-msgid "cannot read $file for replaying"
-msgstr ""
+#~ msgid "Server supports multi_ack"
+#~ msgstr "Il server supporta multi_ack"
 
-#: git-bisect.sh:408
-msgid "?? what are you talking about?"
-msgstr "?? di cosa si sta parlando?"
+#~ msgid "Server supports side-band-64k"
+#~ msgstr "Il server supporta side-band-64k"
 
-#: git-bisect.sh:420
-#, sh-format
-msgid "running $command"
-msgstr "sto eseguendo $command"
+#~ msgid "Server supports side-band"
+#~ msgstr "Il server supporta side-band"
 
-#: git-bisect.sh:427
-#, sh-format
-msgid ""
-"bisect run failed:\n"
-"exit code $res from '$command' is < 0 or >= 128"
-msgstr ""
-"bisect run non riuscito:\n"
-"il codice di uscita $res da '$command' è < 0 oppure >= 128"
+#~ msgid "Server supports allow-tip-sha1-in-want"
+#~ msgstr "Il server supporta allow-tip-sha1-in-want"
 
-#: git-bisect.sh:453
-msgid "bisect run cannot continue any more"
-msgstr "bisect run non può più proseguire"
+#~ msgid "Server supports allow-reachable-sha1-in-want"
+#~ msgstr "Il server supporta allow-reachable-sha1-in-want"
 
-#: git-bisect.sh:459
-#, sh-format
-msgid ""
-"bisect run failed:\n"
-"'bisect_state $state' exited with error code $res"
-msgstr ""
-"bisect run non riuscito:\n"
-"bisect_state $state è uscito con il codice di errore $res"
+#~ msgid "Server supports ofs-delta"
+#~ msgstr "Il server supporta ofs-delta"
 
-#: git-bisect.sh:466
-msgid "bisect run success"
-msgstr "bisect run eseguito con successo"
+#~ msgid "(HEAD detached at %s)"
+#~ msgstr "(HEAD scollegato su %s)"
 
-#: git-pull.sh:21
-msgid ""
-"Pull is not possible because you have unmerged files.\n"
-"Please, fix them up in the work tree, and then use 'git add/rm <file>'\n"
-"as appropriate to mark resolution, or use 'git commit -a'."
-msgstr ""
+#~ msgid "(HEAD detached from %s)"
+#~ msgstr "(HEAD scollegato da %s)"
 
-#: git-pull.sh:25
-msgid "Pull is not possible because you have unmerged files."
-msgstr ""
-"Il pull non è possibile perché ci sono file di cui non è stato eseguito il "
-"merge."
+#~ msgid "Checking out files"
+#~ msgstr "Checkout dei file in corso"
 
-#: git-pull.sh:197
-msgid "updating an unborn branch with changes added to the index"
-msgstr ""
+#~ msgid "cannot be interactive without stdin connected to a terminal."
+#~ msgstr ""
+#~ "impossibile eseguire l'attività in modalità interattiva con lo standard "
+#~ "input non collegato a un terminale."
 
-#. The fetch involved updating the current branch.
-#. The working tree and the index file is still based on the
-#. $orig_head commit, but we are merging into $curr_head.
-#. First update the working tree to match $curr_head.
-#: git-pull.sh:228
-#, sh-format
-msgid ""
-"Warning: fetch updated the current branch head.\n"
-"Warning: fast-forwarding your working tree from\n"
-"Warning: commit $orig_head."
-msgstr ""
+#~ msgid "failed to stat %s\n"
+#~ msgstr "stat di %s non riuscito\n"
 
-#: git-pull.sh:253
-msgid "Cannot merge multiple branches into empty head"
-msgstr "Impossibile eseguire il merge di branch multipli in un head vuoto"
+#~ msgid ""
+#~ "If you wish to skip this commit, use:\n"
+#~ "\n"
+#~ "    git reset\n"
+#~ "\n"
+#~ "Then \"git cherry-pick --continue\" will resume cherry-picking\n"
+#~ "the remaining commits.\n"
+#~ msgstr ""
+#~ "Se vuoi ignorare questo commit, usa:\n"
+#~ "\n"
+#~ "    git reset\n"
+#~ "\n"
+#~ "Quindi il comando \"git cherry-pick --continue\" farà riprendere\n"
+#~ "il cherry picking per i commit rimanenti.\n"
 
-#: git-pull.sh:257
-msgid "Cannot rebase onto multiple branches"
-msgstr "Impossibile eseguire il rebase su branch multipli"
+#~ msgid "unrecognized verb: %s"
+#~ msgstr "verbo non riconosciuto: %s"
 
-#: git-stash.sh:51
-msgid "git stash clear with parameters is unimplemented"
-msgstr "git stash clear con parametri non è implementato"
+#~ msgid "hash version %X does not match version %X"
+#~ msgstr "la versione dell'hash %X non corrisponde alla versione %X"
 
-#: git-stash.sh:74
-msgid "You do not have the initial commit yet"
-msgstr "Non hai ancora un commit iniziale"
+#~ msgid "option '%s' requires a value"
+#~ msgstr "l'opzione '%s' richiede un valore"
 
-#: git-stash.sh:89
-msgid "Cannot save the current index state"
-msgstr "Impossibile salvare lo stato corrente di index"
+#~ msgid "could not transform the todo list"
+#~ msgstr "impossibile trasformare l'elenco todo"
 
-#: git-stash.sh:123 git-stash.sh:136
-msgid "Cannot save the current worktree state"
-msgstr ""
+#~ msgid "default"
+#~ msgstr "impostazione predefinita"
 
-#: git-stash.sh:140
-msgid "No changes selected"
-msgstr "Nessuna modifica selezionata"
+#~ msgid "Could not create directory '%s'"
+#~ msgstr "Non è stato possibile creare la directory '%s'"
 
-#: git-stash.sh:143
-msgid "Cannot remove temporary index (can't happen)"
-msgstr ""
+#, fuzzy
+#~ msgid "could not open %s"
+#~ msgstr "impossibile aprire '%s'"
 
-#: git-stash.sh:156
-msgid "Cannot record working tree state"
-msgstr ""
+#, fuzzy
+#~ msgid "Could not move back to $head_name"
+#~ msgstr "Non è stato possibile rimuovere il branch %s"
 
-#. TRANSLATORS: $option is an invalid option, like
-#. `--blah-blah'. The 7 spaces at the beginning of the
-#. second line correspond to "error: ". So you should line
-#. up the second line with however many characters the
-#. translation of "error: " takes in your language. E.g. in
-#. English this is:
-#.
-#. $ git stash save --blah-blah 2>&1 | head -n 2
-#. error: unknown option for 'stash save': --blah-blah
-#. To provide a message, use git stash save -- '--blah-blah'
-#: git-stash.sh:202
-#, sh-format
-msgid ""
-"error: unknown option for 'stash save': $option\n"
-"       To provide a message, use git stash save -- '$option'"
-msgstr ""
-"errore: opzione sconosciuta per 'stash save': $option\n"
-"        Per aggiungere un messaggio, usare git stash save -- '$option'"
+#, fuzzy
+#~ msgid "fatal: cannot combine '--signoff' with '--preserve-merges'"
+#~ msgstr "Impossibile combinare --no-ff con --ff-only."
 
-#: git-stash.sh:223
-msgid "No local changes to save"
-msgstr "Nessuna modifica locale da salvare"
+#, fuzzy
+#~ msgid "fatal: cannot combine '--preserve-merges' with '--rebase-merges'"
+#~ msgstr "Impossibile combinare --no-ff con --ff-only."
 
-#: git-stash.sh:227
-msgid "Cannot initialize stash"
-msgstr "Impossibile inizializzare stash"
+#, fuzzy
+#~ msgid "fatal: cannot combine '--rebase-merges' with '--strategy-option'"
+#~ msgstr "Impossibile combinare --no-ff con --ff-only."
 
-#: git-stash.sh:235
-msgid "Cannot save the current status"
-msgstr "Impossibile salvare lo stato attuale"
+#, fuzzy
+#~ msgid "fatal: cannot combine '--rebase-merges' with '--strategy'"
+#~ msgstr "Impossibile combinare --no-ff con --ff-only."
 
-#: git-stash.sh:253
-msgid "Cannot remove worktree changes"
-msgstr ""
+#, fuzzy
+#~ msgid "Does not point to a valid commit: $onto_name"
+#~ msgstr "'%s' non punta ad un commit"
 
-#: git-stash.sh:352
-msgid "No stash found."
-msgstr "Nessuno stash trovato."
+#, fuzzy
+#~ msgid "Changes to $onto:"
+#~ msgstr "Modifiche di cui verrà eseguito il commit:"
 
-#: git-stash.sh:359
-#, sh-format
-msgid "Too many revisions specified: $REV"
-msgstr "Troppe revisioni specificate: $REV"
+#~ msgid "ignoring unknown color-moved-ws mode '%s'"
+#~ msgstr "modalità color-moved-ws sconosciuta '%s' ignorata"
 
-#: git-stash.sh:365
-#, sh-format
-msgid "$reference is not valid reference"
-msgstr "$reference non è un riferimento valido"
+#~ msgid "only 'tree:0' is supported"
+#~ msgstr "è supportato solo 'tree:0'"
 
-#: git-stash.sh:393
-#, sh-format
-msgid "'$args' is not a stash-like commit"
-msgstr "'$args' non è un commit di tipo stash"
+#~ msgid "Renaming %s to %s and %s to %s instead"
+#~ msgstr "Ridenomino %s in %s e %s in %s"
 
-#: git-stash.sh:404
-#, sh-format
-msgid "'$args' is not a stash reference"
-msgstr "'$args' non è un referimento a uno stash"
+#~ msgid "Adding merged %s"
+#~ msgstr "Aggiunta elemento sottoposto a merge %s"
 
-#: git-stash.sh:412
-msgid "unable to refresh index"
-msgstr "impossibile aggiornare index"
+#~ msgid "Internal error"
+#~ msgstr "Errore interno"
 
-#: git-stash.sh:416
-msgid "Cannot apply a stash in the middle of a merge"
-msgstr "Impossibile applicare uno stash nel mezzo di un merge"
+#~ msgid "mainline was specified but commit %s is not a merge."
+#~ msgstr "è stato specificato mainline ma il commit %s non è un merge."
 
-#: git-stash.sh:424
-msgid "Conflicts in index. Try without --index."
-msgstr "Ci sono conflitti in index. Prova senza --index."
+#~ msgid "unable to write sha1 filename %s"
+#~ msgstr "impossibile scrivere il file sha1 con nome %s"
 
-#: git-stash.sh:426
-msgid "Could not save index tree"
-msgstr ""
+#~ msgid "cannot read sha1_file for %s"
+#~ msgstr "impossibile leggere il file sha1 per %s"
 
-#: git-stash.sh:460
-msgid "Cannot unstage modified files"
-msgstr ""
+#~ msgid "unrecognised option: '$arg'"
+#~ msgstr "opzione non riconosciuta: '$arg'"
 
-#: git-stash.sh:474
-msgid "Index was not unstashed."
-msgstr ""
+#~ msgid "'$invalid' is not a valid commit"
+#~ msgstr "'$invalid' non è un commit valido"
 
-#: git-stash.sh:491
-#, sh-format
-msgid "Dropped ${REV} ($s)"
-msgstr "${REV} eliminata ($s)"
+#, fuzzy
+#~ msgid "could not parse '%s' (looking for '%s')"
+#~ msgstr "non è stato possibile leggere il file di log '%s'"
 
-#: git-stash.sh:492
-#, sh-format
-msgid "${REV}: Could not drop stash entry"
-msgstr "${REV}: non è stato possibile rimuovere la voce di stash"
+#, fuzzy
+#~ msgid "Can't stat %s"
+#~ msgstr "impossibile eseguire lo stat di '%s'"
 
-#: git-stash.sh:499
-msgid "No branch name specified"
-msgstr "Nome del branch non specificato"
+#~ msgid "No such remote: %s"
+#~ msgstr "Remote non esistente: %s"
 
-#: git-stash.sh:570
-msgid "(To restore them type \"git stash apply\")"
-msgstr "(Per ripristinarli digita \"git stash apply\")"
+#~ msgid " %d file changed"
+#~ msgid_plural " %d files changed"
+#~ msgstr[0] " %d file modificato"
+#~ msgstr[1] " %d file modificati"
 
-#: git-submodule.sh:56
-#, sh-format
-msgid "cannot strip one component off url '$remoteurl'"
-msgstr ""
+#~ msgid ", %d insertion(+)"
+#~ msgid_plural ", %d insertions(+)"
+#~ msgstr[0] ", %d inserzione(+)"
+#~ msgstr[1] ", %d inserzioni(+)"
 
-#: git-submodule.sh:109
-#, sh-format
-msgid "No submodule mapping found in .gitmodules for path '$sm_path'"
-msgstr ""
+#~ msgid ", %d deletion(-)"
+#~ msgid_plural ", %d deletions(-)"
+#~ msgstr[0] ". %d rimozione(-)"
+#~ msgstr[1] ", %d rimozioni(-)"
 
-#: git-submodule.sh:150
-#, sh-format
-msgid "Clone of '$url' into submodule path '$sm_path' failed"
-msgstr ""
+#~ msgid "could not run gpg."
+#~ msgstr "non è stato possibile eseguire gpg."
 
-#: git-submodule.sh:160
-#, sh-format
-msgid "Gitdir '$a' is part of the submodule path '$b' or vice versa"
-msgstr ""
+#~ msgid "gpg did not accept the data"
+#~ msgstr "gpg non ha accettato i dati"
 
-#: git-submodule.sh:249
-#, sh-format
-msgid "repo URL: '$repo' must be absolute or begin with ./|../"
-msgstr "repo URL: '$repo' deve essere assoluto o iniziare con ./|../"
+#~ msgid "'%s': %s"
+#~ msgstr "'%s': %s"
 
-#: git-submodule.sh:266
-#, sh-format
-msgid "'$sm_path' already exists in the index"
-msgstr "'$sm_path' esiste già in index"
+#~ msgid "in %0.1f seconds automatically..."
+#~ msgstr "automaticamente tra %0.1f secondi..."
 
-#: git-submodule.sh:270
-#, sh-format
-msgid ""
-"The following path is ignored by one of your .gitignore files:\n"
-"$sm_path\n"
-"Use -f if you really want to add it."
-msgstr ""
-"Il seguente path è ignorato da uno dei tuoi file .gitignore:\n"
-"$sm_path\n"
-"Usa -f se vuoi davvero aggiungerlo."
+#~ msgid "You do not have a valid HEAD"
+#~ msgstr "Non hai un HEAD valido"
 
-#: git-submodule.sh:281
-#, sh-format
-msgid "Adding existing repo at '$sm_path' to the index"
-msgstr ""
+#~ msgid "unable to look up current user in the passwd file: %s"
+#~ msgstr "impossibile trovare l'utente corrente nel file passwd: %s"
 
-#: git-submodule.sh:283
-#, sh-format
-msgid "'$sm_path' already exists and is not a valid git repo"
-msgstr "'$sm_path' esiste già e non è un repository git valido"
+#~ msgid "no such user"
+#~ msgstr "utente non esistente"
 
-#: git-submodule.sh:297
-#, sh-format
-msgid "Unable to checkout submodule '$sm_path'"
-msgstr ""
+#~ msgid "bug"
+#~ msgstr "bug"
 
-#: git-submodule.sh:302
-#, sh-format
-msgid "Failed to add submodule '$sm_path'"
-msgstr ""
+#~ msgid "copied:     %s -> %s"
+#~ msgstr "copiato:     %s -> %s"
 
-#: git-submodule.sh:307
-#, sh-format
-msgid "Failed to register submodule '$sm_path'"
-msgstr ""
+#~ msgid "deleted:    %s"
+#~ msgstr "eliminato:    %s"
 
-#: git-submodule.sh:349
-#, sh-format
-msgid "Entering '$prefix$sm_path'"
-msgstr ""
+#~ msgid "modified:   %s"
+#~ msgstr "modificato:   %s"
 
-#: git-submodule.sh:363
-#, sh-format
-msgid "Stopping at '$sm_path'; script returned non-zero status."
-msgstr ""
-"Interruzione a '$sm_path'; lo script ha restituito uno stato diverso da zero."
+#~ msgid "renamed:    %s -> %s"
+#~ msgstr "rinominato:    %s -> %s"
 
-#: git-submodule.sh:406
-#, sh-format
-msgid "No url found for submodule path '$sm_path' in .gitmodules"
-msgstr ""
+#~ msgid ", behind "
+#~ msgstr ", indietro "
 
-#: git-submodule.sh:415
-#, sh-format
-msgid "Failed to register url for submodule path '$sm_path'"
-msgstr ""
+#~ msgid "no files added"
+#~ msgstr "nessun file aggiunto"
 
-#: git-submodule.sh:417
-#, sh-format
-msgid "Submodule '$name' ($url) registered for path '$sm_path'"
-msgstr ""
+#~ msgid "oops"
+#~ msgstr "oops"
 
-#: git-submodule.sh:425
-#, sh-format
-msgid "Failed to register update mode for submodule path '$sm_path'"
-msgstr ""
+#~ msgid "%s: has been deleted/renamed"
+#~ msgstr "%s: è stata eliminata/rinominata"
 
-#: git-submodule.sh:524
-#, sh-format
-msgid ""
-"Submodule path '$sm_path' not initialized\n"
-"Maybe you want to use 'update --init'?"
-msgstr ""
+#~ msgid "[%s: ahead %d]"
+#~ msgstr "[%s: avanti %d]"
 
-#: git-submodule.sh:537
-#, sh-format
-msgid "Unable to find current revision in submodule path '$sm_path'"
-msgstr ""
+#~ msgid "diff_setup_done failed"
+#~ msgstr "diff_setup_done non riuscito"
 
-#: git-submodule.sh:556
-#, sh-format
-msgid "Unable to fetch in submodule path '$sm_path'"
-msgstr ""
+#~ msgid "--detach cannot be used with -b/-B/--orphan"
+#~ msgstr "--detach non può essere usata con -b/-B/--orphan"
 
-#: git-submodule.sh:570
-#, sh-format
-msgid "Unable to rebase '$sha1' in submodule path '$sm_path'"
-msgstr ""
+#~ msgid "--detach cannot be used with -t"
+#~ msgstr "--detach non può essere usata con -t"
 
-#: git-submodule.sh:571
-#, sh-format
-msgid "Submodule path '$sm_path': rebased into '$sha1'"
-msgstr ""
+#~ msgid "--orphan cannot be used with -t"
+#~ msgstr "--orphan non può essere usata con -t"
 
-#: git-submodule.sh:576
-#, sh-format
-msgid "Unable to merge '$sha1' in submodule path '$sm_path'"
-msgstr ""
+#~ msgid "git checkout: -f and -m are incompatible"
+#~ msgstr "git checkout: -f e -m non sono compatibili"
 
-#: git-submodule.sh:577
-#, sh-format
-msgid "Submodule path '$sm_path': merged in '$sha1'"
-msgstr ""
+#~ msgid "No existing author found with '%s'"
+#~ msgstr "Nessun autore esistente trovato con '%s'"
 
-#: git-submodule.sh:582
-#, sh-format
-msgid "Unable to checkout '$sha1' in submodule path '$sm_path'"
-msgstr ""
+#~ msgid "'%s': not a documentation directory."
+#~ msgstr "'%s': non è una directory della documentazione."
 
-#: git-submodule.sh:583
-#, sh-format
-msgid "Submodule path '$sm_path': checked out '$sha1'"
-msgstr ""
+#~ msgid "Reinitialized existing"
+#~ msgstr "Reinizializzato un esistente"
 
-#: git-submodule.sh:605 git-submodule.sh:928
-#, sh-format
-msgid "Failed to recurse into submodule path '$sm_path'"
-msgstr ""
+#~ msgid "Initialized empty"
+#~ msgstr "Inizializzato un"
 
-#: git-submodule.sh:713
-msgid "--cached cannot be used with --files"
-msgstr "--cached non può essere usata con --files"
+#~ msgid " shared"
+#~ msgstr " condiviso"
 
-#. unexpected type
-#: git-submodule.sh:753
-#, sh-format
-msgid "unexpected mode $mod_dst"
-msgstr "modalità $mod_dst inattesa"
+#~ msgid "Writing SQUASH_MSG"
+#~ msgstr "Scrittura di SQUASH_MSG"
 
-#: git-submodule.sh:771
-#, sh-format
-msgid "  Warn: $name doesn't contain commit $sha1_src"
-msgstr "  Attenzione: $name non contiene commit $sha1_src"
+#~ msgid "Finishing SQUASH_MSG"
+#~ msgstr "Completamento di SQUASH_MSG"
 
-#: git-submodule.sh:774
-#, sh-format
-msgid "  Warn: $name doesn't contain commit $sha1_dst"
-msgstr "  Attenzione: $name non contiene commit $sha1_dst"
+#~ msgid "tag name too long: %.*s..."
+#~ msgstr "nome tag troppo lungo: %.*s..."
 
-#: git-submodule.sh:777
-#, sh-format
-msgid "  Warn: $name doesn't contain commits $sha1_src and $sha1_dst"
-msgstr "  Attenzione: $name non contiene commit $sha1_src e $sha1_dst"
+#~ msgid "tag header too big."
+#~ msgstr "intestazione del tag troppo grande."
 
-#: git-submodule.sh:802
-msgid "blob"
-msgstr "blob"
+#~ msgid "You need to set your committer info first"
+#~ msgstr "È necessario impostare le informazioni sul committer"
 
-#: git-submodule.sh:803
-msgid "submodule"
-msgstr "sottomodulo"
+#~ msgid ""
+#~ "When you have resolved this problem run \"$cmdline --resolved\".\n"
+#~ "If you would prefer to skip this patch, instead run \"$cmdline --skip\".\n"
+#~ "To restore the original branch and stop patching run \"$cmdline --abort\"."
+#~ msgstr ""
+#~ "Quando hai risolto il problema esegui \"$cmdline --resolved\".\n"
+#~ "Se vuoi saltare questa patch, esegui invece \"$cmdline --skip\".\n"
+#~ "Per ripristinare il branch originale e interrompere l'applicazione delle "
+#~ "patch esegui \"$cmdline --abort\"."
 
-#: git-submodule.sh:840
-msgid "# Submodules changed but not updated:"
-msgstr ""
+#~ msgid "Patch format $patch_format is not supported."
+#~ msgstr "Il formato patch $patch_format non è supportato."
 
-#: git-submodule.sh:842
-msgid "# Submodule changes to be committed:"
-msgstr ""
+#~ msgid "Please make up your mind. --skip or --abort?"
+#~ msgstr "Per favore, deciditi. --skip o --abort?"
 
-#: git-submodule.sh:974
-#, sh-format
-msgid "Synchronizing submodule url for '$name'"
-msgstr ""
+#~ msgid "Patch does not have a valid e-mail address."
+#~ msgstr "La patch non contiene un indirizzo email valido."
+
+#~ msgid "Patch failed at $msgnum $FIRSTLINE"
+#~ msgstr "Patch non riuscita a $msgnum $FIRSTLINE"
+
+#~ msgid "Please call 'bisect_state' with at least one argument."
+#~ msgstr "Per favore, chiama 'bisect_state' con almeno un argomento."
+
+#~ msgid ""
+#~ "error: unknown option for 'stash save': $option\n"
+#~ "       To provide a message, use git stash save -- '$option'"
+#~ msgstr ""
+#~ "errore: opzione sconosciuta per 'stash save': $option\n"
+#~ "        Per aggiungere un messaggio, usare git stash save -- '$option'"
+
+#~ msgid "Stopping at '$sm_path'; script returned non-zero status."
+#~ msgstr ""
+#~ "Interruzione a '$sm_path'; lo script ha restituito uno stato diverso da "
+#~ "zero."
 
 #~ msgid "--"
 #~ msgstr "--"
diff -pruN 1.2.1+git2.18.0-1/git/po/README 1.2.3+git2.25.1-1/git/po/README
--- 1.2.1+git2.18.0-1/git/po/README	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/po/README	2020-02-17 04:47:35.000000000 +0000
@@ -289,16 +289,11 @@ something in the test suite might still
 version of the strings, e.g. to grep some error message or other
 output.
 
-To smoke out issues like these Git can be compiled with gettext poison
-support, at the top-level:
+To smoke out issues like these, Git tested with a translation mode that
+emits gibberish on every call to gettext. To use it run the test suite
+with it, e.g.:
 
-    make GETTEXT_POISON=YesPlease
-
-That'll give you a git which emits gibberish on every call to
-gettext. It's obviously not meant to be installed, but you should run
-the test suite with it:
-
-    cd t && prove -j 9 ./t[0-9]*.sh
+    cd t && GIT_TEST_GETTEXT_POISON=true prove -j 9 ./t[0-9]*.sh
 
 If tests break with it you should inspect them manually and see if
 what you're translating is sane, i.e. that you're not translating
diff -pruN 1.2.1+git2.18.0-1/git/po/ru.po 1.2.3+git2.25.1-1/git/po/ru.po
--- 1.2.1+git2.18.0-1/git/po/ru.po	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/po/ru.po	2020-02-17 04:47:35.000000000 +0000
@@ -3,15 +3,16 @@
 # This file is distributed under the same license as the PACKAGE package.
 # 
 # Translators:
-# Dimitriy Ryazantcev <DJm00n@mail.ru>, 2014-2018
+# Dimitriy Ryazantcev <DJm00n@mail.ru>, 2014-2019
 # insolor, 2014
 # insolor, 2014
+# Чук Таблицоменделеев <aurum444an@gmail.com>, 2019
 msgid ""
 msgstr ""
 "Project-Id-Version: Git Russian Localization Project\n"
 "Report-Msgid-Bugs-To: Git Mailing List <git@vger.kernel.org>\n"
-"POT-Creation-Date: 2018-01-07 07:50+0800\n"
-"PO-Revision-Date: 2018-01-09 10:56+0000\n"
+"POT-Creation-Date: 2019-06-04 08:24+0800\n"
+"PO-Revision-Date: 2019-06-21 17:28+0000\n"
 "Last-Translator: Dimitriy Ryazantcev <DJm00n@mail.ru>\n"
 "Language-Team: Russian (http://www.transifex.com/djm00n/git-po-ru/language/ru/)\n"
 "MIME-Version: 1.0\n"
@@ -20,59 +21,59 @@ msgstr ""
 "Language: ru\n"
 "Plural-Forms: nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);\n"
 
-#: advice.c:62
+#: advice.c:103
 #, c-format
-msgid "hint: %.*s\n"
-msgstr "подсказка: %.*s\n"
+msgid "%shint: %.*s%s\n"
+msgstr "%sподсказка: %.*s%s\n"
 
-#: advice.c:90
+#: advice.c:156
 msgid "Cherry-picking is not possible because you have unmerged files."
 msgstr "Невозможно выполнить копирование коммита в текущую ветку, так как у вас имеются не слитые файлы."
 
-#: advice.c:92
+#: advice.c:158
 msgid "Committing is not possible because you have unmerged files."
 msgstr "Невозможно закоммитить, так как у вас имеются не слитые файлы."
 
-#: advice.c:94
+#: advice.c:160
 msgid "Merging is not possible because you have unmerged files."
 msgstr "Невозможно выполнить слияние, так как у вас имеются не слитые файлы."
 
-#: advice.c:96
+#: advice.c:162
 msgid "Pulling is not possible because you have unmerged files."
 msgstr "Невозможно выполнить получение, так как у вас имеются не слитые файлы."
 
-#: advice.c:98
+#: advice.c:164
 msgid "Reverting is not possible because you have unmerged files."
 msgstr "Невозможно обратить изменения, так как у вас имеются не слитые файлы."
 
-#: advice.c:100
+#: advice.c:166
 #, c-format
 msgid "It is not possible to %s because you have unmerged files."
 msgstr "Невозможно выполнить %s, так как у вас имеются не слитые файлы."
 
-#: advice.c:108
+#: advice.c:174
 msgid ""
 "Fix them up in the work tree, and then use 'git add/rm <file>'\n"
 "as appropriate to mark resolution and make a commit."
 msgstr "Исправьте их в рабочем каталоге, затем запустите «git add/rm <файл>»,\nчтобы пометить исправление и сделайте коммит."
 
-#: advice.c:116
+#: advice.c:182
 msgid "Exiting because of an unresolved conflict."
 msgstr "Выход из-за неразрешенного конфликта."
 
-#: advice.c:121 builtin/merge.c:1213
+#: advice.c:187 builtin/merge.c:1320
 msgid "You have not concluded your merge (MERGE_HEAD exists)."
 msgstr "Вы не завершили слияние (присутствует файл MERGE_HEAD)."
 
-#: advice.c:123
+#: advice.c:189
 msgid "Please, commit your changes before merging."
 msgstr "Перед слиянием, выполните коммит ваших изменений."
 
-#: advice.c:124
+#: advice.c:190
 msgid "Exiting because of unfinished merge."
 msgstr "Выход из-за незавершенного слияния."
 
-#: advice.c:130
+#: advice.c:196
 #, c-format
 msgid ""
 "Note: checking out '%s'.\n"
@@ -88,92 +89,100 @@ msgid ""
 "\n"
 msgstr "Примечание: переход на «%s».\n\nВы сейчас в состоянии «отделённого HEAD». Вы можете осмотреться, сделать\nэкспериментальные изменения и закоммитить их, также вы можете отменить\nизменения любых коммитов в этом состоянии не затрагивая любые ветки и\nне переходя на них.\n\nЕсли вы хотите создать новую ветку и сохранить свои коммиты, то вы\nможете сделать это (сейчас или позже) вызвав команду checkout снова,\nно с параметром -b. Например:\n\n  git checkout -b <имя-новой-ветки>\n\n"
 
-#: apply.c:58
+#: alias.c:50
+msgid "cmdline ends with \\"
+msgstr "командная строка заканчивается символом \\"
+
+#: alias.c:51
+msgid "unclosed quote"
+msgstr "пропущена закрывающая кавычка"
+
+#: apply.c:63
 #, c-format
 msgid "unrecognized whitespace option '%s'"
 msgstr "неопознанная опция для пробелов «%s»"
 
-#: apply.c:74
+#: apply.c:79
 #, c-format
 msgid "unrecognized whitespace ignore option '%s'"
 msgstr "неопознанная опция для игнорирования пробелов «%s»"
 
-#: apply.c:122
+#: apply.c:129
 msgid "--reject and --3way cannot be used together."
 msgstr "--reject и --3way нельзя использовать одновременно."
 
-#: apply.c:124
+#: apply.c:131
 msgid "--cached and --3way cannot be used together."
 msgstr "--cached и --3way нельзя использовать одновременно."
 
-#: apply.c:127
+#: apply.c:134
 msgid "--3way outside a repository"
 msgstr "--3way вне репозитория"
 
-#: apply.c:138
+#: apply.c:145
 msgid "--index outside a repository"
 msgstr "--index вне репозитория"
 
-#: apply.c:141
+#: apply.c:148
 msgid "--cached outside a repository"
 msgstr "--cached вне репозитория"
 
-#: apply.c:821
+#: apply.c:829
 #, c-format
 msgid "Cannot prepare timestamp regexp %s"
 msgstr "Не удалось подготовить регулярное выражение для метки времени %s"
 
-#: apply.c:830
+#: apply.c:838
 #, c-format
 msgid "regexec returned %d for input: %s"
 msgstr "regexec возвратил %d для ввода: %s"
 
-#: apply.c:904
+#: apply.c:912
 #, c-format
 msgid "unable to find filename in patch at line %d"
 msgstr "не удалось найти имя файла в строке патча %d"
 
-#: apply.c:942
+#: apply.c:950
 #, c-format
 msgid "git apply: bad git-diff - expected /dev/null, got %s on line %d"
 msgstr "git apply: плохой git-diff — ожидалось /dev/null, получено %s на строке %d"
 
-#: apply.c:948
+#: apply.c:956
 #, c-format
 msgid "git apply: bad git-diff - inconsistent new filename on line %d"
 msgstr "git apply: плохой git-diff — не согласующееся новое имя файла на строке %d"
 
-#: apply.c:949
+#: apply.c:957
 #, c-format
 msgid "git apply: bad git-diff - inconsistent old filename on line %d"
 msgstr "git apply: плохой git-diff — не согласующееся старое имя файла на строке %d"
 
-#: apply.c:954
+#: apply.c:962
 #, c-format
 msgid "git apply: bad git-diff - expected /dev/null on line %d"
 msgstr "git apply: плохой git-diff  — ожидалось /dev/null на строке %d"
 
-#: apply.c:983
+#: apply.c:991
 #, c-format
 msgid "invalid mode on line %d: %s"
 msgstr "недопустимый режим %d: %s"
 
-#: apply.c:1301
+#: apply.c:1310
 #, c-format
 msgid "inconsistent header lines %d and %d"
 msgstr "противоречивые строки заголовка %d и %d"
 
-#: apply.c:1473
+#: apply.c:1482
 #, c-format
 msgid "recount: unexpected line: %.*s"
 msgstr "recount: не ожидаемая строка: %.*s"
 
-#: apply.c:1542
+#: apply.c:1551
 #, c-format
 msgid "patch fragment without header at line %d: %.*s"
 msgstr "фрагмент изменений без заголовка на строке %d: %.*s"
 
-#: apply.c:1562
+#: apply.c:1571
 #, c-format
 msgid ""
 "git diff header lacks filename information when removing %d leading pathname"
@@ -186,70 +195,70 @@ msgstr[1] "заголовок git diff 
 msgstr[2] "заголовок git diff не нашел информацию об имени файла при удалении %d ведущих компонент пути к файлу (строка %d)"
 msgstr[3] "заголовок git diff не нашел информацию об имени файла при удалении %d ведущих компонент пути к файлу (строка %d)"
 
-#: apply.c:1575
+#: apply.c:1584
 #, c-format
 msgid "git diff header lacks filename information (line %d)"
 msgstr "заголовок git diff не содержит информации об имени файла (строка %d)"
 
-#: apply.c:1763
+#: apply.c:1772
 msgid "new file depends on old contents"
 msgstr "новый файл зависит от старого содержимого"
 
-#: apply.c:1765
+#: apply.c:1774
 msgid "deleted file still has contents"
 msgstr "удаленный файл все еще имеет содержимое"
 
-#: apply.c:1799
+#: apply.c:1808
 #, c-format
 msgid "corrupt patch at line %d"
 msgstr "патч поврежден на строке %d"
 
-#: apply.c:1836
+#: apply.c:1845
 #, c-format
 msgid "new file %s depends on old contents"
 msgstr "новый файл %s зависит от старого содержимого"
 
-#: apply.c:1838
+#: apply.c:1847
 #, c-format
 msgid "deleted file %s still has contents"
 msgstr "удаленный файл %s все еще имеет содержимое"
 
-#: apply.c:1841
+#: apply.c:1850
 #, c-format
 msgid "** warning: file %s becomes empty but is not deleted"
 msgstr "** предупреждение: файл %s становится пустым, но не удаляется"
 
-#: apply.c:1988
+#: apply.c:1997
 #, c-format
 msgid "corrupt binary patch at line %d: %.*s"
 msgstr "поврежденный двоичный патч на строке %d: %.*s"
 
-#: apply.c:2025
+#: apply.c:2034
 #, c-format
 msgid "unrecognized binary patch at line %d"
 msgstr "неопознанный двоичный патч на строке %d"
 
-#: apply.c:2185
+#: apply.c:2196
 #, c-format
 msgid "patch with only garbage at line %d"
 msgstr "патч с мусором на строке %d"
 
-#: apply.c:2271
+#: apply.c:2282
 #, c-format
 msgid "unable to read symlink %s"
 msgstr "не удалось прочитать символьную ссылку %s"
 
-#: apply.c:2275
+#: apply.c:2286
 #, c-format
 msgid "unable to open or read %s"
 msgstr "не удалось открыть или прочесть %s"
 
-#: apply.c:2934
+#: apply.c:2945
 #, c-format
 msgid "invalid start of line: '%c'"
 msgstr "неправильное начало строки: «%c»"
 
-#: apply.c:3055
+#: apply.c:3066
 #, c-format
 msgid "Hunk #%d succeeded at %d (offset %d line)."
 msgid_plural "Hunk #%d succeeded at %d (offset %d lines)."
@@ -258,257 +267,258 @@ msgstr[1] "Часть #%d успешно
 msgstr[2] "Часть #%d успешно применена на %d (со сдвигом в %d строк)."
 msgstr[3] "Часть #%d успешно применена на %d (со сдвигом в %d строк)."
 
-#: apply.c:3067
+#: apply.c:3078
 #, c-format
 msgid "Context reduced to (%ld/%ld) to apply fragment at %d"
 msgstr "Контекст сужен до (%ld/%ld), чтобы применить фрагмент на %d строке"
 
-#: apply.c:3073
+#: apply.c:3084
 #, c-format
 msgid ""
 "while searching for:\n"
 "%.*s"
 msgstr "при поиске:\n%.*s"
 
-#: apply.c:3095
+#: apply.c:3106
 #, c-format
 msgid "missing binary patch data for '%s'"
 msgstr "пропущены данные двоичного патча для «%s»"
 
-#: apply.c:3103
+#: apply.c:3114
 #, c-format
 msgid "cannot reverse-apply a binary patch without the reverse hunk to '%s'"
 msgstr "невозможно выполнить reverse-apply для двоичного патча, без обращения изменений блока «%s»"
 
-#: apply.c:3149
+#: apply.c:3161
 #, c-format
 msgid "cannot apply binary patch to '%s' without full index line"
 msgstr "невозможно применить двоичный патч «%s» без строки с указанной полной версией индекса"
 
-#: apply.c:3159
+#: apply.c:3171
 #, c-format
 msgid ""
 "the patch applies to '%s' (%s), which does not match the current contents."
 msgstr "патч применятся к файлу «%s» (%s), но его текущее содержимое не соотвествует ожидаемому."
 
-#: apply.c:3167
+#: apply.c:3179
 #, c-format
 msgid "the patch applies to an empty '%s' but it is not empty"
 msgstr "патч применяется к пустому файлу «%s», но файл не пустой"
 
-#: apply.c:3185
+#: apply.c:3197
 #, c-format
 msgid "the necessary postimage %s for '%s' cannot be read"
 msgstr "не удалось прочитать необходимую посылку %s для «%s»"
 
-#: apply.c:3198
+#: apply.c:3210
 #, c-format
 msgid "binary patch does not apply to '%s'"
 msgstr "не удалось применить двоичный патч к «%s»"
 
-#: apply.c:3204
+#: apply.c:3216
 #, c-format
 msgid "binary patch to '%s' creates incorrect result (expecting %s, got %s)"
 msgstr "после применения двоичного патча для «%s» был получен неправильный результат (ожидалось %s, получено %s)"
 
-#: apply.c:3225
+#: apply.c:3237
 #, c-format
 msgid "patch failed: %s:%ld"
 msgstr "ошибка применения изменений: %s:%ld"
 
-#: apply.c:3347
+#: apply.c:3360
 #, c-format
 msgid "cannot checkout %s"
 msgstr "не удалось переключить состояние на %s"
 
-#: apply.c:3396 apply.c:3407 apply.c:3453 setup.c:277
+#: apply.c:3412 apply.c:3423 apply.c:3469 midx.c:59 setup.c:279
 #, c-format
 msgid "failed to read %s"
 msgstr "не удалось прочитать %s"
 
-#: apply.c:3404
+#: apply.c:3420
 #, c-format
 msgid "reading from '%s' beyond a symbolic link"
 msgstr "чтение из «%s» за символической ссылкой"
 
-#: apply.c:3433 apply.c:3673
+#: apply.c:3449 apply.c:3692
 #, c-format
 msgid "path %s has been renamed/deleted"
 msgstr "путь %s был переименован/удален"
 
-#: apply.c:3516 apply.c:3687
+#: apply.c:3535 apply.c:3707
 #, c-format
 msgid "%s: does not exist in index"
 msgstr "%s: нет в индексе"
 
-#: apply.c:3525 apply.c:3695
+#: apply.c:3544 apply.c:3715
 #, c-format
 msgid "%s: does not match index"
 msgstr "%s: не совпадает с индексом"
 
-#: apply.c:3560
+#: apply.c:3579
 msgid "repository lacks the necessary blob to fall back on 3-way merge."
 msgstr "в репозитории отсутствует необходимый двоичный объект для отката к трёхходовому слиянию."
 
-#: apply.c:3563
+#: apply.c:3582
 #, c-format
 msgid "Falling back to three-way merge...\n"
 msgstr "Откат к трёхходовому слиянию…\n"
 
-#: apply.c:3579 apply.c:3583
+#: apply.c:3598 apply.c:3602
 #, c-format
 msgid "cannot read the current contents of '%s'"
 msgstr "не удалось прочитать текущее содержимое «%s»"
 
-#: apply.c:3595
+#: apply.c:3614
 #, c-format
 msgid "Failed to fall back on three-way merge...\n"
 msgstr "Не удалось откатиться к трёхходовому слиянию…\n"
 
-#: apply.c:3609
+#: apply.c:3628
 #, c-format
 msgid "Applied patch to '%s' with conflicts.\n"
 msgstr "Патч применен к «%s» с конфликтами.\n"
 
-#: apply.c:3614
+#: apply.c:3633
 #, c-format
 msgid "Applied patch to '%s' cleanly.\n"
 msgstr "Патч применен к «%s» без ошибок.\n"
 
-#: apply.c:3640
+#: apply.c:3659
 msgid "removal patch leaves file contents"
 msgstr "патч удаления не удалил содержимое файла"
 
-#: apply.c:3712
+#: apply.c:3732
 #, c-format
 msgid "%s: wrong type"
 msgstr "%s: неправильный тип"
 
-#: apply.c:3714
+#: apply.c:3734
 #, c-format
 msgid "%s has type %o, expected %o"
 msgstr "%s имеет тип %o, а ожидался %o"
 
-#: apply.c:3864 apply.c:3866
+#: apply.c:3885 apply.c:3887 read-cache.c:830 read-cache.c:856
+#: read-cache.c:1309
 #, c-format
 msgid "invalid path '%s'"
 msgstr "неправильный путь «%s»"
 
-#: apply.c:3922
+#: apply.c:3943
 #, c-format
 msgid "%s: already exists in index"
 msgstr "%s: уже содержится в индексе"
 
-#: apply.c:3925
+#: apply.c:3946
 #, c-format
 msgid "%s: already exists in working directory"
 msgstr "%s: уже содержится в рабочем каталоге"
 
-#: apply.c:3945
+#: apply.c:3966
 #, c-format
 msgid "new mode (%o) of %s does not match old mode (%o)"
 msgstr "новый режим доступа (%o) для %s не соответствует старому режиму доступа (%o)"
 
-#: apply.c:3950
+#: apply.c:3971
 #, c-format
 msgid "new mode (%o) of %s does not match old mode (%o) of %s"
 msgstr "новый режим доступа (%o) для %s не соответствует старому режиму доступа (%o) для %s"
 
-#: apply.c:3970
+#: apply.c:3991
 #, c-format
 msgid "affected file '%s' is beyond a symbolic link"
 msgstr "затронутый файл «%s» находится за символической ссылкой"
 
-#: apply.c:3974
+#: apply.c:3995
 #, c-format
 msgid "%s: patch does not apply"
 msgstr "%s: не удалось применить патч"
 
-#: apply.c:3989
+#: apply.c:4010
 #, c-format
 msgid "Checking patch %s..."
 msgstr "Проверка патча %s…"
 
-#: apply.c:4080
+#: apply.c:4102
 #, c-format
 msgid "sha1 information is lacking or useless for submodule %s"
 msgstr "информация об sha1 отсутствует или бесполезна для подмодуля %s"
 
-#: apply.c:4087
+#: apply.c:4109
 #, c-format
 msgid "mode change for %s, which is not in current HEAD"
 msgstr "изменен режим для %s, который не находится в текущем HEAD"
 
-#: apply.c:4090
+#: apply.c:4112
 #, c-format
 msgid "sha1 information is lacking or useless (%s)."
 msgstr "информация об sha1 отсутствует или бесполезна (%s)."
 
-#: apply.c:4095 builtin/checkout.c:236 builtin/reset.c:148
+#: apply.c:4117 builtin/checkout.c:257 builtin/reset.c:143
 #, c-format
 msgid "make_cache_entry failed for path '%s'"
 msgstr "сбой make_cache_entry для пути «%s»"
 
-#: apply.c:4099
+#: apply.c:4121
 #, c-format
 msgid "could not add %s to temporary index"
 msgstr "не удалось добавить %s во временный индекс"
 
-#: apply.c:4109
+#: apply.c:4131
 #, c-format
 msgid "could not write temporary index to %s"
 msgstr "не удалось записать временный индкекс в %s"
 
-#: apply.c:4247
+#: apply.c:4269
 #, c-format
 msgid "unable to remove %s from index"
 msgstr "не удалось удалить %s из индекса"
 
-#: apply.c:4282
+#: apply.c:4303
 #, c-format
 msgid "corrupt patch for submodule %s"
 msgstr "поврежденный патч для подмодуля %s"
 
-#: apply.c:4288
+#: apply.c:4309
 #, c-format
 msgid "unable to stat newly created file '%s'"
 msgstr "не удалось выполнить stat для созданного файла «%s»"
 
-#: apply.c:4296
+#: apply.c:4317
 #, c-format
 msgid "unable to create backing store for newly created file %s"
 msgstr "не удалось создать вспомогательный файл для созданного файла %s"
 
-#: apply.c:4302 apply.c:4446
+#: apply.c:4323 apply.c:4468
 #, c-format
 msgid "unable to add cache entry for %s"
 msgstr "не удалось создать запись в кэше для %s"
 
-#: apply.c:4343
+#: apply.c:4366
 #, c-format
 msgid "failed to write to '%s'"
 msgstr "не удалось записать в «%s»"
 
-#: apply.c:4347
+#: apply.c:4370
 #, c-format
 msgid "closing file '%s'"
 msgstr "закрытие файла «%s»"
 
-#: apply.c:4417
+#: apply.c:4440
 #, c-format
 msgid "unable to write file '%s' mode %o"
 msgstr "не удалось записать файл «%s» с режимом доступа %o"
 
-#: apply.c:4515
+#: apply.c:4538
 #, c-format
 msgid "Applied patch %s cleanly."
 msgstr "Патч %s применен без ошибок."
 
-#: apply.c:4523
+#: apply.c:4546
 msgid "internal error"
 msgstr "внутренняя ошибка"
 
-#: apply.c:4526
+#: apply.c:4549
 #, c-format
 msgid "Applying patch %%s with %d reject..."
 msgid_plural "Applying patch %%s with %d rejects..."
@@ -517,45 +527,45 @@ msgstr[1] "Применение патч
 msgstr[2] "Применение патча %%s с %d отказами…"
 msgstr[3] "Применение патча %%s с %d отказами…"
 
-#: apply.c:4537
+#: apply.c:4560
 #, c-format
 msgid "truncating .rej filename to %.*s.rej"
 msgstr "усечение имени .rej файла до %.*s.rej"
 
-#: apply.c:4545 builtin/fetch.c:761 builtin/fetch.c:1011
+#: apply.c:4568 builtin/fetch.c:837 builtin/fetch.c:1118
 #, c-format
 msgid "cannot open %s"
 msgstr "не удалось открыть %s"
 
-#: apply.c:4559
+#: apply.c:4582
 #, c-format
 msgid "Hunk #%d applied cleanly."
 msgstr "Блок №%d применен без ошибок."
 
-#: apply.c:4563
+#: apply.c:4586
 #, c-format
 msgid "Rejected hunk #%d."
 msgstr "Блок №%d отклонен."
 
-#: apply.c:4673
+#: apply.c:4696
 #, c-format
 msgid "Skipped patch '%s'."
 msgstr "Патч «%s» пропущен."
 
-#: apply.c:4681
+#: apply.c:4704
 msgid "unrecognized input"
 msgstr "не распознанный ввод"
 
-#: apply.c:4700
+#: apply.c:4724
 msgid "unable to read index file"
 msgstr "не удалось прочитать файл индекса"
 
-#: apply.c:4837
+#: apply.c:4879
 #, c-format
 msgid "can't open patch '%s': %s"
 msgstr "не удалось открыть патч «%s»: %s"
 
-#: apply.c:4864
+#: apply.c:4906
 #, c-format
 msgid "squelched %d whitespace error"
 msgid_plural "squelched %d whitespace errors"
@@ -564,7 +574,7 @@ msgstr[1] "пропущено %d оши
 msgstr[2] "пропущено %d ошибок в пробельных символах"
 msgstr[3] "пропущено %d ошибок в пробельных символах"
 
-#: apply.c:4870 apply.c:4885
+#: apply.c:4912 apply.c:4927
 #, c-format
 msgid "%d line adds whitespace errors."
 msgid_plural "%d lines add whitespace errors."
@@ -573,7 +583,7 @@ msgstr[1] "%d строки добави
 msgstr[2] "%d строк добавили ошибки в пробельных символах."
 msgstr[3] "%d строк добавили ошибки в пробельных символах."
 
-#: apply.c:4878
+#: apply.c:4920
 #, c-format
 msgid "%d line applied after fixing whitespace errors."
 msgid_plural "%d lines applied after fixing whitespace errors."
@@ -582,301 +592,379 @@ msgstr[1] "%d строки добавл
 msgstr[2] "%d строк добавлено после исправления ошибок в пробелах."
 msgstr[3] "%d строки добавлено после исправления ошибок в пробелах."
 
-#: apply.c:4894 builtin/add.c:539 builtin/mv.c:298 builtin/rm.c:390
+#: apply.c:4936 builtin/add.c:540 builtin/mv.c:301 builtin/rm.c:390
 msgid "Unable to write new index file"
 msgstr "Не удалось записать новый файл индекса"
 
-#: apply.c:4921 apply.c:4924 builtin/am.c:2220 builtin/am.c:2223
-#: builtin/clone.c:116 builtin/fetch.c:116 builtin/pull.c:193
-#: builtin/submodule--helper.c:369 builtin/submodule--helper.c:860
-#: builtin/submodule--helper.c:863 builtin/submodule--helper.c:1230
-#: builtin/submodule--helper.c:1233 builtin/submodule--helper.c:1450
-#: git-add--interactive.perl:197
+#: apply.c:4963 apply.c:4966 builtin/am.c:2210 builtin/am.c:2213
+#: builtin/clone.c:120 builtin/fetch.c:118 builtin/merge.c:271
+#: builtin/pull.c:207 builtin/submodule--helper.c:407
+#: builtin/submodule--helper.c:1366 builtin/submodule--helper.c:1369
+#: builtin/submodule--helper.c:1849 builtin/submodule--helper.c:1852
+#: builtin/submodule--helper.c:2091 git-add--interactive.perl:197
 msgid "path"
 msgstr "путь"
 
-#: apply.c:4922
+#: apply.c:4964
 msgid "don't apply changes matching the given path"
 msgstr "не применять изменения по указанному пути"
 
-#: apply.c:4925
+#: apply.c:4967
 msgid "apply changes matching the given path"
 msgstr "применять изменения по указанному пути"
 
-#: apply.c:4927 builtin/am.c:2229
+#: apply.c:4969 builtin/am.c:2219
 msgid "num"
 msgstr "количество"
 
-#: apply.c:4928
+#: apply.c:4970
 msgid "remove <num> leading slashes from traditional diff paths"
 msgstr "удалить <количество> ведущих косых черт из традиционных путей списка изменений"
 
-#: apply.c:4931
+#: apply.c:4973
 msgid "ignore additions made by the patch"
 msgstr "игнорировать добавления, сделанные этим патчем"
 
-#: apply.c:4933
+#: apply.c:4975
 msgid "instead of applying the patch, output diffstat for the input"
 msgstr "вместо применения патча вывести статистику добавлений и удалений для ввода"
 
-#: apply.c:4937
+#: apply.c:4979
 msgid "show number of added and deleted lines in decimal notation"
 msgstr "показать количество добавленных и удаленных строк в десятичном представлении"
 
-#: apply.c:4939
+#: apply.c:4981
 msgid "instead of applying the patch, output a summary for the input"
-msgstr "вместо применения патча вывести статистику изменений для ввода"
+msgstr "вместо применения патча вывести сводку изменений для ввода"
 
-#: apply.c:4941
+#: apply.c:4983
 msgid "instead of applying the patch, see if the patch is applicable"
 msgstr "вместо применения патча проверить подходит ли он"
 
-#: apply.c:4943
+#: apply.c:4985
 msgid "make sure the patch is applicable to the current index"
 msgstr "проверить, что патч применяется к текущему индексу"
 
-#: apply.c:4945
+#: apply.c:4987
+msgid "mark new files with `git add --intent-to-add`"
+msgstr "помечать новые файлы с «git add --intent-to-add»"
+
+#: apply.c:4989
 msgid "apply a patch without touching the working tree"
 msgstr "применить патч, не изменяя рабочий каталог"
 
-#: apply.c:4947
+#: apply.c:4991
 msgid "accept a patch that touches outside the working area"
 msgstr "принять патч, который затрагивает файлы за рабочим каталогом"
 
-#: apply.c:4949
+#: apply.c:4994
 msgid "also apply the patch (use with --stat/--summary/--check)"
 msgstr "а также применить патч (используйте с --stat/--summary/--check)"
 
-#: apply.c:4951
+#: apply.c:4996
 msgid "attempt three-way merge if a patch does not apply"
 msgstr "попытаться сделать трехходовое слияние, если патч не применяется"
 
-#: apply.c:4953
+#: apply.c:4998
 msgid "build a temporary index based on embedded index information"
 msgstr "построить временный индекс, основанный на встроенной информации об индексе"
 
-#: apply.c:4956 builtin/checkout-index.c:168 builtin/ls-files.c:515
+#: apply.c:5001 builtin/checkout-index.c:173 builtin/ls-files.c:524
 msgid "paths are separated with NUL character"
 msgstr "пути, отделённые НУЛЕВЫМ символом"
 
-#: apply.c:4958
+#: apply.c:5003
 msgid "ensure at least <n> lines of context match"
 msgstr "удостовериться, что по крайней мере <n> строк контекста совпадают"
 
-#: apply.c:4959 builtin/am.c:2208 builtin/interpret-trailers.c:95
-#: builtin/interpret-trailers.c:97 builtin/interpret-trailers.c:99
-#: builtin/pack-objects.c:3009
+#: apply.c:5004 builtin/am.c:2198 builtin/interpret-trailers.c:97
+#: builtin/interpret-trailers.c:99 builtin/interpret-trailers.c:101
+#: builtin/pack-objects.c:3317 builtin/rebase.c:1415
 msgid "action"
 msgstr "действие"
 
-#: apply.c:4960
+#: apply.c:5005
 msgid "detect new or modified lines that have whitespace errors"
 msgstr "определять новые или модифицированные строки, у которых есть ошибки в пробельных символах"
 
-#: apply.c:4963 apply.c:4966
+#: apply.c:5008 apply.c:5011
 msgid "ignore changes in whitespace when finding context"
 msgstr "игнорировать изменения в пробельных символах при поиске контекста"
 
-#: apply.c:4969
+#: apply.c:5014
 msgid "apply the patch in reverse"
 msgstr "применить патч с обращением изменений"
 
-#: apply.c:4971
+#: apply.c:5016
 msgid "don't expect at least one line of context"
 msgstr "не ожидать как минимум одной строки контекста"
 
-#: apply.c:4973
+#: apply.c:5018
 msgid "leave the rejected hunks in corresponding *.rej files"
 msgstr "оставить отклоненные блоки изменений в соответствующих *.rej файлах"
 
-#: apply.c:4975
+#: apply.c:5020
 msgid "allow overlapping hunks"
 msgstr "разрешить перекрывающиеся блоки изменений"
 
-#: apply.c:4976 builtin/add.c:292 builtin/check-ignore.c:21
-#: builtin/commit.c:1361 builtin/count-objects.c:96 builtin/fsck.c:640
-#: builtin/log.c:1896 builtin/mv.c:123 builtin/read-tree.c:125
+#: apply.c:5021 builtin/add.c:291 builtin/check-ignore.c:22
+#: builtin/commit.c:1317 builtin/count-objects.c:98 builtin/fsck.c:786
+#: builtin/log.c:2045 builtin/mv.c:123 builtin/read-tree.c:128
 msgid "be verbose"
 msgstr "быть многословнее"
 
-#: apply.c:4978
+#: apply.c:5023
 msgid "tolerate incorrectly detected missing new-line at the end of file"
 msgstr "разрешить некорректно определенные пропущенные пустые строки в конце файла"
 
-#: apply.c:4981
+#: apply.c:5026
 msgid "do not trust the line counts in the hunk headers"
 msgstr "не доверять количеству строк из заголовка блока изменений"
 
-#: apply.c:4983 builtin/am.c:2217
+#: apply.c:5028 builtin/am.c:2207
 msgid "root"
 msgstr "корень"
 
-#: apply.c:4984
+#: apply.c:5029
 msgid "prepend <root> to all filenames"
 msgstr "добавить <корень> спереди ко всем именам файлов"
 
-#: archive.c:13
+#: archive.c:14
 msgid "git archive [<options>] <tree-ish> [<path>...]"
 msgstr "git archive [<опции>] <указатель-дерева> [<путь>…]"
 
-#: archive.c:14
+#: archive.c:15
 msgid "git archive --list"
 msgstr "git archive --list"
 
-#: archive.c:15
+#: archive.c:16
 msgid ""
 "git archive --remote <repo> [--exec <cmd>] [<options>] <tree-ish> "
 "[<path>...]"
 msgstr "git archive --remote <репозиторий> [--exec <команда>] [<опции>] <указатель-дерева> [<путь>…]"
 
-#: archive.c:16
+#: archive.c:17
 msgid "git archive --remote <repo> [--exec <cmd>] --list"
 msgstr "git archive --remote <репозиторий> [--exec <команда>] --list"
 
-#: archive.c:351 builtin/add.c:176 builtin/add.c:515 builtin/rm.c:299
+#: archive.c:372 builtin/add.c:177 builtin/add.c:516 builtin/rm.c:299
 #, c-format
 msgid "pathspec '%s' did not match any files"
 msgstr "спецификатор пути «%s» не соответствует ни одному файлу"
 
-#: archive.c:436
+#: archive.c:396
+#, c-format
+msgid "no such ref: %.*s"
+msgstr "нет такой ссылки: %.*s"
+
+#: archive.c:401
+#, c-format
+msgid "not a valid object name: %s"
+msgstr "недопустимое имя объекта: %s"
+
+#: archive.c:414
+#, c-format
+msgid "not a tree object: %s"
+msgstr "недействительный объект дерева: %s"
+
+#: archive.c:424
+msgid "current working directory is untracked"
+msgstr "текущий рабочий каталог не отслеживается"
+
+#: archive.c:455
 msgid "fmt"
 msgstr "формат"
 
-#: archive.c:436
+#: archive.c:455
 msgid "archive format"
 msgstr "формат архива"
 
-#: archive.c:437 builtin/log.c:1459
+#: archive.c:456 builtin/log.c:1557
 msgid "prefix"
 msgstr "префикс"
 
-#: archive.c:438
+#: archive.c:457
 msgid "prepend prefix to each pathname in the archive"
 msgstr "добавлять префикс перед каждым путем файла в архиве"
 
-#: archive.c:439 builtin/blame.c:693 builtin/blame.c:694 builtin/config.c:62
-#: builtin/fast-export.c:1005 builtin/fast-export.c:1007 builtin/grep.c:861
-#: builtin/hash-object.c:102 builtin/ls-files.c:551 builtin/ls-files.c:554
-#: builtin/notes.c:405 builtin/notes.c:568 builtin/read-tree.c:120
-#: parse-options.h:153
+#: archive.c:458 builtin/blame.c:821 builtin/blame.c:822
+#: builtin/commit-tree.c:117 builtin/config.c:129 builtin/fast-export.c:1091
+#: builtin/fast-export.c:1093 builtin/grep.c:895 builtin/hash-object.c:105
+#: builtin/ls-files.c:560 builtin/ls-files.c:563 builtin/notes.c:412
+#: builtin/notes.c:578 builtin/read-tree.c:123 parse-options.h:177
 msgid "file"
 msgstr "файл"
 
-#: archive.c:440 builtin/archive.c:89
+#: archive.c:459 builtin/archive.c:90
 msgid "write the archive to this file"
 msgstr "запись архива в этот файл"
 
-#: archive.c:442
+#: archive.c:461
 msgid "read .gitattributes in working directory"
 msgstr "читать .gitattributes в рабочем каталоге"
 
-#: archive.c:443
+#: archive.c:462
 msgid "report archived files on stderr"
 msgstr "отчет об архивированных файлах в stderr"
 
-#: archive.c:444
+#: archive.c:463
 msgid "store only"
 msgstr "только хранение"
 
-#: archive.c:445
+#: archive.c:464
 msgid "compress faster"
 msgstr "сжимать быстрее"
 
-#: archive.c:453
+#: archive.c:472
 msgid "compress better"
 msgstr "сжимать лучше"
 
-#: archive.c:456
+#: archive.c:475
 msgid "list supported archive formats"
 msgstr "перечислить поддерживаемые форматы архивов"
 
-#: archive.c:458 builtin/archive.c:90 builtin/clone.c:106 builtin/clone.c:109
-#: builtin/submodule--helper.c:872 builtin/submodule--helper.c:1239
+#: archive.c:477 builtin/archive.c:91 builtin/clone.c:110 builtin/clone.c:113
+#: builtin/submodule--helper.c:1378 builtin/submodule--helper.c:1858
 msgid "repo"
 msgstr "репозиторий"
 
-#: archive.c:459 builtin/archive.c:91
+#: archive.c:478 builtin/archive.c:92
 msgid "retrieve the archive from remote repository <repo>"
 msgstr "получить архив из внешнего <репозитория>"
 
-#: archive.c:460 builtin/archive.c:92 builtin/notes.c:489
+#: archive.c:479 builtin/archive.c:93 builtin/difftool.c:707
+#: builtin/notes.c:498
 msgid "command"
 msgstr "команда"
 
-#: archive.c:461 builtin/archive.c:93
+#: archive.c:480 builtin/archive.c:94
 msgid "path to the remote git-upload-archive command"
 msgstr "путь к команде git-upload-archive на машине с внешним репозиторием"
 
-#: archive.c:468
+#: archive.c:487
 msgid "Unexpected option --remote"
 msgstr "Неожиданная опция --remote"
 
-#: archive.c:470
+#: archive.c:489
 msgid "Option --exec can only be used together with --remote"
 msgstr "Опция --exec может использоваться только вместе с --remote"
 
-#: archive.c:472
+#: archive.c:491
 msgid "Unexpected option --output"
 msgstr "Неожиданная опция --output"
 
-#: archive.c:494
+#: archive.c:513
 #, c-format
 msgid "Unknown archive format '%s'"
 msgstr "Неизвестный формат архива «%s»"
 
-#: archive.c:501
+#: archive.c:520
 #, c-format
 msgid "Argument not supported for format '%s': -%d"
 msgstr "Аргумент не поддерживается для формата «%s»: -%d"
 
-#: attr.c:218
+#: archive-tar.c:125 archive-zip.c:345
+#, c-format
+msgid "cannot stream blob %s"
+msgstr "не удалось создать поток двоичного объекта %s"
+
+#: archive-tar.c:260 archive-zip.c:363
+#, c-format
+msgid "unsupported file mode: 0%o (SHA1: %s)"
+msgstr "неподдерживаемый режим доступа к файлу: 0%o (SHA1: %s)"
+
+#: archive-tar.c:287 archive-zip.c:353
+#, c-format
+msgid "cannot read %s"
+msgstr "не удалось прочитать %s"
+
+#: archive-tar.c:459
+#, c-format
+msgid "unable to start '%s' filter"
+msgstr "не удалось запустить фильтр «%s»"
+
+#: archive-tar.c:462
+msgid "unable to redirect descriptor"
+msgstr "не удалось перенаправить дескриптор"
+
+#: archive-tar.c:469
+#, c-format
+msgid "'%s' filter reported error"
+msgstr "фильтр «%s» сообщил об ошибке"
+
+#: archive-zip.c:314
+#, c-format
+msgid "path is not valid UTF-8: %s"
+msgstr "путь не является действительным UTF-8: %s"
+
+#: archive-zip.c:318
+#, c-format
+msgid "path too long (%d chars, SHA1: %s): %s"
+msgstr "путь слишком длинный (%d символов, SHA1: %s): %s"
+
+#: archive-zip.c:474 builtin/pack-objects.c:226 builtin/pack-objects.c:229
+#, c-format
+msgid "deflate error (%d)"
+msgstr "ошибка сжатия (%d)"
+
+#: archive-zip.c:609
+#, c-format
+msgid "timestamp too large for this system: %<PRIuMAX>"
+msgstr "отметка времени слишком большая для этой системы: %<PRIuMAX>"
+
+#: attr.c:211
 #, c-format
 msgid "%.*s is not a valid attribute name"
 msgstr "%.*s не является допустимым именем атрибута"
 
-#: attr.c:415
+#: attr.c:368
+#, c-format
+msgid "%s not allowed: %s:%d"
+msgstr "%s не разрешено: %s:%d"
+
+#: attr.c:408
 msgid ""
 "Negative patterns are ignored in git attributes\n"
 "Use '\\!' for literal leading exclamation."
 msgstr "Отрицающие шаблоны в атрибутах git игнорируются.\nИспользуйте «\\!» для буквального использования символа в значении «восклицательный знак»."
 
-#: bisect.c:458
+#: bisect.c:468
 #, c-format
 msgid "Badly quoted content in file '%s': %s"
 msgstr "Плохое содержимое файла «%s»: %s"
 
-#: bisect.c:666
+#: bisect.c:678
 #, c-format
 msgid "We cannot bisect more!\n"
 msgstr "Невозможно продолжить бинарный поиск!\n"
 
-#: bisect.c:720
+#: bisect.c:733
 #, c-format
 msgid "Not a valid commit name %s"
 msgstr "Недопустимое имя коммита %s"
 
-#: bisect.c:744
+#: bisect.c:758
 #, c-format
 msgid ""
 "The merge base %s is bad.\n"
 "This means the bug has been fixed between %s and [%s].\n"
 msgstr "База слияния %s является плохим коммитом.\nЭто значит, что ошибка была исправлена где-то между %s и [%s].\n"
 
-#: bisect.c:749
+#: bisect.c:763
 #, c-format
 msgid ""
 "The merge base %s is new.\n"
 "The property has changed between %s and [%s].\n"
 msgstr "База слияния %s является новой.\nСвойство было изменено где-то между %s и [%s].\n"
 
-#: bisect.c:754
+#: bisect.c:768
 #, c-format
 msgid ""
 "The merge base %s is %s.\n"
 "This means the first '%s' commit is between %s and [%s].\n"
 msgstr "База слияния %s является %s.\nЭто значит, что «%s» коммит находится где-то между %s и [%s].\n"
 
-#: bisect.c:762
+#: bisect.c:776
 #, c-format
 msgid ""
 "Some %s revs are not ancestors of the %s rev.\n"
@@ -884,7 +972,7 @@ msgid ""
 "Maybe you mistook %s and %s revs?\n"
 msgstr "Несколько %s коммитов не являются предками %s коммита.\nВ этом случае git bisect не может работать правильно.\nВозможно, вы перепутали редакции %s и %s местами?\n"
 
-#: bisect.c:775
+#: bisect.c:789
 #, c-format
 msgid ""
 "the merge base between %s and [%s] must be skipped.\n"
@@ -892,43 +980,43 @@ msgid ""
 "We continue anyway."
 msgstr "База слияния между %s и [%s] должно быть пропущена.\nПоэтому мы не можем быть уверены, что первый %s коммит находится между %s и %s.\nНо все же продолжаем поиск."
 
-#: bisect.c:810
+#: bisect.c:822
 #, c-format
 msgid "Bisecting: a merge base must be tested\n"
 msgstr "Бинарный поиск: база слияния должна быть проверена\n"
 
-#: bisect.c:862
+#: bisect.c:865
 #, c-format
 msgid "a %s revision is needed"
 msgstr "нужно указать %s редакцию"
 
-#: bisect.c:879 builtin/notes.c:175 builtin/tag.c:234
+#: bisect.c:884 builtin/notes.c:177 builtin/tag.c:248
 #, c-format
 msgid "could not create file '%s'"
 msgstr "не удалось создать файл «%s»"
 
-#: bisect.c:930
+#: bisect.c:928 builtin/merge.c:146
 #, c-format
 msgid "could not read file '%s'"
 msgstr "не удалось прочитать файл «%s»"
 
-#: bisect.c:960
+#: bisect.c:958
 msgid "reading bisect refs failed"
 msgstr "сбой при чтении ссылок двоичного поиска"
 
-#: bisect.c:979
+#: bisect.c:977
 #, c-format
 msgid "%s was both %s and %s\n"
 msgstr "%s была одновременно и %s и %s\n"
 
-#: bisect.c:987
+#: bisect.c:985
 #, c-format
 msgid ""
 "No testable commit found.\n"
 "Maybe you started with bad path parameters?\n"
 msgstr "Тестируемый коммит не найден.\nВозможно, вы начали поиск с указанием неправильного параметра пути?\n"
 
-#: bisect.c:1006
+#: bisect.c:1004
 #, c-format
 msgid "(roughly %d step)"
 msgid_plural "(roughly %d steps)"
@@ -939,7 +1027,7 @@ msgstr[3] "(примерно %d шаго
 
 #. TRANSLATORS: the last %s will be replaced with "(roughly %d
 #. steps)" translation.
-#: bisect.c:1012
+#: bisect.c:1010
 #, c-format
 msgid "Bisecting: %d revision left to test after this %s\n"
 msgid_plural "Bisecting: %d revisions left to test after this %s\n"
@@ -948,36 +1036,37 @@ msgstr[1] "Бинарный поиск:
 msgstr[2] "Бинарный поиск: %d редакций осталось проверить после этой %s\n"
 msgstr[3] "Бинарный поиск: %d редакций осталось проверить после этой %s\n"
 
-#: blame.c:1757
+#: blame.c:1794
 msgid "--contents and --reverse do not blend well."
 msgstr "--contents и --reverse не очень сочетаются."
 
-#: blame.c:1768
+#: blame.c:1808
 msgid "cannot use --contents with final commit object name"
 msgstr "нельзя использовать --contents с указанием финального имени объекта"
 
-#: blame.c:1788
+#: blame.c:1829
 msgid "--reverse and --first-parent together require specified latest commit"
 msgstr "при --reverse и --first-parent вместе нужно указывать конкретный последний коммит"
 
-#: blame.c:1797 bundle.c:169 ref-filter.c:1981 sequencer.c:1177
-#: sequencer.c:2370 builtin/commit.c:1066 builtin/log.c:364 builtin/log.c:918
-#: builtin/log.c:1368 builtin/log.c:1697 builtin/log.c:1945
-#: builtin/merge.c:369 builtin/shortlog.c:191
+#: blame.c:1838 bundle.c:164 ref-filter.c:2077 remote.c:1938 sequencer.c:2030
+#: sequencer.c:4224 builtin/commit.c:1017 builtin/log.c:382 builtin/log.c:940
+#: builtin/log.c:1428 builtin/log.c:1804 builtin/log.c:2094
+#: builtin/merge.c:415 builtin/pack-objects.c:3140 builtin/pack-objects.c:3155
+#: builtin/shortlog.c:192
 msgid "revision walk setup failed"
 msgstr "сбой инициализации прохода по редакциям"
 
-#: blame.c:1815
+#: blame.c:1856
 msgid ""
 "--reverse --first-parent together require range along first-parent chain"
 msgstr "при указании --reverse и --first-parent вместе, требуется также указать диапазон по цепочке первого родителя"
 
-#: blame.c:1826
+#: blame.c:1867
 #, c-format
 msgid "no such path %s in %s"
 msgstr "нет такого пути %s в %s"
 
-#: blame.c:1837
+#: blame.c:1878
 #, c-format
 msgid "cannot read blob %s for path %s"
 msgstr "невозможно прочитать объект %s для пути %s"
@@ -1082,17 +1171,17 @@ msgid ""
 "\"git push -u\" to set the upstream config as you push."
 msgstr "\nЕсли вы планируете основывать свою работу на вышестоящей ветке, которая уже существует во внешнем репозитории, вам может потребоваться запустить «git fetch» для ее получения.\n\nЕсли вы планируете отправить новую локальную ветку, которая будет отслеживаться, во внешний репозиторий, вам может потребоваться запустить «git push -u» — чтобы сохранить настройку вышестоящего репозитория для отправки."
 
-#: branch.c:280
+#: branch.c:281
 #, c-format
 msgid "Not a valid object name: '%s'."
 msgstr "Недопустимое имя объекта: «%s»."
 
-#: branch.c:300
+#: branch.c:301
 #, c-format
 msgid "Ambiguous object name: '%s'."
 msgstr "Неоднозначное имя объекта: «%s»."
 
-#: branch.c:305
+#: branch.c:306
 #, c-format
 msgid "Not a valid branch point: '%s'."
 msgstr "Недопустимая точка ветки: «%s»."
@@ -1107,27 +1196,27 @@ msgstr "«%s» уже находится
 msgid "HEAD of working tree %s is not updated"
 msgstr "HEAD рабочего каталога %s не обновлён"
 
-#: bundle.c:34
+#: bundle.c:36
 #, c-format
 msgid "'%s' does not look like a v2 bundle file"
 msgstr "«%s» не похож на файл пакета версии 2"
 
-#: bundle.c:62
+#: bundle.c:64
 #, c-format
 msgid "unrecognized header: %s%s (%d)"
 msgstr "неопознанный заголовок: %s%s (%d)"
 
-#: bundle.c:88 sequencer.c:1360 sequencer.c:1807 sequencer.c:2637
-#: sequencer.c:2663 sequencer.c:2754 sequencer.c:2856 builtin/commit.c:782
+#: bundle.c:90 rerere.c:480 rerere.c:690 sequencer.c:2281 sequencer.c:2916
+#: builtin/commit.c:788
 #, c-format
 msgid "could not open '%s'"
 msgstr "не удалось открыть «%s»"
 
-#: bundle.c:140
+#: bundle.c:143
 msgid "Repository lacks these prerequisite commits:"
 msgstr "В репозитории отсутствуют необходимые коммиты:"
 
-#: bundle.c:193
+#: bundle.c:194
 #, c-format
 msgid "The bundle contains this ref:"
 msgid_plural "The bundle contains these %d refs:"
@@ -1136,11 +1225,11 @@ msgstr[1] "Пакет содержит 
 msgstr[2] "Пакет содержит эти %d ссылок:"
 msgstr[3] "Пакет содержит эти %d ссылок:"
 
-#: bundle.c:200
+#: bundle.c:201
 msgid "The bundle records a complete history."
 msgstr "Пакет содержит полную историю."
 
-#: bundle.c:202
+#: bundle.c:203
 #, c-format
 msgid "The bundle requires this ref:"
 msgid_plural "The bundle requires these %d refs:"
@@ -1149,228 +1238,605 @@ msgstr[1] "Пакет требует э
 msgstr[2] "Пакет требует эти %d ссылок:"
 msgstr[3] "Пакет требует эти %d ссылок:"
 
-#: bundle.c:261
+#: bundle.c:269
+msgid "unable to dup bundle descriptor"
+msgstr "не удалось дублировать дескриптор пакета"
+
+#: bundle.c:276
 msgid "Could not spawn pack-objects"
 msgstr "Не удалось создать объекты пакета"
 
-#: bundle.c:272
+#: bundle.c:287
 msgid "pack-objects died"
 msgstr "критическая ошибка pack-objects"
 
-#: bundle.c:314
+#: bundle.c:329
 msgid "rev-list died"
 msgstr "критическая ошибка rev-list"
 
-#: bundle.c:363
+#: bundle.c:378
 #, c-format
 msgid "ref '%s' is excluded by the rev-list options"
 msgstr "ссылка «%s» исключена в соответствии с опциями rev-list"
 
-#: bundle.c:453 builtin/log.c:181 builtin/log.c:1604 builtin/shortlog.c:296
+#: bundle.c:457 builtin/log.c:197 builtin/log.c:1709 builtin/shortlog.c:306
 #, c-format
 msgid "unrecognized argument: %s"
 msgstr "неопознанный аргумент: %s"
 
-#: bundle.c:461
+#: bundle.c:465
 msgid "Refusing to create empty bundle."
 msgstr "Отклонение создания пустого пакета."
 
-#: bundle.c:473
+#: bundle.c:475
 #, c-format
 msgid "cannot create '%s'"
 msgstr "не удалось создать «%s»"
 
-#: bundle.c:501
+#: bundle.c:500
 msgid "index-pack died"
 msgstr "критическая ошибка index-pack"
 
-#: color.c:301
+#: color.c:296
 #, c-format
 msgid "invalid color value: %.*s"
 msgstr "недопустимое значение цвета: %.*s"
 
-#: commit.c:41 sequencer.c:1614 builtin/am.c:421 builtin/am.c:465
-#: builtin/am.c:1434 builtin/am.c:2069
+#: commit.c:50 sequencer.c:2697 builtin/am.c:355 builtin/am.c:399
+#: builtin/am.c:1377 builtin/am.c:2022 builtin/replace.c:455
 #, c-format
 msgid "could not parse %s"
 msgstr "не удалось разобрать %s"
 
-#: commit.c:43
+#: commit.c:52
 #, c-format
 msgid "%s %s is not a commit!"
 msgstr "%s %s не является коммитом!"
 
-#: commit.c:1524
+#: commit.c:193
+msgid ""
+"Support for <GIT_DIR>/info/grafts is deprecated\n"
+"and will be removed in a future Git version.\n"
+"\n"
+"Please use \"git replace --convert-graft-file\"\n"
+"to convert the grafts into replace refs.\n"
+"\n"
+"Turn this message off by running\n"
+"\"git config advice.graftFileDeprecated false\""
+msgstr "Поддержка <GIT_DIR>/info/grafts устарела и будет удалена в следующих версиях Git.\n\nИспользуйте «git replace --convert-graft-file» для  конвертации сращений (grafts) на ссылки замены.\n\nЧтобы скрыть это сообщение запустите «git config advice.graftFileDeprecated false»"
+
+#: commit.c:1128
+#, c-format
+msgid "Commit %s has an untrusted GPG signature, allegedly by %s."
+msgstr "Коммит %s содержит не доверенную GPG подпись, предположительно от %s."
+
+#: commit.c:1131
+#, c-format
+msgid "Commit %s has a bad GPG signature allegedly by %s."
+msgstr "Коммит %s содержит плохую GPG подпись, предположительно от %s."
+
+#: commit.c:1134
+#, c-format
+msgid "Commit %s does not have a GPG signature."
+msgstr "Коммит %s не содержит GPG подпись."
+
+#: commit.c:1137
+#, c-format
+msgid "Commit %s has a good GPG signature by %s\n"
+msgstr "Коммит %s содержит действительную GPG подпись, от %s.\n"
+
+#: commit.c:1391
 msgid ""
 "Warning: commit message did not conform to UTF-8.\n"
 "You may want to amend it after fixing the message, or set the config\n"
 "variable i18n.commitencoding to the encoding your project uses.\n"
 msgstr "Предупреждение: сообщение коммита не соответствует UTF-8.\nВозможно, вы захотите исправить его после исправления сообщения\nили настроить опцию i18n.commitencoding и указать кодировку\nсообщений, которую использует ваш проект.\n"
 
-#: compat/obstack.c:405 compat/obstack.c:407
+#: commit-graph.c:105
+msgid "commit-graph file is too small"
+msgstr "файл commit-graph слишком маленький"
+
+#: commit-graph.c:170
+#, c-format
+msgid "commit-graph signature %X does not match signature %X"
+msgstr "подпись commit-graph файла %X не соотвествует подписи %X"
+
+#: commit-graph.c:177
+#, c-format
+msgid "commit-graph version %X does not match version %X"
+msgstr "версия commit-graph файла %X не соотвествует версии %X"
+
+#: commit-graph.c:184
+#, c-format
+msgid "commit-graph hash version %X does not match version %X"
+msgstr "версия хеш-суммы commit-graph файла %X не соответствует версии %X"
+
+#: commit-graph.c:207
+msgid "commit-graph chunk lookup table entry missing; file may be incomplete"
+msgstr "не найдена таблица расположения частей в файле commit-graph; возможно файл повреждён"
+
+#: commit-graph.c:218
+#, c-format
+msgid "commit-graph improper chunk offset %08x%08x"
+msgstr "некорректное смещение части в commit-graph файле %08x%08x"
+
+#: commit-graph.c:255
+#, c-format
+msgid "commit-graph chunk id %08x appears multiple times"
+msgstr "часть файла commit-graph с идентификатором %08x появляется несколько раз"
+
+#: commit-graph.c:390
+#, c-format
+msgid "could not find commit %s"
+msgstr "не удалось найти коммит %s"
+
+#: commit-graph.c:732 builtin/pack-objects.c:2649
+#, c-format
+msgid "unable to get type of object %s"
+msgstr "не удалось получить тип объекта %s"
+
+#: commit-graph.c:765
+msgid "Loading known commits in commit graph"
+msgstr "Загрузка известных коммитов на граф коммитов"
+
+#: commit-graph.c:781
+msgid "Expanding reachable commits in commit graph"
+msgstr "Расширение достижимых коммитов на граф коммитов"
+
+#: commit-graph.c:793
+msgid "Clearing commit marks in commit graph"
+msgstr "Очистка пометок коммитов на графе коммитов"
+
+#: commit-graph.c:813
+msgid "Computing commit graph generation numbers"
+msgstr "Вычисление номеров поколений на графе коммитов"
+
+#: commit-graph.c:930
+#, c-format
+msgid "Finding commits for commit graph in %d pack"
+msgid_plural "Finding commits for commit graph in %d packs"
+msgstr[0] "Поиск коммитов для графа коммитов в %d пакете"
+msgstr[1] "Поиск коммитов для графа коммитов в %d пакетах"
+msgstr[2] "Поиск коммитов для графа коммитов в %d пакетах"
+msgstr[3] "Поиск коммитов для графа коммитов в %d пакетах"
+
+#: commit-graph.c:943
+#, c-format
+msgid "error adding pack %s"
+msgstr "ошибка добавления пакета %s"
+
+#: commit-graph.c:945
+#, c-format
+msgid "error opening index for %s"
+msgstr "ошибка открытия индекса для %s"
+
+#: commit-graph.c:959
+#, c-format
+msgid "Finding commits for commit graph from %d ref"
+msgid_plural "Finding commits for commit graph from %d refs"
+msgstr[0] "Поиск коммитов для графа коммитов по %d ссылке"
+msgstr[1] "Поиск коммитов для графа коммитов по %d ссылкам"
+msgstr[2] "Поиск коммитов для графа коммитов по %d ссылкам"
+msgstr[3] "Поиск коммитов для графа коммитов по %d ссылкам"
+
+#: commit-graph.c:991
+msgid "Finding commits for commit graph among packed objects"
+msgstr "Поиск коммитов для графа коммитов среди упакованных объектов"
+
+#: commit-graph.c:1004
+msgid "Counting distinct commits in commit graph"
+msgstr "Вычисление количества отдельных коммитов на графе коммитов"
+
+#: commit-graph.c:1017
+#, c-format
+msgid "the commit graph format cannot write %d commits"
+msgstr "программе форматирования графа коммитов не удалось записать %d коммитов"
+
+#: commit-graph.c:1026
+msgid "Finding extra edges in commit graph"
+msgstr "Поиск дополнительных ребер на графе коммитов"
+
+#: commit-graph.c:1050
+msgid "too many commits to write graph"
+msgstr "слишком много коммитов для записи графа"
+
+#: commit-graph.c:1057 midx.c:819
+#, c-format
+msgid "unable to create leading directories of %s"
+msgstr "не удалось создать родительские каталоги для %s"
+
+#: commit-graph.c:1097
+#, c-format
+msgid "Writing out commit graph in %d pass"
+msgid_plural "Writing out commit graph in %d passes"
+msgstr[0] "Запись графа коммитов в %d проход"
+msgstr[1] "Запись графа коммитов в %d прохода"
+msgstr[2] "Запись графа коммитов в %d проходов"
+msgstr[3] "Запись графа коммитов в %d прохода"
+
+#: commit-graph.c:1162
+msgid "the commit-graph file has incorrect checksum and is likely corrupt"
+msgstr "файл commit-graph содержит неправильную контрольную сумму и скорее всего поврежден"
+
+#: commit-graph.c:1172
+#, c-format
+msgid "commit-graph has incorrect OID order: %s then %s"
+msgstr "файл commit-graph содержит неправильный порядок OID: %s, а затем %s"
+
+#: commit-graph.c:1182 commit-graph.c:1197
+#, c-format
+msgid "commit-graph has incorrect fanout value: fanout[%d] = %u != %u"
+msgstr "файл commit-graph содержит неправильное значение fanout: fanout[%d] = %u != %u"
+
+#: commit-graph.c:1189
+#, c-format
+msgid "failed to parse commit %s from commit-graph"
+msgstr "не удалось разобрать коммит %s из файла commit-graph"
+
+#: commit-graph.c:1206
+msgid "Verifying commits in commit graph"
+msgstr "Проверка коммитов на графе коммитов"
+
+#: commit-graph.c:1219
+#, c-format
+msgid "failed to parse commit %s from object database for commit-graph"
+msgstr "не удалось разобрать коммит %s из базы объектов файла commit-graph"
+
+#: commit-graph.c:1226
+#, c-format
+msgid "root tree OID for commit %s in commit-graph is %s != %s"
+msgstr " в файле commit-graph OID корня дерева для коммита %s является %s != %s"
+
+#: commit-graph.c:1236
+#, c-format
+msgid "commit-graph parent list for commit %s is too long"
+msgstr "слишком большой список родителей файле commit-graph для коммита %s"
+
+#: commit-graph.c:1242
+#, c-format
+msgid "commit-graph parent for %s is %s != %s"
+msgstr "в файле commit-graph родитель для %s является %s != %s"
+
+#: commit-graph.c:1255
+#, c-format
+msgid "commit-graph parent list for commit %s terminates early"
+msgstr "в файле commit-graph список родителей для коммита %s закончился слишком рано"
+
+#: commit-graph.c:1260
+#, c-format
+msgid ""
+"commit-graph has generation number zero for commit %s, but non-zero "
+"elsewhere"
+msgstr "в файле commit-graph содержится нулевой номер поколения для коммита %s, но ненулевой в остальных случаях"
+
+#: commit-graph.c:1264
+#, c-format
+msgid ""
+"commit-graph has non-zero generation number for commit %s, but zero "
+"elsewhere"
+msgstr "в файле commit-graph содержится ненулевой номер поколения для коммита %s, но нулевой в остальных случаях"
+
+#: commit-graph.c:1279
+#, c-format
+msgid "commit-graph generation for commit %s is %u != %u"
+msgstr "в файле commit-graph номер поколения для коммита %s является %u != %u"
+
+#: commit-graph.c:1285
+#, c-format
+msgid "commit date for commit %s in commit-graph is %<PRIuMAX> != %<PRIuMAX>"
+msgstr "в файле commit-graph дата коммита %s является %<PRIuMAX> != %<PRIuMAX>"
+
+#: compat/obstack.c:406 compat/obstack.c:408
 msgid "memory exhausted"
 msgstr "память исчерпана"
 
-#: config.c:186
+#: config.c:123
+#, c-format
+msgid ""
+"exceeded maximum include depth (%d) while including\n"
+"\t%s\n"
+"from\n"
+"\t%s\n"
+"This might be due to circular includes."
+msgstr ""
+
+#: config.c:139
+#, c-format
+msgid "could not expand include path '%s'"
+msgstr "не удалось раскрыть путь включения «%s»"
+
+#: config.c:150
+msgid "relative config includes must come from files"
+msgstr "относительные включения конфигурации должны исходить из файлов"
+
+#: config.c:190
 msgid "relative config include conditionals must come from files"
 msgstr "относительные условные включения конфигурации должны исходить из файлов"
 
-#: config.c:720
+#: config.c:348
+#, c-format
+msgid "key does not contain a section: %s"
+msgstr ""
+
+#: config.c:354
+#, c-format
+msgid "key does not contain variable name: %s"
+msgstr ""
+
+#: config.c:378 sequencer.c:2459
+#, c-format
+msgid "invalid key: %s"
+msgstr "недействительный ключ: %s"
+
+#: config.c:384
+#, c-format
+msgid "invalid key (newline): %s"
+msgstr ""
+
+#: config.c:420 config.c:432
+#, c-format
+msgid "bogus config parameter: %s"
+msgstr ""
+
+#: config.c:467
+#, c-format
+msgid "bogus format in %s"
+msgstr ""
+
+#: config.c:793
 #, c-format
 msgid "bad config line %d in blob %s"
 msgstr "ошибка в %d строке двоичного объекта %s"
 
-#: config.c:724
+#: config.c:797
 #, c-format
 msgid "bad config line %d in file %s"
 msgstr "ошибка в %d строке файла %s"
 
-#: config.c:728
+#: config.c:801
 #, c-format
 msgid "bad config line %d in standard input"
 msgstr "ошибка в %d строке стандартного ввода"
 
-#: config.c:732
+#: config.c:805
 #, c-format
 msgid "bad config line %d in submodule-blob %s"
 msgstr "ошибка в %d строке двоичного объекта подмодуля %s"
 
-#: config.c:736
+#: config.c:809
 #, c-format
 msgid "bad config line %d in command line %s"
 msgstr "ошибка в %d строке коммандной строки %s"
 
-#: config.c:740
+#: config.c:813
 #, c-format
 msgid "bad config line %d in %s"
 msgstr "ошибка в %d строке в %s"
 
-#: config.c:868
+#: config.c:952
 msgid "out of range"
 msgstr "вне диапазона"
 
-#: config.c:868
+#: config.c:952
 msgid "invalid unit"
 msgstr "неправильное число"
 
-#: config.c:874
+#: config.c:958
 #, c-format
 msgid "bad numeric config value '%s' for '%s': %s"
 msgstr "неправильное числовое значение «%s» для «%s»: %s"
 
-#: config.c:879
+#: config.c:963
 #, c-format
 msgid "bad numeric config value '%s' for '%s' in blob %s: %s"
 msgstr "неправильное числовое значение «%s» для «%s» в двоичном объекте %s: %s"
 
-#: config.c:882
+#: config.c:966
 #, c-format
 msgid "bad numeric config value '%s' for '%s' in file %s: %s"
 msgstr "неправильное числовое значение «%s» для «%s» в файле %s: %s"
 
-#: config.c:885
+#: config.c:969
 #, c-format
 msgid "bad numeric config value '%s' for '%s' in standard input: %s"
 msgstr "неправильное числовое значение «%s» для «%s» на стандартном вводе: %s"
 
-#: config.c:888
+#: config.c:972
 #, c-format
 msgid "bad numeric config value '%s' for '%s' in submodule-blob %s: %s"
 msgstr "неправильное числовое значение «%s» для «%s» в двоичном объекте подмодуля %s: %s"
 
-#: config.c:891
+#: config.c:975
 #, c-format
 msgid "bad numeric config value '%s' for '%s' in command line %s: %s"
 msgstr "неправильное числовое значение «%s» для «%s» на коммандной строке %s: %s"
 
-#: config.c:894
+#: config.c:978
 #, c-format
 msgid "bad numeric config value '%s' for '%s' in %s: %s"
 msgstr "неправильное числовое значение «%s» для «%s» в %s: %s"
 
-#: config.c:989
+#: config.c:1073
 #, c-format
 msgid "failed to expand user dir in: '%s'"
 msgstr "сбой разворачивания пути каталога пользователя: «%s»"
 
-#: config.c:998
+#: config.c:1082
 #, c-format
 msgid "'%s' for '%s' is not a valid timestamp"
 msgstr "«%s» для «%s» не является допустимой меткой даты/времени"
 
-#: config.c:1094 config.c:1105
+#: config.c:1173
+#, c-format
+msgid "abbrev length out of range: %d"
+msgstr ""
+
+#: config.c:1187 config.c:1198
 #, c-format
 msgid "bad zlib compression level %d"
 msgstr "неправильный уровень сжатия zlib %d"
 
-#: config.c:1222
+#: config.c:1290
+msgid "core.commentChar should only be one character"
+msgstr ""
+
+#: config.c:1323
 #, c-format
 msgid "invalid mode for object creation: %s"
 msgstr "недопустимый режим создания объекта: %s"
 
-#: config.c:1378
+#: config.c:1395
+#, c-format
+msgid "malformed value for %s"
+msgstr ""
+
+#: config.c:1421
+#, c-format
+msgid "malformed value for %s: %s"
+msgstr ""
+
+#: config.c:1422
+msgid "must be one of nothing, matching, simple, upstream or current"
+msgstr ""
+
+#: config.c:1483 builtin/pack-objects.c:3397
 #, c-format
 msgid "bad pack compression level %d"
 msgstr "неправильный уровень сжатия пакета %d"
 
-#: config.c:1574
+#: config.c:1604
+#, c-format
+msgid "unable to load config blob object '%s'"
+msgstr ""
+
+#: config.c:1607
+#, c-format
+msgid "reference '%s' does not point to a blob"
+msgstr ""
+
+#: config.c:1624
+#, c-format
+msgid "unable to resolve config blob '%s'"
+msgstr ""
+
+#: config.c:1654
+#, c-format
+msgid "failed to parse %s"
+msgstr ""
+
+#: config.c:1710
 msgid "unable to parse command-line config"
 msgstr "не удалось разобрать конфигурацию из командной строки"
 
-#: config.c:1906
+#: config.c:2059
 msgid "unknown error occurred while reading the configuration files"
 msgstr "произошла неизвестная ошибка при чтении файлов конфигурации"
 
-#: config.c:2093
+#: config.c:2229
 #, c-format
 msgid "Invalid %s: '%s'"
 msgstr "Недействительный %s: «%s»"
 
-#: config.c:2136
+#: config.c:2272
 #, c-format
 msgid "unknown core.untrackedCache value '%s'; using 'keep' default value"
 msgstr "неизвестное значение «%s» для core.untrackedCache; использую стандартное значение «keep»"
 
-#: config.c:2162
+#: config.c:2298
 #, c-format
 msgid "splitIndex.maxPercentChange value '%d' should be between 0 and 100"
 msgstr "значение «%d» для splitIndex.maxPercentChange должно быть от 0 до 100"
 
-#: config.c:2187
+#: config.c:2344
 #, c-format
 msgid "unable to parse '%s' from command-line config"
 msgstr "не удалось разобрать «%s» в конфигурации из командной строки"
 
-#: config.c:2189
+#: config.c:2346
 #, c-format
 msgid "bad config variable '%s' in file '%s' at line %d"
 msgstr "неправильная переменная конфигурации «%s» в файле «%s» на строке %d"
 
-#: config.c:2248
+#: config.c:2427
+#, c-format
+msgid "invalid section name '%s'"
+msgstr ""
+
+#: config.c:2459
 #, c-format
 msgid "%s has multiple values"
 msgstr "%s имеет несколько значений"
 
-#: config.c:2591 config.c:2808
+#: config.c:2488
+#, c-format
+msgid "failed to write new configuration file %s"
+msgstr ""
+
+#: config.c:2740 config.c:3064
+#, c-format
+msgid "could not lock config file %s"
+msgstr ""
+
+#: config.c:2751
+#, c-format
+msgid "opening %s"
+msgstr ""
+
+#: config.c:2786 builtin/config.c:328
+#, c-format
+msgid "invalid pattern: %s"
+msgstr ""
+
+#: config.c:2811
+#, c-format
+msgid "invalid config file %s"
+msgstr ""
+
+#: config.c:2824 config.c:3077
 #, c-format
 msgid "fstat on %s failed"
 msgstr "сбой при выполнении fstat на файле %s"
 
-#: config.c:2698
+#: config.c:2835
+#, c-format
+msgid "unable to mmap '%s'"
+msgstr ""
+
+#: config.c:2844 config.c:3082
+#, c-format
+msgid "chmod on %s failed"
+msgstr ""
+
+#: config.c:2929 config.c:3179
+#, c-format
+msgid "could not write config file %s"
+msgstr ""
+
+#: config.c:2963
 #, c-format
 msgid "could not set '%s' to '%s'"
 msgstr "не удалось установить «%s» в «%s»"
 
-#: config.c:2700 builtin/remote.c:776
+#: config.c:2965 builtin/remote.c:782
 #, c-format
 msgid "could not unset '%s'"
 msgstr "не удалось сбросить значение для «%s»"
 
-#: connect.c:52
-msgid "The remote end hung up upon initial contact"
-msgstr "Внешний сервер отсоединился до начала сеанса связи"
+#: config.c:3055
+#, c-format
+msgid "invalid section name: %s"
+msgstr ""
+
+#: config.c:3222
+#, c-format
+msgid "missing value for '%s'"
+msgstr ""
+
+#: connect.c:61
+msgid "the remote end hung up upon initial contact"
+msgstr ""
 
-#: connect.c:54
+#: connect.c:63
 msgid ""
 "Could not read from remote repository.\n"
 "\n"
@@ -1378,60 +1844,292 @@ msgid ""
 "and the repository exists."
 msgstr "Не удалось прочитать из внешнего репозитория.\n\nУдостоверьтесь, что у вас есть необходимые права доступа\nи репозиторий существует."
 
-#: connected.c:64 builtin/fsck.c:183 builtin/prune.c:141
-msgid "Checking connectivity"
-msgstr "Проверка соединения"
-
-#: connected.c:76
-msgid "Could not run 'git rev-list'"
-msgstr "Не удалось запустить «git rev-list»"
+#: connect.c:81
+#, c-format
+msgid "server doesn't support '%s'"
+msgstr ""
 
-#: connected.c:96
-msgid "failed write to rev-list"
-msgstr "сбой записи в rev-list"
+#: connect.c:103
+#, c-format
+msgid "server doesn't support feature '%s'"
+msgstr ""
 
-#: connected.c:103
-msgid "failed to close rev-list's stdin"
-msgstr "сбой закрытия стандартного ввода у rev-list"
+#: connect.c:114
+msgid "expected flush after capabilities"
+msgstr ""
 
-#: convert.c:205
+#: connect.c:233
 #, c-format
-msgid ""
-"CRLF will be replaced by LF in %s.\n"
-"The file will have its original line endings in your working directory."
-msgstr "CRLF будет заменен на LF в %s.\nФайл будет иметь свои оригинальные концы строк в вашей рабочей копии."
+msgid "ignoring capabilities after first line '%s'"
+msgstr ""
 
-#: convert.c:209
-#, c-format
-msgid "CRLF would be replaced by LF in %s."
-msgstr "CRLF будет заменен на LF в %s."
+#: connect.c:252
+msgid "protocol error: unexpected capabilities^{}"
+msgstr ""
 
-#: convert.c:215
+#: connect.c:273
 #, c-format
-msgid ""
-"LF will be replaced by CRLF in %s.\n"
-"The file will have its original line endings in your working directory."
-msgstr "LF будет заменен на CRLF в %s.\nФайл будет иметь свои оригинальные концы строк в вашей рабочей копии."
+msgid "protocol error: expected shallow sha-1, got '%s'"
+msgstr ""
 
-#: convert.c:219
-#, c-format
-msgid "LF would be replaced by CRLF in %s"
-msgstr "LF будет заменен на CRLF в %s"
+#: connect.c:275
+msgid "repository on the other end cannot be shallow"
+msgstr ""
 
-#: date.c:116
-msgid "in the future"
-msgstr "в будущем"
+#: connect.c:313
+msgid "invalid packet"
+msgstr ""
 
-#: date.c:122
+#: connect.c:333
 #, c-format
-msgid "%<PRIuMAX> second ago"
+msgid "protocol error: unexpected '%s'"
+msgstr ""
+
+#: connect.c:441
+#, c-format
+msgid "invalid ls-refs response: %s"
+msgstr ""
+
+#: connect.c:445
+msgid "expected flush after ref listing"
+msgstr ""
+
+#: connect.c:544
+#, c-format
+msgid "protocol '%s' is not supported"
+msgstr ""
+
+#: connect.c:595
+msgid "unable to set SO_KEEPALIVE on socket"
+msgstr ""
+
+#: connect.c:635 connect.c:698
+#, c-format
+msgid "Looking up %s ... "
+msgstr ""
+
+#: connect.c:639
+#, c-format
+msgid "unable to look up %s (port %s) (%s)"
+msgstr ""
+
+#. TRANSLATORS: this is the end of "Looking up %s ... "
+#: connect.c:643 connect.c:714
+#, c-format
+msgid ""
+"done.\n"
+"Connecting to %s (port %s) ... "
+msgstr ""
+
+#: connect.c:665 connect.c:742
+#, c-format
+msgid ""
+"unable to connect to %s:\n"
+"%s"
+msgstr ""
+
+#. TRANSLATORS: this is the end of "Connecting to %s (port %s) ... "
+#: connect.c:671 connect.c:748
+msgid "done."
+msgstr ""
+
+#: connect.c:702
+#, c-format
+msgid "unable to look up %s (%s)"
+msgstr ""
+
+#: connect.c:708
+#, c-format
+msgid "unknown port %s"
+msgstr ""
+
+#: connect.c:845 connect.c:1171
+#, c-format
+msgid "strange hostname '%s' blocked"
+msgstr ""
+
+#: connect.c:847
+#, c-format
+msgid "strange port '%s' blocked"
+msgstr ""
+
+#: connect.c:857
+#, c-format
+msgid "cannot start proxy %s"
+msgstr ""
+
+#: connect.c:924
+msgid "no path specified; see 'git help pull' for valid url syntax"
+msgstr ""
+
+#: connect.c:1119
+msgid "ssh variant 'simple' does not support -4"
+msgstr ""
+
+#: connect.c:1131
+msgid "ssh variant 'simple' does not support -6"
+msgstr ""
+
+#: connect.c:1148
+msgid "ssh variant 'simple' does not support setting port"
+msgstr ""
+
+#: connect.c:1260
+#, c-format
+msgid "strange pathname '%s' blocked"
+msgstr ""
+
+#: connect.c:1307
+msgid "unable to fork"
+msgstr ""
+
+#: connected.c:85 builtin/fsck.c:221 builtin/prune.c:43
+msgid "Checking connectivity"
+msgstr "Проверка соединения"
+
+#: connected.c:97
+msgid "Could not run 'git rev-list'"
+msgstr "Не удалось запустить «git rev-list»"
+
+#: connected.c:117
+msgid "failed write to rev-list"
+msgstr "сбой записи в rev-list"
+
+#: connected.c:124
+msgid "failed to close rev-list's stdin"
+msgstr "сбой закрытия стандартного ввода у rev-list"
+
+#: convert.c:193
+#, c-format
+msgid "illegal crlf_action %d"
+msgstr ""
+
+#: convert.c:206
+#, c-format
+msgid "CRLF would be replaced by LF in %s"
+msgstr ""
+
+#: convert.c:208
+#, c-format
+msgid ""
+"CRLF will be replaced by LF in %s.\n"
+"The file will have its original line endings in your working directory"
+msgstr ""
+
+#: convert.c:216
+#, c-format
+msgid "LF would be replaced by CRLF in %s"
+msgstr "LF будет заменен на CRLF в %s"
+
+#: convert.c:218
+#, c-format
+msgid ""
+"LF will be replaced by CRLF in %s.\n"
+"The file will have its original line endings in your working directory"
+msgstr ""
+
+#: convert.c:279
+#, c-format
+msgid "BOM is prohibited in '%s' if encoded as %s"
+msgstr "BOM запрещен в «%s», если кодируется как %s"
+
+#: convert.c:286
+#, c-format
+msgid ""
+"The file '%s' contains a byte order mark (BOM). Please use UTF-%s as "
+"working-tree-encoding."
+msgstr "Файл «%s» содержит маркер последовательности байтов (BOM). Используйте UTF-%s как кодировку рабочего каталога."
+
+#: convert.c:304
+#, c-format
+msgid "BOM is required in '%s' if encoded as %s"
+msgstr "BOM требуется в «%s», если кодируется как %s"
+
+#: convert.c:306
+#, c-format
+msgid ""
+"The file '%s' is missing a byte order mark (BOM). Please use UTF-%sBE or "
+"UTF-%sLE (depending on the byte order) as working-tree-encoding."
+msgstr "Файл «%s» не содержит маркер последовательности байтов (BOM).  Используйте UTF-%sBE или UTF-%sLE (в зависимости от порядка байтов) как кодировку рабочего каталога."
+
+#: convert.c:424 convert.c:495
+#, c-format
+msgid "failed to encode '%s' from %s to %s"
+msgstr "не удалось перекодировать «%s» из %s в %s"
+
+#: convert.c:467
+#, c-format
+msgid "encoding '%s' from %s to %s and back is not the same"
+msgstr "перекодирование «%s» из %s в %s и обратно не одно и то же"
+
+#: convert.c:673
+#, c-format
+msgid "cannot fork to run external filter '%s'"
+msgstr ""
+
+#: convert.c:693
+#, c-format
+msgid "cannot feed the input to external filter '%s'"
+msgstr ""
+
+#: convert.c:700
+#, c-format
+msgid "external filter '%s' failed %d"
+msgstr ""
+
+#: convert.c:735 convert.c:738
+#, c-format
+msgid "read from external filter '%s' failed"
+msgstr ""
+
+#: convert.c:741 convert.c:796
+#, c-format
+msgid "external filter '%s' failed"
+msgstr ""
+
+#: convert.c:844
+msgid "unexpected filter type"
+msgstr ""
+
+#: convert.c:855
+msgid "path name too long for external filter"
+msgstr ""
+
+#: convert.c:929
+#, c-format
+msgid ""
+"external filter '%s' is not available anymore although not all paths have "
+"been filtered"
+msgstr ""
+
+#: convert.c:1228
+msgid "true/false are no valid working-tree-encodings"
+msgstr "true/false не является допустимым значением для working-tree-encoding"
+
+#: convert.c:1398 convert.c:1432
+#, c-format
+msgid "%s: clean filter '%s' failed"
+msgstr ""
+
+#: convert.c:1476
+#, c-format
+msgid "%s: smudge filter %s failed"
+msgstr ""
+
+#: date.c:137
+msgid "in the future"
+msgstr "в будущем"
+
+#: date.c:143
+#, c-format
+msgid "%<PRIuMAX> second ago"
 msgid_plural "%<PRIuMAX> seconds ago"
 msgstr[0] "%<PRIuMAX> секунда назад"
 msgstr[1] "%<PRIuMAX> секунды назад"
 msgstr[2] "%<PRIuMAX> секунд назад"
 msgstr[3] "%<PRIuMAX> секунды назад"
 
-#: date.c:129
+#: date.c:150
 #, c-format
 msgid "%<PRIuMAX> minute ago"
 msgid_plural "%<PRIuMAX> minutes ago"
@@ -1440,7 +2138,7 @@ msgstr[1] "%<PRIuMAX> минуты на
 msgstr[2] "%<PRIuMAX> минут назад"
 msgstr[3] "%<PRIuMAX> минуты назад"
 
-#: date.c:136
+#: date.c:157
 #, c-format
 msgid "%<PRIuMAX> hour ago"
 msgid_plural "%<PRIuMAX> hours ago"
@@ -1449,7 +2147,7 @@ msgstr[1] "%<PRIuMAX> часа наза
 msgstr[2] "%<PRIuMAX> часов назад"
 msgstr[3] "%<PRIuMAX> часа назад"
 
-#: date.c:143
+#: date.c:164
 #, c-format
 msgid "%<PRIuMAX> day ago"
 msgid_plural "%<PRIuMAX> days ago"
@@ -1458,7 +2156,7 @@ msgstr[1] "%<PRIuMAX> дня назад"
 msgstr[2] "%<PRIuMAX> дней назад"
 msgstr[3] "%<PRIuMAX> дня назад"
 
-#: date.c:149
+#: date.c:170
 #, c-format
 msgid "%<PRIuMAX> week ago"
 msgid_plural "%<PRIuMAX> weeks ago"
@@ -1467,7 +2165,7 @@ msgstr[1] "%<PRIuMAX> недели на
 msgstr[2] "%<PRIuMAX> недель назад"
 msgstr[3] "%<PRIuMAX> недели назад"
 
-#: date.c:156
+#: date.c:177
 #, c-format
 msgid "%<PRIuMAX> month ago"
 msgid_plural "%<PRIuMAX> months ago"
@@ -1476,7 +2174,7 @@ msgstr[1] "%<PRIuMAX> месяца на
 msgstr[2] "%<PRIuMAX> месяцев назад"
 msgstr[3] "%<PRIuMAX> месяца назад"
 
-#: date.c:167
+#: date.c:188
 #, c-format
 msgid "%<PRIuMAX> year"
 msgid_plural "%<PRIuMAX> years"
@@ -1486,7 +2184,7 @@ msgstr[2] "%<PRIuMAX> лет"
 msgstr[3] "%<PRIuMAX> года"
 
 #. TRANSLATORS: "%s" is "<n> years"
-#: date.c:170
+#: date.c:191
 #, c-format
 msgid "%s, %<PRIuMAX> month ago"
 msgid_plural "%s, %<PRIuMAX> months ago"
@@ -1495,7 +2193,7 @@ msgstr[1] "%s, %<PRIuMAX> месяца 
 msgstr[2] "%s, %<PRIuMAX> месяцев назад"
 msgstr[3] "%s, %<PRIuMAX> месяца назад"
 
-#: date.c:175 date.c:180
+#: date.c:196 date.c:201
 #, c-format
 msgid "%<PRIuMAX> year ago"
 msgid_plural "%<PRIuMAX> years ago"
@@ -1504,9872 +2202,14050 @@ msgstr[1] "%<PRIuMAX> года наза
 msgstr[2] "%<PRIuMAX> лет назад"
 msgstr[3] "%<PRIuMAX> года назад"
 
+#: delta-islands.c:272
+msgid "Propagating island marks"
+msgstr ""
+
+#: delta-islands.c:290
+#, c-format
+msgid "bad tree object %s"
+msgstr ""
+
+#: delta-islands.c:334
+#, c-format
+msgid "failed to load island regex for '%s': %s"
+msgstr ""
+
+#: delta-islands.c:390
+#, c-format
+msgid "island regex from config has too many capture groups (max=%d)"
+msgstr ""
+
+#: delta-islands.c:466
+#, c-format
+msgid "Marked %d islands, done.\n"
+msgstr ""
+
 #: diffcore-order.c:24
 #, c-format
 msgid "failed to read orderfile '%s'"
 msgstr "сбой чтения orderfile «%s»"
 
-#: diffcore-rename.c:535
+#: diffcore-rename.c:544
 msgid "Performing inexact rename detection"
 msgstr "Выполняется неточное определение переименования"
 
-#: diff.c:74
-#, c-format
-msgid "option '%s' requires a value"
-msgstr "параметр «%s» требует указания значения"
+#: diff-no-index.c:238
+msgid "git diff --no-index [<options>] <path> <path>"
+msgstr ""
+
+#: diff-no-index.c:263
+msgid ""
+"Not a git repository. Use --no-index to compare two paths outside a working "
+"tree"
+msgstr ""
 
-#: diff.c:152
+#: diff.c:155
 #, c-format
 msgid "  Failed to parse dirstat cut-off percentage '%s'\n"
 msgstr "  Сбой разбора величины среза (cut-off) у dirstat «%s»\n"
 
-#: diff.c:157
+#: diff.c:160
 #, c-format
 msgid "  Unknown dirstat parameter '%s'\n"
 msgstr "Неизвестный параметр dirstat: «%s»\n"
 
-#: diff.c:281
+#: diff.c:296
+msgid ""
+"color moved setting must be one of 'no', 'default', 'blocks', 'zebra', "
+"'dimmed-zebra', 'plain'"
+msgstr ""
+
+#: diff.c:324
+#, c-format
+msgid ""
+"unknown color-moved-ws mode '%s', possible values are 'ignore-space-change',"
+" 'ignore-space-at-eol', 'ignore-all-space', 'allow-indentation-change'"
+msgstr ""
+
+#: diff.c:332
 msgid ""
-"color moved setting must be one of 'no', 'default', 'zebra', 'dimmed_zebra',"
-" 'plain'"
-msgstr "значение настройки цвета для перемещённых строк должно быть одно из «no» «default», «zebra», «dimmed_zebra», «plain»"
+"color-moved-ws: allow-indentation-change cannot be combined with other "
+"whitespace modes"
+msgstr ""
 
-#: diff.c:341
+#: diff.c:405
 #, c-format
 msgid "Unknown value for 'diff.submodule' config variable: '%s'"
 msgstr "Неизвестное значения для переменной «diff.submodule»: «%s»"
 
-#: diff.c:401
+#: diff.c:465
 #, c-format
 msgid ""
 "Found errors in 'diff.dirstat' config variable:\n"
 "%s"
 msgstr "Найдены ошибки в переменной «diff.dirstat»:\n%s"
 
-#: diff.c:3799
+#: diff.c:4210
 #, c-format
 msgid "external diff died, stopping at %s"
 msgstr "критическая ошибка при внешнем сравнении, останов на %s"
 
-#: diff.c:4127
+#: diff.c:4555
 msgid "--name-only, --name-status, --check and -s are mutually exclusive"
 msgstr "--name-only, --name-status, --check и -s нельзя использовать одновременно"
 
-#: diff.c:4215
+#: diff.c:4558
+msgid "-G, -S and --find-object are mutually exclusive"
+msgstr "-G, -S и --find-object нельзя использовать одновременно"
+
+#: diff.c:4636
 msgid "--follow requires exactly one pathspec"
 msgstr "--follow требует ровно одного спецификатора пути"
 
-#: diff.c:4381
+#: diff.c:4684
+#, c-format
+msgid "invalid --stat value: %s"
+msgstr ""
+
+#: diff.c:4689 diff.c:4694 diff.c:4699 diff.c:4704 diff.c:5217
+#: parse-options.c:199 parse-options.c:203
+#, c-format
+msgid "%s expects a numerical value"
+msgstr ""
+
+#: diff.c:4721
 #, c-format
 msgid ""
 "Failed to parse --dirstat/-X option parameter:\n"
 "%s"
 msgstr "Сбой разбора параметра опции --dirstat/-X :\n%s"
 
-#: diff.c:4395
+#: diff.c:4806
 #, c-format
-msgid "Failed to parse --submodule option parameter: '%s'"
-msgstr "Сбой разбора параметра опции --submodule: «%s»"
-
-#: diff.c:5446
-msgid "inexact rename detection was skipped due to too many files."
-msgstr "неточное определение переименования было пропущено из-за слишком большого количества файлов."
-
-#: diff.c:5449
-msgid "only found copies from modified paths due to too many files."
-msgstr "найдены только копии из измененных путей из-за слишком большого количества файлов."
+msgid "unknown change class '%c' in --diff-filter=%s"
+msgstr ""
 
-#: diff.c:5452
+#: diff.c:4830
 #, c-format
-msgid ""
-"you may want to set your %s variable to at least %d and retry the command."
-msgstr "возможно вы захотите установить переменную %s в как минимум значение %d и повторить вызов команды."
-
-#: dir.c:2100
-msgid "failed to get kernel name and information"
-msgstr "не удалось получить имя ядра и информацию"
-
-#: dir.c:2219
-msgid "Untracked cache is disabled on this system or location."
-msgstr "Кэш неотслеживаемых файлов отключен на этой системе или в этом месте."
+msgid "unknown value after ws-error-highlight=%.*s"
+msgstr ""
 
-#: dir.c:3002 dir.c:3007
+#: diff.c:4844
 #, c-format
-msgid "could not create directories for %s"
-msgstr "не удалось создать каталоги для %s"
+msgid "unable to resolve '%s'"
+msgstr ""
 
-#: dir.c:3032
+#: diff.c:4894 diff.c:4900
 #, c-format
-msgid "could not migrate git directory from '%s' to '%s'"
-msgstr "не удалось переместить каталог git с «%s» в «%s»"
+msgid "%s expects <n>/<m> form"
+msgstr ""
 
-#: editor.c:61
+#: diff.c:4912
 #, c-format
-msgid "hint: Waiting for your editor to close the file...%c"
-msgstr "подсказка: Ожидание, пока вы закроете редактор с файлом…%c"
+msgid "%s expects a character, got '%s'"
+msgstr ""
 
-#: entry.c:177
-msgid "Filtering content"
-msgstr "Фильтруется содержимое"
+#: diff.c:4933
+#, c-format
+msgid "bad --color-moved argument: %s"
+msgstr ""
 
-#: entry.c:435
+#: diff.c:4952
 #, c-format
-msgid "could not stat file '%s'"
-msgstr "не удалось выполнить stat для файла «%s»"
+msgid "invalid mode '%s' in --color-moved-ws"
+msgstr ""
 
-#: fetch-pack.c:252
-msgid "git fetch-pack: expected shallow list"
-msgstr "git fetch-pack: ожидается передача списка для получение части"
+#: diff.c:4992
+msgid "option diff-algorithm accepts \"myers\", \"minimal\", \"patience\" and \"histogram\""
+msgstr ""
 
-#: fetch-pack.c:264
-msgid "git fetch-pack: expected ACK/NAK, got EOF"
-msgstr "git fetch-pack: ожидается ACK/NAK, а получено EOF"
+#: diff.c:5028 diff.c:5048
+#, c-format
+msgid "invalid argument to %s"
+msgstr ""
 
-#: fetch-pack.c:283 builtin/archive.c:63
+#: diff.c:5186
 #, c-format
-msgid "remote error: %s"
-msgstr "ошибка внешнего репозитория: %s"
+msgid "failed to parse --submodule option parameter: '%s'"
+msgstr ""
 
-#: fetch-pack.c:284
+#: diff.c:5242
 #, c-format
-msgid "git fetch-pack: expected ACK/NAK, got '%s'"
-msgstr "git fetch-pack: ожидается ACK/NAK, а получено «%s»"
+msgid "bad --word-diff argument: %s"
+msgstr ""
 
-#: fetch-pack.c:336
-msgid "--stateless-rpc requires multi_ack_detailed"
-msgstr "--stateless-rpc требует multi_ack_detailed"
+#: diff.c:5265
+msgid "Diff output format options"
+msgstr ""
 
-#: fetch-pack.c:422
-#, c-format
-msgid "invalid shallow line: %s"
-msgstr "неправильная строка частичного получения: %s"
+#: diff.c:5267 diff.c:5273
+msgid "generate patch"
+msgstr ""
 
-#: fetch-pack.c:428
-#, c-format
-msgid "invalid unshallow line: %s"
-msgstr "неправильная строка полного получения: %s"
+#: diff.c:5270 builtin/log.c:167
+msgid "suppress diff output"
+msgstr "не выводить список изменений"
 
-#: fetch-pack.c:430
-#, c-format
-msgid "object not found: %s"
-msgstr "объект не найден: %s"
+#: diff.c:5275 diff.c:5389 diff.c:5396
+msgid "<n>"
+msgstr ""
 
-#: fetch-pack.c:433
-#, c-format
-msgid "error in object: %s"
-msgstr "ошибка в объекте: %s"
+#: diff.c:5276 diff.c:5279
+msgid "generate diffs with <n> lines context"
+msgstr ""
 
-#: fetch-pack.c:435
-#, c-format
-msgid "no shallow found: %s"
-msgstr "частичный клон не найден: %s"
+#: diff.c:5281
+msgid "generate the diff in raw format"
+msgstr ""
 
-#: fetch-pack.c:438
-#, c-format
-msgid "expected shallow/unshallow, got %s"
-msgstr "ожидалось shallow/unshallow, а получено %s"
+#: diff.c:5284
+msgid "synonym for '-p --raw'"
+msgstr ""
 
-#: fetch-pack.c:477
-#, c-format
-msgid "got %s %d %s"
-msgstr "получено %s %d %s"
+#: diff.c:5288
+msgid "synonym for '-p --stat'"
+msgstr ""
 
-#: fetch-pack.c:491
-#, c-format
-msgid "invalid commit %s"
-msgstr "недопустимый коммит %s"
+#: diff.c:5292
+msgid "machine friendly --stat"
+msgstr ""
 
-#: fetch-pack.c:524
-msgid "giving up"
-msgstr "останавливаю дальнейшие попытки"
+#: diff.c:5295
+msgid "output only the last line of --stat"
+msgstr ""
 
-#: fetch-pack.c:534 progress.c:229
-msgid "done"
-msgstr "готово"
+#: diff.c:5297 diff.c:5305
+msgid "<param1,param2>..."
+msgstr ""
 
-#: fetch-pack.c:546
-#, c-format
-msgid "got %s (%d) %s"
-msgstr "получено %s (%d) %s"
+#: diff.c:5298
+msgid ""
+"output the distribution of relative amount of changes for each sub-directory"
+msgstr ""
 
-#: fetch-pack.c:592
-#, c-format
-msgid "Marking %s as complete"
-msgstr "Помечаю %s как завершенный"
+#: diff.c:5302
+msgid "synonym for --dirstat=cumulative"
+msgstr ""
 
-#: fetch-pack.c:777
-#, c-format
-msgid "already have %s (%s)"
-msgstr "уже есть %s (%s)"
+#: diff.c:5306
+msgid "synonym for --dirstat=files,param1,param2..."
+msgstr ""
 
-#: fetch-pack.c:815
-msgid "fetch-pack: unable to fork off sideband demultiplexer"
-msgstr "fetch-pack: не удалось запустить программу разбора данных"
+#: diff.c:5310
+msgid "warn if changes introduce conflict markers or whitespace errors"
+msgstr ""
 
-#: fetch-pack.c:823
-msgid "protocol error: bad pack header"
-msgstr "ошибка протокола: неправильный заголовок потока"
+#: diff.c:5313
+msgid "condensed summary such as creations, renames and mode changes"
+msgstr "краткая сводка изменений, вроде созданий, переименований или изменений режима доступа"
 
-#: fetch-pack.c:879
-#, c-format
-msgid "fetch-pack: unable to fork off %s"
-msgstr "fetch-pack: не удалось запустить программу %s"
+#: diff.c:5316
+msgid "show only names of changed files"
+msgstr ""
 
-#: fetch-pack.c:895
-#, c-format
-msgid "%s failed"
-msgstr "%s завершен с ошибкой"
+#: diff.c:5319
+msgid "show only names and status of changed files"
+msgstr ""
 
-#: fetch-pack.c:897
-msgid "error in sideband demultiplexer"
-msgstr "произошла  ошибка в  программе разбора данных"
+#: diff.c:5321
+msgid "<width>[,<name-width>[,<count>]]"
+msgstr ""
 
-#: fetch-pack.c:924
-msgid "Server does not support shallow clients"
-msgstr "Сервер не поддерживает клиентов с частичным клонированием"
+#: diff.c:5322
+msgid "generate diffstat"
+msgstr ""
 
-#: fetch-pack.c:928
-msgid "Server supports multi_ack_detailed"
-msgstr "Сервер поддерживает multi_ack_detailed"
+#: diff.c:5324 diff.c:5327 diff.c:5330
+msgid "<width>"
+msgstr ""
 
-#: fetch-pack.c:931
-msgid "Server supports no-done"
-msgstr "Сервер поддерживает no-done"
+#: diff.c:5325
+msgid "generate diffstat with a given width"
+msgstr ""
 
-#: fetch-pack.c:937
-msgid "Server supports multi_ack"
-msgstr "Сервер поддерживает multi_ack"
+#: diff.c:5328
+msgid "generate diffstat with a given name width"
+msgstr ""
 
-#: fetch-pack.c:941
-msgid "Server supports side-band-64k"
-msgstr "Сервер поддерживает side-band-64k"
+#: diff.c:5331
+msgid "generate diffstat with a given graph width"
+msgstr ""
 
-#: fetch-pack.c:945
-msgid "Server supports side-band"
-msgstr "Сервер поддерживает side-band"
+#: diff.c:5333
+msgid "<count>"
+msgstr ""
 
-#: fetch-pack.c:949
-msgid "Server supports allow-tip-sha1-in-want"
-msgstr "Сервер поддерживает allow-tip-sha1-in-want"
+#: diff.c:5334
+msgid "generate diffstat with limited lines"
+msgstr ""
 
-#: fetch-pack.c:953
-msgid "Server supports allow-reachable-sha1-in-want"
-msgstr "Сервер поддерживает allow-reachable-sha1-in-want"
+#: diff.c:5337
+msgid "generate compact summary in diffstat"
+msgstr "генерация компактной сводки изменений в diffstat"
 
-#: fetch-pack.c:963
-msgid "Server supports ofs-delta"
-msgstr "Сервер поддерживает ofs-delta"
+#: diff.c:5340
+msgid "output a binary diff that can be applied"
+msgstr ""
 
-#: fetch-pack.c:970
-#, c-format
-msgid "Server version is %.*s"
-msgstr "Версия сервера %.*s"
+#: diff.c:5343
+msgid "show full pre- and post-image object names on the \"index\" lines"
+msgstr ""
 
-#: fetch-pack.c:976
-msgid "Server does not support --shallow-since"
-msgstr "Сервер не поддерживает --shallow-since"
+#: diff.c:5345
+msgid "show colored diff"
+msgstr ""
 
-#: fetch-pack.c:980
-msgid "Server does not support --shallow-exclude"
-msgstr "Сервер не поддерживает --shallow-exclude"
+#: diff.c:5346
+msgid "<kind>"
+msgstr ""
 
-#: fetch-pack.c:982
-msgid "Server does not support --deepen"
-msgstr "Сервер не поддерживает --deepen"
+#: diff.c:5347
+msgid ""
+"highlight whitespace errors in the 'context', 'old' or 'new' lines in the "
+"diff"
+msgstr ""
 
-#: fetch-pack.c:993
-msgid "no common commits"
-msgstr "не общих коммитов"
+#: diff.c:5350
+msgid ""
+"do not munge pathnames and use NULs as output field terminators in --raw or "
+"--numstat"
+msgstr ""
 
-#: fetch-pack.c:1005
-msgid "git fetch-pack: fetch failed."
-msgstr "git fetch-pack: ошибка при получении данных."
+#: diff.c:5353 diff.c:5356 diff.c:5359 diff.c:5465
+msgid "<prefix>"
+msgstr ""
 
-#: fetch-pack.c:1167
-msgid "no matching remote head"
-msgstr "нет соотвествующего внешнего указателя на ветку"
+#: diff.c:5354
+msgid "show the given source prefix instead of \"a/\""
+msgstr ""
 
-#: fetch-pack.c:1189
-#, c-format
-msgid "no such remote ref %s"
-msgstr "нет такой внешней ссылки %s"
+#: diff.c:5357
+msgid "show the given destination prefix instead of \"b/\""
+msgstr ""
 
-#: fetch-pack.c:1192
-#, c-format
-msgid "Server does not allow request for unadvertised object %s"
-msgstr "Сервер не поддерживает запрос необъявленного объекта %s"
+#: diff.c:5360
+msgid "prepend an additional prefix to every line of output"
+msgstr ""
 
-#: gpg-interface.c:181
-msgid "gpg failed to sign the data"
-msgstr "gpg не удалось подписать данные"
+#: diff.c:5363
+msgid "do not show any source or destination prefix"
+msgstr ""
 
-#: gpg-interface.c:211
-msgid "could not create temporary file"
-msgstr "не удалось создать временный файл"
+#: diff.c:5366
+msgid "show context between diff hunks up to the specified number of lines"
+msgstr ""
 
-#: gpg-interface.c:214
-#, c-format
-msgid "failed writing detached signature to '%s'"
-msgstr "сбой записи отсоединенной подписи в «%s»"
+#: diff.c:5370 diff.c:5375 diff.c:5380
+msgid "<char>"
+msgstr ""
 
-#: graph.c:97
-#, c-format
-msgid "ignore invalid color '%.*s' in log.graphColors"
-msgstr "игнорирую недопустимый цвет «%.*s» в log.graphColors"
+#: diff.c:5371
+msgid "specify the character to indicate a new line instead of '+'"
+msgstr ""
 
-#: grep.c:2017
-#, c-format
-msgid "'%s': unable to read %s"
-msgstr "«%s»: не удалось прочесть %s"
+#: diff.c:5376
+msgid "specify the character to indicate an old line instead of '-'"
+msgstr ""
 
-#: grep.c:2034 builtin/clone.c:404 builtin/diff.c:81 builtin/rm.c:134
-#, c-format
-msgid "failed to stat '%s'"
-msgstr "не удалось выполнить stat «%s»"
+#: diff.c:5381
+msgid "specify the character to indicate a context instead of ' '"
+msgstr ""
 
-#: grep.c:2045
-#, c-format
-msgid "'%s': short read"
-msgstr "«%s»: слишком мало данных прочитано"
+#: diff.c:5384
+msgid "Diff rename options"
+msgstr ""
 
-#: help.c:179
-#, c-format
-msgid "available git commands in '%s'"
-msgstr "доступные команды git в «%s»"
+#: diff.c:5385
+msgid "<n>[/<m>]"
+msgstr ""
 
-#: help.c:186
-msgid "git commands available from elsewhere on your $PATH"
-msgstr "команды git, доступные в других местах вашего $PATH"
+#: diff.c:5386
+msgid "break complete rewrite changes into pairs of delete and create"
+msgstr ""
 
-#: help.c:217
-msgid "These are common Git commands used in various situations:"
-msgstr "Стандартные команды Git используемые в различных ситуациях:"
+#: diff.c:5390
+msgid "detect renames"
+msgstr ""
 
-#: help.c:281
-#, c-format
-msgid ""
-"'%s' appears to be a git command, but we were not\n"
-"able to execute it. Maybe git-%s is broken?"
-msgstr "«%s» похоже на команду git, но нам не удалось ее запустить. Возможно, git-%s  не работает?"
+#: diff.c:5394
+msgid "omit the preimage for deletes"
+msgstr ""
 
-#: help.c:336
-msgid "Uh oh. Your system reports no Git commands at all."
-msgstr "Ой-ёй! Ваша система не сообщает ни о каких командах Git вообще."
+#: diff.c:5397
+msgid "detect copies"
+msgstr ""
 
-#: help.c:358
-#, c-format
-msgid "WARNING: You called a Git command named '%s', which does not exist."
-msgstr "Внимание: Вы запустили не существующую команду Git «%s»."
+#: diff.c:5401
+msgid "use unmodified files as source to find copies"
+msgstr ""
 
-#: help.c:363
-#, c-format
-msgid "Continuing under the assumption that you meant '%s'."
-msgstr "Продолжаю, предполагая, что вы имели в виду «%s»."
+#: diff.c:5403
+msgid "disable rename detection"
+msgstr ""
 
-#: help.c:368
-#, c-format
-msgid "Continuing in %0.1f seconds, assuming that you meant '%s'."
-msgstr "Продолжу через %0.1f секунд, предполагая, что вы имели в виду «%s»."
+#: diff.c:5406
+msgid "use empty blobs as rename source"
+msgstr ""
 
-#: help.c:376
-#, c-format
-msgid "git: '%s' is not a git command. See 'git --help'."
-msgstr "git: «%s» не является командой git. Смотрите «git --help»."
+#: diff.c:5408
+msgid "continue listing the history of a file beyond renames"
+msgstr ""
 
-#: help.c:380
+#: diff.c:5411
 msgid ""
-"\n"
-"The most similar command is"
-msgid_plural ""
-"\n"
-"The most similar commands are"
-msgstr[0] "\nСамые похожие команды:"
-msgstr[1] "\nСамые похожие команды:"
-msgstr[2] "\nСамые похожие команды:"
-msgstr[3] "\nСамые похожие команды:"
+"prevent rename/copy detection if the number of rename/copy targets exceeds "
+"given limit"
+msgstr ""
 
-#: help.c:395
-msgid "git version [<options>]"
-msgstr "git version [<options>]"
+#: diff.c:5413
+msgid "Diff algorithm options"
+msgstr ""
 
-#: help.c:462
-#, c-format
-msgid "%s: %s - %s"
-msgstr "%s: %s — %s"
+#: diff.c:5415
+msgid "produce the smallest possible diff"
+msgstr ""
 
-#: help.c:466
-msgid ""
-"\n"
-"Did you mean this?"
-msgid_plural ""
-"\n"
-"Did you mean one of these?"
-msgstr[0] "\nВозможно, вы имели в виду это?"
-msgstr[1] "\nВозможно, вы имели в виду что-то из этого?"
-msgstr[2] "\nВозможно, вы имели в виду что-то из этого?"
-msgstr[3] "\nВозможно, вы имели в виду что-то из этого?"
+#: diff.c:5418
+msgid "ignore whitespace when comparing lines"
+msgstr ""
 
-#: ident.c:342
-msgid ""
-"\n"
-"*** Please tell me who you are.\n"
-"\n"
-"Run\n"
-"\n"
-"  git config --global user.email \"you@example.com\"\n"
-"  git config --global user.name \"Your Name\"\n"
-"\n"
-"to set your account's default identity.\n"
-"Omit --global to set the identity only in this repository.\n"
-"\n"
-msgstr "\n*** Пожалуйста, скажите мне кто вы есть.\n\nЗапустите\n\n  git config --global user.email \"you@example.com\"\n  git config --global user.name \"Ваше Имя\"\n\nдля указания идентификационных данных аккаунта по умолчанию.\nПропустите параметр --global для указания данных только для этого репозитория.\n\n"
+#: diff.c:5421
+msgid "ignore changes in amount of whitespace"
+msgstr ""
 
-#: ident.c:366
-msgid "no email was given and auto-detection is disabled"
-msgstr "адрес электронной почты не указан и автоопределение отключено"
+#: diff.c:5424
+msgid "ignore changes in whitespace at EOL"
+msgstr ""
 
-#: ident.c:371
-#, c-format
-msgid "unable to auto-detect email address (got '%s')"
-msgstr "не удалось выполнить автоопределение адреса электронной почты (получено «%s»)"
+#: diff.c:5427
+msgid "ignore carrier-return at the end of line"
+msgstr ""
 
-#: ident.c:381
-msgid "no name was given and auto-detection is disabled"
-msgstr "имя не указано и автоопределение отключено"
+#: diff.c:5430
+msgid "ignore changes whose lines are all blank"
+msgstr ""
 
-#: ident.c:387
-#, c-format
-msgid "unable to auto-detect name (got '%s')"
-msgstr "не удалось выполнить автоопределение имени (получено «%s»)"
+#: diff.c:5433
+msgid "heuristic to shift diff hunk boundaries for easy reading"
+msgstr ""
 
-#: ident.c:395
-#, c-format
-msgid "empty ident name (for <%s>) not allowed"
-msgstr "пустое имя идентификатора (для <%s>) не разрешено"
+#: diff.c:5436
+msgid "generate diff using the \"patience diff\" algorithm"
+msgstr ""
 
-#: ident.c:401
-#, c-format
-msgid "name consists only of disallowed characters: %s"
-msgstr "имя состоит только из неразрешенных симоволов: %s"
+#: diff.c:5440
+msgid "generate diff using the \"histogram diff\" algorithm"
+msgstr ""
 
-#: ident.c:416 builtin/commit.c:616
-#, c-format
-msgid "invalid date format: %s"
-msgstr "неправильный формат даты: %s"
+#: diff.c:5442
+msgid "<algorithm>"
+msgstr ""
 
-#: list-objects-filter-options.c:30
-msgid "multiple object filter types cannot be combined"
-msgstr "невозможно использовать фильтр по нескольким типам объектов"
+#: diff.c:5443
+msgid "choose a diff algorithm"
+msgstr ""
 
-#: list-objects-filter-options.c:41 list-objects-filter-options.c:68
-#, c-format
-msgid "invalid filter-spec expression '%s'"
-msgstr "недопустимое выражение спецификатора фильтра «%s»"
+#: diff.c:5445
+msgid "<text>"
+msgstr ""
 
-#: lockfile.c:151
-#, c-format
-msgid ""
-"Unable to create '%s.lock': %s.\n"
-"\n"
-"Another git process seems to be running in this repository, e.g.\n"
-"an editor opened by 'git commit'. Please make sure all processes\n"
-"are terminated then try again. If it still fails, a git process\n"
-"may have crashed in this repository earlier:\n"
-"remove the file manually to continue."
-msgstr "Не удалось создать «%s.lock»: %s.\n\nПохоже, что другой процесс git запущен в этом репозитории,\nнапример редактор открыт из «git commit». Пожалуйста, убедитесь,\nчто все процессы были завершены и потом попробуйте снова.\nЕсли это не поможет, то возможно процесс git был ранее завершен\nс ошибкой в этом репозитории: \nудалите файл вручную для продолжения."
+#: diff.c:5446
+msgid "generate diff using the \"anchored diff\" algorithm"
+msgstr ""
 
-#: lockfile.c:159
-#, c-format
-msgid "Unable to create '%s.lock': %s"
-msgstr "Не удалось создать «%s.lock»: %s"
+#: diff.c:5448 diff.c:5457 diff.c:5460
+msgid "<mode>"
+msgstr ""
 
-#: merge.c:74
-msgid "failed to read the cache"
-msgstr "сбой чтения кэша"
+#: diff.c:5449
+msgid "show word diff, using <mode> to delimit changed words"
+msgstr ""
 
-#: merge.c:128 builtin/am.c:1943 builtin/am.c:1977 builtin/checkout.c:379
-#: builtin/checkout.c:600 builtin/clone.c:754
-msgid "unable to write new index file"
-msgstr "не удалось записать новый файл индекса"
+#: diff.c:5451 diff.c:5454 diff.c:5499
+msgid "<regex>"
+msgstr ""
 
-#: merge-recursive.c:235
-msgid "(bad commit)\n"
-msgstr "(плохой коммит)\n"
+#: diff.c:5452
+msgid "use <regex> to decide what a word is"
+msgstr ""
 
-#: merge-recursive.c:257 merge-recursive.c:265
-#, c-format
-msgid "addinfo_cache failed for path '%s'"
-msgstr "сбой addinfo_cache для пути «%s»"
+#: diff.c:5455
+msgid "equivalent to --word-diff=color --word-diff-regex=<regex>"
+msgstr ""
 
-#: merge-recursive.c:329
-msgid "error building trees"
-msgstr "ошибка при построении деревьев"
+#: diff.c:5458
+msgid "moved lines of code are colored differently"
+msgstr ""
 
-#: merge-recursive.c:752
-#, c-format
-msgid "failed to create path '%s'%s"
-msgstr "не удалось создать путь «%s»%s"
+#: diff.c:5461
+msgid "how white spaces are ignored in --color-moved"
+msgstr ""
 
-#: merge-recursive.c:763
-#, c-format
-msgid "Removing %s to make room for subdirectory\n"
-msgstr "Удаление %s, чтобы освободить место для подкаталогов\n"
+#: diff.c:5464
+msgid "Other diff options"
+msgstr ""
 
-#: merge-recursive.c:777 merge-recursive.c:796
-msgid ": perhaps a D/F conflict?"
-msgstr ": возможно, конфликт каталогов/файлов?"
+#: diff.c:5466
+msgid "when run from subdir, exclude changes outside and show relative paths"
+msgstr ""
 
-#: merge-recursive.c:786
-#, c-format
-msgid "refusing to lose untracked file at '%s'"
-msgstr "отказ потери неотслеживаемого файла в «%s»"
+#: diff.c:5470
+msgid "treat all files as text"
+msgstr ""
 
-#: merge-recursive.c:828 builtin/cat-file.c:37
-#, c-format
-msgid "cannot read object %s '%s'"
-msgstr "невозможно прочитать объект %s «%s»"
+#: diff.c:5472
+msgid "swap two inputs, reverse the diff"
+msgstr ""
 
-#: merge-recursive.c:830
-#, c-format
-msgid "blob expected for %s '%s'"
-msgstr "ожидается двоичный объект для %s «%s»"
+#: diff.c:5474
+msgid "exit with 1 if there were differences, 0 otherwise"
+msgstr ""
 
-#: merge-recursive.c:854
-#, c-format
-msgid "failed to open '%s': %s"
-msgstr "не удалось открыть «%s»: %s"
+#: diff.c:5476
+msgid "disable all output of the program"
+msgstr ""
 
-#: merge-recursive.c:865
-#, c-format
-msgid "failed to symlink '%s': %s"
-msgstr "не удалось создать символьную ссылку «%s»: %s"
+#: diff.c:5478
+msgid "allow an external diff helper to be executed"
+msgstr ""
 
-#: merge-recursive.c:870
-#, c-format
-msgid "do not know what to do with %06o %s '%s'"
-msgstr "не понятно, что делать с %06o %s «%s»"
+#: diff.c:5480
+msgid "run external text conversion filters when comparing binary files"
+msgstr ""
 
-#: merge-recursive.c:1010
-msgid "Failed to execute internal merge"
-msgstr "Не удалось запустить внутреннее слияние"
+#: diff.c:5482
+msgid "<when>"
+msgstr ""
 
-#: merge-recursive.c:1014
-#, c-format
-msgid "Unable to add %s to database"
-msgstr "Не удалось добавить %s в базу данных"
+#: diff.c:5483
+msgid "ignore changes to submodules in the diff generation"
+msgstr ""
 
-#: merge-recursive.c:1117
-#, c-format
-msgid ""
-"CONFLICT (%s/delete): %s deleted in %s and %s in %s. Version %s of %s left "
-"in tree."
-msgstr "КОНФЛИКТ (%s/удаление): %s удалено в %s и %s в %s. Версия %s из %s оставлена в дереве."
+#: diff.c:5486
+msgid "<format>"
+msgstr ""
 
-#: merge-recursive.c:1122
-#, c-format
-msgid ""
-"CONFLICT (%s/delete): %s deleted in %s and %s to %s in %s. Version %s of %s "
-"left in tree."
-msgstr "КОНФЛИКТ (%s/удаление): %s удалено в %s и от %s до %s в %s. Версия %s из %s оставлена в дереве."
+#: diff.c:5487
+msgid "specify how differences in submodules are shown"
+msgstr ""
 
-#: merge-recursive.c:1129
-#, c-format
+#: diff.c:5491
+msgid "hide 'git add -N' entries from the index"
+msgstr ""
+
+#: diff.c:5494
+msgid "treat 'git add -N' entries as real in the index"
+msgstr ""
+
+#: diff.c:5496
+msgid "<string>"
+msgstr ""
+
+#: diff.c:5497
 msgid ""
-"CONFLICT (%s/delete): %s deleted in %s and %s in %s. Version %s of %s left "
-"in tree at %s."
-msgstr "КОНФЛИКТ (%s/удаление): %s удалено в %s и %s в %s. Версия %s из %s оставлена в дереве на %s."
+"look for differences that change the number of occurrences of the specified "
+"string"
+msgstr ""
 
-#: merge-recursive.c:1134
-#, c-format
+#: diff.c:5500
 msgid ""
-"CONFLICT (%s/delete): %s deleted in %s and %s to %s in %s. Version %s of %s "
-"left in tree at %s."
-msgstr "КОНФЛИКТ (%s/удаление): %s удалено в %s и от %s до %s в %s. Версия %s из %s оставлена в дереве на %s."
+"look for differences that change the number of occurrences of the specified "
+"regex"
+msgstr ""
 
-#: merge-recursive.c:1168
-msgid "rename"
-msgstr "переименование"
+#: diff.c:5503
+msgid "show all changes in the changeset with -S or -G"
+msgstr ""
 
-#: merge-recursive.c:1168
-msgid "renamed"
-msgstr "переименовано"
+#: diff.c:5506
+msgid "treat <string> in -S as extended POSIX regular expression"
+msgstr ""
 
-#: merge-recursive.c:1225
-#, c-format
-msgid "%s is a directory in %s adding as %s instead"
-msgstr "%s — это каталог в %s, добавляем как %s вместо этого"
+#: diff.c:5509
+msgid "control the order in which files appear in the output"
+msgstr ""
 
-#: merge-recursive.c:1250
-#, c-format
+#: diff.c:5510
+msgid "<object-id>"
+msgstr ""
+
+#: diff.c:5511
 msgid ""
-"CONFLICT (rename/rename): Rename \"%s\"->\"%s\" in branch \"%s\" rename "
-"\"%s\"->\"%s\" in \"%s\"%s"
-msgstr "КОНФЛИКТ (переименование/переименование): Переименование «%s»→«%s» в ветке «%s» и переименование «%s»→«%s» в ветке «%s»%s"
+"look for differences that change the number of occurrences of the specified "
+"object"
+msgstr ""
 
-#: merge-recursive.c:1255
-msgid " (left unresolved)"
-msgstr " (оставлено неразрешенным)"
+#: diff.c:5513
+msgid "[(A|C|D|M|R|T|U|X|B)...[*]]"
+msgstr ""
 
-#: merge-recursive.c:1317
-#, c-format
-msgid "CONFLICT (rename/rename): Rename %s->%s in %s. Rename %s->%s in %s"
-msgstr "КОНФЛИКТ (переименование/переименование): Переименование «%s»→«%s» в ветке «%s» и переименование «%s»→«%s» в ветке «%s»"
+#: diff.c:5514
+msgid "select files by diff type"
+msgstr ""
 
-#: merge-recursive.c:1350
-#, c-format
-msgid "Renaming %s to %s and %s to %s instead"
-msgstr "Переименовываю %s в %s и %s в %s вместо этого"
+#: diff.c:5516
+msgid "<file>"
+msgstr ""
 
-#: merge-recursive.c:1553
-#, c-format
-msgid "CONFLICT (rename/add): Rename %s->%s in %s. %s added in %s"
-msgstr "КОНФЛИКТ (переименование/добавление): Переименование «%s»→«%s» в ветке «%s» и добавление «%s» в ветке «%s»"
+#: diff.c:5517
+msgid "Output to a specific file"
+msgstr ""
 
-#: merge-recursive.c:1568
-#, c-format
-msgid "Adding merged %s"
-msgstr "Добавление слитого %s"
+#: diff.c:6150
+msgid "inexact rename detection was skipped due to too many files."
+msgstr "неточное определение переименования было пропущено из-за слишком большого количества файлов."
 
-#: merge-recursive.c:1575 merge-recursive.c:1805
-#, c-format
-msgid "Adding as %s instead"
-msgstr "Добавление вместо этого как %s"
+#: diff.c:6153
+msgid "only found copies from modified paths due to too many files."
+msgstr "найдены только копии из измененных путей из-за слишком большого количества файлов."
 
-#: merge-recursive.c:1632
+#: diff.c:6156
 #, c-format
-msgid "cannot read object %s"
-msgstr "невозможно прочитать объект «%s»"
+msgid ""
+"you may want to set your %s variable to at least %d and retry the command."
+msgstr "возможно вы захотите установить переменную %s в как минимум значение %d и повторить вызов команды."
 
-#: merge-recursive.c:1635
+#: dir.c:537
 #, c-format
-msgid "object %s is not a blob"
-msgstr "объект %s не является двоичным объектом"
+msgid "pathspec '%s' did not match any file(s) known to git"
+msgstr ""
 
-#: merge-recursive.c:1704
-msgid "modify"
-msgstr "изменение"
+#: dir.c:926
+#, c-format
+msgid "cannot use %s as an exclude file"
+msgstr ""
 
-#: merge-recursive.c:1704
-msgid "modified"
-msgstr "изменено"
+#: dir.c:1843
+#, c-format
+msgid "could not open directory '%s'"
+msgstr "не удалось открыть каталог «%s»"
 
-#: merge-recursive.c:1714
-msgid "content"
-msgstr "содержимое"
+#: dir.c:2085
+msgid "failed to get kernel name and information"
+msgstr "не удалось получить имя ядра и информацию"
 
-#: merge-recursive.c:1721
-msgid "add/add"
-msgstr "добавление/добавление"
+#: dir.c:2209
+msgid "untracked cache is disabled on this system or location"
+msgstr ""
 
-#: merge-recursive.c:1757
+#: dir.c:3013
 #, c-format
-msgid "Skipped %s (merged same as existing)"
-msgstr "Пропуск %s (слиты одинаковые изменения как существующие)"
+msgid "index file corrupt in repo %s"
+msgstr ""
 
-#: merge-recursive.c:1771
+#: dir.c:3058 dir.c:3063
 #, c-format
-msgid "Auto-merging %s"
-msgstr "Автослияние %s"
-
-#: merge-recursive.c:1775 git-submodule.sh:932
-msgid "submodule"
-msgstr "подмодуль"
+msgid "could not create directories for %s"
+msgstr "не удалось создать каталоги для %s"
 
-#: merge-recursive.c:1776
+#: dir.c:3092
 #, c-format
-msgid "CONFLICT (%s): Merge conflict in %s"
-msgstr "КОНФЛИКТ (%s): Конфликт слияния в %s"
+msgid "could not migrate git directory from '%s' to '%s'"
+msgstr "не удалось переместить каталог git с «%s» в «%s»"
 
-#: merge-recursive.c:1870
+#: editor.c:73
 #, c-format
-msgid "Removing %s"
-msgstr "Удаление %s"
+msgid "hint: Waiting for your editor to close the file...%c"
+msgstr "подсказка: Ожидание, пока вы закроете редактор с файлом…%c"
 
-#: merge-recursive.c:1896
-msgid "file/directory"
-msgstr "файл/каталог"
+#: entry.c:178
+msgid "Filtering content"
+msgstr "Фильтруется содержимое"
 
-#: merge-recursive.c:1902
-msgid "directory/file"
-msgstr "каталог/файл"
+#: entry.c:476
+#, c-format
+msgid "could not stat file '%s'"
+msgstr "не удалось выполнить stat для файла «%s»"
 
-#: merge-recursive.c:1909
+#: environment.c:150
 #, c-format
-msgid ""
-"CONFLICT (%s): There is a directory with name %s in %s. Adding %s as %s"
-msgstr "КОНФЛИКТ (%s): Уже существует каталог с именем «%s» в «%s». Добавление «%s» как «%s»"
+msgid "bad git namespace path \"%s\""
+msgstr ""
 
-#: merge-recursive.c:1918
+#: environment.c:332
 #, c-format
-msgid "Adding %s"
-msgstr "Добавление %s"
+msgid "could not set GIT_DIR to '%s'"
+msgstr ""
 
-#: merge-recursive.c:1958
+#: exec-cmd.c:363
 #, c-format
-msgid "Dirty index: cannot merge (dirty: %s)"
-msgstr "Индекс не пустой: не могу слить (в индексе: %s)"
+msgid "too many args to run %s"
+msgstr ""
 
-#: merge-recursive.c:1962
-msgid "Already up to date!"
-msgstr "Уже обновлено!"
+#: fetch-object.c:17
+msgid "Remote with no URL"
+msgstr "Внешний репозиторий без URL"
 
-#: merge-recursive.c:1971
-#, c-format
-msgid "merging of trees %s and %s failed"
-msgstr "сбой слияния деревьев «%s» и «%s»"
+#: fetch-pack.c:151
+msgid "git fetch-pack: expected shallow list"
+msgstr "git fetch-pack: ожидается передача списка для получение части"
 
-#: merge-recursive.c:2068
-msgid "Merging:"
-msgstr "Слияние:"
+#: fetch-pack.c:154
+msgid "git fetch-pack: expected a flush packet after shallow list"
+msgstr ""
+
+#: fetch-pack.c:165
+msgid "git fetch-pack: expected ACK/NAK, got a flush packet"
+msgstr "git fetch-pack: ожидается ACK/NAK, а получен пустой пакет"
 
-#: merge-recursive.c:2081
+#: fetch-pack.c:185
 #, c-format
-msgid "found %u common ancestor:"
-msgid_plural "found %u common ancestors:"
-msgstr[0] "найден %u общий предок:"
-msgstr[1] "найдено %u общих предка:"
-msgstr[2] "найдено %u общих предков:"
-msgstr[3] "найдено %u общих предков:"
+msgid "git fetch-pack: expected ACK/NAK, got '%s'"
+msgstr "git fetch-pack: ожидается ACK/NAK, а получено «%s»"
 
-#: merge-recursive.c:2120
-msgid "merge returned no commit"
-msgstr "слияние не вернуло коммит"
+#: fetch-pack.c:196
+msgid "unable to write to remote"
+msgstr ""
 
-#: merge-recursive.c:2183
-#, c-format
-msgid "Could not parse object '%s'"
-msgstr "Не удалось разобрать объект «%s»"
+#: fetch-pack.c:258
+msgid "--stateless-rpc requires multi_ack_detailed"
+msgstr "--stateless-rpc требует multi_ack_detailed"
 
-#: merge-recursive.c:2197 builtin/merge.c:656 builtin/merge.c:815
-msgid "Unable to write index."
-msgstr "Не удается записать индекс."
+#: fetch-pack.c:360 fetch-pack.c:1271
+#, c-format
+msgid "invalid shallow line: %s"
+msgstr "неправильная строка частичного получения: %s"
 
-#: notes-merge.c:272
+#: fetch-pack.c:366 fetch-pack.c:1277
 #, c-format
-msgid ""
-"You have not concluded your previous notes merge (%s exists).\n"
-"Please, use 'git notes merge --commit' or 'git notes merge --abort' to commit/abort the previous merge before you start a new notes merge."
-msgstr "Вы не закончили предыдущее слияние заметок (%s существует).\nЗапустите «git notes merge --commit» или «git notes merge --abort» для коммита или отмены предыдущего слияния и запуска нового слияния заметок."
+msgid "invalid unshallow line: %s"
+msgstr "неправильная строка полного получения: %s"
 
-#: notes-merge.c:279
+#: fetch-pack.c:368 fetch-pack.c:1279
 #, c-format
-msgid "You have not concluded your notes merge (%s exists)."
-msgstr "Вы не закончили предыдущее слияние заметок (%s существует)."
+msgid "object not found: %s"
+msgstr "объект не найден: %s"
 
-#: notes-utils.c:42
-msgid "Cannot commit uninitialized/unreferenced notes tree"
-msgstr "Нельзя закоммитить неинициализированное или не имеющее ссылок дерево заметок"
+#: fetch-pack.c:371 fetch-pack.c:1282
+#, c-format
+msgid "error in object: %s"
+msgstr "ошибка в объекте: %s"
 
-#: notes-utils.c:101
+#: fetch-pack.c:373 fetch-pack.c:1284
 #, c-format
-msgid "Bad notes.rewriteMode value: '%s'"
-msgstr "Неправильное значение notes.rewriteMode: «%s»"
+msgid "no shallow found: %s"
+msgstr "частичный клон не найден: %s"
 
-#: notes-utils.c:111
+#: fetch-pack.c:376 fetch-pack.c:1288
 #, c-format
-msgid "Refusing to rewrite notes in %s (outside of refs/notes/)"
-msgstr "Отказ в перезаписи заметок в %s (за пределами refs/notes/)"
+msgid "expected shallow/unshallow, got %s"
+msgstr "ожидалось shallow/unshallow, а получено %s"
 
-#. TRANSLATORS: The first %s is the name of
-#. the environment variable, the second %s is
-#. its value.
-#: notes-utils.c:141
+#: fetch-pack.c:417
 #, c-format
-msgid "Bad %s value: '%s'"
-msgstr "Неправильное значение переменной %s: «%s»"
+msgid "got %s %d %s"
+msgstr "получено %s %d %s"
 
-#: object.c:239
+#: fetch-pack.c:434
 #, c-format
-msgid "unable to parse object: %s"
-msgstr "не удалось разобрать объект: %s"
+msgid "invalid commit %s"
+msgstr "недопустимый коммит %s"
 
-#: packfile.c:556
-msgid "offset before end of packfile (broken .idx?)"
-msgstr "сдвиг до конца файла пакета (возможно, повреждён файл .idx?)"
+#: fetch-pack.c:465
+msgid "giving up"
+msgstr "останавливаю дальнейшие попытки"
 
-#: packfile.c:1683
-#, c-format
-msgid "offset before start of pack index for %s (corrupt index?)"
-msgstr "сдвиг до начала индекса пакета для %s (повреждён индекс?)"
+#: fetch-pack.c:477 progress.c:284
+msgid "done"
+msgstr "готово"
 
-#: packfile.c:1687
+#: fetch-pack.c:489
 #, c-format
-msgid "offset beyond end of pack index for %s (truncated index?)"
-msgstr "сдвиг за пределами индекса пакета для %s (обрезан индекс?)"
+msgid "got %s (%d) %s"
+msgstr "получено %s (%d) %s"
 
-#: parse-options.c:573
-msgid "..."
-msgstr "…"
+#: fetch-pack.c:535
+#, c-format
+msgid "Marking %s as complete"
+msgstr "Помечаю %s как завершенный"
 
-#: parse-options.c:592
+#: fetch-pack.c:744
 #, c-format
-msgid "usage: %s"
-msgstr "использование: %s"
-
-#. TRANSLATORS: the colon here should align with the
-#. one in "usage: %s" translation.
-#: parse-options.c:598
-#, c-format
-msgid "   or: %s"
-msgstr "          или: %s"
+msgid "already have %s (%s)"
+msgstr "уже есть %s (%s)"
 
-#: parse-options.c:601
-#, c-format
-msgid "    %s"
-msgstr "            %s"
+#: fetch-pack.c:783
+msgid "fetch-pack: unable to fork off sideband demultiplexer"
+msgstr "fetch-pack: не удалось запустить программу разбора данных"
 
-#: parse-options.c:640
-msgid "-NUM"
-msgstr "-КОЛИЧЕСТВО"
+#: fetch-pack.c:791
+msgid "protocol error: bad pack header"
+msgstr "ошибка протокола: неправильный заголовок потока"
 
-#: parse-options-cb.c:108
+#: fetch-pack.c:859
 #, c-format
-msgid "malformed object name '%s'"
-msgstr "Неправильное имя объекта «%s»"
+msgid "fetch-pack: unable to fork off %s"
+msgstr "fetch-pack: не удалось запустить программу %s"
 
-#: path.c:891
+#: fetch-pack.c:875
 #, c-format
-msgid "Could not make %s writable by group"
-msgstr "Не удалось предоставить доступ к %s на запись"
+msgid "%s failed"
+msgstr "%s завершен с ошибкой"
 
-#: pathspec.c:129
-msgid "Escape character '\\' not allowed as last character in attr value"
-msgstr "Управляющий символ «\\» не разрешен как последний символ в значении attr"
+#: fetch-pack.c:877
+msgid "error in sideband demultiplexer"
+msgstr "произошла  ошибка в  программе разбора данных"
 
-#: pathspec.c:147
-msgid "Only one 'attr:' specification is allowed."
-msgstr "Разрешен только один спецификатор «attr:»."
+#: fetch-pack.c:906
+msgid "Server does not support shallow clients"
+msgstr "Сервер не поддерживает клиентов с частичным клонированием"
 
-#: pathspec.c:150
-msgid "attr spec must not be empty"
-msgstr "спецификатор attr не должен быть пустой"
+#: fetch-pack.c:910
+msgid "Server supports multi_ack_detailed"
+msgstr "Сервер поддерживает multi_ack_detailed"
 
-#: pathspec.c:193
-#, c-format
-msgid "invalid attribute name %s"
-msgstr "недопустимое имя атрибута %s"
+#: fetch-pack.c:913
+msgid "Server supports no-done"
+msgstr "Сервер поддерживает no-done"
 
-#: pathspec.c:258
-msgid "global 'glob' and 'noglob' pathspec settings are incompatible"
-msgstr "глобальные опции спецификаторов пути «glob» и «noglob» нельзя использовать одновременно"
+#: fetch-pack.c:919
+msgid "Server supports multi_ack"
+msgstr "Сервер поддерживает multi_ack"
 
-#: pathspec.c:265
-msgid ""
-"global 'literal' pathspec setting is incompatible with all other global "
-"pathspec settings"
-msgstr "глобальная опция спецификатора пути «literal» не совместима с другими глобальными спецификаторами доступа"
+#: fetch-pack.c:923
+msgid "Server supports side-band-64k"
+msgstr "Сервер поддерживает side-band-64k"
 
-#: pathspec.c:305
-msgid "invalid parameter for pathspec magic 'prefix'"
-msgstr "неправильный параметр для магического слова «prefix» в спецификаторе пути "
+#: fetch-pack.c:927
+msgid "Server supports side-band"
+msgstr "Сервер поддерживает side-band"
 
-#: pathspec.c:326
-#, c-format
-msgid "Invalid pathspec magic '%.*s' in '%s'"
-msgstr "неправильное магическое слово «%.*s» в спецификаторе пути «%s»"
+#: fetch-pack.c:931
+msgid "Server supports allow-tip-sha1-in-want"
+msgstr "Сервер поддерживает allow-tip-sha1-in-want"
 
-#: pathspec.c:331
-#, c-format
-msgid "Missing ')' at the end of pathspec magic in '%s'"
-msgstr "Пропущено «)» в конце магического слова спецификатора пути «%s»"
+#: fetch-pack.c:935
+msgid "Server supports allow-reachable-sha1-in-want"
+msgstr "Сервер поддерживает allow-reachable-sha1-in-want"
 
-#: pathspec.c:369
-#, c-format
-msgid "Unimplemented pathspec magic '%c' in '%s'"
-msgstr "Нереализованное магическое слово «%c» спецификатора пути «%s»"
+#: fetch-pack.c:945
+msgid "Server supports ofs-delta"
+msgstr "Сервер поддерживает ofs-delta"
 
-#: pathspec.c:428
-#, c-format
-msgid "%s: 'literal' and 'glob' are incompatible"
-msgstr "%s: «literal» и «glob» не совместимы"
+#: fetch-pack.c:951 fetch-pack.c:1144
+msgid "Server supports filter"
+msgstr "Сервер поддерживает фильтрацию"
 
-#: pathspec.c:441
+#: fetch-pack.c:959
 #, c-format
-msgid "%s: '%s' is outside repository"
-msgstr "%s: «%s» вне репозитория"
+msgid "Server version is %.*s"
+msgstr "Версия сервера %.*s"
 
-#: pathspec.c:515
-#, c-format
-msgid "'%s' (mnemonic: '%c')"
-msgstr "«%s» (мнемоника: «%c»)"
+#: fetch-pack.c:965
+msgid "Server does not support --shallow-since"
+msgstr "Сервер не поддерживает --shallow-since"
 
-#: pathspec.c:525
-#, c-format
-msgid "%s: pathspec magic not supported by this command: %s"
-msgstr "%s: магические слова в спецификаторе пути не поддерживаются командой: %s"
+#: fetch-pack.c:969
+msgid "Server does not support --shallow-exclude"
+msgstr "Сервер не поддерживает --shallow-exclude"
 
-#: pathspec.c:592
-#, c-format
-msgid "pathspec '%s' is beyond a symbolic link"
-msgstr "спецификатор пути «%s» находится за символической ссылкой"
+#: fetch-pack.c:971
+msgid "Server does not support --deepen"
+msgstr "Сервер не поддерживает --deepen"
 
-#: pretty.c:962
-msgid "unable to parse --pretty format"
-msgstr "не удалось разобрать формат для --pretty"
+#: fetch-pack.c:988
+msgid "no common commits"
+msgstr "не общих коммитов"
 
-#: read-cache.c:1472
-#, c-format
-msgid ""
-"index.version set, but the value is invalid.\n"
-"Using version %i"
-msgstr "index.version указан, но значение недействительное.\nИспользую версию %i"
+#: fetch-pack.c:1000 fetch-pack.c:1449
+msgid "git fetch-pack: fetch failed."
+msgstr "git fetch-pack: ошибка при получении данных."
 
-#: read-cache.c:1482
-#, c-format
-msgid ""
-"GIT_INDEX_VERSION set, but the value is invalid.\n"
-"Using version %i"
-msgstr "GIT_INDEX_VERSION указан, но значение недействительное.\nИспользую версию %i"
+#: fetch-pack.c:1138
+msgid "Server does not support shallow requests"
+msgstr "Сервер не поддерживает частичные запросы"
 
-#: read-cache.c:2370 sequencer.c:2731 wrapper.c:658 builtin/merge.c:1048
-#, c-format
-msgid "could not close '%s'"
-msgstr "не удалось закрыть «%s»"
+#: fetch-pack.c:1171
+msgid "unable to write request to remote"
+msgstr ""
 
-#: read-cache.c:2442 sequencer.c:1369 sequencer.c:2096
+#: fetch-pack.c:1189
 #, c-format
-msgid "could not stat '%s'"
-msgstr "не удалось выполнить stat для «%s»"
+msgid "error reading section header '%s'"
+msgstr ""
 
-#: read-cache.c:2455
+#: fetch-pack.c:1195
 #, c-format
-msgid "unable to open git dir: %s"
-msgstr "не удалось открыть каталог git: %s"
+msgid "expected '%s', received '%s'"
+msgstr ""
 
-#: read-cache.c:2467
+#: fetch-pack.c:1234
 #, c-format
-msgid "unable to unlink: %s"
-msgstr "не удалось отсоединить: %s"
+msgid "unexpected acknowledgment line: '%s'"
+msgstr ""
 
-#: refs.c:706
+#: fetch-pack.c:1239
 #, c-format
-msgid "Could not open '%s' for writing"
-msgstr "Не удалось открыть «%s» для записи"
+msgid "error processing acks: %d"
+msgstr ""
 
-#: refs.c:1850
-msgid "ref updates forbidden inside quarantine environment"
-msgstr "обновление ссылок запрещено в изолированном окружении"
+#: fetch-pack.c:1249
+msgid "expected packfile to be sent after 'ready'"
+msgstr ""
 
-#: refs/files-backend.c:1189
-#, c-format
-msgid "could not remove reference %s"
-msgstr "не удалось удалить ссылки %s"
+#: fetch-pack.c:1251
+msgid "expected no other sections to be sent after no 'ready'"
+msgstr ""
 
-#: refs/files-backend.c:1203 refs/packed-backend.c:1524
-#: refs/packed-backend.c:1534
+#: fetch-pack.c:1293
 #, c-format
-msgid "could not delete reference %s: %s"
-msgstr "не удалось удалить ссылку %s: %s"
+msgid "error processing shallow info: %d"
+msgstr ""
 
-#: refs/files-backend.c:1206 refs/packed-backend.c:1537
+#: fetch-pack.c:1340
 #, c-format
-msgid "could not delete references: %s"
-msgstr "не удалось удалить ссылки: %s"
-
-#: ref-filter.c:35 wt-status.c:1816
-msgid "gone"
-msgstr "исчез"
+msgid "expected wanted-ref, got '%s'"
+msgstr ""
 
-#: ref-filter.c:36
+#: fetch-pack.c:1345
 #, c-format
-msgid "ahead %d"
-msgstr "впереди %d"
+msgid "unexpected wanted-ref: '%s'"
+msgstr ""
 
-#: ref-filter.c:37
+#: fetch-pack.c:1350
 #, c-format
-msgid "behind %d"
-msgstr "позади %d"
+msgid "error processing wanted refs: %d"
+msgstr ""
 
-#: ref-filter.c:38
-#, c-format
-msgid "ahead %d, behind %d"
-msgstr "впереди %d, позади %d"
+#: fetch-pack.c:1676
+msgid "no matching remote head"
+msgstr "нет соотвествующего внешнего указателя на ветку"
 
-#: ref-filter.c:107
-#, c-format
-msgid "expected format: %%(color:<color>)"
-msgstr "ожидаемый формат: %%(color:<color>)"
+#: fetch-pack.c:1699 builtin/clone.c:673
+msgid "remote did not send all necessary objects"
+msgstr "внешний репозиторий прислал не все необходимые объекты"
 
-#: ref-filter.c:109
+#: fetch-pack.c:1726
 #, c-format
-msgid "unrecognized color: %%(color:%s)"
-msgstr "неопознанный цвет: %%(color:%s)"
+msgid "no such remote ref %s"
+msgstr "нет такой внешней ссылки %s"
 
-#: ref-filter.c:129
+#: fetch-pack.c:1729
 #, c-format
-msgid "Integer value expected refname:lstrip=%s"
-msgstr "Ожидается целочисленное значение refname:lstrip=%s"
+msgid "Server does not allow request for unadvertised object %s"
+msgstr "Сервер не поддерживает запрос необъявленного объекта %s"
 
-#: ref-filter.c:133
-#, c-format
-msgid "Integer value expected refname:rstrip=%s"
-msgstr "Ожидается целочисленное значение refname:rstrip=%s"
+#: gpg-interface.c:318
+msgid "gpg failed to sign the data"
+msgstr "gpg не удалось подписать данные"
 
-#: ref-filter.c:135
-#, c-format
-msgid "unrecognized %%(%s) argument: %s"
-msgstr "неопознанный аргумент %%(%s): %s"
+#: gpg-interface.c:344
+msgid "could not create temporary file"
+msgstr "не удалось создать временный файл"
 
-#: ref-filter.c:184
+#: gpg-interface.c:347
 #, c-format
-msgid "%%(body) does not take arguments"
-msgstr "параметр %%(body) не принимает аргументы"
+msgid "failed writing detached signature to '%s'"
+msgstr "сбой записи отсоединенной подписи в «%s»"
 
-#: ref-filter.c:191
+#: graph.c:97
 #, c-format
-msgid "%%(subject) does not take arguments"
-msgstr "параметр %%(subject) не принимает аргументы"
+msgid "ignore invalid color '%.*s' in log.graphColors"
+msgstr "игнорирую недопустимый цвет «%.*s» в log.graphColors"
 
-#: ref-filter.c:209
+#: grep.c:2113
 #, c-format
-msgid "unknown %%(trailers) argument: %s"
-msgstr "неизвестный аргумент для %%(trailers): %s"
+msgid "'%s': unable to read %s"
+msgstr "«%s»: не удалось прочесть %s"
 
-#: ref-filter.c:232
+#: grep.c:2130 setup.c:164 builtin/clone.c:411 builtin/diff.c:82
+#: builtin/rm.c:135
 #, c-format
-msgid "positive value expected contents:lines=%s"
-msgstr "положительное значение ожидает contents:lines=%s"
+msgid "failed to stat '%s'"
+msgstr "не удалось выполнить stat «%s»"
 
-#: ref-filter.c:234
+#: grep.c:2141
 #, c-format
-msgid "unrecognized %%(contents) argument: %s"
-msgstr "неопознанный аргумент %%(contents): %s"
+msgid "'%s': short read"
+msgstr "«%s»: слишком мало данных прочитано"
 
-#: ref-filter.c:247
-#, c-format
-msgid "positive value expected objectname:short=%s"
-msgstr "ожидается положительное значение objectname:short=%s"
+#: help.c:23
+msgid "start a working area (see also: git help tutorial)"
+msgstr "создание рабочей области (смотрите также: git help tutorial)"
 
-#: ref-filter.c:251
-#, c-format
-msgid "unrecognized %%(objectname) argument: %s"
-msgstr "неопознанный аргумент %%(objectname): %s"
+#: help.c:24
+msgid "work on the current change (see also: git help everyday)"
+msgstr "работа с текущими изменениями (смотрите также: git help everyday)"
 
-#: ref-filter.c:278
-#, c-format
-msgid "expected format: %%(align:<width>,<position>)"
-msgstr "ожидаемый формат: %%(align:<width>,<position>)"
+#: help.c:25
+msgid "examine the history and state (see also: git help revisions)"
+msgstr "просмотр истории и текущего состояния (смотрите также: git help revisions)"
 
-#: ref-filter.c:290
-#, c-format
-msgid "unrecognized position:%s"
-msgstr "неопознанная позиция:%s"
+#: help.c:26
+msgid "grow, mark and tweak your common history"
+msgstr "выращивание, отметка и настройка вашей общей истории"
 
-#: ref-filter.c:294
-#, c-format
-msgid "unrecognized width:%s"
-msgstr "неопознанная ширина:%s"
+#: help.c:27
+msgid "collaborate (see also: git help workflows)"
+msgstr "совместная работа (смотрите также: git help workflows)"
 
-#: ref-filter.c:300
-#, c-format
-msgid "unrecognized %%(align) argument: %s"
-msgstr "неопознанный аргумент %%(align): %s"
+#: help.c:31
+msgid "Main Porcelain Commands"
+msgstr "Основные машиночитаемые команды"
+
+#: help.c:32
+msgid "Ancillary Commands / Manipulators"
+msgstr "Вспомогательные команды / Манипуляторы"
+
+#: help.c:33
+msgid "Ancillary Commands / Interrogators"
+msgstr "Вспомогательные команды / Запросчики"
+
+#: help.c:34
+msgid "Interacting with Others"
+msgstr "Взаимодействие с другими"
+
+#: help.c:35
+msgid "Low-level Commands / Manipulators"
+msgstr "Низкоуровневые команды / Манипуляторы"
+
+#: help.c:36
+msgid "Low-level Commands / Interrogators"
+msgstr "Низкоуровневые команды / Запросчики"
+
+#: help.c:37
+msgid "Low-level Commands / Synching Repositories"
+msgstr "Низкоуровневые команды / Синхронизация репозиториев"
+
+#: help.c:38
+msgid "Low-level Commands / Internal Helpers"
+msgstr "Низкоуровневые команды / Внутренние вспомогательные"
 
-#: ref-filter.c:304
+#: help.c:298
 #, c-format
-msgid "positive width expected with the %%(align) atom"
-msgstr "ожидается положительная ширина с указанием частицы %%(align)"
+msgid "available git commands in '%s'"
+msgstr "доступные команды git в «%s»"
 
-#: ref-filter.c:319
-#, c-format
-msgid "unrecognized %%(if) argument: %s"
-msgstr "неопознанный аргумент %%(if): %s"
+#: help.c:305
+msgid "git commands available from elsewhere on your $PATH"
+msgstr "команды git, доступные в других местах вашего $PATH"
 
-#: ref-filter.c:409
-#, c-format
-msgid "malformed field name: %.*s"
-msgstr "неправильное имя поля: %.*s"
+#: help.c:314
+msgid "These are common Git commands used in various situations:"
+msgstr "Стандартные команды Git используемые в различных ситуациях:"
 
-#: ref-filter.c:435
+#: help.c:363 git.c:97
 #, c-format
-msgid "unknown field name: %.*s"
-msgstr "неизвестное имя поля: %.*s"
+msgid "unsupported command listing type '%s'"
+msgstr "неподдерживаемый тип списка команд «%s»"
 
-#: ref-filter.c:547
-#, c-format
-msgid "format: %%(if) atom used without a %%(then) atom"
-msgstr "формат: частица %%(if) использована без частицы %%(then)"
+#: help.c:403
+msgid "The common Git guides are:"
+msgstr "Основные руководства Git:"
 
-#: ref-filter.c:607
-#, c-format
-msgid "format: %%(then) atom used without an %%(if) atom"
-msgstr "формат: частица %%(then) использована без частицы %%(if)"
+#: help.c:512
+msgid "See 'git help <command>' to read about a specific subcommand"
+msgstr "Запустите «git help <команда>», чтобы прочесть о конкретной подкоманде"
 
-#: ref-filter.c:609
-#, c-format
-msgid "format: %%(then) atom used more than once"
-msgstr "формат: частица %%(then) использована более одного раза"
+#: help.c:517
+msgid "External commands"
+msgstr ""
 
-#: ref-filter.c:611
-#, c-format
-msgid "format: %%(then) atom used after %%(else)"
-msgstr "формат: частица %%(then) использована после %%(else)"
+#: help.c:532
+msgid "Command aliases"
+msgstr ""
 
-#: ref-filter.c:637
+#: help.c:596
 #, c-format
-msgid "format: %%(else) atom used without an %%(if) atom"
-msgstr "формат: частица %%(else) использована без частицы %%(if)"
+msgid ""
+"'%s' appears to be a git command, but we were not\n"
+"able to execute it. Maybe git-%s is broken?"
+msgstr "«%s» похоже на команду git, но нам не удалось ее запустить. Возможно, git-%s  не работает?"
 
-#: ref-filter.c:639
-#, c-format
-msgid "format: %%(else) atom used without a %%(then) atom"
-msgstr "формат: частица %%(else) использована без частицы %%(then)"
+#: help.c:655
+msgid "Uh oh. Your system reports no Git commands at all."
+msgstr "Ой-ёй! Ваша система не сообщает ни о каких командах Git вообще."
 
-#: ref-filter.c:641
+#: help.c:677
 #, c-format
-msgid "format: %%(else) atom used more than once"
-msgstr "формат: частица %%(else) использована более одного раза"
+msgid "WARNING: You called a Git command named '%s', which does not exist."
+msgstr "Внимание: Вы запустили не существующую команду Git «%s»."
 
-#: ref-filter.c:654
+#: help.c:682
 #, c-format
-msgid "format: %%(end) atom used without corresponding atom"
-msgstr "формат: частица %%(end) использована без соответствующей частицы"
+msgid "Continuing under the assumption that you meant '%s'."
+msgstr "Продолжаю, предполагая, что вы имели в виду «%s»."
 
-#: ref-filter.c:709
+#: help.c:687
 #, c-format
-msgid "malformed format string %s"
-msgstr "неправильная строка формата %s"
+msgid "Continuing in %0.1f seconds, assuming that you meant '%s'."
+msgstr "Продолжу через %0.1f секунд, предполагая, что вы имели в виду «%s»."
 
-#: ref-filter.c:1313
+#: help.c:695
 #, c-format
-msgid "(no branch, rebasing %s)"
-msgstr "(нет ветки, перемещение %s)"
+msgid "git: '%s' is not a git command. See 'git --help'."
+msgstr "git: «%s» не является командой git. Смотрите «git --help»."
 
-#: ref-filter.c:1316
-#, c-format
-msgid "(no branch, bisect started on %s)"
-msgstr "(нет ветки, двоичный поиск начат на %s)"
+#: help.c:699
+msgid ""
+"\n"
+"The most similar command is"
+msgid_plural ""
+"\n"
+"The most similar commands are"
+msgstr[0] "\nСамые похожие команды:"
+msgstr[1] "\nСамые похожие команды:"
+msgstr[2] "\nСамые похожие команды:"
+msgstr[3] "\nСамые похожие команды:"
 
-#. TRANSLATORS: make sure this matches "HEAD
-#. detached at " in wt-status.c
-#: ref-filter.c:1324
-#, c-format
-msgid "(HEAD detached at %s)"
-msgstr "(HEAD отделён на %s)"
+#: help.c:714
+msgid "git version [<options>]"
+msgstr "git version [<options>]"
 
-#. TRANSLATORS: make sure this matches "HEAD
-#. detached from " in wt-status.c
-#: ref-filter.c:1331
+#: help.c:782
 #, c-format
-msgid "(HEAD detached from %s)"
-msgstr "(HEAD отделён начиная с %s)"
+msgid "%s: %s - %s"
+msgstr "%s: %s — %s"
 
-#: ref-filter.c:1335
-msgid "(no branch)"
-msgstr "(нет ветки)"
+#: help.c:786
+msgid ""
+"\n"
+"Did you mean this?"
+msgid_plural ""
+"\n"
+"Did you mean one of these?"
+msgstr[0] "\nВозможно, вы имели в виду это?"
+msgstr[1] "\nВозможно, вы имели в виду что-то из этого?"
+msgstr[2] "\nВозможно, вы имели в виду что-то из этого?"
+msgstr[3] "\nВозможно, вы имели в виду что-то из этого?"
 
-#: ref-filter.c:1488 ref-filter.c:1519
-#, c-format
-msgid "missing object %s for %s"
-msgstr "не найден объект %s для %s"
+#: ident.c:349
+msgid ""
+"\n"
+"*** Please tell me who you are.\n"
+"\n"
+"Run\n"
+"\n"
+"  git config --global user.email \"you@example.com\"\n"
+"  git config --global user.name \"Your Name\"\n"
+"\n"
+"to set your account's default identity.\n"
+"Omit --global to set the identity only in this repository.\n"
+"\n"
+msgstr "\n*** Пожалуйста, скажите мне кто вы есть.\n\nЗапустите\n\n  git config --global user.email \"you@example.com\"\n  git config --global user.name \"Ваше Имя\"\n\nдля указания идентификационных данных аккаунта по умолчанию.\nПропустите параметр --global для указания данных только для этого репозитория.\n\n"
 
-#: ref-filter.c:1491 ref-filter.c:1522
-#, c-format
-msgid "parse_object_buffer failed on %s for %s"
-msgstr "сбой при выполнении parse_object_buffer на %s для %s"
+#: ident.c:379
+msgid "no email was given and auto-detection is disabled"
+msgstr "адрес электронной почты не указан и автоопределение отключено"
 
-#: ref-filter.c:1822
+#: ident.c:384
 #, c-format
-msgid "malformed object at '%s'"
-msgstr "Повреждённый объект «%s»"
+msgid "unable to auto-detect email address (got '%s')"
+msgstr "не удалось выполнить автоопределение адреса электронной почты (получено «%s»)"
+
+#: ident.c:401
+msgid "no name was given and auto-detection is disabled"
+msgstr "имя не указано и автоопределение отключено"
 
-#: ref-filter.c:1889
+#: ident.c:407
 #, c-format
-msgid "ignoring ref with broken name %s"
-msgstr "игнорирую ссылку с неправильным именем %s"
+msgid "unable to auto-detect name (got '%s')"
+msgstr "не удалось выполнить автоопределение имени (получено «%s»)"
 
-#: ref-filter.c:1894
+#: ident.c:415
 #, c-format
-msgid "ignoring broken ref %s"
-msgstr "игнорирую неправильную ссылку %s"
+msgid "empty ident name (for <%s>) not allowed"
+msgstr "пустое имя идентификатора (для <%s>) не разрешено"
 
-#: ref-filter.c:2156
+#: ident.c:421
 #, c-format
-msgid "format: %%(end) atom missing"
-msgstr "format: пропущена частица %%(end)"
+msgid "name consists only of disallowed characters: %s"
+msgstr "имя состоит только из неразрешенных симоволов: %s"
 
-#: ref-filter.c:2250
+#: ident.c:436 builtin/commit.c:608
 #, c-format
-msgid "malformed object name %s"
-msgstr "неправильное имя объекта %s"
+msgid "invalid date format: %s"
+msgstr "неправильный формат даты: %s"
 
-#: remote.c:780
+#: list-objects.c:129
 #, c-format
-msgid "Cannot fetch both %s and %s to %s"
-msgstr "Нельзя извлечь одновременно %s и %s в %s"
+msgid "entry '%s' in tree %s has tree mode, but is not a tree"
+msgstr ""
 
-#: remote.c:784
+#: list-objects.c:142
 #, c-format
-msgid "%s usually tracks %s, not %s"
-msgstr "%s обычно отслеживает %s, а не %s"
+msgid "entry '%s' in tree %s has blob mode, but is not a blob"
+msgstr ""
 
-#: remote.c:788
+#: list-objects.c:378
 #, c-format
-msgid "%s tracks both %s and %s"
-msgstr "%s отслеживает и %s и %s"
+msgid "unable to load root tree for commit %s"
+msgstr ""
 
-#: remote.c:796
-msgid "Internal error"
-msgstr "Внутренняя ошибка"
+#: list-objects-filter-options.c:36
+msgid "multiple filter-specs cannot be combined"
+msgstr "невозможно объединять фильтрацию с помощью нескольких спецификаций"
 
-#: remote.c:1711 remote.c:1813
-msgid "HEAD does not point to a branch"
-msgstr "HEAD не указывает на ветку"
+#: list-objects-filter-options.c:58
+msgid "expected 'tree:<depth>'"
+msgstr ""
+
+#: list-objects-filter-options.c:84
+msgid "sparse:path filters support has been dropped"
+msgstr ""
 
-#: remote.c:1720
+#: list-objects-filter-options.c:158
+msgid "cannot change partial clone promisor remote"
+msgstr "нельзя изменить внешний репозиторий при частичном клонировании"
+
+#: lockfile.c:151
 #, c-format
-msgid "no such branch: '%s'"
-msgstr "нет такой ветки: «%s»"
+msgid ""
+"Unable to create '%s.lock': %s.\n"
+"\n"
+"Another git process seems to be running in this repository, e.g.\n"
+"an editor opened by 'git commit'. Please make sure all processes\n"
+"are terminated then try again. If it still fails, a git process\n"
+"may have crashed in this repository earlier:\n"
+"remove the file manually to continue."
+msgstr "Не удалось создать «%s.lock»: %s.\n\nПохоже, что другой процесс git запущен в этом репозитории,\nнапример редактор открыт из «git commit». Пожалуйста, убедитесь,\nчто все процессы были завершены и потом попробуйте снова.\nЕсли это не поможет, то возможно процесс git был ранее завершен\nс ошибкой в этом репозитории: \nудалите файл вручную для продолжения."
 
-#: remote.c:1723
+#: lockfile.c:159
 #, c-format
-msgid "no upstream configured for branch '%s'"
-msgstr "вышестоящая ветка не настроена для ветки «%s»"
+msgid "Unable to create '%s.lock': %s"
+msgstr "Не удалось создать «%s.lock»: %s"
+
+#: merge.c:41
+msgid "failed to read the cache"
+msgstr "сбой чтения кэша"
+
+#: merge.c:107 rerere.c:720 builtin/am.c:1887 builtin/am.c:1921
+#: builtin/checkout.c:461 builtin/checkout.c:811 builtin/clone.c:773
+#: builtin/stash.c:264
+msgid "unable to write new index file"
+msgstr "не удалось записать новый файл индекса"
 
-#: remote.c:1729
+#: merge-recursive.c:322
+msgid "(bad commit)\n"
+msgstr "(плохой коммит)\n"
+
+#: merge-recursive.c:345
 #, c-format
-msgid "upstream branch '%s' not stored as a remote-tracking branch"
-msgstr "вышестоящая ветка «%s» не сохранена как отслеживаемая ветка"
+msgid "add_cacheinfo failed for path '%s'; merge aborting."
+msgstr "сбой add_cacheinfo для пути «%s»; отмена слияния."
 
-#: remote.c:1744
+#: merge-recursive.c:354
 #, c-format
-msgid "push destination '%s' on remote '%s' has no local tracking branch"
-msgstr "назначение для отправки «%s» на внешнем сервере «%s» не имеет локальной отслеживаемой ветки"
+msgid "add_cacheinfo failed to refresh for path '%s'; merge aborting."
+msgstr "сбой обновления add_cacheinfo для пути «%s»; отмена слияния."
+
+#: merge-recursive.c:437
+msgid "error building trees"
+msgstr "ошибка при построении деревьев"
 
-#: remote.c:1756
+#: merge-recursive.c:861
 #, c-format
-msgid "branch '%s' has no remote for pushing"
-msgstr "ветка «%s» не имеет внешнего сервера для отправки"
+msgid "failed to create path '%s'%s"
+msgstr "не удалось создать путь «%s»%s"
 
-#: remote.c:1767
+#: merge-recursive.c:872
 #, c-format
-msgid "push refspecs for '%s' do not include '%s'"
-msgstr "спецификаторы пути для отправки «%s» не включают в себя «%s»"
+msgid "Removing %s to make room for subdirectory\n"
+msgstr "Удаление %s, чтобы освободить место для подкаталогов\n"
 
-#: remote.c:1780
-msgid "push has no destination (push.default is 'nothing')"
-msgstr "отправка не имеет точки назначения (push.default выставлен в «nothing»)"
+#: merge-recursive.c:886 merge-recursive.c:905
+msgid ": perhaps a D/F conflict?"
+msgstr ": возможно, конфликт каталогов/файлов?"
 
-#: remote.c:1802
-msgid "cannot resolve 'simple' push to a single destination"
-msgstr "не удалось выполнить «simple» отправку в единственную точку назначения"
+#: merge-recursive.c:895
+#, c-format
+msgid "refusing to lose untracked file at '%s'"
+msgstr "отказ потери неотслеживаемого файла в «%s»"
 
-#: remote.c:2106
+#: merge-recursive.c:936 builtin/cat-file.c:40
 #, c-format
-msgid "Your branch is based on '%s', but the upstream is gone.\n"
-msgstr "Ваша ветка базируется на «%s», но вышестоящий репозиторий исчез.\n"
+msgid "cannot read object %s '%s'"
+msgstr "невозможно прочитать объект %s «%s»"
 
-#: remote.c:2110
-msgid "  (use \"git branch --unset-upstream\" to fixup)\n"
-msgstr "(для исправления запустите «git branch --unset-upstream»)\n"
+#: merge-recursive.c:939
+#, c-format
+msgid "blob expected for %s '%s'"
+msgstr "ожидается двоичный объект для %s «%s»"
 
-#: remote.c:2113
+#: merge-recursive.c:963
 #, c-format
-msgid "Your branch is up to date with '%s'.\n"
-msgstr "Ваша ветка обновлена в соответствии с «%s».\n"
+msgid "failed to open '%s': %s"
+msgstr "не удалось открыть «%s»: %s"
 
-#: remote.c:2117
+#: merge-recursive.c:974
 #, c-format
-msgid "Your branch is ahead of '%s' by %d commit.\n"
-msgid_plural "Your branch is ahead of '%s' by %d commits.\n"
-msgstr[0] "Ваша ветка опережает «%s» на %d коммит.\n"
-msgstr[1] "Ваша ветка опережает «%s» на %d коммита.\n"
-msgstr[2] "Ваша ветка опережает «%s» на %d коммитов.\n"
-msgstr[3] "Ваша ветка опережает «%s» на %d коммитов.\n"
+msgid "failed to symlink '%s': %s"
+msgstr "не удалось создать символьную ссылку «%s»: %s"
 
-#: remote.c:2123
-msgid "  (use \"git push\" to publish your local commits)\n"
-msgstr "  (используйте «git push», чтобы опубликовать ваши локальные коммиты)\n"
+#: merge-recursive.c:979
+#, c-format
+msgid "do not know what to do with %06o %s '%s'"
+msgstr "не понятно, что делать с %06o %s «%s»"
 
-#: remote.c:2126
+#: merge-recursive.c:1175
 #, c-format
-msgid "Your branch is behind '%s' by %d commit, and can be fast-forwarded.\n"
-msgid_plural ""
-"Your branch is behind '%s' by %d commits, and can be fast-forwarded.\n"
-msgstr[0] "Ваша ветка отстает от «%s» на %d коммит и может быть перемотана вперед.\n"
-msgstr[1] "Ваша ветка отстает от «%s» на %d коммита и может быть перемотана вперед.\n"
-msgstr[2] "Ваша ветка отстает от «%s» на %d коммитов и может быть перемотана вперед.\n"
-msgstr[3] "Ваша ветка отстает от «%s» на %d коммитов и может быть перемотана вперед.\n"
+msgid "Failed to merge submodule %s (not checked out)"
+msgstr "Не удалось слить подмодуль %s (состояние не забрано)"
 
-#: remote.c:2134
-msgid "  (use \"git pull\" to update your local branch)\n"
-msgstr "  (используйте «git pull», чтобы обновить вашу локальную ветку)\n"
+#: merge-recursive.c:1182
+#, c-format
+msgid "Failed to merge submodule %s (commits not present)"
+msgstr "Не удалось слить подмодуль %s (нет коммитов)"
 
-#: remote.c:2137
+#: merge-recursive.c:1189
 #, c-format
-msgid ""
-"Your branch and '%s' have diverged,\n"
-"and have %d and %d different commit each, respectively.\n"
-msgid_plural ""
-"Your branch and '%s' have diverged,\n"
-"and have %d and %d different commits each, respectively.\n"
-msgstr[0] "Ваша ветка и «%s» разделились\nи теперь имеют %d и %d разный коммит в каждой соответственно.\n"
-msgstr[1] "Ваша ветка и «%s» разделились\nи теперь имеют %d и %d разных коммита в каждой соответственно.\n"
-msgstr[2] "Ваша ветка и «%s» разделились\nи теперь имеют %d и %d разных коммитов в каждой соответственно.\n"
-msgstr[3] "Ваша ветка и «%s» разделились\nи теперь имеют %d и %d разных коммитов в каждой соответственно.\n"
+msgid "Failed to merge submodule %s (commits don't follow merge-base)"
+msgstr "Не удалось слить подмодуль %s (у коммитов другая база слияния)"
 
-#: remote.c:2147
-msgid "  (use \"git pull\" to merge the remote branch into yours)\n"
-msgstr "  (используйте «git pull», чтобы слить внешнюю ветку в вашу)\n"
+#: merge-recursive.c:1197 merge-recursive.c:1209
+#, c-format
+msgid "Fast-forwarding submodule %s to the following commit:"
+msgstr "Перемотка вперед подмодуля %s до указанного коммита:"
 
-#: revision.c:2268
-msgid "your current branch appears to be broken"
-msgstr "похоже, ваша текущая ветка повреждена"
+#: merge-recursive.c:1200 merge-recursive.c:1212
+#, c-format
+msgid "Fast-forwarding submodule %s"
+msgstr "Перемотка вперед подмодуля %s"
 
-#: revision.c:2271
+#: merge-recursive.c:1235
 #, c-format
-msgid "your current branch '%s' does not have any commits yet"
-msgstr "ваша текущая ветка «%s» еще не содержит ни одного коммита"
+msgid "Failed to merge submodule %s (merge following commits not found)"
+msgstr "Не удалось слить подмодуль %s (нет указанных коммитов для слияния)"
 
-#: revision.c:2465
-msgid "--first-parent is incompatible with --bisect"
-msgstr "опцию --first-parent нельзя использовать одновременно с --bisect"
+#: merge-recursive.c:1239
+#, c-format
+msgid "Failed to merge submodule %s (not fast-forward)"
+msgstr "Не удалось слить подмодуль %s (нельзя сделать перемотку вперед)"
 
-#: run-command.c:645
-msgid "open /dev/null failed"
-msgstr "сбой открытия /dev/null"
+#: merge-recursive.c:1240
+msgid "Found a possible merge resolution for the submodule:\n"
+msgstr "Найдено возможное разрешение слиятия для подмодуля:\n"
 
-#: run-command.c:1188
+#: merge-recursive.c:1243
 #, c-format
 msgid ""
-"The '%s' hook was ignored because it's not set as executable.\n"
-"You can disable this warning with `git config advice.ignoredHook false`."
-msgstr "Перехватчик «%s» был проигнорирован, так как он не установлен как исполняемый.\nВы можете отключить это предупреждение с помощью команды «git config advice.ignoredHook false»."
+"If this is correct simply add it to the index for example\n"
+"by using:\n"
+"\n"
+"  git update-index --cacheinfo 160000 %s \"%s\"\n"
+"\n"
+"which will accept this suggestion.\n"
+msgstr "Если оно верное, то просто добавьте его в индекс, например так:\n\n  git update-index --cacheinfo 160000 %s \"%s\"\n\nтем самым принимая это предположение.\n"
 
-#: send-pack.c:141
+#: merge-recursive.c:1252
 #, c-format
-msgid "unable to parse remote unpack status: %s"
-msgstr "не удалось разобрать статус внешней распаковки: %s"
+msgid "Failed to merge submodule %s (multiple merges found)"
+msgstr "Не удалось слить подмодуль %s (найдено несколько слияний)"
 
-#: send-pack.c:143
+#: merge-recursive.c:1325
+msgid "Failed to execute internal merge"
+msgstr "Не удалось запустить внутреннее слияние"
+
+#: merge-recursive.c:1330
 #, c-format
-msgid "remote unpack failed: %s"
-msgstr "сбой при внешней распаковке %s"
+msgid "Unable to add %s to database"
+msgstr "Не удалось добавить %s в базу данных"
 
-#: send-pack.c:306
-msgid "failed to sign the push certificate"
-msgstr "сбой подписания сертификата отправки"
+#: merge-recursive.c:1362
+#, c-format
+msgid "Auto-merging %s"
+msgstr "Автослияние %s"
 
-#: send-pack.c:419
-msgid "the receiving end does not support --signed push"
-msgstr "принимающая сторона не поддерживает отправку с опцией --signed"
+#: merge-recursive.c:1385
+#, c-format
+msgid "Error: Refusing to lose untracked file at %s; writing to %s instead."
+msgstr "Ошибка: Отказ потери неотслеживаемого файла %s; запись в %s взамен."
 
-#: send-pack.c:421
+#: merge-recursive.c:1457
+#, c-format
 msgid ""
-"not sending a push certificate since the receiving end does not support "
-"--signed push"
-msgstr "не отправляем сертификат для отправки, так как принимающая сторона не поддерживает отправку с опцией --signed"
-
-#: send-pack.c:433
-msgid "the receiving end does not support --atomic push"
-msgstr "принимающая сторона не поддерживает отправку с опцией --atomic"
-
-#: send-pack.c:438
-msgid "the receiving end does not support push options"
-msgstr "принимающая сторона не поддерживает отправку с опциями"
-
-#: sequencer.c:218
-msgid "revert"
-msgstr "обратить изменения"
-
-#: sequencer.c:220
-msgid "cherry-pick"
-msgstr "копировать коммит"
-
-#: sequencer.c:222
-msgid "rebase -i"
-msgstr "rebase -i"
+"CONFLICT (%s/delete): %s deleted in %s and %s in %s. Version %s of %s left "
+"in tree."
+msgstr "КОНФЛИКТ (%s/удаление): %s удалено в %s и %s в %s. Версия %s из %s оставлена в дереве."
 
-#: sequencer.c:224
+#: merge-recursive.c:1462
 #, c-format
-msgid "Unknown action: %d"
-msgstr "Неизвестное действие: %d"
-
-#: sequencer.c:281
 msgid ""
-"after resolving the conflicts, mark the corrected paths\n"
-"with 'git add <paths>' or 'git rm <paths>'"
-msgstr "после разрешения конфликтов, пометьте исправленные пути\nс помощью «git add <пути>» или «git rm <пути>»"
+"CONFLICT (%s/delete): %s deleted in %s and %s to %s in %s. Version %s of %s "
+"left in tree."
+msgstr "КОНФЛИКТ (%s/удаление): %s удалено в %s и от %s до %s в %s. Версия %s из %s оставлена в дереве."
 
-#: sequencer.c:284
+#: merge-recursive.c:1469
+#, c-format
 msgid ""
-"after resolving the conflicts, mark the corrected paths\n"
-"with 'git add <paths>' or 'git rm <paths>'\n"
-"and commit the result with 'git commit'"
-msgstr "после разрешения конфликтов, пометьте исправленные пути\nс помощью «git add <пути>» или «git rm <пути>»\nи сделайте коммит с помощью «git commit»"
+"CONFLICT (%s/delete): %s deleted in %s and %s in %s. Version %s of %s left "
+"in tree at %s."
+msgstr "КОНФЛИКТ (%s/удаление): %s удалено в %s и %s в %s. Версия %s из %s оставлена в дереве на %s."
 
-#: sequencer.c:297 sequencer.c:1718
+#: merge-recursive.c:1474
 #, c-format
-msgid "could not lock '%s'"
-msgstr "не удалось заблокировать «%s»"
+msgid ""
+"CONFLICT (%s/delete): %s deleted in %s and %s to %s in %s. Version %s of %s "
+"left in tree at %s."
+msgstr "КОНФЛИКТ (%s/удаление): %s удалено в %s и от %s до %s в %s. Версия %s из %s оставлена в дереве на %s."
 
-#: sequencer.c:300 sequencer.c:1595 sequencer.c:1723 sequencer.c:1737
-#: sequencer.c:2729 sequencer.c:2800 wrapper.c:656
-#, c-format
-msgid "could not write to '%s'"
-msgstr "не удалось записать в «%s»"
+#: merge-recursive.c:1509
+msgid "rename"
+msgstr "переименование"
 
-#: sequencer.c:304
-#, c-format
-msgid "could not write eol to '%s'"
-msgstr "не удалось записать eol в «%s»"
+#: merge-recursive.c:1509
+msgid "renamed"
+msgstr "переименовано"
 
-#: sequencer.c:308 sequencer.c:1600 sequencer.c:1725
+#: merge-recursive.c:1589 merge-recursive.c:2445 merge-recursive.c:3085
 #, c-format
-msgid "failed to finalize '%s'."
-msgstr "не удалось завершить «%s»."
+msgid "Refusing to lose dirty file at %s"
+msgstr "Отказ потери изменённого файла %s"
 
-#: sequencer.c:332 sequencer.c:829 sequencer.c:1621 builtin/am.c:259
-#: builtin/commit.c:754 builtin/merge.c:1046
+#: merge-recursive.c:1599
 #, c-format
-msgid "could not read '%s'"
-msgstr "не удалось прочитать «%s»"
+msgid "Refusing to lose untracked file at %s, even though it's in the way."
+msgstr "Отказ потери неотслеживаемого файла %s, даже с учетом его наличия."
 
-#: sequencer.c:358
+#: merge-recursive.c:1657
 #, c-format
-msgid "your local changes would be overwritten by %s."
-msgstr "ваши локальные изменения будут перезаписаны %s."
+msgid "CONFLICT (rename/add): Rename %s->%s in %s.  Added %s in %s"
+msgstr ""
 
-#: sequencer.c:362
-msgid "commit your changes or stash them to proceed."
-msgstr "для продолжения закоммитьте ваши изменения или спрячьте их."
+#: merge-recursive.c:1687
+#, c-format
+msgid "%s is a directory in %s adding as %s instead"
+msgstr "%s — это каталог в %s, добавляем как %s вместо этого"
 
-#: sequencer.c:391
+#: merge-recursive.c:1692
 #, c-format
-msgid "%s: fast-forward"
-msgstr "%s: перемотка вперед"
+msgid "Refusing to lose untracked file at %s; adding as %s instead"
+msgstr "Отказ потери неотслеживаемого файла %s; добавление как %s взамен."
 
-#. TRANSLATORS: %s will be "revert", "cherry-pick" or
-#. "rebase -i".
-#: sequencer.c:477
+#: merge-recursive.c:1711
 #, c-format
-msgid "%s: Unable to write new index file"
-msgstr "%s: Не удалось записать файл индекса"
+msgid ""
+"CONFLICT (rename/rename): Rename \"%s\"->\"%s\" in branch \"%s\" rename "
+"\"%s\"->\"%s\" in \"%s\"%s"
+msgstr "КОНФЛИКТ (переименование/переименование): Переименование «%s»→«%s» в ветке «%s» и переименование «%s»→«%s» в ветке «%s»%s"
 
-#: sequencer.c:496
-msgid "could not resolve HEAD commit"
-msgstr "не удалось распознать HEAD коммит"
+#: merge-recursive.c:1716
+msgid " (left unresolved)"
+msgstr " (оставлено неразрешенным)"
 
-#: sequencer.c:516
-msgid "unable to update cache tree"
-msgstr "не удалось обновить дерево кэша"
+#: merge-recursive.c:1825
+#, c-format
+msgid "CONFLICT (rename/rename): Rename %s->%s in %s. Rename %s->%s in %s"
+msgstr "КОНФЛИКТ (переименование/переименование): Переименование «%s»→«%s» в ветке «%s» и переименование «%s»→«%s» в ветке «%s»"
 
-#: sequencer.c:600
+#: merge-recursive.c:2030
 #, c-format
 msgid ""
-"you have staged changes in your working tree\n"
-"If these changes are meant to be squashed into the previous commit, run:\n"
-"\n"
-"  git commit --amend %s\n"
-"\n"
-"If they are meant to go into a new commit, run:\n"
-"\n"
-"  git commit %s\n"
-"\n"
-"In both cases, once you're done, continue with:\n"
-"\n"
-"  git rebase --continue\n"
-msgstr "у вас имеются проиндексированные изменения в рабочем каталоге. Если эти изменения должны быть объеденены с предыдущим коммитом, то запустите:\n\n  git commit --amend %s\n\nЕсли же они должны быть помещены в новый коммит, то запустите:\n\n  git commit %s\n\nВ любом случае, после того как вы закончите, продолжить перемещение можно выполнив:\n\n  git rebase --continue\n"
+"CONFLICT (directory rename split): Unclear where to place %s because "
+"directory %s was renamed to multiple other directories, with no destination "
+"getting a majority of the files."
+msgstr ""
 
-#: sequencer.c:702
+#: merge-recursive.c:2062
 #, c-format
-msgid "could not parse commit %s"
-msgstr "не удалось разобрать коммит %s"
+msgid ""
+"CONFLICT (implicit dir rename): Existing file/dir at %s in the way of "
+"implicit directory rename(s) putting the following path(s) there: %s."
+msgstr ""
 
-#: sequencer.c:707
+#: merge-recursive.c:2072
 #, c-format
-msgid "could not parse parent commit %s"
-msgstr "не удалось разобрать родительский коммит %s"
+msgid ""
+"CONFLICT (implicit dir rename): Cannot map more than one path to %s; "
+"implicit directory renames tried to put these paths there: %s"
+msgstr ""
 
-#: sequencer.c:836
+#: merge-recursive.c:2164
 #, c-format
 msgid ""
-"unexpected 1st line of squash message:\n"
-"\n"
-"\t%.*s"
-msgstr "неожиданная первая строка сообщения уплотнения:\n\n\t%.*s"
+"CONFLICT (rename/rename): Rename directory %s->%s in %s. Rename directory "
+"%s->%s in %s"
+msgstr ""
 
-#: sequencer.c:842
+#: merge-recursive.c:2408
 #, c-format
 msgid ""
-"invalid 1st line of squash message:\n"
-"\n"
-"\t%.*s"
-msgstr "недопустимая первая строка сообщения уплотнения:\n\n\t%.*s"
+"WARNING: Avoiding applying %s -> %s rename to %s, because %s itself was "
+"renamed."
+msgstr ""
 
-#: sequencer.c:848 sequencer.c:873
+#: merge-recursive.c:2929
 #, c-format
-msgid "This is a combination of %d commits."
-msgstr "Это объединение %d коммитов."
+msgid "cannot read object %s"
+msgstr "невозможно прочитать объект «%s»"
 
-#: sequencer.c:857 sequencer.c:2748
-msgid "need a HEAD to fixup"
-msgstr "нужен HEAD для исправления"
+#: merge-recursive.c:2932
+#, c-format
+msgid "object %s is not a blob"
+msgstr "объект %s не является двоичным объектом"
 
-#: sequencer.c:859
-msgid "could not read HEAD"
-msgstr "не удалось прочитать HEAD"
+#: merge-recursive.c:2996
+msgid "modify"
+msgstr "изменение"
 
-#: sequencer.c:861
-msgid "could not read HEAD's commit message"
-msgstr "не удалось прочитать сообщение коммита текущего HEAD"
+#: merge-recursive.c:2996
+msgid "modified"
+msgstr "изменено"
 
-#: sequencer.c:867
-#, c-format
-msgid "cannot write '%s'"
-msgstr "не удалось записать «%s»"
+#: merge-recursive.c:3008
+msgid "content"
+msgstr "содержимое"
 
-#: sequencer.c:876 git-rebase--interactive.sh:446
-msgid "This is the 1st commit message:"
-msgstr "Это 1-е сообщение коммита:"
+#: merge-recursive.c:3012
+msgid "add/add"
+msgstr "добавление/добавление"
 
-#: sequencer.c:884
+#: merge-recursive.c:3035
 #, c-format
-msgid "could not read commit message of %s"
-msgstr "не удалось прочитать сообщение коммита для %s"
+msgid "Skipped %s (merged same as existing)"
+msgstr "Пропуск %s (слиты одинаковые изменения как существующие)"
 
-#: sequencer.c:891
-#, c-format
-msgid "This is the commit message #%d:"
-msgstr "Это сообщение коммита номер #%d:"
+#: merge-recursive.c:3057 git-submodule.sh:937
+msgid "submodule"
+msgstr "подмодуль"
 
-#: sequencer.c:896
+#: merge-recursive.c:3058
 #, c-format
-msgid "The commit message #%d will be skipped:"
-msgstr "Сообщение коммита номер #%d будет пропущено:"
+msgid "CONFLICT (%s): Merge conflict in %s"
+msgstr "КОНФЛИКТ (%s): Конфликт слияния в %s"
 
-#: sequencer.c:901
+#: merge-recursive.c:3088
 #, c-format
-msgid "unknown command: %d"
-msgstr "неизвестная команда: %d"
+msgid "Adding as %s instead"
+msgstr "Добавление вместо этого как %s"
 
-#: sequencer.c:967
-msgid "your index file is unmerged."
-msgstr "ваш индекс не слит."
+#: merge-recursive.c:3170
+#, c-format
+msgid ""
+"Path updated: %s added in %s inside a directory that was renamed in %s; "
+"moving it to %s."
+msgstr ""
 
-#: sequencer.c:986
+#: merge-recursive.c:3173
 #, c-format
-msgid "commit %s is a merge but no -m option was given."
-msgstr "коммит %s — это коммит-слияние, но опция -m не указана."
+msgid ""
+"CONFLICT (file location): %s added in %s inside a directory that was renamed"
+" in %s, suggesting it should perhaps be moved to %s."
+msgstr ""
 
-#: sequencer.c:994
+#: merge-recursive.c:3177
 #, c-format
-msgid "commit %s does not have parent %d"
-msgstr "у коммита %s нет предка %d"
+msgid ""
+"Path updated: %s renamed to %s in %s, inside a directory that was renamed in"
+" %s; moving it to %s."
+msgstr ""
 
-#: sequencer.c:998
+#: merge-recursive.c:3180
 #, c-format
-msgid "mainline was specified but commit %s is not a merge."
-msgstr "основная ветка указана, но коммит %s не является слиянием."
+msgid ""
+"CONFLICT (file location): %s renamed to %s in %s, inside a directory that "
+"was renamed in %s, suggesting it should perhaps be moved to %s."
+msgstr ""
 
-#: sequencer.c:1004
+#: merge-recursive.c:3294
 #, c-format
-msgid "cannot get commit message for %s"
-msgstr "не удалось получить сообщение коммита для %s"
+msgid "Removing %s"
+msgstr "Удаление %s"
 
-#. TRANSLATORS: The first %s will be a "todo" command like
-#. "revert" or "pick", the second %s a SHA1.
-#: sequencer.c:1023
+#: merge-recursive.c:3317
+msgid "file/directory"
+msgstr "файл/каталог"
+
+#: merge-recursive.c:3322
+msgid "directory/file"
+msgstr "каталог/файл"
+
+#: merge-recursive.c:3329
 #, c-format
-msgid "%s: cannot parse parent commit %s"
-msgstr "%s: не удалось разобрать родительский коммит для %s"
+msgid ""
+"CONFLICT (%s): There is a directory with name %s in %s. Adding %s as %s"
+msgstr "КОНФЛИКТ (%s): Уже существует каталог с именем «%s» в «%s». Добавление «%s» как «%s»"
 
-#: sequencer.c:1086 sequencer.c:1867
+#: merge-recursive.c:3338
 #, c-format
-msgid "could not rename '%s' to '%s'"
-msgstr "не удалось переименовать «%s» в «%s»"
+msgid "Adding %s"
+msgstr "Добавление %s"
 
-#: sequencer.c:1137
+#: merge-recursive.c:3347
 #, c-format
-msgid "could not revert %s... %s"
-msgstr "не удалось обратить изменения коммита %s… %s"
+msgid "CONFLICT (add/add): Merge conflict in %s"
+msgstr ""
 
-#: sequencer.c:1138
+#: merge-recursive.c:3385
 #, c-format
-msgid "could not apply %s... %s"
-msgstr "не удалось применить коммит %s… %s"
+msgid ""
+"Your local changes to the following files would be overwritten by merge:\n"
+"  %s"
+msgstr ""
 
-#: sequencer.c:1180
-msgid "empty commit set passed"
-msgstr "передан пустой набор коммитов"
+#: merge-recursive.c:3396
+msgid "Already up to date!"
+msgstr "Уже обновлено!"
 
-#: sequencer.c:1190
+#: merge-recursive.c:3405
 #, c-format
-msgid "git %s: failed to read the index"
-msgstr "git %s: сбой чтения индекса"
+msgid "merging of trees %s and %s failed"
+msgstr "сбой слияния деревьев «%s» и «%s»"
+
+#: merge-recursive.c:3504
+msgid "Merging:"
+msgstr "Слияние:"
 
-#: sequencer.c:1196
+#: merge-recursive.c:3517
 #, c-format
-msgid "git %s: failed to refresh the index"
-msgstr "git %s: сбой обновления индекса"
+msgid "found %u common ancestor:"
+msgid_plural "found %u common ancestors:"
+msgstr[0] "найден %u общий предок:"
+msgstr[1] "найдено %u общих предка:"
+msgstr[2] "найдено %u общих предков:"
+msgstr[3] "найдено %u общих предков:"
+
+#: merge-recursive.c:3556
+msgid "merge returned no commit"
+msgstr "слияние не вернуло коммит"
 
-#: sequencer.c:1270
+#: merge-recursive.c:3622
 #, c-format
-msgid "%s does not accept arguments: '%s'"
-msgstr "параметр %s не принимает аргументы: «%s»"
+msgid "Could not parse object '%s'"
+msgstr "Не удалось разобрать объект «%s»"
 
-#: sequencer.c:1279
+#: merge-recursive.c:3638 builtin/merge.c:702 builtin/merge.c:873
+msgid "Unable to write index."
+msgstr "Не удается записать индекс."
+
+#: midx.c:66
 #, c-format
-msgid "missing arguments for %s"
-msgstr "пропущены аргументы для %s"
+msgid "multi-pack-index file %s is too small"
+msgstr ""
 
-#: sequencer.c:1322
+#: midx.c:82
 #, c-format
-msgid "invalid line %d: %.*s"
-msgstr "неправильная строка %d: %.*s"
+msgid "multi-pack-index signature 0x%08x does not match signature 0x%08x"
+msgstr ""
 
-#: sequencer.c:1330
+#: midx.c:87
 #, c-format
-msgid "cannot '%s' without a previous commit"
-msgstr "нельзя выполнить «%s» без указания предыдущего коммита"
+msgid "multi-pack-index version %d not recognized"
+msgstr ""
 
-#: sequencer.c:1363 sequencer.c:2525 sequencer.c:2560 sequencer.c:2642
-#: sequencer.c:2668 sequencer.c:2758 sequencer.c:2859
+#: midx.c:92
 #, c-format
-msgid "could not read '%s'."
-msgstr "не удалось прочитать «%s»."
+msgid "hash version %u does not match"
+msgstr "версия хеш-суммы %u не соответсвует"
 
-#: sequencer.c:1375
-msgid "please fix this using 'git rebase --edit-todo'."
-msgstr "пожалуйста исправьте это с помощью «git rebase --edit-todo»."
+#: midx.c:106
+msgid "invalid chunk offset (too large)"
+msgstr ""
 
-#: sequencer.c:1377
-#, c-format
-msgid "unusable instruction sheet: '%s'"
-msgstr "непригодная для использования карта с инструкциями: «%s»"
+#: midx.c:130
+msgid "terminating multi-pack-index chunk id appears earlier than expected"
+msgstr ""
 
-#: sequencer.c:1382
-msgid "no commits parsed."
-msgstr "коммиты не разобраны."
+#: midx.c:143
+msgid "multi-pack-index missing required pack-name chunk"
+msgstr ""
 
-#: sequencer.c:1393
-msgid "cannot cherry-pick during a revert."
-msgstr "нельзя скопировать коммит во время процесса обращения коммита."
+#: midx.c:145
+msgid "multi-pack-index missing required OID fanout chunk"
+msgstr ""
 
-#: sequencer.c:1395
-msgid "cannot revert during a cherry-pick."
-msgstr "нельзя обратить изменения коммита во время копирования коммита."
+#: midx.c:147
+msgid "multi-pack-index missing required OID lookup chunk"
+msgstr ""
+
+#: midx.c:149
+msgid "multi-pack-index missing required object offsets chunk"
+msgstr ""
 
-#: sequencer.c:1462
+#: midx.c:163
 #, c-format
-msgid "invalid key: %s"
-msgstr "недействительный ключ: %s"
-
-#: sequencer.c:1465
-#, c-format
-msgid "invalid value for %s: %s"
-msgstr "неправильное значение %s: %s"
+msgid "multi-pack-index pack names out of order: '%s' before '%s'"
+msgstr ""
 
-#: sequencer.c:1531
+#: midx.c:208
 #, c-format
-msgid "malformed options sheet: '%s'"
-msgstr "испорченная карта с опциями: «%s»"
+msgid "bad pack-int-id: %u (%u total packs)"
+msgstr ""
 
-#: sequencer.c:1569
-msgid "a cherry-pick or revert is already in progress"
-msgstr "копирование или обращение изменений коммита уже выполняются"
+#: midx.c:258
+msgid "multi-pack-index stores a 64-bit offset, but off_t is too small"
+msgstr ""
 
-#: sequencer.c:1570
-msgid "try \"git cherry-pick (--continue | --quit | --abort)\""
-msgstr "попробуйте «git cherry-pick (--continue | --quit | --abort)»"
+#: midx.c:286
+msgid "error preparing packfile from multi-pack-index"
+msgstr ""
 
-#: sequencer.c:1573
+#: midx.c:457
 #, c-format
-msgid "could not create sequencer directory '%s'"
-msgstr "не удалось создать каталог для указателя следования коммитов «%s»"
-
-#: sequencer.c:1588
-msgid "could not lock HEAD"
-msgstr "не удалось заблокировать HEAD"
-
-#: sequencer.c:1646 sequencer.c:2230
-msgid "no cherry-pick or revert in progress"
-msgstr "копирование или обращение изменений коммита уже выполняются"
-
-#: sequencer.c:1648
-msgid "cannot resolve HEAD"
-msgstr "не удалось определить HEAD"
-
-#: sequencer.c:1650 sequencer.c:1685
-msgid "cannot abort from a branch yet to be born"
-msgstr "нельзя отменить изменения с ветки, которая еще не создана"
+msgid "failed to add packfile '%s'"
+msgstr ""
 
-#: sequencer.c:1671 builtin/grep.c:713
+#: midx.c:463
 #, c-format
-msgid "cannot open '%s'"
-msgstr "не удалось открыть «%s»"
+msgid "failed to open pack-index '%s'"
+msgstr ""
 
-#: sequencer.c:1673
+#: midx.c:557
 #, c-format
-msgid "cannot read '%s': %s"
-msgstr "не удалось прочитать «%s»: %s"
-
-#: sequencer.c:1674
-msgid "unexpected end of file"
-msgstr "неожиданный конец файла"
+msgid "failed to locate object %d in packfile"
+msgstr ""
 
-#: sequencer.c:1680
+#: midx.c:993
 #, c-format
-msgid "stored pre-cherry-pick HEAD file '%s' is corrupt"
-msgstr "сохраненный файл с HEAD перед копированием коммита «%s» поврежден"
-
-#: sequencer.c:1691
-msgid "You seem to have moved HEAD. Not rewinding, check your HEAD!"
-msgstr "Похоже, что вы переместили HEAD. Перемотка не выполняется, проверьте свой указатель HEAD!"
+msgid "failed to clear multi-pack-index at %s"
+msgstr ""
 
-#: sequencer.c:1832 sequencer.c:2128
-msgid "cannot read HEAD"
-msgstr "не удалось прочитать HEAD"
+#: midx.c:1048
+msgid "Looking for referenced packfiles"
+msgstr ""
 
-#: sequencer.c:1872 builtin/difftool.c:639
+#: midx.c:1063
 #, c-format
-msgid "could not copy '%s' to '%s'"
-msgstr "не удалось скопировать «%s» в «%s»"
+msgid ""
+"oid fanout out of order: fanout[%d] = %<PRIx32> > %<PRIx32> = fanout[%d]"
+msgstr ""
 
-#: sequencer.c:1891
-msgid "could not read index"
-msgstr "не удалось прочитать индекс"
+#: midx.c:1067
+msgid "Verifying OID order in MIDX"
+msgstr ""
 
-#: sequencer.c:1896
+#: midx.c:1076
 #, c-format
-msgid ""
-"execution failed: %s\n"
-"%sYou can fix the problem, and then run\n"
-"\n"
-"  git rebase --continue\n"
-"\n"
-msgstr "ошибка выполнения: %s\n%sВы можете исправить ошибку, а затем запустить\n\n  git rebase --continue\n\n"
+msgid "oid lookup out of order: oid[%d] = %s >= %s = oid[%d]"
+msgstr ""
 
-#: sequencer.c:1902
-msgid "and made changes to the index and/or the working tree\n"
-msgstr "и были сделаны изменения в индексе и/или в рабочем каталоге\n"
+#: midx.c:1095
+msgid "Sorting objects by packfile"
+msgstr ""
 
-#: sequencer.c:1908
-#, c-format
-msgid ""
-"execution succeeded: %s\n"
-"but left changes to the index and/or the working tree\n"
-"Commit or stash your changes, and then run\n"
-"\n"
-"  git rebase --continue\n"
-"\n"
-msgstr "успешное выполнение: %s\nно остались изменения в индексе и/или в рабочем каталоге\nСделайте коммит или спрячьте ваши изменения, а затем выполните\n\n  git rebase --continue\n\n"
+#: midx.c:1101
+msgid "Verifying object offsets"
+msgstr ""
 
-#: sequencer.c:1967
+#: midx.c:1117
 #, c-format
-msgid "Applied autostash.\n"
-msgstr "Применены автоматически спрятанные изменения.\n"
+msgid "failed to load pack entry for oid[%d] = %s"
+msgstr ""
 
-#: sequencer.c:1979
+#: midx.c:1123
 #, c-format
-msgid "cannot store %s"
-msgstr "не удалось сохранить %s"
+msgid "failed to load pack-index for packfile %s"
+msgstr ""
 
-#: sequencer.c:1982 git-rebase.sh:175
+#: midx.c:1132
 #, c-format
-msgid ""
-"Applying autostash resulted in conflicts.\n"
-"Your changes are safe in the stash.\n"
-"You can run \"git stash pop\" or \"git stash drop\" at any time.\n"
-msgstr "Применение автоматически спрятанных изменений вызвало конфликты.\nВаши изменения спрятаны и в безопасности.\nВы можете выполнить «git stash pop» или «git stash drop» в любой момент.\n"
+msgid "incorrect object offset for oid[%d] = %s: %<PRIx64> != %<PRIx64>"
+msgstr ""
 
-#: sequencer.c:2064
+#: name-hash.c:531
 #, c-format
-msgid "Stopped at %s...  %.*s\n"
-msgstr "Остановлено на %s …  %.*s\n"
+msgid "unable to create lazy_dir thread: %s"
+msgstr ""
 
-#: sequencer.c:2106
+#: name-hash.c:553
 #, c-format
-msgid "unknown command %d"
-msgstr "неизвестная команда %d"
-
-#: sequencer.c:2136
-msgid "could not read orig-head"
-msgstr "не удалось прочитать orig-head"
-
-#: sequencer.c:2141 sequencer.c:2745
-msgid "could not read 'onto'"
-msgstr "не удалось прочитать «onto»"
+msgid "unable to create lazy_name thread: %s"
+msgstr ""
 
-#: sequencer.c:2148
+#: name-hash.c:559
 #, c-format
-msgid "could not update %s"
-msgstr "не удалось обновить %s"
+msgid "unable to join lazy_name thread: %s"
+msgstr ""
 
-#: sequencer.c:2155
+#: notes-merge.c:277
 #, c-format
-msgid "could not update HEAD to %s"
-msgstr "не удалось обновить HEAD на %s"
-
-#: sequencer.c:2239
-msgid "cannot rebase: You have unstaged changes."
-msgstr "не удалось выполнить перемещение коммитов: У вас есть непроиндексированные изменения."
+msgid ""
+"You have not concluded your previous notes merge (%s exists).\n"
+"Please, use 'git notes merge --commit' or 'git notes merge --abort' to commit/abort the previous merge before you start a new notes merge."
+msgstr "Вы не закончили предыдущее слияние заметок (%s существует).\nЗапустите «git notes merge --commit» или «git notes merge --abort» для коммита или отмены предыдущего слияния и запуска нового слияния заметок."
 
-#: sequencer.c:2244
-msgid "could not remove CHERRY_PICK_HEAD"
-msgstr "не удалось удалить CHERRY_PICK_HEAD"
+#: notes-merge.c:284
+#, c-format
+msgid "You have not concluded your notes merge (%s exists)."
+msgstr "Вы не закончили предыдущее слияние заметок (%s существует)."
 
-#: sequencer.c:2253
-msgid "cannot amend non-existing commit"
-msgstr "не удалось исправить несуществующий коммит"
+#: notes-utils.c:46
+msgid "Cannot commit uninitialized/unreferenced notes tree"
+msgstr "Нельзя закоммитить неинициализированное или не имеющее ссылок дерево заметок"
 
-#: sequencer.c:2255
+#: notes-utils.c:105
 #, c-format
-msgid "invalid file: '%s'"
-msgstr "недопустимый файл: «%s»"
+msgid "Bad notes.rewriteMode value: '%s'"
+msgstr "Неправильное значение notes.rewriteMode: «%s»"
 
-#: sequencer.c:2257
+#: notes-utils.c:115
 #, c-format
-msgid "invalid contents: '%s'"
-msgstr "недопустимое содержимое: «%s»"
+msgid "Refusing to rewrite notes in %s (outside of refs/notes/)"
+msgstr "Отказ в перезаписи заметок в %s (за пределами refs/notes/)"
 
-#: sequencer.c:2260
-msgid ""
-"\n"
-"You have uncommitted changes in your working tree. Please, commit them\n"
-"first and then run 'git rebase --continue' again."
-msgstr "\nУ вас имеются незакоммиченные изменения в рабочем каталоге. Сделайте коммит, а затем запустите «git rebase --continue» снова."
+#. TRANSLATORS: The first %s is the name of
+#. the environment variable, the second %s is
+#. its value.
+#: notes-utils.c:145
+#, c-format
+msgid "Bad %s value: '%s'"
+msgstr "Неправильное значение переменной %s: «%s»"
 
-#: sequencer.c:2270
-msgid "could not commit staged changes."
-msgstr "не удалось закоммитить проиндексированные изменения."
+#: object.c:54
+#, c-format
+msgid "invalid object type \"%s\""
+msgstr ""
 
-#: sequencer.c:2350
+#: object.c:174
 #, c-format
-msgid "%s: can't cherry-pick a %s"
-msgstr "%s: не удалось скопировать коммит %s"
+msgid "object %s is a %s, not a %s"
+msgstr ""
 
-#: sequencer.c:2354
+#: object.c:234
 #, c-format
-msgid "%s: bad revision"
-msgstr "%s: плохая редакция"
+msgid "object %s has unknown type id %d"
+msgstr ""
 
-#: sequencer.c:2387
-msgid "can't revert as initial commit"
-msgstr "нельзя возвратить изначальный коммит"
+#: object.c:247
+#, c-format
+msgid "unable to parse object: %s"
+msgstr "не удалось разобрать объект: %s"
 
-#: sequencer.c:2492
-msgid "make_script: unhandled options"
-msgstr "make_script: не обработанные опции"
+#: object.c:267 object.c:278
+#, c-format
+msgid "hash mismatch %s"
+msgstr "несоответствие хеш-суммы %s"
 
-#: sequencer.c:2495
-msgid "make_script: error preparing revisions"
-msgstr "make_script: ошибка при обновлении редакций"
+#: packfile.c:617
+msgid "offset before end of packfile (broken .idx?)"
+msgstr "сдвиг до конца файла пакета (возможно, повреждён файл .idx?)"
 
-#: sequencer.c:2529 sequencer.c:2564
+#: packfile.c:1868
 #, c-format
-msgid "unusable todo list: '%s'"
-msgstr "непригодный для использования список дел: «%s»"
+msgid "offset before start of pack index for %s (corrupt index?)"
+msgstr "сдвиг до начала индекса пакета для %s (повреждён индекс?)"
 
-#: sequencer.c:2615
+#: packfile.c:1872
 #, c-format
-msgid ""
-"unrecognized setting %s for option rebase.missingCommitsCheck. Ignoring."
-msgstr "нераспознанная настройка %s для опции rebase.missingCommitsCheck. Игнорирую."
+msgid "offset beyond end of pack index for %s (truncated index?)"
+msgstr "сдвиг за пределами индекса пакета для %s (обрезан индекс?)"
 
-#: sequencer.c:2695
+#: parse-options.c:38
 #, c-format
-msgid ""
-"Warning: some commits may have been dropped accidentally.\n"
-"Dropped commits (newer to older):\n"
-msgstr "Внимание: некоторые коммиты могли быть отброшены по ошибке.\nОтброшенные коммиты (от новых к старым):\n"
+msgid "%s requires a value"
+msgstr ""
 
-#: sequencer.c:2702
+#: parse-options.c:73
 #, c-format
-msgid ""
-"To avoid this message, use \"drop\" to explicitly remove a commit.\n"
-"\n"
-"Use 'git config rebase.missingCommitsCheck' to change the level of warnings.\n"
-"The possible behaviours are: ignore, warn, error.\n"
-"\n"
-msgstr "Для избежания этого сообщения, используйте «drop» чтобы явно удалить коммит.\n\nИспользуйте опцию «git config rebase.missingCommitsCheck» для изменения количества предупреждений.\nВозможные значения: ignore, warn, error.\n\n"
+msgid "%s is incompatible with %s"
+msgstr ""
 
-#: sequencer.c:2714
+#: parse-options.c:78
 #, c-format
-msgid ""
-"You can fix this with 'git rebase --edit-todo' and then run 'git rebase --continue'.\n"
-"Or you can abort the rebase with 'git rebase --abort'.\n"
-msgstr "Вы можете исправить это с помощью «git rebase --edit-todo», а потом запустив «git rebase --continue».\nИли вы можете прервать процесс перемещения, выполнив «git rebase --abort»\n"
+msgid "%s : incompatible with something else"
+msgstr ""
 
-#: sequencer.c:2727 sequencer.c:2794 wrapper.c:225 wrapper.c:395
-#: builtin/am.c:779
+#: parse-options.c:92 parse-options.c:96 parse-options.c:319
 #, c-format
-msgid "could not open '%s' for writing"
-msgstr "не удалось открыть «%s» для записи"
+msgid "%s takes no value"
+msgstr ""
 
-#: sequencer.c:2775
+#: parse-options.c:94
 #, c-format
-msgid "could not parse commit '%s'"
-msgstr "не удалось разобрать коммит «%s»"
-
-#: sequencer.c:2897
-msgid "the script was already rearranged."
-msgstr "сценарий уже был перестроен."
+msgid "%s isn't available"
+msgstr ""
 
-#: setup.c:171
+#: parse-options.c:219
 #, c-format
-msgid ""
-"%s: no such path in the working tree.\n"
-"Use 'git <command> -- <path>...' to specify paths that do not exist locally."
-msgstr "%s: нет такого пути в рабочем каталоге.\nИспользуйте «git <команда> -- <путь>…» для указания путей, которые не существуют локально."
+msgid "%s expects a non-negative integer value with an optional k/m/g suffix"
+msgstr ""
 
-#: setup.c:184
+#: parse-options.c:389
 #, c-format
-msgid ""
-"ambiguous argument '%s': unknown revision or path not in the working tree.\n"
-"Use '--' to separate paths from revisions, like this:\n"
-"'git <command> [<revision>...] -- [<file>...]'"
-msgstr "неоднозначный аргумент «%s»: неизвестная редакция или не путь в рабочем каталоге.\nИспользуйте «--» для отделения путей от редакций, вот так:\n«git <команда> [<редакция>…] -- [<файл>…]»"
+msgid "ambiguous option: %s (could be --%s%s or --%s%s)"
+msgstr ""
 
-#: setup.c:252
+#: parse-options.c:423 parse-options.c:431
 #, c-format
-msgid ""
-"ambiguous argument '%s': both revision and filename\n"
-"Use '--' to separate paths from revisions, like this:\n"
-"'git <command> [<revision>...] -- [<file>...]'"
-msgstr "неоднозначный аргумент «%s»: является одновременно и редакцией и именем файла.\nИспользуйте «--» для отделения путей от редакций, вот так:\n«git <команда> [<редакция>…] -- [<файл>…]»"
+msgid "did you mean `--%s` (with two dashes ?)"
+msgstr ""
 
-#: setup.c:501
+#: parse-options.c:859
 #, c-format
-msgid "Expected git repo version <= %d, found %d"
-msgstr "Ожидаемая версия git репозитория <= %d, а обнаружена %d"
-
-#: setup.c:509
-msgid "unknown repository extensions found:"
-msgstr "обнаружены неизвестные расширения репозитория:"
+msgid "unknown option `%s'"
+msgstr ""
 
-#: setup.c:811
+#: parse-options.c:861
 #, c-format
-msgid "Not a git repository (or any of the parent directories): %s"
-msgstr "Не найден git репозитоий (или один из его каталогов): %s"
+msgid "unknown switch `%c'"
+msgstr ""
 
-#: setup.c:813 builtin/index-pack.c:1653
-msgid "Cannot come back to cwd"
-msgstr "Не удалось вернуться в текущий рабочий каталог"
+#: parse-options.c:863
+#, c-format
+msgid "unknown non-ascii option in string: `%s'"
+msgstr ""
 
-#: setup.c:1052
-msgid "Unable to read current working directory"
-msgstr "Не удалось прочитать текущий рабочий каталог"
+#: parse-options.c:887
+msgid "..."
+msgstr "…"
 
-#: setup.c:1064 setup.c:1070
+#: parse-options.c:906
 #, c-format
-msgid "Cannot change to '%s'"
-msgstr "Не удалось изменить на «%s»"
+msgid "usage: %s"
+msgstr "использование: %s"
 
-#: setup.c:1083
+#. TRANSLATORS: the colon here should align with the
+#. one in "usage: %s" translation.
+#: parse-options.c:912
 #, c-format
-msgid ""
-"Not a git repository (or any parent up to mount point %s)\n"
-"Stopping at filesystem boundary (GIT_DISCOVERY_ACROSS_FILESYSTEM not set)."
-msgstr "Не найден git репозитоий (или один из его каталогов вплоть до точки монтирования %s)\nОстанавливаю поиск на границе файловой системы (так как GIT_DISCOVERY_ACROSS_FILESYSTEM не установлен)."
+msgid "   or: %s"
+msgstr "          или: %s"
 
-#: setup.c:1167
+#: parse-options.c:915
 #, c-format
-msgid ""
-"Problem with core.sharedRepository filemode value (0%.3o).\n"
-"The owner of files must always have read and write permissions."
-msgstr "Проблема со значением режима доступа к файлу core.sharedRepository (0%.3o).\nВладелец файлов должен всегда иметь права на чтение и на запись."
+msgid "    %s"
+msgstr "            %s"
 
-#: sha1_file.c:598
+#: parse-options.c:954
+msgid "-NUM"
+msgstr "-КОЛИЧЕСТВО"
+
+#: parse-options.c:968
 #, c-format
-msgid "path '%s' does not exist"
-msgstr "путь «%s» не существует"
+msgid "alias of --%s"
+msgstr ""
 
-#: sha1_file.c:624
+#: parse-options-cb.c:20 parse-options-cb.c:24
 #, c-format
-msgid "reference repository '%s' as a linked checkout is not supported yet."
-msgstr "ссылаемый репозиторий «%s» как связанное состояние, пока не поддерживается."
+msgid "option `%s' expects a numerical value"
+msgstr ""
 
-#: sha1_file.c:630
+#: parse-options-cb.c:41
 #, c-format
-msgid "reference repository '%s' is not a local repository."
-msgstr "ссылаемый репозиторий «%s» не является локальным."
+msgid "malformed expiration date '%s'"
+msgstr ""
 
-#: sha1_file.c:636
+#: parse-options-cb.c:54
 #, c-format
-msgid "reference repository '%s' is shallow"
-msgstr "ссылаемый репозиторий «%s» является частичным"
+msgid "option `%s' expects \"always\", \"auto\", or \"never\""
+msgstr ""
 
-#: sha1_file.c:644
+#: parse-options-cb.c:130 parse-options-cb.c:147
 #, c-format
-msgid "reference repository '%s' is grafted"
-msgstr "ссылаемый репозиторий «%s» является сращенным"
+msgid "malformed object name '%s'"
+msgstr "Неправильное имя объекта «%s»"
 
-#: sha1_name.c:422
+#: path.c:897
 #, c-format
-msgid "short SHA1 %s is ambiguous"
-msgstr "сокращённый SHA1 идентификатор %s неоднозначен"
+msgid "Could not make %s writable by group"
+msgstr "Не удалось предоставить доступ к %s на запись"
 
-#: sha1_name.c:433
-msgid "The candidates are:"
-msgstr "Возможно, вы имели в виду:"
+#: pathspec.c:128
+msgid "Escape character '\\' not allowed as last character in attr value"
+msgstr "Управляющий символ «\\» не разрешен как последний символ в значении attr"
 
-#: sha1_name.c:693
-msgid ""
-"Git normally never creates a ref that ends with 40 hex characters\n"
-"because it will be ignored when you just specify 40-hex. These refs\n"
-"may be created by mistake. For example,\n"
-"\n"
-"  git checkout -b $br $(git rev-parse ...)\n"
-"\n"
-"where \"$br\" is somehow empty and a 40-hex ref is created. Please\n"
-"examine these refs and maybe delete them. Turn this message off by\n"
-"running \"git config advice.objectNameWarning false\""
-msgstr "Обычно Git не создает ссылки, оканчивающиеся на 40 шестнадцатеричных\nсимволов, потому, что они будут игнорироваться, когда вы просто\nукажете это 40-символьное шестнадцатеричное число. Такие ссылки\nмогли быть созданы по ошибке. Например, с помощью:\n\n  git checkout -b $br $(git rev-parse …)\n\n, если «$br» оказался пустым, то ссылка с 40-символьным\nшестнадцатеричным числом будет создана. Пожалуйста, просмотрите эти\nссылки и, возможно, удалите их. Вы можете отключить это сообщение\nзапустив «git config advice.objectNameWarning false»"
+#: pathspec.c:146
+msgid "Only one 'attr:' specification is allowed."
+msgstr "Разрешен только один спецификатор «attr:»."
 
-#: submodule.c:96 submodule.c:130
-msgid "Cannot change unmerged .gitmodules, resolve merge conflicts first"
-msgstr "Не удалось изменить не слитый .gitmodules, сначала разрешите конфликты"
+#: pathspec.c:149
+msgid "attr spec must not be empty"
+msgstr "спецификатор attr не должен быть пустой"
 
-#: submodule.c:100 submodule.c:134
+#: pathspec.c:192
 #, c-format
-msgid "Could not find section in .gitmodules where path=%s"
-msgstr "Не удалось найти раздел в .gitmodules, где путь равен %s"
+msgid "invalid attribute name %s"
+msgstr "недопустимое имя атрибута %s"
 
-#: submodule.c:108
-#, c-format
-msgid "Could not update .gitmodules entry %s"
-msgstr " Не удалось обновить .gitmodules запись %s"
+#: pathspec.c:257
+msgid "global 'glob' and 'noglob' pathspec settings are incompatible"
+msgstr "глобальные опции спецификаторов пути «glob» и «noglob» нельзя использовать одновременно"
 
-#: submodule.c:141
-#, c-format
-msgid "Could not remove .gitmodules entry for %s"
-msgstr "Не удалось удалить запись в .gitmodules для %s"
+#: pathspec.c:264
+msgid ""
+"global 'literal' pathspec setting is incompatible with all other global "
+"pathspec settings"
+msgstr "глобальная опция спецификатора пути «literal» не совместима с другими глобальными спецификаторами доступа"
 
-#: submodule.c:152
-msgid "staging updated .gitmodules failed"
-msgstr "сбой индексирования обновленного .gitmodules"
+#: pathspec.c:304
+msgid "invalid parameter for pathspec magic 'prefix'"
+msgstr "неправильный параметр для магического слова «prefix» в спецификаторе пути "
 
-#: submodule.c:312
+#: pathspec.c:325
 #, c-format
-msgid "in unpopulated submodule '%s'"
-msgstr "в пустом подмодуле «%s»"
+msgid "Invalid pathspec magic '%.*s' in '%s'"
+msgstr "неправильное магическое слово «%.*s» в спецификаторе пути «%s»"
 
-#: submodule.c:343
+#: pathspec.c:330
 #, c-format
-msgid "Pathspec '%s' is in submodule '%.*s'"
-msgstr "Спецификатор пути «%s» в подмодуле «%.*s»"
+msgid "Missing ')' at the end of pathspec magic in '%s'"
+msgstr "Пропущено «)» в конце магического слова спецификатора пути «%s»"
 
-#: submodule.c:833
+#: pathspec.c:368
 #, c-format
-msgid "submodule entry '%s' (%s) is a %s, not a commit"
-msgstr "запись подмодуля «%s» (%s) является %s, а не является коммитом"
-
-#: submodule.c:1065 builtin/branch.c:648 builtin/submodule--helper.c:1387
-msgid "Failed to resolve HEAD as a valid ref."
-msgstr "Не удалось определить HEAD как действительную ссылку."
+msgid "Unimplemented pathspec magic '%c' in '%s'"
+msgstr "Нереализованное магическое слово «%c» спецификатора пути «%s»"
 
-#: submodule.c:1370
+#: pathspec.c:427
 #, c-format
-msgid "'%s' not recognized as a git repository"
-msgstr "«%s» не распознан как репозиторий git"
+msgid "%s: 'literal' and 'glob' are incompatible"
+msgstr "%s: «literal» и «glob» не совместимы"
 
-#: submodule.c:1508
+#: pathspec.c:440
 #, c-format
-msgid "could not start 'git status' in submodule '%s'"
-msgstr "не удалось запустить «git status» в подмодуле «%s»"
+msgid "%s: '%s' is outside repository"
+msgstr "%s: «%s» вне репозитория"
 
-#: submodule.c:1521
+#: pathspec.c:514
 #, c-format
-msgid "could not run 'git status' in submodule '%s'"
-msgstr "не удалось запустить «git status» в подмодуле «%s»"
+msgid "'%s' (mnemonic: '%c')"
+msgstr "«%s» (мнемоника: «%c»)"
 
-#: submodule.c:1614
+#: pathspec.c:524
 #, c-format
-msgid "submodule '%s' has dirty index"
-msgstr "подмодуль «%s» имеет изменённый индекс"
+msgid "%s: pathspec magic not supported by this command: %s"
+msgstr "%s: магические слова в спецификаторе пути не поддерживаются командой: %s"
 
-#: submodule.c:1876
+#: pathspec.c:591
 #, c-format
-msgid ""
-"relocate_gitdir for submodule '%s' with more than one worktree not supported"
-msgstr "relocate_gitdir для подмодуля «%s» с указанием более одного рабочего дерева не поддерживается"
+msgid "pathspec '%s' is beyond a symbolic link"
+msgstr "спецификатор пути «%s» находится за символической ссылкой"
 
-#: submodule.c:1888 submodule.c:1944
-#, c-format
-msgid "could not lookup name for submodule '%s'"
-msgstr "не удалось запросить имя подмодуля «%s»"
+#: pkt-line.c:92
+msgid "unable to write flush packet"
+msgstr ""
 
-#: submodule.c:1892 builtin/submodule--helper.c:909
-#: builtin/submodule--helper.c:919
-#, c-format
-msgid "could not create directory '%s'"
-msgstr "не удалось создать каталог «%s»"
+#: pkt-line.c:99
+msgid "unable to write delim packet"
+msgstr ""
 
-#: submodule.c:1895
-#, c-format
-msgid ""
-"Migrating git directory of '%s%s' from\n"
-"'%s' to\n"
-"'%s'\n"
-msgstr "Перемещение каталога git для «%s%s» из\n«%s» в\n«%s»\n"
+#: pkt-line.c:106
+msgid "flush packet write failed"
+msgstr ""
 
-#: submodule.c:1979
-#, c-format
-msgid "could not recurse into submodule '%s'"
-msgstr "не удалось рекурсивно зайти в подмодуль «%s»"
+#: pkt-line.c:146 pkt-line.c:232
+msgid "protocol error: impossibly long line"
+msgstr ""
 
-#: submodule.c:2023
-msgid "could not start ls-files in .."
-msgstr "не удалось выполнить stat ls-files в .."
+#: pkt-line.c:162 pkt-line.c:164
+msgid "packet write with format failed"
+msgstr ""
 
-#: submodule.c:2043
-msgid "BUG: returned path string doesn't match cwd?"
-msgstr "ОШИБКА: возвращенная строка не соответсвует cwd?"
+#: pkt-line.c:196
+msgid "packet write failed - data exceeds max packet size"
+msgstr ""
 
-#: submodule.c:2062
-#, c-format
-msgid "ls-tree returned unexpected return code %d"
-msgstr "ls-tree вернул неожиданный код %d"
+#: pkt-line.c:203 pkt-line.c:210
+msgid "packet write failed"
+msgstr ""
 
-#: submodule-config.c:263
-msgid "negative values not allowed for submodule.fetchjobs"
-msgstr "нельзя использовать отрицательные значения для submodule.fetchjobs"
+#: pkt-line.c:295
+msgid "read error"
+msgstr ""
 
-#: submodule-config.c:436
-#, c-format
-msgid "invalid value for %s"
-msgstr "неправильное значение %s"
+#: pkt-line.c:303
+msgid "the remote end hung up unexpectedly"
+msgstr ""
 
-#: trailer.c:238
+#: pkt-line.c:331
 #, c-format
-msgid "running trailer command '%s' failed"
-msgstr "сбой при запуске команды завершителя «%s»"
+msgid "protocol error: bad line length character: %.4s"
+msgstr ""
 
-#: trailer.c:485 trailer.c:490 trailer.c:495 trailer.c:549 trailer.c:553
-#: trailer.c:557
+#: pkt-line.c:341 pkt-line.c:346
 #, c-format
-msgid "unknown value '%s' for key '%s'"
-msgstr "неизвестное значение «%s» для ключа «%s»"
+msgid "protocol error: bad line length %d"
+msgstr ""
 
-#: trailer.c:539 trailer.c:544 builtin/remote.c:290
+#: pkt-line.c:362
 #, c-format
-msgid "more than one %s"
-msgstr "больше одного %s"
+msgid "remote error: %s"
+msgstr "ошибка внешнего репозитория: %s"
 
-#: trailer.c:730
-#, c-format
-msgid "empty trailer token in trailer '%.*s'"
-msgstr "пустая последняя лексема в завершителе «%.*s»"
+#: preload-index.c:119
+msgid "Refreshing index"
+msgstr ""
 
-#: trailer.c:750
+#: preload-index.c:138
 #, c-format
-msgid "could not read input file '%s'"
-msgstr "не удалось прочитать входной файл «%s»"
+msgid "unable to create threaded lstat: %s"
+msgstr ""
 
-#: trailer.c:753
-msgid "could not read from stdin"
-msgstr "не удалось прочитать из стандартного ввода"
+#: pretty.c:966
+msgid "unable to parse --pretty format"
+msgstr "не удалось разобрать формат для --pretty"
 
-#: trailer.c:1008 builtin/am.c:46
-#, c-format
-msgid "could not stat %s"
-msgstr "не удалось выполнить stat для %s"
+#: range-diff.c:56
+msgid "could not start `log`"
+msgstr ""
 
-#: trailer.c:1010
-#, c-format
-msgid "file %s is not a regular file"
-msgstr "файл %s не является обычным файлом"
+#: range-diff.c:59
+msgid "could not read `log` output"
+msgstr ""
 
-#: trailer.c:1012
+#: range-diff.c:74 sequencer.c:4897
 #, c-format
-msgid "file %s is not writable by user"
-msgstr "файл %s не доступен на запись пользователю"
+msgid "could not parse commit '%s'"
+msgstr "не удалось разобрать коммит «%s»"
 
-#: trailer.c:1024
-msgid "could not open temporary file"
-msgstr "не удалось создать временный файл"
+#: range-diff.c:224
+msgid "failed to generate diff"
+msgstr ""
 
-#: trailer.c:1064
+#: range-diff.c:455 range-diff.c:457
 #, c-format
-msgid "could not rename temporary file to %s"
-msgstr "не удалось переименовать временный файл в %s"
+msgid "could not parse log for '%s'"
+msgstr ""
 
-#: transport.c:63
+#: read-cache.c:680
 #, c-format
-msgid "Would set upstream of '%s' to '%s' of '%s'\n"
-msgstr "Будет установлен вышестоящий репозиторий для «%s» на «%s» с «%s»\n"
+msgid "will not add file alias '%s' ('%s' already exists in index)"
+msgstr ""
 
-#: transport.c:152
-#, c-format
-msgid "transport: invalid depth option '%s'"
-msgstr "транспорт: неправильный параметр глубины «%s»"
+#: read-cache.c:696
+msgid "cannot create an empty blob in the object database"
+msgstr ""
 
-#: transport.c:904
+#: read-cache.c:718
 #, c-format
-msgid ""
-"The following submodule paths contain changes that can\n"
-"not be found on any remote:\n"
-msgstr "Подмодули по указанным путям содержат изменения, которые не найдены ни на одном из внешних репозиториев:\n"
+msgid "%s: can only add regular files, symbolic links or git-directories"
+msgstr ""
 
-#: transport.c:908
+#: read-cache.c:723
 #, c-format
-msgid ""
-"\n"
-"Please try\n"
-"\n"
-"\tgit push --recurse-submodules=on-demand\n"
-"\n"
-"or cd to the path and use\n"
-"\n"
-"\tgit push\n"
-"\n"
-"to push them to a remote.\n"
-"\n"
-msgstr "\nПопробуйте выполнить\n\n\tgit push --recurse-submodules=on-demand\n\nили перейти в каталог с помощью команды cd и выполнить\n\n\tgit push\n\nдля их отправки на внешний репозиторий.\n"
-
-#: transport.c:916
-msgid "Aborting."
-msgstr "Прерываю."
+msgid "'%s' does not have a commit checked out"
+msgstr ""
 
-#: transport-helper.c:1074
+#: read-cache.c:775
 #, c-format
-msgid "Could not read ref %s"
-msgstr "Не удалось прочитать ссылку %s"
+msgid "unable to index file '%s'"
+msgstr ""
 
-#: tree-walk.c:31
-msgid "too-short tree object"
-msgstr "слишком  короткий объект дерева"
+#: read-cache.c:794
+#, c-format
+msgid "unable to add '%s' to index"
+msgstr ""
 
-#: tree-walk.c:37
-msgid "malformed mode in tree entry"
-msgstr "неправильный режим в записи дерева"
+#: read-cache.c:805
+#, c-format
+msgid "unable to stat '%s'"
+msgstr ""
 
-#: tree-walk.c:41
-msgid "empty filename in tree entry"
-msgstr "пустое имя файла в записи дерева"
+#: read-cache.c:1314
+#, c-format
+msgid "'%s' appears as both a file and as a directory"
+msgstr ""
 
-#: tree-walk.c:114
-msgid "too-short tree file"
-msgstr "слишком  короткий файл дерева"
+#: read-cache.c:1499
+msgid "Refresh index"
+msgstr ""
 
-#: unpack-trees.c:107
+#: read-cache.c:1613
 #, c-format
 msgid ""
-"Your local changes to the following files would be overwritten by checkout:\n"
-"%%sPlease commit your changes or stash them before you switch branches."
-msgstr "Ваши локальные изменения в указанных файлах будут перезаписаны при переключении на состояние:\n%%sСделайте коммит или спрячьте ваши изменения перед переключением веток."
+"index.version set, but the value is invalid.\n"
+"Using version %i"
+msgstr "index.version указан, но значение недействительное.\nИспользую версию %i"
 
-#: unpack-trees.c:109
+#: read-cache.c:1623
 #, c-format
 msgid ""
-"Your local changes to the following files would be overwritten by checkout:\n"
-"%%s"
-msgstr "Ваши локальные изменения в указанных файлах будут перезаписаны при переключении на состояние:\n%%s"
+"GIT_INDEX_VERSION set, but the value is invalid.\n"
+"Using version %i"
+msgstr "GIT_INDEX_VERSION указан, но значение недействительное.\nИспользую версию %i"
 
-#: unpack-trees.c:112
+#: read-cache.c:1679
 #, c-format
-msgid ""
-"Your local changes to the following files would be overwritten by merge:\n"
-"%%sPlease commit your changes or stash them before you merge."
-msgstr "Ваши локальные изменения в указанных файлах будут перезаписаны при слиянии:\n%%sСделайте коммит или спрячьте ваши изменения перед слиянием веток."
+msgid "bad signature 0x%08x"
+msgstr ""
 
-#: unpack-trees.c:114
+#: read-cache.c:1682
 #, c-format
-msgid ""
-"Your local changes to the following files would be overwritten by merge:\n"
-"%%s"
-msgstr "Ваши локальные изменения в указанных файлах будут перезаписаны при слиянии:\n%%s"
+msgid "bad index version %d"
+msgstr ""
 
-#: unpack-trees.c:117
-#, c-format
-msgid ""
-"Your local changes to the following files would be overwritten by %s:\n"
-"%%sPlease commit your changes or stash them before you %s."
-msgstr "Ваши локальные изменения в указанных файлах будут перезаписаны при %s:\n%%sСделайте коммит или спрячьте ваши изменения перед %s."
+#: read-cache.c:1691
+msgid "bad index file sha1 signature"
+msgstr ""
 
-#: unpack-trees.c:119
+#: read-cache.c:1721
 #, c-format
-msgid ""
-"Your local changes to the following files would be overwritten by %s:\n"
-"%%s"
-msgstr "Ваши локальные изменения в указанных файлах будут перезаписаны при %s:\n%%s"
+msgid "index uses %.4s extension, which we do not understand"
+msgstr ""
 
-#: unpack-trees.c:124
+#: read-cache.c:1723
 #, c-format
-msgid ""
-"Updating the following directories would lose untracked files in them:\n"
-"%s"
-msgstr "Обновление указанных каталогов приведет к потере неотслеживаемых файлов в них:\n%s"
+msgid "ignoring %.4s extension"
+msgstr ""
 
-#: unpack-trees.c:128
+#: read-cache.c:1760
 #, c-format
-msgid ""
-"The following untracked working tree files would be removed by checkout:\n"
-"%%sPlease move or remove them before you switch branches."
-msgstr "Указанные неотслеживаемые файлы в рабочем каталоге будут удалены при переключении на состояние:\n%%sПереместите эти файлы или удалите их перед переключением веток."
+msgid "unknown index entry format 0x%08x"
+msgstr ""
 
-#: unpack-trees.c:130
+#: read-cache.c:1776
 #, c-format
-msgid ""
-"The following untracked working tree files would be removed by checkout:\n"
-"%%s"
-msgstr "Указанные неотслеживаемые файлы в рабочем каталоге будут удалены при переключении на состояние:\n%%s"
+msgid "malformed name field in the index, near path '%s'"
+msgstr ""
+
+#: read-cache.c:1833
+msgid "unordered stage entries in index"
+msgstr ""
 
-#: unpack-trees.c:133
+#: read-cache.c:1836
 #, c-format
-msgid ""
-"The following untracked working tree files would be removed by merge:\n"
-"%%sPlease move or remove them before you merge."
-msgstr "Указанные неотслеживаемые файлы в рабочем каталоге будут удалены при слиянии:\n%%sПереместите эти файлы или удалите их перед переключением веток."
+msgid "multiple stage entries for merged file '%s'"
+msgstr ""
 
-#: unpack-trees.c:135
+#: read-cache.c:1839
 #, c-format
-msgid ""
-"The following untracked working tree files would be removed by merge:\n"
-"%%s"
-msgstr "Указанные неотслеживаемые файлы в рабочем каталоге будут удалены при слиянии:\n%%s"
+msgid "unordered stage entries for '%s'"
+msgstr ""
+
+#: read-cache.c:1946 read-cache.c:2234 rerere.c:565 rerere.c:599 rerere.c:1111
+#: builtin/add.c:460 builtin/check-ignore.c:178 builtin/checkout.c:358
+#: builtin/checkout.c:672 builtin/checkout.c:1060 builtin/clean.c:955
+#: builtin/commit.c:344 builtin/diff-tree.c:120 builtin/grep.c:498
+#: builtin/mv.c:145 builtin/reset.c:245 builtin/rm.c:271
+#: builtin/submodule--helper.c:330
+msgid "index file corrupt"
+msgstr "файл индекса поврежден"
 
-#: unpack-trees.c:138
+#: read-cache.c:2087
 #, c-format
-msgid ""
-"The following untracked working tree files would be removed by %s:\n"
-"%%sPlease move or remove them before you %s."
-msgstr "Указанные неотслеживаемые файлы в рабочем каталоге будут удалены при %s:\n%%sПереместите эти файлы или удалите их перед %s."
+msgid "unable to create load_cache_entries thread: %s"
+msgstr ""
 
-#: unpack-trees.c:140
+#: read-cache.c:2100
 #, c-format
-msgid ""
-"The following untracked working tree files would be removed by %s:\n"
-"%%s"
-msgstr "Указанные неотслеживаемые файлы в рабочем каталоге будут удалены при %s:\n%%s"
+msgid "unable to join load_cache_entries thread: %s"
+msgstr ""
 
-#: unpack-trees.c:145
+#: read-cache.c:2133
 #, c-format
-msgid ""
-"The following untracked working tree files would be overwritten by checkout:\n"
-"%%sPlease move or remove them before you switch branches."
-msgstr "Указанные неотслеживаемые файлы в рабочем каталоге будут перезаписаны при переключении на состояние:\n%%sПереместите эти файлы или удалите их перед переключением веток."
+msgid "%s: index file open failed"
+msgstr ""
 
-#: unpack-trees.c:147
+#: read-cache.c:2137
 #, c-format
-msgid ""
-"The following untracked working tree files would be overwritten by checkout:\n"
-"%%s"
-msgstr "Указанные неотслеживаемые файлы в рабочем каталоге будут перезаписаны при переключении на состояние:\n%%s"
+msgid "%s: cannot stat the open index"
+msgstr ""
 
-#: unpack-trees.c:150
+#: read-cache.c:2141
 #, c-format
-msgid ""
-"The following untracked working tree files would be overwritten by merge:\n"
-"%%sPlease move or remove them before you merge."
-msgstr "Указанные неотслеживаемые файлы в рабочем каталоге будут перезаписаны при слиянии:\n%%sПереместите эти файлы или удалите их перед переключением веток."
+msgid "%s: index file smaller than expected"
+msgstr ""
 
-#: unpack-trees.c:152
+#: read-cache.c:2145
 #, c-format
-msgid ""
-"The following untracked working tree files would be overwritten by merge:\n"
-"%%s"
-msgstr "Указанные неотслеживаемые файлы в рабочем каталоге будут перезаписаны при слиянии:\n%%s"
+msgid "%s: unable to map index file"
+msgstr ""
 
-#: unpack-trees.c:155
+#: read-cache.c:2187
 #, c-format
-msgid ""
-"The following untracked working tree files would be overwritten by %s:\n"
-"%%sPlease move or remove them before you %s."
-msgstr "Указанные неотслеживаемые файлы в рабочем каталоге будут перезаписаны при %s:\n%%sПереместите эти файлы или удалите их перед %s."
+msgid "unable to create load_index_extensions thread: %s"
+msgstr ""
 
-#: unpack-trees.c:157
+#: read-cache.c:2214
 #, c-format
-msgid ""
-"The following untracked working tree files would be overwritten by %s:\n"
-"%%s"
-msgstr "Указанные неотслеживаемые файлы в рабочем каталоге будут перезаписаны при %s:\n%%s"
+msgid "unable to join load_index_extensions thread: %s"
+msgstr ""
 
-#: unpack-trees.c:164
+#: read-cache.c:2246
 #, c-format
-msgid "Entry '%s' overlaps with '%s'.  Cannot bind."
-msgstr "Запись «%s» частично совпадает с «%s».  Не удалось назначить соответствие."
+msgid "could not freshen shared index '%s'"
+msgstr ""
 
-#: unpack-trees.c:167
+#: read-cache.c:2293
 #, c-format
-msgid ""
-"Cannot update sparse checkout: the following entries are not up to date:\n"
-"%s"
-msgstr "Не удалось обновить частичное состояние: следующие элементы не последней версии:\n%s"
+msgid "broken index, expect %s in %s, got %s"
+msgstr ""
 
-#: unpack-trees.c:169
+#: read-cache.c:2989 wrapper.c:658 builtin/merge.c:1117
 #, c-format
-msgid ""
-"The following working tree files would be overwritten by sparse checkout update:\n"
-"%s"
-msgstr "Указанные файлы из рабочего каталога будут перезаписаны при обновлении частичного состояния:\n%s"
+msgid "could not close '%s'"
+msgstr "не удалось закрыть «%s»"
 
-#: unpack-trees.c:171
+#: read-cache.c:3092 sequencer.c:2354 sequencer.c:3807
 #, c-format
-msgid ""
-"The following working tree files would be removed by sparse checkout update:\n"
-"%s"
-msgstr "Указанные файлы из рабочего каталога будут удалены при обновлении частичного состояния:\n%s"
+msgid "could not stat '%s'"
+msgstr "не удалось выполнить stat для «%s»"
 
-#: unpack-trees.c:173
+#: read-cache.c:3105
 #, c-format
-msgid ""
-"Cannot update submodule:\n"
-"%s"
-msgstr "Не удолось обновить подмодуль:\n%s"
+msgid "unable to open git dir: %s"
+msgstr "не удалось открыть каталог git: %s"
 
-#: unpack-trees.c:250
+#: read-cache.c:3117
 #, c-format
-msgid "Aborting\n"
-msgstr "Прерываю\n"
+msgid "unable to unlink: %s"
+msgstr "не удалось отсоединить: %s"
 
-#: unpack-trees.c:332
-msgid "Checking out files"
-msgstr "Распаковка файлов"
+#: read-cache.c:3142
+#, c-format
+msgid "cannot fix permission bits on '%s'"
+msgstr ""
 
-#: urlmatch.c:163
-msgid "invalid URL scheme name or missing '://' suffix"
-msgstr "Неправильная имя URL схемы или пропущен суффикс «://»"
+#: read-cache.c:3291
+#, c-format
+msgid "%s: cannot drop to stage #0"
+msgstr ""
 
-#: urlmatch.c:187 urlmatch.c:346 urlmatch.c:405
+#: rebase-interactive.c:26
 #, c-format
-msgid "invalid %XX escape sequence"
-msgstr "неправильная управляющая последовательность %XX"
+msgid ""
+"unrecognized setting %s for option rebase.missingCommitsCheck. Ignoring."
+msgstr "нераспознанная настройка %s для опции rebase.missingCommitsCheck. Игнорирую."
 
-#: urlmatch.c:215
-msgid "missing host and scheme is not 'file:'"
-msgstr "пропущено имя сервера и схема доступа не «file:»"
+#: rebase-interactive.c:35
+msgid ""
+"\n"
+"Commands:\n"
+"p, pick <commit> = use commit\n"
+"r, reword <commit> = use commit, but edit the commit message\n"
+"e, edit <commit> = use commit, but stop for amending\n"
+"s, squash <commit> = use commit, but meld into previous commit\n"
+"f, fixup <commit> = like \"squash\", but discard this commit's log message\n"
+"x, exec <command> = run command (the rest of the line) using shell\n"
+"b, break = stop here (continue rebase later with 'git rebase --continue')\n"
+"d, drop <commit> = remove commit\n"
+"l, label <label> = label current HEAD with a name\n"
+"t, reset <label> = reset HEAD to a label\n"
+"m, merge [-C <commit> | -c <commit>] <label> [# <oneline>]\n"
+".       create a merge commit using the original merge commit's\n"
+".       message (or the oneline, if no original merge commit was\n"
+".       specified). Use -c <commit> to reword the commit message.\n"
+"\n"
+"These lines can be re-ordered; they are executed from top to bottom.\n"
+msgstr "\nКоманды:\np, pick <коммит> = использовать коммит\nr, reword <коммит> = использовать коммит, но изменить сообщение коммита\ne, edit <коммит> = использовать коммит, но остановиться для исправления\ns, squash <коммит> = использовать коммит, но объединить с предыдущим коммитом\nf, fixup <коммит> = как «squash», но пропустить сообщение коммита\nx, exec <команда> = выполнить команду (остаток строки) с помощью командной оболочки\nb, break = остановиться здесь (продолжить с помощью «git rebase --continue»)\nd, drop <коммит> = удалить коммит\nl, label <метка> = дать имя текущему HEAD\nt, reset <метка> = сбросить HEAD к указанной метке\nm, merge [-C <коммит> | -c <коммит>] <метка> [# <строка>]\n. создать слияние используя сообщение коммита оригинального\n. слияния (или использовать указанную строку, если оригинальное\n. слияние не указано). Используйте -c <коммит> чтобы изменить\n. сообщение коммита.\n\nЭти строки можно перемещать; они будут выполнены сверху вниз.\n"
 
-#: urlmatch.c:232
-msgid "a 'file:' URL may not have a port number"
-msgstr "URL со схемой «file:» не может содержать номер порта"
+#: rebase-interactive.c:56
+#, c-format
+msgid "Rebase %s onto %s (%d command)"
+msgid_plural "Rebase %s onto %s (%d commands)"
+msgstr[0] ""
+msgstr[1] ""
+msgstr[2] ""
+msgstr[3] ""
 
-#: urlmatch.c:247
-msgid "invalid characters in host name"
-msgstr "неправильные символы в имени сервера"
+#: rebase-interactive.c:65 git-rebase--preserve-merges.sh:173
+msgid ""
+"\n"
+"Do not remove any line. Use 'drop' explicitly to remove a commit.\n"
+msgstr "\nНе удаляйте строки. Используйте «drop», чтобы явно удалить коммит.\n"
 
-#: urlmatch.c:292 urlmatch.c:303
-msgid "invalid port number"
-msgstr "неправильный номер порта"
+#: rebase-interactive.c:68 git-rebase--preserve-merges.sh:177
+msgid ""
+"\n"
+"If you remove a line here THAT COMMIT WILL BE LOST.\n"
+msgstr "\nЕсли вы удалите строку здесь, то УКАЗАННЫЙ КОММИТ БУДЕТ УТЕРЯН.\n"
 
-#: urlmatch.c:371
-msgid "invalid '..' path segment"
-msgstr "неправильная часть пути «..»"
+#: rebase-interactive.c:74 git-rebase--preserve-merges.sh:816
+msgid ""
+"\n"
+"You are editing the todo file of an ongoing interactive rebase.\n"
+"To continue rebase after editing, run:\n"
+"    git rebase --continue\n"
+"\n"
+msgstr "\nВы сейчас редактируете файл со списком дел для интерактивного перемещения.\nДля продолжения перемещения, после редактирования файла запустите:\n    git rebase --continue\n\n"
+
+#: rebase-interactive.c:79 git-rebase--preserve-merges.sh:893
+msgid ""
+"\n"
+"However, if you remove everything, the rebase will be aborted.\n"
+"\n"
+msgstr "\nНо если вы удалите все, то процесс перемещения будет будет прерван.\n\n"
 
-#: worktree.c:245
+#: rebase-interactive.c:85 git-rebase--preserve-merges.sh:900
+msgid "Note that empty commits are commented out"
+msgstr "Заметьте, что пустые коммиты закомментированны"
+
+#: rebase-interactive.c:105 rerere.c:485 rerere.c:692 sequencer.c:3339
+#: sequencer.c:3365 sequencer.c:4996 builtin/fsck.c:356 builtin/rebase.c:235
 #, c-format
-msgid "failed to read '%s'"
-msgstr "не удалось прочитать «%s»"
+msgid "could not write '%s'"
+msgstr "не удалось записать «%s»"
 
-#: wrapper.c:223 wrapper.c:393
+#: rebase-interactive.c:108
 #, c-format
-msgid "could not open '%s' for reading and writing"
-msgstr "не удалось открыть «%s» для чтения и записи"
+msgid "could not copy '%s' to '%s'."
+msgstr ""
 
-#: wrapper.c:227 wrapper.c:397 builtin/am.c:320 builtin/am.c:770
-#: builtin/am.c:862 builtin/merge.c:1043
+#: rebase-interactive.c:173
 #, c-format
-msgid "could not open '%s' for reading"
-msgstr "не удалось открыть «%s» для чтения"
+msgid ""
+"Warning: some commits may have been dropped accidentally.\n"
+"Dropped commits (newer to older):\n"
+msgstr "Внимание: некоторые коммиты могли быть отброшены по ошибке.\nОтброшенные коммиты (от новых к старым):\n"
 
-#: wrapper.c:424 wrapper.c:624
+#: rebase-interactive.c:180
 #, c-format
-msgid "unable to access '%s'"
-msgstr "«%s» недоступно"
+msgid ""
+"To avoid this message, use \"drop\" to explicitly remove a commit.\n"
+"\n"
+"Use 'git config rebase.missingCommitsCheck' to change the level of warnings.\n"
+"The possible behaviours are: ignore, warn, error.\n"
+"\n"
+msgstr "Чтобы избежать этого сообщения, используйте «drop» чтобы явно удалить коммит.\n\nИспользуйте опцию «git config rebase.missingCommitsCheck» для изменения количества предупреждений.\nВозможные значения: ignore, warn, error.\n\n"
 
-#: wrapper.c:632
-msgid "unable to get current working directory"
-msgstr "не удалось получить текущий рабочий каталог"
+#: refs.c:192
+#, c-format
+msgid "%s does not point to a valid object!"
+msgstr ""
 
-#: wt-status.c:150
-msgid "Unmerged paths:"
-msgstr "Не слитые пути:"
+#: refs.c:597
+#, c-format
+msgid "ignoring dangling symref %s"
+msgstr ""
 
-#: wt-status.c:177 wt-status.c:204
+#: refs.c:599 ref-filter.c:1982
 #, c-format
-msgid "  (use \"git reset %s <file>...\" to unstage)"
-msgstr "  (используйте «git reset %s <файл>…», чтобы убрать из индекса)"
+msgid "ignoring broken ref %s"
+msgstr "игнорирую неправильную ссылку %s"
 
-#: wt-status.c:179 wt-status.c:206
-msgid "  (use \"git rm --cached <file>...\" to unstage)"
-msgstr "  (используйте «git rm --cached <файл>…», чтобы убрать из индекса)"
+#: refs.c:734
+#, c-format
+msgid "could not open '%s' for writing: %s"
+msgstr "не удалось открыть «%s» для записи: %s"
 
-#: wt-status.c:183
-msgid "  (use \"git add <file>...\" to mark resolution)"
-msgstr "  (используйте «git add <файл>…», чтобы пометить разрешение конфликта)"
+#: refs.c:744 refs.c:795
+#, c-format
+msgid "could not read ref '%s'"
+msgstr ""
 
-#: wt-status.c:185 wt-status.c:189
-msgid "  (use \"git add/rm <file>...\" as appropriate to mark resolution)"
-msgstr "  (используйте «git add/rm <файл>…», чтобы пометить выбранное разрешение конфликта)"
+#: refs.c:750
+#, c-format
+msgid "ref '%s' already exists"
+msgstr ""
 
-#: wt-status.c:187
-msgid "  (use \"git rm <file>...\" to mark resolution)"
-msgstr "  (используйте «git rm <файл>…», чтобы пометить разрешение конфликта)"
+#: refs.c:755
+#, c-format
+msgid "unexpected object ID when writing '%s'"
+msgstr ""
 
-#: wt-status.c:198 wt-status.c:984
-msgid "Changes to be committed:"
-msgstr "Изменения, которые будут включены в коммит:"
+#: refs.c:763 sequencer.c:400 sequencer.c:2679 sequencer.c:2805
+#: sequencer.c:2819 sequencer.c:3076 sequencer.c:4913 wrapper.c:656
+#, c-format
+msgid "could not write to '%s'"
+msgstr "не удалось записать в «%s»"
 
-#: wt-status.c:216 wt-status.c:993
-msgid "Changes not staged for commit:"
-msgstr "Изменения, которые не в индексе для коммита:"
+#: refs.c:790 wrapper.c:225 wrapper.c:395 builtin/am.c:715
+#: builtin/rebase.c:993
+#, c-format
+msgid "could not open '%s' for writing"
+msgstr "не удалось открыть «%s» для записи"
 
-#: wt-status.c:220
-msgid "  (use \"git add <file>...\" to update what will be committed)"
-msgstr "  (используйте «git add <файл>…», чтобы добавить файл в индекс)"
+#: refs.c:797
+#, c-format
+msgid "unexpected object ID when deleting '%s'"
+msgstr ""
 
-#: wt-status.c:222
-msgid "  (use \"git add/rm <file>...\" to update what will be committed)"
-msgstr "  (используйте «git add/rm <файл>…», чтобы добавить или удалить файл из индекса)"
+#: refs.c:928
+#, c-format
+msgid "log for ref %s has gap after %s"
+msgstr ""
 
-#: wt-status.c:223
-msgid ""
-"  (use \"git checkout -- <file>...\" to discard changes in working "
-"directory)"
-msgstr "  (используйте «git checkout -- <файл>…», чтобы отменить изменения\n   в рабочем каталоге)"
+#: refs.c:934
+#, c-format
+msgid "log for ref %s unexpectedly ended on %s"
+msgstr ""
 
-#: wt-status.c:225
-msgid "  (commit or discard the untracked or modified content in submodules)"
-msgstr "  (сделайте коммит или отмените изменения в неотслеживаемом или измененном содержимом в подмодулях)"
+#: refs.c:993
+#, c-format
+msgid "log for %s is empty"
+msgstr ""
 
-#: wt-status.c:237
+#: refs.c:1085
 #, c-format
-msgid "  (use \"git %s <file>...\" to include in what will be committed)"
-msgstr "  (используйте «git %s <файл>…», чтобы добавить в то, что будет включено в коммит)"
+msgid "refusing to update ref with bad name '%s'"
+msgstr ""
 
-#: wt-status.c:252
-msgid "both deleted:"
-msgstr "оба удалены:"
+#: refs.c:1161
+#, c-format
+msgid "update_ref failed for ref '%s': %s"
+msgstr ""
 
-#: wt-status.c:254
-msgid "added by us:"
-msgstr "добавлено нами:"
+#: refs.c:1942
+#, c-format
+msgid "multiple updates for ref '%s' not allowed"
+msgstr ""
 
-#: wt-status.c:256
-msgid "deleted by them:"
-msgstr "удалено ими:"
+#: refs.c:1974
+msgid "ref updates forbidden inside quarantine environment"
+msgstr "обновление ссылок запрещено в изолированном окружении"
 
-#: wt-status.c:258
-msgid "added by them:"
-msgstr "добавлено ими:"
+#: refs.c:2070 refs.c:2100
+#, c-format
+msgid "'%s' exists; cannot create '%s'"
+msgstr ""
 
-#: wt-status.c:260
-msgid "deleted by us:"
-msgstr "удалено нами:"
+#: refs.c:2076 refs.c:2111
+#, c-format
+msgid "cannot process '%s' and '%s' at the same time"
+msgstr ""
 
-#: wt-status.c:262
-msgid "both added:"
-msgstr "оба добавлены:"
+#: refs/files-backend.c:1234
+#, c-format
+msgid "could not remove reference %s"
+msgstr "не удалось удалить ссылки %s"
 
-#: wt-status.c:264
-msgid "both modified:"
-msgstr "оба изменены:"
+#: refs/files-backend.c:1248 refs/packed-backend.c:1532
+#: refs/packed-backend.c:1542
+#, c-format
+msgid "could not delete reference %s: %s"
+msgstr "не удалось удалить ссылку %s: %s"
 
-#: wt-status.c:274
-msgid "new file:"
-msgstr "новый файл:"
+#: refs/files-backend.c:1251 refs/packed-backend.c:1545
+#, c-format
+msgid "could not delete references: %s"
+msgstr "не удалось удалить ссылки: %s"
 
-#: wt-status.c:276
-msgid "copied:"
-msgstr "скопировано:"
+#: refspec.c:137
+#, c-format
+msgid "invalid refspec '%s'"
+msgstr ""
 
-#: wt-status.c:278
-msgid "deleted:"
-msgstr "удалено:"
+#: ref-filter.c:39 wt-status.c:1909
+msgid "gone"
+msgstr "исчез"
 
-#: wt-status.c:280
-msgid "modified:"
-msgstr "изменено:"
+#: ref-filter.c:40
+#, c-format
+msgid "ahead %d"
+msgstr "впереди %d"
 
-#: wt-status.c:282
-msgid "renamed:"
-msgstr "переименовано:"
+#: ref-filter.c:41
+#, c-format
+msgid "behind %d"
+msgstr "позади %d"
 
-#: wt-status.c:284
-msgid "typechange:"
-msgstr "изменен тип:"
+#: ref-filter.c:42
+#, c-format
+msgid "ahead %d, behind %d"
+msgstr "впереди %d, позади %d"
 
-#: wt-status.c:286
-msgid "unknown:"
-msgstr "неизвестно:"
+#: ref-filter.c:138
+#, c-format
+msgid "expected format: %%(color:<color>)"
+msgstr "ожидаемый формат: %%(color:<color>)"
 
-#: wt-status.c:288
-msgid "unmerged:"
-msgstr "не слитые:"
+#: ref-filter.c:140
+#, c-format
+msgid "unrecognized color: %%(color:%s)"
+msgstr "неопознанный цвет: %%(color:%s)"
 
-#: wt-status.c:370
-msgid "new commits, "
-msgstr "новые коммиты, "
+#: ref-filter.c:162
+#, c-format
+msgid "Integer value expected refname:lstrip=%s"
+msgstr "Ожидается целочисленное значение refname:lstrip=%s"
 
-#: wt-status.c:372
-msgid "modified content, "
-msgstr "изменено содержимое, "
+#: ref-filter.c:166
+#, c-format
+msgid "Integer value expected refname:rstrip=%s"
+msgstr "Ожидается целочисленное значение refname:rstrip=%s"
 
-#: wt-status.c:374
-msgid "untracked content, "
-msgstr "неотслеживаемое содержимое, "
+#: ref-filter.c:168
+#, c-format
+msgid "unrecognized %%(%s) argument: %s"
+msgstr "неопознанный аргумент %%(%s): %s"
 
-#: wt-status.c:824
+#: ref-filter.c:223
 #, c-format
-msgid "Your stash currently has %d entry"
-msgid_plural "Your stash currently has %d entries"
-msgstr[0] "У вас сейчас спрятана %d запись"
-msgstr[1] "У вас сейчас спрятаны %d записи"
-msgstr[2] "У вас сейчас спрятано %d записей"
-msgstr[3] "У вас сейчас спрятаны %d записи"
+msgid "%%(objecttype) does not take arguments"
+msgstr ""
 
-#: wt-status.c:856
-msgid "Submodules changed but not updated:"
-msgstr "Измененные, но не обновленные подмодули:"
+#: ref-filter.c:245
+#, c-format
+msgid "unrecognized %%(objectsize) argument: %s"
+msgstr ""
 
-#: wt-status.c:858
-msgid "Submodule changes to be committed:"
-msgstr "Изменения в подмодулях, которые будут закоммичены:"
+#: ref-filter.c:253
+#, c-format
+msgid "%%(deltabase) does not take arguments"
+msgstr ""
 
-#: wt-status.c:940
-msgid ""
-"Do not modify or remove the line above.\n"
-"Everything below it will be ignored."
-msgstr "Не изменяйте или удаляйте строку выше этой.\nВсё, что ниже — будет проигнорировано."
+#: ref-filter.c:265
+#, c-format
+msgid "%%(body) does not take arguments"
+msgstr "параметр %%(body) не принимает аргументы"
 
-#: wt-status.c:1053
-msgid "You have unmerged paths."
-msgstr "У вас есть не слитые пути."
+#: ref-filter.c:274
+#, c-format
+msgid "%%(subject) does not take arguments"
+msgstr "параметр %%(subject) не принимает аргументы"
 
-#: wt-status.c:1056
-msgid "  (fix conflicts and run \"git commit\")"
-msgstr "  (разрешите конфликты, затем запустите «git commit»)"
+#: ref-filter.c:296
+#, c-format
+msgid "unknown %%(trailers) argument: %s"
+msgstr "неизвестный аргумент для %%(trailers): %s"
 
-#: wt-status.c:1058
-msgid "  (use \"git merge --abort\" to abort the merge)"
-msgstr "  (используйте «git merge --abort», чтобы остановить операцию слияния)"
+#: ref-filter.c:325
+#, c-format
+msgid "positive value expected contents:lines=%s"
+msgstr "положительное значение ожидает contents:lines=%s"
 
-#: wt-status.c:1063
-msgid "All conflicts fixed but you are still merging."
-msgstr "Все конфликты исправлены, но вы все еще в процессе слияния."
+#: ref-filter.c:327
+#, c-format
+msgid "unrecognized %%(contents) argument: %s"
+msgstr "неопознанный аргумент %%(contents): %s"
 
-#: wt-status.c:1066
-msgid "  (use \"git commit\" to conclude merge)"
-msgstr "  (используйте «git commit», чтобы завершить слияние)"
+#: ref-filter.c:342
+#, c-format
+msgid "positive value expected objectname:short=%s"
+msgstr "ожидается положительное значение objectname:short=%s"
 
-#: wt-status.c:1076
-msgid "You are in the middle of an am session."
-msgstr "Вы в процессе сессии am."
+#: ref-filter.c:346
+#, c-format
+msgid "unrecognized %%(objectname) argument: %s"
+msgstr "неопознанный аргумент %%(objectname): %s"
 
-#: wt-status.c:1079
-msgid "The current patch is empty."
-msgstr "Текущий патч пустой."
+#: ref-filter.c:376
+#, c-format
+msgid "expected format: %%(align:<width>,<position>)"
+msgstr "ожидаемый формат: %%(align:<width>,<position>)"
 
-#: wt-status.c:1083
-msgid "  (fix conflicts and then run \"git am --continue\")"
-msgstr "  (разрешите конфликты, затем запустите «git am --continue»)"
+#: ref-filter.c:388
+#, c-format
+msgid "unrecognized position:%s"
+msgstr "неопознанная позиция:%s"
 
-#: wt-status.c:1085
-msgid "  (use \"git am --skip\" to skip this patch)"
-msgstr "  (используйте «git am --skip», чтобы пропустить этот патч)"
+#: ref-filter.c:395
+#, c-format
+msgid "unrecognized width:%s"
+msgstr "неопознанная ширина:%s"
 
-#: wt-status.c:1087
-msgid "  (use \"git am --abort\" to restore the original branch)"
-msgstr "  (используйте «git am --abort», чтобы восстановить оригинальную ветку)"
+#: ref-filter.c:404
+#, c-format
+msgid "unrecognized %%(align) argument: %s"
+msgstr "неопознанный аргумент %%(align): %s"
 
-#: wt-status.c:1219
-msgid "git-rebase-todo is missing."
-msgstr "git-rebase-todo отсутствует."
+#: ref-filter.c:412
+#, c-format
+msgid "positive width expected with the %%(align) atom"
+msgstr "ожидается положительная ширина с указанием частицы %%(align)"
 
-#: wt-status.c:1221
-msgid "No commands done."
-msgstr "Команды не выполнены."
+#: ref-filter.c:430
+#, c-format
+msgid "unrecognized %%(if) argument: %s"
+msgstr "неопознанный аргумент %%(if): %s"
 
-#: wt-status.c:1224
+#: ref-filter.c:531
 #, c-format
-msgid "Last command done (%d command done):"
-msgid_plural "Last commands done (%d commands done):"
-msgstr[0] "Последняя команда выполнена (%d команда выполнена):"
-msgstr[1] "Последняя команда выполнена (%d команды выполнено):"
-msgstr[2] "Последняя команда выполнена (%d команд выполнено):"
-msgstr[3] "Последняя команда выполнена (%d команд выполнено):"
+msgid "malformed field name: %.*s"
+msgstr "неправильное имя поля: %.*s"
 
-#: wt-status.c:1235
+#: ref-filter.c:558
 #, c-format
-msgid "  (see more in file %s)"
-msgstr "  (смотрите дополнительно в файле %s)"
+msgid "unknown field name: %.*s"
+msgstr "неизвестное имя поля: %.*s"
 
-#: wt-status.c:1240
-msgid "No commands remaining."
-msgstr "Команд больше не осталось."
+#: ref-filter.c:562
+#, c-format
+msgid ""
+"not a git repository, but the field '%.*s' requires access to object data"
+msgstr ""
 
-#: wt-status.c:1243
+#: ref-filter.c:686
 #, c-format
-msgid "Next command to do (%d remaining command):"
-msgid_plural "Next commands to do (%d remaining commands):"
-msgstr[0] "Следующая команда для выполнения (%d команда осталась):"
-msgstr[1] "Следующая команда для выполнения (%d команды осталось):"
-msgstr[2] "Следующая команда для выполнения (%d команд осталось):"
-msgstr[3] "Следующая команда для выполнения (%d команд осталось):"
+msgid "format: %%(if) atom used without a %%(then) atom"
+msgstr "формат: частица %%(if) использована без частицы %%(then)"
 
-#: wt-status.c:1251
-msgid "  (use \"git rebase --edit-todo\" to view and edit)"
-msgstr "  (используйте «git rebase --edit-todo», чтобы просмотреть и изменить)"
+#: ref-filter.c:749
+#, c-format
+msgid "format: %%(then) atom used without an %%(if) atom"
+msgstr "формат: частица %%(then) использована без частицы %%(if)"
 
-#: wt-status.c:1264
+#: ref-filter.c:751
 #, c-format
-msgid "You are currently rebasing branch '%s' on '%s'."
-msgstr "Вы сейчас перемещаете ветку «%s» над «%s»."
+msgid "format: %%(then) atom used more than once"
+msgstr "формат: частица %%(then) использована более одного раза"
 
-#: wt-status.c:1269
-msgid "You are currently rebasing."
-msgstr "Вы сейчас перемещаете ветку."
+#: ref-filter.c:753
+#, c-format
+msgid "format: %%(then) atom used after %%(else)"
+msgstr "формат: частица %%(then) использована после %%(else)"
 
-#: wt-status.c:1283
-msgid "  (fix conflicts and then run \"git rebase --continue\")"
-msgstr "  (разрешите конфликты, затем запустите «git rebase --continue»)"
+#: ref-filter.c:781
+#, c-format
+msgid "format: %%(else) atom used without an %%(if) atom"
+msgstr "формат: частица %%(else) использована без частицы %%(if)"
 
-#: wt-status.c:1285
-msgid "  (use \"git rebase --skip\" to skip this patch)"
-msgstr "  (используйте «git rebase --skip», чтобы пропустить этот патч)"
+#: ref-filter.c:783
+#, c-format
+msgid "format: %%(else) atom used without a %%(then) atom"
+msgstr "формат: частица %%(else) использована без частицы %%(then)"
 
-#: wt-status.c:1287
-msgid "  (use \"git rebase --abort\" to check out the original branch)"
-msgstr "  (используйте «git rebase --abort», чтобы перейти на оригинальную ветку)"
+#: ref-filter.c:785
+#, c-format
+msgid "format: %%(else) atom used more than once"
+msgstr "формат: частица %%(else) использована более одного раза"
 
-#: wt-status.c:1293
-msgid "  (all conflicts fixed: run \"git rebase --continue\")"
-msgstr "  (все конфликты разрешены: запустите «git rebase --continue»)"
+#: ref-filter.c:800
+#, c-format
+msgid "format: %%(end) atom used without corresponding atom"
+msgstr "формат: частица %%(end) использована без соответствующей частицы"
 
-#: wt-status.c:1297
+#: ref-filter.c:857
 #, c-format
-msgid ""
-"You are currently splitting a commit while rebasing branch '%s' on '%s'."
-msgstr "Вы сейчас разделяете коммит при перемещении ветки  «%s» над «%s»."
+msgid "malformed format string %s"
+msgstr "неправильная строка формата %s"
 
-#: wt-status.c:1302
-msgid "You are currently splitting a commit during a rebase."
-msgstr "Вы сейчас разделяете коммит при перемещении ветки."
+#: ref-filter.c:1453
+#, c-format
+msgid "(no branch, rebasing %s)"
+msgstr "(нет ветки, перемещение %s)"
 
-#: wt-status.c:1305
-msgid "  (Once your working directory is clean, run \"git rebase --continue\")"
-msgstr "(Как только ваш рабочий каталог будет чистый, запустите «git rebase --continue»)"
+#: ref-filter.c:1456
+#, c-format
+msgid "(no branch, rebasing detached HEAD %s)"
+msgstr "(нет ветки перемещение отделённого HEAD %s)"
 
-#: wt-status.c:1309
+#: ref-filter.c:1459
 #, c-format
-msgid "You are currently editing a commit while rebasing branch '%s' on '%s'."
-msgstr "Вы сейчас редактируете коммит при перемещении ветки  «%s» над «%s»."
+msgid "(no branch, bisect started on %s)"
+msgstr "(нет ветки, двоичный поиск начат на %s)"
 
-#: wt-status.c:1314
-msgid "You are currently editing a commit during a rebase."
-msgstr "Вы сейчас редактируете коммит при перемещении ветки."
+#. TRANSLATORS: make sure this matches "HEAD
+#. detached at " in wt-status.c
+#: ref-filter.c:1467
+#, c-format
+msgid "(HEAD detached at %s)"
+msgstr "(HEAD отделён на %s)"
 
-#: wt-status.c:1317
-msgid "  (use \"git commit --amend\" to amend the current commit)"
-msgstr "  (используйте «git commit --amend», чтобы исправить текущий коммит)"
+#. TRANSLATORS: make sure this matches "HEAD
+#. detached from " in wt-status.c
+#: ref-filter.c:1474
+#, c-format
+msgid "(HEAD detached from %s)"
+msgstr "(HEAD отделён начиная с %s)"
 
-#: wt-status.c:1319
-msgid "  (use \"git rebase --continue\" once you are satisfied with your changes)"
-msgstr "  (используйте «git rebase --continue», когда будете довольны изменениями)"
+#: ref-filter.c:1478
+msgid "(no branch)"
+msgstr "(нет ветки)"
 
-#: wt-status.c:1329
+#: ref-filter.c:1512 ref-filter.c:1669
 #, c-format
-msgid "You are currently cherry-picking commit %s."
-msgstr "Вы копируете коммит %s."
+msgid "missing object %s for %s"
+msgstr "не найден объект %s для %s"
 
-#: wt-status.c:1334
-msgid "  (fix conflicts and run \"git cherry-pick --continue\")"
-msgstr "  (разрешите конфликты, затем запустите «git cherry-pick --continue»)"
+#: ref-filter.c:1522
+#, c-format
+msgid "parse_object_buffer failed on %s for %s"
+msgstr "сбой при выполнении parse_object_buffer на %s для %s"
 
-#: wt-status.c:1337
-msgid "  (all conflicts fixed: run \"git cherry-pick --continue\")"
-msgstr "  (все конфликты разрешены: запустите «git cherry-pick --continue»)"
+#: ref-filter.c:1888
+#, c-format
+msgid "malformed object at '%s'"
+msgstr "Повреждённый объект «%s»"
 
-#: wt-status.c:1339
-msgid "  (use \"git cherry-pick --abort\" to cancel the cherry-pick operation)"
-msgstr "  (используйте «git cherry-pick --abort», чтобы отменить копирования коммита)"
+#: ref-filter.c:1977
+#, c-format
+msgid "ignoring ref with broken name %s"
+msgstr "игнорирую ссылку с неправильным именем %s"
 
-#: wt-status.c:1348
+#: ref-filter.c:2263
 #, c-format
-msgid "You are currently reverting commit %s."
-msgstr "Вы сейчас обращаете изменения коммита %s."
+msgid "format: %%(end) atom missing"
+msgstr "format: пропущена частица %%(end)"
 
-#: wt-status.c:1353
-msgid "  (fix conflicts and run \"git revert --continue\")"
-msgstr "  (разрешите конфликты, затем запустите «git revert --continue»)"
+#: ref-filter.c:2363
+#, c-format
+msgid "option `%s' is incompatible with --merged"
+msgstr ""
 
-#: wt-status.c:1356
-msgid "  (all conflicts fixed: run \"git revert --continue\")"
-msgstr "  (все конфликты разрешены: запустите «git revert --continue»)"
+#: ref-filter.c:2366
+#, c-format
+msgid "option `%s' is incompatible with --no-merged"
+msgstr ""
 
-#: wt-status.c:1358
-msgid "  (use \"git revert --abort\" to cancel the revert operation)"
-msgstr "  (используйте «git revert --abort», чтобы отменить операцию обращения изменений коммита)"
+#: ref-filter.c:2376
+#, c-format
+msgid "malformed object name %s"
+msgstr "неправильное имя объекта %s"
 
-#: wt-status.c:1369
+#: ref-filter.c:2381
 #, c-format
-msgid "You are currently bisecting, started from branch '%s'."
-msgstr "Вы сейчас в процессе двоичного поиска, начатого с ветки «%s»."
+msgid "option `%s' must point to a commit"
+msgstr ""
 
-#: wt-status.c:1373
-msgid "You are currently bisecting."
-msgstr "Вы сейчас в процессе двоичного поиска."
+#: remote.c:363
+#, c-format
+msgid "config remote shorthand cannot begin with '/': %s"
+msgstr ""
 
-#: wt-status.c:1376
-msgid "  (use \"git bisect reset\" to get back to the original branch)"
-msgstr "  (используйте «git bisect reset», чтобы вернуться на исходную ветку)"
+#: remote.c:410
+msgid "more than one receivepack given, using the first"
+msgstr ""
 
-#: wt-status.c:1573
-msgid "On branch "
-msgstr "На ветке "
+#: remote.c:418
+msgid "more than one uploadpack given, using the first"
+msgstr ""
 
-#: wt-status.c:1579
-msgid "interactive rebase in progress; onto "
-msgstr "интерактивное перемещение в процессе; над "
+#: remote.c:608
+#, c-format
+msgid "Cannot fetch both %s and %s to %s"
+msgstr "Нельзя извлечь одновременно %s и %s в %s"
 
-#: wt-status.c:1581
-msgid "rebase in progress; onto "
-msgstr "перемещение в процессе; над "
+#: remote.c:612
+#, c-format
+msgid "%s usually tracks %s, not %s"
+msgstr "%s обычно отслеживает %s, а не %s"
 
-#: wt-status.c:1586
-msgid "HEAD detached at "
-msgstr "HEAD отделён на "
+#: remote.c:616
+#, c-format
+msgid "%s tracks both %s and %s"
+msgstr "%s отслеживает и %s и %s"
 
-#: wt-status.c:1588
-msgid "HEAD detached from "
-msgstr "HEAD отделён начиная с "
+#: remote.c:684
+#, c-format
+msgid "key '%s' of pattern had no '*'"
+msgstr ""
 
-#: wt-status.c:1591
-msgid "Not currently on any branch."
-msgstr "Сейчас ни на одной из веток"
+#: remote.c:694
+#, c-format
+msgid "value '%s' of pattern has no '*'"
+msgstr ""
 
-#: wt-status.c:1611
-msgid "Initial commit"
-msgstr "Начальный коммит"
+#: remote.c:1000
+#, c-format
+msgid "src refspec %s does not match any"
+msgstr ""
 
-#: wt-status.c:1612
-msgid "No commits yet"
-msgstr "Еще нет коммитов"
+#: remote.c:1005
+#, c-format
+msgid "src refspec %s matches more than one"
+msgstr ""
 
-#: wt-status.c:1626
-msgid "Untracked files"
-msgstr "Неотслеживаемые файлы"
+#. TRANSLATORS: "matches '%s'%" is the <dst> part of "git push
+#. <remote> <src>:<dst>" push, and "being pushed ('%s')" is
+#. the <src>.
+#: remote.c:1020
+#, c-format
+msgid ""
+"The destination you provided is not a full refname (i.e.,\n"
+"starting with \"refs/\"). We tried to guess what you meant by:\n"
+"\n"
+"- Looking for a ref that matches '%s' on the remote side.\n"
+"- Checking if the <src> being pushed ('%s')\n"
+"  is a ref in \"refs/{heads,tags}/\". If so we add a corresponding\n"
+"  refs/{heads,tags}/ prefix on the remote side.\n"
+"\n"
+"Neither worked, so we gave up. You must fully qualify the ref."
+msgstr ""
 
-#: wt-status.c:1628
-msgid "Ignored files"
-msgstr "Игнорируемые файлы"
+#: remote.c:1040
+#, c-format
+msgid ""
+"The <src> part of the refspec is a commit object.\n"
+"Did you mean to create a new branch by pushing to\n"
+"'%s:refs/heads/%s'?"
+msgstr ""
 
-#: wt-status.c:1632
+#: remote.c:1045
 #, c-format
 msgid ""
-"It took %.2f seconds to enumerate untracked files. 'status -uno'\n"
-"may speed it up, but you have to be careful not to forget to add\n"
-"new files yourself (see 'git help status')."
-msgstr "%.2f секунды занял вывод списка неотслеживаемых файлов. «status -uno» возможно может ускорить это, но будьте внимательны, и не забудьте добавить новые файлы вручную (смотрите «git help status» для подробностей)."
+"The <src> part of the refspec is a tag object.\n"
+"Did you mean to create a new tag by pushing to\n"
+"'%s:refs/tags/%s'?"
+msgstr ""
 
-#: wt-status.c:1638
+#: remote.c:1050
 #, c-format
-msgid "Untracked files not listed%s"
-msgstr "Неотслеживаемые файлы не показаны%s"
+msgid ""
+"The <src> part of the refspec is a tree object.\n"
+"Did you mean to tag a new tree by pushing to\n"
+"'%s:refs/tags/%s'?"
+msgstr ""
 
-#: wt-status.c:1640
-msgid " (use -u option to show untracked files)"
-msgstr "(используйте опцию «-u», чтобы показать неотслеживаемые файлы)"
+#: remote.c:1055
+#, c-format
+msgid ""
+"The <src> part of the refspec is a blob object.\n"
+"Did you mean to tag a new blob by pushing to\n"
+"'%s:refs/tags/%s'?"
+msgstr ""
 
-#: wt-status.c:1646
-msgid "No changes"
-msgstr "Нет изменений"
+#: remote.c:1091
+#, c-format
+msgid "%s cannot be resolved to branch"
+msgstr ""
 
-#: wt-status.c:1651
+#: remote.c:1102
 #, c-format
-msgid "no changes added to commit (use \"git add\" and/or \"git commit -a\")\n"
-msgstr "нет изменений добавленных для коммита\n(используйте «git add» и/или «git commit -a»)\n"
+msgid "unable to delete '%s': remote ref does not exist"
+msgstr ""
 
-#: wt-status.c:1654
+#: remote.c:1114
 #, c-format
-msgid "no changes added to commit\n"
-msgstr "нет изменений добавленных для коммита\n"
+msgid "dst refspec %s matches more than one"
+msgstr ""
 
-#: wt-status.c:1657
+#: remote.c:1121
 #, c-format
-msgid ""
-"nothing added to commit but untracked files present (use \"git add\" to "
-"track)\n"
-msgstr "ничего не добавлено в коммит, но есть неотслеживаемые файлы (используйте «git add», чтобы отслеживать их)\n"
+msgid "dst ref %s receives from more than one src"
+msgstr ""
+
+#: remote.c:1624 remote.c:1725
+msgid "HEAD does not point to a branch"
+msgstr "HEAD не указывает на ветку"
 
-#: wt-status.c:1660
+#: remote.c:1633
 #, c-format
-msgid "nothing added to commit but untracked files present\n"
-msgstr "ничего не добавлено в коммит, но есть неотслеживаемые файлы\n"
+msgid "no such branch: '%s'"
+msgstr "нет такой ветки: «%s»"
 
-#: wt-status.c:1663
+#: remote.c:1636
 #, c-format
-msgid "nothing to commit (create/copy files and use \"git add\" to track)\n"
-msgstr "нечего коммитить (создайте/скопируйте файлы, затем запустите «git add», чтобы отслеживать их)\n"
+msgid "no upstream configured for branch '%s'"
+msgstr "вышестоящая ветка не настроена для ветки «%s»"
 
-#: wt-status.c:1666 wt-status.c:1671
+#: remote.c:1642
 #, c-format
-msgid "nothing to commit\n"
-msgstr "нечего коммитить\n"
+msgid "upstream branch '%s' not stored as a remote-tracking branch"
+msgstr "вышестоящая ветка «%s» не сохранена как отслеживаемая ветка"
 
-#: wt-status.c:1669
+#: remote.c:1657
 #, c-format
-msgid "nothing to commit (use -u to show untracked files)\n"
-msgstr "нечего коммитить (используйте опцию «-u», чтобы показать неотслеживаемые файлы)\n"
+msgid "push destination '%s' on remote '%s' has no local tracking branch"
+msgstr "назначение для отправки «%s» на внешнем сервере «%s» не имеет локальной отслеживаемой ветки"
 
-#: wt-status.c:1673
+#: remote.c:1669
 #, c-format
-msgid "nothing to commit, working tree clean\n"
-msgstr "нечего коммитить, нет изменений в рабочем каталоге\n"
+msgid "branch '%s' has no remote for pushing"
+msgstr "ветка «%s» не имеет внешнего сервера для отправки"
 
-#: wt-status.c:1785
-msgid "No commits yet on "
-msgstr "Еще нет коммитов в"
+#: remote.c:1679
+#, c-format
+msgid "push refspecs for '%s' do not include '%s'"
+msgstr "спецификаторы пути для отправки «%s» не включают в себя «%s»"
 
-#: wt-status.c:1789
-msgid "HEAD (no branch)"
-msgstr "HEAD (нет ветки)"
+#: remote.c:1692
+msgid "push has no destination (push.default is 'nothing')"
+msgstr "отправка не имеет точки назначения (push.default выставлен в «nothing»)"
 
-#: wt-status.c:1818 wt-status.c:1826
-msgid "behind "
-msgstr "позади"
+#: remote.c:1714
+msgid "cannot resolve 'simple' push to a single destination"
+msgstr "не удалось выполнить «simple» отправку в единственную точку назначения"
 
-#: wt-status.c:1821 wt-status.c:1824
-msgid "ahead "
-msgstr "впереди "
+#: remote.c:1840
+#, c-format
+msgid "couldn't find remote ref %s"
+msgstr ""
 
-#. TRANSLATORS: the action is e.g. "pull with rebase"
-#: wt-status.c:2318
+#: remote.c:1853
 #, c-format
-msgid "cannot %s: You have unstaged changes."
-msgstr "не удалось выполнить %s: У вас есть непроиндексированные изменения."
+msgid "* Ignoring funny ref '%s' locally"
+msgstr ""
 
-#: wt-status.c:2324
-msgid "additionally, your index contains uncommitted changes."
-msgstr "к тому же, в вашем индексе есть незакоммиченные изменения."
+#: remote.c:2016
+#, c-format
+msgid "Your branch is based on '%s', but the upstream is gone.\n"
+msgstr "Ваша ветка базируется на «%s», но вышестоящий репозиторий исчез.\n"
+
+#: remote.c:2020
+msgid "  (use \"git branch --unset-upstream\" to fixup)\n"
+msgstr "(для исправления запустите «git branch --unset-upstream»)\n"
 
-#: wt-status.c:2326
+#: remote.c:2023
 #, c-format
-msgid "cannot %s: Your index contains uncommitted changes."
-msgstr "не удалось выполнить %s: В вашем индексе есть незакоммиченные изменения."
+msgid "Your branch is up to date with '%s'.\n"
+msgstr "Ваша ветка обновлена в соответствии с «%s».\n"
 
-#: compat/precompose_utf8.c:58 builtin/clone.c:437
+#: remote.c:2027
 #, c-format
-msgid "failed to unlink '%s'"
-msgstr "сбой отсоединения «%s»"
+msgid "Your branch and '%s' refer to different commits.\n"
+msgstr "Ваша ветка и «%s» указывают на разные коммиты.\n"
 
-#: builtin/add.c:24
-msgid "git add [<options>] [--] <pathspec>..."
-msgstr "git add [<опции>] [--] <спецификатор-пути>…"
+#: remote.c:2030
+#, c-format
+msgid "  (use \"%s\" for details)\n"
+msgstr "  (используйте «%s» для просмотра описания)\n"
 
-#: builtin/add.c:83
+#: remote.c:2034
 #, c-format
-msgid "unexpected diff status %c"
-msgstr "неожиданный статус различий %c"
+msgid "Your branch is ahead of '%s' by %d commit.\n"
+msgid_plural "Your branch is ahead of '%s' by %d commits.\n"
+msgstr[0] "Ваша ветка опережает «%s» на %d коммит.\n"
+msgstr[1] "Ваша ветка опережает «%s» на %d коммита.\n"
+msgstr[2] "Ваша ветка опережает «%s» на %d коммитов.\n"
+msgstr[3] "Ваша ветка опережает «%s» на %d коммитов.\n"
 
-#: builtin/add.c:88 builtin/commit.c:291
-msgid "updating files failed"
-msgstr "сбой при обновлении файлов"
+#: remote.c:2040
+msgid "  (use \"git push\" to publish your local commits)\n"
+msgstr "  (используйте «git push», чтобы опубликовать ваши локальные коммиты)\n"
 
-#: builtin/add.c:98
+#: remote.c:2043
 #, c-format
-msgid "remove '%s'\n"
-msgstr "удалить «%s»\n"
-
-#: builtin/add.c:173
-msgid "Unstaged changes after refreshing the index:"
-msgstr "Непроиндексированные изменения после обновления индекса:"
+msgid "Your branch is behind '%s' by %d commit, and can be fast-forwarded.\n"
+msgid_plural ""
+"Your branch is behind '%s' by %d commits, and can be fast-forwarded.\n"
+msgstr[0] "Ваша ветка отстает от «%s» на %d коммит и может быть перемотана вперед.\n"
+msgstr[1] "Ваша ветка отстает от «%s» на %d коммита и может быть перемотана вперед.\n"
+msgstr[2] "Ваша ветка отстает от «%s» на %d коммитов и может быть перемотана вперед.\n"
+msgstr[3] "Ваша ветка отстает от «%s» на %d коммитов и может быть перемотана вперед.\n"
 
-#: builtin/add.c:233 builtin/rev-parse.c:888
-msgid "Could not read the index"
-msgstr "Не удалось прочитать индекс"
+#: remote.c:2051
+msgid "  (use \"git pull\" to update your local branch)\n"
+msgstr "  (используйте «git pull», чтобы обновить вашу локальную ветку)\n"
 
-#: builtin/add.c:244
+#: remote.c:2054
 #, c-format
-msgid "Could not open '%s' for writing."
-msgstr "Не удалось открыть «%s» для записи."
+msgid ""
+"Your branch and '%s' have diverged,\n"
+"and have %d and %d different commit each, respectively.\n"
+msgid_plural ""
+"Your branch and '%s' have diverged,\n"
+"and have %d and %d different commits each, respectively.\n"
+msgstr[0] "Ваша ветка и «%s» разделились\nи теперь имеют %d и %d разный коммит в каждой соответственно.\n"
+msgstr[1] "Ваша ветка и «%s» разделились\nи теперь имеют %d и %d разных коммита в каждой соответственно.\n"
+msgstr[2] "Ваша ветка и «%s» разделились\nи теперь имеют %d и %d разных коммитов в каждой соответственно.\n"
+msgstr[3] "Ваша ветка и «%s» разделились\nи теперь имеют %d и %d разных коммитов в каждой соответственно.\n"
 
-#: builtin/add.c:248
-msgid "Could not write patch"
-msgstr "Не удалось записать патч"
+#: remote.c:2064
+msgid "  (use \"git pull\" to merge the remote branch into yours)\n"
+msgstr "  (используйте «git pull», чтобы слить внешнюю ветку в вашу)\n"
 
-#: builtin/add.c:251
-msgid "editing patch failed"
-msgstr "сбой при редактировании патча"
+#: remote.c:2247
+#, c-format
+msgid "cannot parse expected object name '%s'"
+msgstr ""
 
-#: builtin/add.c:254
+#: replace-object.c:21
 #, c-format
-msgid "Could not stat '%s'"
-msgstr "Не удалось выполнить stat для «%s»"
+msgid "bad replace ref name: %s"
+msgstr ""
 
-#: builtin/add.c:256
-msgid "Empty patch. Aborted."
-msgstr "Пустой патч. Операция прервана."
+#: replace-object.c:30
+#, c-format
+msgid "duplicate replace ref: %s"
+msgstr ""
 
-#: builtin/add.c:261
+#: replace-object.c:73
 #, c-format
-msgid "Could not apply '%s'"
-msgstr "Не удалось применить «%s»"
+msgid "replace depth too high for object %s"
+msgstr ""
 
-#: builtin/add.c:271
-msgid "The following paths are ignored by one of your .gitignore files:\n"
-msgstr "Следующие пути игнорируются одним из ваших файлов .gitignore:\n"
+#: rerere.c:217 rerere.c:226 rerere.c:229
+msgid "corrupt MERGE_RR"
+msgstr ""
 
-#: builtin/add.c:291 builtin/clean.c:911 builtin/fetch.c:133 builtin/mv.c:124
-#: builtin/prune-packed.c:55 builtin/pull.c:207 builtin/push.c:541
-#: builtin/remote.c:1333 builtin/rm.c:242 builtin/send-pack.c:164
-msgid "dry run"
-msgstr "пробный запуск"
+#: rerere.c:264 rerere.c:269
+msgid "unable to write rerere record"
+msgstr ""
 
-#: builtin/add.c:294
-msgid "interactive picking"
-msgstr "интерактивный выбор"
+#: rerere.c:495
+#, c-format
+msgid "there were errors while writing '%s' (%s)"
+msgstr ""
 
-#: builtin/add.c:295 builtin/checkout.c:1137 builtin/reset.c:310
-msgid "select hunks interactively"
-msgstr "интерактивный выбор блоков"
+#: rerere.c:498
+#, c-format
+msgid "failed to flush '%s'"
+msgstr ""
 
-#: builtin/add.c:296
-msgid "edit current diff and apply"
-msgstr "отредактировать текущий файл различий и применить его"
+#: rerere.c:503 rerere.c:1039
+#, c-format
+msgid "could not parse conflict hunks in '%s'"
+msgstr ""
 
-#: builtin/add.c:297
-msgid "allow adding otherwise ignored files"
-msgstr "разрешить добавление игнорируемых иначе файлов"
-
-#: builtin/add.c:298
-msgid "update tracked files"
-msgstr "обновить отслеживаемые файлы"
+#: rerere.c:684
+#, c-format
+msgid "failed utime() on '%s'"
+msgstr ""
 
-#: builtin/add.c:299
-msgid "renormalize EOL of tracked files (implies -u)"
-msgstr "перенормализировать концы строк (EOL) отслеживаемых файлов (подразумевает -u)"
+#: rerere.c:694
+#, c-format
+msgid "writing '%s' failed"
+msgstr ""
 
-#: builtin/add.c:300
-msgid "record only the fact that the path will be added later"
-msgstr "записать только факт, что путь будет добавлен позже"
+#: rerere.c:714
+#, c-format
+msgid "Staged '%s' using previous resolution."
+msgstr ""
 
-#: builtin/add.c:301
-msgid "add changes from all tracked and untracked files"
-msgstr "добавить изменения из всех отслеживаемых и неотслеживаемых файлов"
+#: rerere.c:753
+#, c-format
+msgid "Recorded resolution for '%s'."
+msgstr ""
 
-#: builtin/add.c:304
-msgid "ignore paths removed in the working tree (same as --no-all)"
-msgstr "игнорировать пути удаленные из рабочего каталога (тоже, что и --no-all)"
+#: rerere.c:788
+#, c-format
+msgid "Resolved '%s' using previous resolution."
+msgstr ""
 
-#: builtin/add.c:306
-msgid "don't add, only refresh the index"
-msgstr "не добавлять, только обновить индекс"
+#: rerere.c:803
+#, c-format
+msgid "cannot unlink stray '%s'"
+msgstr ""
 
-#: builtin/add.c:307
-msgid "just skip files which cannot be added because of errors"
-msgstr "пропускать файлы, которые не могут быть добавлены из-за ошибок"
+#: rerere.c:807
+#, c-format
+msgid "Recorded preimage for '%s'"
+msgstr ""
 
-#: builtin/add.c:308
-msgid "check if - even missing - files are ignored in dry run"
-msgstr "удостовериться, что даже недостающие файлы будут проигнорированы при  пробном запуске"
+#: rerere.c:881 submodule.c:2024 builtin/log.c:1750
+#: builtin/submodule--helper.c:1417 builtin/submodule--helper.c:1427
+#, c-format
+msgid "could not create directory '%s'"
+msgstr "не удалось создать каталог «%s»"
 
-#: builtin/add.c:309 builtin/update-index.c:964
-msgid "(+/-)x"
-msgstr "(+/-)x"
+#: rerere.c:1057
+#, c-format
+msgid "failed to update conflicted state in '%s'"
+msgstr ""
 
-#: builtin/add.c:309 builtin/update-index.c:965
-msgid "override the executable bit of the listed files"
-msgstr "переопределить бит выполнения на указанных файлах"
+#: rerere.c:1068 rerere.c:1075
+#, c-format
+msgid "no remembered resolution for '%s'"
+msgstr ""
 
-#: builtin/add.c:311
-msgid "warn when adding an embedded repository"
-msgstr "предупреждать при добавлении встроенного git репозитория"
+#: rerere.c:1077
+#, c-format
+msgid "cannot unlink '%s'"
+msgstr ""
 
-#: builtin/add.c:326
+#: rerere.c:1087
 #, c-format
-msgid ""
-"You've added another git repository inside your current repository.\n"
-"Clones of the outer repository will not contain the contents of\n"
-"the embedded repository and will not know how to obtain it.\n"
-"If you meant to add a submodule, use:\n"
-"\n"
-"\tgit submodule add <url> %s\n"
-"\n"
-"If you added this path by mistake, you can remove it from the\n"
-"index with:\n"
-"\n"
-"\tgit rm --cached %s\n"
-"\n"
-"See \"git help submodule\" for more information."
-msgstr "Вы добавили другой репозиторий git внутри текущего репозитория\nКлоны внешнего репозитория не будут содержать внутренний\nрепозиторий и не будут знать как его получить.\nЕсли вы хотели добавить подмодуль, то запустите:\n\n\tgit submodule add <url> %s\n\nЕсли бы добавили этот путь по ошибке, то вы можете удалить его\nиз индекса с помощью:\n\n\tgit rm --cached %s\n\nДля дополнительной информации смотрите «git help submodule»."
+msgid "Updated preimage for '%s'"
+msgstr ""
 
-#: builtin/add.c:354
+#: rerere.c:1096
 #, c-format
-msgid "adding embedded git repository: %s"
-msgstr "добавление встроенного git репозитория: %s"
+msgid "Forgot resolution for '%s'\n"
+msgstr ""
 
-#: builtin/add.c:372
+#: rerere.c:1199
+msgid "unable to open rr-cache directory"
+msgstr ""
+
+#: revision.c:2476
+msgid "your current branch appears to be broken"
+msgstr "похоже, ваша текущая ветка повреждена"
+
+#: revision.c:2479
 #, c-format
-msgid "Use -f if you really want to add them.\n"
-msgstr "Используйте -f, если вы действительно хотите добавить их.\n"
+msgid "your current branch '%s' does not have any commits yet"
+msgstr "ваша текущая ветка «%s» еще не содержит ни одного коммита"
 
-#: builtin/add.c:380
-msgid "adding files failed"
-msgstr "ошибка при добавлении файлов"
+#: revision.c:2679
+msgid "--first-parent is incompatible with --bisect"
+msgstr "опцию --first-parent нельзя использовать одновременно с --bisect"
 
-#: builtin/add.c:417
-msgid "-A and -u are mutually incompatible"
-msgstr "-A и -u нельзя использовать одновременно"
+#: revision.c:2683
+msgid "-L does not yet support diff formats besides -p and -s"
+msgstr ""
 
-#: builtin/add.c:424
-msgid "Option --ignore-missing can only be used together with --dry-run"
-msgstr "Опция --ignore-missing может использоваться только вместе с --dry-run"
+#: run-command.c:763
+msgid "open /dev/null failed"
+msgstr "сбой открытия /dev/null"
 
-#: builtin/add.c:428
+#: run-command.c:1269
 #, c-format
-msgid "--chmod param '%s' must be either -x or +x"
-msgstr "параметр --chmod «%s» должен быть -x или +x"
+msgid "cannot create async thread: %s"
+msgstr ""
 
-#: builtin/add.c:443
+#: run-command.c:1333
 #, c-format
-msgid "Nothing specified, nothing added.\n"
-msgstr "Ничего не указано, ничего не добавлено.\n"
+msgid ""
+"The '%s' hook was ignored because it's not set as executable.\n"
+"You can disable this warning with `git config advice.ignoredHook false`."
+msgstr "Перехватчик «%s» был проигнорирован, так как он не установлен как исполняемый.\nВы можете отключить это предупреждение с помощью команды «git config advice.ignoredHook false»."
+
+#: send-pack.c:141
+msgid "unexpected flush packet while reading remote unpack status"
+msgstr "неожиданный пустой пакет при чтении статуса внешней распаковки"
 
-#: builtin/add.c:444
+#: send-pack.c:143
 #, c-format
-msgid "Maybe you wanted to say 'git add .'?\n"
-msgstr "Возможно, вы имели в виду «git add .»?\n"
+msgid "unable to parse remote unpack status: %s"
+msgstr "не удалось разобрать статус внешней распаковки: %s"
 
-#: builtin/add.c:449 builtin/check-ignore.c:176 builtin/checkout.c:281
-#: builtin/checkout.c:484 builtin/clean.c:958 builtin/commit.c:350
-#: builtin/diff-tree.c:114 builtin/mv.c:143 builtin/reset.c:249
-#: builtin/rm.c:271 builtin/submodule--helper.c:311
-msgid "index file corrupt"
-msgstr "файл индекса поврежден"
+#: send-pack.c:145
+#, c-format
+msgid "remote unpack failed: %s"
+msgstr "сбой при внешней распаковке %s"
 
-#: builtin/am.c:414
-msgid "could not parse author script"
-msgstr "не удалось разобрать сценарий авторства"
+#: send-pack.c:306
+msgid "failed to sign the push certificate"
+msgstr "сбой подписания сертификата отправки"
 
-#: builtin/am.c:498
-#, c-format
-msgid "'%s' was deleted by the applypatch-msg hook"
-msgstr "«%s» был удален перехватчиком applypatch-msg"
+#: send-pack.c:420
+msgid "the receiving end does not support --signed push"
+msgstr "принимающая сторона не поддерживает отправку с опцией --signed"
 
-#: builtin/am.c:539
-#, c-format
-msgid "Malformed input line: '%s'."
-msgstr "Неправильная строка ввода: «%s»."
+#: send-pack.c:422
+msgid ""
+"not sending a push certificate since the receiving end does not support "
+"--signed push"
+msgstr "не отправляем сертификат для отправки, так как принимающая сторона не поддерживает отправку с опцией --signed"
 
-#: builtin/am.c:576
-#, c-format
-msgid "Failed to copy notes from '%s' to '%s'"
-msgstr "Не удалось скопировать заметку из «%s» в «%s»"
+#: send-pack.c:434
+msgid "the receiving end does not support --atomic push"
+msgstr "принимающая сторона не поддерживает отправку с опцией --atomic"
 
-#: builtin/am.c:602
-msgid "fseek failed"
-msgstr "сбой при выполнении fseek"
+#: send-pack.c:439
+msgid "the receiving end does not support push options"
+msgstr "принимающая сторона не поддерживает отправку с опциями"
 
-#: builtin/am.c:790
+#: sequencer.c:187
 #, c-format
-msgid "could not parse patch '%s'"
-msgstr "не удалось разобрать патч «%s»"
-
-#: builtin/am.c:855
-msgid "Only one StGIT patch series can be applied at once"
-msgstr "Только серия патчей StGIT может быть применена за раз"
+msgid "invalid commit message cleanup mode '%s'"
+msgstr "неправильный режим очистки сообщения коммита «%s»"
 
-#: builtin/am.c:903
-msgid "invalid timestamp"
-msgstr "недопустимая метка даты/времени"
+#: sequencer.c:292
+#, c-format
+msgid "could not delete '%s'"
+msgstr "не удалось удалить «%s»"
 
-#: builtin/am.c:908 builtin/am.c:920
-msgid "invalid Date line"
-msgstr "недопустимая строка даты"
+#: sequencer.c:318
+msgid "revert"
+msgstr "обратить изменения"
 
-#: builtin/am.c:915
-msgid "invalid timezone offset"
-msgstr "недопустимое смещение часового пояса"
+#: sequencer.c:320
+msgid "cherry-pick"
+msgstr "копировать коммит"
 
-#: builtin/am.c:1008
-msgid "Patch format detection failed."
-msgstr "Сбой определения формата патча."
+#: sequencer.c:322
+msgid "rebase -i"
+msgstr "rebase -i"
 
-#: builtin/am.c:1013 builtin/clone.c:402
+#: sequencer.c:324
 #, c-format
-msgid "failed to create directory '%s'"
-msgstr "не удалось создать каталог «%s»"
+msgid "unknown action: %d"
+msgstr ""
 
-#: builtin/am.c:1017
-msgid "Failed to split patches."
-msgstr "Не удалось разделить патчи на части."
+#: sequencer.c:382
+msgid ""
+"after resolving the conflicts, mark the corrected paths\n"
+"with 'git add <paths>' or 'git rm <paths>'"
+msgstr "после разрешения конфликтов, пометьте исправленные пути\nс помощью «git add <пути>» или «git rm <пути>»"
 
-#: builtin/am.c:1146 builtin/commit.c:376
-msgid "unable to write index file"
-msgstr "не удалось записать индекс"
+#: sequencer.c:385
+msgid ""
+"after resolving the conflicts, mark the corrected paths\n"
+"with 'git add <paths>' or 'git rm <paths>'\n"
+"and commit the result with 'git commit'"
+msgstr "после разрешения конфликтов, пометьте исправленные пути\nс помощью «git add <пути>» или «git rm <пути>»\nи сделайте коммит с помощью «git commit»"
 
-#: builtin/am.c:1160
+#: sequencer.c:398 sequencer.c:2801
 #, c-format
-msgid "When you have resolved this problem, run \"%s --continue\"."
-msgstr "Когда вы устраните эту проблему, запустите «%s --continue»."
+msgid "could not lock '%s'"
+msgstr "не удалось заблокировать «%s»"
 
-#: builtin/am.c:1161
+#: sequencer.c:405
 #, c-format
-msgid "If you prefer to skip this patch, run \"%s --skip\" instead."
-msgstr "Если вы хотите пропустить этот патч, то запустите «%s --skip»."
+msgid "could not write eol to '%s'"
+msgstr "не удалось записать eol в «%s»"
 
-#: builtin/am.c:1162
+#: sequencer.c:410 sequencer.c:2684 sequencer.c:2807 sequencer.c:2821
+#: sequencer.c:3084
 #, c-format
-msgid "To restore the original branch and stop patching, run \"%s --abort\"."
-msgstr "Чтобы вернуться на предыдущую ветку и остановить применение изменений, запустите «%s --abort»."
-
-#: builtin/am.c:1269
-msgid "Patch is empty."
-msgstr "Патч пустой."
+msgid "failed to finalize '%s'"
+msgstr "не удалось завершить «%s»"
 
-#: builtin/am.c:1335
+#: sequencer.c:433 sequencer.c:978 sequencer.c:1652 sequencer.c:2704
+#: sequencer.c:3066 sequencer.c:3175 builtin/am.c:245 builtin/commit.c:760
+#: builtin/merge.c:1115 builtin/rebase.c:567
 #, c-format
-msgid "invalid ident line: %.*s"
-msgstr "неправильная строка идентификации: %.*s"
+msgid "could not read '%s'"
+msgstr "не удалось прочитать «%s»"
 
-#: builtin/am.c:1357
+#: sequencer.c:459
 #, c-format
-msgid "unable to parse commit %s"
-msgstr "не удалось разобрать коммит %s"
+msgid "your local changes would be overwritten by %s."
+msgstr "ваши локальные изменения будут перезаписаны %s."
 
-#: builtin/am.c:1550
-msgid "Repository lacks necessary blobs to fall back on 3-way merge."
-msgstr "В репозитории отсутствуют двоичные объекты, необходимые для отката к трехходовому слиянию."
+#: sequencer.c:463
+msgid "commit your changes or stash them to proceed."
+msgstr "для продолжения закоммитьте ваши изменения или спрячьте их."
 
-#: builtin/am.c:1552
-msgid "Using index info to reconstruct a base tree..."
-msgstr "Использую индекс для реконструкции базового дерева…"
+#: sequencer.c:495
+#, c-format
+msgid "%s: fast-forward"
+msgstr "%s: перемотка вперед"
 
-#: builtin/am.c:1571
-msgid ""
-"Did you hand edit your patch?\n"
-"It does not apply to blobs recorded in its index."
-msgstr "Вы вручную изменяли патч?\nОн не накладывается без ошибок на двоичные объекты, записанные в его заголовке."
+#: sequencer.c:534 builtin/tag.c:555
+#, c-format
+msgid "Invalid cleanup mode %s"
+msgstr "Неправильное значение режима очистки %s"
 
-#: builtin/am.c:1577
-msgid "Falling back to patching base and 3-way merge..."
-msgstr "Откат к применению изменений к базовому коммиту с помощью трехходового слияния…"
+#. TRANSLATORS: %s will be "revert", "cherry-pick" or
+#. "rebase -i".
+#: sequencer.c:629
+#, c-format
+msgid "%s: Unable to write new index file"
+msgstr "%s: Не удалось записать файл индекса"
 
-#: builtin/am.c:1602
-msgid "Failed to merge in the changes."
-msgstr "Не удалось слить изменения."
+#: sequencer.c:646
+msgid "unable to update cache tree"
+msgstr "не удалось обновить дерево кэша"
 
-#: builtin/am.c:1626 builtin/merge.c:642
-msgid "git write-tree failed to write a tree"
-msgstr "git write-tree не удалось записать дерево"
+#: sequencer.c:660
+msgid "could not resolve HEAD commit"
+msgstr "не удалось распознать HEAD коммит"
 
-#: builtin/am.c:1633
-msgid "applying to an empty history"
-msgstr "применение к пустой истории"
+#: sequencer.c:740
+#, c-format
+msgid "no key present in '%.*s'"
+msgstr ""
 
-#: builtin/am.c:1646 builtin/commit.c:1798 builtin/merge.c:825
-#: builtin/merge.c:850
-msgid "failed to write commit object"
-msgstr "сбой записи объекта коммита"
+#: sequencer.c:751
+#, c-format
+msgid "unable to dequote value of '%s'"
+msgstr ""
 
-#: builtin/am.c:1679 builtin/am.c:1683
+#: sequencer.c:788 wrapper.c:227 wrapper.c:397 builtin/am.c:706
+#: builtin/am.c:798 builtin/merge.c:1112 builtin/rebase.c:1035
 #, c-format
-msgid "cannot resume: %s does not exist."
-msgstr "нельзя продолжнить: %s не существует "
+msgid "could not open '%s' for reading"
+msgstr "не удалось открыть «%s» для чтения"
 
-#: builtin/am.c:1699
-msgid "cannot be interactive without stdin connected to a terminal."
-msgstr "не удалось использовать интерактивное поведение, без stdin подключенного к терминалу."
+#: sequencer.c:798
+msgid "'GIT_AUTHOR_NAME' already given"
+msgstr ""
 
-#: builtin/am.c:1704
-msgid "Commit Body is:"
-msgstr "Тело коммита:"
+#: sequencer.c:803
+msgid "'GIT_AUTHOR_EMAIL' already given"
+msgstr ""
 
-#. TRANSLATORS: Make sure to include [y], [n], [e], [v] and [a]
-#. in your translation. The program will only accept English
-#. input at this point.
-#: builtin/am.c:1714
-msgid "Apply? [y]es/[n]o/[e]dit/[v]iew patch/[a]ccept all: "
-msgstr "Применить? [y] - да/[n] - нет/[e] - редактировать/[v] - просмотреть патч/[a] - применить всё: "
+#: sequencer.c:808
+msgid "'GIT_AUTHOR_DATE' already given"
+msgstr ""
 
-#: builtin/am.c:1764
+#: sequencer.c:812
 #, c-format
-msgid "Dirty index: cannot apply patches (dirty: %s)"
-msgstr "Индекс не пустой: нельзя применять патчи (в индексе: %s)"
+msgid "unknown variable '%s'"
+msgstr ""
 
-#: builtin/am.c:1804 builtin/am.c:1876
-#, c-format
-msgid "Applying: %.*s"
-msgstr "Применение: %.*s"
+#: sequencer.c:817
+msgid "missing 'GIT_AUTHOR_NAME'"
+msgstr ""
 
-#: builtin/am.c:1820
-msgid "No changes -- Patch already applied."
-msgstr "Нет изменений — Патч уже применен."
+#: sequencer.c:819
+msgid "missing 'GIT_AUTHOR_EMAIL'"
+msgstr ""
+
+#: sequencer.c:821
+msgid "missing 'GIT_AUTHOR_DATE'"
+msgstr ""
 
-#: builtin/am.c:1828
+#: sequencer.c:881
 #, c-format
-msgid "Patch failed at %s %.*s"
-msgstr "Ошибка применения изменений на %s %.*s"
+msgid "invalid date format '%s' in '%s'"
+msgstr ""
 
-#: builtin/am.c:1834
+#: sequencer.c:898
 #, c-format
-msgid "The copy of the patch that failed is found in: %s"
-msgstr "Копию изменений, которые не удалось применить, вы можете найти в: %s"
+msgid ""
+"you have staged changes in your working tree\n"
+"If these changes are meant to be squashed into the previous commit, run:\n"
+"\n"
+"  git commit --amend %s\n"
+"\n"
+"If they are meant to go into a new commit, run:\n"
+"\n"
+"  git commit %s\n"
+"\n"
+"In both cases, once you're done, continue with:\n"
+"\n"
+"  git rebase --continue\n"
+msgstr "у вас имеются проиндексированные изменения в рабочем каталоге. Если эти изменения должны быть объеденены с предыдущим коммитом, то запустите:\n\n  git commit --amend %s\n\nЕсли же они должны быть помещены в новый коммит, то запустите:\n\n  git commit %s\n\nВ любом случае, после того как вы закончите, продолжить перемещение можно выполнив:\n\n  git rebase --continue\n"
+
+#: sequencer.c:992
+msgid "writing root commit"
+msgstr "запись коневого коммита"
+
+#: sequencer.c:1213
+msgid "'prepare-commit-msg' hook failed"
+msgstr "ошибка при вызове перехватчика «prepare-commit-msg»"
 
-#: builtin/am.c:1879
+#: sequencer.c:1220
 msgid ""
-"No changes - did you forget to use 'git add'?\n"
-"If there is nothing left to stage, chances are that something else\n"
-"already introduced the same changes; you might want to skip this patch."
-msgstr "Нет изменений — возможно, вы забыли вызвать «git add»?\nЕсли ничего не осталось для индексации, то, скорее всего, что-то другое уже сделало те же изменения; возможно, вам следует пропустить этот патч."
+"Your name and email address were configured automatically based\n"
+"on your username and hostname. Please check that they are accurate.\n"
+"You can suppress this message by setting them explicitly. Run the\n"
+"following command and follow the instructions in your editor to edit\n"
+"your configuration file:\n"
+"\n"
+"    git config --global --edit\n"
+"\n"
+"After doing this, you may fix the identity used for this commit with:\n"
+"\n"
+"    git commit --amend --reset-author\n"
+msgstr "Ваше имя или электронная почта настроены автоматически на основании вашего\nимени пользователя и имени машины. Пожалуйста, проверьте, что они \nопределены правильно.\nВы можете отключить это уведомление установив их напрямую. Запустите следующую\nкоманду и следуйте инструкциям вашего текстового редактора, для\nредактирования вашего файла конфигурации:\n\n    git config --global --edit\n\nПосле этого, изменить авторство этой коммита можно будет с помощью команды:\n\n    git commit --amend --reset-author\n"
 
-#: builtin/am.c:1886
+#: sequencer.c:1233
 msgid ""
-"You still have unmerged paths in your index.\n"
-"You should 'git add' each file with resolved conflicts to mark them as such.\n"
-"You might run `git rm` on a file to accept \"deleted by them\" for it."
-msgstr "У вас есть не слитые пути в индексе.\nВы должны выполнить «git add» для каждого файла с разрешенными конфликтами, чтобы пометить их таковыми.\nВы можете запустить «git rm» с именем файла, чтобы пометить его как «удалено ими»."
+"Your name and email address were configured automatically based\n"
+"on your username and hostname. Please check that they are accurate.\n"
+"You can suppress this message by setting them explicitly:\n"
+"\n"
+"    git config --global user.name \"Your Name\"\n"
+"    git config --global user.email you@example.com\n"
+"\n"
+"After doing this, you may fix the identity used for this commit with:\n"
+"\n"
+"    git commit --amend --reset-author\n"
+msgstr "Ваше имя или электронная почта настроены автоматически на основании вашего\nимени пользователя и имени машины. Пожалуйста, проверьте, что они \nопределены правильно.\nВы можете отключить это уведомление установив их напрямую:\n\n    git config --global user.name \"Ваше Имя\"\n    git config --global user.email you@example.com\n\nПосле этого, изменить авторство этой коммита можно будет с помощью команды:\n\n    git commit --amend --reset-author\n"
 
-#: builtin/am.c:1993 builtin/am.c:1997 builtin/am.c:2009 builtin/reset.c:332
-#: builtin/reset.c:340
-#, c-format
-msgid "Could not parse object '%s'."
-msgstr "Не удалось разобрать объект «%s»."
+#: sequencer.c:1275
+msgid "couldn't look up newly created commit"
+msgstr "нельзя запросить новосозданный коммит"
 
-#: builtin/am.c:2045
-msgid "failed to clean index"
-msgstr "не удалось очистить индекс"
+#: sequencer.c:1277
+msgid "could not parse newly created commit"
+msgstr "нельзя разобрать новосозданный коммит"
 
-#: builtin/am.c:2080
-msgid ""
-"You seem to have moved HEAD since the last 'am' failure.\n"
-"Not rewinding to ORIG_HEAD"
-msgstr "Похоже, что вы переместили HEAD с момента последней ошибки выполнения «am».\nПеремотка на ORIG_HEAD не выполняется"
+#: sequencer.c:1323
+msgid "unable to resolve HEAD after creating commit"
+msgstr "не удалось найти HEAD после создания коммита"
 
-#: builtin/am.c:2143
-#, c-format
-msgid "Invalid value for --patch-format: %s"
-msgstr "Неправильное значение для --patch-format: %s"
+#: sequencer.c:1325
+msgid "detached HEAD"
+msgstr "отделённый HEAD"
 
-#: builtin/am.c:2176
-msgid "git am [<options>] [(<mbox> | <Maildir>)...]"
-msgstr "git am [<опции>] [(<mbox> | <Maildir>)…]"
+#: sequencer.c:1329
+msgid " (root-commit)"
+msgstr " (корневой коммит)"
 
-#: builtin/am.c:2177
-msgid "git am [<options>] (--continue | --skip | --abort)"
-msgstr "git am [<опции>] (--continue | --skip | --abort)"
+#: sequencer.c:1350
+msgid "could not parse HEAD"
+msgstr "не удалось разобрать HEAD"
 
-#: builtin/am.c:2183
-msgid "run interactively"
-msgstr "запустить в интерактивном режиме"
+#: sequencer.c:1352
+#, c-format
+msgid "HEAD %s is not a commit!"
+msgstr "HEAD %s не является коммитом!"
 
-#: builtin/am.c:2185
-msgid "historical option -- no-op"
-msgstr "историческая опция — ничего не делает"
+#: sequencer.c:1356 builtin/commit.c:1551
+msgid "could not parse HEAD commit"
+msgstr "не удалось разобрать HEAD коммит"
 
-#: builtin/am.c:2187
-msgid "allow fall back on 3way merging if needed"
-msgstr "разрешить откатиться к трехходовому слиянию, если нужно"
+#: sequencer.c:1408 sequencer.c:2001
+msgid "unable to parse commit author"
+msgstr "не удалось разобрать автора коммита"
 
-#: builtin/am.c:2188 builtin/init-db.c:484 builtin/prune-packed.c:57
-#: builtin/repack.c:180
-msgid "be quiet"
-msgstr "тихий режим"
+#: sequencer.c:1418 builtin/am.c:1572 builtin/merge.c:688
+msgid "git write-tree failed to write a tree"
+msgstr "git write-tree не удалось записать дерево"
 
-#: builtin/am.c:2190
-msgid "add a Signed-off-by line to the commit message"
-msgstr "добавить строку Signed-off-by к сообщению коммита"
+#: sequencer.c:1435 sequencer.c:1496
+#, c-format
+msgid "unable to read commit message from '%s'"
+msgstr "не удалось прочитать сообщение коммита из «%s»"
 
-#: builtin/am.c:2193
-msgid "recode into utf8 (default)"
-msgstr "перекодировать в utf8 (по умолчанию)"
+#: sequencer.c:1462 builtin/am.c:1594 builtin/commit.c:1650
+#: builtin/merge.c:882 builtin/merge.c:906
+msgid "failed to write commit object"
+msgstr "сбой записи объекта коммита"
 
-#: builtin/am.c:2195
-msgid "pass -k flag to git-mailinfo"
-msgstr "передать флаг -k в git-mailinfo"
+#: sequencer.c:1523
+#, c-format
+msgid "could not parse commit %s"
+msgstr "не удалось разобрать коммит %s"
 
-#: builtin/am.c:2197
-msgid "pass -b flag to git-mailinfo"
-msgstr "передать флаг -b в git-mailinfo"
+#: sequencer.c:1528
+#, c-format
+msgid "could not parse parent commit %s"
+msgstr "не удалось разобрать родительский коммит %s"
 
-#: builtin/am.c:2199
-msgid "pass -m flag to git-mailinfo"
-msgstr "передать флаг -m в git-mailinfo"
+#: sequencer.c:1602 sequencer.c:1712
+#, c-format
+msgid "unknown command: %d"
+msgstr "неизвестная команда: %d"
 
-#: builtin/am.c:2201
-msgid "pass --keep-cr flag to git-mailsplit for mbox format"
-msgstr "передать флаг --keep-cr в git-mailsplit для формата mbox"
+#: sequencer.c:1659 sequencer.c:1684
+#, c-format
+msgid "This is a combination of %d commits."
+msgstr "Это объединение %d коммитов."
 
-#: builtin/am.c:2204
-msgid "do not pass --keep-cr flag to git-mailsplit independent of am.keepcr"
-msgstr "не передавать --keep-cr флаг в git-mailsplit вне зависимости от am.keepcr"
+#: sequencer.c:1669
+msgid "need a HEAD to fixup"
+msgstr "нужен HEAD для исправления"
 
-#: builtin/am.c:2207
-msgid "strip everything before a scissors line"
-msgstr "обрезать все до строки обрезки"
+#: sequencer.c:1671 sequencer.c:3111
+msgid "could not read HEAD"
+msgstr "не удалось прочитать HEAD"
 
-#: builtin/am.c:2209 builtin/am.c:2212 builtin/am.c:2215 builtin/am.c:2218
-#: builtin/am.c:2221 builtin/am.c:2224 builtin/am.c:2227 builtin/am.c:2230
-#: builtin/am.c:2236
-msgid "pass it through git-apply"
-msgstr "передать его в git-apply"
+#: sequencer.c:1673
+msgid "could not read HEAD's commit message"
+msgstr "не удалось прочитать сообщение коммита текущего HEAD"
 
-#: builtin/am.c:2226 builtin/fmt-merge-msg.c:665 builtin/fmt-merge-msg.c:668
-#: builtin/grep.c:845 builtin/merge.c:205 builtin/pull.c:145
-#: builtin/pull.c:203 builtin/repack.c:189 builtin/repack.c:193
-#: builtin/repack.c:195 builtin/show-branch.c:631 builtin/show-ref.c:169
-#: builtin/tag.c:377 parse-options.h:132 parse-options.h:134
-#: parse-options.h:245
-msgid "n"
-msgstr "n"
+#: sequencer.c:1679
+#, c-format
+msgid "cannot write '%s'"
+msgstr "не удалось записать «%s»"
 
-#: builtin/am.c:2232 builtin/branch.c:629 builtin/for-each-ref.c:38
-#: builtin/replace.c:444 builtin/tag.c:412 builtin/verify-tag.c:39
-msgid "format"
-msgstr "формат"
+#: sequencer.c:1686 git-rebase--preserve-merges.sh:441
+msgid "This is the 1st commit message:"
+msgstr "Это 1-е сообщение коммита:"
 
-#: builtin/am.c:2233
-msgid "format the patch(es) are in"
-msgstr "формат, в котором находятся патчи"
+#: sequencer.c:1694
+#, c-format
+msgid "could not read commit message of %s"
+msgstr "не удалось прочитать сообщение коммита для %s"
 
-#: builtin/am.c:2239
-msgid "override error message when patch failure occurs"
-msgstr "переопределить сообщение об ошибке, если не удалось наложить изменения"
+#: sequencer.c:1701
+#, c-format
+msgid "This is the commit message #%d:"
+msgstr "Это сообщение коммита номер #%d:"
 
-#: builtin/am.c:2241
-msgid "continue applying patches after resolving a conflict"
-msgstr "продолжить применение изменений после разрешения конфиликта"
+#: sequencer.c:1707
+#, c-format
+msgid "The commit message #%d will be skipped:"
+msgstr "Сообщение коммита номер #%d будет пропущено:"
 
-#: builtin/am.c:2244
-msgid "synonyms for --continue"
-msgstr "синоним для --continue"
+#: sequencer.c:1795
+msgid "your index file is unmerged."
+msgstr "ваш индекс не слит."
 
-#: builtin/am.c:2247
-msgid "skip the current patch"
-msgstr "пропустить текущий патч"
+#: sequencer.c:1802
+msgid "cannot fixup root commit"
+msgstr "нельзя исправить корневой коммит"
 
-#: builtin/am.c:2250
-msgid "restore the original branch and abort the patching operation."
-msgstr "восстановить оригинальную ветку и отменить операцию применения изменений."
+#: sequencer.c:1821
+#, c-format
+msgid "commit %s is a merge but no -m option was given."
+msgstr "коммит %s — это коммит-слияние, но опция -m не указана."
 
-#: builtin/am.c:2254
-msgid "lie about committer date"
-msgstr "соврать о дате коммитера"
+#: sequencer.c:1829 sequencer.c:1837
+#, c-format
+msgid "commit %s does not have parent %d"
+msgstr "у коммита %s нет предка %d"
 
-#: builtin/am.c:2256
-msgid "use current timestamp for author date"
-msgstr "использовать текущее время как время авторства"
+#: sequencer.c:1843
+#, c-format
+msgid "cannot get commit message for %s"
+msgstr "не удалось получить сообщение коммита для %s"
 
-#: builtin/am.c:2258 builtin/commit.c:1636 builtin/merge.c:236
-#: builtin/pull.c:178 builtin/revert.c:112 builtin/tag.c:392
-msgid "key-id"
-msgstr "key-id"
+#. TRANSLATORS: The first %s will be a "todo" command like
+#. "revert" or "pick", the second %s a SHA1.
+#: sequencer.c:1862
+#, c-format
+msgid "%s: cannot parse parent commit %s"
+msgstr "%s: не удалось разобрать родительский коммит для %s"
 
-#: builtin/am.c:2259
-msgid "GPG-sign commits"
-msgstr "подписать коммиты с помощью GPG"
+#: sequencer.c:1927
+#, c-format
+msgid "could not rename '%s' to '%s'"
+msgstr "не удалось переименовать «%s» в «%s»"
 
-#: builtin/am.c:2262
-msgid "(internal use for git-rebase)"
-msgstr "(внутреннее использование для git-rebase)"
+#: sequencer.c:1982
+#, c-format
+msgid "could not revert %s... %s"
+msgstr "не удалось обратить изменения коммита %s… %s"
 
-#: builtin/am.c:2280
-msgid ""
-"The -b/--binary option has been a no-op for long time, and\n"
-"it will be removed. Please do not use it anymore."
-msgstr "Опция -b/--binary уже долгое время ничего не делает и будет удалена с следующих версиях Git. Пожалуйста, не используйте ее."
+#: sequencer.c:1983
+#, c-format
+msgid "could not apply %s... %s"
+msgstr "не удалось применить коммит %s… %s"
 
-#: builtin/am.c:2287
-msgid "failed to read the index"
-msgstr "сбой чтения индекса"
+#: sequencer.c:2042
+#, c-format
+msgid "git %s: failed to read the index"
+msgstr "git %s: сбой чтения индекса"
 
-#: builtin/am.c:2302
+#: sequencer.c:2049
 #, c-format
-msgid "previous rebase directory %s still exists but mbox given."
-msgstr "предыдущий каталог перемещения %s еще существует, но передан mbox."
+msgid "git %s: failed to refresh the index"
+msgstr "git %s: сбой обновления индекса"
 
-#: builtin/am.c:2326
+#: sequencer.c:2118
 #, c-format
-msgid ""
-"Stray %s directory found.\n"
-"Use \"git am --abort\" to remove it."
-msgstr "Найден забытый каталог %s.\nИспользуйте «git am --abort», чтобы удалить его."
+msgid "%s does not accept arguments: '%s'"
+msgstr "параметр %s не принимает аргументы: «%s»"
 
-#: builtin/am.c:2332
-msgid "Resolve operation not in progress, we are not resuming."
-msgstr "Операция разрешения конфликтов не в процессе выполнения, не продолжаем."
+#: sequencer.c:2127
+#, c-format
+msgid "missing arguments for %s"
+msgstr "пропущены аргументы для %s"
 
-#: builtin/apply.c:8
-msgid "git apply [<options>] [<patch>...]"
-msgstr "git apply [<опции>] [<патч>…]"
+#: sequencer.c:2164
+#, c-format
+msgid "could not parse '%.*s'"
+msgstr ""
 
-#: builtin/archive.c:17
+#: sequencer.c:2226
 #, c-format
-msgid "could not create archive file '%s'"
-msgstr "не удалось создать файл архива «%s»"
+msgid "invalid line %d: %.*s"
+msgstr "неправильная строка %d: %.*s"
 
-#: builtin/archive.c:20
-msgid "could not redirect output"
-msgstr "не удалось перенаправить вывод"
+#: sequencer.c:2237
+#, c-format
+msgid "cannot '%s' without a previous commit"
+msgstr "нельзя выполнить «%s» без указания предыдущего коммита"
 
-#: builtin/archive.c:37
-msgid "git archive: Remote with no URL"
-msgstr "git archive: внешний репозиторий без URL"
+#: sequencer.c:2285 builtin/rebase.c:153 builtin/rebase.c:178
+#: builtin/rebase.c:204 builtin/rebase.c:229
+#, c-format
+msgid "could not read '%s'."
+msgstr "не удалось прочитать «%s»."
 
-#: builtin/archive.c:58
-msgid "git archive: expected ACK/NAK, got EOF"
-msgstr "git archive: ожидался ACK/NAK, а получен EOF"
+#: sequencer.c:2360
+msgid "please fix this using 'git rebase --edit-todo'."
+msgstr "пожалуйста исправьте это с помощью «git rebase --edit-todo»."
 
-#: builtin/archive.c:61
+#: sequencer.c:2362
 #, c-format
-msgid "git archive: NACK %s"
-msgstr "git archive: NACK %s"
-
-#: builtin/archive.c:64
-msgid "git archive: protocol error"
-msgstr "git archive: ошибка протокола"
-
-#: builtin/archive.c:68
-msgid "git archive: expected a flush"
-msgstr "git archive: ожидался сброс буфера"
+msgid "unusable instruction sheet: '%s'"
+msgstr "непригодная для использования карта с инструкциями: «%s»"
 
-#: builtin/bisect--helper.c:12
-msgid "git bisect--helper --next-all [--no-checkout]"
-msgstr "git bisect--helper --next-all [--no-checkout]"
+#: sequencer.c:2367
+msgid "no commits parsed."
+msgstr "коммиты не разобраны."
 
-#: builtin/bisect--helper.c:13
-msgid "git bisect--helper --write-terms <bad_term> <good_term>"
-msgstr "git bisect--helper --write-terms <плохое-определение> <хорошее-определение>"
+#: sequencer.c:2378
+msgid "cannot cherry-pick during a revert."
+msgstr "нельзя скопировать коммит во время процесса обращения коммита."
 
-#: builtin/bisect--helper.c:14
-msgid "git bisect--helper --bisect-clean-state"
-msgstr "git bisect--helper --bisect-clean-state"
+#: sequencer.c:2380
+msgid "cannot revert during a cherry-pick."
+msgstr "нельзя обратить изменения коммита во время копирования коммита."
 
-#: builtin/bisect--helper.c:46
+#: sequencer.c:2462
 #, c-format
-msgid "'%s' is not a valid term"
-msgstr "«%s» не является допустимым определением"
+msgid "invalid value for %s: %s"
+msgstr "неправильное значение %s: %s"
 
-#: builtin/bisect--helper.c:50
-#, c-format
-msgid "can't use the builtin command '%s' as a term"
-msgstr "нельзя использовать встроенную команду «%s» как определение"
+#: sequencer.c:2549
+msgid "unusable squash-onto"
+msgstr "непригодный для использования уплотнить-над"
 
-#: builtin/bisect--helper.c:60
+#: sequencer.c:2565
 #, c-format
-msgid "can't change the meaning of the term '%s'"
-msgstr "нельзя изменить значение определения «%s»"
-
-#: builtin/bisect--helper.c:71
-msgid "please use two different terms"
-msgstr "используйте два разных определения"
+msgid "malformed options sheet: '%s'"
+msgstr "испорченная карта с опциями: «%s»"
 
-#: builtin/bisect--helper.c:78
-msgid "could not open the file BISECT_TERMS"
-msgstr "не удалось открыть файл BISECT_TERMS"
+#: sequencer.c:2648 sequencer.c:4227
+msgid "empty commit set passed"
+msgstr "передан пустой набор коммитов"
 
-#: builtin/bisect--helper.c:120
-msgid "perform 'git bisect next'"
-msgstr "выполнить «git bisect next»"
+#: sequencer.c:2656
+msgid "a cherry-pick or revert is already in progress"
+msgstr "копирование или обращение изменений коммита уже выполняются"
 
-#: builtin/bisect--helper.c:122
-msgid "write the terms to .git/BISECT_TERMS"
-msgstr "записать определения в .git/BISECT_TERMS"
+#: sequencer.c:2657
+msgid "try \"git cherry-pick (--continue | --quit | --abort)\""
+msgstr "попробуйте «git cherry-pick (--continue | --quit | --abort)»"
 
-#: builtin/bisect--helper.c:124
-msgid "cleanup the bisection state"
-msgstr "очистить состояние двоичного поиска"
+#: sequencer.c:2660
+#, c-format
+msgid "could not create sequencer directory '%s'"
+msgstr "не удалось создать каталог для указателя следования коммитов «%s»"
 
-#: builtin/bisect--helper.c:126
-msgid "check for expected revs"
-msgstr "проверить ожидаемые редакции"
+#: sequencer.c:2674
+msgid "could not lock HEAD"
+msgstr "не удалось заблокировать HEAD"
 
-#: builtin/bisect--helper.c:128
-msgid "update BISECT_HEAD instead of checking out the current commit"
-msgstr "обновить BISECT_HEAD вместо перехода на текущий коммит"
+#: sequencer.c:2729 sequencer.c:3979
+msgid "no cherry-pick or revert in progress"
+msgstr "копирование или обращение изменений коммита уже выполняются"
 
-#: builtin/bisect--helper.c:143
-msgid "--write-terms requires two arguments"
-msgstr "--write-terms требует указания двух параметров"
+#: sequencer.c:2731
+msgid "cannot resolve HEAD"
+msgstr "не удалось определить HEAD"
 
-#: builtin/bisect--helper.c:147
-msgid "--bisect-clean-state requires no arguments"
-msgstr "--bisect-clean-state не требует указания параметров"
+#: sequencer.c:2733 sequencer.c:2768
+msgid "cannot abort from a branch yet to be born"
+msgstr "нельзя отменить изменения с ветки, которая еще не создана"
 
-#: builtin/blame.c:27
-msgid "git blame [<options>] [<rev-opts>] [<rev>] [--] <file>"
-msgstr "git blame [<опции>] [<опции-редакции>] [<редакция>] [--] <файл>"
+#: sequencer.c:2754 builtin/grep.c:732
+#, c-format
+msgid "cannot open '%s'"
+msgstr "не удалось открыть «%s»"
 
-#: builtin/blame.c:32
-msgid "<rev-opts> are documented in git-rev-list(1)"
-msgstr "<опции-rev-list> документированы в git-rev-list(1)"
+#: sequencer.c:2756
+#, c-format
+msgid "cannot read '%s': %s"
+msgstr "не удалось прочитать «%s»: %s"
 
-#: builtin/blame.c:668
-msgid "Show blame entries as we find them, incrementally"
-msgstr "Показать записи авторства постепенно, в процессе нахождения"
+#: sequencer.c:2757
+msgid "unexpected end of file"
+msgstr "неожиданный конец файла"
 
-#: builtin/blame.c:669
-msgid "Show blank SHA-1 for boundary commits (Default: off)"
-msgstr "Не показывать SHA-1 для коммитов, не входящих в границы запроса (По умолчанию: отключено)"
+#: sequencer.c:2763
+#, c-format
+msgid "stored pre-cherry-pick HEAD file '%s' is corrupt"
+msgstr "сохраненный файл с HEAD перед копированием коммита «%s» поврежден"
 
-#: builtin/blame.c:670
-msgid "Do not treat root commits as boundaries (Default: off)"
-msgstr "Не воспринимать корневые коммиты как граничные (По умолчанию: отключено)"
+#: sequencer.c:2774
+msgid "You seem to have moved HEAD. Not rewinding, check your HEAD!"
+msgstr "Похоже, что вы переместили HEAD. Перемотка не выполняется, проверьте свой указатель HEAD!"
 
-#: builtin/blame.c:671
-msgid "Show work cost statistics"
-msgstr "Показать статистику расходов на выполнение запроса"
+#: sequencer.c:2903 sequencer.c:3894
+#, c-format
+msgid "could not update %s"
+msgstr "не удалось обновить %s"
 
-#: builtin/blame.c:672
-msgid "Force progress reporting"
-msgstr "Принудительно выводить прогресс выполнения"
+#: sequencer.c:2941 sequencer.c:3874
+msgid "cannot read HEAD"
+msgstr "не удалось прочитать HEAD"
 
-#: builtin/blame.c:673
-msgid "Show output score for blame entries"
-msgstr "Показать оценку для записей авторства"
+#: sequencer.c:2958
+#, c-format
+msgid "unable to copy '%s' to '%s'"
+msgstr ""
 
-#: builtin/blame.c:674
-msgid "Show original filename (Default: auto)"
-msgstr "Показать оригинальное имя файла (По умолчанию: автоматически)"
+#: sequencer.c:2966
+#, c-format
+msgid ""
+"You can amend the commit now, with\n"
+"\n"
+"  git commit --amend %s\n"
+"\n"
+"Once you are satisfied with your changes, run\n"
+"\n"
+"  git rebase --continue\n"
+msgstr ""
 
-#: builtin/blame.c:675
-msgid "Show original linenumber (Default: off)"
-msgstr "Показать оригинальные номера строк (По умолчанию: отключено)"
+#: sequencer.c:2976
+#, c-format
+msgid "Could not apply %s... %.*s"
+msgstr ""
 
-#: builtin/blame.c:676
-msgid "Show in a format designed for machine consumption"
-msgstr "Показать в формате для программного разбора"
+#: sequencer.c:2983
+#, c-format
+msgid "Could not merge %.*s"
+msgstr ""
 
-#: builtin/blame.c:677
-msgid "Show porcelain format with per-line commit information"
-msgstr "Показать в машиночитаемом формате, с построчной информацией о коммите"
+#: sequencer.c:2997 sequencer.c:3001 builtin/difftool.c:633
+#, c-format
+msgid "could not copy '%s' to '%s'"
+msgstr "не удалось скопировать «%s» в «%s»"
 
-#: builtin/blame.c:678
-msgid "Use the same output mode as git-annotate (Default: off)"
-msgstr "Использовать такой же формат вывода, как и git-annotate (По умолчанию: отключено)"
+#: sequencer.c:3023 sequencer.c:3446 builtin/rebase.c:839
+#: builtin/rebase.c:1580 builtin/rebase.c:1940 builtin/rebase.c:1995
+msgid "could not read index"
+msgstr "не удалось прочитать индекс"
 
-#: builtin/blame.c:679
-msgid "Show raw timestamp (Default: off)"
-msgstr "Показать необработанные временные метки (По умолчанию: отключено)"
+#: sequencer.c:3028
+#, c-format
+msgid ""
+"execution failed: %s\n"
+"%sYou can fix the problem, and then run\n"
+"\n"
+"  git rebase --continue\n"
+"\n"
+msgstr "ошибка выполнения: %s\n%sВы можете исправить ошибку, а затем запустить\n\n  git rebase --continue\n\n"
 
-#: builtin/blame.c:680
-msgid "Show long commit SHA1 (Default: off)"
-msgstr "Показать длинный SHA1 идентификатор коммита (По умолчанию: отключено)"
+#: sequencer.c:3034
+msgid "and made changes to the index and/or the working tree\n"
+msgstr "и были сделаны изменения в индексе и/или в рабочем каталоге\n"
 
-#: builtin/blame.c:681
-msgid "Suppress author name and timestamp (Default: off)"
-msgstr "Не показывать имя автора и временные метки (По умолчанию: отключено)"
+#: sequencer.c:3040
+#, c-format
+msgid ""
+"execution succeeded: %s\n"
+"but left changes to the index and/or the working tree\n"
+"Commit or stash your changes, and then run\n"
+"\n"
+"  git rebase --continue\n"
+"\n"
+msgstr "успешное выполнение: %s\nно остались изменения в индексе и/или в рабочем каталоге\nСделайте коммит или спрячьте ваши изменения, а затем выполните\n\n  git rebase --continue\n\n"
 
-#: builtin/blame.c:682
-msgid "Show author email instead of name (Default: off)"
-msgstr "Показать почту автора вместо имени (По умолчанию: отключено)"
+#: sequencer.c:3101
+#, c-format
+msgid "illegal label name: '%.*s'"
+msgstr ""
 
-#: builtin/blame.c:683
-msgid "Ignore whitespace differences"
-msgstr "Игнорировать различия в пробелах"
+#: sequencer.c:3155
+msgid "writing fake root commit"
+msgstr "запись поддельного корневого коммита"
 
-#: builtin/blame.c:690
-msgid "Use an experimental heuristic to improve diffs"
-msgstr "Использовать эксперементальную эвристику, чтобы улучшить файлы различий"
+#: sequencer.c:3160
+msgid "writing squash-onto"
+msgstr "запить уплотнить-над"
 
-#: builtin/blame.c:692
-msgid "Spend extra cycles to find better match"
-msgstr "Потратить больше времени, для нахождения лучших совпадений"
+#: sequencer.c:3198 builtin/rebase.c:844 builtin/rebase.c:850
+#, c-format
+msgid "failed to find tree of %s"
+msgstr "не удалось найти дерево для %s"
 
-#: builtin/blame.c:693
-msgid "Use revisions from <file> instead of calling git-rev-list"
-msgstr "Использовать редакции из <файла> вместо вызова git-rev-list"
+#: sequencer.c:3216 builtin/rebase.c:863
+msgid "could not write index"
+msgstr "не удалось записать индекс"
 
-#: builtin/blame.c:694
-msgid "Use <file>'s contents as the final image"
-msgstr "Использовать содержимое <файла> как финальный снимок"
+#: sequencer.c:3243
+#, c-format
+msgid "could not resolve '%s'"
+msgstr "не удалось распознать «%s»"
 
-#: builtin/blame.c:695 builtin/blame.c:696
-msgid "score"
-msgstr "мин-длина"
+#: sequencer.c:3271
+msgid "cannot merge without a current revision"
+msgstr "нельзя слить без текущей редакции"
 
-#: builtin/blame.c:695
-msgid "Find line copies within and across files"
-msgstr "Найти копирование строк в пределах и между файлами"
+#: sequencer.c:3293
+#, c-format
+msgid "unable to parse '%.*s'"
+msgstr ""
 
-#: builtin/blame.c:696
-msgid "Find line movements within and across files"
-msgstr "Найти перемещения строк в пределах и между файлами"
+#: sequencer.c:3302
+#, c-format
+msgid "nothing to merge: '%.*s'"
+msgstr ""
 
-#: builtin/blame.c:697
-msgid "n,m"
-msgstr "начало,конец"
+#: sequencer.c:3314
+msgid "octopus merge cannot be executed on top of a [new root]"
+msgstr ""
 
-#: builtin/blame.c:697
-msgid "Process only line range n,m, counting from 1"
-msgstr "Обработать только строки в диапазоне начало,конец, начиная с 1"
+#: sequencer.c:3329
+#, c-format
+msgid "could not get commit message of '%s'"
+msgstr "не удалось получить сообщение коммита для «%s»"
 
-#: builtin/blame.c:744
-msgid "--progress can't be used with --incremental or porcelain formats"
-msgstr "--progress нельзя использовать одновременно с --incremental или машиночитаемым (porcelain) форматом"
+#: sequencer.c:3478
+#, c-format
+msgid "could not even attempt to merge '%.*s'"
+msgstr "не удалось даже попытаться слить «%.*s»"
 
-#. TRANSLATORS: This string is used to tell us the
-#. maximum display width for a relative timestamp in
-#. "git blame" output.  For C locale, "4 years, 11
-#. months ago", which takes 22 places, is the longest
-#. among various forms of relative timestamps, but
-#. your language may need more or fewer display
-#. columns.
-#: builtin/blame.c:795
-msgid "4 years, 11 months ago"
-msgstr "4 года и 11 месяцев назад"
+#: sequencer.c:3494
+msgid "merge: Unable to write new index file"
+msgstr "слияние: Не удалось записать файл индекса"
 
-#: builtin/blame.c:882
+#: sequencer.c:3562 builtin/rebase.c:711
 #, c-format
-msgid "file %s has only %lu line"
-msgid_plural "file %s has only %lu lines"
-msgstr[0] "файл %s содержит только %lu строку"
-msgstr[1] "файл %s содержит только %lu строки"
-msgstr[2] "файл %s содержит только %lu строк"
-msgstr[3] "файл %s содержит только %lu строки"
-
-#: builtin/blame.c:928
-msgid "Blaming lines"
-msgstr "Просмотр авторов строк"
+msgid "Applied autostash.\n"
+msgstr "Применены автоматически спрятанные изменения.\n"
 
-#: builtin/branch.c:27
-msgid "git branch [<options>] [-r | -a] [--merged | --no-merged]"
-msgstr "git branch [<опции>] [-r | -a] [--merged | --no-merged]"
+#: sequencer.c:3574
+#, c-format
+msgid "cannot store %s"
+msgstr "не удалось сохранить %s"
 
-#: builtin/branch.c:28
-msgid "git branch [<options>] [-l] [-f] <branch-name> [<start-point>]"
-msgstr "git branch [<опции>] [-l] [-f] <имя-ветки> [<точка-начала>]"
+#: sequencer.c:3577 builtin/rebase.c:727
+#, c-format
+msgid ""
+"Applying autostash resulted in conflicts.\n"
+"Your changes are safe in the stash.\n"
+"You can run \"git stash pop\" or \"git stash drop\" at any time.\n"
+msgstr "Применение автоматически спрятанных изменений вызвало конфликты.\nВаши изменения спрятаны и в безопасности.\nВы можете выполнить «git stash pop» или «git stash drop» в любой момент.\n"
 
-#: builtin/branch.c:29
-msgid "git branch [<options>] [-r] (-d | -D) <branch-name>..."
-msgstr "git branch [<опции>] [-r] (-d | -D) <имя-ветки>…"
+#: sequencer.c:3638
+#, c-format
+msgid "could not checkout %s"
+msgstr ""
 
-#: builtin/branch.c:30
-msgid "git branch [<options>] (-m | -M) [<old-branch>] <new-branch>"
-msgstr "git branch [<опции>] (-m | -M) [<старая-ветка>] <новая-ветка>"
+#: sequencer.c:3652
+#, c-format
+msgid "%s: not a valid OID"
+msgstr ""
 
-#: builtin/branch.c:31
-msgid "git branch [<options>] (-c | -C) [<old-branch>] <new-branch>"
-msgstr "git branch [<опции>] (-c | -C) [<старая-ветка>] <новая-ветка>"
+#: sequencer.c:3657 git-rebase--preserve-merges.sh:724
+msgid "could not detach HEAD"
+msgstr "не удалось отделить HEAD"
 
-#: builtin/branch.c:32
-msgid "git branch [<options>] [-r | -a] [--points-at]"
-msgstr "git branch [<опции>] [-r | -a] [--points-at]"
+#: sequencer.c:3672
+#, c-format
+msgid "Stopped at HEAD\n"
+msgstr ""
 
-#: builtin/branch.c:33
-msgid "git branch [<options>] [-r | -a] [--format]"
-msgstr "git branch [<опции>] [-r | -a] [--format]"
+#: sequencer.c:3674
+#, c-format
+msgid "Stopped at %s\n"
+msgstr ""
 
-#: builtin/branch.c:146
+#: sequencer.c:3682
 #, c-format
 msgid ""
-"deleting branch '%s' that has been merged to\n"
-"         '%s', but not yet merged to HEAD."
-msgstr "удаление ветки «%s», которая была слита с\n         «%s», но не слита с HEAD."
-
-#: builtin/branch.c:150
-#, c-format
-msgid ""
-"not deleting branch '%s' that is not yet merged to\n"
-"         '%s', even though it is merged to HEAD."
-msgstr "не удаление ветки «%s», которая еще не слита с\n         «%s», хотя уже слита с HEAD."
+"Could not execute the todo command\n"
+"\n"
+"    %.*s\n"
+"It has been rescheduled; To edit the command before continuing, please\n"
+"edit the todo list first:\n"
+"\n"
+"    git rebase --edit-todo\n"
+"    git rebase --continue\n"
+msgstr ""
 
-#: builtin/branch.c:164
+#: sequencer.c:3759
 #, c-format
-msgid "Couldn't look up commit object for '%s'"
-msgstr "Не удалось найти объект коммита для «%s»"
+msgid "Stopped at %s...  %.*s\n"
+msgstr "Остановлено на %s …  %.*s\n"
 
-#: builtin/branch.c:168
+#: sequencer.c:3837
 #, c-format
-msgid ""
-"The branch '%s' is not fully merged.\n"
-"If you are sure you want to delete it, run 'git branch -D %s'."
-msgstr "Ветка «%s» не слита полностью.\nЕсли вы уверены, что хотите ее удалить, запустите «git branch -D %s»."
-
-#: builtin/branch.c:181
-msgid "Update of config-file failed"
-msgstr "Не удалось обновить файл конфигурации"
+msgid "unknown command %d"
+msgstr "неизвестная команда %d"
 
-#: builtin/branch.c:212
-msgid "cannot use -a with -d"
-msgstr "нельзя использовать одновременно ключи -a и -d"
+#: sequencer.c:3882
+msgid "could not read orig-head"
+msgstr "не удалось прочитать orig-head"
 
-#: builtin/branch.c:218
-msgid "Couldn't look up commit object for HEAD"
-msgstr "Не удалось найти объект коммита для HEAD"
+#: sequencer.c:3887
+msgid "could not read 'onto'"
+msgstr "не удалось прочитать «onto»"
 
-#: builtin/branch.c:232
+#: sequencer.c:3901
 #, c-format
-msgid "Cannot delete branch '%s' checked out at '%s'"
-msgstr "Нельзя удалить ветку «%s» т.к. она активна на «%s»"
+msgid "could not update HEAD to %s"
+msgstr "не удалось обновить HEAD на %s"
 
-#: builtin/branch.c:247
-#, c-format
-msgid "remote-tracking branch '%s' not found."
-msgstr "внешняя отслеживаемая ветка «%s» не найдена."
+#: sequencer.c:3991
+msgid "cannot rebase: You have unstaged changes."
+msgstr "не удалось выполнить перемещение коммитов: У вас есть непроиндексированные изменения."
 
-#: builtin/branch.c:248
-#, c-format
-msgid "branch '%s' not found."
-msgstr "ветка «%s» не найдена."
+#: sequencer.c:4000
+msgid "cannot amend non-existing commit"
+msgstr "не удалось исправить несуществующий коммит"
 
-#: builtin/branch.c:263
+#: sequencer.c:4002
 #, c-format
-msgid "Error deleting remote-tracking branch '%s'"
-msgstr "Ошибка удаления внешней отслеживаемой ветки «%s»"
+msgid "invalid file: '%s'"
+msgstr "недопустимый файл: «%s»"
 
-#: builtin/branch.c:264
+#: sequencer.c:4004
 #, c-format
-msgid "Error deleting branch '%s'"
-msgstr "Ошибка удаления ветки «%s»"
+msgid "invalid contents: '%s'"
+msgstr "недопустимое содержимое: «%s»"
 
-#: builtin/branch.c:271
-#, c-format
-msgid "Deleted remote-tracking branch %s (was %s).\n"
-msgstr "Внешняя отслеживаемая ветка %s удалена (была %s).\n"
+#: sequencer.c:4007
+msgid ""
+"\n"
+"You have uncommitted changes in your working tree. Please, commit them\n"
+"first and then run 'git rebase --continue' again."
+msgstr "\nУ вас имеются незакоммиченные изменения в рабочем каталоге. Сделайте коммит, а затем запустите «git rebase --continue» снова."
 
-#: builtin/branch.c:272
+#: sequencer.c:4043 sequencer.c:4081
 #, c-format
-msgid "Deleted branch %s (was %s).\n"
-msgstr "Ветка %s удалена (была %s).\n"
+msgid "could not write file: '%s'"
+msgstr ""
 
-#: builtin/branch.c:417 builtin/tag.c:58
-msgid "unable to parse format string"
-msgstr "не удалось разобрать строку формата"
+#: sequencer.c:4096
+msgid "could not remove CHERRY_PICK_HEAD"
+msgstr "не удалось удалить CHERRY_PICK_HEAD"
+
+#: sequencer.c:4103
+msgid "could not commit staged changes."
+msgstr "не удалось закоммитить проиндексированные изменения."
 
-#: builtin/branch.c:450
+#: sequencer.c:4204
 #, c-format
-msgid "Branch %s is being rebased at %s"
-msgstr "Производится перемещение ветки %s на %s"
+msgid "%s: can't cherry-pick a %s"
+msgstr "%s: не удалось скопировать коммит %s"
 
-#: builtin/branch.c:454
+#: sequencer.c:4208
 #, c-format
-msgid "Branch %s is being bisected at %s"
-msgstr "Производится двоичный поиск в ветке %s на %s"
+msgid "%s: bad revision"
+msgstr "%s: плохая редакция"
 
-#: builtin/branch.c:471
-msgid "cannot copy the current branch while not on any."
-msgstr "невозможно скопировать текущую ветку, если вы не находитесь ни на одной из веток."
+#: sequencer.c:4243
+msgid "can't revert as initial commit"
+msgstr "нельзя возвратить изначальный коммит"
 
-#: builtin/branch.c:473
-msgid "cannot rename the current branch while not on any."
-msgstr "невозможно переименовать текущую ветку, если вы не находитесь ни на одной из них."
+#: sequencer.c:4686
+msgid "make_script: unhandled options"
+msgstr "make_script: не обработанные опции"
 
-#: builtin/branch.c:484
-#, c-format
-msgid "Invalid branch name: '%s'"
-msgstr "Недействительное имя ветки: «%s»"
+#: sequencer.c:4689
+msgid "make_script: error preparing revisions"
+msgstr "make_script: ошибка при обновлении редакций"
 
-#: builtin/branch.c:511
-msgid "Branch rename failed"
-msgstr "Сбой переименования ветки"
+#: sequencer.c:4847
+msgid ""
+"You can fix this with 'git rebase --edit-todo' and then run 'git rebase --continue'.\n"
+"Or you can abort the rebase with 'git rebase --abort'.\n"
+msgstr "Вы можете исправить это с помощью «git rebase --edit-todo», а потом запустив «git rebase --continue».\nИли вы можете прервать процесс перемещения, выполнив «git rebase --abort»\n"
 
-#: builtin/branch.c:513
-msgid "Branch copy failed"
-msgstr "Сбой копирования ветки"
+#: sequencer.c:4959 sequencer.c:4976
+msgid "nothing to do"
+msgstr ""
 
-#: builtin/branch.c:517
-#, c-format
-msgid "Created a copy of a misnamed branch '%s'"
-msgstr "Создана копия неправильно названной ветки «%s»"
+#: sequencer.c:4990
+msgid "could not skip unnecessary pick commands"
+msgstr ""
 
-#: builtin/branch.c:520
+#: sequencer.c:5073
+msgid "the script was already rearranged."
+msgstr "сценарий уже был перестроен."
+
+#: setup.c:123
 #, c-format
-msgid "Renamed a misnamed branch '%s' away"
-msgstr "Переименована неправильно названная ветка «%s»"
+msgid "'%s' is outside repository"
+msgstr "«%s» вне репозитория"
 
-#: builtin/branch.c:526
+#: setup.c:173
 #, c-format
-msgid "Branch renamed to %s, but HEAD is not updated!"
-msgstr "Ветка переименована в %s, но HEAD не обновлен!"
+msgid ""
+"%s: no such path in the working tree.\n"
+"Use 'git <command> -- <path>...' to specify paths that do not exist locally."
+msgstr "%s: нет такого пути в рабочем каталоге.\nИспользуйте «git <команда> -- <путь>…» для указания путей, которые не существуют локально."
 
-#: builtin/branch.c:535
-msgid "Branch is renamed, but update of config-file failed"
-msgstr "Ветка переименована, но произошел сбой обновления файла конфигурации"
+#: setup.c:186
+#, c-format
+msgid ""
+"ambiguous argument '%s': unknown revision or path not in the working tree.\n"
+"Use '--' to separate paths from revisions, like this:\n"
+"'git <command> [<revision>...] -- [<file>...]'"
+msgstr "неоднозначный аргумент «%s»: неизвестная редакция или не путь в рабочем каталоге.\nИспользуйте «--» для отделения путей от редакций, вот так:\n«git <команда> [<редакция>…] -- [<файл>…]»"
 
-#: builtin/branch.c:537
-msgid "Branch is copied, but update of config-file failed"
-msgstr "Ветка скопирована, но произошел сбой обновления файла конфигурации"
+#: setup.c:235
+#, c-format
+msgid "option '%s' must come before non-option arguments"
+msgstr ""
 
-#: builtin/branch.c:553
+#: setup.c:254
 #, c-format
 msgid ""
-"Please edit the description for the branch\n"
-"  %s\n"
-"Lines starting with '%c' will be stripped.\n"
-msgstr "Измените описание для ветки:\n  %s\nСтроки, начинающиеся с «%c» будут вырезаны.\n"
+"ambiguous argument '%s': both revision and filename\n"
+"Use '--' to separate paths from revisions, like this:\n"
+"'git <command> [<revision>...] -- [<file>...]'"
+msgstr "неоднозначный аргумент «%s»: является одновременно и редакцией и именем файла.\nИспользуйте «--» для отделения путей от редакций, вот так:\n«git <команда> [<редакция>…] -- [<файл>…]»"
 
-#: builtin/branch.c:586
-msgid "Generic options"
-msgstr "Общие параметры"
+#: setup.c:390
+msgid "unable to set up work tree using invalid config"
+msgstr ""
 
-#: builtin/branch.c:588
-msgid "show hash and subject, give twice for upstream branch"
-msgstr "показывать хэш-сумму и тему, укажите дважды для вышестоящей ветки"
+#: setup.c:394
+msgid "this operation must be run in a work tree"
+msgstr ""
 
-#: builtin/branch.c:589
-msgid "suppress informational messages"
-msgstr "не выводить информационные сообщения"
+#: setup.c:540
+#, c-format
+msgid "Expected git repo version <= %d, found %d"
+msgstr "Ожидаемая версия git репозитория <= %d, а обнаружена %d"
 
-#: builtin/branch.c:590
-msgid "set up tracking mode (see git-pull(1))"
-msgstr "установить режим отслеживания вышестоящей ветки (см. git-pull(1))"
+#: setup.c:548
+msgid "unknown repository extensions found:"
+msgstr "обнаружены неизвестные расширения репозитория:"
 
-#: builtin/branch.c:592
-msgid "do not use"
-msgstr "не используйте"
+#: setup.c:567
+#, c-format
+msgid "error opening '%s'"
+msgstr "ошибка открытия «%s»"
 
-#: builtin/branch.c:594
-msgid "upstream"
-msgstr "вышестоящая"
+#: setup.c:569
+#, c-format
+msgid "too large to be a .git file: '%s'"
+msgstr "файл слишком большой как для .git файла: «%s»"
 
-#: builtin/branch.c:594
-msgid "change the upstream info"
-msgstr "изменить информацию о вышестоящей ветке"
+#: setup.c:571
+#, c-format
+msgid "error reading %s"
+msgstr "ошибка чтения %s"
 
-#: builtin/branch.c:595
-msgid "Unset the upstream info"
-msgstr "Убрать информацию о вышестоящей ветке"
+#: setup.c:573
+#, c-format
+msgid "invalid gitfile format: %s"
+msgstr "неправильный формат файла gitfile: %s"
 
-#: builtin/branch.c:596
-msgid "use colored output"
-msgstr "использовать цветной вывод"
+#: setup.c:575
+#, c-format
+msgid "no path in gitfile: %s"
+msgstr "нет пути в gitfile: %s"
 
-#: builtin/branch.c:597
-msgid "act on remote-tracking branches"
-msgstr "выполнить действия на отслеживаемых внешних ветках"
+#: setup.c:577
+#, c-format
+msgid "not a git repository: %s"
+msgstr "не является репозиторием git: %s"
 
-#: builtin/branch.c:599 builtin/branch.c:601
-msgid "print only branches that contain the commit"
-msgstr "вывод только веток, которые содержат коммит"
+#: setup.c:676
+#, c-format
+msgid "'$%s' too big"
+msgstr "«$%s» слишком большой"
 
-#: builtin/branch.c:600 builtin/branch.c:602
-msgid "print only branches that don't contain the commit"
-msgstr "вывод только веток, которые не содержат коммит"
+#: setup.c:690
+#, c-format
+msgid "not a git repository: '%s'"
+msgstr "не является репозиторием git: «%s»"
 
-#: builtin/branch.c:605
-msgid "Specific git-branch actions:"
-msgstr "Специфичные для git-branch действия:"
+#: setup.c:719 setup.c:721 setup.c:752
+#, c-format
+msgid "cannot chdir to '%s'"
+msgstr "не удалось выполнить chdir в «%s»"
 
-#: builtin/branch.c:606
-msgid "list both remote-tracking and local branches"
-msgstr "показать список и отслеживаемых и локальных веток"
+#: setup.c:724 setup.c:780 setup.c:790 setup.c:829 setup.c:837
+msgid "cannot come back to cwd"
+msgstr "не удалось вернуться в cwd"
 
-#: builtin/branch.c:608
-msgid "delete fully merged branch"
-msgstr "удалить полностью слитую ветку"
+#: setup.c:851
+#, c-format
+msgid "failed to stat '%*s%s%s'"
+msgstr "не удалось выполнить stat для «%*s%s%s»"
 
-#: builtin/branch.c:609
-msgid "delete branch (even if not merged)"
-msgstr "удалить ветку (даже никуда не слитую)"
+#: setup.c:1083
+msgid "Unable to read current working directory"
+msgstr "Не удалось прочитать текущий рабочий каталог"
 
-#: builtin/branch.c:610
-msgid "move/rename a branch and its reflog"
-msgstr "переместить/переименовать ветки и ее журнал ссылок"
+#: setup.c:1092 setup.c:1098
+#, c-format
+msgid "cannot change to '%s'"
+msgstr "не удалось изменить на «%s»"
 
-#: builtin/branch.c:611
-msgid "move/rename a branch, even if target exists"
-msgstr "переместить/переименовать ветку, даже если целевое имя уже существует"
+#: setup.c:1103
+#, c-format
+msgid "not a git repository (or any of the parent directories): %s"
+msgstr "не найден git репозиторий (или один из родительских каталогов): %s"
 
-#: builtin/branch.c:612
-msgid "copy a branch and its reflog"
-msgstr "скопировать ветку и её журнал ссылок"
+#: setup.c:1109
+#, c-format
+msgid ""
+"not a git repository (or any parent up to mount point %s)\n"
+"Stopping at filesystem boundary (GIT_DISCOVERY_ACROSS_FILESYSTEM not set)."
+msgstr "не найден git репозиторий (или один из его каталогов вплоть до точки монтирования %s)\nОстанавливаю поиск на границе файловой системы (так как GIT_DISCOVERY_ACROSS_FILESYSTEM не установлен)."
 
-#: builtin/branch.c:613
-msgid "copy a branch, even if target exists"
-msgstr "скопировать ветку, даже если целевое имя уже существует"
+#: setup.c:1220
+#, c-format
+msgid ""
+"problem with core.sharedRepository filemode value (0%.3o).\n"
+"The owner of files must always have read and write permissions."
+msgstr ""
 
-#: builtin/branch.c:614
-msgid "list branch names"
-msgstr "показать список имен веток"
+#: setup.c:1264
+msgid "open /dev/null or dup failed"
+msgstr "сбой открытия /dev/null или дублирования дескриптора"
 
-#: builtin/branch.c:615
-msgid "create the branch's reflog"
-msgstr "создать журнал ссылок ветки"
+#: setup.c:1279
+msgid "fork failed"
+msgstr "сбой при выполнении fork"
 
-#: builtin/branch.c:617
-msgid "edit the description for the branch"
-msgstr "изменить описание ветки"
+#: setup.c:1284
+msgid "setsid failed"
+msgstr "сбой при выполнении setsid"
 
-#: builtin/branch.c:618
-msgid "force creation, move/rename, deletion"
-msgstr "принудительное создание, перемещение или удаление ветки"
+#: sha1-file.c:453
+#, c-format
+msgid "object directory %s does not exist; check .git/objects/info/alternates"
+msgstr ""
 
-#: builtin/branch.c:619
-msgid "print only branches that are merged"
-msgstr "вывод только слитых веток"
+#: sha1-file.c:504
+#, c-format
+msgid "unable to normalize alternate object path: %s"
+msgstr ""
 
-#: builtin/branch.c:620
-msgid "print only branches that are not merged"
-msgstr "вывод только не слитых веток"
+#: sha1-file.c:576
+#, c-format
+msgid "%s: ignoring alternate object stores, nesting too deep"
+msgstr ""
 
-#: builtin/branch.c:621
-msgid "list branches in columns"
-msgstr "показать список веток по столбцам"
+#: sha1-file.c:583
+#, c-format
+msgid "unable to normalize object directory: %s"
+msgstr ""
 
-#: builtin/branch.c:622 builtin/for-each-ref.c:40 builtin/tag.c:405
-msgid "key"
-msgstr "ключ"
+#: sha1-file.c:626
+msgid "unable to fdopen alternates lockfile"
+msgstr ""
 
-#: builtin/branch.c:623 builtin/for-each-ref.c:41 builtin/tag.c:406
-msgid "field name to sort on"
-msgstr "имя поля, по которому выполнить сортировку"
+#: sha1-file.c:644
+msgid "unable to read alternates file"
+msgstr ""
 
-#: builtin/branch.c:625 builtin/for-each-ref.c:43 builtin/notes.c:408
-#: builtin/notes.c:411 builtin/notes.c:571 builtin/notes.c:574
-#: builtin/tag.c:408
-msgid "object"
-msgstr "объект"
+#: sha1-file.c:651
+msgid "unable to move new alternates file into place"
+msgstr ""
 
-#: builtin/branch.c:626
-msgid "print only branches of the object"
-msgstr "вывод только веток, определенного объекта"
+#: sha1-file.c:686
+#, c-format
+msgid "path '%s' does not exist"
+msgstr "путь «%s» не существует"
 
-#: builtin/branch.c:628 builtin/for-each-ref.c:49 builtin/tag.c:415
-msgid "sorting and filtering are case insensitive"
-msgstr "сортировка и фильтрация не зависят от регистра"
+#: sha1-file.c:712
+#, c-format
+msgid "reference repository '%s' as a linked checkout is not supported yet."
+msgstr "ссылаемый репозиторий «%s» как связанное состояние, пока не поддерживается."
 
-#: builtin/branch.c:629 builtin/for-each-ref.c:38 builtin/tag.c:413
-#: builtin/verify-tag.c:39
-msgid "format to use for the output"
-msgstr "использовать формат для вывода"
-
-#: builtin/branch.c:652 builtin/clone.c:730
-msgid "HEAD not found below refs/heads!"
-msgstr "HEAD не найден в refs/heads!"
+#: sha1-file.c:718
+#, c-format
+msgid "reference repository '%s' is not a local repository."
+msgstr "ссылаемый репозиторий «%s» не является локальным."
 
-#: builtin/branch.c:675
-msgid "--column and --verbose are incompatible"
-msgstr "--column и --verbose нельзя использовать одновременно"
+#: sha1-file.c:724
+#, c-format
+msgid "reference repository '%s' is shallow"
+msgstr "ссылаемый репозиторий «%s» является частичным"
 
-#: builtin/branch.c:690 builtin/branch.c:742 builtin/branch.c:751
-msgid "branch name required"
-msgstr "требуется имя ветки"
+#: sha1-file.c:732
+#, c-format
+msgid "reference repository '%s' is grafted"
+msgstr "ссылаемый репозиторий «%s» является сращенным"
 
-#: builtin/branch.c:718
-msgid "Cannot give description to detached HEAD"
-msgstr "Нельзя дать описание отделённому HEAD"
+#: sha1-file.c:846
+#, c-format
+msgid "attempting to mmap %<PRIuMAX> over limit %<PRIuMAX>"
+msgstr ""
 
-#: builtin/branch.c:723
-msgid "cannot edit description of more than one branch"
-msgstr "нельзя изменить описание более одной ветки за раз"
+#: sha1-file.c:871
+msgid "mmap failed"
+msgstr ""
 
-#: builtin/branch.c:730
+#: sha1-file.c:1035
 #, c-format
-msgid "No commit on branch '%s' yet."
-msgstr "Еще нет коммита на ветке «%s»."
+msgid "object file %s is empty"
+msgstr ""
 
-#: builtin/branch.c:733
+#: sha1-file.c:1159 sha1-file.c:2297
 #, c-format
-msgid "No branch named '%s'."
-msgstr "Нет ветки с именем «%s»."
+msgid "corrupt loose object '%s'"
+msgstr ""
 
-#: builtin/branch.c:748
-msgid "too many branches for a copy operation"
-msgstr "слишком много веток для операции копирования"
+#: sha1-file.c:1161 sha1-file.c:2301
+#, c-format
+msgid "garbage at end of loose object '%s'"
+msgstr ""
 
-#: builtin/branch.c:757
-msgid "too many arguments for a rename operation"
-msgstr "слишком много аргументов для операции переименования"
+#: sha1-file.c:1203
+msgid "invalid object type"
+msgstr ""
 
-#: builtin/branch.c:762
-msgid "too many arguments to set new upstream"
-msgstr "слишком много аргументов для указания новой вышестоящей ветки"
+#: sha1-file.c:1287
+#, c-format
+msgid "unable to unpack %s header with --allow-unknown-type"
+msgstr ""
 
-#: builtin/branch.c:766
+#: sha1-file.c:1290
 #, c-format
-msgid ""
-"could not set upstream of HEAD to %s when it does not point to any branch."
-msgstr "невозможно установить вышестоящий репозиторий для HEAD на %s, так как он не указывает ни на одну ветку."
+msgid "unable to unpack %s header"
+msgstr ""
 
-#: builtin/branch.c:769 builtin/branch.c:791 builtin/branch.c:807
+#: sha1-file.c:1296
 #, c-format
-msgid "no such branch '%s'"
-msgstr "нет такой ветки «%s»"
+msgid "unable to parse %s header with --allow-unknown-type"
+msgstr ""
 
-#: builtin/branch.c:773
+#: sha1-file.c:1299
 #, c-format
-msgid "branch '%s' does not exist"
-msgstr "ветка «%s» не существует"
+msgid "unable to parse %s header"
+msgstr ""
 
-#: builtin/branch.c:785
-msgid "too many arguments to unset upstream"
-msgstr "слишком много аргументов для сброса указания вышестоящей ветки"
+#: sha1-file.c:1490
+#, c-format
+msgid "failed to read object %s"
+msgstr ""
 
-#: builtin/branch.c:789
-msgid "could not unset upstream of HEAD when it does not point to any branch."
-msgstr "невозможно убрать вышестоящий репозиторий для HEAD, так как он не указывает ни на одну ветку."
+#: sha1-file.c:1494
+#, c-format
+msgid "replacement %s not found for %s"
+msgstr ""
 
-#: builtin/branch.c:795
+#: sha1-file.c:1498
 #, c-format
-msgid "Branch '%s' has no upstream information"
-msgstr "Ветка «%s» не имеет информации о вышестоящей ветке"
+msgid "loose object %s (stored in %s) is corrupt"
+msgstr ""
 
-#: builtin/branch.c:810
-msgid "-a and -r options to 'git branch' do not make sense with a branch name"
-msgstr "параметры -a и -r для «git branch» не имеют смысла с указанием имени ветки"
+#: sha1-file.c:1502
+#, c-format
+msgid "packed object %s (stored in %s) is corrupt"
+msgstr ""
 
-#: builtin/branch.c:813
-msgid ""
-"the '--set-upstream' option is no longer supported. Please use '--track' or "
-"'--set-upstream-to' instead."
-msgstr "опция --set-upstream больше не поддерживается. Вместо неё используйте «--track» или «--set-upstream-to»"
+#: sha1-file.c:1604
+#, c-format
+msgid "unable to write file %s"
+msgstr ""
 
-#: builtin/bundle.c:45
+#: sha1-file.c:1611
 #, c-format
-msgid "%s is okay\n"
-msgstr "%s в порядке\n"
+msgid "unable to set permission to '%s'"
+msgstr ""
 
-#: builtin/bundle.c:58
-msgid "Need a repository to create a bundle."
-msgstr "Требуется репозиторий для создания пакета."
+#: sha1-file.c:1618
+msgid "file write error"
+msgstr ""
 
-#: builtin/bundle.c:62
-msgid "Need a repository to unbundle."
-msgstr "Требуется репозиторий для распаковки."
+#: sha1-file.c:1637
+msgid "error when closing loose object file"
+msgstr ""
 
-#: builtin/cat-file.c:521
-msgid ""
-"git cat-file (-t [--allow-unknown-type] | -s [--allow-unknown-type] | -e | "
-"-p | <type> | --textconv | --filters) [--path=<path>] <object>"
-msgstr "git cat-file (-t [--allow-unknown-type] | -s [--allow-unknown-type] | -e | -p | <тип> | --textconv | --filters) [--path=<путь>] <объект>"
+#: sha1-file.c:1702
+#, c-format
+msgid "insufficient permission for adding an object to repository database %s"
+msgstr ""
 
-#: builtin/cat-file.c:522
-msgid ""
-"git cat-file (--batch | --batch-check) [--follow-symlinks] [--textconv | "
-"--filters]"
-msgstr "git cat-file (--batch | --batch-check) [--follow-symlinks] [--textconv | --filters]"
+#: sha1-file.c:1704
+msgid "unable to create temporary file"
+msgstr ""
 
-#: builtin/cat-file.c:559
-msgid "<type> can be one of: blob, tree, commit, tag"
-msgstr "<тип> может быть одним из: blob, tree, commit, tag"
+#: sha1-file.c:1728
+msgid "unable to write loose object file"
+msgstr ""
 
-#: builtin/cat-file.c:560
-msgid "show object type"
-msgstr "показать тип объекта"
+#: sha1-file.c:1734
+#, c-format
+msgid "unable to deflate new object %s (%d)"
+msgstr ""
 
-#: builtin/cat-file.c:561
-msgid "show object size"
-msgstr "показать размер объекта"
+#: sha1-file.c:1738
+#, c-format
+msgid "deflateEnd on object %s failed (%d)"
+msgstr ""
 
-#: builtin/cat-file.c:563
-msgid "exit with zero when there's no error"
-msgstr "выйти с нулевым кодом возврата, если нет ошибки"
+#: sha1-file.c:1742
+#, c-format
+msgid "confused by unstable object source data for %s"
+msgstr ""
 
-#: builtin/cat-file.c:564
-msgid "pretty-print object's content"
-msgstr "структурированный вывод содержимого объекта"
+#: sha1-file.c:1752 builtin/pack-objects.c:920
+#, c-format
+msgid "failed utime() on %s"
+msgstr ""
 
-#: builtin/cat-file.c:566
-msgid "for blob objects, run textconv on object's content"
-msgstr "запустить texconv на содержимом двоичных объектов "
+#: sha1-file.c:1827
+#, c-format
+msgid "cannot read object for %s"
+msgstr ""
 
-#: builtin/cat-file.c:568
-msgid "for blob objects, run filters on object's content"
-msgstr "запуск фильтров на содержимом двоичных объектов "
+#: sha1-file.c:1867
+msgid "corrupt commit"
+msgstr ""
 
-#: builtin/cat-file.c:569 git-submodule.sh:931
-msgid "blob"
-msgstr "двоичный объект"
+#: sha1-file.c:1875
+msgid "corrupt tag"
+msgstr ""
 
-#: builtin/cat-file.c:570
-msgid "use a specific path for --textconv/--filters"
-msgstr "использовать определенный путь для --textconv/--filters"
+#: sha1-file.c:1974
+#, c-format
+msgid "read error while indexing %s"
+msgstr ""
 
-#: builtin/cat-file.c:572
-msgid "allow -s and -t to work with broken/corrupt objects"
-msgstr "разрешить -s и -t работать с повреждёнными объектами"
+#: sha1-file.c:1977
+#, c-format
+msgid "short read while indexing %s"
+msgstr ""
 
-#: builtin/cat-file.c:573
-msgid "buffer --batch output"
-msgstr "буфферировать вывод --batch"
+#: sha1-file.c:2050 sha1-file.c:2059
+#, c-format
+msgid "%s: failed to insert into database"
+msgstr ""
 
-#: builtin/cat-file.c:575
-msgid "show info and content of objects fed from the standard input"
-msgstr "показать информацию и содержимое объектов, переданных из стандартного ввода"
+#: sha1-file.c:2065
+#, c-format
+msgid "%s: unsupported file type"
+msgstr ""
 
-#: builtin/cat-file.c:578
-msgid "show info about objects fed from the standard input"
-msgstr "показать информацию об объектах, переданных из стандартного ввода"
+#: sha1-file.c:2089
+#, c-format
+msgid "%s is not a valid object"
+msgstr ""
 
-#: builtin/cat-file.c:581
-msgid "follow in-tree symlinks (used with --batch or --batch-check)"
-msgstr "переходить по символьным ссылкам внутри дерева (используется с опциями --batch и --batch-check)"
+#: sha1-file.c:2091
+#, c-format
+msgid "%s is not a valid '%s' object"
+msgstr "%s не является действительным объектом «%s»"
 
-#: builtin/cat-file.c:583
-msgid "show all objects with --batch or --batch-check"
-msgstr "показать все объекты с опциями --batch или --batch-check"
+#: sha1-file.c:2118 builtin/index-pack.c:154
+#, c-format
+msgid "unable to open %s"
+msgstr "не удалось открыть %s"
 
-#: builtin/check-attr.c:12
-msgid "git check-attr [-a | --all | <attr>...] [--] <pathname>..."
-msgstr "git check-attr [-a | --all | <атрибут>…] [--] <путь>…"
+#: sha1-file.c:2308 sha1-file.c:2360
+#, c-format
+msgid "hash mismatch for %s (expected %s)"
+msgstr "несоответствие хеш-суммы %s (ожидается %s)"
 
-#: builtin/check-attr.c:13
-msgid "git check-attr --stdin [-z] [-a | --all | <attr>...]"
-msgstr "git check-attr --stdin [-z] [-a | --all | <атрибут>…]"
+#: sha1-file.c:2332
+#, c-format
+msgid "unable to mmap %s"
+msgstr ""
 
-#: builtin/check-attr.c:20
-msgid "report all attributes set on file"
-msgstr "вывести все атрибуты установленные для файла"
+#: sha1-file.c:2337
+#, c-format
+msgid "unable to unpack header of %s"
+msgstr ""
 
-#: builtin/check-attr.c:21
-msgid "use .gitattributes only from the index"
-msgstr "использовать только .gitattributes из индекса"
+#: sha1-file.c:2343
+#, c-format
+msgid "unable to parse header of %s"
+msgstr ""
 
-#: builtin/check-attr.c:22 builtin/check-ignore.c:24 builtin/hash-object.c:99
-msgid "read file names from stdin"
-msgstr "прочитать имена файлов из стандартного ввода"
+#: sha1-file.c:2354
+#, c-format
+msgid "unable to unpack contents of %s"
+msgstr ""
 
-#: builtin/check-attr.c:24 builtin/check-ignore.c:26
-msgid "terminate input and output records by a NUL character"
-msgstr "окончание ввода и вывода записей по НУЛЕВОМУ символу"
+#: sha1-name.c:490
+#, c-format
+msgid "short SHA1 %s is ambiguous"
+msgstr "сокращённый SHA1 идентификатор %s неоднозначен"
 
-#: builtin/check-ignore.c:20 builtin/checkout.c:1118 builtin/gc.c:358
-msgid "suppress progress reporting"
-msgstr "не выводить прогресс выполнения"
+#: sha1-name.c:501
+msgid "The candidates are:"
+msgstr "Возможно, вы имели в виду:"
 
-#: builtin/check-ignore.c:28
-msgid "show non-matching input paths"
-msgstr "показать не совпадающие введенные пути"
+#: sha1-name.c:800
+msgid ""
+"Git normally never creates a ref that ends with 40 hex characters\n"
+"because it will be ignored when you just specify 40-hex. These refs\n"
+"may be created by mistake. For example,\n"
+"\n"
+"  git checkout -b $br $(git rev-parse ...)\n"
+"\n"
+"where \"$br\" is somehow empty and a 40-hex ref is created. Please\n"
+"examine these refs and maybe delete them. Turn this message off by\n"
+"running \"git config advice.objectNameWarning false\""
+msgstr "Обычно Git не создает ссылки, оканчивающиеся на 40 шестнадцатеричных\nсимволов, потому, что они будут игнорироваться, когда вы просто\nукажете это 40-символьное шестнадцатеричное число. Такие ссылки\nмогли быть созданы по ошибке. Например, с помощью:\n\n  git checkout -b $br $(git rev-parse …)\n\n, если «$br» оказался пустым, то ссылка с 40-символьным\nшестнадцатеричным числом будет создана. Пожалуйста, просмотрите эти\nссылки и, возможно, удалите их. Вы можете отключить это сообщение\nзапустив «git config advice.objectNameWarning false»"
 
-#: builtin/check-ignore.c:30
-msgid "ignore index when checking"
-msgstr "игнорировать индекс при проверке"
+#: submodule.c:114 submodule.c:143
+msgid "Cannot change unmerged .gitmodules, resolve merge conflicts first"
+msgstr "Не удалось изменить не слитый .gitmodules, сначала разрешите конфликты"
 
-#: builtin/check-ignore.c:158
-msgid "cannot specify pathnames with --stdin"
-msgstr "нельзя указывать пути вместе с параметром --stdin"
+#: submodule.c:118 submodule.c:147
+#, c-format
+msgid "Could not find section in .gitmodules where path=%s"
+msgstr "Не удалось найти раздел в .gitmodules, где путь равен %s"
 
-#: builtin/check-ignore.c:161
-msgid "-z only makes sense with --stdin"
-msgstr "-z имеет смысл только вместе с параметром --stdin"
+#: submodule.c:154
+#, c-format
+msgid "Could not remove .gitmodules entry for %s"
+msgstr "Не удалось удалить запись в .gitmodules для %s"
 
-#: builtin/check-ignore.c:163
-msgid "no path specified"
-msgstr "не указан путь"
+#: submodule.c:165
+msgid "staging updated .gitmodules failed"
+msgstr "сбой индексирования обновленного .gitmodules"
 
-#: builtin/check-ignore.c:167
-msgid "--quiet is only valid with a single pathname"
-msgstr "--quiet можно использовать только при указании одного пути"
+#: submodule.c:327
+#, c-format
+msgid "in unpopulated submodule '%s'"
+msgstr "в пустом подмодуле «%s»"
 
-#: builtin/check-ignore.c:169
-msgid "cannot have both --quiet and --verbose"
-msgstr "нельзя использовать одновременно --quiet и --verbose"
+#: submodule.c:358
+#, c-format
+msgid "Pathspec '%s' is in submodule '%.*s'"
+msgstr "Спецификатор пути «%s» в подмодуле «%.*s»"
 
-#: builtin/check-ignore.c:172
-msgid "--non-matching is only valid with --verbose"
-msgstr "--non-matching можно использовать только вместе с --verbose"
+#: submodule.c:910
+#, c-format
+msgid "submodule entry '%s' (%s) is a %s, not a commit"
+msgstr "запись подмодуля «%s» (%s) является %s, а не является коммитом"
 
-#: builtin/check-mailmap.c:9
-msgid "git check-mailmap [<options>] <contact>..."
-msgstr "git check-mailmap [<опции>] <контакт>…"
+#: submodule.c:1147 builtin/branch.c:672 builtin/submodule--helper.c:1988
+msgid "Failed to resolve HEAD as a valid ref."
+msgstr "Не удалось определить HEAD как действительную ссылку."
 
-#: builtin/check-mailmap.c:14
-msgid "also read contacts from stdin"
-msgstr "также читать контакты из стандартного ввода"
+#: submodule.c:1481
+#, c-format
+msgid "Could not access submodule '%s'"
+msgstr ""
 
-#: builtin/check-mailmap.c:25
+#: submodule.c:1651
 #, c-format
-msgid "unable to parse contact: %s"
-msgstr "не удалось разобрать контакт: %s"
+msgid "'%s' not recognized as a git repository"
+msgstr "«%s» не распознан как репозиторий git"
 
-#: builtin/check-mailmap.c:48
-msgid "no contacts specified"
-msgstr "не указаны контакты"
+#: submodule.c:1789
+#, c-format
+msgid "could not start 'git status' in submodule '%s'"
+msgstr "не удалось запустить «git status» в подмодуле «%s»"
 
-#: builtin/checkout-index.c:128
-msgid "git checkout-index [<options>] [--] [<file>...]"
-msgstr "git checkout-index [<опции>] [--] [<файл>…]"
-
-#: builtin/checkout-index.c:143
-msgid "stage should be between 1 and 3 or all"
-msgstr "индекс должен быть между 1 и 3 или all"
-
-#: builtin/checkout-index.c:159
-msgid "check out all files in the index"
-msgstr "переключиться на состояние всех файлов из индекса"
+#: submodule.c:1802
+#, c-format
+msgid "could not run 'git status' in submodule '%s'"
+msgstr "не удалось запустить «git status» в подмодуле «%s»"
 
-#: builtin/checkout-index.c:160
-msgid "force overwrite of existing files"
-msgstr "принудительная перезапись существующих файлов"
+#: submodule.c:1817
+#, c-format
+msgid "Could not unset core.worktree setting in submodule '%s'"
+msgstr ""
 
-#: builtin/checkout-index.c:162
-msgid "no warning for existing files and files not in index"
-msgstr "не выводить предупреждения для существующих и непроиндексированных файлов"
+#: submodule.c:1907
+#, c-format
+msgid "submodule '%s' has dirty index"
+msgstr "подмодуль «%s» имеет изменённый индекс"
 
-#: builtin/checkout-index.c:164
-msgid "don't checkout new files"
-msgstr "не создавать новые файлы"
+#: submodule.c:1959
+#, c-format
+msgid "Submodule '%s' could not be updated."
+msgstr ""
 
-#: builtin/checkout-index.c:166
-msgid "update stat information in the index file"
-msgstr "обновить статистику доступа в файле индекса"
+#: submodule.c:2008
+#, c-format
+msgid ""
+"relocate_gitdir for submodule '%s' with more than one worktree not supported"
+msgstr "relocate_gitdir для подмодуля «%s» с указанием более одного рабочего дерева не поддерживается"
 
-#: builtin/checkout-index.c:170
-msgid "read list of paths from the standard input"
-msgstr "прочитать список путей из стандартного ввода"
+#: submodule.c:2020 submodule.c:2076
+#, c-format
+msgid "could not lookup name for submodule '%s'"
+msgstr "не удалось запросить имя подмодуля «%s»"
 
-#: builtin/checkout-index.c:172
-msgid "write the content to temporary files"
-msgstr "записать содержимое во временные файлы"
+#: submodule.c:2027
+#, c-format
+msgid ""
+"Migrating git directory of '%s%s' from\n"
+"'%s' to\n"
+"'%s'\n"
+msgstr "Перемещение каталога git для «%s%s» из\n«%s» в\n«%s»\n"
 
-#: builtin/checkout-index.c:173 builtin/column.c:31
-#: builtin/submodule--helper.c:866 builtin/submodule--helper.c:869
-#: builtin/submodule--helper.c:875 builtin/submodule--helper.c:1237
-#: builtin/worktree.c:552
-msgid "string"
-msgstr "строка"
+#: submodule.c:2111
+#, c-format
+msgid "could not recurse into submodule '%s'"
+msgstr "не удалось рекурсивно зайти в подмодуль «%s»"
 
-#: builtin/checkout-index.c:174
-msgid "when creating files, prepend <string>"
-msgstr "добавить спереди <строку> при создании файлов"
+#: submodule.c:2155
+msgid "could not start ls-files in .."
+msgstr "не удалось выполнить stat ls-files в .."
 
-#: builtin/checkout-index.c:176
-msgid "copy out the files from named stage"
-msgstr "копировать файлы из указанного индекса"
+#: submodule.c:2194
+#, c-format
+msgid "ls-tree returned unexpected return code %d"
+msgstr "ls-tree вернул неожиданный код %d"
 
-#: builtin/checkout.c:27
-msgid "git checkout [<options>] <branch>"
-msgstr "git checkout [<опции>] <ветка>"
+#: submodule-config.c:232
+#, c-format
+msgid "ignoring suspicious submodule name: %s"
+msgstr "игнорирую подозрительный подмодуль с именем: %s"
 
-#: builtin/checkout.c:28
-msgid "git checkout [<options>] [<branch>] -- <file>..."
-msgstr "git checkout [<опции>] [<ветка>] -- <файл>…"
+#: submodule-config.c:299
+msgid "negative values not allowed for submodule.fetchjobs"
+msgstr "нельзя использовать отрицательные значения для submodule.fetchjobs"
 
-#: builtin/checkout.c:136 builtin/checkout.c:169
+#: submodule-config.c:397
 #, c-format
-msgid "path '%s' does not have our version"
-msgstr "путь «%s» не имеет нашей версии"
+msgid "ignoring '%s' which may be interpreted as a command-line option: %s"
+msgstr ""
 
-#: builtin/checkout.c:138 builtin/checkout.c:171
+#: submodule-config.c:486
 #, c-format
-msgid "path '%s' does not have their version"
-msgstr "путь «%s» не имеет их версии"
+msgid "invalid value for %s"
+msgstr "неправильное значение %s"
 
-#: builtin/checkout.c:154
+#: submodule-config.c:755
 #, c-format
-msgid "path '%s' does not have all necessary versions"
-msgstr "путь «%s» не имеет всех необходимых версий"
+msgid "Could not update .gitmodules entry %s"
+msgstr " Не удалось обновить .gitmodules запись %s"
 
-#: builtin/checkout.c:198
+#: trailer.c:238
 #, c-format
-msgid "path '%s' does not have necessary versions"
-msgstr "путь «%s» не имеет необходимых версий"
+msgid "running trailer command '%s' failed"
+msgstr "сбой при запуске команды завершителя «%s»"
 
-#: builtin/checkout.c:215
+#: trailer.c:485 trailer.c:490 trailer.c:495 trailer.c:549 trailer.c:553
+#: trailer.c:557
 #, c-format
-msgid "path '%s': cannot merge"
-msgstr "путь «%s»: не удалось слить"
+msgid "unknown value '%s' for key '%s'"
+msgstr "неизвестное значение «%s» для ключа «%s»"
 
-#: builtin/checkout.c:232
+#: trailer.c:539 trailer.c:544 builtin/remote.c:295
 #, c-format
-msgid "Unable to add merge result for '%s'"
-msgstr "Не удалось добавить результат слияния «%s»"
+msgid "more than one %s"
+msgstr "больше одного %s"
 
-#: builtin/checkout.c:254 builtin/checkout.c:257 builtin/checkout.c:260
-#: builtin/checkout.c:263
+#: trailer.c:730
 #, c-format
-msgid "'%s' cannot be used with updating paths"
-msgstr "«%s» нельзя использовать при обновлении путей"
+msgid "empty trailer token in trailer '%.*s'"
+msgstr "пустая последняя лексема в завершителе «%.*s»"
 
-#: builtin/checkout.c:266 builtin/checkout.c:269
+#: trailer.c:750
 #, c-format
-msgid "'%s' cannot be used with %s"
-msgstr "«%s» нельзя использовать одновременно с %s"
+msgid "could not read input file '%s'"
+msgstr "не удалось прочитать входной файл «%s»"
 
-#: builtin/checkout.c:272
-#, c-format
-msgid "Cannot update paths and switch to branch '%s' at the same time."
-msgstr "Нельзя обновлять пути и переключаться на ветку «%s» одновременно."
+#: trailer.c:753
+msgid "could not read from stdin"
+msgstr "не удалось прочитать из стандартного ввода"
 
-#: builtin/checkout.c:341 builtin/checkout.c:348
+#: trailer.c:1011 wrapper.c:701
 #, c-format
-msgid "path '%s' is unmerged"
-msgstr "путь «%s» не слит"
-
-#: builtin/checkout.c:506
-msgid "you need to resolve your current index first"
-msgstr "сначала нужно разрешить конфликты в вашем текущем индексе"
+msgid "could not stat %s"
+msgstr "не удалось выполнить stat для %s"
 
-#: builtin/checkout.c:637
+#: trailer.c:1013
 #, c-format
-msgid "Can not do reflog for '%s': %s\n"
-msgstr "Не удалось создать журнал ссылок для «%s»: %s\n"
+msgid "file %s is not a regular file"
+msgstr "файл %s не является обычным файлом"
 
-#: builtin/checkout.c:678
-msgid "HEAD is now at"
-msgstr "HEAD сейчас на"
+#: trailer.c:1015
+#, c-format
+msgid "file %s is not writable by user"
+msgstr "файл %s не доступен на запись пользователю"
 
-#: builtin/checkout.c:682 builtin/clone.c:684
-msgid "unable to update HEAD"
-msgstr "не удалось обновить HEAD"
+#: trailer.c:1027
+msgid "could not open temporary file"
+msgstr "не удалось создать временный файл"
 
-#: builtin/checkout.c:686
+#: trailer.c:1067
 #, c-format
-msgid "Reset branch '%s'\n"
-msgstr "Сброс ветки «%s»\n"
+msgid "could not rename temporary file to %s"
+msgstr "не удалось переименовать временный файл в %s"
 
-#: builtin/checkout.c:689
+#: transport.c:116
 #, c-format
-msgid "Already on '%s'\n"
-msgstr "Уже на «%s»\n"
+msgid "Would set upstream of '%s' to '%s' of '%s'\n"
+msgstr "Будет установлен вышестоящий репозиторий для «%s» на «%s» с «%s»\n"
 
-#: builtin/checkout.c:693
+#: transport.c:142
 #, c-format
-msgid "Switched to and reset branch '%s'\n"
-msgstr "Переключение и сброс ветки «%s»\n"
+msgid "could not read bundle '%s'"
+msgstr ""
 
-#: builtin/checkout.c:695 builtin/checkout.c:1051
+#: transport.c:208
 #, c-format
-msgid "Switched to a new branch '%s'\n"
-msgstr "Переключено на новую ветку «%s»\n"
+msgid "transport: invalid depth option '%s'"
+msgstr "транспорт: неправильный параметр глубины «%s»"
+
+#: transport.c:259
+msgid "see protocol.version in 'git help config' for more details"
+msgstr ""
 
-#: builtin/checkout.c:697
+#: transport.c:260
+msgid "server options require protocol version 2 or later"
+msgstr ""
+
+#: transport.c:625
+msgid "could not parse transport.color.* config"
+msgstr "не удалось разобрать опцию transport.color.*"
+
+#: transport.c:698
+msgid "support for protocol v2 not implemented yet"
+msgstr ""
+
+#: transport.c:825
 #, c-format
-msgid "Switched to branch '%s'\n"
-msgstr "Переключено на ветку «%s»\n"
+msgid "unknown value for config '%s': %s"
+msgstr ""
 
-#: builtin/checkout.c:748
+#: transport.c:891
 #, c-format
-msgid " ... and %d more.\n"
-msgstr " … и еще %d.\n"
+msgid "transport '%s' not allowed"
+msgstr ""
+
+#: transport.c:945
+msgid "git-over-rsync is no longer supported"
+msgstr ""
 
-#: builtin/checkout.c:754
+#: transport.c:1040
 #, c-format
 msgid ""
-"Warning: you are leaving %d commit behind, not connected to\n"
-"any of your branches:\n"
-"\n"
-"%s\n"
-msgid_plural ""
-"Warning: you are leaving %d commits behind, not connected to\n"
-"any of your branches:\n"
-"\n"
-"%s\n"
-msgstr[0] "Предупреждение: вы оставляете позади %d коммит не соединенную ни с одной из ваших веток:\n\n%s\n"
-msgstr[1] "Предупреждение: вы оставляете позади %d коммита не соединенные ни с одной из ваших веток:\n\n%s\n"
-msgstr[2] "Предупреждение: вы оставляете позади %d коммитов не соединенные ни с одной из ваших веток:\n\n%s\n"
-msgstr[3] "Предупреждение: вы оставляете позади %d коммитов не соединенные ни с одной из ваших веток:\n\n%s\n"
+"The following submodule paths contain changes that can\n"
+"not be found on any remote:\n"
+msgstr "Подмодули по указанным путям содержат изменения, которые не найдены ни на одном из внешних репозиториев:\n"
 
-#: builtin/checkout.c:773
+#: transport.c:1044
 #, c-format
 msgid ""
-"If you want to keep it by creating a new branch, this may be a good time\n"
-"to do so with:\n"
 "\n"
-" git branch <new-branch-name> %s\n"
+"Please try\n"
 "\n"
-msgid_plural ""
-"If you want to keep them by creating a new branch, this may be a good time\n"
-"to do so with:\n"
+"\tgit push --recurse-submodules=on-demand\n"
 "\n"
-" git branch <new-branch-name> %s\n"
+"or cd to the path and use\n"
 "\n"
-msgstr[0] "Если вы хотите сохранить их с помощью создания новой ветки, то сейчас самое время\nсделать это с помощью:\n\n git branch <имя-новой-ветки> %s\n"
-msgstr[1] "Если вы хотите сохранить их с помощью создания новой ветки, то сейчас самое время\nсделать это с помощью:\n\n git branch <имя-новой-ветки> %s\n"
-msgstr[2] "Если вы хотите сохранить их с помощью создания новой ветки, то сейчас самое время\nсделать это с помощью:\n\n git branch <имя-новой-ветки> %s\n"
-msgstr[3] "Если вы хотите сохранить их с помощью создания новой ветки, то сейчас самое время\nсделать это с помощью:\n\n git branch <имя-новой-ветки> %s\n"
+"\tgit push\n"
+"\n"
+"to push them to a remote.\n"
+"\n"
+msgstr "\nПопробуйте выполнить\n\n\tgit push --recurse-submodules=on-demand\n\nили перейти в каталог с помощью команды cd и выполнить\n\n\tgit push\n\nдля их отправки на внешний репозиторий.\n"
 
-#: builtin/checkout.c:814
-msgid "internal error in revision walk"
-msgstr "внутренняя ошибка при хождении по редакциям"
+#: transport.c:1052
+msgid "Aborting."
+msgstr "Прерываю."
 
-#: builtin/checkout.c:818
-msgid "Previous HEAD position was"
-msgstr "Предыдущая позиция HEAD была"
+#: transport.c:1193
+msgid "failed to push all needed submodules"
+msgstr ""
 
-#: builtin/checkout.c:848 builtin/checkout.c:1046
-msgid "You are on a branch yet to be born"
-msgstr "Вы находитесь на еще не созданной ветке"
+#: transport.c:1326 transport-helper.c:645
+msgid "operation not supported by protocol"
+msgstr ""
 
-#: builtin/checkout.c:952
+#: transport.c:1430
 #, c-format
-msgid "only one reference expected, %d given."
-msgstr "ожидается только одна ссылка, а передано %d."
+msgid "invalid line while parsing alternate refs: %s"
+msgstr ""
 
-#: builtin/checkout.c:992 builtin/worktree.c:247
-#, c-format
-msgid "invalid reference: %s"
-msgstr "неправильная ссылка: %s"
+#: transport-helper.c:51 transport-helper.c:80
+msgid "full write to remote helper failed"
+msgstr ""
 
-#: builtin/checkout.c:1021
+#: transport-helper.c:134
 #, c-format
-msgid "reference is not a tree: %s"
-msgstr "в дереве нет такой ссылки: %s"
+msgid "unable to find remote helper for '%s'"
+msgstr ""
 
-#: builtin/checkout.c:1060
-msgid "paths cannot be used with switching branches"
-msgstr "нельзя использовать пути при переключении веток"
+#: transport-helper.c:150 transport-helper.c:559
+msgid "can't dup helper output fd"
+msgstr ""
 
-#: builtin/checkout.c:1063 builtin/checkout.c:1067
+#: transport-helper.c:201
 #, c-format
-msgid "'%s' cannot be used with switching branches"
-msgstr "нельзя использовать «%s» при переключении веток"
+msgid ""
+"unknown mandatory capability %s; this remote helper probably needs newer "
+"version of Git"
+msgstr ""
 
-#: builtin/checkout.c:1071 builtin/checkout.c:1074 builtin/checkout.c:1079
-#: builtin/checkout.c:1082
+#: transport-helper.c:207
+msgid "this remote helper should implement refspec capability"
+msgstr ""
+
+#: transport-helper.c:274 transport-helper.c:414
 #, c-format
-msgid "'%s' cannot be used with '%s'"
-msgstr "«%s» нельзя использовать одновременно с «%s»"
+msgid "%s unexpectedly said: '%s'"
+msgstr ""
 
-#: builtin/checkout.c:1087
+#: transport-helper.c:403
 #, c-format
-msgid "Cannot switch branch to a non-commit '%s'"
-msgstr "Нельзя переключить ветку на не коммит «%s»"
+msgid "%s also locked %s"
+msgstr ""
 
-#: builtin/checkout.c:1119 builtin/checkout.c:1121 builtin/clone.c:114
-#: builtin/remote.c:166 builtin/remote.c:168 builtin/worktree.c:369
-#: builtin/worktree.c:371
-msgid "branch"
-msgstr "ветка"
+#: transport-helper.c:481
+msgid "couldn't run fast-import"
+msgstr ""
 
-#: builtin/checkout.c:1120
-msgid "create and checkout a new branch"
-msgstr "создать и переключиться на новую ветку"
+#: transport-helper.c:504
+msgid "error while running fast-import"
+msgstr ""
 
-#: builtin/checkout.c:1122
-msgid "create/reset and checkout a branch"
-msgstr "создать/сбросить и перключиться на новую ветку"
+#: transport-helper.c:533 transport-helper.c:1099
+#, c-format
+msgid "could not read ref %s"
+msgstr ""
 
-#: builtin/checkout.c:1123
-msgid "create reflog for new branch"
-msgstr "создать журнал ссылок для новой ветки"
+#: transport-helper.c:578
+#, c-format
+msgid "unknown response to connect: %s"
+msgstr ""
 
-#: builtin/checkout.c:1124 builtin/worktree.c:373
-msgid "detach HEAD at named commit"
-msgstr "отсоединить HEAD на указанном коммите"
+#: transport-helper.c:600
+msgid "setting remote service path not supported by protocol"
+msgstr ""
 
-#: builtin/checkout.c:1125
-msgid "set upstream info for new branch"
-msgstr "установить информацию о вышестоящей ветке для новой ветки"
+#: transport-helper.c:602
+msgid "invalid remote service path"
+msgstr ""
 
-#: builtin/checkout.c:1127
-msgid "new-branch"
-msgstr "новая-ветка"
+#: transport-helper.c:648
+#, c-format
+msgid "can't connect to subservice %s"
+msgstr ""
 
-#: builtin/checkout.c:1127
-msgid "new unparented branch"
-msgstr "новая ветка без родителей"
+#: transport-helper.c:720
+#, c-format
+msgid "expected ok/error, helper said '%s'"
+msgstr ""
 
-#: builtin/checkout.c:1128
-msgid "checkout our version for unmerged files"
-msgstr "переключиться на нашу версию для не слитых файлов"
+#: transport-helper.c:773
+#, c-format
+msgid "helper reported unexpected status of %s"
+msgstr ""
 
-#: builtin/checkout.c:1130
-msgid "checkout their version for unmerged files"
-msgstr "переключиться на их версию для не слитых файлов"
+#: transport-helper.c:834
+#, c-format
+msgid "helper %s does not support dry-run"
+msgstr ""
 
-#: builtin/checkout.c:1132
-msgid "force checkout (throw away local modifications)"
-msgstr "принудительное переключение на состояние (отбрасывает все локальные изменения)"
+#: transport-helper.c:837
+#, c-format
+msgid "helper %s does not support --signed"
+msgstr ""
 
-#: builtin/checkout.c:1133
-msgid "perform a 3-way merge with the new branch"
-msgstr "выполнить трехходовое слияние с новой веткой"
+#: transport-helper.c:840
+#, c-format
+msgid "helper %s does not support --signed=if-asked"
+msgstr ""
 
-#: builtin/checkout.c:1134 builtin/merge.c:238
-msgid "update ignored files (default)"
-msgstr "обновить игнорируемые файлы (по умолчанию)"
+#: transport-helper.c:847
+#, c-format
+msgid "helper %s does not support 'push-option'"
+msgstr ""
 
-#: builtin/checkout.c:1135 builtin/log.c:1496 parse-options.h:251
-msgid "style"
-msgstr "стиль"
+#: transport-helper.c:939
+msgid "remote-helper doesn't support push; refspec needed"
+msgstr ""
 
-#: builtin/checkout.c:1136
-msgid "conflict style (merge or diff3)"
-msgstr "стиль конфликтов слияния (merge или diff3)"
+#: transport-helper.c:944
+#, c-format
+msgid "helper %s does not support 'force'"
+msgstr ""
 
-#: builtin/checkout.c:1139
-msgid "do not limit pathspecs to sparse entries only"
-msgstr "не ограничивать спецификаторы пути только частичными записями"
+#: transport-helper.c:991
+msgid "couldn't run fast-export"
+msgstr ""
 
-#: builtin/checkout.c:1141
-msgid "second guess 'git checkout <no-such-branch>'"
-msgstr "пересмотр «git checkout <нет-такой-ветки>»"
+#: transport-helper.c:996
+msgid "error while running fast-export"
+msgstr ""
 
-#: builtin/checkout.c:1143
-msgid "do not check if another worktree is holding the given ref"
-msgstr "не проверять, что другое дерево уже содержит указанную ссылку"
+#: transport-helper.c:1021
+#, c-format
+msgid ""
+"No refs in common and none specified; doing nothing.\n"
+"Perhaps you should specify a branch such as 'master'.\n"
+msgstr ""
 
-#: builtin/checkout.c:1147 builtin/clone.c:81 builtin/fetch.c:137
-#: builtin/merge.c:235 builtin/pull.c:123 builtin/push.c:556
-#: builtin/send-pack.c:173
-msgid "force progress reporting"
-msgstr "принудительно выводить прогресс"
+#: transport-helper.c:1085
+#, c-format
+msgid "malformed response in ref list: %s"
+msgstr ""
 
-#: builtin/checkout.c:1177
-msgid "-b, -B and --orphan are mutually exclusive"
-msgstr "-b, -B и --orphan нельзя использовать одновременно"
+#: transport-helper.c:1238
+#, c-format
+msgid "read(%s) failed"
+msgstr ""
 
-#: builtin/checkout.c:1194
-msgid "--track needs a branch name"
-msgstr "--track требует имя ветки"
+#: transport-helper.c:1265
+#, c-format
+msgid "write(%s) failed"
+msgstr ""
 
-#: builtin/checkout.c:1199
-msgid "Missing branch name; try -b"
-msgstr "Пропущено имя ветки; попробуйте -b"
+#: transport-helper.c:1314
+#, c-format
+msgid "%s thread failed"
+msgstr ""
 
-#: builtin/checkout.c:1235
-msgid "invalid path specification"
-msgstr "недопустимый спецификатор пути"
+#: transport-helper.c:1318
+#, c-format
+msgid "%s thread failed to join: %s"
+msgstr ""
 
-#: builtin/checkout.c:1242
+#: transport-helper.c:1337 transport-helper.c:1341
 #, c-format
-msgid "'%s' is not a commit and a branch '%s' cannot be created from it"
-msgstr "«%s» не является коммитом, поэтому невозможно создать из него ветку «%s»"
+msgid "can't start thread for copying data: %s"
+msgstr ""
 
-#: builtin/checkout.c:1246
+#: transport-helper.c:1378
 #, c-format
-msgid "git checkout: --detach does not take a path argument '%s'"
-msgstr "git checkout: --detach не принимает путь «%s» как аргумент"
+msgid "%s process failed to wait"
+msgstr ""
+
+#: transport-helper.c:1382
+#, c-format
+msgid "%s process failed"
+msgstr ""
+
+#: transport-helper.c:1400 transport-helper.c:1409
+msgid "can't start thread for copying data"
+msgstr ""
+
+#: tree-walk.c:33
+msgid "too-short tree object"
+msgstr "слишком  короткий объект дерева"
+
+#: tree-walk.c:39
+msgid "malformed mode in tree entry"
+msgstr "неправильный режим в записи дерева"
+
+#: tree-walk.c:43
+msgid "empty filename in tree entry"
+msgstr "пустое имя файла в записи дерева"
+
+#: tree-walk.c:116
+msgid "too-short tree file"
+msgstr "слишком  короткий файл дерева"
 
-#: builtin/checkout.c:1250
+#: unpack-trees.c:111
+#, c-format
 msgid ""
-"git checkout: --ours/--theirs, --force and --merge are incompatible when\n"
-"checking out of the index."
-msgstr "git checkout: --ours/--theirs, --force and --merge нельзя использовать одновременно при применении состояния индекса."
+"Your local changes to the following files would be overwritten by checkout:\n"
+"%%sPlease commit your changes or stash them before you switch branches."
+msgstr "Ваши локальные изменения в указанных файлах будут перезаписаны при переключении на состояние:\n%%sСделайте коммит или спрячьте ваши изменения перед переключением веток."
 
-#: builtin/clean.c:26
+#: unpack-trees.c:113
+#, c-format
 msgid ""
-"git clean [-d] [-f] [-i] [-n] [-q] [-e <pattern>] [-x | -X] [--] <paths>..."
-msgstr "git clean [-d] [-f] [-i] [-n] [-q] [-e <шаблон>] [-x | -X] [--] <пути>…"
+"Your local changes to the following files would be overwritten by checkout:\n"
+"%%s"
+msgstr "Ваши локальные изменения в указанных файлах будут перезаписаны при переключении на состояние:\n%%s"
 
-#: builtin/clean.c:30
+#: unpack-trees.c:116
 #, c-format
-msgid "Removing %s\n"
-msgstr "Удаление %s\n"
+msgid ""
+"Your local changes to the following files would be overwritten by merge:\n"
+"%%sPlease commit your changes or stash them before you merge."
+msgstr "Ваши локальные изменения в указанных файлах будут перезаписаны при слиянии:\n%%sСделайте коммит или спрячьте ваши изменения перед слиянием веток."
 
-#: builtin/clean.c:31
+#: unpack-trees.c:118
 #, c-format
-msgid "Would remove %s\n"
-msgstr "Будет удалено %s\n"
+msgid ""
+"Your local changes to the following files would be overwritten by merge:\n"
+"%%s"
+msgstr "Ваши локальные изменения в указанных файлах будут перезаписаны при слиянии:\n%%s"
 
-#: builtin/clean.c:32
+#: unpack-trees.c:121
 #, c-format
-msgid "Skipping repository %s\n"
-msgstr "Пропуск репозитория %s\n"
+msgid ""
+"Your local changes to the following files would be overwritten by %s:\n"
+"%%sPlease commit your changes or stash them before you %s."
+msgstr "Ваши локальные изменения в указанных файлах будут перезаписаны при %s:\n%%sСделайте коммит или спрячьте ваши изменения перед %s."
 
-#: builtin/clean.c:33
+#: unpack-trees.c:123
 #, c-format
-msgid "Would skip repository %s\n"
-msgstr "Будет пропущен репозиторий %s\n"
+msgid ""
+"Your local changes to the following files would be overwritten by %s:\n"
+"%%s"
+msgstr "Ваши локальные изменения в указанных файлах будут перезаписаны при %s:\n%%s"
 
-#: builtin/clean.c:34
+#: unpack-trees.c:128
 #, c-format
-msgid "failed to remove %s"
-msgstr "сбой удаления %s"
+msgid ""
+"Updating the following directories would lose untracked files in them:\n"
+"%s"
+msgstr "Обновление указанных каталогов приведет к потере неотслеживаемых файлов в них:\n%s"
 
-#: builtin/clean.c:302 git-add--interactive.perl:572
+#: unpack-trees.c:132
 #, c-format
 msgid ""
-"Prompt help:\n"
-"1          - select a numbered item\n"
-"foo        - select item based on unique prefix\n"
-"           - (empty) select nothing\n"
-msgstr "Справка по выделению:\n1          - выбрать указанный элемент\nfoo        - выбрать элемент с указанным префиксом\n           - (пусто) не выбирать ничего\n"
+"The following untracked working tree files would be removed by checkout:\n"
+"%%sPlease move or remove them before you switch branches."
+msgstr "Указанные неотслеживаемые файлы в рабочем каталоге будут удалены при переключении на состояние:\n%%sПереместите эти файлы или удалите их перед переключением веток."
 
-#: builtin/clean.c:306 git-add--interactive.perl:581
+#: unpack-trees.c:134
 #, c-format
 msgid ""
-"Prompt help:\n"
-"1          - select a single item\n"
-"3-5        - select a range of items\n"
-"2-3,6-9    - select multiple ranges\n"
-"foo        - select item based on unique prefix\n"
-"-...       - unselect specified items\n"
-"*          - choose all items\n"
-"           - (empty) finish selecting\n"
-msgstr "Справка по выделению:\n1          - выбрать один элемент\n3-5        - выбрать диапазон элементов\n2-3,6-9    - выбрать несколько диапазонов\nfoo        - выбрать элемент с указанным префиксом\n-…       - убрать выделение с указанных элементов\n*          - выбрать все элементы\n           - (пусто) завершить выделение\n"
+"The following untracked working tree files would be removed by checkout:\n"
+"%%s"
+msgstr "Указанные неотслеживаемые файлы в рабочем каталоге будут удалены при переключении на состояние:\n%%s"
 
-#: builtin/clean.c:522 git-add--interactive.perl:547
-#: git-add--interactive.perl:552
-#, c-format, perl-format
-msgid "Huh (%s)?\n"
-msgstr "Хм (%s)?\n"
+#: unpack-trees.c:137
+#, c-format
+msgid ""
+"The following untracked working tree files would be removed by merge:\n"
+"%%sPlease move or remove them before you merge."
+msgstr "Указанные неотслеживаемые файлы в рабочем каталоге будут удалены при слиянии:\n%%sПереместите эти файлы или удалите их перед переключением веток."
 
-#: builtin/clean.c:664
+#: unpack-trees.c:139
 #, c-format
-msgid "Input ignore patterns>> "
-msgstr "Шаблоны игнорирования ввода>> "
+msgid ""
+"The following untracked working tree files would be removed by merge:\n"
+"%%s"
+msgstr "Указанные неотслеживаемые файлы в рабочем каталоге будут удалены при слиянии:\n%%s"
 
-#: builtin/clean.c:701
+#: unpack-trees.c:142
 #, c-format
-msgid "WARNING: Cannot find items matched by: %s"
-msgstr "ПРЕДУПРЕЖДЕНИЕ: Не удалось найти элементы соответствующие: %s"
+msgid ""
+"The following untracked working tree files would be removed by %s:\n"
+"%%sPlease move or remove them before you %s."
+msgstr "Указанные неотслеживаемые файлы в рабочем каталоге будут удалены при %s:\n%%sПереместите эти файлы или удалите их перед %s."
 
-#: builtin/clean.c:722
-msgid "Select items to delete"
-msgstr "Укажите элементы для удаления"
+#: unpack-trees.c:144
+#, c-format
+msgid ""
+"The following untracked working tree files would be removed by %s:\n"
+"%%s"
+msgstr "Указанные неотслеживаемые файлы в рабочем каталоге будут удалены при %s:\n%%s"
 
-#. TRANSLATORS: Make sure to keep [y/N] as is
-#: builtin/clean.c:763
+#: unpack-trees.c:150
 #, c-format
-msgid "Remove %s [y/N]? "
-msgstr "Удалить %s [y - да/N - нет]? "
+msgid ""
+"The following untracked working tree files would be overwritten by checkout:\n"
+"%%sPlease move or remove them before you switch branches."
+msgstr "Указанные неотслеживаемые файлы в рабочем каталоге будут перезаписаны при переключении на состояние:\n%%sПереместите эти файлы или удалите их перед переключением веток."
 
-#: builtin/clean.c:788 git-add--interactive.perl:1616
+#: unpack-trees.c:152
 #, c-format
-msgid "Bye.\n"
-msgstr "До свидания.\n"
+msgid ""
+"The following untracked working tree files would be overwritten by checkout:\n"
+"%%s"
+msgstr "Указанные неотслеживаемые файлы в рабочем каталоге будут перезаписаны при переключении на состояние:\n%%s"
 
-#: builtin/clean.c:796
+#: unpack-trees.c:155
+#, c-format
 msgid ""
-"clean               - start cleaning\n"
-"filter by pattern   - exclude items from deletion\n"
-"select by numbers   - select items to be deleted by numbers\n"
-"ask each            - confirm each deletion (like \"rm -i\")\n"
-"quit                - stop cleaning\n"
-"help                - this screen\n"
-"?                   - help for prompt selection"
-msgstr "clean               - начать очистку\nfilter by pattern   - исключить удаление элементов\nselect by numbers   - исключить удаление элементов по номерам\nask each            - запрашивать подтверждение на удаление каждого элемента (как «rm -i»)\nquit                - прекратить очистку\nhelp                - этот экран\n?                   - справка по выделению"
+"The following untracked working tree files would be overwritten by merge:\n"
+"%%sPlease move or remove them before you merge."
+msgstr "Указанные неотслеживаемые файлы в рабочем каталоге будут перезаписаны при слиянии:\n%%sПереместите эти файлы или удалите их перед переключением веток."
 
-#: builtin/clean.c:823 git-add--interactive.perl:1692
-msgid "*** Commands ***"
-msgstr "*** Команды ***"
+#: unpack-trees.c:157
+#, c-format
+msgid ""
+"The following untracked working tree files would be overwritten by merge:\n"
+"%%s"
+msgstr "Указанные неотслеживаемые файлы в рабочем каталоге будут перезаписаны при слиянии:\n%%s"
 
-#: builtin/clean.c:824 git-add--interactive.perl:1689
-msgid "What now"
-msgstr "Что теперь"
+#: unpack-trees.c:160
+#, c-format
+msgid ""
+"The following untracked working tree files would be overwritten by %s:\n"
+"%%sPlease move or remove them before you %s."
+msgstr "Указанные неотслеживаемые файлы в рабочем каталоге будут перезаписаны при %s:\n%%sПереместите эти файлы или удалите их перед %s."
 
-#: builtin/clean.c:832
-msgid "Would remove the following item:"
-msgid_plural "Would remove the following items:"
-msgstr[0] "Удалить следующие элементы:"
-msgstr[1] "Удалить следующие элементы:"
-msgstr[2] "Удалить следующие элементы:"
-msgstr[3] "Удалить следующие элементы:"
+#: unpack-trees.c:162
+#, c-format
+msgid ""
+"The following untracked working tree files would be overwritten by %s:\n"
+"%%s"
+msgstr "Указанные неотслеживаемые файлы в рабочем каталоге будут перезаписаны при %s:\n%%s"
 
-#: builtin/clean.c:848
-msgid "No more files to clean, exiting."
-msgstr "Больше нет файлов для очистки, выходим."
+#: unpack-trees.c:170
+#, c-format
+msgid "Entry '%s' overlaps with '%s'.  Cannot bind."
+msgstr "Запись «%s» частично совпадает с «%s».  Не удалось назначить соответствие."
 
-#: builtin/clean.c:910
-msgid "do not print names of files removed"
-msgstr "не выводить имена удаляемых файлов"
+#: unpack-trees.c:173
+#, c-format
+msgid ""
+"Cannot update sparse checkout: the following entries are not up to date:\n"
+"%s"
+msgstr "Не удалось обновить частичное состояние: следующие элементы не последней версии:\n%s"
 
-#: builtin/clean.c:912
-msgid "force"
-msgstr "принудительно"
+#: unpack-trees.c:175
+#, c-format
+msgid ""
+"The following working tree files would be overwritten by sparse checkout update:\n"
+"%s"
+msgstr "Указанные файлы из рабочего каталога будут перезаписаны при обновлении частичного состояния:\n%s"
 
-#: builtin/clean.c:913
-msgid "interactive cleaning"
-msgstr "интерактивная очистка"
+#: unpack-trees.c:177
+#, c-format
+msgid ""
+"The following working tree files would be removed by sparse checkout update:\n"
+"%s"
+msgstr "Указанные файлы из рабочего каталога будут удалены при обновлении частичного состояния:\n%s"
 
-#: builtin/clean.c:915
-msgid "remove whole directories"
-msgstr "удалить каталоги полностью"
+#: unpack-trees.c:179
+#, c-format
+msgid ""
+"Cannot update submodule:\n"
+"%s"
+msgstr "Не удолось обновить подмодуль:\n%s"
 
-#: builtin/clean.c:916 builtin/describe.c:530 builtin/describe.c:532
-#: builtin/grep.c:863 builtin/log.c:155 builtin/log.c:157
-#: builtin/ls-files.c:548 builtin/name-rev.c:397 builtin/name-rev.c:399
-#: builtin/show-ref.c:176
-msgid "pattern"
-msgstr "шаблон"
+#: unpack-trees.c:256
+#, c-format
+msgid "Aborting\n"
+msgstr "Прерываю\n"
 
-#: builtin/clean.c:917
-msgid "add <pattern> to ignore rules"
-msgstr "добавить <шаблон> в правила игнорирования"
+#: unpack-trees.c:318
+msgid "Checking out files"
+msgstr "Распаковка файлов"
 
-#: builtin/clean.c:918
-msgid "remove ignored files, too"
-msgstr "также удалить игнорируемые файлы"
+#: unpack-trees.c:350
+msgid ""
+"the following paths have collided (e.g. case-sensitive paths\n"
+"on a case-insensitive filesystem) and only one from the same\n"
+"colliding group is in the working tree:\n"
+msgstr ""
 
-#: builtin/clean.c:920
-msgid "remove only ignored files"
-msgstr "удалить только игнорируемые файлы"
+#: urlmatch.c:163
+msgid "invalid URL scheme name or missing '://' suffix"
+msgstr "Неправильная имя URL схемы или пропущен суффикс «://»"
 
-#: builtin/clean.c:938
-msgid "-x and -X cannot be used together"
-msgstr "нельзя использовать одновременно -x и -X"
+#: urlmatch.c:187 urlmatch.c:346 urlmatch.c:405
+#, c-format
+msgid "invalid %XX escape sequence"
+msgstr "неправильная управляющая последовательность %XX"
 
-#: builtin/clean.c:942
-msgid ""
-"clean.requireForce set to true and neither -i, -n, nor -f given; refusing to"
-" clean"
-msgstr "clean.requireForce установлен как true и ни одна из опций -i, -n или -f не указана; отказ очистки"
+#: urlmatch.c:215
+msgid "missing host and scheme is not 'file:'"
+msgstr "пропущено имя сервера и схема доступа не «file:»"
 
-#: builtin/clean.c:945
-msgid ""
-"clean.requireForce defaults to true and neither -i, -n, nor -f given; "
-"refusing to clean"
-msgstr "clean.requireForce установлен по умолчанию как true и ни одна из опций -i, -n или -f не указана; отказ очистки"
+#: urlmatch.c:232
+msgid "a 'file:' URL may not have a port number"
+msgstr "URL со схемой «file:» не может содержать номер порта"
 
-#: builtin/clone.c:39
-msgid "git clone [<options>] [--] <repo> [<dir>]"
-msgstr "git clone [<опции>] [--] <репозиторий> [<каталог>]"
+#: urlmatch.c:247
+msgid "invalid characters in host name"
+msgstr "неправильные символы в имени сервера"
 
-#: builtin/clone.c:83
-msgid "don't create a checkout"
-msgstr "не переключать рабочую копию на HEAD"
+#: urlmatch.c:292 urlmatch.c:303
+msgid "invalid port number"
+msgstr "неправильный номер порта"
 
-#: builtin/clone.c:84 builtin/clone.c:86 builtin/init-db.c:479
-msgid "create a bare repository"
-msgstr "создать голый репозиторий"
+#: urlmatch.c:371
+msgid "invalid '..' path segment"
+msgstr "неправильная часть пути «..»"
 
-#: builtin/clone.c:88
-msgid "create a mirror repository (implies bare)"
-msgstr "создать зеркало репозитория (включает в себя и параметр bare)"
+#: worktree.c:255 builtin/am.c:2097
+#, c-format
+msgid "failed to read '%s'"
+msgstr "не удалось прочитать «%s»"
 
-#: builtin/clone.c:90
-msgid "to clone from a local repository"
-msgstr "для клонирования из локального репозитория"
+#: worktree.c:301
+#, c-format
+msgid "'%s' at main working tree is not the repository directory"
+msgstr ""
 
-#: builtin/clone.c:92
-msgid "don't use local hardlinks, always copy"
-msgstr "не использовать жесткие ссылки, всегда копировать файлы"
+#: worktree.c:312
+#, c-format
+msgid "'%s' file does not contain absolute path to the working tree location"
+msgstr ""
 
-#: builtin/clone.c:94
-msgid "setup as shared repository"
-msgstr "настроить как общедоступный репозиторий"
+#: worktree.c:324
+#, c-format
+msgid "'%s' does not exist"
+msgstr "«%s» не существует"
 
-#: builtin/clone.c:96 builtin/clone.c:100
-msgid "pathspec"
-msgstr "спецификатор-пути"
+#: worktree.c:330
+#, c-format
+msgid "'%s' is not a .git file, error code %d"
+msgstr ""
 
-#: builtin/clone.c:96 builtin/clone.c:100
-msgid "initialize submodules in the clone"
-msgstr "инициализировать подмодули в клоне"
+#: worktree.c:338
+#, c-format
+msgid "'%s' does not point back to '%s'"
+msgstr ""
 
-#: builtin/clone.c:103
-msgid "number of submodules cloned in parallel"
-msgstr "количество подмодулей, которые будут клонированы парралельно"
+#: wrapper.c:223 wrapper.c:393
+#, c-format
+msgid "could not open '%s' for reading and writing"
+msgstr "не удалось открыть «%s» для чтения и записи"
 
-#: builtin/clone.c:104 builtin/init-db.c:476
-msgid "template-directory"
-msgstr "каталог-шаблонов"
+#: wrapper.c:424 wrapper.c:624
+#, c-format
+msgid "unable to access '%s'"
+msgstr "«%s» недоступно"
 
-#: builtin/clone.c:105 builtin/init-db.c:477
-msgid "directory from which templates will be used"
-msgstr "каталог, шаблоны из которого будут использованы"
+#: wrapper.c:632
+msgid "unable to get current working directory"
+msgstr "не удалось получить текущий рабочий каталог"
 
-#: builtin/clone.c:107 builtin/clone.c:109 builtin/submodule--helper.c:873
-#: builtin/submodule--helper.c:1240
-msgid "reference repository"
-msgstr "ссылаемый репозиторий"
+#: wt-status.c:156
+msgid "Unmerged paths:"
+msgstr "Не слитые пути:"
 
-#: builtin/clone.c:111
-msgid "use --reference only while cloning"
-msgstr "используйте --reference только при клонировании"
+#: wt-status.c:183 wt-status.c:210
+#, c-format
+msgid "  (use \"git reset %s <file>...\" to unstage)"
+msgstr "  (используйте «git reset %s <файл>…», чтобы убрать из индекса)"
 
-#: builtin/clone.c:112 builtin/column.c:27 builtin/merge-file.c:44
-msgid "name"
-msgstr "имя"
+#: wt-status.c:185 wt-status.c:212
+msgid "  (use \"git rm --cached <file>...\" to unstage)"
+msgstr "  (используйте «git rm --cached <файл>…», чтобы убрать из индекса)"
 
-#: builtin/clone.c:113
-msgid "use <name> instead of 'origin' to track upstream"
-msgstr "использовать <имя> вместо «origin» для отслеживания вышестоящего репозитория"
+#: wt-status.c:189
+msgid "  (use \"git add <file>...\" to mark resolution)"
+msgstr "  (используйте «git add <файл>…», чтобы пометить разрешение конфликта)"
 
-#: builtin/clone.c:115
-msgid "checkout <branch> instead of the remote's HEAD"
-msgstr "переключиться на <ветку>, вместо HEAD внешнего репозитория"
+#: wt-status.c:191 wt-status.c:195
+msgid "  (use \"git add/rm <file>...\" as appropriate to mark resolution)"
+msgstr "  (используйте «git add/rm <файл>…», чтобы пометить выбранное разрешение конфликта)"
 
-#: builtin/clone.c:117
-msgid "path to git-upload-pack on the remote"
-msgstr "путь к git-upload-pack на внешнем репозитории"
+#: wt-status.c:193
+msgid "  (use \"git rm <file>...\" to mark resolution)"
+msgstr "  (используйте «git rm <файл>…», чтобы пометить разрешение конфликта)"
 
-#: builtin/clone.c:118 builtin/fetch.c:138 builtin/grep.c:806
-#: builtin/pull.c:211
-msgid "depth"
-msgstr "глубина"
+#: wt-status.c:204 wt-status.c:1064
+msgid "Changes to be committed:"
+msgstr "Изменения, которые будут включены в коммит:"
 
-#: builtin/clone.c:119
-msgid "create a shallow clone of that depth"
-msgstr "сделать частичный клон указанной глубины"
+#: wt-status.c:222 wt-status.c:1073
+msgid "Changes not staged for commit:"
+msgstr "Изменения, которые не в индексе для коммита:"
 
-#: builtin/clone.c:120 builtin/fetch.c:140 builtin/pack-objects.c:2991
-#: parse-options.h:142
-msgid "time"
-msgstr "время"
+#: wt-status.c:226
+msgid "  (use \"git add <file>...\" to update what will be committed)"
+msgstr "  (используйте «git add <файл>…», чтобы добавить файл в индекс)"
 
-#: builtin/clone.c:121
-msgid "create a shallow clone since a specific time"
-msgstr "сделать частичный клон до определенного времени"
+#: wt-status.c:228
+msgid "  (use \"git add/rm <file>...\" to update what will be committed)"
+msgstr "  (используйте «git add/rm <файл>…», чтобы добавить или удалить файл из индекса)"
 
-#: builtin/clone.c:122 builtin/fetch.c:142
-msgid "revision"
-msgstr "редакция"
+#: wt-status.c:229
+msgid ""
+"  (use \"git checkout -- <file>...\" to discard changes in working "
+"directory)"
+msgstr "  (используйте «git checkout -- <файл>…», чтобы отменить изменения\n   в рабочем каталоге)"
 
-#: builtin/clone.c:123 builtin/fetch.c:143
-msgid "deepen history of shallow clone, excluding rev"
-msgstr "углубить историю частичного клона исключая редакцию"
+#: wt-status.c:231
+msgid "  (commit or discard the untracked or modified content in submodules)"
+msgstr "  (сделайте коммит или отмените изменения в неотслеживаемом или измененном содержимом в подмодулях)"
 
-#: builtin/clone.c:125
-msgid "clone only one branch, HEAD or --branch"
-msgstr "клонировать только одну ветку, HEAD или --branch"
+#: wt-status.c:243
+#, c-format
+msgid "  (use \"git %s <file>...\" to include in what will be committed)"
+msgstr "  (используйте «git %s <файл>…», чтобы добавить в то, что будет включено в коммит)"
 
-#: builtin/clone.c:127
-msgid "don't clone any tags, and make later fetches not to follow them"
-msgstr "не клонировать метки, а также настроить, чтобы не клонировались и в дальнейшем"
+#: wt-status.c:258
+msgid "both deleted:"
+msgstr "оба удалены:"
 
-#: builtin/clone.c:129
-msgid "any cloned submodules will be shallow"
-msgstr "все склонированные подмодули будут частичными клонами"
+#: wt-status.c:260
+msgid "added by us:"
+msgstr "добавлено нами:"
 
-#: builtin/clone.c:130 builtin/init-db.c:485
-msgid "gitdir"
-msgstr "каталог-git"
+#: wt-status.c:262
+msgid "deleted by them:"
+msgstr "удалено ими:"
 
-#: builtin/clone.c:131 builtin/init-db.c:486
-msgid "separate git dir from working tree"
-msgstr "разместить каталог git отдельно от рабочей копии"
+#: wt-status.c:264
+msgid "added by them:"
+msgstr "добавлено ими:"
 
-#: builtin/clone.c:132
-msgid "key=value"
-msgstr "ключ=значение"
+#: wt-status.c:266
+msgid "deleted by us:"
+msgstr "удалено нами:"
 
-#: builtin/clone.c:133
-msgid "set config inside the new repository"
-msgstr "установить параметры внутри нового репозитория"
+#: wt-status.c:268
+msgid "both added:"
+msgstr "оба добавлены:"
 
-#: builtin/clone.c:134 builtin/fetch.c:160 builtin/pull.c:224
-#: builtin/push.c:567
-msgid "use IPv4 addresses only"
-msgstr "использовать только IPv4 адреса"
+#: wt-status.c:270
+msgid "both modified:"
+msgstr "оба изменены:"
 
-#: builtin/clone.c:136 builtin/fetch.c:162 builtin/pull.c:227
-#: builtin/push.c:569
-msgid "use IPv6 addresses only"
-msgstr "использовать только IPv6 адреса"
+#: wt-status.c:280
+msgid "new file:"
+msgstr "новый файл:"
 
-#: builtin/clone.c:273
-msgid ""
-"No directory name could be guessed.\n"
-"Please specify a directory on the command line"
-msgstr "Имя каталога не может быть угадано.\nУкажите имя каталога с помощью параметра командной строки"
+#: wt-status.c:282
+msgid "copied:"
+msgstr "скопировано:"
 
-#: builtin/clone.c:326
-#, c-format
-msgid "info: Could not add alternate for '%s': %s\n"
-msgstr "информация: Не удалось добавить альтернативу для «%s»: %s\n"
+#: wt-status.c:284
+msgid "deleted:"
+msgstr "удалено:"
 
-#: builtin/clone.c:398
-#, c-format
-msgid "failed to open '%s'"
-msgstr "не удалось открыть «%s»"
+#: wt-status.c:286
+msgid "modified:"
+msgstr "изменено:"
 
-#: builtin/clone.c:406
-#, c-format
-msgid "%s exists and is not a directory"
-msgstr "%s уже существует и не является каталогом"
+#: wt-status.c:288
+msgid "renamed:"
+msgstr "переименовано:"
 
-#: builtin/clone.c:420
-#, c-format
-msgid "failed to stat %s\n"
-msgstr "не удалось выполнить stat %s\n"
+#: wt-status.c:290
+msgid "typechange:"
+msgstr "изменен тип:"
 
-#: builtin/clone.c:442
-#, c-format
-msgid "failed to create link '%s'"
-msgstr "не удалось создать ссылку «%s»"
+#: wt-status.c:292
+msgid "unknown:"
+msgstr "неизвестно:"
 
-#: builtin/clone.c:446
-#, c-format
-msgid "failed to copy file to '%s'"
-msgstr "не удалось копировать файл в «%s»"
+#: wt-status.c:294
+msgid "unmerged:"
+msgstr "не слитые:"
 
-#: builtin/clone.c:472
-#, c-format
-msgid "done.\n"
-msgstr "готово.\n"
+#: wt-status.c:374
+msgid "new commits, "
+msgstr "новые коммиты, "
 
-#: builtin/clone.c:484
-msgid ""
-"Clone succeeded, but checkout failed.\n"
-"You can inspect what was checked out with 'git status'\n"
-"and retry the checkout with 'git checkout -f HEAD'\n"
-msgstr "Клонирование прошло успешно, но во время переключения состояния произошла ошибка.\nС помощь команды «git status» вы можете просмотреть, какие файлы были обновлены,\nа с помощью «git checkout -f HEAD» можно повторить попытку переключения на ветку \n"
+#: wt-status.c:376
+msgid "modified content, "
+msgstr "изменено содержимое, "
 
-#: builtin/clone.c:561
-#, c-format
-msgid "Could not find remote branch %s to clone."
-msgstr "Не удалось найти внешнюю ветку %s для клонирования."
-
-#: builtin/clone.c:656
-msgid "remote did not send all necessary objects"
-msgstr "внешний репозиторий прислал не все необходимые объекты"
+#: wt-status.c:378
+msgid "untracked content, "
+msgstr "неотслеживаемое содержимое, "
 
-#: builtin/clone.c:672
+#: wt-status.c:896
 #, c-format
-msgid "unable to update %s"
-msgstr "не удалось обновить %s"
+msgid "Your stash currently has %d entry"
+msgid_plural "Your stash currently has %d entries"
+msgstr[0] "У вас сейчас спрятана %d запись"
+msgstr[1] "У вас сейчас спрятаны %d записи"
+msgstr[2] "У вас сейчас спрятано %d записей"
+msgstr[3] "У вас сейчас спрятаны %d записи"
 
-#: builtin/clone.c:721
-msgid "remote HEAD refers to nonexistent ref, unable to checkout.\n"
-msgstr "внешний HEAD ссылается на несуществующую ссылку, нельзя переключиться на такую версию.\n"
+#: wt-status.c:928
+msgid "Submodules changed but not updated:"
+msgstr "Измененные, но не обновленные подмодули:"
 
-#: builtin/clone.c:751
-msgid "unable to checkout working tree"
-msgstr "не удалось переключиться на версию в рабочем каталоге"
+#: wt-status.c:930
+msgid "Submodule changes to be committed:"
+msgstr "Изменения в подмодулях, которые будут закоммичены:"
 
-#: builtin/clone.c:796
-msgid "unable to write parameters to config file"
-msgstr "не удалось записать параметры в файл конфигурации"
+#: wt-status.c:1012
+msgid ""
+"Do not modify or remove the line above.\n"
+"Everything below it will be ignored."
+msgstr "Не изменяйте или удаляйте строку выше этой.\nВсё, что ниже — будет проигнорировано."
 
-#: builtin/clone.c:859
-msgid "cannot repack to clean up"
-msgstr "не удалось выполнить перепаковку для очистки"
+#: wt-status.c:1119
+msgid "You have unmerged paths."
+msgstr "У вас есть не слитые пути."
 
-#: builtin/clone.c:861
-msgid "cannot unlink temporary alternates file"
-msgstr "не удалось отсоединить временные альтернативные файлы"
+#: wt-status.c:1122
+msgid "  (fix conflicts and run \"git commit\")"
+msgstr "  (разрешите конфликты, затем запустите «git commit»)"
 
-#: builtin/clone.c:894 builtin/receive-pack.c:1945
-msgid "Too many arguments."
-msgstr "Слишком много аргументов."
+#: wt-status.c:1124
+msgid "  (use \"git merge --abort\" to abort the merge)"
+msgstr "  (используйте «git merge --abort», чтобы остановить операцию слияния)"
 
-#: builtin/clone.c:898
-msgid "You must specify a repository to clone."
-msgstr "Вы должны указать репозиторий для клонирования."
+#: wt-status.c:1128
+msgid "All conflicts fixed but you are still merging."
+msgstr "Все конфликты исправлены, но вы все еще в процессе слияния."
 
-#: builtin/clone.c:911
-#, c-format
-msgid "--bare and --origin %s options are incompatible."
-msgstr "--bare и --origin %s нельзя использовать одновременно."
+#: wt-status.c:1131
+msgid "  (use \"git commit\" to conclude merge)"
+msgstr "  (используйте «git commit», чтобы завершить слияние)"
 
-#: builtin/clone.c:914
-msgid "--bare and --separate-git-dir are incompatible."
-msgstr "--bare и --separate-git-dir нельзя использовать одновременно."
+#: wt-status.c:1140
+msgid "You are in the middle of an am session."
+msgstr "Вы в процессе сессии am."
 
-#: builtin/clone.c:927
-#, c-format
-msgid "repository '%s' does not exist"
-msgstr "репозиторий «%s» не существует"
+#: wt-status.c:1143
+msgid "The current patch is empty."
+msgstr "Текущий патч пустой."
 
-#: builtin/clone.c:933 builtin/fetch.c:1358
-#, c-format
-msgid "depth %s is not a positive number"
-msgstr "глубина %s не является положительным числом"
+#: wt-status.c:1147
+msgid "  (fix conflicts and then run \"git am --continue\")"
+msgstr "  (разрешите конфликты, затем запустите «git am --continue»)"
 
-#: builtin/clone.c:943
-#, c-format
-msgid "destination path '%s' already exists and is not an empty directory."
-msgstr "целевой путь «%s» уже существует и не является пустым каталогом."
+#: wt-status.c:1149
+msgid "  (use \"git am --skip\" to skip this patch)"
+msgstr "  (используйте «git am --skip», чтобы пропустить этот патч)"
 
-#: builtin/clone.c:953
-#, c-format
-msgid "working tree '%s' already exists."
-msgstr "рабочий каталог «%s» уже существует."
+#: wt-status.c:1151
+msgid "  (use \"git am --abort\" to restore the original branch)"
+msgstr "  (используйте «git am --abort», чтобы восстановить оригинальную ветку)"
 
-#: builtin/clone.c:968 builtin/clone.c:979 builtin/difftool.c:270
-#: builtin/worktree.c:253 builtin/worktree.c:283
-#, c-format
-msgid "could not create leading directories of '%s'"
-msgstr "не удалось создать родительские каталоги для «%s»"
+#: wt-status.c:1284
+msgid "git-rebase-todo is missing."
+msgstr "git-rebase-todo отсутствует."
 
-#: builtin/clone.c:971
+#: wt-status.c:1286
+msgid "No commands done."
+msgstr "Команды не выполнены."
+
+#: wt-status.c:1289
 #, c-format
-msgid "could not create work tree dir '%s'"
-msgstr "не удалось создать рабочий каталог «%s»"
+msgid "Last command done (%d command done):"
+msgid_plural "Last commands done (%d commands done):"
+msgstr[0] "Последняя команда выполнена (%d команда выполнена):"
+msgstr[1] "Последняя команда выполнена (%d команды выполнено):"
+msgstr[2] "Последняя команда выполнена (%d команд выполнено):"
+msgstr[3] "Последняя команда выполнена (%d команд выполнено):"
 
-#: builtin/clone.c:983
+#: wt-status.c:1300
 #, c-format
-msgid "Cloning into bare repository '%s'...\n"
-msgstr "Клонирование в голый репозиторий «%s»…\n"
+msgid "  (see more in file %s)"
+msgstr "  (смотрите дополнительно в файле %s)"
+
+#: wt-status.c:1305
+msgid "No commands remaining."
+msgstr "Команд больше не осталось."
 
-#: builtin/clone.c:985
+#: wt-status.c:1308
 #, c-format
-msgid "Cloning into '%s'...\n"
-msgstr "Клонирование в «%s»…\n"
+msgid "Next command to do (%d remaining command):"
+msgid_plural "Next commands to do (%d remaining commands):"
+msgstr[0] "Следующая команда для выполнения (%d команда осталась):"
+msgstr[1] "Следующая команда для выполнения (%d команды осталось):"
+msgstr[2] "Следующая команда для выполнения (%d команд осталось):"
+msgstr[3] "Следующая команда для выполнения (%d команд осталось):"
 
-#: builtin/clone.c:1009
-msgid ""
-"clone --recursive is not compatible with both --reference and --reference-"
-"if-able"
-msgstr "клонирование с параметром --recursive нельзя использовать одновременно ни с --reference, ни с --reference-if-able"
+#: wt-status.c:1316
+msgid "  (use \"git rebase --edit-todo\" to view and edit)"
+msgstr "  (используйте «git rebase --edit-todo», чтобы просмотреть и изменить)"
 
-#: builtin/clone.c:1071
-msgid "--depth is ignored in local clones; use file:// instead."
-msgstr "--depth игнорируется на локальных клонах; вместо этого используйте file://."
+#: wt-status.c:1328
+#, c-format
+msgid "You are currently rebasing branch '%s' on '%s'."
+msgstr "Вы сейчас перемещаете ветку «%s» над «%s»."
 
-#: builtin/clone.c:1073
-msgid "--shallow-since is ignored in local clones; use file:// instead."
-msgstr "--shallow-since игнорируется на локальных клонах; используйте file:// вместо этого."
+#: wt-status.c:1333
+msgid "You are currently rebasing."
+msgstr "Вы сейчас перемещаете ветку."
 
-#: builtin/clone.c:1075
-msgid "--shallow-exclude is ignored in local clones; use file:// instead."
-msgstr "--shallow-exclude игнорируется на локальных клонах; используйте file:// вместо этого."
+#: wt-status.c:1346
+msgid "  (fix conflicts and then run \"git rebase --continue\")"
+msgstr "  (разрешите конфликты, затем запустите «git rebase --continue»)"
 
-#: builtin/clone.c:1078
-msgid "source repository is shallow, ignoring --local"
-msgstr "исходный репозиторий является частичным, --local игнорируется"
+#: wt-status.c:1348
+msgid "  (use \"git rebase --skip\" to skip this patch)"
+msgstr "  (используйте «git rebase --skip», чтобы пропустить этот патч)"
 
-#: builtin/clone.c:1083
-msgid "--local is ignored"
-msgstr "--local игнорируется"
+#: wt-status.c:1350
+msgid "  (use \"git rebase --abort\" to check out the original branch)"
+msgstr "  (используйте «git rebase --abort», чтобы перейти на оригинальную ветку)"
+
+#: wt-status.c:1357
+msgid "  (all conflicts fixed: run \"git rebase --continue\")"
+msgstr "  (все конфликты разрешены: запустите «git rebase --continue»)"
 
-#: builtin/clone.c:1139 builtin/clone.c:1147
+#: wt-status.c:1361
 #, c-format
-msgid "Remote branch %s not found in upstream %s"
-msgstr "Внешняя ветка %s не найдена в вышестоящем репозитории %s"
+msgid ""
+"You are currently splitting a commit while rebasing branch '%s' on '%s'."
+msgstr "Вы сейчас разделяете коммит при перемещении ветки  «%s» над «%s»."
 
-#: builtin/clone.c:1150
-msgid "You appear to have cloned an empty repository."
-msgstr "Похоже, что вы клонировали пустой репозиторий."
+#: wt-status.c:1366
+msgid "You are currently splitting a commit during a rebase."
+msgstr "Вы сейчас разделяете коммит при перемещении ветки."
 
-#: builtin/column.c:10
-msgid "git column [<options>]"
-msgstr "git column [<опции>]"
+#: wt-status.c:1369
+msgid "  (Once your working directory is clean, run \"git rebase --continue\")"
+msgstr "(Как только ваш рабочий каталог будет чистый, запустите «git rebase --continue»)"
 
-#: builtin/column.c:27
-msgid "lookup config vars"
-msgstr "запросить переменные конфигурации"
+#: wt-status.c:1373
+#, c-format
+msgid "You are currently editing a commit while rebasing branch '%s' on '%s'."
+msgstr "Вы сейчас редактируете коммит при перемещении ветки  «%s» над «%s»."
 
-#: builtin/column.c:28 builtin/column.c:29
-msgid "layout to use"
-msgstr "использовать схему расположения"
+#: wt-status.c:1378
+msgid "You are currently editing a commit during a rebase."
+msgstr "Вы сейчас редактируете коммит при перемещении ветки."
 
-#: builtin/column.c:30
-msgid "Maximum width"
-msgstr "Максимальная ширина"
+#: wt-status.c:1381
+msgid "  (use \"git commit --amend\" to amend the current commit)"
+msgstr "  (используйте «git commit --amend», чтобы исправить текущий коммит)"
 
-#: builtin/column.c:31
-msgid "Padding space on left border"
-msgstr "Расстояние отступа слева"
+#: wt-status.c:1383
+msgid "  (use \"git rebase --continue\" once you are satisfied with your changes)"
+msgstr "  (используйте «git rebase --continue», когда будете довольны изменениями)"
 
-#: builtin/column.c:32
-msgid "Padding space on right border"
-msgstr "Расстояние отступа справа"
+#: wt-status.c:1394
+msgid "Cherry-pick currently in progress."
+msgstr ""
 
-#: builtin/column.c:33
-msgid "Padding space between columns"
-msgstr "Расстояние отступа между колонками"
+#: wt-status.c:1397
+#, c-format
+msgid "You are currently cherry-picking commit %s."
+msgstr "Вы копируете коммит %s."
 
-#: builtin/column.c:52
-msgid "--command must be the first argument"
-msgstr "параметр --command должен быть первым"
+#: wt-status.c:1404
+msgid "  (fix conflicts and run \"git cherry-pick --continue\")"
+msgstr "  (разрешите конфликты, затем запустите «git cherry-pick --continue»)"
 
-#: builtin/commit.c:39
-msgid "git commit [<options>] [--] <pathspec>..."
-msgstr "git commit [<опции>] [--] <спецификатор-пути>…"
+#: wt-status.c:1407
+msgid "  (run \"git cherry-pick --continue\" to continue)"
+msgstr ""
 
-#: builtin/commit.c:44
-msgid "git status [<options>] [--] <pathspec>..."
-msgstr "git status [<опции>] [--] <спецификатор-пути>…"
+#: wt-status.c:1410
+msgid "  (all conflicts fixed: run \"git cherry-pick --continue\")"
+msgstr "  (все конфликты разрешены: запустите «git cherry-pick --continue»)"
 
-#: builtin/commit.c:49
-msgid ""
-"Your name and email address were configured automatically based\n"
-"on your username and hostname. Please check that they are accurate.\n"
-"You can suppress this message by setting them explicitly. Run the\n"
-"following command and follow the instructions in your editor to edit\n"
-"your configuration file:\n"
-"\n"
-"    git config --global --edit\n"
-"\n"
-"After doing this, you may fix the identity used for this commit with:\n"
-"\n"
-"    git commit --amend --reset-author\n"
-msgstr "Ваше имя или электронная почта настроены автоматически на основании вашего\nимени пользователя и имени машины. Пожалуйста, проверьте, что они \nопределены правильно.\nВы можете отключить это уведомление установив их напрямую. Запустите следующую\nкоманду и следуйте инструкциям вашего текстового редактора, для\nредактирования вашего файла конфигурации:\n\n    git config --global --edit\n\nПосле этого, изменить авторство этой коммита можно будет с помощью команды:\n\n    git commit --amend --reset-author\n"
+#: wt-status.c:1412
+msgid "  (use \"git cherry-pick --abort\" to cancel the cherry-pick operation)"
+msgstr "  (используйте «git cherry-pick --abort», чтобы отменить копирования коммита)"
 
-#: builtin/commit.c:62
-msgid ""
-"Your name and email address were configured automatically based\n"
-"on your username and hostname. Please check that they are accurate.\n"
-"You can suppress this message by setting them explicitly:\n"
-"\n"
-"    git config --global user.name \"Your Name\"\n"
-"    git config --global user.email you@example.com\n"
-"\n"
-"After doing this, you may fix the identity used for this commit with:\n"
-"\n"
-"    git commit --amend --reset-author\n"
-msgstr "Ваше имя или электронная почта настроены автоматически на основании вашего\nимени пользователя и имени машины. Пожалуйста, проверьте, что они \nопределены правильно.\nВы можете отключить это уведомление установив их напрямую:\n\n    git config --global user.name \"Ваше Имя\"\n    git config --global user.email you@example.com\n\nПосле этого, изменить авторство этой коммита можно будет с помощью команды:\n\n    git commit --amend --reset-author\n"
+#: wt-status.c:1422
+msgid "Revert currently in progress."
+msgstr ""
 
-#: builtin/commit.c:74
-msgid ""
-"You asked to amend the most recent commit, but doing so would make\n"
-"it empty. You can repeat your command with --allow-empty, or you can\n"
-"remove the commit entirely with \"git reset HEAD^\".\n"
-msgstr "Вы попросили исправить последний коммит, но делая это вы сделаете\nпустой коммит. Вы можете повторить эту команду с опцией --allow-empty\nили вы можете удалить коммит полностью с помощью команды \n«git reset HEAD^».\n"
+#: wt-status.c:1425
+#, c-format
+msgid "You are currently reverting commit %s."
+msgstr "Вы сейчас обращаете изменения коммита %s."
 
-#: builtin/commit.c:79
-msgid ""
-"The previous cherry-pick is now empty, possibly due to conflict resolution.\n"
-"If you wish to commit it anyway, use:\n"
-"\n"
-"    git commit --allow-empty\n"
-"\n"
-msgstr "Копируемый коммит теперь пуст, возможно после разрешения конфликтов.\nЕсли вы все равно хотите сделать пустой коммит, используйте:\n\n    git commit --allow-empty\n\n"
+#: wt-status.c:1431
+msgid "  (fix conflicts and run \"git revert --continue\")"
+msgstr "  (разрешите конфликты, затем запустите «git revert --continue»)"
 
-#: builtin/commit.c:86
-msgid "Otherwise, please use 'git reset'\n"
-msgstr "В противном случае, используйте «git reset»\n"
+#: wt-status.c:1434
+msgid "  (run \"git revert --continue\" to continue)"
+msgstr ""
 
-#: builtin/commit.c:89
-msgid ""
-"If you wish to skip this commit, use:\n"
-"\n"
-"    git reset\n"
-"\n"
-"Then \"git cherry-pick --continue\" will resume cherry-picking\n"
-"the remaining commits.\n"
-msgstr "Если вы хотите пропустит этот коммит, используйте команду:\n\n    git reset\n\nПосле этого «git cherry-pick --continue» продолжит копирование оставшихся коммитов.\n"
+#: wt-status.c:1437
+msgid "  (all conflicts fixed: run \"git revert --continue\")"
+msgstr "  (все конфликты разрешены: запустите «git revert --continue»)"
 
-#: builtin/commit.c:318
-msgid "failed to unpack HEAD tree object"
-msgstr "сбой распаковки объекта дерева HEAD"
+#: wt-status.c:1439
+msgid "  (use \"git revert --abort\" to cancel the revert operation)"
+msgstr "  (используйте «git revert --abort», чтобы отменить операцию обращения изменений коммита)"
 
-#: builtin/commit.c:359
-msgid "unable to create temporary index"
-msgstr "не удалось создать временный индекс"
+#: wt-status.c:1449
+#, c-format
+msgid "You are currently bisecting, started from branch '%s'."
+msgstr "Вы сейчас в процессе двоичного поиска, начатого с ветки «%s»."
 
-#: builtin/commit.c:365
-msgid "interactive add failed"
-msgstr "сбой интерактивного добавления"
+#: wt-status.c:1453
+msgid "You are currently bisecting."
+msgstr "Вы сейчас в процессе двоичного поиска."
 
-#: builtin/commit.c:378
-msgid "unable to update temporary index"
-msgstr "не удалось обновить временный индекс"
+#: wt-status.c:1456
+msgid "  (use \"git bisect reset\" to get back to the original branch)"
+msgstr "  (используйте «git bisect reset», чтобы вернуться на исходную ветку)"
 
-#: builtin/commit.c:380
-msgid "Failed to update main cache tree"
-msgstr "Сбой при обновлении основного кэша дерева"
+#: wt-status.c:1665
+msgid "On branch "
+msgstr "На ветке "
 
-#: builtin/commit.c:405 builtin/commit.c:429 builtin/commit.c:478
-msgid "unable to write new_index file"
-msgstr "не удалось записать файл new_index"
+#: wt-status.c:1672
+msgid "interactive rebase in progress; onto "
+msgstr "интерактивное перемещение в процессе; над "
 
-#: builtin/commit.c:461
-msgid "cannot do a partial commit during a merge."
-msgstr "нельзя создать частичный коммит во время слияния."
+#: wt-status.c:1674
+msgid "rebase in progress; onto "
+msgstr "перемещение в процессе; над "
 
-#: builtin/commit.c:463
-msgid "cannot do a partial commit during a cherry-pick."
-msgstr "нельзя создать частичный коммит во время копирования коммита."
+#: wt-status.c:1679
+msgid "HEAD detached at "
+msgstr "HEAD отделён на "
 
-#: builtin/commit.c:471
-msgid "cannot read the index"
-msgstr "не удалось прочитать индекс"
+#: wt-status.c:1681
+msgid "HEAD detached from "
+msgstr "HEAD отделён начиная с "
 
-#: builtin/commit.c:490
-msgid "unable to write temporary index file"
-msgstr "не удалось записать временный файл индекса"
+#: wt-status.c:1684
+msgid "Not currently on any branch."
+msgstr "Сейчас ни на одной из веток"
+
+#: wt-status.c:1701
+msgid "Initial commit"
+msgstr "Начальный коммит"
+
+#: wt-status.c:1702
+msgid "No commits yet"
+msgstr "Еще нет коммитов"
+
+#: wt-status.c:1716
+msgid "Untracked files"
+msgstr "Неотслеживаемые файлы"
+
+#: wt-status.c:1718
+msgid "Ignored files"
+msgstr "Игнорируемые файлы"
 
-#: builtin/commit.c:587
+#: wt-status.c:1722
 #, c-format
-msgid "commit '%s' lacks author header"
-msgstr "у коммита «%s» отсутствует автор в заголовке"
+msgid ""
+"It took %.2f seconds to enumerate untracked files. 'status -uno'\n"
+"may speed it up, but you have to be careful not to forget to add\n"
+"new files yourself (see 'git help status')."
+msgstr "%.2f секунды занял вывод списка неотслеживаемых файлов. «status -uno» возможно может ускорить это, но будьте внимательны, и не забудьте добавить новые файлы вручную (смотрите «git help status» для подробностей)."
 
-#: builtin/commit.c:589
+#: wt-status.c:1728
 #, c-format
-msgid "commit '%s' has malformed author line"
-msgstr "у коммита «%s» строка автора в неправильном формате"
+msgid "Untracked files not listed%s"
+msgstr "Неотслеживаемые файлы не показаны%s"
 
-#: builtin/commit.c:608
-msgid "malformed --author parameter"
-msgstr "параметр --author в неправильном формате"
+#: wt-status.c:1730
+msgid " (use -u option to show untracked files)"
+msgstr "(используйте опцию «-u», чтобы показать неотслеживаемые файлы)"
+
+#: wt-status.c:1736
+msgid "No changes"
+msgstr "Нет изменений"
+
+#: wt-status.c:1741
+#, c-format
+msgid "no changes added to commit (use \"git add\" and/or \"git commit -a\")\n"
+msgstr "нет изменений добавленных для коммита\n(используйте «git add» и/или «git commit -a»)\n"
+
+#: wt-status.c:1744
+#, c-format
+msgid "no changes added to commit\n"
+msgstr "нет изменений добавленных для коммита\n"
 
-#: builtin/commit.c:660
+#: wt-status.c:1747
+#, c-format
 msgid ""
-"unable to select a comment character that is not used\n"
-"in the current commit message"
-msgstr "нельзя выбрать символ комментария, который\nне используется в текущем сообщении коммита"
+"nothing added to commit but untracked files present (use \"git add\" to "
+"track)\n"
+msgstr "ничего не добавлено в коммит, но есть неотслеживаемые файлы (используйте «git add», чтобы отслеживать их)\n"
 
-#: builtin/commit.c:697 builtin/commit.c:730 builtin/commit.c:1114
+#: wt-status.c:1750
 #, c-format
-msgid "could not lookup commit %s"
-msgstr "не удалось запросить коммит %s"
+msgid "nothing added to commit but untracked files present\n"
+msgstr "ничего не добавлено в коммит, но есть неотслеживаемые файлы\n"
 
-#: builtin/commit.c:709 builtin/shortlog.c:309
+#: wt-status.c:1753
 #, c-format
-msgid "(reading log message from standard input)\n"
-msgstr "(чтение файла журнала из стандартного ввода)\n"
+msgid "nothing to commit (create/copy files and use \"git add\" to track)\n"
+msgstr "нечего коммитить (создайте/скопируйте файлы, затем запустите «git add», чтобы отслеживать их)\n"
 
-#: builtin/commit.c:711
-msgid "could not read log from standard input"
-msgstr "не удалось прочитать файл журнала из стандартного ввода"
+#: wt-status.c:1756 wt-status.c:1761
+#, c-format
+msgid "nothing to commit\n"
+msgstr "нечего коммитить\n"
 
-#: builtin/commit.c:715
+#: wt-status.c:1759
 #, c-format
-msgid "could not read log file '%s'"
-msgstr "не удалось прочитать файл журнала «%s»"
+msgid "nothing to commit (use -u to show untracked files)\n"
+msgstr "нечего коммитить (используйте опцию «-u», чтобы показать неотслеживаемые файлы)\n"
 
-#: builtin/commit.c:742 builtin/commit.c:750
-msgid "could not read SQUASH_MSG"
-msgstr "не удалось прочитать SQUASH_MSG"
+#: wt-status.c:1763
+#, c-format
+msgid "nothing to commit, working tree clean\n"
+msgstr "нечего коммитить, нет изменений в рабочем каталоге\n"
 
-#: builtin/commit.c:747
-msgid "could not read MERGE_MSG"
-msgstr "не удалось прочитать MERGE_MSG"
+#: wt-status.c:1876
+msgid "No commits yet on "
+msgstr "Еще нет коммитов в"
 
-#: builtin/commit.c:801
-msgid "could not write commit template"
-msgstr "не удалось записать шаблон описания коммита"
+#: wt-status.c:1880
+msgid "HEAD (no branch)"
+msgstr "HEAD (нет ветки)"
+
+#: wt-status.c:1911
+msgid "different"
+msgstr "отличается"
+
+#: wt-status.c:1913 wt-status.c:1921
+msgid "behind "
+msgstr "позади"
 
-#: builtin/commit.c:819
+#: wt-status.c:1916 wt-status.c:1919
+msgid "ahead "
+msgstr "впереди "
+
+#. TRANSLATORS: the action is e.g. "pull with rebase"
+#: wt-status.c:2443
 #, c-format
-msgid ""
-"\n"
-"It looks like you may be committing a merge.\n"
-"If this is not correct, please remove the file\n"
-"\t%s\n"
-"and try again.\n"
-msgstr "\nПохоже, что вы пытаетесь закоммитить слияние.\nЕсли это ошибка, пожалуйста удалите файл\n\t%s\nи попробуйте снова.\n"
+msgid "cannot %s: You have unstaged changes."
+msgstr "не удалось выполнить %s: У вас есть непроиндексированные изменения."
+
+#: wt-status.c:2449
+msgid "additionally, your index contains uncommitted changes."
+msgstr "к тому же, в вашем индексе есть незакоммиченные изменения."
 
-#: builtin/commit.c:824
+#: wt-status.c:2451
 #, c-format
-msgid ""
-"\n"
-"It looks like you may be committing a cherry-pick.\n"
-"If this is not correct, please remove the file\n"
-"\t%s\n"
-"and try again.\n"
-msgstr "\nПохоже, что вы пытаетесь закоммитить при копировании коммита.\nЕсли это не так, то удалите файл\n\t%s\nи попробуйте снова.\n"
+msgid "cannot %s: Your index contains uncommitted changes."
+msgstr "не удалось выполнить %s: В вашем индексе есть незакоммиченные изменения."
+
+#: builtin/add.c:25
+msgid "git add [<options>] [--] <pathspec>..."
+msgstr "git add [<опции>] [--] <спецификатор-пути>…"
 
-#: builtin/commit.c:837
+#: builtin/add.c:84
 #, c-format
-msgid ""
-"Please enter the commit message for your changes. Lines starting\n"
-"with '%c' will be ignored, and an empty message aborts the commit.\n"
-msgstr "Пожалуйста, введите сообщение коммита для ваших изменений. Строки,\nначинающиеся с «%c» будут проигнорированы, а пустое сообщение\nотменяет процесс коммита.\n"
+msgid "unexpected diff status %c"
+msgstr "неожиданный статус утилиты сравнения %c"
 
-#: builtin/commit.c:844
+#: builtin/add.c:89 builtin/commit.c:285
+msgid "updating files failed"
+msgstr "сбой при обновлении файлов"
+
+#: builtin/add.c:99
 #, c-format
-msgid ""
-"Please enter the commit message for your changes. Lines starting\n"
-"with '%c' will be kept; you may remove them yourself if you want to.\n"
-"An empty message aborts the commit.\n"
-msgstr "Пожалуйста, введите сообщение коммита для ваших изменений. Строки,\nначинающиеся с «%c» будут оставлены; вы можете удалить их вручную,\nесли хотите. Пустое сообщение отменяет процесс коммита.\n"
+msgid "remove '%s'\n"
+msgstr "удалить «%s»\n"
+
+#: builtin/add.c:174
+msgid "Unstaged changes after refreshing the index:"
+msgstr "Непроиндексированные изменения после обновления индекса:"
+
+#: builtin/add.c:234 builtin/rev-parse.c:896
+msgid "Could not read the index"
+msgstr "Не удалось прочитать индекс"
 
-#: builtin/commit.c:861
+#: builtin/add.c:245
 #, c-format
-msgid "%sAuthor:    %.*s <%.*s>"
-msgstr "%sАвтор:     %.*s <%.*s>"
+msgid "Could not open '%s' for writing."
+msgstr "Не удалось открыть «%s» для записи."
+
+#: builtin/add.c:249
+msgid "Could not write patch"
+msgstr "Не удалось записать патч"
+
+#: builtin/add.c:252
+msgid "editing patch failed"
+msgstr "сбой при редактировании патча"
+
+#: builtin/add.c:255
+#, c-format
+msgid "Could not stat '%s'"
+msgstr "Не удалось выполнить stat для «%s»"
+
+#: builtin/add.c:257
+msgid "Empty patch. Aborted."
+msgstr "Пустой патч. Операция прервана."
+
+#: builtin/add.c:262
+#, c-format
+msgid "Could not apply '%s'"
+msgstr "Не удалось применить «%s»"
+
+#: builtin/add.c:270
+msgid "The following paths are ignored by one of your .gitignore files:\n"
+msgstr "Следующие пути игнорируются одним из ваших файлов .gitignore:\n"
+
+#: builtin/add.c:290 builtin/clean.c:908 builtin/fetch.c:137 builtin/mv.c:124
+#: builtin/prune-packed.c:56 builtin/pull.c:221 builtin/push.c:560
+#: builtin/remote.c:1345 builtin/rm.c:241 builtin/send-pack.c:165
+msgid "dry run"
+msgstr "пробный запуск"
+
+#: builtin/add.c:293
+msgid "interactive picking"
+msgstr "интерактивный выбор"
+
+#: builtin/add.c:294 builtin/checkout.c:1379 builtin/reset.c:306
+msgid "select hunks interactively"
+msgstr "интерактивный выбор блоков"
+
+#: builtin/add.c:295
+msgid "edit current diff and apply"
+msgstr "отредактировать текущий файл списка изменений и применить его"
+
+#: builtin/add.c:296
+msgid "allow adding otherwise ignored files"
+msgstr "разрешить добавление игнорируемых иначе файлов"
+
+#: builtin/add.c:297
+msgid "update tracked files"
+msgstr "обновить отслеживаемые файлы"
+
+#: builtin/add.c:298
+msgid "renormalize EOL of tracked files (implies -u)"
+msgstr "перенормализировать концы строк (EOL) отслеживаемых файлов (подразумевает -u)"
+
+#: builtin/add.c:299
+msgid "record only the fact that the path will be added later"
+msgstr "записать только факт, что путь будет добавлен позже"
+
+#: builtin/add.c:300
+msgid "add changes from all tracked and untracked files"
+msgstr "добавить изменения из всех отслеживаемых и неотслеживаемых файлов"
+
+#: builtin/add.c:303
+msgid "ignore paths removed in the working tree (same as --no-all)"
+msgstr "игнорировать пути удаленные из рабочего каталога (тоже, что и --no-all)"
+
+#: builtin/add.c:305
+msgid "don't add, only refresh the index"
+msgstr "не добавлять, только обновить индекс"
+
+#: builtin/add.c:306
+msgid "just skip files which cannot be added because of errors"
+msgstr "пропускать файлы, которые не могут быть добавлены из-за ошибок"
+
+#: builtin/add.c:307
+msgid "check if - even missing - files are ignored in dry run"
+msgstr "удостовериться, что даже недостающие файлы будут проигнорированы при  пробном запуске"
+
+#: builtin/add.c:309 builtin/update-index.c:1001
+msgid "override the executable bit of the listed files"
+msgstr "переопределить бит выполнения на указанных файлах"
+
+#: builtin/add.c:311
+msgid "warn when adding an embedded repository"
+msgstr "предупреждать при добавлении встроенного git репозитория"
+
+#: builtin/add.c:326
+#, c-format
+msgid ""
+"You've added another git repository inside your current repository.\n"
+"Clones of the outer repository will not contain the contents of\n"
+"the embedded repository and will not know how to obtain it.\n"
+"If you meant to add a submodule, use:\n"
+"\n"
+"\tgit submodule add <url> %s\n"
+"\n"
+"If you added this path by mistake, you can remove it from the\n"
+"index with:\n"
+"\n"
+"\tgit rm --cached %s\n"
+"\n"
+"See \"git help submodule\" for more information."
+msgstr "Вы добавили другой репозиторий git внутри текущего репозитория\nКлоны внешнего репозитория не будут содержать внутренний\nрепозиторий и не будут знать как его получить.\nЕсли вы хотели добавить подмодуль, то запустите:\n\n\tgit submodule add <url> %s\n\nЕсли бы добавили этот путь по ошибке, то вы можете удалить его\nиз индекса с помощью:\n\n\tgit rm --cached %s\n\nДля дополнительной информации смотрите «git help submodule»."
+
+#: builtin/add.c:354
+#, c-format
+msgid "adding embedded git repository: %s"
+msgstr "добавление встроенного git репозитория: %s"
+
+#: builtin/add.c:372
+#, c-format
+msgid "Use -f if you really want to add them.\n"
+msgstr "Используйте -f, если вы действительно хотите добавить их.\n"
+
+#: builtin/add.c:379
+msgid "adding files failed"
+msgstr "ошибка при добавлении файлов"
+
+#: builtin/add.c:419
+msgid "-A and -u are mutually incompatible"
+msgstr "-A и -u нельзя использовать одновременно"
+
+#: builtin/add.c:426
+msgid "Option --ignore-missing can only be used together with --dry-run"
+msgstr "Опция --ignore-missing может использоваться только вместе с --dry-run"
+
+#: builtin/add.c:430
+#, c-format
+msgid "--chmod param '%s' must be either -x or +x"
+msgstr "параметр --chmod «%s» должен быть -x или +x"
+
+#: builtin/add.c:445
+#, c-format
+msgid "Nothing specified, nothing added.\n"
+msgstr "Ничего не указано, ничего не добавлено.\n"
+
+#: builtin/add.c:446
+#, c-format
+msgid "Maybe you wanted to say 'git add .'?\n"
+msgstr "Возможно, вы имели в виду «git add .»?\n"
+
+#: builtin/am.c:348
+msgid "could not parse author script"
+msgstr "не удалось разобрать сценарий авторства"
+
+#: builtin/am.c:432
+#, c-format
+msgid "'%s' was deleted by the applypatch-msg hook"
+msgstr "«%s» был удален перехватчиком applypatch-msg"
+
+#: builtin/am.c:474
+#, c-format
+msgid "Malformed input line: '%s'."
+msgstr "Неправильная строка ввода: «%s»."
+
+#: builtin/am.c:512
+#, c-format
+msgid "Failed to copy notes from '%s' to '%s'"
+msgstr "Не удалось скопировать заметку из «%s» в «%s»"
+
+#: builtin/am.c:538
+msgid "fseek failed"
+msgstr "сбой при выполнении fseek"
+
+#: builtin/am.c:726
+#, c-format
+msgid "could not parse patch '%s'"
+msgstr "не удалось разобрать патч «%s»"
+
+#: builtin/am.c:791
+msgid "Only one StGIT patch series can be applied at once"
+msgstr "Только серия патчей StGIT может быть применена за раз"
+
+#: builtin/am.c:839
+msgid "invalid timestamp"
+msgstr "недопустимая метка даты/времени"
+
+#: builtin/am.c:844 builtin/am.c:856
+msgid "invalid Date line"
+msgstr "недопустимая строка даты"
+
+#: builtin/am.c:851
+msgid "invalid timezone offset"
+msgstr "недопустимое смещение часового пояса"
+
+#: builtin/am.c:944
+msgid "Patch format detection failed."
+msgstr "Сбой определения формата патча."
+
+#: builtin/am.c:949 builtin/clone.c:409
+#, c-format
+msgid "failed to create directory '%s'"
+msgstr "не удалось создать каталог «%s»"
+
+#: builtin/am.c:954
+msgid "Failed to split patches."
+msgstr "Не удалось разделить патчи на части."
+
+#: builtin/am.c:1084 builtin/commit.c:371
+msgid "unable to write index file"
+msgstr "не удалось записать индекс"
+
+#: builtin/am.c:1098
+#, c-format
+msgid "When you have resolved this problem, run \"%s --continue\"."
+msgstr "Когда вы устраните эту проблему, запустите «%s --continue»."
+
+#: builtin/am.c:1099
+#, c-format
+msgid "If you prefer to skip this patch, run \"%s --skip\" instead."
+msgstr "Если вы хотите пропустить этот патч, то запустите «%s --skip»."
+
+#: builtin/am.c:1100
+#, c-format
+msgid "To restore the original branch and stop patching, run \"%s --abort\"."
+msgstr "Чтобы вернуться на предыдущую ветку и остановить применение изменений, запустите «%s --abort»."
+
+#: builtin/am.c:1183
+msgid ""
+"Patch sent with format=flowed; space at the end of lines might be lost."
+msgstr ""
+
+#: builtin/am.c:1211
+msgid "Patch is empty."
+msgstr "Патч пустой."
+
+#: builtin/am.c:1277
+#, c-format
+msgid "invalid ident line: %.*s"
+msgstr "неправильная строка идентификации: %.*s"
+
+#: builtin/am.c:1299
+#, c-format
+msgid "unable to parse commit %s"
+msgstr "не удалось разобрать коммит %s"
+
+#: builtin/am.c:1495
+msgid "Repository lacks necessary blobs to fall back on 3-way merge."
+msgstr "В репозитории отсутствуют двоичные объекты, необходимые для отката к трехходовому слиянию."
+
+#: builtin/am.c:1497
+msgid "Using index info to reconstruct a base tree..."
+msgstr "Использую индекс для реконструкции базового дерева…"
+
+#: builtin/am.c:1516
+msgid ""
+"Did you hand edit your patch?\n"
+"It does not apply to blobs recorded in its index."
+msgstr "Вы вручную изменяли патч?\nОн не накладывается без ошибок на двоичные объекты, записанные в его заголовке."
+
+#: builtin/am.c:1522
+msgid "Falling back to patching base and 3-way merge..."
+msgstr "Откат к применению изменений к базовому коммиту с помощью трехходового слияния…"
+
+#: builtin/am.c:1548
+msgid "Failed to merge in the changes."
+msgstr "Не удалось слить изменения."
+
+#: builtin/am.c:1580
+msgid "applying to an empty history"
+msgstr "применение к пустой истории"
+
+#: builtin/am.c:1627 builtin/am.c:1631
+#, c-format
+msgid "cannot resume: %s does not exist."
+msgstr "нельзя продолжнить: %s не существует "
+
+#: builtin/am.c:1647
+msgid "cannot be interactive without stdin connected to a terminal."
+msgstr "не удалось использовать интерактивное поведение, без stdin подключенного к терминалу."
+
+#: builtin/am.c:1652
+msgid "Commit Body is:"
+msgstr "Тело коммита:"
+
+#. TRANSLATORS: Make sure to include [y], [n], [e], [v] and [a]
+#. in your translation. The program will only accept English
+#. input at this point.
+#: builtin/am.c:1662
+msgid "Apply? [y]es/[n]o/[e]dit/[v]iew patch/[a]ccept all: "
+msgstr "Применить? [y] - да/[n] - нет/[e] - редактировать/[v] - просмотреть патч/[a] - применить всё: "
+
+#: builtin/am.c:1712
+#, c-format
+msgid "Dirty index: cannot apply patches (dirty: %s)"
+msgstr "Индекс изменён: нельзя применять патчи (изменено: %s)"
+
+#: builtin/am.c:1752 builtin/am.c:1820
+#, c-format
+msgid "Applying: %.*s"
+msgstr "Применение: %.*s"
+
+#: builtin/am.c:1769
+msgid "No changes -- Patch already applied."
+msgstr "Нет изменений — Патч уже применен."
+
+#: builtin/am.c:1775
+#, c-format
+msgid "Patch failed at %s %.*s"
+msgstr "Ошибка применения изменений на %s %.*s"
+
+#: builtin/am.c:1779
+msgid "Use 'git am --show-current-patch' to see the failed patch"
+msgstr ""
+
+#: builtin/am.c:1823
+msgid ""
+"No changes - did you forget to use 'git add'?\n"
+"If there is nothing left to stage, chances are that something else\n"
+"already introduced the same changes; you might want to skip this patch."
+msgstr "Нет изменений — возможно, вы забыли вызвать «git add»?\nЕсли ничего не осталось для индексации, то, скорее всего, что-то другое уже сделало те же изменения; возможно, вам следует пропустить этот патч."
+
+#: builtin/am.c:1830
+msgid ""
+"You still have unmerged paths in your index.\n"
+"You should 'git add' each file with resolved conflicts to mark them as such.\n"
+"You might run `git rm` on a file to accept \"deleted by them\" for it."
+msgstr "У вас есть не слитые пути в индексе.\nВы должны выполнить «git add» для каждого файла с разрешенными конфликтами, чтобы пометить их таковыми.\nВы можете запустить «git rm» с именем файла, чтобы пометить его как «удалено ими»."
+
+#: builtin/am.c:1937 builtin/am.c:1941 builtin/am.c:1953 builtin/reset.c:329
+#: builtin/reset.c:337
+#, c-format
+msgid "Could not parse object '%s'."
+msgstr "Не удалось разобрать объект «%s»."
+
+#: builtin/am.c:1989
+msgid "failed to clean index"
+msgstr "не удалось очистить индекс"
+
+#: builtin/am.c:2033
+msgid ""
+"You seem to have moved HEAD since the last 'am' failure.\n"
+"Not rewinding to ORIG_HEAD"
+msgstr "Похоже, что вы переместили HEAD с момента последней ошибки выполнения «am».\nПеремотка на ORIG_HEAD не выполняется"
+
+#: builtin/am.c:2130
+#, c-format
+msgid "Invalid value for --patch-format: %s"
+msgstr "Неправильное значение для --patch-format: %s"
+
+#: builtin/am.c:2166
+msgid "git am [<options>] [(<mbox> | <Maildir>)...]"
+msgstr "git am [<опции>] [(<mbox> | <Maildir>)…]"
+
+#: builtin/am.c:2167
+msgid "git am [<options>] (--continue | --skip | --abort)"
+msgstr "git am [<опции>] (--continue | --skip | --abort)"
+
+#: builtin/am.c:2173
+msgid "run interactively"
+msgstr "запустить в интерактивном режиме"
+
+#: builtin/am.c:2175
+msgid "historical option -- no-op"
+msgstr "историческая опция — ничего не делает"
+
+#: builtin/am.c:2177
+msgid "allow fall back on 3way merging if needed"
+msgstr "разрешить откатиться к трехходовому слиянию, если нужно"
+
+#: builtin/am.c:2178 builtin/init-db.c:494 builtin/prune-packed.c:58
+#: builtin/repack.c:306 builtin/stash.c:805
+msgid "be quiet"
+msgstr "тихий режим"
+
+#: builtin/am.c:2180
+msgid "add a Signed-off-by line to the commit message"
+msgstr "добавить строку Signed-off-by к сообщению коммита"
+
+#: builtin/am.c:2183
+msgid "recode into utf8 (default)"
+msgstr "перекодировать в utf8 (по умолчанию)"
+
+#: builtin/am.c:2185
+msgid "pass -k flag to git-mailinfo"
+msgstr "передать флаг -k в git-mailinfo"
+
+#: builtin/am.c:2187
+msgid "pass -b flag to git-mailinfo"
+msgstr "передать флаг -b в git-mailinfo"
+
+#: builtin/am.c:2189
+msgid "pass -m flag to git-mailinfo"
+msgstr "передать флаг -m в git-mailinfo"
+
+#: builtin/am.c:2191
+msgid "pass --keep-cr flag to git-mailsplit for mbox format"
+msgstr "передать флаг --keep-cr в git-mailsplit для формата mbox"
+
+#: builtin/am.c:2194
+msgid "do not pass --keep-cr flag to git-mailsplit independent of am.keepcr"
+msgstr "не передавать --keep-cr флаг в git-mailsplit вне зависимости от am.keepcr"
+
+#: builtin/am.c:2197
+msgid "strip everything before a scissors line"
+msgstr "обрезать все до строки обрезки"
+
+#: builtin/am.c:2199 builtin/am.c:2202 builtin/am.c:2205 builtin/am.c:2208
+#: builtin/am.c:2211 builtin/am.c:2214 builtin/am.c:2217 builtin/am.c:2220
+#: builtin/am.c:2226
+msgid "pass it through git-apply"
+msgstr "передать его в git-apply"
+
+#: builtin/am.c:2216 builtin/commit.c:1348 builtin/fmt-merge-msg.c:671
+#: builtin/fmt-merge-msg.c:674 builtin/grep.c:879 builtin/merge.c:247
+#: builtin/pull.c:158 builtin/pull.c:217 builtin/rebase.c:1412
+#: builtin/repack.c:317 builtin/repack.c:321 builtin/repack.c:323
+#: builtin/show-branch.c:651 builtin/show-ref.c:172 builtin/tag.c:397
+#: parse-options.h:141 parse-options.h:162 parse-options.h:311
+msgid "n"
+msgstr "n"
+
+#: builtin/am.c:2222 builtin/branch.c:653 builtin/for-each-ref.c:38
+#: builtin/replace.c:554 builtin/tag.c:431 builtin/verify-tag.c:39
+msgid "format"
+msgstr "формат"
+
+#: builtin/am.c:2223
+msgid "format the patch(es) are in"
+msgstr "формат, в котором находятся патчи"
+
+#: builtin/am.c:2229
+msgid "override error message when patch failure occurs"
+msgstr "переопределить сообщение об ошибке, если не удалось наложить изменения"
+
+#: builtin/am.c:2231
+msgid "continue applying patches after resolving a conflict"
+msgstr "продолжить применение изменений после разрешения конфиликта"
+
+#: builtin/am.c:2234
+msgid "synonyms for --continue"
+msgstr "синоним для --continue"
+
+#: builtin/am.c:2237
+msgid "skip the current patch"
+msgstr "пропустить текущий патч"
+
+#: builtin/am.c:2240
+msgid "restore the original branch and abort the patching operation."
+msgstr "восстановить оригинальную ветку и отменить операцию применения изменений."
+
+#: builtin/am.c:2243
+msgid "abort the patching operation but keep HEAD where it is."
+msgstr ""
+
+#: builtin/am.c:2246
+msgid "show the patch being applied."
+msgstr ""
+
+#: builtin/am.c:2250
+msgid "lie about committer date"
+msgstr "соврать о дате коммитера"
+
+#: builtin/am.c:2252
+msgid "use current timestamp for author date"
+msgstr "использовать текущее время как время авторства"
+
+#: builtin/am.c:2254 builtin/commit-tree.c:120 builtin/commit.c:1491
+#: builtin/merge.c:282 builtin/pull.c:192 builtin/rebase.c:489
+#: builtin/rebase.c:1453 builtin/revert.c:116 builtin/tag.c:412
+msgid "key-id"
+msgstr "key-id"
+
+#: builtin/am.c:2255 builtin/rebase.c:490 builtin/rebase.c:1454
+msgid "GPG-sign commits"
+msgstr "подписать коммиты с помощью GPG"
+
+#: builtin/am.c:2258
+msgid "(internal use for git-rebase)"
+msgstr "(внутреннее использование для git-rebase)"
+
+#: builtin/am.c:2276
+msgid ""
+"The -b/--binary option has been a no-op for long time, and\n"
+"it will be removed. Please do not use it anymore."
+msgstr "Опция -b/--binary уже долгое время ничего не делает и будет удалена с следующих версиях Git. Пожалуйста, не используйте ее."
+
+#: builtin/am.c:2283
+msgid "failed to read the index"
+msgstr "сбой чтения индекса"
+
+#: builtin/am.c:2298
+#, c-format
+msgid "previous rebase directory %s still exists but mbox given."
+msgstr "предыдущий каталог перемещения %s еще существует, но передан mbox."
+
+#: builtin/am.c:2322
+#, c-format
+msgid ""
+"Stray %s directory found.\n"
+"Use \"git am --abort\" to remove it."
+msgstr "Найден забытый каталог %s.\nИспользуйте «git am --abort», чтобы удалить его."
+
+#: builtin/am.c:2328
+msgid "Resolve operation not in progress, we are not resuming."
+msgstr "Операция разрешения конфликтов не в процессе выполнения, не продолжаем."
+
+#: builtin/apply.c:8
+msgid "git apply [<options>] [<patch>...]"
+msgstr "git apply [<опции>] [<патч>…]"
+
+#: builtin/archive.c:17
+#, c-format
+msgid "could not create archive file '%s'"
+msgstr "не удалось создать файл архива «%s»"
+
+#: builtin/archive.c:20
+msgid "could not redirect output"
+msgstr "не удалось перенаправить вывод"
+
+#: builtin/archive.c:37
+msgid "git archive: Remote with no URL"
+msgstr "git archive: внешний репозиторий без URL"
+
+#: builtin/archive.c:61
+msgid "git archive: expected ACK/NAK, got a flush packet"
+msgstr "git archive: ожидается ACK/NAK, получен пакет сброса буфера"
+
+#: builtin/archive.c:64
+#, c-format
+msgid "git archive: NACK %s"
+msgstr "git archive: NACK %s"
+
+#: builtin/archive.c:65
+msgid "git archive: protocol error"
+msgstr "git archive: ошибка протокола"
+
+#: builtin/archive.c:69
+msgid "git archive: expected a flush"
+msgstr "git archive: ожидался сброс буфера"
+
+#: builtin/bisect--helper.c:22
+msgid "git bisect--helper --next-all [--no-checkout]"
+msgstr "git bisect--helper --next-all [--no-checkout]"
+
+#: builtin/bisect--helper.c:23
+msgid "git bisect--helper --write-terms <bad_term> <good_term>"
+msgstr "git bisect--helper --write-terms <плохое-определение> <хорошее-определение>"
+
+#: builtin/bisect--helper.c:24
+msgid "git bisect--helper --bisect-clean-state"
+msgstr "git bisect--helper --bisect-clean-state"
+
+#: builtin/bisect--helper.c:25
+msgid "git bisect--helper --bisect-reset [<commit>]"
+msgstr ""
+
+#: builtin/bisect--helper.c:26
+msgid ""
+"git bisect--helper --bisect-write [--no-log] <state> <revision> <good_term> "
+"<bad_term>"
+msgstr ""
+
+#: builtin/bisect--helper.c:27
+msgid ""
+"git bisect--helper --bisect-check-and-set-terms <command> <good_term> "
+"<bad_term>"
+msgstr ""
+
+#: builtin/bisect--helper.c:28
+msgid "git bisect--helper --bisect-next-check <good_term> <bad_term> [<term>]"
+msgstr ""
+
+#: builtin/bisect--helper.c:29
+msgid ""
+"git bisect--helper --bisect-terms [--term-good | --term-old | --term-bad | "
+"--term-new]"
+msgstr ""
+
+#: builtin/bisect--helper.c:30
+msgid ""
+"git bisect--helper --bisect-start [--term-{old,good}=<term> "
+"--term-{new,bad}=<term>][--no-checkout] [<bad> [<good>...]] [--] "
+"[<paths>...]"
+msgstr ""
+
+#: builtin/bisect--helper.c:86
+#, c-format
+msgid "'%s' is not a valid term"
+msgstr "«%s» не является допустимым определением"
+
+#: builtin/bisect--helper.c:90
+#, c-format
+msgid "can't use the builtin command '%s' as a term"
+msgstr "нельзя использовать встроенную команду «%s» как определение"
+
+#: builtin/bisect--helper.c:100
+#, c-format
+msgid "can't change the meaning of the term '%s'"
+msgstr "нельзя изменить значение определения «%s»"
+
+#: builtin/bisect--helper.c:111
+msgid "please use two different terms"
+msgstr "используйте два разных определения"
+
+#: builtin/bisect--helper.c:118
+msgid "could not open the file BISECT_TERMS"
+msgstr "не удалось открыть файл BISECT_TERMS"
+
+#: builtin/bisect--helper.c:155
+#, c-format
+msgid "We are not bisecting.\n"
+msgstr ""
+
+#: builtin/bisect--helper.c:163
+#, c-format
+msgid "'%s' is not a valid commit"
+msgstr ""
+
+#: builtin/bisect--helper.c:174
+#, c-format
+msgid ""
+"could not check out original HEAD '%s'. Try 'git bisect reset <commit>'."
+msgstr ""
+
+#: builtin/bisect--helper.c:215
+#, c-format
+msgid "Bad bisect_write argument: %s"
+msgstr ""
+
+#: builtin/bisect--helper.c:220
+#, c-format
+msgid "couldn't get the oid of the rev '%s'"
+msgstr ""
+
+#: builtin/bisect--helper.c:232
+#, c-format
+msgid "couldn't open the file '%s'"
+msgstr ""
+
+#: builtin/bisect--helper.c:258
+#, c-format
+msgid "Invalid command: you're currently in a %s/%s bisect"
+msgstr ""
+
+#: builtin/bisect--helper.c:285
+#, c-format
+msgid ""
+"You need to give me at least one %s and %s revision.\n"
+"You can use \"git bisect %s\" and \"git bisect %s\" for that."
+msgstr ""
+
+#: builtin/bisect--helper.c:289
+#, c-format
+msgid ""
+"You need to start by \"git bisect start\".\n"
+"You then need to give me at least one %s and %s revision.\n"
+"You can use \"git bisect %s\" and \"git bisect %s\" for that."
+msgstr ""
+
+#: builtin/bisect--helper.c:321
+#, c-format
+msgid "bisecting only with a %s commit"
+msgstr ""
+
+#. TRANSLATORS: Make sure to include [Y] and [n] in your
+#. translation. The program will only accept English input
+#. at this point.
+#: builtin/bisect--helper.c:329
+msgid "Are you sure [Y/n]? "
+msgstr "Вы уверены [Y - да/n - нет]? "
+
+#: builtin/bisect--helper.c:376
+msgid "no terms defined"
+msgstr "определения не заданы"
+
+#: builtin/bisect--helper.c:379
+#, c-format
+msgid ""
+"Your current terms are %s for the old state\n"
+"and %s for the new state.\n"
+msgstr ""
+
+#: builtin/bisect--helper.c:389
+#, c-format
+msgid ""
+"invalid argument %s for 'git bisect terms'.\n"
+"Supported options are: --term-good|--term-old and --term-bad|--term-new."
+msgstr ""
+
+#: builtin/bisect--helper.c:475
+#, c-format
+msgid "unrecognized option: '%s'"
+msgstr ""
+
+#: builtin/bisect--helper.c:479
+#, c-format
+msgid "'%s' does not appear to be a valid revision"
+msgstr ""
+
+#: builtin/bisect--helper.c:511
+msgid "bad HEAD - I need a HEAD"
+msgstr ""
+
+#: builtin/bisect--helper.c:526
+#, c-format
+msgid "checking out '%s' failed. Try 'git bisect start <valid-branch>'."
+msgstr ""
+
+#: builtin/bisect--helper.c:547
+msgid "won't bisect on cg-seek'ed tree"
+msgstr "нельзя выполнить двоичный поиск на дереве после cg-seek"
+
+#: builtin/bisect--helper.c:550
+msgid "bad HEAD - strange symbolic ref"
+msgstr ""
+
+#: builtin/bisect--helper.c:627
+msgid "perform 'git bisect next'"
+msgstr "выполнить «git bisect next»"
+
+#: builtin/bisect--helper.c:629
+msgid "write the terms to .git/BISECT_TERMS"
+msgstr "записать определения в .git/BISECT_TERMS"
+
+#: builtin/bisect--helper.c:631
+msgid "cleanup the bisection state"
+msgstr "очистить состояние двоичного поиска"
+
+#: builtin/bisect--helper.c:633
+msgid "check for expected revs"
+msgstr "проверить ожидаемые редакции"
+
+#: builtin/bisect--helper.c:635
+msgid "reset the bisection state"
+msgstr ""
+
+#: builtin/bisect--helper.c:637
+msgid "write out the bisection state in BISECT_LOG"
+msgstr ""
+
+#: builtin/bisect--helper.c:639
+msgid "check and set terms in a bisection state"
+msgstr ""
+
+#: builtin/bisect--helper.c:641
+msgid "check whether bad or good terms exist"
+msgstr ""
+
+#: builtin/bisect--helper.c:643
+msgid "print out the bisect terms"
+msgstr ""
+
+#: builtin/bisect--helper.c:645
+msgid "start the bisect session"
+msgstr ""
+
+#: builtin/bisect--helper.c:647
+msgid "update BISECT_HEAD instead of checking out the current commit"
+msgstr "обновить BISECT_HEAD вместо перехода на текущий коммит"
+
+#: builtin/bisect--helper.c:649
+msgid "no log for BISECT_WRITE"
+msgstr ""
+
+#: builtin/bisect--helper.c:666
+msgid "--write-terms requires two arguments"
+msgstr "--write-terms требует указания двух параметров"
+
+#: builtin/bisect--helper.c:670
+msgid "--bisect-clean-state requires no arguments"
+msgstr "--bisect-clean-state не требует указания параметров"
+
+#: builtin/bisect--helper.c:677
+msgid "--bisect-reset requires either no argument or a commit"
+msgstr ""
+
+#: builtin/bisect--helper.c:681
+msgid "--bisect-write requires either 4 or 5 arguments"
+msgstr ""
+
+#: builtin/bisect--helper.c:687
+msgid "--check-and-set-terms requires 3 arguments"
+msgstr ""
+
+#: builtin/bisect--helper.c:693
+msgid "--bisect-next-check requires 2 or 3 arguments"
+msgstr ""
+
+#: builtin/bisect--helper.c:699
+msgid "--bisect-terms requires 0 or 1 argument"
+msgstr ""
+
+#: builtin/blame.c:32
+msgid "git blame [<options>] [<rev-opts>] [<rev>] [--] <file>"
+msgstr "git blame [<опции>] [<опции-редакции>] [<редакция>] [--] <файл>"
+
+#: builtin/blame.c:37
+msgid "<rev-opts> are documented in git-rev-list(1)"
+msgstr "<опции-rev-list> документированы в git-rev-list(1)"
+
+#: builtin/blame.c:407
+#, c-format
+msgid "expecting a color: %s"
+msgstr "ожидается цвет: %s"
+
+#: builtin/blame.c:414
+msgid "must end with a color"
+msgstr "должно заканчиваться на цвет"
+
+#: builtin/blame.c:701
+#, c-format
+msgid "invalid color '%s' in color.blame.repeatedLines"
+msgstr ""
+
+#: builtin/blame.c:719
+msgid "invalid value for blame.coloring"
+msgstr ""
+
+#: builtin/blame.c:794
+msgid "Show blame entries as we find them, incrementally"
+msgstr "Показать записи авторства постепенно, в процессе нахождения"
+
+#: builtin/blame.c:795
+msgid "Show blank SHA-1 for boundary commits (Default: off)"
+msgstr "Не показывать SHA-1 для коммитов, не входящих в границы запроса (По умолчанию: отключено)"
+
+#: builtin/blame.c:796
+msgid "Do not treat root commits as boundaries (Default: off)"
+msgstr "Не воспринимать корневые коммиты как граничные (По умолчанию: отключено)"
+
+#: builtin/blame.c:797
+msgid "Show work cost statistics"
+msgstr "Показать статистику расходов на выполнение запроса"
+
+#: builtin/blame.c:798
+msgid "Force progress reporting"
+msgstr "Принудительно выводить прогресс выполнения"
+
+#: builtin/blame.c:799
+msgid "Show output score for blame entries"
+msgstr "Показать оценку для записей авторства"
+
+#: builtin/blame.c:800
+msgid "Show original filename (Default: auto)"
+msgstr "Показать оригинальное имя файла (По умолчанию: автоматически)"
+
+#: builtin/blame.c:801
+msgid "Show original linenumber (Default: off)"
+msgstr "Показать оригинальные номера строк (По умолчанию: отключено)"
+
+#: builtin/blame.c:802
+msgid "Show in a format designed for machine consumption"
+msgstr "Показать в формате для программного разбора"
+
+#: builtin/blame.c:803
+msgid "Show porcelain format with per-line commit information"
+msgstr "Показать в машиночитаемом формате, с построчной информацией о коммите"
+
+#: builtin/blame.c:804
+msgid "Use the same output mode as git-annotate (Default: off)"
+msgstr "Использовать такой же формат вывода, как и git-annotate (По умолчанию: отключено)"
+
+#: builtin/blame.c:805
+msgid "Show raw timestamp (Default: off)"
+msgstr "Показать необработанные временные метки (По умолчанию: отключено)"
+
+#: builtin/blame.c:806
+msgid "Show long commit SHA1 (Default: off)"
+msgstr "Показать длинный SHA1 идентификатор коммита (По умолчанию: отключено)"
+
+#: builtin/blame.c:807
+msgid "Suppress author name and timestamp (Default: off)"
+msgstr "Не показывать имя автора и временные метки (По умолчанию: отключено)"
+
+#: builtin/blame.c:808
+msgid "Show author email instead of name (Default: off)"
+msgstr "Показать почту автора вместо имени (По умолчанию: отключено)"
+
+#: builtin/blame.c:809
+msgid "Ignore whitespace differences"
+msgstr "Игнорировать различия в пробелах"
+
+#: builtin/blame.c:810
+msgid "color redundant metadata from previous line differently"
+msgstr ""
+
+#: builtin/blame.c:811
+msgid "color lines by age"
+msgstr ""
+
+#: builtin/blame.c:818
+msgid "Use an experimental heuristic to improve diffs"
+msgstr "Использовать эксперементальную эвристику, чтобы улучшить файлы списка изменений"
+
+#: builtin/blame.c:820
+msgid "Spend extra cycles to find better match"
+msgstr "Потратить больше времени, для нахождения лучших совпадений"
+
+#: builtin/blame.c:821
+msgid "Use revisions from <file> instead of calling git-rev-list"
+msgstr "Использовать редакции из <файла> вместо вызова git-rev-list"
+
+#: builtin/blame.c:822
+msgid "Use <file>'s contents as the final image"
+msgstr "Использовать содержимое <файла> как финальный снимок"
+
+#: builtin/blame.c:823 builtin/blame.c:824
+msgid "score"
+msgstr "мин-длина"
+
+#: builtin/blame.c:823
+msgid "Find line copies within and across files"
+msgstr "Найти копирование строк в пределах и между файлами"
+
+#: builtin/blame.c:824
+msgid "Find line movements within and across files"
+msgstr "Найти перемещения строк в пределах и между файлами"
+
+#: builtin/blame.c:825
+msgid "n,m"
+msgstr "начало,конец"
+
+#: builtin/blame.c:825
+msgid "Process only line range n,m, counting from 1"
+msgstr "Обработать только строки в диапазоне начало,конец, начиная с 1"
+
+#: builtin/blame.c:876
+msgid "--progress can't be used with --incremental or porcelain formats"
+msgstr "--progress нельзя использовать одновременно с --incremental или машиночитаемым (porcelain) форматом"
+
+#. TRANSLATORS: This string is used to tell us the
+#. maximum display width for a relative timestamp in
+#. "git blame" output.  For C locale, "4 years, 11
+#. months ago", which takes 22 places, is the longest
+#. among various forms of relative timestamps, but
+#. your language may need more or fewer display
+#. columns.
+#: builtin/blame.c:927
+msgid "4 years, 11 months ago"
+msgstr "4 года и 11 месяцев назад"
+
+#: builtin/blame.c:1031
+#, c-format
+msgid "file %s has only %lu line"
+msgid_plural "file %s has only %lu lines"
+msgstr[0] "файл %s содержит только %lu строку"
+msgstr[1] "файл %s содержит только %lu строки"
+msgstr[2] "файл %s содержит только %lu строк"
+msgstr[3] "файл %s содержит только %lu строки"
+
+#: builtin/blame.c:1077
+msgid "Blaming lines"
+msgstr "Просмотр авторов строк"
+
+#: builtin/branch.c:29
+msgid "git branch [<options>] [-r | -a] [--merged | --no-merged]"
+msgstr "git branch [<опции>] [-r | -a] [--merged | --no-merged]"
+
+#: builtin/branch.c:30
+msgid "git branch [<options>] [-l] [-f] <branch-name> [<start-point>]"
+msgstr "git branch [<опции>] [-l] [-f] <имя-ветки> [<точка-начала>]"
+
+#: builtin/branch.c:31
+msgid "git branch [<options>] [-r] (-d | -D) <branch-name>..."
+msgstr "git branch [<опции>] [-r] (-d | -D) <имя-ветки>…"
+
+#: builtin/branch.c:32
+msgid "git branch [<options>] (-m | -M) [<old-branch>] <new-branch>"
+msgstr "git branch [<опции>] (-m | -M) [<старая-ветка>] <новая-ветка>"
+
+#: builtin/branch.c:33
+msgid "git branch [<options>] (-c | -C) [<old-branch>] <new-branch>"
+msgstr "git branch [<опции>] (-c | -C) [<старая-ветка>] <новая-ветка>"
+
+#: builtin/branch.c:34
+msgid "git branch [<options>] [-r | -a] [--points-at]"
+msgstr "git branch [<опции>] [-r | -a] [--points-at]"
+
+#: builtin/branch.c:35
+msgid "git branch [<options>] [-r | -a] [--format]"
+msgstr "git branch [<опции>] [-r | -a] [--format]"
+
+#: builtin/branch.c:151
+#, c-format
+msgid ""
+"deleting branch '%s' that has been merged to\n"
+"         '%s', but not yet merged to HEAD."
+msgstr "удаление ветки «%s», которая была слита с\n         «%s», но не слита с HEAD."
+
+#: builtin/branch.c:155
+#, c-format
+msgid ""
+"not deleting branch '%s' that is not yet merged to\n"
+"         '%s', even though it is merged to HEAD."
+msgstr "не удаление ветки «%s», которая еще не слита с\n         «%s», хотя уже слита с HEAD."
+
+#: builtin/branch.c:169
+#, c-format
+msgid "Couldn't look up commit object for '%s'"
+msgstr "Не удалось найти объект коммита для «%s»"
+
+#: builtin/branch.c:173
+#, c-format
+msgid ""
+"The branch '%s' is not fully merged.\n"
+"If you are sure you want to delete it, run 'git branch -D %s'."
+msgstr "Ветка «%s» не слита полностью.\nЕсли вы уверены, что хотите ее удалить, запустите «git branch -D %s»."
+
+#: builtin/branch.c:186
+msgid "Update of config-file failed"
+msgstr "Не удалось обновить файл конфигурации"
+
+#: builtin/branch.c:217
+msgid "cannot use -a with -d"
+msgstr "нельзя использовать одновременно ключи -a и -d"
+
+#: builtin/branch.c:223
+msgid "Couldn't look up commit object for HEAD"
+msgstr "Не удалось найти объект коммита для HEAD"
+
+#: builtin/branch.c:237
+#, c-format
+msgid "Cannot delete branch '%s' checked out at '%s'"
+msgstr "Нельзя удалить ветку «%s» т.к. она активна на «%s»"
+
+#: builtin/branch.c:252
+#, c-format
+msgid "remote-tracking branch '%s' not found."
+msgstr "внешняя отслеживаемая ветка «%s» не найдена."
+
+#: builtin/branch.c:253
+#, c-format
+msgid "branch '%s' not found."
+msgstr "ветка «%s» не найдена."
+
+#: builtin/branch.c:268
+#, c-format
+msgid "Error deleting remote-tracking branch '%s'"
+msgstr "Ошибка удаления внешней отслеживаемой ветки «%s»"
+
+#: builtin/branch.c:269
+#, c-format
+msgid "Error deleting branch '%s'"
+msgstr "Ошибка удаления ветки «%s»"
+
+#: builtin/branch.c:276
+#, c-format
+msgid "Deleted remote-tracking branch %s (was %s).\n"
+msgstr "Внешняя отслеживаемая ветка %s удалена (была %s).\n"
+
+#: builtin/branch.c:277
+#, c-format
+msgid "Deleted branch %s (was %s).\n"
+msgstr "Ветка %s удалена (была %s).\n"
+
+#: builtin/branch.c:421 builtin/tag.c:60
+msgid "unable to parse format string"
+msgstr "не удалось разобрать строку формата"
+
+#: builtin/branch.c:452
+msgid "could not resolve HEAD"
+msgstr ""
+
+#: builtin/branch.c:458
+#, c-format
+msgid "HEAD (%s) points outside of refs/heads/"
+msgstr ""
+
+#: builtin/branch.c:473
+#, c-format
+msgid "Branch %s is being rebased at %s"
+msgstr "Производится перемещение ветки %s на %s"
+
+#: builtin/branch.c:477
+#, c-format
+msgid "Branch %s is being bisected at %s"
+msgstr "Производится двоичный поиск в ветке %s на %s"
+
+#: builtin/branch.c:494
+msgid "cannot copy the current branch while not on any."
+msgstr "невозможно скопировать текущую ветку, если вы не находитесь ни на одной из веток."
+
+#: builtin/branch.c:496
+msgid "cannot rename the current branch while not on any."
+msgstr "невозможно переименовать текущую ветку, если вы не находитесь ни на одной из них."
+
+#: builtin/branch.c:507
+#, c-format
+msgid "Invalid branch name: '%s'"
+msgstr "Недействительное имя ветки: «%s»"
+
+#: builtin/branch.c:534
+msgid "Branch rename failed"
+msgstr "Сбой переименования ветки"
+
+#: builtin/branch.c:536
+msgid "Branch copy failed"
+msgstr "Сбой копирования ветки"
+
+#: builtin/branch.c:540
+#, c-format
+msgid "Created a copy of a misnamed branch '%s'"
+msgstr "Создана копия неправильно названной ветки «%s»"
+
+#: builtin/branch.c:543
+#, c-format
+msgid "Renamed a misnamed branch '%s' away"
+msgstr "Переименована неправильно названная ветка «%s»"
+
+#: builtin/branch.c:549
+#, c-format
+msgid "Branch renamed to %s, but HEAD is not updated!"
+msgstr "Ветка переименована в %s, но HEAD не обновлен!"
+
+#: builtin/branch.c:558
+msgid "Branch is renamed, but update of config-file failed"
+msgstr "Ветка переименована, но произошел сбой обновления файла конфигурации"
+
+#: builtin/branch.c:560
+msgid "Branch is copied, but update of config-file failed"
+msgstr "Ветка скопирована, но произошел сбой обновления файла конфигурации"
+
+#: builtin/branch.c:576
+#, c-format
+msgid ""
+"Please edit the description for the branch\n"
+"  %s\n"
+"Lines starting with '%c' will be stripped.\n"
+msgstr "Измените описание для ветки:\n  %s\nСтроки, начинающиеся с «%c» будут вырезаны.\n"
+
+#: builtin/branch.c:610
+msgid "Generic options"
+msgstr "Общие параметры"
+
+#: builtin/branch.c:612
+msgid "show hash and subject, give twice for upstream branch"
+msgstr "показывать хеш-сумму и тему, укажите дважды для вышестоящей ветки"
+
+#: builtin/branch.c:613
+msgid "suppress informational messages"
+msgstr "не выводить информационные сообщения"
+
+#: builtin/branch.c:614
+msgid "set up tracking mode (see git-pull(1))"
+msgstr "установить режим отслеживания вышестоящей ветки (см. git-pull(1))"
+
+#: builtin/branch.c:616
+msgid "do not use"
+msgstr "не используйте"
+
+#: builtin/branch.c:618 builtin/rebase.c:485
+msgid "upstream"
+msgstr "вышестоящая"
+
+#: builtin/branch.c:618
+msgid "change the upstream info"
+msgstr "изменить информацию о вышестоящей ветке"
+
+#: builtin/branch.c:619
+msgid "Unset the upstream info"
+msgstr "Убрать информацию о вышестоящей ветке"
+
+#: builtin/branch.c:620
+msgid "use colored output"
+msgstr "использовать цветной вывод"
+
+#: builtin/branch.c:621
+msgid "act on remote-tracking branches"
+msgstr "выполнить действия на отслеживаемых внешних ветках"
+
+#: builtin/branch.c:623 builtin/branch.c:625
+msgid "print only branches that contain the commit"
+msgstr "вывод только веток, которые содержат коммит"
+
+#: builtin/branch.c:624 builtin/branch.c:626
+msgid "print only branches that don't contain the commit"
+msgstr "вывод только веток, которые не содержат коммит"
+
+#: builtin/branch.c:629
+msgid "Specific git-branch actions:"
+msgstr "Специфичные для git-branch действия:"
+
+#: builtin/branch.c:630
+msgid "list both remote-tracking and local branches"
+msgstr "показать список и отслеживаемых и локальных веток"
+
+#: builtin/branch.c:632
+msgid "delete fully merged branch"
+msgstr "удалить полностью слитую ветку"
+
+#: builtin/branch.c:633
+msgid "delete branch (even if not merged)"
+msgstr "удалить ветку (даже никуда не слитую)"
+
+#: builtin/branch.c:634
+msgid "move/rename a branch and its reflog"
+msgstr "переместить/переименовать ветки и ее журнал ссылок"
+
+#: builtin/branch.c:635
+msgid "move/rename a branch, even if target exists"
+msgstr "переместить/переименовать ветку, даже если целевое имя уже существует"
+
+#: builtin/branch.c:636
+msgid "copy a branch and its reflog"
+msgstr "скопировать ветку и её журнал ссылок"
+
+#: builtin/branch.c:637
+msgid "copy a branch, even if target exists"
+msgstr "скопировать ветку, даже если целевое имя уже существует"
+
+#: builtin/branch.c:638
+msgid "list branch names"
+msgstr "показать список имен веток"
+
+#: builtin/branch.c:639
+msgid "show current branch name"
+msgstr ""
+
+#: builtin/branch.c:640
+msgid "create the branch's reflog"
+msgstr "создать журнал ссылок ветки"
+
+#: builtin/branch.c:642
+msgid "edit the description for the branch"
+msgstr "изменить описание ветки"
+
+#: builtin/branch.c:643
+msgid "force creation, move/rename, deletion"
+msgstr "принудительное создание, перемещение или удаление ветки"
+
+#: builtin/branch.c:644
+msgid "print only branches that are merged"
+msgstr "вывод только слитых веток"
+
+#: builtin/branch.c:645
+msgid "print only branches that are not merged"
+msgstr "вывод только не слитых веток"
+
+#: builtin/branch.c:646
+msgid "list branches in columns"
+msgstr "показать список веток по столбцам"
+
+#: builtin/branch.c:649 builtin/for-each-ref.c:42 builtin/notes.c:415
+#: builtin/notes.c:418 builtin/notes.c:581 builtin/notes.c:584
+#: builtin/tag.c:427
+msgid "object"
+msgstr "объект"
+
+#: builtin/branch.c:650
+msgid "print only branches of the object"
+msgstr "вывод только веток, определенного объекта"
+
+#: builtin/branch.c:652 builtin/for-each-ref.c:48 builtin/tag.c:434
+msgid "sorting and filtering are case insensitive"
+msgstr "сортировка и фильтрация не зависят от регистра"
+
+#: builtin/branch.c:653 builtin/for-each-ref.c:38 builtin/tag.c:432
+#: builtin/verify-tag.c:39
+msgid "format to use for the output"
+msgstr "использовать формат для вывода"
+
+#: builtin/branch.c:676 builtin/clone.c:748
+msgid "HEAD not found below refs/heads!"
+msgstr "HEAD не найден в refs/heads!"
+
+#: builtin/branch.c:700
+msgid "--column and --verbose are incompatible"
+msgstr "--column и --verbose нельзя использовать одновременно"
+
+#: builtin/branch.c:715 builtin/branch.c:769 builtin/branch.c:778
+msgid "branch name required"
+msgstr "требуется имя ветки"
+
+#: builtin/branch.c:745
+msgid "Cannot give description to detached HEAD"
+msgstr "Нельзя дать описание отделённому HEAD"
+
+#: builtin/branch.c:750
+msgid "cannot edit description of more than one branch"
+msgstr "нельзя изменить описание более одной ветки за раз"
+
+#: builtin/branch.c:757
+#, c-format
+msgid "No commit on branch '%s' yet."
+msgstr "Еще нет коммита на ветке «%s»."
+
+#: builtin/branch.c:760
+#, c-format
+msgid "No branch named '%s'."
+msgstr "Нет ветки с именем «%s»."
+
+#: builtin/branch.c:775
+msgid "too many branches for a copy operation"
+msgstr "слишком много веток для операции копирования"
+
+#: builtin/branch.c:784
+msgid "too many arguments for a rename operation"
+msgstr "слишком много аргументов для операции переименования"
+
+#: builtin/branch.c:789
+msgid "too many arguments to set new upstream"
+msgstr "слишком много аргументов для указания новой вышестоящей ветки"
+
+#: builtin/branch.c:793
+#, c-format
+msgid ""
+"could not set upstream of HEAD to %s when it does not point to any branch."
+msgstr "невозможно установить вышестоящий репозиторий для HEAD на %s, так как он не указывает ни на одну ветку."
+
+#: builtin/branch.c:796 builtin/branch.c:819
+#, c-format
+msgid "no such branch '%s'"
+msgstr "нет такой ветки «%s»"
+
+#: builtin/branch.c:800
+#, c-format
+msgid "branch '%s' does not exist"
+msgstr "ветка «%s» не существует"
+
+#: builtin/branch.c:813
+msgid "too many arguments to unset upstream"
+msgstr "слишком много аргументов для сброса указания вышестоящей ветки"
+
+#: builtin/branch.c:817
+msgid "could not unset upstream of HEAD when it does not point to any branch."
+msgstr "невозможно убрать вышестоящий репозиторий для HEAD, так как он не указывает ни на одну ветку."
+
+#: builtin/branch.c:823
+#, c-format
+msgid "Branch '%s' has no upstream information"
+msgstr "Ветка «%s» не имеет информации о вышестоящей ветке"
+
+#: builtin/branch.c:833
+msgid "-a and -r options to 'git branch' do not make sense with a branch name"
+msgstr "параметры -a и -r для «git branch» не имеют смысла с указанием имени ветки"
+
+#: builtin/branch.c:836
+msgid ""
+"the '--set-upstream' option is no longer supported. Please use '--track' or "
+"'--set-upstream-to' instead."
+msgstr "опция --set-upstream больше не поддерживается. Вместо неё используйте «--track» или «--set-upstream-to»"
+
+#: builtin/bundle.c:45
+#, c-format
+msgid "%s is okay\n"
+msgstr "%s в порядке\n"
+
+#: builtin/bundle.c:58
+msgid "Need a repository to create a bundle."
+msgstr "Требуется репозиторий для создания пакета."
+
+#: builtin/bundle.c:62
+msgid "Need a repository to unbundle."
+msgstr "Требуется репозиторий для распаковки."
+
+#: builtin/cat-file.c:593
+msgid ""
+"git cat-file (-t [--allow-unknown-type] | -s [--allow-unknown-type] | -e | "
+"-p | <type> | --textconv | --filters) [--path=<path>] <object>"
+msgstr "git cat-file (-t [--allow-unknown-type] | -s [--allow-unknown-type] | -e | -p | <тип> | --textconv | --filters) [--path=<путь>] <объект>"
+
+#: builtin/cat-file.c:594
+msgid ""
+"git cat-file (--batch | --batch-check) [--follow-symlinks] [--textconv | "
+"--filters]"
+msgstr "git cat-file (--batch | --batch-check) [--follow-symlinks] [--textconv | --filters]"
+
+#: builtin/cat-file.c:615
+msgid "only one batch option may be specified"
+msgstr ""
+
+#: builtin/cat-file.c:633
+msgid "<type> can be one of: blob, tree, commit, tag"
+msgstr "<тип> может быть одним из: blob, tree, commit, tag"
+
+#: builtin/cat-file.c:634
+msgid "show object type"
+msgstr "показать тип объекта"
+
+#: builtin/cat-file.c:635
+msgid "show object size"
+msgstr "показать размер объекта"
+
+#: builtin/cat-file.c:637
+msgid "exit with zero when there's no error"
+msgstr "выйти с нулевым кодом возврата, если нет ошибки"
+
+#: builtin/cat-file.c:638
+msgid "pretty-print object's content"
+msgstr "структурированный вывод содержимого объекта"
+
+#: builtin/cat-file.c:640
+msgid "for blob objects, run textconv on object's content"
+msgstr "запустить texconv на содержимом двоичных объектов "
+
+#: builtin/cat-file.c:642
+msgid "for blob objects, run filters on object's content"
+msgstr "запуск фильтров на содержимом двоичных объектов "
+
+#: builtin/cat-file.c:643 git-submodule.sh:936
+msgid "blob"
+msgstr "двоичный объект"
+
+#: builtin/cat-file.c:644
+msgid "use a specific path for --textconv/--filters"
+msgstr "использовать определенный путь для --textconv/--filters"
+
+#: builtin/cat-file.c:646
+msgid "allow -s and -t to work with broken/corrupt objects"
+msgstr "разрешить -s и -t работать с повреждёнными объектами"
+
+#: builtin/cat-file.c:647
+msgid "buffer --batch output"
+msgstr "буфферировать вывод --batch"
+
+#: builtin/cat-file.c:649
+msgid "show info and content of objects fed from the standard input"
+msgstr "показать информацию и содержимое объектов, переданных из стандартного ввода"
+
+#: builtin/cat-file.c:653
+msgid "show info about objects fed from the standard input"
+msgstr "показать информацию об объектах, переданных из стандартного ввода"
+
+#: builtin/cat-file.c:657
+msgid "follow in-tree symlinks (used with --batch or --batch-check)"
+msgstr "переходить по символьным ссылкам внутри дерева (используется с опциями --batch и --batch-check)"
+
+#: builtin/cat-file.c:659
+msgid "show all objects with --batch or --batch-check"
+msgstr "показать все объекты с опциями --batch или --batch-check"
+
+#: builtin/cat-file.c:661
+msgid "do not order --batch-all-objects output"
+msgstr ""
+
+#: builtin/check-attr.c:13
+msgid "git check-attr [-a | --all | <attr>...] [--] <pathname>..."
+msgstr "git check-attr [-a | --all | <атрибут>…] [--] <путь>…"
+
+#: builtin/check-attr.c:14
+msgid "git check-attr --stdin [-z] [-a | --all | <attr>...]"
+msgstr "git check-attr --stdin [-z] [-a | --all | <атрибут>…]"
+
+#: builtin/check-attr.c:21
+msgid "report all attributes set on file"
+msgstr "вывести все атрибуты установленные для файла"
+
+#: builtin/check-attr.c:22
+msgid "use .gitattributes only from the index"
+msgstr "использовать только .gitattributes из индекса"
+
+#: builtin/check-attr.c:23 builtin/check-ignore.c:25 builtin/hash-object.c:102
+msgid "read file names from stdin"
+msgstr "прочитать имена файлов из стандартного ввода"
+
+#: builtin/check-attr.c:25 builtin/check-ignore.c:27
+msgid "terminate input and output records by a NUL character"
+msgstr "окончание ввода и вывода записей по НУЛЕВОМУ символу"
+
+#: builtin/check-ignore.c:21 builtin/checkout.c:1355 builtin/gc.c:538
+#: builtin/worktree.c:499
+msgid "suppress progress reporting"
+msgstr "не выводить прогресс выполнения"
+
+#: builtin/check-ignore.c:29
+msgid "show non-matching input paths"
+msgstr "показать не совпадающие введенные пути"
+
+#: builtin/check-ignore.c:31
+msgid "ignore index when checking"
+msgstr "игнорировать индекс при проверке"
+
+#: builtin/check-ignore.c:160
+msgid "cannot specify pathnames with --stdin"
+msgstr "нельзя указывать пути вместе с параметром --stdin"
+
+#: builtin/check-ignore.c:163
+msgid "-z only makes sense with --stdin"
+msgstr "-z имеет смысл только вместе с параметром --stdin"
+
+#: builtin/check-ignore.c:165
+msgid "no path specified"
+msgstr "не указан путь"
+
+#: builtin/check-ignore.c:169
+msgid "--quiet is only valid with a single pathname"
+msgstr "--quiet можно использовать только при указании одного пути"
+
+#: builtin/check-ignore.c:171
+msgid "cannot have both --quiet and --verbose"
+msgstr "нельзя использовать одновременно --quiet и --verbose"
+
+#: builtin/check-ignore.c:174
+msgid "--non-matching is only valid with --verbose"
+msgstr "--non-matching можно использовать только вместе с --verbose"
+
+#: builtin/check-mailmap.c:9
+msgid "git check-mailmap [<options>] <contact>..."
+msgstr "git check-mailmap [<опции>] <контакт>…"
+
+#: builtin/check-mailmap.c:14
+msgid "also read contacts from stdin"
+msgstr "также читать контакты из стандартного ввода"
+
+#: builtin/check-mailmap.c:25
+#, c-format
+msgid "unable to parse contact: %s"
+msgstr "не удалось разобрать контакт: %s"
+
+#: builtin/check-mailmap.c:48
+msgid "no contacts specified"
+msgstr "не указаны контакты"
+
+#: builtin/checkout-index.c:131
+msgid "git checkout-index [<options>] [--] [<file>...]"
+msgstr "git checkout-index [<опции>] [--] [<файл>…]"
+
+#: builtin/checkout-index.c:148
+msgid "stage should be between 1 and 3 or all"
+msgstr "индекс должен быть между 1 и 3 или all"
+
+#: builtin/checkout-index.c:164
+msgid "check out all files in the index"
+msgstr "переключиться на состояние всех файлов из индекса"
+
+#: builtin/checkout-index.c:165
+msgid "force overwrite of existing files"
+msgstr "принудительная перезапись существующих файлов"
+
+#: builtin/checkout-index.c:167
+msgid "no warning for existing files and files not in index"
+msgstr "не выводить предупреждения для существующих и непроиндексированных файлов"
+
+#: builtin/checkout-index.c:169
+msgid "don't checkout new files"
+msgstr "не создавать новые файлы"
+
+#: builtin/checkout-index.c:171
+msgid "update stat information in the index file"
+msgstr "обновить статистику доступа в файле индекса"
+
+#: builtin/checkout-index.c:175
+msgid "read list of paths from the standard input"
+msgstr "прочитать список путей из стандартного ввода"
+
+#: builtin/checkout-index.c:177
+msgid "write the content to temporary files"
+msgstr "записать содержимое во временные файлы"
+
+#: builtin/checkout-index.c:178 builtin/column.c:31
+#: builtin/submodule--helper.c:1372 builtin/submodule--helper.c:1375
+#: builtin/submodule--helper.c:1383 builtin/submodule--helper.c:1856
+#: builtin/worktree.c:672
+msgid "string"
+msgstr "строка"
+
+#: builtin/checkout-index.c:179
+msgid "when creating files, prepend <string>"
+msgstr "добавить спереди <строку> при создании файлов"
+
+#: builtin/checkout-index.c:181
+msgid "copy out the files from named stage"
+msgstr "копировать файлы из указанного индекса"
+
+#: builtin/checkout.c:32
+msgid "git checkout [<options>] <branch>"
+msgstr "git checkout [<опции>] <ветка>"
+
+#: builtin/checkout.c:33
+msgid "git checkout [<options>] [<branch>] -- <file>..."
+msgstr "git checkout [<опции>] [<ветка>] -- <файл>…"
+
+#: builtin/checkout.c:151 builtin/checkout.c:190
+#, c-format
+msgid "path '%s' does not have our version"
+msgstr "путь «%s» не имеет нашей версии"
+
+#: builtin/checkout.c:153 builtin/checkout.c:192
+#, c-format
+msgid "path '%s' does not have their version"
+msgstr "путь «%s» не имеет их версии"
+
+#: builtin/checkout.c:169
+#, c-format
+msgid "path '%s' does not have all necessary versions"
+msgstr "путь «%s» не имеет всех необходимых версий"
+
+#: builtin/checkout.c:219
+#, c-format
+msgid "path '%s' does not have necessary versions"
+msgstr "путь «%s» не имеет необходимых версий"
+
+#: builtin/checkout.c:237
+#, c-format
+msgid "path '%s': cannot merge"
+msgstr "путь «%s»: не удалось слить"
+
+#: builtin/checkout.c:253
+#, c-format
+msgid "Unable to add merge result for '%s'"
+msgstr "Не удалось добавить результат слияния «%s»"
+
+#: builtin/checkout.c:331 builtin/checkout.c:334 builtin/checkout.c:337
+#: builtin/checkout.c:340
+#, c-format
+msgid "'%s' cannot be used with updating paths"
+msgstr "«%s» нельзя использовать при обновлении путей"
+
+#: builtin/checkout.c:343 builtin/checkout.c:346
+#, c-format
+msgid "'%s' cannot be used with %s"
+msgstr "«%s» нельзя использовать одновременно с %s"
+
+#: builtin/checkout.c:349
+#, c-format
+msgid "Cannot update paths and switch to branch '%s' at the same time."
+msgstr "Нельзя обновлять пути и переключаться на ветку «%s» одновременно."
+
+#: builtin/checkout.c:396 builtin/checkout.c:403
+#, c-format
+msgid "path '%s' is unmerged"
+msgstr "путь «%s» не слит"
+
+#: builtin/checkout.c:442
+#, c-format
+msgid "Recreated %d merge conflict"
+msgid_plural "Recreated %d merge conflicts"
+msgstr[0] ""
+msgstr[1] ""
+msgstr[2] ""
+msgstr[3] ""
+
+#: builtin/checkout.c:447
+#, c-format
+msgid "Updated %d path from %s"
+msgid_plural "Updated %d paths from %s"
+msgstr[0] ""
+msgstr[1] ""
+msgstr[2] ""
+msgstr[3] ""
+
+#: builtin/checkout.c:454
+#, c-format
+msgid "Updated %d path from the index"
+msgid_plural "Updated %d paths from the index"
+msgstr[0] ""
+msgstr[1] ""
+msgstr[2] ""
+msgstr[3] ""
+
+#: builtin/checkout.c:695
+msgid "you need to resolve your current index first"
+msgstr "сначала нужно разрешить конфликты в вашем текущем индексе"
+
+#: builtin/checkout.c:744
+#, c-format
+msgid ""
+"cannot continue with staged changes in the following files:\n"
+"%s"
+msgstr ""
+
+#: builtin/checkout.c:751
+#, c-format
+msgid "staged changes in the following files may be lost: %s"
+msgstr ""
+
+#: builtin/checkout.c:848
+#, c-format
+msgid "Can not do reflog for '%s': %s\n"
+msgstr "Не удалось создать журнал ссылок для «%s»: %s\n"
+
+#: builtin/checkout.c:890
+msgid "HEAD is now at"
+msgstr "HEAD сейчас на"
+
+#: builtin/checkout.c:894 builtin/clone.c:701
+msgid "unable to update HEAD"
+msgstr "не удалось обновить HEAD"
+
+#: builtin/checkout.c:898
+#, c-format
+msgid "Reset branch '%s'\n"
+msgstr "Сброс ветки «%s»\n"
+
+#: builtin/checkout.c:901
+#, c-format
+msgid "Already on '%s'\n"
+msgstr "Уже на «%s»\n"
+
+#: builtin/checkout.c:905
+#, c-format
+msgid "Switched to and reset branch '%s'\n"
+msgstr "Переключение и сброс ветки «%s»\n"
+
+#: builtin/checkout.c:907 builtin/checkout.c:1283
+#, c-format
+msgid "Switched to a new branch '%s'\n"
+msgstr "Переключено на новую ветку «%s»\n"
+
+#: builtin/checkout.c:909
+#, c-format
+msgid "Switched to branch '%s'\n"
+msgstr "Переключено на ветку «%s»\n"
+
+#: builtin/checkout.c:960
+#, c-format
+msgid " ... and %d more.\n"
+msgstr " … и еще %d.\n"
+
+#: builtin/checkout.c:966
+#, c-format
+msgid ""
+"Warning: you are leaving %d commit behind, not connected to\n"
+"any of your branches:\n"
+"\n"
+"%s\n"
+msgid_plural ""
+"Warning: you are leaving %d commits behind, not connected to\n"
+"any of your branches:\n"
+"\n"
+"%s\n"
+msgstr[0] "Предупреждение: вы оставляете позади %d коммит не соединенную ни с одной из ваших веток:\n\n%s\n"
+msgstr[1] "Предупреждение: вы оставляете позади %d коммита не соединенные ни с одной из ваших веток:\n\n%s\n"
+msgstr[2] "Предупреждение: вы оставляете позади %d коммитов не соединенные ни с одной из ваших веток:\n\n%s\n"
+msgstr[3] "Предупреждение: вы оставляете позади %d коммитов не соединенные ни с одной из ваших веток:\n\n%s\n"
+
+#: builtin/checkout.c:985
+#, c-format
+msgid ""
+"If you want to keep it by creating a new branch, this may be a good time\n"
+"to do so with:\n"
+"\n"
+" git branch <new-branch-name> %s\n"
+"\n"
+msgid_plural ""
+"If you want to keep them by creating a new branch, this may be a good time\n"
+"to do so with:\n"
+"\n"
+" git branch <new-branch-name> %s\n"
+"\n"
+msgstr[0] "Если вы хотите сохранить их с помощью создания новой ветки, то сейчас самое время\nсделать это с помощью:\n\n git branch <имя-новой-ветки> %s\n"
+msgstr[1] "Если вы хотите сохранить их с помощью создания новой ветки, то сейчас самое время\nсделать это с помощью:\n\n git branch <имя-новой-ветки> %s\n"
+msgstr[2] "Если вы хотите сохранить их с помощью создания новой ветки, то сейчас самое время\nсделать это с помощью:\n\n git branch <имя-новой-ветки> %s\n"
+msgstr[3] "Если вы хотите сохранить их с помощью создания новой ветки, то сейчас самое время\nсделать это с помощью:\n\n git branch <имя-новой-ветки> %s\n"
+
+#: builtin/checkout.c:1017
+msgid "internal error in revision walk"
+msgstr "внутренняя ошибка при хождении по редакциям"
+
+#: builtin/checkout.c:1021
+msgid "Previous HEAD position was"
+msgstr "Предыдущая позиция HEAD была"
+
+#: builtin/checkout.c:1052 builtin/checkout.c:1278
+msgid "You are on a branch yet to be born"
+msgstr "Вы находитесь на еще не созданной ветке"
+
+#: builtin/checkout.c:1173
+#, c-format
+msgid "only one reference expected, %d given."
+msgstr "ожидается только одна ссылка, а передано %d."
+
+#: builtin/checkout.c:1209
+#, c-format
+msgid ""
+"'%s' could be both a local file and a tracking branch.\n"
+"Please use -- (and optionally --no-guess) to disambiguate"
+msgstr ""
+
+#: builtin/checkout.c:1222 builtin/worktree.c:290 builtin/worktree.c:448
+#, c-format
+msgid "invalid reference: %s"
+msgstr "неправильная ссылка: %s"
+
+#: builtin/checkout.c:1251
+#, c-format
+msgid "reference is not a tree: %s"
+msgstr "в дереве нет такой ссылки: %s"
+
+#: builtin/checkout.c:1292
+msgid "paths cannot be used with switching branches"
+msgstr "нельзя использовать пути при переключении веток"
+
+#: builtin/checkout.c:1295 builtin/checkout.c:1299 builtin/checkout.c:1303
+#, c-format
+msgid "'%s' cannot be used with switching branches"
+msgstr "нельзя использовать «%s» при переключении веток"
+
+#: builtin/checkout.c:1307 builtin/checkout.c:1310 builtin/checkout.c:1315
+#: builtin/checkout.c:1318
+#, c-format
+msgid "'%s' cannot be used with '%s'"
+msgstr "«%s» нельзя использовать одновременно с «%s»"
+
+#: builtin/checkout.c:1323
+#, c-format
+msgid "Cannot switch branch to a non-commit '%s'"
+msgstr "Нельзя переключить ветку на не коммит «%s»"
+
+#: builtin/checkout.c:1356 builtin/checkout.c:1358 builtin/clone.c:118
+#: builtin/remote.c:169 builtin/remote.c:171 builtin/worktree.c:492
+#: builtin/worktree.c:494
+msgid "branch"
+msgstr "ветка"
+
+#: builtin/checkout.c:1357
+msgid "create and checkout a new branch"
+msgstr "создать и переключиться на новую ветку"
+
+#: builtin/checkout.c:1359
+msgid "create/reset and checkout a branch"
+msgstr "создать/сбросить и перключиться на новую ветку"
+
+#: builtin/checkout.c:1360
+msgid "create reflog for new branch"
+msgstr "создать журнал ссылок для новой ветки"
+
+#: builtin/checkout.c:1361 builtin/worktree.c:496
+msgid "detach HEAD at named commit"
+msgstr "отсоединить HEAD на указанном коммите"
+
+#: builtin/checkout.c:1362
+msgid "set upstream info for new branch"
+msgstr "установить информацию о вышестоящей ветке для новой ветки"
+
+#: builtin/checkout.c:1364
+msgid "new-branch"
+msgstr "новая-ветка"
+
+#: builtin/checkout.c:1364
+msgid "new unparented branch"
+msgstr "новая ветка без родителей"
+
+#: builtin/checkout.c:1366
+msgid "checkout our version for unmerged files"
+msgstr "переключиться на нашу версию для не слитых файлов"
+
+#: builtin/checkout.c:1369
+msgid "checkout their version for unmerged files"
+msgstr "переключиться на их версию для не слитых файлов"
+
+#: builtin/checkout.c:1371
+msgid "force checkout (throw away local modifications)"
+msgstr "принудительное переключение на состояние (отбрасывает все локальные изменения)"
+
+#: builtin/checkout.c:1373
+msgid "perform a 3-way merge with the new branch"
+msgstr "выполнить трехходовое слияние с новой веткой"
+
+#: builtin/checkout.c:1375 builtin/merge.c:284
+msgid "update ignored files (default)"
+msgstr "обновить игнорируемые файлы (по умолчанию)"
+
+#: builtin/checkout.c:1377 builtin/log.c:1594 parse-options.h:317
+msgid "style"
+msgstr "стиль"
+
+#: builtin/checkout.c:1378
+msgid "conflict style (merge or diff3)"
+msgstr "стиль конфликтов слияния (merge или diff3)"
+
+#: builtin/checkout.c:1381
+msgid "do not limit pathspecs to sparse entries only"
+msgstr "не ограничивать спецификаторы пути только частичными записями"
+
+#: builtin/checkout.c:1383
+msgid "do not second guess 'git checkout <no-such-branch>'"
+msgstr ""
+
+#: builtin/checkout.c:1385
+msgid "do not check if another worktree is holding the given ref"
+msgstr "не проверять, что другое дерево уже содержит указанную ссылку"
+
+#: builtin/checkout.c:1389 builtin/clone.c:88 builtin/fetch.c:141
+#: builtin/merge.c:281 builtin/pull.c:136 builtin/push.c:575
+#: builtin/send-pack.c:174
+msgid "force progress reporting"
+msgstr "принудительно выводить прогресс"
+
+#: builtin/checkout.c:1390
+msgid "use overlay mode (default)"
+msgstr ""
+
+#: builtin/checkout.c:1422
+msgid "-b, -B and --orphan are mutually exclusive"
+msgstr "-b, -B и --orphan нельзя использовать одновременно"
+
+#: builtin/checkout.c:1425
+msgid "-p and --overlay are mutually exclusive"
+msgstr ""
+
+#: builtin/checkout.c:1442
+msgid "--track needs a branch name"
+msgstr "--track требует имя ветки"
+
+#: builtin/checkout.c:1447
+msgid "missing branch name; try -b"
+msgstr "пропущено имя ветки; попробуйте -b"
+
+#: builtin/checkout.c:1484
+msgid "invalid path specification"
+msgstr "недопустимый спецификатор пути"
+
+#: builtin/checkout.c:1491
+#, c-format
+msgid "'%s' is not a commit and a branch '%s' cannot be created from it"
+msgstr "«%s» не является коммитом, поэтому невозможно создать из него ветку «%s»"
+
+#: builtin/checkout.c:1495
+#, c-format
+msgid "git checkout: --detach does not take a path argument '%s'"
+msgstr "git checkout: --detach не принимает путь «%s» как аргумент"
+
+#: builtin/checkout.c:1499
+msgid ""
+"git checkout: --ours/--theirs, --force and --merge are incompatible when\n"
+"checking out of the index."
+msgstr "git checkout: --ours/--theirs, --force and --merge нельзя использовать одновременно при применении состояния индекса."
+
+#: builtin/checkout.c:1519
+#, c-format
+msgid ""
+"'%s' matched more than one remote tracking branch.\n"
+"We found %d remotes with a reference that matched. So we fell back\n"
+"on trying to resolve the argument as a path, but failed there too!\n"
+"\n"
+"If you meant to check out a remote tracking branch on, e.g. 'origin',\n"
+"you can do so by fully qualifying the name with the --track option:\n"
+"\n"
+"    git checkout --track origin/<name>\n"
+"\n"
+"If you'd like to always have checkouts of an ambiguous <name> prefer\n"
+"one remote, e.g. the 'origin' remote, consider setting\n"
+"checkout.defaultRemote=origin in your config."
+msgstr ""
+
+#: builtin/clean.c:28
+msgid ""
+"git clean [-d] [-f] [-i] [-n] [-q] [-e <pattern>] [-x | -X] [--] <paths>..."
+msgstr "git clean [-d] [-f] [-i] [-n] [-q] [-e <шаблон>] [-x | -X] [--] <пути>…"
+
+#: builtin/clean.c:32
+#, c-format
+msgid "Removing %s\n"
+msgstr "Удаление %s\n"
+
+#: builtin/clean.c:33
+#, c-format
+msgid "Would remove %s\n"
+msgstr "Будет удалено %s\n"
+
+#: builtin/clean.c:34
+#, c-format
+msgid "Skipping repository %s\n"
+msgstr "Пропуск репозитория %s\n"
+
+#: builtin/clean.c:35
+#, c-format
+msgid "Would skip repository %s\n"
+msgstr "Будет пропущен репозиторий %s\n"
+
+#: builtin/clean.c:36
+#, c-format
+msgid "failed to remove %s"
+msgstr "сбой удаления %s"
+
+#: builtin/clean.c:299 git-add--interactive.perl:579
+#, c-format
+msgid ""
+"Prompt help:\n"
+"1          - select a numbered item\n"
+"foo        - select item based on unique prefix\n"
+"           - (empty) select nothing\n"
+msgstr "Справка по выделению:\n1          - выбрать указанный элемент\nfoo        - выбрать элемент с указанным префиксом\n           - (пусто) не выбирать ничего\n"
+
+#: builtin/clean.c:303 git-add--interactive.perl:588
+#, c-format
+msgid ""
+"Prompt help:\n"
+"1          - select a single item\n"
+"3-5        - select a range of items\n"
+"2-3,6-9    - select multiple ranges\n"
+"foo        - select item based on unique prefix\n"
+"-...       - unselect specified items\n"
+"*          - choose all items\n"
+"           - (empty) finish selecting\n"
+msgstr "Справка по выделению:\n1          - выбрать один элемент\n3-5        - выбрать диапазон элементов\n2-3,6-9    - выбрать несколько диапазонов\nfoo        - выбрать элемент с указанным префиксом\n-…       - убрать выделение с указанных элементов\n*          - выбрать все элементы\n           - (пусто) завершить выделение\n"
+
+#: builtin/clean.c:519 git-add--interactive.perl:554
+#: git-add--interactive.perl:559
+#, c-format, perl-format
+msgid "Huh (%s)?\n"
+msgstr "Хм (%s)?\n"
+
+#: builtin/clean.c:661
+#, c-format
+msgid "Input ignore patterns>> "
+msgstr "Шаблоны игнорирования ввода>> "
+
+#: builtin/clean.c:698
+#, c-format
+msgid "WARNING: Cannot find items matched by: %s"
+msgstr "ПРЕДУПРЕЖДЕНИЕ: Не удалось найти элементы соответствующие: %s"
+
+#: builtin/clean.c:719
+msgid "Select items to delete"
+msgstr "Укажите элементы для удаления"
+
+#. TRANSLATORS: Make sure to keep [y/N] as is
+#: builtin/clean.c:760
+#, c-format
+msgid "Remove %s [y/N]? "
+msgstr "Удалить %s [y - да/N - нет]? "
+
+#: builtin/clean.c:785 git-add--interactive.perl:1717
+#, c-format
+msgid "Bye.\n"
+msgstr "До свидания.\n"
+
+#: builtin/clean.c:793
+msgid ""
+"clean               - start cleaning\n"
+"filter by pattern   - exclude items from deletion\n"
+"select by numbers   - select items to be deleted by numbers\n"
+"ask each            - confirm each deletion (like \"rm -i\")\n"
+"quit                - stop cleaning\n"
+"help                - this screen\n"
+"?                   - help for prompt selection"
+msgstr "clean               - начать очистку\nfilter by pattern   - исключить удаление элементов\nselect by numbers   - исключить удаление элементов по номерам\nask each            - запрашивать подтверждение на удаление каждого элемента (как «rm -i»)\nquit                - прекратить очистку\nhelp                - этот экран\n?                   - справка по выделению"
+
+#: builtin/clean.c:820 git-add--interactive.perl:1793
+msgid "*** Commands ***"
+msgstr "*** Команды ***"
+
+#: builtin/clean.c:821 git-add--interactive.perl:1790
+msgid "What now"
+msgstr "Что теперь"
+
+#: builtin/clean.c:829
+msgid "Would remove the following item:"
+msgid_plural "Would remove the following items:"
+msgstr[0] "Удалить следующие элементы:"
+msgstr[1] "Удалить следующие элементы:"
+msgstr[2] "Удалить следующие элементы:"
+msgstr[3] "Удалить следующие элементы:"
+
+#: builtin/clean.c:845
+msgid "No more files to clean, exiting."
+msgstr "Больше нет файлов для очистки, выходим."
+
+#: builtin/clean.c:907
+msgid "do not print names of files removed"
+msgstr "не выводить имена удаляемых файлов"
+
+#: builtin/clean.c:909
+msgid "force"
+msgstr "принудительно"
+
+#: builtin/clean.c:910
+msgid "interactive cleaning"
+msgstr "интерактивная очистка"
+
+#: builtin/clean.c:912
+msgid "remove whole directories"
+msgstr "удалить каталоги полностью"
+
+#: builtin/clean.c:913 builtin/describe.c:546 builtin/describe.c:548
+#: builtin/grep.c:897 builtin/log.c:171 builtin/log.c:173
+#: builtin/ls-files.c:557 builtin/name-rev.c:417 builtin/name-rev.c:419
+#: builtin/show-ref.c:179
+msgid "pattern"
+msgstr "шаблон"
+
+#: builtin/clean.c:914
+msgid "add <pattern> to ignore rules"
+msgstr "добавить <шаблон> в правила игнорирования"
+
+#: builtin/clean.c:915
+msgid "remove ignored files, too"
+msgstr "также удалить игнорируемые файлы"
+
+#: builtin/clean.c:917
+msgid "remove only ignored files"
+msgstr "удалить только игнорируемые файлы"
+
+#: builtin/clean.c:935
+msgid "-x and -X cannot be used together"
+msgstr "нельзя использовать одновременно -x и -X"
+
+#: builtin/clean.c:939
+msgid ""
+"clean.requireForce set to true and neither -i, -n, nor -f given; refusing to"
+" clean"
+msgstr "clean.requireForce установлен как true и ни одна из опций -i, -n или -f не указана; отказ очистки"
+
+#: builtin/clean.c:942
+msgid ""
+"clean.requireForce defaults to true and neither -i, -n, nor -f given; "
+"refusing to clean"
+msgstr "clean.requireForce установлен по умолчанию как true и ни одна из опций -i, -n или -f не указана; отказ очистки"
+
+#: builtin/clone.c:44
+msgid "git clone [<options>] [--] <repo> [<dir>]"
+msgstr "git clone [<опции>] [--] <репозиторий> [<каталог>]"
+
+#: builtin/clone.c:90
+msgid "don't create a checkout"
+msgstr "не переключать рабочую копию на HEAD"
+
+#: builtin/clone.c:91 builtin/clone.c:93 builtin/init-db.c:489
+msgid "create a bare repository"
+msgstr "создать голый репозиторий"
+
+#: builtin/clone.c:95
+msgid "create a mirror repository (implies bare)"
+msgstr "создать зеркало репозитория (включает в себя и параметр bare)"
+
+#: builtin/clone.c:97
+msgid "to clone from a local repository"
+msgstr "для клонирования из локального репозитория"
+
+#: builtin/clone.c:99
+msgid "don't use local hardlinks, always copy"
+msgstr "не использовать жесткие ссылки, всегда копировать файлы"
+
+#: builtin/clone.c:101
+msgid "setup as shared repository"
+msgstr "настроить как общедоступный репозиторий"
+
+#: builtin/clone.c:104
+msgid "pathspec"
+msgstr "спецификатор-пути"
+
+#: builtin/clone.c:104
+msgid "initialize submodules in the clone"
+msgstr "инициализировать подмодули в клоне"
+
+#: builtin/clone.c:107
+msgid "number of submodules cloned in parallel"
+msgstr "количество подмодулей, которые будут клонированы парралельно"
+
+#: builtin/clone.c:108 builtin/init-db.c:486
+msgid "template-directory"
+msgstr "каталог-шаблонов"
+
+#: builtin/clone.c:109 builtin/init-db.c:487
+msgid "directory from which templates will be used"
+msgstr "каталог, шаблоны из которого будут использованы"
+
+#: builtin/clone.c:111 builtin/clone.c:113 builtin/submodule--helper.c:1379
+#: builtin/submodule--helper.c:1859
+msgid "reference repository"
+msgstr "ссылаемый репозиторий"
+
+#: builtin/clone.c:115 builtin/submodule--helper.c:1381
+#: builtin/submodule--helper.c:1861
+msgid "use --reference only while cloning"
+msgstr "используйте --reference только при клонировании"
+
+#: builtin/clone.c:116 builtin/column.c:27 builtin/merge-file.c:46
+#: builtin/pack-objects.c:3306 builtin/repack.c:329
+msgid "name"
+msgstr "имя"
+
+#: builtin/clone.c:117
+msgid "use <name> instead of 'origin' to track upstream"
+msgstr "использовать <имя> вместо «origin» для отслеживания вышестоящего репозитория"
+
+#: builtin/clone.c:119
+msgid "checkout <branch> instead of the remote's HEAD"
+msgstr "переключиться на <ветку>, вместо HEAD внешнего репозитория"
+
+#: builtin/clone.c:121
+msgid "path to git-upload-pack on the remote"
+msgstr "путь к git-upload-pack на внешнем репозитории"
+
+#: builtin/clone.c:122 builtin/fetch.c:142 builtin/grep.c:836
+#: builtin/pull.c:225
+msgid "depth"
+msgstr "глубина"
+
+#: builtin/clone.c:123
+msgid "create a shallow clone of that depth"
+msgstr "сделать частичный клон указанной глубины"
+
+#: builtin/clone.c:124 builtin/fetch.c:144 builtin/pack-objects.c:3295
+msgid "time"
+msgstr "время"
+
+#: builtin/clone.c:125
+msgid "create a shallow clone since a specific time"
+msgstr "сделать частичный клон до определенного времени"
+
+#: builtin/clone.c:126 builtin/fetch.c:146 builtin/fetch.c:169
+#: builtin/rebase.c:1389
+msgid "revision"
+msgstr "редакция"
+
+#: builtin/clone.c:127 builtin/fetch.c:147
+msgid "deepen history of shallow clone, excluding rev"
+msgstr "углубить историю частичного клона исключая редакцию"
+
+#: builtin/clone.c:129
+msgid "clone only one branch, HEAD or --branch"
+msgstr "клонировать только одну ветку, HEAD или --branch"
+
+#: builtin/clone.c:131
+msgid "don't clone any tags, and make later fetches not to follow them"
+msgstr "не клонировать метки, а также настроить, чтобы не клонировались и в дальнейшем"
+
+#: builtin/clone.c:133
+msgid "any cloned submodules will be shallow"
+msgstr "все склонированные подмодули будут частичными клонами"
+
+#: builtin/clone.c:134 builtin/init-db.c:495
+msgid "gitdir"
+msgstr "каталог-git"
+
+#: builtin/clone.c:135 builtin/init-db.c:496
+msgid "separate git dir from working tree"
+msgstr "разместить каталог git отдельно от рабочей копии"
+
+#: builtin/clone.c:136
+msgid "key=value"
+msgstr "ключ=значение"
+
+#: builtin/clone.c:137
+msgid "set config inside the new repository"
+msgstr "установить параметры внутри нового репозитория"
+
+#: builtin/clone.c:139 builtin/fetch.c:164 builtin/ls-remote.c:76
+#: builtin/push.c:585 builtin/send-pack.c:172
+msgid "server-specific"
+msgstr "зависит-от-сервера"
+
+#: builtin/clone.c:139 builtin/fetch.c:164 builtin/ls-remote.c:76
+#: builtin/push.c:585 builtin/send-pack.c:173
+msgid "option to transmit"
+msgstr "передаваемые опции"
+
+#: builtin/clone.c:140 builtin/fetch.c:165 builtin/pull.c:238
+#: builtin/push.c:586
+msgid "use IPv4 addresses only"
+msgstr "использовать только IPv4 адреса"
+
+#: builtin/clone.c:142 builtin/fetch.c:167 builtin/pull.c:241
+#: builtin/push.c:588
+msgid "use IPv6 addresses only"
+msgstr "использовать только IPv6 адреса"
+
+#: builtin/clone.c:280
+msgid ""
+"No directory name could be guessed.\n"
+"Please specify a directory on the command line"
+msgstr "Имя каталога не может быть угадано.\nУкажите имя каталога с помощью параметра командной строки"
+
+#: builtin/clone.c:333
+#, c-format
+msgid "info: Could not add alternate for '%s': %s\n"
+msgstr "информация: Не удалось добавить альтернативу для «%s»: %s\n"
+
+#: builtin/clone.c:405
+#, c-format
+msgid "failed to open '%s'"
+msgstr "не удалось открыть «%s»"
+
+#: builtin/clone.c:413
+#, c-format
+msgid "%s exists and is not a directory"
+msgstr "%s уже существует и не является каталогом"
+
+#: builtin/clone.c:427
+#, c-format
+msgid "failed to stat %s\n"
+msgstr "не удалось выполнить stat %s\n"
+
+#: builtin/clone.c:444
+#, c-format
+msgid "failed to unlink '%s'"
+msgstr "сбой отсоединения «%s»"
+
+#: builtin/clone.c:449
+#, c-format
+msgid "failed to create link '%s'"
+msgstr "не удалось создать ссылку «%s»"
+
+#: builtin/clone.c:453
+#, c-format
+msgid "failed to copy file to '%s'"
+msgstr "не удалось копировать файл в «%s»"
+
+#: builtin/clone.c:479
+#, c-format
+msgid "done.\n"
+msgstr "готово.\n"
+
+#: builtin/clone.c:493
+msgid ""
+"Clone succeeded, but checkout failed.\n"
+"You can inspect what was checked out with 'git status'\n"
+"and retry the checkout with 'git checkout -f HEAD'\n"
+msgstr "Клонирование прошло успешно, но во время переключения состояния произошла ошибка.\nС помощь команды «git status» вы можете просмотреть, какие файлы были обновлены,\nа с помощью «git checkout -f HEAD» можно повторить попытку переключения на ветку \n"
+
+#: builtin/clone.c:570
+#, c-format
+msgid "Could not find remote branch %s to clone."
+msgstr "Не удалось найти внешнюю ветку %s для клонирования."
+
+#: builtin/clone.c:689
+#, c-format
+msgid "unable to update %s"
+msgstr "не удалось обновить %s"
+
+#: builtin/clone.c:739
+msgid "remote HEAD refers to nonexistent ref, unable to checkout.\n"
+msgstr "внешний HEAD ссылается на несуществующую ссылку, нельзя переключиться на такую версию.\n"
+
+#: builtin/clone.c:770
+msgid "unable to checkout working tree"
+msgstr "не удалось переключиться на версию в рабочем каталоге"
+
+#: builtin/clone.c:815
+msgid "unable to write parameters to config file"
+msgstr "не удалось записать параметры в файл конфигурации"
+
+#: builtin/clone.c:878
+msgid "cannot repack to clean up"
+msgstr "не удалось выполнить перепаковку для очистки"
+
+#: builtin/clone.c:880
+msgid "cannot unlink temporary alternates file"
+msgstr "не удалось отсоединить временные альтернативные файлы"
+
+#: builtin/clone.c:920 builtin/receive-pack.c:1952
+msgid "Too many arguments."
+msgstr "Слишком много аргументов."
+
+#: builtin/clone.c:924
+msgid "You must specify a repository to clone."
+msgstr "Вы должны указать репозиторий для клонирования."
+
+#: builtin/clone.c:937
+#, c-format
+msgid "--bare and --origin %s options are incompatible."
+msgstr "--bare и --origin %s нельзя использовать одновременно."
+
+#: builtin/clone.c:940
+msgid "--bare and --separate-git-dir are incompatible."
+msgstr "--bare и --separate-git-dir нельзя использовать одновременно."
+
+#: builtin/clone.c:953
+#, c-format
+msgid "repository '%s' does not exist"
+msgstr "репозиторий «%s» не существует"
+
+#: builtin/clone.c:959 builtin/fetch.c:1610
+#, c-format
+msgid "depth %s is not a positive number"
+msgstr "глубина %s не является положительным числом"
+
+#: builtin/clone.c:969
+#, c-format
+msgid "destination path '%s' already exists and is not an empty directory."
+msgstr "целевой путь «%s» уже существует и не является пустым каталогом."
+
+#: builtin/clone.c:979
+#, c-format
+msgid "working tree '%s' already exists."
+msgstr "рабочий каталог «%s» уже существует."
+
+#: builtin/clone.c:994 builtin/clone.c:1015 builtin/difftool.c:264
+#: builtin/worktree.c:296 builtin/worktree.c:328
+#, c-format
+msgid "could not create leading directories of '%s'"
+msgstr "не удалось создать родительские каталоги для «%s»"
+
+#: builtin/clone.c:999
+#, c-format
+msgid "could not create work tree dir '%s'"
+msgstr "не удалось создать рабочий каталог «%s»"
+
+#: builtin/clone.c:1019
+#, c-format
+msgid "Cloning into bare repository '%s'...\n"
+msgstr "Клонирование в голый репозиторий «%s»…\n"
+
+#: builtin/clone.c:1021
+#, c-format
+msgid "Cloning into '%s'...\n"
+msgstr "Клонирование в «%s»…\n"
+
+#: builtin/clone.c:1045
+msgid ""
+"clone --recursive is not compatible with both --reference and --reference-"
+"if-able"
+msgstr "клонирование с параметром --recursive нельзя использовать одновременно ни с --reference, ни с --reference-if-able"
+
+#: builtin/clone.c:1106
+msgid "--depth is ignored in local clones; use file:// instead."
+msgstr "--depth игнорируется на локальных клонах; вместо этого используйте file://."
+
+#: builtin/clone.c:1108
+msgid "--shallow-since is ignored in local clones; use file:// instead."
+msgstr "--shallow-since игнорируется на локальных клонах; используйте file:// вместо этого."
+
+#: builtin/clone.c:1110
+msgid "--shallow-exclude is ignored in local clones; use file:// instead."
+msgstr "--shallow-exclude игнорируется на локальных клонах; используйте file:// вместо этого."
+
+#: builtin/clone.c:1112
+msgid "--filter is ignored in local clones; use file:// instead."
+msgstr ""
+
+#: builtin/clone.c:1115
+msgid "source repository is shallow, ignoring --local"
+msgstr "исходный репозиторий является частичным, --local игнорируется"
+
+#: builtin/clone.c:1120
+msgid "--local is ignored"
+msgstr "--local игнорируется"
+
+#: builtin/clone.c:1197 builtin/clone.c:1205
+#, c-format
+msgid "Remote branch %s not found in upstream %s"
+msgstr "Внешняя ветка %s не найдена в вышестоящем репозитории %s"
+
+#: builtin/clone.c:1208
+msgid "You appear to have cloned an empty repository."
+msgstr "Похоже, что вы клонировали пустой репозиторий."
+
+#: builtin/column.c:10
+msgid "git column [<options>]"
+msgstr "git column [<опции>]"
+
+#: builtin/column.c:27
+msgid "lookup config vars"
+msgstr "запросить переменные конфигурации"
+
+#: builtin/column.c:28 builtin/column.c:29
+msgid "layout to use"
+msgstr "использовать схему расположения"
+
+#: builtin/column.c:30
+msgid "Maximum width"
+msgstr "Максимальная ширина"
+
+#: builtin/column.c:31
+msgid "Padding space on left border"
+msgstr "Расстояние отступа слева"
+
+#: builtin/column.c:32
+msgid "Padding space on right border"
+msgstr "Расстояние отступа справа"
+
+#: builtin/column.c:33
+msgid "Padding space between columns"
+msgstr "Расстояние отступа между колонками"
+
+#: builtin/column.c:51
+msgid "--command must be the first argument"
+msgstr "параметр --command должен быть первым"
+
+#: builtin/commit-tree.c:18
+msgid ""
+"git commit-tree [(-p <parent>)...] [-S[<keyid>]] [(-m <message>)...] [(-F "
+"<file>)...] <tree>"
+msgstr ""
+
+#: builtin/commit-tree.c:31
+#, c-format
+msgid "duplicate parent %s ignored"
+msgstr ""
+
+#: builtin/commit-tree.c:56 builtin/commit-tree.c:136 builtin/log.c:520
+#, c-format
+msgid "not a valid object name %s"
+msgstr ""
+
+#: builtin/commit-tree.c:93
+#, c-format
+msgid "git commit-tree: failed to open '%s'"
+msgstr ""
+
+#: builtin/commit-tree.c:96
+#, c-format
+msgid "git commit-tree: failed to read '%s'"
+msgstr ""
+
+#: builtin/commit-tree.c:98
+#, c-format
+msgid "git commit-tree: failed to close '%s'"
+msgstr ""
+
+#: builtin/commit-tree.c:111
+msgid "parent"
+msgstr ""
+
+#: builtin/commit-tree.c:112
+msgid "id of a parent commit object"
+msgstr ""
+
+#: builtin/commit-tree.c:114 builtin/commit.c:1480 builtin/merge.c:268
+#: builtin/notes.c:409 builtin/notes.c:575 builtin/stash.c:1473
+#: builtin/tag.c:406
+msgid "message"
+msgstr "сообщение"
+
+#: builtin/commit-tree.c:115 builtin/commit.c:1480
+msgid "commit message"
+msgstr "сообщение коммита"
+
+#: builtin/commit-tree.c:118
+msgid "read commit log message from file"
+msgstr ""
+
+#: builtin/commit-tree.c:121 builtin/commit.c:1492 builtin/merge.c:283
+#: builtin/pull.c:193 builtin/revert.c:117
+msgid "GPG sign commit"
+msgstr "подписать коммит с помощью GPG"
+
+#: builtin/commit-tree.c:133
+msgid "must give exactly one tree"
+msgstr ""
+
+#: builtin/commit-tree.c:140
+msgid "git commit-tree: failed to read"
+msgstr ""
+
+#: builtin/commit.c:41
+msgid "git commit [<options>] [--] <pathspec>..."
+msgstr "git commit [<опции>] [--] <спецификатор-пути>…"
+
+#: builtin/commit.c:46
+msgid "git status [<options>] [--] <pathspec>..."
+msgstr "git status [<опции>] [--] <спецификатор-пути>…"
+
+#: builtin/commit.c:51
+msgid ""
+"You asked to amend the most recent commit, but doing so would make\n"
+"it empty. You can repeat your command with --allow-empty, or you can\n"
+"remove the commit entirely with \"git reset HEAD^\".\n"
+msgstr "Вы попросили исправить последний коммит, но делая это вы сделаете\nпустой коммит. Вы можете повторить эту команду с опцией --allow-empty\nили вы можете удалить коммит полностью с помощью команды \n«git reset HEAD^».\n"
+
+#: builtin/commit.c:56
+msgid ""
+"The previous cherry-pick is now empty, possibly due to conflict resolution.\n"
+"If you wish to commit it anyway, use:\n"
+"\n"
+"    git commit --allow-empty\n"
+"\n"
+msgstr "Копируемый коммит теперь пуст, возможно после разрешения конфликтов.\nЕсли вы все равно хотите сделать пустой коммит, используйте:\n\n    git commit --allow-empty\n\n"
+
+#: builtin/commit.c:63
+msgid "Otherwise, please use 'git reset'\n"
+msgstr "В противном случае, используйте «git reset»\n"
+
+#: builtin/commit.c:66
+msgid ""
+"If you wish to skip this commit, use:\n"
+"\n"
+"    git reset\n"
+"\n"
+"Then \"git cherry-pick --continue\" will resume cherry-picking\n"
+"the remaining commits.\n"
+msgstr "Если вы хотите пропустит этот коммит, используйте команду:\n\n    git reset\n\nПосле этого «git cherry-pick --continue» продолжит копирование оставшихся коммитов.\n"
+
+#: builtin/commit.c:312
+msgid "failed to unpack HEAD tree object"
+msgstr "сбой распаковки объекта дерева HEAD"
+
+#: builtin/commit.c:353
+msgid "unable to create temporary index"
+msgstr "не удалось создать временный индекс"
+
+#: builtin/commit.c:359
+msgid "interactive add failed"
+msgstr "сбой интерактивного добавления"
+
+#: builtin/commit.c:373
+msgid "unable to update temporary index"
+msgstr "не удалось обновить временный индекс"
+
+#: builtin/commit.c:375
+msgid "Failed to update main cache tree"
+msgstr "Сбой при обновлении основного кэша дерева"
+
+#: builtin/commit.c:400 builtin/commit.c:423 builtin/commit.c:469
+msgid "unable to write new_index file"
+msgstr "не удалось записать файл new_index"
+
+#: builtin/commit.c:452
+msgid "cannot do a partial commit during a merge."
+msgstr "нельзя создать частичный коммит во время слияния."
+
+#: builtin/commit.c:454
+msgid "cannot do a partial commit during a cherry-pick."
+msgstr "нельзя создать частичный коммит во время копирования коммита."
+
+#: builtin/commit.c:462
+msgid "cannot read the index"
+msgstr "не удалось прочитать индекс"
+
+#: builtin/commit.c:481
+msgid "unable to write temporary index file"
+msgstr "не удалось записать временный файл индекса"
+
+#: builtin/commit.c:579
+#, c-format
+msgid "commit '%s' lacks author header"
+msgstr "у коммита «%s» отсутствует автор в заголовке"
+
+#: builtin/commit.c:581
+#, c-format
+msgid "commit '%s' has malformed author line"
+msgstr "у коммита «%s» строка автора в неправильном формате"
+
+#: builtin/commit.c:600
+msgid "malformed --author parameter"
+msgstr "параметр --author в неправильном формате"
+
+#: builtin/commit.c:653
+msgid ""
+"unable to select a comment character that is not used\n"
+"in the current commit message"
+msgstr "нельзя выбрать символ комментария, который\nне используется в текущем сообщении коммита"
+
+#: builtin/commit.c:691 builtin/commit.c:724 builtin/commit.c:1069
+#, c-format
+msgid "could not lookup commit %s"
+msgstr "не удалось запросить коммит %s"
+
+#: builtin/commit.c:703 builtin/shortlog.c:319
+#, c-format
+msgid "(reading log message from standard input)\n"
+msgstr "(чтение файла журнала из стандартного ввода)\n"
+
+#: builtin/commit.c:705
+msgid "could not read log from standard input"
+msgstr "не удалось прочитать файл журнала из стандартного ввода"
+
+#: builtin/commit.c:709
+#, c-format
+msgid "could not read log file '%s'"
+msgstr "не удалось прочитать файл журнала «%s»"
+
+#: builtin/commit.c:740 builtin/commit.c:756
+msgid "could not read SQUASH_MSG"
+msgstr "не удалось прочитать SQUASH_MSG"
+
+#: builtin/commit.c:747
+msgid "could not read MERGE_MSG"
+msgstr "не удалось прочитать MERGE_MSG"
+
+#: builtin/commit.c:807
+msgid "could not write commit template"
+msgstr "не удалось записать шаблон описания коммита"
+
+#: builtin/commit.c:826
+#, c-format
+msgid ""
+"\n"
+"It looks like you may be committing a merge.\n"
+"If this is not correct, please remove the file\n"
+"\t%s\n"
+"and try again.\n"
+msgstr "\nПохоже, что вы пытаетесь закоммитить слияние.\nЕсли это ошибка, пожалуйста удалите файл\n\t%s\nи попробуйте снова.\n"
+
+#: builtin/commit.c:831
+#, c-format
+msgid ""
+"\n"
+"It looks like you may be committing a cherry-pick.\n"
+"If this is not correct, please remove the file\n"
+"\t%s\n"
+"and try again.\n"
+msgstr "\nПохоже, что вы пытаетесь закоммитить при копировании коммита.\nЕсли это не так, то удалите файл\n\t%s\nи попробуйте снова.\n"
+
+#: builtin/commit.c:844
+#, c-format
+msgid ""
+"Please enter the commit message for your changes. Lines starting\n"
+"with '%c' will be ignored, and an empty message aborts the commit.\n"
+msgstr "Пожалуйста, введите сообщение коммита для ваших изменений. Строки,\nначинающиеся с «%c» будут проигнорированы, а пустое сообщение\nотменяет процесс коммита.\n"
+
+#: builtin/commit.c:852
+#, c-format
+msgid ""
+"Please enter the commit message for your changes. Lines starting\n"
+"with '%c' will be kept; you may remove them yourself if you want to.\n"
+"An empty message aborts the commit.\n"
+msgstr "Пожалуйста, введите сообщение коммита для ваших изменений. Строки,\nначинающиеся с «%c» будут оставлены; вы можете удалить их вручную,\nесли хотите. Пустое сообщение отменяет процесс коммита.\n"
+
+#: builtin/commit.c:869
+#, c-format
+msgid "%sAuthor:    %.*s <%.*s>"
+msgstr "%sАвтор:     %.*s <%.*s>"
+
+#: builtin/commit.c:877
+#, c-format
+msgid "%sDate:      %s"
+msgstr "%sДата:      %s"
+
+#: builtin/commit.c:884
+#, c-format
+msgid "%sCommitter: %.*s <%.*s>"
+msgstr "%sКоммитер:  %.*s <%.*s>"
+
+#: builtin/commit.c:902
+msgid "Cannot read index"
+msgstr "Не удалось прочитать индекс"
+
+#: builtin/commit.c:969
+msgid "Error building trees"
+msgstr "Ошибка при построении деревьев"
+
+#: builtin/commit.c:983 builtin/tag.c:269
+#, c-format
+msgid "Please supply the message using either -m or -F option.\n"
+msgstr "Пожалуйста, укажите сообщение, при указании опций -m или -F.\n"
+
+#: builtin/commit.c:1027
+#, c-format
+msgid "--author '%s' is not 'Name <email>' and matches no existing author"
+msgstr "--author «%s» не в формате «Имя <почта>» и не совпадает с существующим автором"
+
+#: builtin/commit.c:1041
+#, c-format
+msgid "Invalid ignored mode '%s'"
+msgstr "Недопустимый режим показа игнорируемых файлов «%s»"
+
+#: builtin/commit.c:1059 builtin/commit.c:1284
+#, c-format
+msgid "Invalid untracked files mode '%s'"
+msgstr "Неправильный режим неотслеживаемых файлов «%s»"
+
+#: builtin/commit.c:1097
+msgid "--long and -z are incompatible"
+msgstr "--long и -z нельзя использовать одновременно"
+
+#: builtin/commit.c:1130
+msgid "Using both --reset-author and --author does not make sense"
+msgstr "Указание одновременно опций --reset-author и --author не имеет смысла"
+
+#: builtin/commit.c:1139
+msgid "You have nothing to amend."
+msgstr "Нечего исправлять."
+
+#: builtin/commit.c:1142
+msgid "You are in the middle of a merge -- cannot amend."
+msgstr "Вы в процессе слияния —  сейчас нельзя исправлять."
+
+#: builtin/commit.c:1144
+msgid "You are in the middle of a cherry-pick -- cannot amend."
+msgstr "Вы в процессе копирования коммита —  сейчас нельзя исправлять."
+
+#: builtin/commit.c:1147
+msgid "Options --squash and --fixup cannot be used together"
+msgstr "Опции --squash и --fixup не могут использоваться одновременно"
+
+#: builtin/commit.c:1157
+msgid "Only one of -c/-C/-F/--fixup can be used."
+msgstr "Может использоваться только одна из опций -c/-C/-F/--fixup."
+
+#: builtin/commit.c:1159
+msgid "Option -m cannot be combined with -c/-C/-F."
+msgstr ""
+
+#: builtin/commit.c:1167
+msgid "--reset-author can be used only with -C, -c or --amend."
+msgstr "--reset-author может использоваться только одновременно с опциями -C, -c или --amend."
+
+#: builtin/commit.c:1184
+msgid "Only one of --include/--only/--all/--interactive/--patch can be used."
+msgstr "Может использоваться только одна из опций --include/--only/--all/--interactive/--patch."
+
+#: builtin/commit.c:1186
+msgid "No paths with --include/--only does not make sense."
+msgstr "Указание путей каталогов с опциями --include/--only не имеет смысла."
+
+#: builtin/commit.c:1192
+#, c-format
+msgid "paths '%s ...' with -a does not make sense"
+msgstr ""
+
+#: builtin/commit.c:1319 builtin/commit.c:1503
+msgid "show status concisely"
+msgstr "кратко показать статус"
+
+#: builtin/commit.c:1321 builtin/commit.c:1505
+msgid "show branch information"
+msgstr "показать информацию о версии"
+
+#: builtin/commit.c:1323
+msgid "show stash information"
+msgstr "показать информацию о спрятанном"
+
+#: builtin/commit.c:1325 builtin/commit.c:1507
+msgid "compute full ahead/behind values"
+msgstr ""
+
+#: builtin/commit.c:1327
+msgid "version"
+msgstr "версия"
+
+#: builtin/commit.c:1327 builtin/commit.c:1509 builtin/push.c:561
+#: builtin/worktree.c:643
+msgid "machine-readable output"
+msgstr "машиночитаемый вывод"
+
+#: builtin/commit.c:1330 builtin/commit.c:1511
+msgid "show status in long format (default)"
+msgstr "показать статус в длинном формате (по умолчанию)"
+
+#: builtin/commit.c:1333 builtin/commit.c:1514
+msgid "terminate entries with NUL"
+msgstr "завершать записи НУЛЕВЫМ байтом"
+
+#: builtin/commit.c:1335 builtin/commit.c:1339 builtin/commit.c:1517
+#: builtin/fast-export.c:1085 builtin/fast-export.c:1088 builtin/rebase.c:1465
+#: parse-options.h:331
+msgid "mode"
+msgstr "режим"
+
+#: builtin/commit.c:1336 builtin/commit.c:1517
+msgid "show untracked files, optional modes: all, normal, no. (Default: all)"
+msgstr "показать неотслеживаемые файлы, опциональные режимы: all (все), normal (как обычно), no (нет). (По умолчанию: all)"
+
+#: builtin/commit.c:1340
+msgid ""
+"show ignored files, optional modes: traditional, matching, no. (Default: "
+"traditional)"
+msgstr "показывать игнорируемые файлы, с опциональным режимом: traditional (традиционный), matching (только совпадающие), no (не показывать). (По умолчанию: traditional)"
+
+#: builtin/commit.c:1342 parse-options.h:179
+msgid "when"
+msgstr "когда"
+
+#: builtin/commit.c:1343
+msgid ""
+"ignore changes to submodules, optional when: all, dirty, untracked. "
+"(Default: all)"
+msgstr "игнорировать изменения в подмодулях, опционально когда: all (всегда), dirty (изменённые), untracked (неотслеживаемые). (По умолчанию: all)"
+
+#: builtin/commit.c:1345
+msgid "list untracked files in columns"
+msgstr "показать неотслеживаемые файлы по столбцам"
+
+#: builtin/commit.c:1346
+msgid "do not detect renames"
+msgstr "не определять переименования"
+
+#: builtin/commit.c:1348
+msgid "detect renames, optionally set similarity index"
+msgstr "определять переименования, опционально устанавливать рейтинг сходства"
+
+#: builtin/commit.c:1368
+msgid "Unsupported combination of ignored and untracked-files arguments"
+msgstr "Неподдерживаемая комбинация аргументов отображения игнорируемых и неотслеживаемых файлов"
+
+#: builtin/commit.c:1473
+msgid "suppress summary after successful commit"
+msgstr "не выводить сводку изменений после успешного коммита"
+
+#: builtin/commit.c:1474
+msgid "show diff in commit message template"
+msgstr "добавить список изменений в шаблон сообщения коммита"
+
+#: builtin/commit.c:1476
+msgid "Commit message options"
+msgstr "Опции сообщения коммита"
+
+#: builtin/commit.c:1477 builtin/merge.c:272 builtin/tag.c:408
+msgid "read message from file"
+msgstr "прочитать сообщение из файла"
+
+#: builtin/commit.c:1478
+msgid "author"
+msgstr "автор"
+
+#: builtin/commit.c:1478
+msgid "override author for commit"
+msgstr "подменить автора коммита"
+
+#: builtin/commit.c:1479 builtin/gc.c:539
+msgid "date"
+msgstr "дата"
+
+#: builtin/commit.c:1479
+msgid "override date for commit"
+msgstr "подменить дату коммита"
+
+#: builtin/commit.c:1481 builtin/commit.c:1482 builtin/commit.c:1483
+#: builtin/commit.c:1484 parse-options.h:323 ref-filter.h:92
+msgid "commit"
+msgstr "коммит"
+
+#: builtin/commit.c:1481
+msgid "reuse and edit message from specified commit"
+msgstr "использовать и отредактировать сообщение от указанного коммита"
+
+#: builtin/commit.c:1482
+msgid "reuse message from specified commit"
+msgstr "использовать сообщение указанного коммита"
+
+#: builtin/commit.c:1483
+msgid "use autosquash formatted message to fixup specified commit"
+msgstr "использовать форматированное сообщение автоуплотнения для исправления указанного коммита"
+
+#: builtin/commit.c:1484
+msgid "use autosquash formatted message to squash specified commit"
+msgstr "использовать форматированное сообщение автоуплотнения для уплотнения указанного коммита"
+
+#: builtin/commit.c:1485
+msgid "the commit is authored by me now (used with -C/-c/--amend)"
+msgstr "коммит теперь за моим авторством (используется с -C/-c/--amend)"
+
+#: builtin/commit.c:1486 builtin/log.c:1541 builtin/merge.c:285
+#: builtin/pull.c:162 builtin/revert.c:109
+msgid "add Signed-off-by:"
+msgstr "добавить Signed-off-by:"
+
+#: builtin/commit.c:1487
+msgid "use specified template file"
+msgstr "использовать указанный файл шаблона"
+
+#: builtin/commit.c:1488
+msgid "force edit of commit"
+msgstr "принудительно редактировать коммит"
+
+#: builtin/commit.c:1490
+msgid "include status in commit message template"
+msgstr "включить статус файлов в шаблон сообщения коммита"
+
+#: builtin/commit.c:1495
+msgid "Commit contents options"
+msgstr "Опции содержимого коммита"
+
+#: builtin/commit.c:1496
+msgid "commit all changed files"
+msgstr "закоммитить все измененные файлы"
+
+#: builtin/commit.c:1497
+msgid "add specified files to index for commit"
+msgstr "добавить указанные файлы в индекс для коммита"
+
+#: builtin/commit.c:1498
+msgid "interactively add files"
+msgstr "интерактивное добавление файлов"
+
+#: builtin/commit.c:1499
+msgid "interactively add changes"
+msgstr "интерактивное добавление изменений"
+
+#: builtin/commit.c:1500
+msgid "commit only specified files"
+msgstr "закоммитить только указанные файлы"
+
+#: builtin/commit.c:1501
+msgid "bypass pre-commit and commit-msg hooks"
+msgstr "пропустить перехватчик pre-commit и commit-msg"
+
+#: builtin/commit.c:1502
+msgid "show what would be committed"
+msgstr "показать, что будет закоммичено"
+
+#: builtin/commit.c:1515
+msgid "amend previous commit"
+msgstr "исправить предыдущий коммит"
+
+#: builtin/commit.c:1516
+msgid "bypass post-rewrite hook"
+msgstr "пропустить перехватчик post-rewrite"
+
+#: builtin/commit.c:1521
+msgid "ok to record an empty change"
+msgstr "разрешить запись пустого коммита"
+
+#: builtin/commit.c:1523
+msgid "ok to record a change with an empty message"
+msgstr "разрешить запись изменений с пустым сообщением"
+
+#: builtin/commit.c:1596
+#, c-format
+msgid "Corrupt MERGE_HEAD file (%s)"
+msgstr "Файл MERGE_HEAD поврежден (%s)"
+
+#: builtin/commit.c:1603
+msgid "could not read MERGE_MODE"
+msgstr "не удалось прочитать MERGE_MODE"
+
+#: builtin/commit.c:1622
+#, c-format
+msgid "could not read commit message: %s"
+msgstr "не удалось открыть сообщение коммита: %s"
+
+#: builtin/commit.c:1629
+#, c-format
+msgid "Aborting commit due to empty commit message.\n"
+msgstr "Отмена коммита из-за пустого сообщения коммита.\n"
+
+#: builtin/commit.c:1634
+#, c-format
+msgid "Aborting commit; you did not edit the message.\n"
+msgstr "Отмена коммита; вы не изменили сообщение.\n"
+
+#: builtin/commit.c:1668
+msgid ""
+"repository has been updated, but unable to write\n"
+"new_index file. Check that disk is not full and quota is\n"
+"not exceeded, and then \"git reset HEAD\" to recover."
+msgstr "репозиторий был обновлен, но не удалось записать файл new_index. Удостоверьтесь, что на диске есть свободное место и квота не исчерпана, а после этого запустите «git reset HEAD» для восстановления."
+
+#: builtin/commit-graph.c:10
+msgid "git commit-graph [--object-dir <objdir>]"
+msgstr "git commit-graph [--object-dir <каталог-объектов>]"
+
+#: builtin/commit-graph.c:11 builtin/commit-graph.c:23
+msgid "git commit-graph read [--object-dir <objdir>]"
+msgstr "git commit-graph read [--object-dir <каталог-объектов>]"
+
+#: builtin/commit-graph.c:12 builtin/commit-graph.c:18
+msgid "git commit-graph verify [--object-dir <objdir>]"
+msgstr "git commit-graph verify [--object-dir <каталог-объектов>]"
+
+#: builtin/commit-graph.c:13 builtin/commit-graph.c:28
+msgid ""
+"git commit-graph write [--object-dir <objdir>] [--append] [--reachable"
+"|--stdin-packs|--stdin-commits]"
+msgstr "git commit-graph write [--object-dir <каталог-объектов>] [--append] [--reachable|--stdin-packs|--stdin-commits]"
+
+#: builtin/commit-graph.c:51 builtin/commit-graph.c:89
+#: builtin/commit-graph.c:147 builtin/commit-graph.c:205 builtin/fetch.c:153
+#: builtin/log.c:1561
+msgid "dir"
+msgstr "каталог"
+
+#: builtin/commit-graph.c:52 builtin/commit-graph.c:90
+#: builtin/commit-graph.c:148 builtin/commit-graph.c:206
+msgid "The object directory to store the graph"
+msgstr "Каталог объектов для сохранения графа"
+
+#: builtin/commit-graph.c:68 builtin/commit-graph.c:105
+#, c-format
+msgid "Could not open commit-graph '%s'"
+msgstr "Не удалось открыть файл commit-graph «%s»"
+
+#: builtin/commit-graph.c:150
+msgid "start walk at all refs"
+msgstr "начать со всех ссылок"
+
+#: builtin/commit-graph.c:152
+msgid "scan pack-indexes listed by stdin for commits"
+msgstr "искать коммиты в pack-indexes, перечисленных на стандартном вводе"
+
+#: builtin/commit-graph.c:154
+msgid "start walk at commits listed by stdin"
+msgstr "начать с коммитов, перечисленных на стандартном вводе"
+
+#: builtin/commit-graph.c:156
+msgid "include all commits already in the commit-graph file"
+msgstr "включить все коммиты, которые уже есть в файле commit-graph"
+
+#: builtin/commit-graph.c:165
+msgid "use at most one of --reachable, --stdin-commits, or --stdin-packs"
+msgstr "используйте что-то одно из --reachable, --stdin-commits и --stdin-packs"
+
+#: builtin/config.c:11
+msgid "git config [<options>]"
+msgstr "git config [<опции>]"
+
+#: builtin/config.c:103
+#, c-format
+msgid "unrecognized --type argument, %s"
+msgstr ""
+
+#: builtin/config.c:115
+msgid "only one type at a time"
+msgstr ""
+
+#: builtin/config.c:124
+msgid "Config file location"
+msgstr "Размещение файла конфигурации"
+
+#: builtin/config.c:125
+msgid "use global config file"
+msgstr "использовать глобальный файл конфигурации"
+
+#: builtin/config.c:126
+msgid "use system config file"
+msgstr "использовать системный файл конфигурации"
+
+#: builtin/config.c:127
+msgid "use repository config file"
+msgstr "использовать файл конфигурации репозитория"
+
+#: builtin/config.c:128
+msgid "use per-worktree config file"
+msgstr ""
+
+#: builtin/config.c:129
+msgid "use given config file"
+msgstr "использовать указанный файл конфигурации"
+
+#: builtin/config.c:130
+msgid "blob-id"
+msgstr "идент-двоичн-объекта"
+
+#: builtin/config.c:130
+msgid "read config from given blob object"
+msgstr "прочитать настройки из указанного двоичного объекта"
+
+#: builtin/config.c:131
+msgid "Action"
+msgstr "Действие"
+
+#: builtin/config.c:132
+msgid "get value: name [value-regex]"
+msgstr "получить значение: имя [шаблон-значений]"
+
+#: builtin/config.c:133
+msgid "get all values: key [value-regex]"
+msgstr "получить все значения: ключ [шаблон-значений]"
+
+#: builtin/config.c:134
+msgid "get values for regexp: name-regex [value-regex]"
+msgstr "получить значения по шаблону: шаблон-имен [шаблон-значений]"
+
+#: builtin/config.c:135
+msgid "get value specific for the URL: section[.var] URL"
+msgstr "получить значение, специфичное для URL: раздел[.переменная] URL"
+
+#: builtin/config.c:136
+msgid "replace all matching variables: name value [value_regex]"
+msgstr "заменить все соответствующие переменные: имя значение [шаблон-значений]"
+
+#: builtin/config.c:137
+msgid "add a new variable: name value"
+msgstr "добавить новую переменную: имя значение"
+
+#: builtin/config.c:138
+msgid "remove a variable: name [value-regex]"
+msgstr "удалить переменную: имя [шаблон-значений]"
+
+#: builtin/config.c:139
+msgid "remove all matches: name [value-regex]"
+msgstr "удалить все совпадающие: имя [шаблон-значений]"
+
+#: builtin/config.c:140
+msgid "rename section: old-name new-name"
+msgstr "переименовать раздел: старое-имя новое-имя"
+
+#: builtin/config.c:141
+msgid "remove a section: name"
+msgstr "удалить раздел: имя"
+
+#: builtin/config.c:142
+msgid "list all"
+msgstr "показать весь список"
+
+#: builtin/config.c:143
+msgid "open an editor"
+msgstr "открыть в редакторе"
+
+#: builtin/config.c:144
+msgid "find the color configured: slot [default]"
+msgstr "найти настроенный цвет: раздел [по-умолчанию]"
+
+#: builtin/config.c:145
+msgid "find the color setting: slot [stdout-is-tty]"
+msgstr "проверить, существует ли настроенный цвет: раздел [stdout-есть-tty]"
+
+#: builtin/config.c:146
+msgid "Type"
+msgstr "Тип"
+
+#: builtin/config.c:147
+msgid "value is given this type"
+msgstr ""
+
+#: builtin/config.c:148
+msgid "value is \"true\" or \"false\""
+msgstr "значение — это «true» (правда) или «false» (ложь)"
+
+#: builtin/config.c:149
+msgid "value is decimal number"
+msgstr "значение — это десятичное число"
+
+#: builtin/config.c:150
+msgid "value is --bool or --int"
+msgstr "значение — это --bool или --int"
+
+#: builtin/config.c:151
+msgid "value is a path (file or directory name)"
+msgstr "значение — это путь (к файлу или каталогу)"
+
+#: builtin/config.c:152
+msgid "value is an expiry date"
+msgstr "значение - это дата окончания срока действия"
+
+#: builtin/config.c:153
+msgid "Other"
+msgstr "Другое"
+
+#: builtin/config.c:154
+msgid "terminate values with NUL byte"
+msgstr "завершать значения НУЛЕВЫМ байтом"
+
+#: builtin/config.c:155
+msgid "show variable names only"
+msgstr "показывать только имена переменных"
+
+#: builtin/config.c:156
+msgid "respect include directives on lookup"
+msgstr "учитывать директивы include (включения файлов) при запросе"
+
+#: builtin/config.c:157
+msgid "show origin of config (file, standard input, blob, command line)"
+msgstr "показать источник настройки (файл, стандартный ввод, двоичный объект, командная строка)"
+
+#: builtin/config.c:158
+msgid "value"
+msgstr ""
+
+#: builtin/config.c:158
+msgid "with --get, use default value when missing entry"
+msgstr ""
+
+#: builtin/config.c:172
+#, c-format
+msgid "wrong number of arguments, should be %d"
+msgstr ""
+
+#: builtin/config.c:174
+#, c-format
+msgid "wrong number of arguments, should be from %d to %d"
+msgstr ""
+
+#: builtin/config.c:308
+#, c-format
+msgid "invalid key pattern: %s"
+msgstr ""
+
+#: builtin/config.c:344
+#, c-format
+msgid "failed to format default config value: %s"
+msgstr ""
+
+#: builtin/config.c:401
+#, c-format
+msgid "cannot parse color '%s'"
+msgstr ""
+
+#: builtin/config.c:443
+msgid "unable to parse default color value"
+msgstr "не удалось разобрать значение цвета по умолчанию"
+
+#: builtin/config.c:496 builtin/config.c:742
+msgid "not in a git directory"
+msgstr ""
+
+#: builtin/config.c:499
+msgid "writing to stdin is not supported"
+msgstr ""
+
+#: builtin/config.c:502
+msgid "writing config blobs is not supported"
+msgstr ""
+
+#: builtin/config.c:587
+#, c-format
+msgid ""
+"# This is Git's per-user configuration file.\n"
+"[user]\n"
+"# Please adapt and uncomment the following lines:\n"
+"#\tname = %s\n"
+"#\temail = %s\n"
+msgstr "# Это файл конфигурации пользователя Git.\n[user]\n# Пожалуйста, адаптируйте и раскомментируйте следующие строки:\n#\tuser = %s\n#\temail = %s\n"
+
+#: builtin/config.c:611
+msgid "only one config file at a time"
+msgstr ""
+
+#: builtin/config.c:616
+msgid "--local can only be used inside a git repository"
+msgstr "--local можно использовать только внутри git репозитория"
+
+#: builtin/config.c:619
+msgid "--blob can only be used inside a git repository"
+msgstr ""
+
+#: builtin/config.c:638
+msgid "$HOME not set"
+msgstr ""
+
+#: builtin/config.c:658
+msgid ""
+"--worktree cannot be used with multiple working trees unless the config\n"
+"extension worktreeConfig is enabled. Please read \"CONFIGURATION FILE\"\n"
+"section in \"git help worktree\" for details"
+msgstr ""
+
+#: builtin/config.c:688
+msgid "--get-color and variable type are incoherent"
+msgstr ""
+
+#: builtin/config.c:693
+msgid "only one action at a time"
+msgstr ""
+
+#: builtin/config.c:706
+msgid "--name-only is only applicable to --list or --get-regexp"
+msgstr ""
+
+#: builtin/config.c:712
+msgid ""
+"--show-origin is only applicable to --get, --get-all, --get-regexp, and "
+"--list"
+msgstr ""
+
+#: builtin/config.c:718
+msgid "--default is only applicable to --get"
+msgstr ""
+
+#: builtin/config.c:731
+#, c-format
+msgid "unable to read config file '%s'"
+msgstr ""
+
+#: builtin/config.c:734
+msgid "error processing config file(s)"
+msgstr ""
+
+#: builtin/config.c:744
+msgid "editing stdin is not supported"
+msgstr ""
+
+#: builtin/config.c:746
+msgid "editing blobs is not supported"
+msgstr ""
+
+#: builtin/config.c:760
+#, c-format
+msgid "cannot create configuration file %s"
+msgstr "не удалось создать файл конфигурации %s"
+
+#: builtin/config.c:773
+#, c-format
+msgid ""
+"cannot overwrite multiple values with a single value\n"
+"       Use a regexp, --add or --replace-all to change %s."
+msgstr "нельзя перезаписать несколько значений одним\n       Используйте регулярные выражения, параметры --add или --replace-all, чтобы изменить %s."
+
+#: builtin/config.c:847 builtin/config.c:858
+#, c-format
+msgid "no such section: %s"
+msgstr ""
+
+#: builtin/count-objects.c:90
+msgid "git count-objects [-v] [-H | --human-readable]"
+msgstr "git count-objects [-v] [-H | --human-readable]"
+
+#: builtin/count-objects.c:100
+msgid "print sizes in human readable format"
+msgstr "вывод размеров в удобочитаемом для человека виде"
+
+#: builtin/describe.c:27
+msgid "git describe [<options>] [<commit-ish>...]"
+msgstr "git describe [<опции>] [<указатель-коммита>…]"
+
+#: builtin/describe.c:28
+msgid "git describe [<options>] --dirty"
+msgstr "git describe [<опции>] --dirty"
+
+#: builtin/describe.c:63
+msgid "head"
+msgstr "указатель на ветку"
+
+#: builtin/describe.c:63
+msgid "lightweight"
+msgstr "легковесный"
+
+#: builtin/describe.c:63
+msgid "annotated"
+msgstr "аннотированный"
+
+#: builtin/describe.c:273
+#, c-format
+msgid "annotated tag %s not available"
+msgstr "аннотированная метка %s не доступна"
+
+#: builtin/describe.c:277
+#, c-format
+msgid "annotated tag %s has no embedded name"
+msgstr "аннотированная метка %s не содержит встроенного названия"
+
+#: builtin/describe.c:279
+#, c-format
+msgid "tag '%s' is really '%s' here"
+msgstr "метка «%s» уже здесь «%s»"
+
+#: builtin/describe.c:323
+#, c-format
+msgid "no tag exactly matches '%s'"
+msgstr "нет меток, точно соответствующих «%s»"
+
+#: builtin/describe.c:325
+#, c-format
+msgid "No exact match on refs or tags, searching to describe\n"
+msgstr "Нет точных совпадений по ссылкам или тегам, ищу описания\n"
+
+#: builtin/describe.c:379
+#, c-format
+msgid "finished search at %s\n"
+msgstr "поиск окончен на %s\n"
+
+#: builtin/describe.c:405
+#, c-format
+msgid ""
+"No annotated tags can describe '%s'.\n"
+"However, there were unannotated tags: try --tags."
+msgstr "Нет аннотированных меток, которые могут описать «%s».\nНо имеются неаннотированные метки: попробуйте добавить параметр --tags."
+
+#: builtin/describe.c:409
+#, c-format
+msgid ""
+"No tags can describe '%s'.\n"
+"Try --always, or create some tags."
+msgstr "Нет меток, которые могут описать «%s….\nПопробуйте добавить параметр --always или создать какие-нибудь метки."
+
+#: builtin/describe.c:439
+#, c-format
+msgid "traversed %lu commits\n"
+msgstr "посещено %lu коммитов\n"
+
+#: builtin/describe.c:442
+#, c-format
+msgid ""
+"more than %i tags found; listed %i most recent\n"
+"gave up search at %s\n"
+msgstr "более %i меток найдено; показано последние %i\nостановлен поиск после %s\n"
+
+#: builtin/describe.c:510
+#, c-format
+msgid "describe %s\n"
+msgstr "описать %s\n"
+
+#: builtin/describe.c:513
+#, c-format
+msgid "Not a valid object name %s"
+msgstr "Недопустимое имя объекта %s"
+
+#: builtin/describe.c:521
+#, c-format
+msgid "%s is neither a commit nor blob"
+msgstr "%s не является коммитом или двоичным объектом"
+
+#: builtin/describe.c:535
+msgid "find the tag that comes after the commit"
+msgstr "поиск метки, которая идет после коммита"
+
+#: builtin/describe.c:536
+msgid "debug search strategy on stderr"
+msgstr "вывод отладочной информации стратегии поиска на стандартный вывод"
+
+#: builtin/describe.c:537
+msgid "use any ref"
+msgstr "использовать любую ссылку"
+
+#: builtin/describe.c:538
+msgid "use any tag, even unannotated"
+msgstr "использовать любую метку, даже неаннотированную"
+
+#: builtin/describe.c:539
+msgid "always use long format"
+msgstr "всегда использовать длинный формат вывода"
+
+#: builtin/describe.c:540
+msgid "only follow first parent"
+msgstr "следовать только за первым родителем"
+
+#: builtin/describe.c:543
+msgid "only output exact matches"
+msgstr "выводить только точные совпадения"
+
+#: builtin/describe.c:545
+msgid "consider <n> most recent tags (default: 10)"
+msgstr "рассматривать последние <n> меток (по умолчанию: 10)"
+
+#: builtin/describe.c:547
+msgid "only consider tags matching <pattern>"
+msgstr "рассматривать только метки по <шаблону>"
+
+#: builtin/describe.c:549
+msgid "do not consider tags matching <pattern>"
+msgstr "не учитывать метки, которые соответствуют <шаблону>"
+
+#: builtin/describe.c:551 builtin/name-rev.c:426
+msgid "show abbreviated commit object as fallback"
+msgstr "если не найдено, показать сокращенный номер редакции коммита"
+
+#: builtin/describe.c:552 builtin/describe.c:555
+msgid "mark"
+msgstr "пометка"
+
+#: builtin/describe.c:553
+msgid "append <mark> on dirty working tree (default: \"-dirty\")"
+msgstr "добавить <пометку> при изменённом рабочем каталоге (по умолчанию: «-dirty»)"
+
+#: builtin/describe.c:556
+msgid "append <mark> on broken working tree (default: \"-broken\")"
+msgstr "добавить <пометку> на повреждённое рабочее дерево (по умолчанию: «-broken»)"
+
+#: builtin/describe.c:574
+msgid "--long is incompatible with --abbrev=0"
+msgstr "--long несовместимо с --abbrev=0"
+
+#: builtin/describe.c:603
+msgid "No names found, cannot describe anything."
+msgstr "Имена не найдены, не могу ничего описать."
+
+#: builtin/describe.c:654
+msgid "--dirty is incompatible with commit-ishes"
+msgstr "--dirty несовместимо с указанием указателей коммитов"
+
+#: builtin/describe.c:656
+msgid "--broken is incompatible with commit-ishes"
+msgstr "--broken несовместимо с указанием указателей коммитов"
+
+#: builtin/diff.c:84
+#, c-format
+msgid "'%s': not a regular file or symlink"
+msgstr "«%s»: не является обычным файлом или символьной ссылкой"
+
+#: builtin/diff.c:235
+#, c-format
+msgid "invalid option: %s"
+msgstr "неправильный параметр: %s"
+
+#: builtin/diff.c:350
+msgid "Not a git repository"
+msgstr "Не найден git репозиторий"
+
+#: builtin/diff.c:394
+#, c-format
+msgid "invalid object '%s' given."
+msgstr "передан неправильный объект «%s»."
+
+#: builtin/diff.c:403
+#, c-format
+msgid "more than two blobs given: '%s'"
+msgstr "передано больше двух двоичных объектов: «%s»"
+
+#: builtin/diff.c:408
+#, c-format
+msgid "unhandled object '%s' given."
+msgstr "передан необработанный объект «%s»."
+
+#: builtin/difftool.c:30
+msgid "git difftool [<options>] [<commit> [<commit>]] [--] [<path>...]"
+msgstr "git difftool [<опции>] [<коммит> [<коммит>]] [--] [<путь>…]"
+
+#: builtin/difftool.c:253
+#, c-format
+msgid "failed: %d"
+msgstr "сбой: %d"
+
+#: builtin/difftool.c:295
+#, c-format
+msgid "could not read symlink %s"
+msgstr "не удалось прочитать символьную ссылку %s"
+
+#: builtin/difftool.c:297
+#, c-format
+msgid "could not read symlink file %s"
+msgstr "не удалось прочитать файл символьной ссылки %s"
+
+#: builtin/difftool.c:305
+#, c-format
+msgid "could not read object %s for symlink %s"
+msgstr "не удалось прочитать объект %s для символьной ссылки %s"
+
+#: builtin/difftool.c:406
+msgid ""
+"combined diff formats('-c' and '--cc') are not supported in\n"
+"directory diff mode('-d' and '--dir-diff')."
+msgstr "комбинированные форматы файлов списка изменений(«-c» и «--cc») не поддерживаются в режиме сравнения каталогов(«-d» и «--dir-diff»)."
+
+#: builtin/difftool.c:626
+#, c-format
+msgid "both files modified: '%s' and '%s'."
+msgstr "оба файла изменены: «%s» и «%s»."
+
+#: builtin/difftool.c:628
+msgid "working tree file has been left."
+msgstr "рабочий каталог был покинут."
+
+#: builtin/difftool.c:639
+#, c-format
+msgid "temporary files exist in '%s'."
+msgstr "временные файлы уже находятся в «%s»."
+
+#: builtin/difftool.c:640
+msgid "you may want to cleanup or recover these."
+msgstr "возможно вы хотите их удалить или восстановить."
+
+#: builtin/difftool.c:689
+msgid "use `diff.guitool` instead of `diff.tool`"
+msgstr "использовать «diff.guitool» вместо «diff.tool»"
+
+#: builtin/difftool.c:691
+msgid "perform a full-directory diff"
+msgstr "выполнить пофайловое сравнение всего каталога"
+
+#: builtin/difftool.c:693
+msgid "do not prompt before launching a diff tool"
+msgstr "не спрашивать перед запуском утилиты сравнения"
+
+#: builtin/difftool.c:698
+msgid "use symlinks in dir-diff mode"
+msgstr "использовать символьные ссылки в режиме сравнения каталога"
+
+#: builtin/difftool.c:699
+msgid "tool"
+msgstr ""
+
+#: builtin/difftool.c:700
+msgid "use the specified diff tool"
+msgstr "использовать указанную утилиту сравнения"
+
+#: builtin/difftool.c:702
+msgid "print a list of diff tools that may be used with `--tool`"
+msgstr "вывести список утилит, которые можно использовать с параметром «--tool»"
+
+#: builtin/difftool.c:705
+msgid ""
+"make 'git-difftool' exit when an invoked diff tool returns a non - zero exit"
+" code"
+msgstr "выходить из «git-difftool», если вызванная утилита сравнения вернула не нулевой код возврата"
+
+#: builtin/difftool.c:708
+msgid "specify a custom command for viewing diffs"
+msgstr "использовать особую команду для просмотра изменений"
+
+#: builtin/difftool.c:709
+msgid "passed to `diff`"
+msgstr ""
+
+#: builtin/difftool.c:724
+msgid "difftool requires worktree or --no-index"
+msgstr ""
+
+#: builtin/difftool.c:731
+msgid "--dir-diff is incompatible with --no-index"
+msgstr ""
+
+#: builtin/difftool.c:734
+msgid "--gui, --tool and --extcmd are mutually exclusive"
+msgstr ""
+
+#: builtin/difftool.c:742
+msgid "no <tool> given for --tool=<tool>"
+msgstr "не передана <утилита> для --tool=<утилита>"
+
+#: builtin/difftool.c:749
+msgid "no <cmd> given for --extcmd=<cmd>"
+msgstr "не передана <команда> для --extcmd=<команда>"
+
+#: builtin/fast-export.c:29
+msgid "git fast-export [rev-list-opts]"
+msgstr "git fast-export [опции-rev-list]"
+
+#: builtin/fast-export.c:1084
+msgid "show progress after <n> objects"
+msgstr "показать прогресс после <n> объектов"
+
+#: builtin/fast-export.c:1086
+msgid "select handling of signed tags"
+msgstr "выбор обработки подписанных меток"
+
+#: builtin/fast-export.c:1089
+msgid "select handling of tags that tag filtered objects"
+msgstr "выбор обработки меток, которыми помечены отфильтрованные объекты"
+
+#: builtin/fast-export.c:1092
+msgid "Dump marks to this file"
+msgstr "Записать пометки в этот файл"
+
+#: builtin/fast-export.c:1094
+msgid "Import marks from this file"
+msgstr "Импортировать пометки из этого файла"
+
+#: builtin/fast-export.c:1096
+msgid "Fake a tagger when tags lack one"
+msgstr "Подделать автора метки, если у метки он отсутствует"
+
+#: builtin/fast-export.c:1098
+msgid "Output full tree for each commit"
+msgstr "Вывести полное дерево для каждого коммита"
+
+#: builtin/fast-export.c:1100
+msgid "Use the done feature to terminate the stream"
+msgstr "Использовать пометку завершения в конце потока"
+
+#: builtin/fast-export.c:1101
+msgid "Skip output of blob data"
+msgstr "Пропустить вывод данных двоичных объектов"
+
+#: builtin/fast-export.c:1102 builtin/log.c:1609
+msgid "refspec"
+msgstr "спецификатор ссылки"
+
+#: builtin/fast-export.c:1103
+msgid "Apply refspec to exported refs"
+msgstr "Применить спецификатор ссылки к экспортируемым ссылкам"
+
+#: builtin/fast-export.c:1104
+msgid "anonymize output"
+msgstr "сделать вывод анонимным"
+
+#: builtin/fast-export.c:1106
+msgid "Reference parents which are not in fast-export stream by object id"
+msgstr ""
+
+#: builtin/fast-export.c:1108
+msgid "Show original object ids of blobs/commits"
+msgstr ""
+
+#: builtin/fetch.c:28
+msgid "git fetch [<options>] [<repository> [<refspec>...]]"
+msgstr "git fetch [<опции>] [<репозиторий> [<спецификатор-ссылки>…]]"
+
+#: builtin/fetch.c:29
+msgid "git fetch [<options>] <group>"
+msgstr "git fetch [<опции>] <группа>"
+
+#: builtin/fetch.c:30
+msgid "git fetch --multiple [<options>] [(<repository> | <group>)...]"
+msgstr "git fetch --multiple [<опции>] [(<репозиторий> | <группа>)…]"
+
+#: builtin/fetch.c:31
+msgid "git fetch --all [<options>]"
+msgstr "git fetch --all [<опции>]"
+
+#: builtin/fetch.c:115 builtin/pull.c:202
+msgid "fetch from all remotes"
+msgstr "извлечь со всех внешних репозиториев"
+
+#: builtin/fetch.c:117 builtin/pull.c:205
+msgid "append to .git/FETCH_HEAD instead of overwriting"
+msgstr "дописать к .git/FETCH_HEAD вместо перезаписи"
+
+#: builtin/fetch.c:119 builtin/pull.c:208
+msgid "path to upload pack on remote end"
+msgstr "путь к программе упаковки пакета на машине с внешним репозиторием"
+
+#: builtin/fetch.c:120
+msgid "force overwrite of local reference"
+msgstr ""
+
+#: builtin/fetch.c:122
+msgid "fetch from multiple remotes"
+msgstr "извлечь с нескольких внешних репозиториев"
+
+#: builtin/fetch.c:124 builtin/pull.c:212
+msgid "fetch all tags and associated objects"
+msgstr "извлечь все метки и связанные объекты"
+
+#: builtin/fetch.c:126
+msgid "do not fetch all tags (--no-tags)"
+msgstr "не извлекать все метки (--no-tags)"
+
+#: builtin/fetch.c:128
+msgid "number of submodules fetched in parallel"
+msgstr "количество подмодулей, которые будут скачаны парралельно"
+
+#: builtin/fetch.c:130 builtin/pull.c:215
+msgid "prune remote-tracking branches no longer on remote"
+msgstr "почистить отслеживаемые внешние ветки, которых уже нет на внешнем репозитории"
+
+#: builtin/fetch.c:132
+msgid "prune local tags no longer on remote and clobber changed tags"
+msgstr ""
+
+#: builtin/fetch.c:133 builtin/fetch.c:156 builtin/pull.c:139
+msgid "on-demand"
+msgstr "по требованию"
+
+#: builtin/fetch.c:134
+msgid "control recursive fetching of submodules"
+msgstr "управление рекурсивным извлечением подмодулей"
+
+#: builtin/fetch.c:138 builtin/pull.c:223
+msgid "keep downloaded pack"
+msgstr "оставить загруженный пакет данных"
+
+#: builtin/fetch.c:140
+msgid "allow updating of HEAD ref"
+msgstr "разрешить обновление ссылки HEAD"
+
+#: builtin/fetch.c:143 builtin/fetch.c:149 builtin/pull.c:226
+msgid "deepen history of shallow clone"
+msgstr "улугубить историю частичного клона"
+
+#: builtin/fetch.c:145
+msgid "deepen history of shallow repository based on time"
+msgstr "углубить историю частичного клона основываясь на времени"
+
+#: builtin/fetch.c:151 builtin/pull.c:229
+msgid "convert to a complete repository"
+msgstr "преобразовать в полный репозиторий"
+
+#: builtin/fetch.c:154
+msgid "prepend this to submodule path output"
+msgstr "присоединять это спереди к выводу путей подмодуля"
 
-#: builtin/commit.c:869
-#, c-format
-msgid "%sDate:      %s"
-msgstr "%sДата:      %s"
+#: builtin/fetch.c:157
+msgid ""
+"default for recursive fetching of submodules (lower priority than config "
+"files)"
+msgstr "настроить по умолчанию рекурсивное извлечение подмодулей (более низкий приоритет, чем файлы конфигурации)"
 
-#: builtin/commit.c:876
-#, c-format
-msgid "%sCommitter: %.*s <%.*s>"
-msgstr "%sКоммитер:  %.*s <%.*s>"
+#: builtin/fetch.c:161 builtin/pull.c:232
+msgid "accept refs that update .git/shallow"
+msgstr "принимать ссылки, которые обновляют .git/shallow"
 
-#: builtin/commit.c:893
-msgid "Cannot read index"
-msgstr "Не удалось прочитать индекс"
+#: builtin/fetch.c:162 builtin/pull.c:234
+msgid "refmap"
+msgstr "соответствие-ссылок"
 
-#: builtin/commit.c:959
-msgid "Error building trees"
-msgstr "Ошибка при построении деревьев"
+#: builtin/fetch.c:163 builtin/pull.c:235
+msgid "specify fetch refmap"
+msgstr "указать соответствие ссылок при извлечении"
 
-#: builtin/commit.c:973 builtin/tag.c:252
-#, c-format
-msgid "Please supply the message using either -m or -F option.\n"
-msgstr "Пожалуйста, укажите сообщение, при указании опций -m или -F.\n"
+#: builtin/fetch.c:170
+msgid "report that we have only objects reachable from this object"
+msgstr ""
 
-#: builtin/commit.c:1076
-#, c-format
-msgid "--author '%s' is not 'Name <email>' and matches no existing author"
-msgstr "--author «%s» не в формате «Имя <почта>» и не совпадает с существующим автором"
+#: builtin/fetch.c:469
+msgid "Couldn't find remote ref HEAD"
+msgstr "Не удалось найти ссылку HEAD на внешнем репозитории"
 
-#: builtin/commit.c:1090
+#: builtin/fetch.c:608
 #, c-format
-msgid "Invalid ignored mode '%s'"
-msgstr "Недопустимый режим показа игнорируемых файлов «%s»"
+msgid "configuration fetch.output contains invalid value %s"
+msgstr "опция fetch.output содержит неправильное значение для %s"
 
-#: builtin/commit.c:1104 builtin/commit.c:1349
+#: builtin/fetch.c:705
 #, c-format
-msgid "Invalid untracked files mode '%s'"
-msgstr "Неправильный режим неотслеживаемых файлов «%s»"
+msgid "object %s not found"
+msgstr "объект %s не найден"
 
-#: builtin/commit.c:1142
-msgid "--long and -z are incompatible"
-msgstr "--long и -z нельзя использовать одновременно"
+#: builtin/fetch.c:709
+msgid "[up to date]"
+msgstr "[актуально]"
 
-#: builtin/commit.c:1172
-msgid "Using both --reset-author and --author does not make sense"
-msgstr "Указание одновременно опций --reset-author и --author не имеет смысла"
+#: builtin/fetch.c:722 builtin/fetch.c:738 builtin/fetch.c:801
+msgid "[rejected]"
+msgstr "[отклонено]"
 
-#: builtin/commit.c:1181
-msgid "You have nothing to amend."
-msgstr "Нечего исправлять."
+#: builtin/fetch.c:723
+msgid "can't fetch in current branch"
+msgstr "нельзя извлечь текущую ветку"
 
-#: builtin/commit.c:1184
-msgid "You are in the middle of a merge -- cannot amend."
-msgstr "Вы в процессе слияния —  сейчас нельзя исправлять."
+#: builtin/fetch.c:733
+msgid "[tag update]"
+msgstr "[обновление метки]"
 
-#: builtin/commit.c:1186
-msgid "You are in the middle of a cherry-pick -- cannot amend."
-msgstr "Вы в процессе копирования коммита —  сейчас нельзя исправлять."
+#: builtin/fetch.c:734 builtin/fetch.c:771 builtin/fetch.c:784
+#: builtin/fetch.c:796
+msgid "unable to update local ref"
+msgstr "не удалось обновить локальную ссылку"
 
-#: builtin/commit.c:1189
-msgid "Options --squash and --fixup cannot be used together"
-msgstr "Опции --squash и --fixup не могут использоваться одновременно"
+#: builtin/fetch.c:738
+msgid "would clobber existing tag"
+msgstr ""
 
-#: builtin/commit.c:1199
-msgid "Only one of -c/-C/-F/--fixup can be used."
-msgstr "Может использоваться только одна из опций -c/-C/-F/--fixup."
+#: builtin/fetch.c:760
+msgid "[new tag]"
+msgstr "[новая метка]"
 
-#: builtin/commit.c:1201
-msgid "Option -m cannot be combined with -c/-C/-F/--fixup."
-msgstr "Опция -m не может использоваться с -c/-C/-F/--fixup."
+#: builtin/fetch.c:763
+msgid "[new branch]"
+msgstr "[новая ветка]"
 
-#: builtin/commit.c:1209
-msgid "--reset-author can be used only with -C, -c or --amend."
-msgstr "--reset-author может использоваться только одновременно с опциями -C, -c или --amend."
+#: builtin/fetch.c:766
+msgid "[new ref]"
+msgstr "[новая ссылка]"
 
-#: builtin/commit.c:1226
-msgid "Only one of --include/--only/--all/--interactive/--patch can be used."
-msgstr "Может использоваться только одна из опций --include/--only/--all/--interactive/--patch."
+#: builtin/fetch.c:796
+msgid "forced update"
+msgstr "принудительное обновление"
 
-#: builtin/commit.c:1228
-msgid "No paths with --include/--only does not make sense."
-msgstr "Указание путей каталогов с опциями --include/--only не имеет смысла."
+#: builtin/fetch.c:801
+msgid "non-fast-forward"
+msgstr "без перемотки вперед"
 
-#: builtin/commit.c:1240 builtin/tag.c:535
+#: builtin/fetch.c:847
 #, c-format
-msgid "Invalid cleanup mode %s"
-msgstr "Неправильное значение режима очистки %s"
+msgid "%s did not send all necessary objects\n"
+msgstr "%s не отправил все необходимые объекты\n"
 
-#: builtin/commit.c:1245
-msgid "Paths with -a does not make sense."
-msgstr "С опцией -a указание пути не имеет смысла."
+#: builtin/fetch.c:868
+#, c-format
+msgid "reject %s because shallow roots are not allowed to be updated"
+msgstr "%s отклонено из-за того, что частичные корни не разрешено обновлять"
 
-#: builtin/commit.c:1363 builtin/commit.c:1648
-msgid "show status concisely"
-msgstr "кратко показать статус"
+#: builtin/fetch.c:959 builtin/fetch.c:1081
+#, c-format
+msgid "From %.*s\n"
+msgstr "Из %.*s\n"
 
-#: builtin/commit.c:1365 builtin/commit.c:1650
-msgid "show branch information"
-msgstr "показать информацию о версии"
+#: builtin/fetch.c:970
+#, c-format
+msgid ""
+"some local refs could not be updated; try running\n"
+" 'git remote prune %s' to remove any old, conflicting branches"
+msgstr "не удалось обновить некоторые локальные ссылки; попробуйте запустить «git remote prune %s», чтобы почистить старые, конфликтующие ветки"
 
-#: builtin/commit.c:1367
-msgid "show stash information"
-msgstr "показать информацию о спрятанном"
+#: builtin/fetch.c:1051
+#, c-format
+msgid "   (%s will become dangling)"
+msgstr "   (%s будет висящей веткой)"
 
-#: builtin/commit.c:1369
-msgid "version"
-msgstr "версия"
+#: builtin/fetch.c:1052
+#, c-format
+msgid "   (%s has become dangling)"
+msgstr "   (%s стала висящей веткой)"
 
-#: builtin/commit.c:1369 builtin/commit.c:1652 builtin/push.c:542
-#: builtin/worktree.c:523
-msgid "machine-readable output"
-msgstr "машиночитаемый вывод"
+#: builtin/fetch.c:1084
+msgid "[deleted]"
+msgstr "[удалено]"
 
-#: builtin/commit.c:1372 builtin/commit.c:1654
-msgid "show status in long format (default)"
-msgstr "показать статус в длинном формате (по умолчанию)"
+#: builtin/fetch.c:1085 builtin/remote.c:1036
+msgid "(none)"
+msgstr "(нет)"
 
-#: builtin/commit.c:1375 builtin/commit.c:1657
-msgid "terminate entries with NUL"
-msgstr "завершать записи НУЛЕВЫМ байтом"
+#: builtin/fetch.c:1108
+#, c-format
+msgid "Refusing to fetch into current branch %s of non-bare repository"
+msgstr "Отказ получения в текущую ветку %s не голого репозитория"
 
-#: builtin/commit.c:1377 builtin/commit.c:1381 builtin/commit.c:1660
-#: builtin/fast-export.c:999 builtin/fast-export.c:1002 builtin/tag.c:390
-msgid "mode"
-msgstr "режим"
+#: builtin/fetch.c:1127
+#, c-format
+msgid "Option \"%s\" value \"%s\" is not valid for %s"
+msgstr "Неправильное значение «%2$s» для параметра «%1$s» для %3$s"
 
-#: builtin/commit.c:1378 builtin/commit.c:1660
-msgid "show untracked files, optional modes: all, normal, no. (Default: all)"
-msgstr "показать неотслеживаемые файлы, опциональные режимы: all (все), normal (как обычно), no (нет). (По умолчанию: all)"
+#: builtin/fetch.c:1130
+#, c-format
+msgid "Option \"%s\" is ignored for %s\n"
+msgstr "Параметр «%s» игнорируется для %s\n"
 
-#: builtin/commit.c:1382
-msgid ""
-"show ignored files, optional modes: traditional, matching, no. (Default: "
-"traditional)"
-msgstr "показывать игнорируемые файлы, с опциональным режимом: traditional (традиционный), matching (только совпадающие), no (не показывать). (По умолчанию: traditional)"
+#: builtin/fetch.c:1434
+#, c-format
+msgid "Fetching %s\n"
+msgstr "Извлечение из %s\n"
 
-#: builtin/commit.c:1384 parse-options.h:155
-msgid "when"
-msgstr "когда"
+#: builtin/fetch.c:1436 builtin/remote.c:100
+#, c-format
+msgid "Could not fetch %s"
+msgstr "Не удалось извлечь %s"
 
-#: builtin/commit.c:1385
+#: builtin/fetch.c:1482
 msgid ""
-"ignore changes to submodules, optional when: all, dirty, untracked. "
-"(Default: all)"
-msgstr "игнорировать изменения в подмодулях, опционально когда: all (всегда), dirty (измененные), untracked (неотслеживаемые). (По умолчанию: all)"
+"--filter can only be used with the remote configured in "
+"extensions.partialClone"
+msgstr ""
 
-#: builtin/commit.c:1387
-msgid "list untracked files in columns"
-msgstr "показать неотслеживаемые файлы по столбцам"
+#: builtin/fetch.c:1506
+msgid ""
+"No remote repository specified.  Please, specify either a URL or a\n"
+"remote name from which new revisions should be fetched."
+msgstr "Не указан внешний репозиторий. Укажите URL или имя внешнего репозитория из которого должны извлекаться новые редакции."
 
-#: builtin/commit.c:1406
-msgid "Unsupported combination of ignored and untracked-files arguments"
-msgstr "Неподдерживаемая комбинация аргументов отображения игнорируемых и неотслеживаемых файлов"
+#: builtin/fetch.c:1543
+msgid "You need to specify a tag name."
+msgstr "Вам нужно указать имя метки."
 
-#: builtin/commit.c:1469
-msgid "couldn't look up newly created commit"
-msgstr "нельзя запросить новосозданный коммит"
+#: builtin/fetch.c:1594
+msgid "Negative depth in --deepen is not supported"
+msgstr "Отрицательная грубина для --deepen не поддерживается"
 
-#: builtin/commit.c:1471
-msgid "could not parse newly created commit"
-msgstr "нельзя разобрать новосозданный коммит"
+#: builtin/fetch.c:1596
+msgid "--deepen and --depth are mutually exclusive"
+msgstr "--deepen и --depth нельзя использовать одновременно"
 
-#: builtin/commit.c:1516
-msgid "unable to resolve HEAD after creating commit"
-msgstr "не удалось найти HEAD после создания коммита"
+#: builtin/fetch.c:1601
+msgid "--depth and --unshallow cannot be used together"
+msgstr "нельзя использовать одновременно --depth и --unshallow"
 
-#: builtin/commit.c:1518
-msgid "detached HEAD"
-msgstr "отделённый HEAD"
+#: builtin/fetch.c:1603
+msgid "--unshallow on a complete repository does not make sense"
+msgstr "--unshallow не имеет смысла на полном репозитории"
 
-#: builtin/commit.c:1521
-msgid " (root-commit)"
-msgstr " (корневой коммит)"
+#: builtin/fetch.c:1619
+msgid "fetch --all does not take a repository argument"
+msgstr "fetch --all не принимает имя репозитория как аргумент"
 
-#: builtin/commit.c:1618
-msgid "suppress summary after successful commit"
-msgstr "не выводить сводку после успешного коммита"
+#: builtin/fetch.c:1621
+msgid "fetch --all does not make sense with refspecs"
+msgstr "fetch --all не имеет смысла при указании спецификаторов ссылок"
 
-#: builtin/commit.c:1619
-msgid "show diff in commit message template"
-msgstr "добавить список изменений в шаблон сообщения коммита"
+#: builtin/fetch.c:1630
+#, c-format
+msgid "No such remote or remote group: %s"
+msgstr "Нет такого внешнего репозитория или группы: %s"
 
-#: builtin/commit.c:1621
-msgid "Commit message options"
-msgstr "Опции сообщения коммита"
+#: builtin/fetch.c:1637
+msgid "Fetching a group and specifying refspecs does not make sense"
+msgstr "Получение группы и указание спецификаций ссылок не имеет смысла"
 
-#: builtin/commit.c:1622 builtin/tag.c:388
-msgid "read message from file"
-msgstr "прочитать сообщение из файла"
+#: builtin/fetch.c:1653
+msgid ""
+"--filter can only be used with the remote configured in "
+"extensions.partialclone"
+msgstr ""
 
-#: builtin/commit.c:1623
-msgid "author"
-msgstr "автор"
+#: builtin/fmt-merge-msg.c:18
+msgid ""
+"git fmt-merge-msg [-m <message>] [--log[=<n>] | --no-log] [--file <file>]"
+msgstr "git fmt-merge-msg [-m <сообщение>] [--log[=<n>] | --no-log] [--file <файл>]"
 
-#: builtin/commit.c:1623
-msgid "override author for commit"
-msgstr "подменить автора коммита"
+#: builtin/fmt-merge-msg.c:672
+msgid "populate log with at most <n> entries from shortlog"
+msgstr "отправить в журнал <n> записей из короткого журнала"
 
-#: builtin/commit.c:1624 builtin/gc.c:359
-msgid "date"
-msgstr "дата"
+#: builtin/fmt-merge-msg.c:675
+msgid "alias for --log (deprecated)"
+msgstr "сокращение для --log (устаревшее)"
 
-#: builtin/commit.c:1624
-msgid "override date for commit"
-msgstr "подменить дату коммита"
+#: builtin/fmt-merge-msg.c:678
+msgid "text"
+msgstr "текст"
 
-#: builtin/commit.c:1625 builtin/merge.c:225 builtin/notes.c:402
-#: builtin/notes.c:565 builtin/tag.c:386
-msgid "message"
-msgstr "сообщение"
+#: builtin/fmt-merge-msg.c:679
+msgid "use <text> as start of message"
+msgstr "использовать <текст> как начальное сообщение"
 
-#: builtin/commit.c:1625
-msgid "commit message"
-msgstr "сообщение коммита"
+#: builtin/fmt-merge-msg.c:680
+msgid "file to read from"
+msgstr "файл для чтения"
 
-#: builtin/commit.c:1626 builtin/commit.c:1627 builtin/commit.c:1628
-#: builtin/commit.c:1629 parse-options.h:257 ref-filter.h:92
-msgid "commit"
-msgstr "коммит"
+#: builtin/for-each-ref.c:10
+msgid "git for-each-ref [<options>] [<pattern>]"
+msgstr "git for-each-ref [<опции>] [<шаблон>]"
 
-#: builtin/commit.c:1626
-msgid "reuse and edit message from specified commit"
-msgstr "использовать и отредактировать сообщение от указанного коммита"
+#: builtin/for-each-ref.c:11
+msgid "git for-each-ref [--points-at <object>]"
+msgstr "git for-each-ref [--points-at <объект>]"
 
-#: builtin/commit.c:1627
-msgid "reuse message from specified commit"
-msgstr "использовать сообщение указанного коммита"
+#: builtin/for-each-ref.c:12
+msgid "git for-each-ref [(--merged | --no-merged) [<commit>]]"
+msgstr "git for-each-ref [(--merged | --no-merged) [<коммит>]]"
 
-#: builtin/commit.c:1628
-msgid "use autosquash formatted message to fixup specified commit"
-msgstr "использовать форматированное сообщение автоуплотнения для исправления указанного коммита"
+#: builtin/for-each-ref.c:13
+msgid "git for-each-ref [--contains [<commit>]] [--no-contains [<commit>]]"
+msgstr "git for-each-ref [--contains [<коммит>]] [--no-contains [<коммит>]]"
 
-#: builtin/commit.c:1629
-msgid "use autosquash formatted message to squash specified commit"
-msgstr "использовать форматированное сообщение автоуплотнения для уплотнения указанного коммита"
+#: builtin/for-each-ref.c:28
+msgid "quote placeholders suitably for shells"
+msgstr "выводить указатели места заполнения в подходящем формате для командного процессора"
 
-#: builtin/commit.c:1630
-msgid "the commit is authored by me now (used with -C/-c/--amend)"
-msgstr "коммит теперь за моим авторством (используется с -C/-c/--amend)"
+#: builtin/for-each-ref.c:30
+msgid "quote placeholders suitably for perl"
+msgstr "выводить указатели места заполнения в подходящем формате для perl"
 
-#: builtin/commit.c:1631 builtin/log.c:1443 builtin/merge.c:239
-#: builtin/pull.c:149 builtin/revert.c:105
-msgid "add Signed-off-by:"
-msgstr "добавить Signed-off-by:"
+#: builtin/for-each-ref.c:32
+msgid "quote placeholders suitably for python"
+msgstr "выводить указатели места заполнения в подходящем формате для python"
 
-#: builtin/commit.c:1632
-msgid "use specified template file"
-msgstr "использовать указанный файл шаблона"
+#: builtin/for-each-ref.c:34
+msgid "quote placeholders suitably for Tcl"
+msgstr "выводить указатели места заполнения в подходящем формате для Tcl"
 
-#: builtin/commit.c:1633
-msgid "force edit of commit"
-msgstr "принудительно редактировать коммит"
+#: builtin/for-each-ref.c:37
+msgid "show only <n> matched refs"
+msgstr "показать только <n> совпадающих ссылок"
 
-#: builtin/commit.c:1634
-msgid "default"
-msgstr "по-умолчанию"
+#: builtin/for-each-ref.c:39 builtin/tag.c:433
+msgid "respect format colors"
+msgstr "использовать цвета из формата"
 
-#: builtin/commit.c:1634 builtin/tag.c:391
-msgid "how to strip spaces and #comments from message"
-msgstr "как удалять пробелы и #комментарии из сообщения коммита"
+#: builtin/for-each-ref.c:42
+msgid "print only refs which points at the given object"
+msgstr "вывод только ссылок, которые указывают на переданный объект"
 
-#: builtin/commit.c:1635
-msgid "include status in commit message template"
-msgstr "включить статус файлов в шаблон сообщения коммита"
+#: builtin/for-each-ref.c:44
+msgid "print only refs that are merged"
+msgstr "вывод только слитых ссылок"
 
-#: builtin/commit.c:1637 builtin/merge.c:237 builtin/pull.c:179
-#: builtin/revert.c:113
-msgid "GPG sign commit"
-msgstr "подписать коммит с помощью GPG"
+#: builtin/for-each-ref.c:45
+msgid "print only refs that are not merged"
+msgstr "вывод только не слитых ссылок"
 
-#: builtin/commit.c:1640
-msgid "Commit contents options"
-msgstr "Опции содержимого коммита"
+#: builtin/for-each-ref.c:46
+msgid "print only refs which contain the commit"
+msgstr "вывод только ссылок, которые содержат коммит"
 
-#: builtin/commit.c:1641
-msgid "commit all changed files"
-msgstr "закоммитить все измененные файлы"
+#: builtin/for-each-ref.c:47
+msgid "print only refs which don't contain the commit"
+msgstr "вывод только ссылок, которые не содержат коммит"
 
-#: builtin/commit.c:1642
-msgid "add specified files to index for commit"
-msgstr "добавить указанные файлы в индекс для коммита"
+#: builtin/fsck.c:88 builtin/fsck.c:160 builtin/fsck.c:161
+msgid "unknown"
+msgstr ""
 
-#: builtin/commit.c:1643
-msgid "interactively add files"
-msgstr "интерактивное добавление файлов"
+#. TRANSLATORS: e.g. error in tree 01bfda: <more explanation>
+#: builtin/fsck.c:120 builtin/fsck.c:136
+#, c-format
+msgid "error in %s %s: %s"
+msgstr ""
 
-#: builtin/commit.c:1644
-msgid "interactively add changes"
-msgstr "интерактивное добавление изменений"
+#. TRANSLATORS: e.g. warning in tree 01bfda: <more explanation>
+#: builtin/fsck.c:131
+#, c-format
+msgid "warning in %s %s: %s"
+msgstr ""
 
-#: builtin/commit.c:1645
-msgid "commit only specified files"
-msgstr "закоммитить только указанные файлы"
+#: builtin/fsck.c:157 builtin/fsck.c:159
+#, c-format
+msgid "broken link from %7s %s"
+msgstr ""
 
-#: builtin/commit.c:1646
-msgid "bypass pre-commit and commit-msg hooks"
-msgstr "пропустить перехватчик pre-commit и commit-msg"
+#: builtin/fsck.c:168
+msgid "wrong object type in link"
+msgstr ""
 
-#: builtin/commit.c:1647
-msgid "show what would be committed"
-msgstr "показать, что будет закоммичено"
+#: builtin/fsck.c:184
+#, c-format
+msgid ""
+"broken link from %7s %s\n"
+"              to %7s %s"
+msgstr ""
 
-#: builtin/commit.c:1658
-msgid "amend previous commit"
-msgstr "исправить предыдущий коммит"
+#: builtin/fsck.c:295
+#, c-format
+msgid "missing %s %s"
+msgstr ""
 
-#: builtin/commit.c:1659
-msgid "bypass post-rewrite hook"
-msgstr "пропустить перехватчик post-rewrite"
+#: builtin/fsck.c:321
+#, c-format
+msgid "unreachable %s %s"
+msgstr ""
 
-#: builtin/commit.c:1664
-msgid "ok to record an empty change"
-msgstr "разрешить запись пустого коммита"
+#: builtin/fsck.c:340
+#, c-format
+msgid "dangling %s %s"
+msgstr ""
 
-#: builtin/commit.c:1666
-msgid "ok to record a change with an empty message"
-msgstr "разрешить запись изменений с пустым сообщением"
+#: builtin/fsck.c:349
+msgid "could not create lost-found"
+msgstr ""
 
-#: builtin/commit.c:1696
-msgid "could not parse HEAD commit"
-msgstr "не удалось разобрать HEAD коммит"
+#: builtin/fsck.c:360
+#, c-format
+msgid "could not finish '%s'"
+msgstr "не удалось закончить '%s'"
 
-#: builtin/commit.c:1741
+#: builtin/fsck.c:377
 #, c-format
-msgid "Corrupt MERGE_HEAD file (%s)"
-msgstr "Файл MERGE_HEAD поврежден (%s)"
+msgid "Checking %s"
+msgstr ""
 
-#: builtin/commit.c:1748
-msgid "could not read MERGE_MODE"
-msgstr "не удалось прочитать MERGE_MODE"
+#: builtin/fsck.c:415
+#, c-format
+msgid "Checking connectivity (%d objects)"
+msgstr ""
 
-#: builtin/commit.c:1767
+#: builtin/fsck.c:434
 #, c-format
-msgid "could not read commit message: %s"
-msgstr "не удалось открыть сообщение коммита: %s"
+msgid "Checking %s %s"
+msgstr ""
+
+#: builtin/fsck.c:438
+msgid "broken links"
+msgstr ""
 
-#: builtin/commit.c:1778
+#: builtin/fsck.c:447
 #, c-format
-msgid "Aborting commit due to empty commit message.\n"
-msgstr "Отмена коммита из-за пустого сообщения коммита.\n"
+msgid "root %s"
+msgstr ""
 
-#: builtin/commit.c:1783
+#: builtin/fsck.c:455
 #, c-format
-msgid "Aborting commit; you did not edit the message.\n"
-msgstr "Отмена коммита; вы не изменили сообщение.\n"
+msgid "tagged %s %s (%s) in %s"
+msgstr ""
 
-#: builtin/commit.c:1831
-msgid ""
-"Repository has been updated, but unable to write\n"
-"new_index file. Check that disk is not full and quota is\n"
-"not exceeded, and then \"git reset HEAD\" to recover."
-msgstr "Репозиторий был обновлен, но не удалось записать файл new_index. Удостоверьтесь, что на диске есть свободное место и квота не исчерпана, а после этого запустите «git reset HEAD» для восстановления."
+#: builtin/fsck.c:484
+#, c-format
+msgid "%s: object corrupt or missing"
+msgstr ""
 
-#: builtin/config.c:10
-msgid "git config [<options>]"
-msgstr "git config [<опции>]"
+#: builtin/fsck.c:509
+#, c-format
+msgid "%s: invalid reflog entry %s"
+msgstr ""
 
-#: builtin/config.c:58
-msgid "Config file location"
-msgstr "Размещение файла конфигурации"
+#: builtin/fsck.c:523
+#, c-format
+msgid "Checking reflog %s->%s"
+msgstr ""
 
-#: builtin/config.c:59
-msgid "use global config file"
-msgstr "использовать глобальный файл конфигурации"
+#: builtin/fsck.c:557
+#, c-format
+msgid "%s: invalid sha1 pointer %s"
+msgstr ""
 
-#: builtin/config.c:60
-msgid "use system config file"
-msgstr "использовать системный файл конфигурации"
+#: builtin/fsck.c:564
+#, c-format
+msgid "%s: not a commit"
+msgstr ""
 
-#: builtin/config.c:61
-msgid "use repository config file"
-msgstr "использовать файл конфигурации репозитория"
+#: builtin/fsck.c:619
+msgid "notice: No default references"
+msgstr ""
 
-#: builtin/config.c:62
-msgid "use given config file"
-msgstr "использовать указанный файл конфигурации"
+#: builtin/fsck.c:634
+#, c-format
+msgid "%s: object corrupt or missing: %s"
+msgstr ""
 
-#: builtin/config.c:63
-msgid "blob-id"
-msgstr "идент-двоичн-объекта"
+#: builtin/fsck.c:647
+#, c-format
+msgid "%s: object could not be parsed: %s"
+msgstr ""
 
-#: builtin/config.c:63
-msgid "read config from given blob object"
-msgstr "прочитать настройки из указанного двоичного объекта"
+#: builtin/fsck.c:667
+#, c-format
+msgid "bad sha1 file: %s"
+msgstr ""
 
-#: builtin/config.c:64
-msgid "Action"
-msgstr "Действие"
+#: builtin/fsck.c:682
+msgid "Checking object directory"
+msgstr ""
 
-#: builtin/config.c:65
-msgid "get value: name [value-regex]"
-msgstr "получить значение: имя [шаблон-значений]"
+#: builtin/fsck.c:685
+msgid "Checking object directories"
+msgstr "Проверка каталогов объектов"
 
-#: builtin/config.c:66
-msgid "get all values: key [value-regex]"
-msgstr "получить все значения: ключ [шаблон-значений]"
+#: builtin/fsck.c:700
+#, c-format
+msgid "Checking %s link"
+msgstr ""
 
-#: builtin/config.c:67
-msgid "get values for regexp: name-regex [value-regex]"
-msgstr "получить значения по шаблону: шаблон-имен [шаблон-значений]"
+#: builtin/fsck.c:705 builtin/index-pack.c:841
+#, c-format
+msgid "invalid %s"
+msgstr "неправильный %s"
 
-#: builtin/config.c:68
-msgid "get value specific for the URL: section[.var] URL"
-msgstr "получить значение, специфичное для URL: раздел[.переменная] URL"
+#: builtin/fsck.c:712
+#, c-format
+msgid "%s points to something strange (%s)"
+msgstr ""
 
-#: builtin/config.c:69
-msgid "replace all matching variables: name value [value_regex]"
-msgstr "заменить все соответствующие переменные: имя значение [шаблон-значений]"
+#: builtin/fsck.c:718
+#, c-format
+msgid "%s: detached HEAD points at nothing"
+msgstr ""
 
-#: builtin/config.c:70
-msgid "add a new variable: name value"
-msgstr "добавить новую переменную: имя значение"
+#: builtin/fsck.c:722
+#, c-format
+msgid "notice: %s points to an unborn branch (%s)"
+msgstr ""
 
-#: builtin/config.c:71
-msgid "remove a variable: name [value-regex]"
-msgstr "удалить переменную: имя [шаблон-значений]"
+#: builtin/fsck.c:734
+msgid "Checking cache tree"
+msgstr ""
 
-#: builtin/config.c:72
-msgid "remove all matches: name [value-regex]"
-msgstr "удалить все совпадающие: имя [шаблон-значений]"
+#: builtin/fsck.c:739
+#, c-format
+msgid "%s: invalid sha1 pointer in cache-tree"
+msgstr ""
 
-#: builtin/config.c:73
-msgid "rename section: old-name new-name"
-msgstr "переименовать раздел: старое-имя новое-имя"
+#: builtin/fsck.c:750
+msgid "non-tree in cache-tree"
+msgstr ""
 
-#: builtin/config.c:74
-msgid "remove a section: name"
-msgstr "удалить раздел: имя"
+#: builtin/fsck.c:781
+msgid "git fsck [<options>] [<object>...]"
+msgstr "git fsck [<опции>] [<объект>…]"
 
-#: builtin/config.c:75
-msgid "list all"
-msgstr "показать весь список"
+#: builtin/fsck.c:787
+msgid "show unreachable objects"
+msgstr "показать недоступные объекты"
 
-#: builtin/config.c:76
-msgid "open an editor"
-msgstr "открыть в редакторе"
+#: builtin/fsck.c:788
+msgid "show dangling objects"
+msgstr "показать объекты, на которые нет ссылок"
 
-#: builtin/config.c:77
-msgid "find the color configured: slot [default]"
-msgstr "найти настроенный цвет: раздел [по-умолчанию]"
+#: builtin/fsck.c:789
+msgid "report tags"
+msgstr "вывести отчет по меткам"
 
-#: builtin/config.c:78
-msgid "find the color setting: slot [stdout-is-tty]"
-msgstr "проверить, существует ли настроенный цвет: раздел [stdout-есть-tty]"
+#: builtin/fsck.c:790
+msgid "report root nodes"
+msgstr "вывести отчет по корневым узлам"
 
-#: builtin/config.c:79
-msgid "Type"
-msgstr "Тип"
+#: builtin/fsck.c:791
+msgid "make index objects head nodes"
+msgstr "воспринимать объекты в индексе как корневые узлы"
 
-#: builtin/config.c:80
-msgid "value is \"true\" or \"false\""
-msgstr "значение — это «true» (правда) или «false» (ложь)"
+#: builtin/fsck.c:792
+msgid "make reflogs head nodes (default)"
+msgstr "создать корневые узлы журналов ссылок (по умолчанию)"
 
-#: builtin/config.c:81
-msgid "value is decimal number"
-msgstr "значение — это десятичное число"
+#: builtin/fsck.c:793
+msgid "also consider packs and alternate objects"
+msgstr "также проверять пакеты и альтернативные объекты"
 
-#: builtin/config.c:82
-msgid "value is --bool or --int"
-msgstr "значение — это --bool или --int"
+#: builtin/fsck.c:794
+msgid "check only connectivity"
+msgstr "только проверить соединение"
 
-#: builtin/config.c:83
-msgid "value is a path (file or directory name)"
-msgstr "значение — это путь (к файлу или каталогу)"
+#: builtin/fsck.c:795
+msgid "enable more strict checking"
+msgstr "использовать более строгую проверку"
 
-#: builtin/config.c:84
-msgid "value is an expiry date"
-msgstr "значение - это дата окончания срока действия"
+#: builtin/fsck.c:797
+msgid "write dangling objects in .git/lost-found"
+msgstr "записать объекты на которые нет ссылок в .git/lost-found"
 
-#: builtin/config.c:85
-msgid "Other"
-msgstr "Другое"
+#: builtin/fsck.c:798 builtin/prune.c:132
+msgid "show progress"
+msgstr "показать прогресс выполнения"
 
-#: builtin/config.c:86
-msgid "terminate values with NUL byte"
-msgstr "завершать значения НУЛЕВЫМ байтом"
+#: builtin/fsck.c:799
+msgid "show verbose names for reachable objects"
+msgstr "показать подробные имена для недоступных объектов"
 
-#: builtin/config.c:87
-msgid "show variable names only"
-msgstr "показывать только имена переменных"
+#: builtin/fsck.c:859 builtin/index-pack.c:224
+msgid "Checking objects"
+msgstr "Проверка объектов"
 
-#: builtin/config.c:88
-msgid "respect include directives on lookup"
-msgstr "учитывать директивы include (включения файлов) при запросе"
+#: builtin/fsck.c:887
+#, c-format
+msgid "%s: object missing"
+msgstr ""
 
-#: builtin/config.c:89
-msgid "show origin of config (file, standard input, blob, command line)"
-msgstr "показать источник настройки (файл, стандартный ввод, двоичный объект, командная строка)"
+#: builtin/fsck.c:899
+#, c-format
+msgid "invalid parameter: expected sha1, got '%s'"
+msgstr ""
 
-#: builtin/config.c:335
-msgid "unable to parse default color value"
-msgstr "не удалось разобрать значение цвета по умолчанию"
+#: builtin/gc.c:34
+msgid "git gc [<options>]"
+msgstr "git gc [<опции>]"
 
-#: builtin/config.c:479
+#: builtin/gc.c:90
 #, c-format
-msgid ""
-"# This is Git's per-user configuration file.\n"
-"[user]\n"
-"# Please adapt and uncomment the following lines:\n"
-"#\tname = %s\n"
-"#\temail = %s\n"
-msgstr "# Это файл конфигурации пользователя Git.\n[user]\n# Пожалуйста, адаптируйте и раскомментируйте следующие строки:\n#\tuser = %s\n#\temail = %s\n"
-
-#: builtin/config.c:507
-msgid "--local can only be used inside a git repository"
-msgstr "--local можно использовать только внутри git репозитория"
+msgid "Failed to fstat %s: %s"
+msgstr "Не удалось выполнить fstat %s: %s"
 
-#: builtin/config.c:632
+#: builtin/gc.c:126
 #, c-format
-msgid "cannot create configuration file %s"
-msgstr "не удалось создать файл конфигурации %s"
+msgid "failed to parse '%s' value '%s'"
+msgstr ""
 
-#: builtin/config.c:645
+#: builtin/gc.c:476 builtin/init-db.c:55
 #, c-format
-msgid ""
-"cannot overwrite multiple values with a single value\n"
-"       Use a regexp, --add or --replace-all to change %s."
-msgstr "нельзя перезаписать несколько значений одним\n       Используйте регулярные выражения, параметры --add или --replace-all, чтобы изменить %s."
+msgid "cannot stat '%s'"
+msgstr "не удалось выполнить stat для «%s»"
 
-#: builtin/count-objects.c:88
-msgid "git count-objects [-v] [-H | --human-readable]"
-msgstr "git count-objects [-v] [-H | --human-readable]"
+#: builtin/gc.c:485 builtin/notes.c:240 builtin/tag.c:519
+#, c-format
+msgid "cannot read '%s'"
+msgstr "не удалось прочитать «%s»"
 
-#: builtin/count-objects.c:98
-msgid "print sizes in human readable format"
-msgstr "вывод размеров в удобочитаемом для человека виде"
+#: builtin/gc.c:492
+#, c-format
+msgid ""
+"The last gc run reported the following. Please correct the root cause\n"
+"and remove %s.\n"
+"Automatic cleanup will not be performed until the file is removed.\n"
+"\n"
+"%s"
+msgstr "Последний запуск gc сообщил следующее. Пожалуйста, исправьте ошибку и удалите %s.\nАвтоматическая очистка репозитория не будет производиться, пока этот файл не удалён.\n\n%s"
 
-#: builtin/describe.c:22
-msgid "git describe [<options>] [<commit-ish>...]"
-msgstr "git describe [<опции>] [<указатель-коммита>…]"
+#: builtin/gc.c:540
+msgid "prune unreferenced objects"
+msgstr "почистить объекты, на которые нет ссылок"
 
-#: builtin/describe.c:23
-msgid "git describe [<options>] --dirty"
-msgstr "git describe [<опции>] --dirty"
+#: builtin/gc.c:542
+msgid "be more thorough (increased runtime)"
+msgstr "проверять более внимательно (занимает больше времени)"
 
-#: builtin/describe.c:57
-msgid "head"
-msgstr "указатель на ветку"
+#: builtin/gc.c:543
+msgid "enable auto-gc mode"
+msgstr "включить режим auto-gc"
 
-#: builtin/describe.c:57
-msgid "lightweight"
-msgstr "легковесный"
+#: builtin/gc.c:546
+msgid "force running gc even if there may be another gc running"
+msgstr "принудительно запустить gc, даже есть другая копия gc уже запущена"
 
-#: builtin/describe.c:57
-msgid "annotated"
-msgstr "аннотированный"
+#: builtin/gc.c:549
+msgid "repack all other packs except the largest pack"
+msgstr ""
 
-#: builtin/describe.c:267
+#: builtin/gc.c:566
 #, c-format
-msgid "annotated tag %s not available"
-msgstr "аннотированная метка %s не доступна"
+msgid "failed to parse gc.logexpiry value %s"
+msgstr ""
 
-#: builtin/describe.c:271
+#: builtin/gc.c:577
 #, c-format
-msgid "annotated tag %s has no embedded name"
-msgstr "аннотированная метка %s не содержит встроенного названия"
+msgid "failed to parse prune expiry value %s"
+msgstr ""
 
-#: builtin/describe.c:273
+#: builtin/gc.c:597
 #, c-format
-msgid "tag '%s' is really '%s' here"
-msgstr "метка «%s» уже здесь «%s»"
+msgid "Auto packing the repository in background for optimum performance.\n"
+msgstr "Автоматическая упаковка репозитория в фоне, для оптимальной производительности.\n"
 
-#: builtin/describe.c:314
+#: builtin/gc.c:599
 #, c-format
-msgid "no tag exactly matches '%s'"
-msgstr "нет меток, точно соответствующих «%s»"
+msgid "Auto packing the repository for optimum performance.\n"
+msgstr "Автоматическая упаковка репозитория, для оптимальной производительности.\n"
 
-#: builtin/describe.c:316
+#: builtin/gc.c:600
 #, c-format
-msgid "No exact match on refs or tags, searching to describe\n"
-msgstr "Нет точных совпадений по ссылкам или тегам, ищу описания\n"
+msgid "See \"git help gc\" for manual housekeeping.\n"
+msgstr "Смотрите «git help gc» руководства по ручной очистке.\n"
 
-#: builtin/describe.c:363
+#: builtin/gc.c:640
 #, c-format
-msgid "finished search at %s\n"
-msgstr "поиск окончен на %s\n"
+msgid ""
+"gc is already running on machine '%s' pid %<PRIuMAX> (use --force if not)"
+msgstr "gc уже запущен на этом компьютере «%s» pid %<PRIuMAX> (если нет, используйте --force)"
 
-#: builtin/describe.c:389
-#, c-format
+#: builtin/gc.c:693
 msgid ""
-"No annotated tags can describe '%s'.\n"
-"However, there were unannotated tags: try --tags."
-msgstr "Нет аннотированных меток, которые могут описать «%s».\nНо имеются неаннотированные метки: попробуйте добавить параметр --tags."
+"There are too many unreachable loose objects; run 'git prune' to remove "
+"them."
+msgstr "Имеется слишком много объектов, на которые нет ссылок; запустите «git prune» для их удаления."
+
+#: builtin/grep.c:29
+msgid "git grep [<options>] [-e] <pattern> [<rev>...] [[--] <path>...]"
+msgstr "git grep [<опции>] [-e] <шаблон> [<редакция>…] [[--] <путь>…]"
 
-#: builtin/describe.c:393
+#: builtin/grep.c:225
 #, c-format
-msgid ""
-"No tags can describe '%s'.\n"
-"Try --always, or create some tags."
-msgstr "Нет меток, которые могут описать «%s….\nПопробуйте добавить параметр --always или создать какие-нибудь метки."
+msgid "grep: failed to create thread: %s"
+msgstr "grep: сбой создания потока: %s"
 
-#: builtin/describe.c:423
+#: builtin/grep.c:279
 #, c-format
-msgid "traversed %lu commits\n"
-msgstr "посещено %lu коммитов\n"
+msgid "invalid number of threads specified (%d) for %s"
+msgstr "указано недопустимое количество потоков (%d) для %s"
 
-#: builtin/describe.c:426
+#. TRANSLATORS: %s is the configuration
+#. variable for tweaking threads, currently
+#. grep.threads
+#: builtin/grep.c:287 builtin/index-pack.c:1514 builtin/index-pack.c:1705
+#: builtin/pack-objects.c:2720
 #, c-format
-msgid ""
-"more than %i tags found; listed %i most recent\n"
-"gave up search at %s\n"
-msgstr "более %i меток найдено; показано последние %i\nостановлен поиск после %s\n"
+msgid "no threads support, ignoring %s"
+msgstr "нет поддержки потоков, игнорирование %s"
 
-#: builtin/describe.c:494
+#: builtin/grep.c:466 builtin/grep.c:590 builtin/grep.c:631
 #, c-format
-msgid "describe %s\n"
-msgstr "описать %s\n"
+msgid "unable to read tree (%s)"
+msgstr "не удалось прочитать дерево (%s)"
 
-#: builtin/describe.c:497 builtin/log.c:500
+#: builtin/grep.c:646
 #, c-format
-msgid "Not a valid object name %s"
-msgstr "Недопустимое имя объекта %s"
+msgid "unable to grep from object of type %s"
+msgstr "не удалось выполнить grep из объекта типа %s"
 
-#: builtin/describe.c:505
+#: builtin/grep.c:712
 #, c-format
-msgid "%s is neither a commit nor blob"
-msgstr "%s не является коммитом или двоичным объектом"
+msgid "switch `%c' expects a numerical value"
+msgstr "параметр «%c» ожидает числовое значение"
 
-#: builtin/describe.c:519
-msgid "find the tag that comes after the commit"
-msgstr "поиск метки, которая идет после коммита"
+#: builtin/grep.c:811
+msgid "search in index instead of in the work tree"
+msgstr "искать в индексе, а не в рабочем каталоге"
 
-#: builtin/describe.c:520
-msgid "debug search strategy on stderr"
-msgstr "вывод отладочной информации стратегии поиска на стандартный вывод"
+#: builtin/grep.c:813
+msgid "find in contents not managed by git"
+msgstr "искать в содержимом не управляемым git"
 
-#: builtin/describe.c:521
-msgid "use any ref"
-msgstr "использовать любую ссылку"
+#: builtin/grep.c:815
+msgid "search in both tracked and untracked files"
+msgstr "искать и в отслеживаемых, и в неотслеживаемых файлах"
 
-#: builtin/describe.c:522
-msgid "use any tag, even unannotated"
-msgstr "использовать любую метку, даже неаннотированную"
+#: builtin/grep.c:817
+msgid "ignore files specified via '.gitignore'"
+msgstr "игнорировать файлы указанные в «.gitignore»"
 
-#: builtin/describe.c:523
-msgid "always use long format"
-msgstr "всегда использовать длинный формат вывода"
+#: builtin/grep.c:819
+msgid "recursively search in each submodule"
+msgstr "рекурсивный поиск по всем подмодулям"
 
-#: builtin/describe.c:524
-msgid "only follow first parent"
-msgstr "следовать только за первым родителем"
+#: builtin/grep.c:822
+msgid "show non-matching lines"
+msgstr "искать в несовпадающих строках"
 
-#: builtin/describe.c:527
-msgid "only output exact matches"
-msgstr "выводить только точные совпадения"
+#: builtin/grep.c:824
+msgid "case insensitive matching"
+msgstr "без учета регистра"
 
-#: builtin/describe.c:529
-msgid "consider <n> most recent tags (default: 10)"
-msgstr "рассматривать последние <n> меток (по умолчанию: 10)"
+#: builtin/grep.c:826
+msgid "match patterns only at word boundaries"
+msgstr "искать совпадения шаблона только на границах слов"
 
-#: builtin/describe.c:531
-msgid "only consider tags matching <pattern>"
-msgstr "рассматривать только метки по <шаблону>"
+#: builtin/grep.c:828
+msgid "process binary files as text"
+msgstr "обработка двоичных файлов как текста"
 
-#: builtin/describe.c:533
-msgid "do not consider tags matching <pattern>"
-msgstr "не учитывать метки, которые соответствуют <шаблону>"
+#: builtin/grep.c:830
+msgid "don't match patterns in binary files"
+msgstr "не искать совпадения шаблона в двоичных файлах"
 
-#: builtin/describe.c:535 builtin/name-rev.c:406
-msgid "show abbreviated commit object as fallback"
-msgstr "если не найдено, показать сокращенный номер редакции коммита"
+#: builtin/grep.c:833
+msgid "process binary files with textconv filters"
+msgstr "обрабатываться двоичные файлы с помощью фильтров textconv"
 
-#: builtin/describe.c:536 builtin/describe.c:539
-msgid "mark"
-msgstr "пометка"
+#: builtin/grep.c:835
+msgid "search in subdirectories (default)"
+msgstr ""
 
-#: builtin/describe.c:537
-msgid "append <mark> on dirty working tree (default: \"-dirty\")"
-msgstr "добавить <пометку> при измененном рабочем каталоге (по умолчанию: «-dirty»)"
+#: builtin/grep.c:837
+msgid "descend at most <depth> levels"
+msgstr "на глубине максиму <глубина> уровней"
 
-#: builtin/describe.c:540
-msgid "append <mark> on broken working tree (default: \"-broken\")"
-msgstr "добавить <пометку> на повреждённое рабочее дерево (по умолчанию: «-broken»)"
+#: builtin/grep.c:841
+msgid "use extended POSIX regular expressions"
+msgstr "использовать расширенные регулярные выражения POSIX"
 
-#: builtin/describe.c:558
-msgid "--long is incompatible with --abbrev=0"
-msgstr "--long несовместимо с --abbrev=0"
+#: builtin/grep.c:844
+msgid "use basic POSIX regular expressions (default)"
+msgstr "использовать базовые регулярные выражения POSIX (по умолчанию)"
 
-#: builtin/describe.c:587
-msgid "No names found, cannot describe anything."
-msgstr "Имена не найдены, не могу ничего описать."
+#: builtin/grep.c:847
+msgid "interpret patterns as fixed strings"
+msgstr "интерпретировать шаблоны как фиксированные строки"
 
-#: builtin/describe.c:637
-msgid "--dirty is incompatible with commit-ishes"
-msgstr "--dirty несовместимо с указанием указателей коммитов"
+#: builtin/grep.c:850
+msgid "use Perl-compatible regular expressions"
+msgstr "использовать Perl-совместимые регулярные выражения"
 
-#: builtin/describe.c:639
-msgid "--broken is incompatible with commit-ishes"
-msgstr "--broken несовместимо с указанием указателей коммитов"
+#: builtin/grep.c:853
+msgid "show line numbers"
+msgstr "вывести номера строк"
 
-#: builtin/diff.c:83
-#, c-format
-msgid "'%s': not a regular file or symlink"
-msgstr "«%s»: не является обычным файлом или символьной ссылкой"
+#: builtin/grep.c:854
+msgid "show column number of first match"
+msgstr ""
 
-#: builtin/diff.c:234
-#, c-format
-msgid "invalid option: %s"
-msgstr "неправильный параметр: %s"
+#: builtin/grep.c:855
+msgid "don't show filenames"
+msgstr "не выводить имена файлов"
 
-#: builtin/diff.c:356
-msgid "Not a git repository"
-msgstr "Не найден git репозитоий"
+#: builtin/grep.c:856
+msgid "show filenames"
+msgstr "выводить имена файлов"
 
-#: builtin/diff.c:399
-#, c-format
-msgid "invalid object '%s' given."
-msgstr "передан неправильный объект «%s»."
+#: builtin/grep.c:858
+msgid "show filenames relative to top directory"
+msgstr "выводить имена файлов относительно каталога репозитория"
 
-#: builtin/diff.c:408
-#, c-format
-msgid "more than two blobs given: '%s'"
-msgstr "передано больше двух двоичных объектов: «%s»"
+#: builtin/grep.c:860
+msgid "show only filenames instead of matching lines"
+msgstr "выводить только имена файлов, а не совпадающие строки"
 
-#: builtin/diff.c:413
-#, c-format
-msgid "unhandled object '%s' given."
-msgstr "передан необработанный объект «%s»."
+#: builtin/grep.c:862
+msgid "synonym for --files-with-matches"
+msgstr "синоним для --files-with-matches"
 
-#: builtin/difftool.c:29
-msgid "git difftool [<options>] [<commit> [<commit>]] [--] [<path>...]"
-msgstr "git difftool [<опции>] [<коммит> [<коммит>]] [--] [<путь>…]"
+#: builtin/grep.c:865
+msgid "show only the names of files without match"
+msgstr "выводить только несовпадающие имена файлов"
+
+#: builtin/grep.c:867
+msgid "print NUL after filenames"
+msgstr "выводить двоичный НОЛЬ после списка имен файлов"
+
+#: builtin/grep.c:870
+msgid "show only matching parts of a line"
+msgstr ""
+
+#: builtin/grep.c:872
+msgid "show the number of matches instead of matching lines"
+msgstr "выводить количество совпадений, а не совпадающие строки"
+
+#: builtin/grep.c:873
+msgid "highlight matches"
+msgstr "подсвечивать совпадения"
+
+#: builtin/grep.c:875
+msgid "print empty line between matches from different files"
+msgstr "выводить пустую строку после совпадений из разных файлов"
+
+#: builtin/grep.c:877
+msgid "show filename only once above matches from same file"
+msgstr "выводить имя файла только раз на несколько совпадений в одном файле"
+
+#: builtin/grep.c:880
+msgid "show <n> context lines before and after matches"
+msgstr "показать <n> строк контекста перед и после совпадения"
+
+#: builtin/grep.c:883
+msgid "show <n> context lines before matches"
+msgstr "показать <n> строк контекста перед совпадением"
+
+#: builtin/grep.c:885
+msgid "show <n> context lines after matches"
+msgstr "показать <n> строк контекста после совпадения"
+
+#: builtin/grep.c:887
+msgid "use <n> worker threads"
+msgstr "использовать <кол> рабочих потоков"
+
+#: builtin/grep.c:888
+msgid "shortcut for -C NUM"
+msgstr "тоже, что и -C КОЛИЧЕСТВО"
+
+#: builtin/grep.c:891
+msgid "show a line with the function name before matches"
+msgstr "показать строку с именем функции перед совпадением"
 
-#: builtin/difftool.c:259
-#, c-format
-msgid "failed: %d"
-msgstr "сбой: %d"
+#: builtin/grep.c:893
+msgid "show the surrounding function"
+msgstr "показать окружающую функцию"
 
-#: builtin/difftool.c:301
-#, c-format
-msgid "could not read symlink %s"
-msgstr "не удалось прочитать символьную ссылку %s"
+#: builtin/grep.c:896
+msgid "read patterns from file"
+msgstr "прочитать шаблоны из файла"
 
-#: builtin/difftool.c:303
-#, c-format
-msgid "could not read symlink file %s"
-msgstr "не удалось прочитать файл символьной ссылки %s"
+#: builtin/grep.c:898
+msgid "match <pattern>"
+msgstr "поиск соответствий с <шаблоном>"
 
-#: builtin/difftool.c:311
-#, c-format
-msgid "could not read object %s for symlink %s"
-msgstr "не удалось прочитать объект %s для символьной ссылки %s"
+#: builtin/grep.c:900
+msgid "combine patterns specified with -e"
+msgstr "объединить шаблоны указанные с помощью -e"
 
-#: builtin/difftool.c:412
-msgid ""
-"combined diff formats('-c' and '--cc') are not supported in\n"
-"directory diff mode('-d' and '--dir-diff')."
-msgstr "комбинированные форматы различий файлов(«-c» и «--cc») не поддерживаются в режиме сравнения каталогов(«-d» и «--dir-diff»)."
+#: builtin/grep.c:912
+msgid "indicate hit with exit status without output"
+msgstr "ничего не выводить, указать на совпадение с помощью кода выхода"
 
-#: builtin/difftool.c:632
-#, c-format
-msgid "both files modified: '%s' and '%s'."
-msgstr "оба файла изменены: «%s» и «%s»."
+#: builtin/grep.c:914
+msgid "show only matches from files that match all patterns"
+msgstr "показать только совпадения из файлов в которых совпадают все шаблоны"
 
-#: builtin/difftool.c:634
-msgid "working tree file has been left."
-msgstr "рабочий каталог был покинут."
+#: builtin/grep.c:916
+msgid "show parse tree for grep expression"
+msgstr "показать дерево разбора для выражения поиска"
 
-#: builtin/difftool.c:645
-#, c-format
-msgid "temporary files exist in '%s'."
-msgstr "временные файлы уже находятся в «%s»."
+#: builtin/grep.c:920
+msgid "pager"
+msgstr "пейджер"
 
-#: builtin/difftool.c:646
-msgid "you may want to cleanup or recover these."
-msgstr "возможно вы хотите их удалить или восстановить."
+#: builtin/grep.c:920
+msgid "show matching files in the pager"
+msgstr "показать совпадающие файлы с помощью программы-пейджера"
 
-#: builtin/difftool.c:695
-msgid "use `diff.guitool` instead of `diff.tool`"
-msgstr "использовать «diff.guitool» вместо «diff.tool»"
+#: builtin/grep.c:924
+msgid "allow calling of grep(1) (ignored by this build)"
+msgstr "разрешить вызов grep(1) (игнорируется в этой сборке)"
 
-#: builtin/difftool.c:697
-msgid "perform a full-directory diff"
-msgstr "выполнить пофайловое сравнение всего каталога"
+#: builtin/grep.c:988
+msgid "no pattern given"
+msgstr ""
 
-#: builtin/difftool.c:699
-msgid "do not prompt before launching a diff tool"
-msgstr "не спрашивать перед запуском утилиты сравнения"
+#: builtin/grep.c:1024
+msgid "--no-index or --untracked cannot be used with revs"
+msgstr "--no-index или --untracked нельзя использовать одновременно с указанием ревизии"
 
-#: builtin/difftool.c:705
-msgid "use symlinks in dir-diff mode"
-msgstr "использовать символьные ссылки в режиме сравнения каталога"
+#: builtin/grep.c:1032
+#, c-format
+msgid "unable to resolve revision: %s"
+msgstr "не удалось определить редакцию: %s"
 
-#: builtin/difftool.c:706
-msgid "<tool>"
-msgstr "<утилита>"
+#: builtin/grep.c:1063
+msgid "invalid option combination, ignoring --threads"
+msgstr ""
 
-#: builtin/difftool.c:707
-msgid "use the specified diff tool"
-msgstr "использовать указанную утилиту сравнения"
+#: builtin/grep.c:1066 builtin/pack-objects.c:3403
+msgid "no threads support, ignoring --threads"
+msgstr "нет поддержки потоков, игнорирование --threads"
 
-#: builtin/difftool.c:709
-msgid "print a list of diff tools that may be used with `--tool`"
-msgstr "вывести список утилит, которые можно использовать с параметром «--tool»"
+#: builtin/grep.c:1069 builtin/index-pack.c:1511 builtin/pack-objects.c:2717
+#, c-format
+msgid "invalid number of threads specified (%d)"
+msgstr "указано неправильное количество потоков (%d)"
 
-#: builtin/difftool.c:712
-msgid ""
-"make 'git-difftool' exit when an invoked diff tool returns a non - zero exit"
-" code"
-msgstr "выходить из «git-difftool», если вызванная утилита сравнения вернула не нулевой код возврата"
+#: builtin/grep.c:1092
+msgid "--open-files-in-pager only works on the worktree"
+msgstr "--open-files-in-pager работает только в рабочем каталоге"
 
-#: builtin/difftool.c:714
-msgid "<command>"
-msgstr "<команда>"
+#: builtin/grep.c:1115
+msgid "option not supported with --recurse-submodules"
+msgstr ""
 
-#: builtin/difftool.c:715
-msgid "specify a custom command for viewing diffs"
-msgstr "использовать особую команду для просмотра различий"
+#: builtin/grep.c:1121
+msgid "--cached or --untracked cannot be used with --no-index"
+msgstr ""
 
-#: builtin/difftool.c:739
-msgid "no <tool> given for --tool=<tool>"
-msgstr "не передана <утилита> для --tool=<утилита>"
+#: builtin/grep.c:1127
+msgid "--[no-]exclude-standard cannot be used for tracked contents"
+msgstr ""
 
-#: builtin/difftool.c:746
-msgid "no <cmd> given for --extcmd=<cmd>"
-msgstr "не передана <команда> для --extcmd=<команда>"
+#: builtin/grep.c:1135
+msgid "both --cached and trees are given"
+msgstr ""
 
-#: builtin/fast-export.c:26
-msgid "git fast-export [rev-list-opts]"
-msgstr "git fast-export [опции-rev-list]"
+#: builtin/hash-object.c:85
+msgid ""
+"git hash-object [-t <type>] [-w] [--path=<file> | --no-filters] [--stdin] "
+"[--] <file>..."
+msgstr "git hash-object [-t <тип>] [-w] [--path=<файл> | --no-filters] [--stdin] [--] <файл>…"
 
-#: builtin/fast-export.c:998
-msgid "show progress after <n> objects"
-msgstr "показать прогресс после <n> объектов"
+#: builtin/hash-object.c:86
+msgid "git hash-object  --stdin-paths"
+msgstr "git hash-object  --stdin-paths"
 
-#: builtin/fast-export.c:1000
-msgid "select handling of signed tags"
-msgstr "выбор обработки подписанных меток"
+#: builtin/hash-object.c:98
+msgid "type"
+msgstr "тип"
 
-#: builtin/fast-export.c:1003
-msgid "select handling of tags that tag filtered objects"
-msgstr "выбор обработки меток, которыми помечены отфильтрованные объекты"
+#: builtin/hash-object.c:98
+msgid "object type"
+msgstr "тип объекта"
 
-#: builtin/fast-export.c:1006
-msgid "Dump marks to this file"
-msgstr "Записать пометки в этот файл"
+#: builtin/hash-object.c:99
+msgid "write the object into the object database"
+msgstr "запись объекта в базу данных объектов"
 
-#: builtin/fast-export.c:1008
-msgid "Import marks from this file"
-msgstr "Импортировать пометки из этого файла"
+#: builtin/hash-object.c:101
+msgid "read the object from stdin"
+msgstr "прочитать объект из стандартного ввода"
 
-#: builtin/fast-export.c:1010
-msgid "Fake a tagger when tags lack one"
-msgstr "Подделать автора метки, если у метки он отсутствует"
+#: builtin/hash-object.c:103
+msgid "store file as is without filters"
+msgstr "сохранить файл без использования фильтров"
 
-#: builtin/fast-export.c:1012
-msgid "Output full tree for each commit"
-msgstr "Вывести полное дерево для каждого коммита"
+#: builtin/hash-object.c:104
+msgid ""
+"just hash any random garbage to create corrupt objects for debugging Git"
+msgstr "хешировать любой мусор и создавать поврежденные объекты для отладки Git"
 
-#: builtin/fast-export.c:1014
-msgid "Use the done feature to terminate the stream"
-msgstr "Использовать пометку завершения в конце потока"
+#: builtin/hash-object.c:105
+msgid "process file as it were from this path"
+msgstr "обработать файл так, будто он находится по указанному пути"
 
-#: builtin/fast-export.c:1015
-msgid "Skip output of blob data"
-msgstr "Пропустить вывод данных двоичных объектов"
+#: builtin/help.c:46
+msgid "print all available commands"
+msgstr "вывести список всех доступных команд"
 
-#: builtin/fast-export.c:1016
-msgid "refspec"
-msgstr "спецификатор ссылки"
+#: builtin/help.c:47
+msgid "exclude guides"
+msgstr "исключить руководства"
 
-#: builtin/fast-export.c:1017
-msgid "Apply refspec to exported refs"
-msgstr "Применить спецификатор ссылки к экспортируемым ссылкам"
+#: builtin/help.c:48
+msgid "print list of useful guides"
+msgstr "вывести список полезных руководств"
 
-#: builtin/fast-export.c:1018
-msgid "anonymize output"
-msgstr "сделать вывод анонимным"
+#: builtin/help.c:49
+msgid "print all configuration variable names"
+msgstr ""
 
-#: builtin/fetch.c:24
-msgid "git fetch [<options>] [<repository> [<refspec>...]]"
-msgstr "git fetch [<опции>] [<репозиторий> [<спецификатор-ссылки>…]]"
+#: builtin/help.c:51
+msgid "show man page"
+msgstr "открыть руководство в формате man"
 
-#: builtin/fetch.c:25
-msgid "git fetch [<options>] <group>"
-msgstr "git fetch [<опции>] <группа>"
+#: builtin/help.c:52
+msgid "show manual in web browser"
+msgstr "открыть руководство в веб-браузере"
 
-#: builtin/fetch.c:26
-msgid "git fetch --multiple [<options>] [(<repository> | <group>)...]"
-msgstr "git fetch --multiple [<опции>] [(<репозиторий> | <группа>)…]"
+#: builtin/help.c:54
+msgid "show info page"
+msgstr "открыть руководство в формате info"
 
-#: builtin/fetch.c:27
-msgid "git fetch --all [<options>]"
-msgstr "git fetch --all [<опции>]"
+#: builtin/help.c:56
+msgid "print command description"
+msgstr ""
 
-#: builtin/fetch.c:113 builtin/pull.c:188
-msgid "fetch from all remotes"
-msgstr "извлечь со всех внешних репозиториев"
+#: builtin/help.c:61
+msgid "git help [--all] [--guides] [--man | --web | --info] [<command>]"
+msgstr "git help [--all] [--guides] [--man | --web | --info] [<команда>]"
 
-#: builtin/fetch.c:115 builtin/pull.c:191
-msgid "append to .git/FETCH_HEAD instead of overwriting"
-msgstr "дописать к .git/FETCH_HEAD вместо перезаписи"
+#: builtin/help.c:77
+#, c-format
+msgid "unrecognized help format '%s'"
+msgstr "неопознанный формат руководства «%s»"
 
-#: builtin/fetch.c:117 builtin/pull.c:194
-msgid "path to upload pack on remote end"
-msgstr "путь к программе упаковки пакета на машине с внешним репозиторием"
+#: builtin/help.c:104
+msgid "Failed to start emacsclient."
+msgstr "Сбой при запуске emacsclient."
 
-#: builtin/fetch.c:118 builtin/pull.c:196
-msgid "force overwrite of local branch"
-msgstr "принудительная перезапись локальной ветки"
+#: builtin/help.c:117
+msgid "Failed to parse emacsclient version."
+msgstr "Сбой при определении версии emacsclient."
 
-#: builtin/fetch.c:120
-msgid "fetch from multiple remotes"
-msgstr "извлечь с нескольких внешних репозиториев"
+#: builtin/help.c:125
+#, c-format
+msgid "emacsclient version '%d' too old (< 22)."
+msgstr "версия emacsclient «%d» слишком старая (< 22)."
 
-#: builtin/fetch.c:122 builtin/pull.c:198
-msgid "fetch all tags and associated objects"
-msgstr "извлечь все метки и связанные объекты"
+#: builtin/help.c:143 builtin/help.c:165 builtin/help.c:175 builtin/help.c:183
+#, c-format
+msgid "failed to exec '%s'"
+msgstr "сбой при запуске «%s»"
 
-#: builtin/fetch.c:124
-msgid "do not fetch all tags (--no-tags)"
-msgstr "не извлекать все метки (--no-tags)"
+#: builtin/help.c:221
+#, c-format
+msgid ""
+"'%s': path for unsupported man viewer.\n"
+"Please consider using 'man.<tool>.cmd' instead."
+msgstr "«%s»: путь для неподдерживаемой программы просмотра man.\nВместо этого используйте «man.<программа>.cmd»."
 
-#: builtin/fetch.c:126
-msgid "number of submodules fetched in parallel"
-msgstr "количество подмодулей, которые будут скачаны парралельно"
+#: builtin/help.c:233
+#, c-format
+msgid ""
+"'%s': cmd for supported man viewer.\n"
+"Please consider using 'man.<tool>.path' instead."
+msgstr "«%s»: команда для неподдерживаемой программы просмотра man.\nВместо этого используйте «man.<программа>.path»."
 
-#: builtin/fetch.c:128 builtin/pull.c:201
-msgid "prune remote-tracking branches no longer on remote"
-msgstr "почистить отслеживаемые внешние ветки, которых уже нет на внешнем репозитории"
+#: builtin/help.c:350
+#, c-format
+msgid "'%s': unknown man viewer."
+msgstr "«%s»: неизвестная программа просмотра man."
 
-#: builtin/fetch.c:129 builtin/fetch.c:152 builtin/pull.c:126
-msgid "on-demand"
-msgstr "по требованию"
+#: builtin/help.c:367
+msgid "no man viewer handled the request"
+msgstr "программа просмотра man не обработала запрос"
 
-#: builtin/fetch.c:130
-msgid "control recursive fetching of submodules"
-msgstr "управление рекурсивным извлечением подмодулей"
+#: builtin/help.c:375
+msgid "no info viewer handled the request"
+msgstr "программа просмотра info не обработала запрос"
 
-#: builtin/fetch.c:134 builtin/pull.c:209
-msgid "keep downloaded pack"
-msgstr "оставить загруженный пакет данных"
+#: builtin/help.c:434 builtin/help.c:445 git.c:335
+#, c-format
+msgid "'%s' is aliased to '%s'"
+msgstr "«%s» — это сокращение для «%s»"
 
-#: builtin/fetch.c:136
-msgid "allow updating of HEAD ref"
-msgstr "разрешить обновление ссылки HEAD"
+#: builtin/help.c:448 git.c:364
+#, c-format
+msgid "bad alias.%s string: %s"
+msgstr ""
 
-#: builtin/fetch.c:139 builtin/fetch.c:145 builtin/pull.c:212
-msgid "deepen history of shallow clone"
-msgstr "улугубить историю частичного клона"
+#: builtin/help.c:477 builtin/help.c:507
+#, c-format
+msgid "usage: %s%s"
+msgstr "использование: %s%s"
 
-#: builtin/fetch.c:141
-msgid "deepen history of shallow repository based on time"
-msgstr "углубить историю частичного клона основываясь на времени"
+#: builtin/help.c:491
+msgid "'git help config' for more information"
+msgstr ""
 
-#: builtin/fetch.c:147 builtin/pull.c:215
-msgid "convert to a complete repository"
-msgstr "преобразовать в полный репозиторий"
+#: builtin/index-pack.c:184
+#, c-format
+msgid "object type mismatch at %s"
+msgstr "несоответствие типа объекта на %s"
 
-#: builtin/fetch.c:149 builtin/log.c:1463
-msgid "dir"
-msgstr "каталог"
+#: builtin/index-pack.c:204
+#, c-format
+msgid "did not receive expected object %s"
+msgstr "ожидаемый объект не получен на %s"
 
-#: builtin/fetch.c:150
-msgid "prepend this to submodule path output"
-msgstr "присоединять это спереди к выводу путей подмодуля"
+#: builtin/index-pack.c:207
+#, c-format
+msgid "object %s: expected type %s, found %s"
+msgstr "объект %s: ожидаемый тип %s, получен %s"
+
+#: builtin/index-pack.c:257
+#, c-format
+msgid "cannot fill %d byte"
+msgid_plural "cannot fill %d bytes"
+msgstr[0] "не удалось заполнить %d байт"
+msgstr[1] "не удалось заполнить %d байта"
+msgstr[2] "не удалось заполнить %d байтов"
+msgstr[3] "не удалось заполнить %d байтов"
 
-#: builtin/fetch.c:153
-msgid ""
-"default for recursive fetching of submodules (lower priority than config "
-"files)"
-msgstr "настроить по умолчанию рекурсивное извлечение подмодулей (более низкий приоритет, чем файлы конфигурации)"
+#: builtin/index-pack.c:267
+msgid "early EOF"
+msgstr "неожиданный конец файла"
 
-#: builtin/fetch.c:157 builtin/pull.c:218
-msgid "accept refs that update .git/shallow"
-msgstr "принимать ссылки, которые обновляют .git/shallow"
+#: builtin/index-pack.c:268
+msgid "read error on input"
+msgstr "ошибка чтения ввода"
 
-#: builtin/fetch.c:158 builtin/pull.c:220
-msgid "refmap"
-msgstr "соответствие-ссылок"
+#: builtin/index-pack.c:280
+msgid "used more bytes than were available"
+msgstr "использовано больше байт, чем было доступно"
 
-#: builtin/fetch.c:159 builtin/pull.c:221
-msgid "specify fetch refmap"
-msgstr "указать соответствие ссылок при извлечении"
+#: builtin/index-pack.c:287 builtin/pack-objects.c:600
+msgid "pack too large for current definition of off_t"
+msgstr "пакет слишком большой для текущего определения off_t"
 
-#: builtin/fetch.c:417
-msgid "Couldn't find remote ref HEAD"
-msgstr "Не удалось найти ссылку HEAD на внешнем репозитории"
+#: builtin/index-pack.c:290 builtin/unpack-objects.c:94
+msgid "pack exceeds maximum allowed size"
+msgstr "размер пакета превышает максимальный допустимый"
 
-#: builtin/fetch.c:535
+#: builtin/index-pack.c:305 builtin/repack.c:250
 #, c-format
-msgid "configuration fetch.output contains invalid value %s"
-msgstr "опция fetch.output содержит неправильное значение для %s"
+msgid "unable to create '%s'"
+msgstr "не удалось создать «%s»"
 
-#: builtin/fetch.c:628
+#: builtin/index-pack.c:311
 #, c-format
-msgid "object %s not found"
-msgstr "объект %s не найден"
+msgid "cannot open packfile '%s'"
+msgstr "не удалось открыть файл пакета «%s»"
 
-#: builtin/fetch.c:632
-msgid "[up to date]"
-msgstr "[актуально]"
+#: builtin/index-pack.c:325
+msgid "pack signature mismatch"
+msgstr "несоответствие подписи пакета"
 
-#: builtin/fetch.c:645 builtin/fetch.c:725
-msgid "[rejected]"
-msgstr "[отклонено]"
+#: builtin/index-pack.c:327
+#, c-format
+msgid "pack version %<PRIu32> unsupported"
+msgstr "версия пакета %<PRIu32> не поддерживается"
 
-#: builtin/fetch.c:646
-msgid "can't fetch in current branch"
-msgstr "нельзя извлечь текущую ветку"
+#: builtin/index-pack.c:345
+#, c-format
+msgid "pack has bad object at offset %<PRIuMAX>: %s"
+msgstr "пакет содержит плохой объект по смещению %<PRIuMAX>: %s"
 
-#: builtin/fetch.c:655
-msgid "[tag update]"
-msgstr "[обновление метки]"
+#: builtin/index-pack.c:465
+#, c-format
+msgid "inflate returned %d"
+msgstr "программа сжатия вернула %d"
 
-#: builtin/fetch.c:656 builtin/fetch.c:689 builtin/fetch.c:705
-#: builtin/fetch.c:720
-msgid "unable to update local ref"
-msgstr "не удалось обновить локальную ссылку"
+#: builtin/index-pack.c:514
+msgid "offset value overflow for delta base object"
+msgstr "переполнение значения смещения у базового объекта дельты"
 
-#: builtin/fetch.c:675
-msgid "[new tag]"
-msgstr "[новая метка]"
+#: builtin/index-pack.c:522
+msgid "delta base offset is out of bound"
+msgstr "смещение базовой дельты вышло за допустимые пределы"
 
-#: builtin/fetch.c:678
-msgid "[new branch]"
-msgstr "[новая ветка]"
+#: builtin/index-pack.c:530
+#, c-format
+msgid "unknown object type %d"
+msgstr "неизвестный тип объекта %d"
 
-#: builtin/fetch.c:681
-msgid "[new ref]"
-msgstr "[новая ссылка]"
+#: builtin/index-pack.c:561
+msgid "cannot pread pack file"
+msgstr "не удалось выполнить pread для файла пакета"
 
-#: builtin/fetch.c:720
-msgid "forced update"
-msgstr "принудительное обновление"
+#: builtin/index-pack.c:563
+#, c-format
+msgid "premature end of pack file, %<PRIuMAX> byte missing"
+msgid_plural "premature end of pack file, %<PRIuMAX> bytes missing"
+msgstr[0] "преждевременное окончание файла пакета, %<PRIuMAX> байт отсутствует"
+msgstr[1] "преждевременное окончание файла пакета, %<PRIuMAX> байта отсутствует"
+msgstr[2] "преждевременное окончание файла пакета, %<PRIuMAX> байтов отсутствует"
+msgstr[3] "преждевременное окончание файла пакета, %<PRIuMAX> байтов отсутствует"
 
-#: builtin/fetch.c:725
-msgid "non-fast-forward"
-msgstr "без перемотки вперед"
+#: builtin/index-pack.c:589
+msgid "serious inflate inconsistency"
+msgstr "серьезное несоответствие при распаковке"
 
-#: builtin/fetch.c:770
+#: builtin/index-pack.c:734 builtin/index-pack.c:740 builtin/index-pack.c:763
+#: builtin/index-pack.c:802 builtin/index-pack.c:811
 #, c-format
-msgid "%s did not send all necessary objects\n"
-msgstr "%s не отправил все необходимые объекты\n"
+msgid "SHA1 COLLISION FOUND WITH %s !"
+msgstr "НАЙДЕНА КОЛЛИЗИЯ SHA1 С %s !"
 
-#: builtin/fetch.c:790
+#: builtin/index-pack.c:737 builtin/pack-objects.c:153
+#: builtin/pack-objects.c:213 builtin/pack-objects.c:307
 #, c-format
-msgid "reject %s because shallow roots are not allowed to be updated"
-msgstr "%s отклонено из-за того, что частичные корни не разрешено обновлять"
+msgid "unable to read %s"
+msgstr "не удалось прочитать %s"
 
-#: builtin/fetch.c:878 builtin/fetch.c:974
+#: builtin/index-pack.c:800
 #, c-format
-msgid "From %.*s\n"
-msgstr "Из %.*s\n"
+msgid "cannot read existing object info %s"
+msgstr "не удалось прочитать информацию существующего объекта %s"
 
-#: builtin/fetch.c:889
+#: builtin/index-pack.c:808
 #, c-format
-msgid ""
-"some local refs could not be updated; try running\n"
-" 'git remote prune %s' to remove any old, conflicting branches"
-msgstr "не удалось обновить некоторые локальные ссылки; попробуйте запустить «git remote prune %s», чтобы почистить старые, конфликтующие ветки"
+msgid "cannot read existing object %s"
+msgstr "не удалось прочитать существующий объект %s"
 
-#: builtin/fetch.c:944
+#: builtin/index-pack.c:822
 #, c-format
-msgid "   (%s will become dangling)"
-msgstr "   (%s будет висящей веткой)"
+msgid "invalid blob object %s"
+msgstr "неправильный файл двоичного объекта %s"
+
+#: builtin/index-pack.c:825 builtin/index-pack.c:844
+msgid "fsck error in packed object"
+msgstr ""
 
-#: builtin/fetch.c:945
+#: builtin/index-pack.c:846
 #, c-format
-msgid "   (%s has become dangling)"
-msgstr "   (%s стала висящей веткой)"
+msgid "Not all child objects of %s are reachable"
+msgstr "Не все дочерние объекты %s достижимы"
 
-#: builtin/fetch.c:977
-msgid "[deleted]"
-msgstr "[удалено]"
+#: builtin/index-pack.c:918 builtin/index-pack.c:949
+msgid "failed to apply delta"
+msgstr "сбой при применении дельты"
 
-#: builtin/fetch.c:978 builtin/remote.c:1024
-msgid "(none)"
-msgstr "(нет)"
+#: builtin/index-pack.c:1117
+msgid "Receiving objects"
+msgstr "Получение объектов"
 
-#: builtin/fetch.c:1001
-#, c-format
-msgid "Refusing to fetch into current branch %s of non-bare repository"
-msgstr "Отказ получения в текущую ветку %s не голого репозитория"
+#: builtin/index-pack.c:1117
+msgid "Indexing objects"
+msgstr "Индексирование объектов"
+
+#: builtin/index-pack.c:1151
+msgid "pack is corrupted (SHA1 mismatch)"
+msgstr "пакет поврежден (несоответствие SHA1)"
+
+#: builtin/index-pack.c:1156
+msgid "cannot fstat packfile"
+msgstr "не удалось выполнить fstat для файла пакета"
 
-#: builtin/fetch.c:1020
+#: builtin/index-pack.c:1159
+msgid "pack has junk at the end"
+msgstr "файл пакета содержит мусор в конце"
+
+#: builtin/index-pack.c:1171
+msgid "confusion beyond insanity in parse_pack_objects()"
+msgstr "безумная путаница в parse_pack_objects()"
+
+#: builtin/index-pack.c:1194
+msgid "Resolving deltas"
+msgstr "Определение изменений"
+
+#: builtin/index-pack.c:1204 builtin/pack-objects.c:2489
 #, c-format
-msgid "Option \"%s\" value \"%s\" is not valid for %s"
-msgstr "Неправильное значение «%2$s» для параметра «%1$s» для %3$s"
+msgid "unable to create thread: %s"
+msgstr "не удалось создать поток: %s"
+
+#: builtin/index-pack.c:1245
+msgid "confusion beyond insanity"
+msgstr "безумная путаница"
 
-#: builtin/fetch.c:1023
+#: builtin/index-pack.c:1251
 #, c-format
-msgid "Option \"%s\" is ignored for %s\n"
-msgstr "Параметр «%s» игнорируется для %s\n"
+msgid "completed with %d local object"
+msgid_plural "completed with %d local objects"
+msgstr[0] "завершено с %d локальным объектом"
+msgstr[1] "завершено с %d локальными объектами"
+msgstr[2] "завершено с %d локальными объектами"
+msgstr[3] "завершено с %d локальными объектами"
 
-#: builtin/fetch.c:1256
+#: builtin/index-pack.c:1263
 #, c-format
-msgid "Fetching %s\n"
-msgstr "Извлечение из %s\n"
+msgid "Unexpected tail checksum for %s (disk corruption?)"
+msgstr "Неожиданная контрольная сумма в конце %s (диск поврежден?)"
 
-#: builtin/fetch.c:1258 builtin/remote.c:97
+#: builtin/index-pack.c:1267
 #, c-format
-msgid "Could not fetch %s"
-msgstr "Не удалось извлечь %s"
+msgid "pack has %d unresolved delta"
+msgid_plural "pack has %d unresolved deltas"
+msgstr[0] "пакет содержит %d неразрешенную дельту"
+msgstr[1] "пакет содержит %d неразрешенные дельты"
+msgstr[2] "пакет содержит %d неразрешенных дельт"
+msgstr[3] "пакет содержит %d неразрешенных дельт"
 
-#: builtin/fetch.c:1276
-msgid ""
-"No remote repository specified.  Please, specify either a URL or a\n"
-"remote name from which new revisions should be fetched."
-msgstr "Не указан внешний репозиторий. Укажите URL или имя внешнего репозитория из которого должны извлекаться новые редакции."
+#: builtin/index-pack.c:1291
+#, c-format
+msgid "unable to deflate appended object (%d)"
+msgstr "нельзя сжать присоединенный объект (%d)"
 
-#: builtin/fetch.c:1299
-msgid "You need to specify a tag name."
-msgstr "Вам нужно указать имя метки."
+#: builtin/index-pack.c:1368
+#, c-format
+msgid "local object %s is corrupt"
+msgstr "локальный объект %s поврежден"
 
-#: builtin/fetch.c:1342
-msgid "Negative depth in --deepen is not supported"
-msgstr "Отрицательная грубина для --deepen не поддерживается"
+#: builtin/index-pack.c:1382
+#, c-format
+msgid "packfile name '%s' does not end with '.pack'"
+msgstr "имя пакета «%s» не оканчивается на «.pack»"
 
-#: builtin/fetch.c:1344
-msgid "--deepen and --depth are mutually exclusive"
-msgstr "--deepen и --depth нельзя использовать одновременно"
+#: builtin/index-pack.c:1407
+#, c-format
+msgid "cannot write %s file '%s'"
+msgstr ""
 
-#: builtin/fetch.c:1349
-msgid "--depth and --unshallow cannot be used together"
-msgstr "нельзя использовать одновременно --depth и --unshallow"
+#: builtin/index-pack.c:1415
+#, c-format
+msgid "cannot close written %s file '%s'"
+msgstr ""
 
-#: builtin/fetch.c:1351
-msgid "--unshallow on a complete repository does not make sense"
-msgstr "--unshallow не имеет смысла на полном репозитории"
+#: builtin/index-pack.c:1439
+msgid "error while closing pack file"
+msgstr "ошибка при закрытии файла пакета"
 
-#: builtin/fetch.c:1364
-msgid "fetch --all does not take a repository argument"
-msgstr "fetch --all не принимает имя репозитория как аргумент"
+#: builtin/index-pack.c:1453
+msgid "cannot store pack file"
+msgstr "не удалось сохранить файл пакета"
 
-#: builtin/fetch.c:1366
-msgid "fetch --all does not make sense with refspecs"
-msgstr "fetch --all не имеет смысла при указании спецификаторов ссылок"
+#: builtin/index-pack.c:1461
+msgid "cannot store index file"
+msgstr "не удалось сохранить файл индекса"
 
-#: builtin/fetch.c:1377
+#: builtin/index-pack.c:1505 builtin/pack-objects.c:2728
 #, c-format
-msgid "No such remote or remote group: %s"
-msgstr "Нет такого внешнего репозитория или группы: %s"
+msgid "bad pack.indexversion=%<PRIu32>"
+msgstr "плохой pack.indexversion=%<PRIu32>"
 
-#: builtin/fetch.c:1385
-msgid "Fetching a group and specifying refspecs does not make sense"
-msgstr "Получение группы и указание спецификаций ссылок не имеет смысла"
+#: builtin/index-pack.c:1573
+#, c-format
+msgid "Cannot open existing pack file '%s'"
+msgstr "Не удалось открыть существующий файл пакета «%s»"
 
-#: builtin/fmt-merge-msg.c:15
-msgid ""
-"git fmt-merge-msg [-m <message>] [--log[=<n>] | --no-log] [--file <file>]"
-msgstr "git fmt-merge-msg [-m <сообщение>] [--log[=<n>] | --no-log] [--file <файл>]"
+#: builtin/index-pack.c:1575
+#, c-format
+msgid "Cannot open existing pack idx file for '%s'"
+msgstr "Не удалось открыть существующий файл индекса для «%s»"
 
-#: builtin/fmt-merge-msg.c:666
-msgid "populate log with at most <n> entries from shortlog"
-msgstr "отправить в журнал <n> записей из короткого журнала"
+#: builtin/index-pack.c:1623
+#, c-format
+msgid "non delta: %d object"
+msgid_plural "non delta: %d objects"
+msgstr[0] "не дельты: %d объект"
+msgstr[1] "не дельты: %d объекта"
+msgstr[2] "не дельты: %d объектов"
+msgstr[3] "не дельты: %d объектов"
 
-#: builtin/fmt-merge-msg.c:669
-msgid "alias for --log (deprecated)"
-msgstr "сокращение для --log (устаревшее)"
+#: builtin/index-pack.c:1630
+#, c-format
+msgid "chain length = %d: %lu object"
+msgid_plural "chain length = %d: %lu objects"
+msgstr[0] "длина цепочки = %d: %lu объект"
+msgstr[1] "длина цепочки = %d: %lu объекта"
+msgstr[2] "длина цепочки = %d: %lu объектов"
+msgstr[3] "длина цепочки = %d: %lu объектов"
 
-#: builtin/fmt-merge-msg.c:672
-msgid "text"
-msgstr "текст"
+#: builtin/index-pack.c:1667
+msgid "Cannot come back to cwd"
+msgstr "Не удалось вернуться в текущий рабочий каталог"
 
-#: builtin/fmt-merge-msg.c:673
-msgid "use <text> as start of message"
-msgstr "использовать <текст> как начальное сообщение"
+#: builtin/index-pack.c:1716 builtin/index-pack.c:1719
+#: builtin/index-pack.c:1735 builtin/index-pack.c:1739
+#, c-format
+msgid "bad %s"
+msgstr "плохой %s"
 
-#: builtin/fmt-merge-msg.c:674
-msgid "file to read from"
-msgstr "файл для чтения"
+#: builtin/index-pack.c:1755
+msgid "--fix-thin cannot be used without --stdin"
+msgstr "--fix-thin нельзя использовать без --stdin"
 
-#: builtin/for-each-ref.c:10
-msgid "git for-each-ref [<options>] [<pattern>]"
-msgstr "git for-each-ref [<опции>] [<шаблон>]"
+#: builtin/index-pack.c:1757
+msgid "--stdin requires a git repository"
+msgstr "опция --stdin требует наличия репозитория git"
 
-#: builtin/for-each-ref.c:11
-msgid "git for-each-ref [--points-at <object>]"
-msgstr "git for-each-ref [--points-at <объект>]"
+#: builtin/index-pack.c:1763
+msgid "--verify with no packfile name given"
+msgstr "--verify без указания имени файла пакета"
 
-#: builtin/for-each-ref.c:12
-msgid "git for-each-ref [(--merged | --no-merged) [<commit>]]"
-msgstr "git for-each-ref [(--merged | --no-merged) [<коммит>]]"
+#: builtin/index-pack.c:1811 builtin/unpack-objects.c:580
+msgid "fsck error in pack objects"
+msgstr ""
 
-#: builtin/for-each-ref.c:13
-msgid "git for-each-ref [--contains [<commit>]] [--no-contains [<commit>]]"
-msgstr "git for-each-ref [--contains [<коммит>]] [--no-contains [<коммит>]]"
+#: builtin/init-db.c:61
+#, c-format
+msgid "cannot stat template '%s'"
+msgstr "не удалось выполнить stat для шаблона «%s»"
 
-#: builtin/for-each-ref.c:28
-msgid "quote placeholders suitably for shells"
-msgstr "выводить указатели места заполнения в подходящем формате для командного процессора"
+#: builtin/init-db.c:66
+#, c-format
+msgid "cannot opendir '%s'"
+msgstr "не удалось выполнить opendir для «%s»"
 
-#: builtin/for-each-ref.c:30
-msgid "quote placeholders suitably for perl"
-msgstr "выводить указатели места заполнения в подходящем формате для perl"
+#: builtin/init-db.c:78
+#, c-format
+msgid "cannot readlink '%s'"
+msgstr "не удалось выполнить readlink для «%s»"
 
-#: builtin/for-each-ref.c:32
-msgid "quote placeholders suitably for python"
-msgstr "выводить указатели места заполнения в подходящем формате для python"
+#: builtin/init-db.c:80
+#, c-format
+msgid "cannot symlink '%s' '%s'"
+msgstr "не удалось создать символьную ссылку «%s» на «%s»"
 
-#: builtin/for-each-ref.c:34
-msgid "quote placeholders suitably for Tcl"
-msgstr "выводить указатели места заполнения в подходящем формате для Tcl"
+#: builtin/init-db.c:86
+#, c-format
+msgid "cannot copy '%s' to '%s'"
+msgstr "не удалось скопировать файл «%s» в «%s»"
 
-#: builtin/for-each-ref.c:37
-msgid "show only <n> matched refs"
-msgstr "показать только <n> совпадающих ссылок"
+#: builtin/init-db.c:90
+#, c-format
+msgid "ignoring template %s"
+msgstr "игнорирование шаблона %s"
 
-#: builtin/for-each-ref.c:39 builtin/tag.c:414
-msgid "respect format colors"
-msgstr "использовать цвета из формата"
+#: builtin/init-db.c:121
+#, c-format
+msgid "templates not found in %s"
+msgstr ""
 
-#: builtin/for-each-ref.c:43
-msgid "print only refs which points at the given object"
-msgstr "вывод только ссылок, которые указывают на переданный объект"
+#: builtin/init-db.c:136
+#, c-format
+msgid "not copying templates from '%s': %s"
+msgstr "не копирую шаблоны из «%s»: %s"
 
-#: builtin/for-each-ref.c:45
-msgid "print only refs that are merged"
-msgstr "вывод только слитых ссылок"
+#: builtin/init-db.c:334
+#, c-format
+msgid "unable to handle file type %d"
+msgstr "не удается обработать файл типа %d"
 
-#: builtin/for-each-ref.c:46
-msgid "print only refs that are not merged"
-msgstr "вывод только не слитых ссылок"
+#: builtin/init-db.c:337
+#, c-format
+msgid "unable to move %s to %s"
+msgstr "не удается переместить файл %s в %s"
 
-#: builtin/for-each-ref.c:47
-msgid "print only refs which contain the commit"
-msgstr "вывод только ссылок, которые содержат коммит"
+#: builtin/init-db.c:354 builtin/init-db.c:357
+#, c-format
+msgid "%s already exists"
+msgstr "%s уже существует"
 
-#: builtin/for-each-ref.c:48
-msgid "print only refs which don't contain the commit"
-msgstr "вывод только ссылок, которые не содержат коммит"
+#: builtin/init-db.c:413
+#, c-format
+msgid "Reinitialized existing shared Git repository in %s%s\n"
+msgstr "Переинициализирован существующий общий репозиторий Git в %s%s\n"
 
-#: builtin/fsck.c:543
-msgid "Checking object directories"
-msgstr "Проверка каталогов объектов"
+#: builtin/init-db.c:414
+#, c-format
+msgid "Reinitialized existing Git repository in %s%s\n"
+msgstr "Переинициализирован существующий репозиторий Git в %s%s\n"
 
-#: builtin/fsck.c:635
-msgid "git fsck [<options>] [<object>...]"
-msgstr "git fsck [<опции>] [<объект>…]"
+#: builtin/init-db.c:418
+#, c-format
+msgid "Initialized empty shared Git repository in %s%s\n"
+msgstr "Инициализирован пустой общий репозиторий Git в %s%s\n"
 
-#: builtin/fsck.c:641
-msgid "show unreachable objects"
-msgstr "показать недоступные объекты"
+#: builtin/init-db.c:419
+#, c-format
+msgid "Initialized empty Git repository in %s%s\n"
+msgstr "Инициализирован пустой репозиторий Git в %s%s\n"
 
-#: builtin/fsck.c:642
-msgid "show dangling objects"
-msgstr "показать объекты, на которые нет ссылок"
+#: builtin/init-db.c:468
+msgid ""
+"git init [-q | --quiet] [--bare] [--template=<template-directory>] "
+"[--shared[=<permissions>]] [<directory>]"
+msgstr "git init [-q | --quiet] [--bare] [--template=<каталог-шаблонов>] [--shared[=<права-доступа>]] [<каталог>]"
 
-#: builtin/fsck.c:643
-msgid "report tags"
-msgstr "вывести отчет по меткам"
+#: builtin/init-db.c:491
+msgid "permissions"
+msgstr "права-доступа"
 
-#: builtin/fsck.c:644
-msgid "report root nodes"
-msgstr "вывести отчет по корневым узлам"
+#: builtin/init-db.c:492
+msgid "specify that the git repository is to be shared amongst several users"
+msgstr "укажите, если репозиторий git будет использоваться несколькими пользователями"
 
-#: builtin/fsck.c:645
-msgid "make index objects head nodes"
-msgstr "воспринимать объекты в индексе как корневые узлы"
+#: builtin/init-db.c:526 builtin/init-db.c:531
+#, c-format
+msgid "cannot mkdir %s"
+msgstr "не удалось выполнить mkdir %s"
 
-#: builtin/fsck.c:646
-msgid "make reflogs head nodes (default)"
-msgstr "создать корневые узлы журналов ссылок (по умолчанию)"
+#: builtin/init-db.c:535
+#, c-format
+msgid "cannot chdir to %s"
+msgstr "не удалось выполнить chdir в %s"
 
-#: builtin/fsck.c:647
-msgid "also consider packs and alternate objects"
-msgstr "также проверять пакеты и альтернативные объекты"
+#: builtin/init-db.c:556
+#, c-format
+msgid ""
+"%s (or --work-tree=<directory>) not allowed without specifying %s (or --git-"
+"dir=<directory>)"
+msgstr "%s (или --work-tree=<каталог>) нельзя использовать без указания %s (или --git-dir=<каталог>)"
 
-#: builtin/fsck.c:648
-msgid "check only connectivity"
-msgstr "только проверить соединение"
+#: builtin/init-db.c:584
+#, c-format
+msgid "Cannot access work tree '%s'"
+msgstr "Не удалось получить доступ к рабочему каталогу «%s»"
 
-#: builtin/fsck.c:649
-msgid "enable more strict checking"
-msgstr "использовать более строгую проверку"
+#: builtin/interpret-trailers.c:15
+msgid ""
+"git interpret-trailers [--in-place] [--trim-empty] [(--trailer "
+"<token>[(=|:)<value>])...] [<file>...]"
+msgstr "git interpret-trailers [--in-place] [--trim-empty] [(--trailer <ключ>[(=|:)<значение>])…] [<файл>…]"
 
-#: builtin/fsck.c:651
-msgid "write dangling objects in .git/lost-found"
-msgstr "записать объекты на которые нет ссылок в .git/lost-found"
+#: builtin/interpret-trailers.c:94
+msgid "edit files in place"
+msgstr "редактировать файлы на месте"
 
-#: builtin/fsck.c:652 builtin/prune.c:107
-msgid "show progress"
-msgstr "показать прогресс выполнения"
+#: builtin/interpret-trailers.c:95
+msgid "trim empty trailers"
+msgstr "удалять пустые завершители"
 
-#: builtin/fsck.c:653
-msgid "show verbose names for reachable objects"
-msgstr "показать подробные имена для недоступных объектов"
+#: builtin/interpret-trailers.c:98
+msgid "where to place the new trailer"
+msgstr "где поместить новый завершитель"
 
-#: builtin/fsck.c:714
-msgid "Checking objects"
-msgstr "Проверка объектов"
+#: builtin/interpret-trailers.c:100
+msgid "action if trailer already exists"
+msgstr "действие, если завершитель уже существует"
 
-#: builtin/gc.c:27
-msgid "git gc [<options>]"
-msgstr "git gc [<опции>]"
+#: builtin/interpret-trailers.c:102
+msgid "action if trailer is missing"
+msgstr "действие, если завершитель не существует"
 
-#: builtin/gc.c:80
-#, c-format
-msgid "Failed to fstat %s: %s"
-msgstr "Не удалось выполнить fstat %s: %s"
+#: builtin/interpret-trailers.c:104
+msgid "output only the trailers"
+msgstr "вывести только завершители"
 
-#: builtin/gc.c:312
-#, c-format
-msgid "Can't stat %s"
-msgstr "Не удалось выполнить stat для %s"
+#: builtin/interpret-trailers.c:105
+msgid "do not apply config rules"
+msgstr "не применять правила из файла конфигурации"
 
-#: builtin/gc.c:321
-#, c-format
-msgid ""
-"The last gc run reported the following. Please correct the root cause\n"
-"and remove %s.\n"
-"Automatic cleanup will not be performed until the file is removed.\n"
-"\n"
-"%s"
-msgstr "Последний запуск gc сообщил следующее. Пожалуйста, исправьте ошибку и удалите %s.\nАвтоматическая очистка репозитория не будет производиться, пока этот файл не удалён.\n\n%s"
+#: builtin/interpret-trailers.c:106
+msgid "join whitespace-continued values"
+msgstr "объединить значения разделенные пробелом"
 
-#: builtin/gc.c:360
-msgid "prune unreferenced objects"
-msgstr "почистить объекты, на которые нет ссылок"
+#: builtin/interpret-trailers.c:107
+msgid "set parsing options"
+msgstr "указание опций разбора"
 
-#: builtin/gc.c:362
-msgid "be more thorough (increased runtime)"
-msgstr "проверять более внимательно (занимает больше времени)"
+#: builtin/interpret-trailers.c:109
+msgid "do not treat --- specially"
+msgstr ""
 
-#: builtin/gc.c:363
-msgid "enable auto-gc mode"
-msgstr "включить режим auto-gc"
+#: builtin/interpret-trailers.c:110
+msgid "trailer"
+msgstr "завершитель"
 
-#: builtin/gc.c:364
-msgid "force running gc even if there may be another gc running"
-msgstr "принудительно запустить gc, даже есть другая копия gc уже запущена"
+#: builtin/interpret-trailers.c:111
+msgid "trailer(s) to add"
+msgstr "завершители для добавления"
 
-#: builtin/gc.c:381
-#, c-format
-msgid "Failed to parse gc.logexpiry value %s"
-msgstr "Не удалось разобрать значение %s для gc.logexpiry"
+#: builtin/interpret-trailers.c:120
+msgid "--trailer with --only-input does not make sense"
+msgstr "--trailer одновременно с --only-input не имеет смысла"
 
-#: builtin/gc.c:409
-#, c-format
-msgid "Auto packing the repository in background for optimum performance.\n"
-msgstr "Автоматическая упаковка репозитория в фоне, для оптимальной производительности.\n"
+#: builtin/interpret-trailers.c:130
+msgid "no input file given for in-place editing"
+msgstr "ничего не передано, для редактирования файлов на месте"
 
-#: builtin/gc.c:411
-#, c-format
-msgid "Auto packing the repository for optimum performance.\n"
-msgstr "Автоматическая упаковка репозитория, для оптимальной производительности.\n"
+#: builtin/log.c:55
+msgid "git log [<options>] [<revision-range>] [[--] <path>...]"
+msgstr "git log [<опции>] [<диапазон-редакций>] [[--] <путь>…]"
 
-#: builtin/gc.c:412
-#, c-format
-msgid "See \"git help gc\" for manual housekeeping.\n"
-msgstr "Смотрите «git help gc» руководства по ручной очистке.\n"
+#: builtin/log.c:56
+msgid "git show [<options>] <object>..."
+msgstr "git show [<опции>] <объект>…"
 
-#: builtin/gc.c:437
+#: builtin/log.c:104
 #, c-format
-msgid ""
-"gc is already running on machine '%s' pid %<PRIuMAX> (use --force if not)"
-msgstr "gc уже запущен на этом компьютере «%s» pid %<PRIuMAX> (если нет, используйте --force)"
+msgid "invalid --decorate option: %s"
+msgstr "неправильный параметр для --decorate: %s"
 
-#: builtin/gc.c:481
-msgid ""
-"There are too many unreachable loose objects; run 'git prune' to remove "
-"them."
-msgstr "Имеется слишком много объектов, на которые нет ссылок; запустите «git prune» для их удаления."
+#: builtin/log.c:168
+msgid "show source"
+msgstr "показать источник"
 
-#: builtin/grep.c:27
-msgid "git grep [<options>] [-e] <pattern> [<rev>...] [[--] <path>...]"
-msgstr "git grep [<опции>] [-e] <шаблон> [<редакция>…] [[--] <путь>…]"
+#: builtin/log.c:169
+msgid "Use mail map file"
+msgstr "Использовать файл соответствия почтовых адресов"
 
-#: builtin/grep.c:226
-#, c-format
-msgid "grep: failed to create thread: %s"
-msgstr "grep: сбой создания потока: %s"
+#: builtin/log.c:171
+msgid "only decorate refs that match <pattern>"
+msgstr "декорировать только ссылки соответствующие <шаблону>"
 
-#: builtin/grep.c:284
-#, c-format
-msgid "invalid number of threads specified (%d) for %s"
-msgstr "указано недопустимое количество потоков (%d) для %s"
+#: builtin/log.c:173
+msgid "do not decorate refs that match <pattern>"
+msgstr "не декорировать ссылки соответствующие <шаблону>"
 
-#. TRANSLATORS: %s is the configuration
-#. variable for tweaking threads, currently
-#. grep.threads
-#: builtin/grep.c:293 builtin/index-pack.c:1495 builtin/index-pack.c:1688
-#, c-format
-msgid "no threads support, ignoring %s"
-msgstr "нет поддержки потоков, игнорирование %s"
+#: builtin/log.c:174
+msgid "decorate options"
+msgstr "опции формата вывода ссылок"
 
-#: builtin/grep.c:453 builtin/grep.c:573 builtin/grep.c:615
-#, c-format
-msgid "unable to read tree (%s)"
-msgstr "не удалось прочитать дерево (%s)"
+#: builtin/log.c:177
+msgid "Process line range n,m in file, counting from 1"
+msgstr "Обработать диапазон строк n,m из файла, начиная с 1"
 
-#: builtin/grep.c:630
+#: builtin/log.c:275
 #, c-format
-msgid "unable to grep from object of type %s"
-msgstr "не удалось выполнить grep из объекта типа %s"
+msgid "Final output: %d %s\n"
+msgstr "Финальный вывод: %d %s\n"
 
-#: builtin/grep.c:696
+#: builtin/log.c:529
 #, c-format
-msgid "switch `%c' expects a numerical value"
-msgstr "параметр «%c» ожидает числовое значение"
+msgid "git show %s: bad file"
+msgstr "git show %s: плохой файл"
 
-#: builtin/grep.c:783
-msgid "search in index instead of in the work tree"
-msgstr "искать в индексе, а не в рабочем каталоге"
+#: builtin/log.c:544 builtin/log.c:638
+#, c-format
+msgid "could not read object %s"
+msgstr ""
 
-#: builtin/grep.c:785
-msgid "find in contents not managed by git"
-msgstr "искать в содержимом не управляемым git"
+#: builtin/log.c:663
+#, c-format
+msgid "unknown type: %d"
+msgstr ""
 
-#: builtin/grep.c:787
-msgid "search in both tracked and untracked files"
-msgstr "искать и в отслеживаемых, и в неотслеживаемых файлах"
+#: builtin/log.c:784
+msgid "format.headers without value"
+msgstr "в format.headers не указано значение"
 
-#: builtin/grep.c:789
-msgid "ignore files specified via '.gitignore'"
-msgstr "игнорировать файлы указанные в «.gitignore»"
+#: builtin/log.c:885
+msgid "name of output directory is too long"
+msgstr "слишком длинное имя выходного каталога"
 
-#: builtin/grep.c:791
-msgid "recursively search in each submodule"
-msgstr "рекурсивный поиск по всем подмодулям"
+#: builtin/log.c:901
+#, c-format
+msgid "cannot open patch file %s"
+msgstr ""
 
-#: builtin/grep.c:794
-msgid "show non-matching lines"
-msgstr "искать в несовпадающих строках"
+#: builtin/log.c:918
+msgid "need exactly one range"
+msgstr ""
 
-#: builtin/grep.c:796
-msgid "case insensitive matching"
-msgstr "без учета регистра"
+#: builtin/log.c:928
+msgid "not a range"
+msgstr ""
 
-#: builtin/grep.c:798
-msgid "match patterns only at word boundaries"
-msgstr "искать совпадения шаблона только на границах слов"
+#: builtin/log.c:1051
+msgid "cover letter needs email format"
+msgstr ""
 
-#: builtin/grep.c:800
-msgid "process binary files as text"
-msgstr "обработка двоичных файлов как текста"
+#: builtin/log.c:1057
+msgid "failed to create cover-letter file"
+msgstr ""
 
-#: builtin/grep.c:802
-msgid "don't match patterns in binary files"
-msgstr "не искать совпадения шаблона в двоичных файлах"
+#: builtin/log.c:1136
+#, c-format
+msgid "insane in-reply-to: %s"
+msgstr "ошибка в поле in-reply-to: %s"
 
-#: builtin/grep.c:805
-msgid "process binary files with textconv filters"
-msgstr "обрабатываться двоичные файлы с помощью фильтров textconv"
+#: builtin/log.c:1163
+msgid "git format-patch [<options>] [<since> | <revision-range>]"
+msgstr "git format-patch [<опции>] [<начиная-с> | <диапазон-редакций>]"
 
-#: builtin/grep.c:807
-msgid "descend at most <depth> levels"
-msgstr "на глубине максиму <глубина> уровней"
+#: builtin/log.c:1221
+msgid "two output directories?"
+msgstr ""
 
-#: builtin/grep.c:811
-msgid "use extended POSIX regular expressions"
-msgstr "использовать расширенные регулярные выражения POSIX"
+#: builtin/log.c:1332 builtin/log.c:2076 builtin/log.c:2078 builtin/log.c:2090
+#, c-format
+msgid "unknown commit %s"
+msgstr ""
 
-#: builtin/grep.c:814
-msgid "use basic POSIX regular expressions (default)"
-msgstr "использовать базовые регулярные выражения POSIX (по умолчанию)"
+#: builtin/log.c:1342 builtin/replace.c:58 builtin/replace.c:207
+#: builtin/replace.c:210
+#, c-format
+msgid "failed to resolve '%s' as a valid ref"
+msgstr ""
 
-#: builtin/grep.c:817
-msgid "interpret patterns as fixed strings"
-msgstr "интерпретировать шаблоны как фиксированные строки"
+#: builtin/log.c:1347
+msgid "could not find exact merge base"
+msgstr ""
 
-#: builtin/grep.c:820
-msgid "use Perl-compatible regular expressions"
-msgstr "использовать Perl-совместимые регулярные выражения"
+#: builtin/log.c:1351
+msgid ""
+"failed to get upstream, if you want to record base commit automatically,\n"
+"please use git branch --set-upstream-to to track a remote branch.\n"
+"Or you could specify base commit by --base=<base-commit-id> manually"
+msgstr ""
 
-#: builtin/grep.c:823
-msgid "show line numbers"
-msgstr "вывести номера строк"
+#: builtin/log.c:1371
+msgid "failed to find exact merge base"
+msgstr ""
 
-#: builtin/grep.c:824
-msgid "don't show filenames"
-msgstr "не выводить имена файлов"
+#: builtin/log.c:1382
+msgid "base commit should be the ancestor of revision list"
+msgstr "базовый коммит должен быть предком списка редакций"
 
-#: builtin/grep.c:825
-msgid "show filenames"
-msgstr "выводить имена файлов"
+#: builtin/log.c:1386
+msgid "base commit shouldn't be in revision list"
+msgstr "базовый коммит не должен быть в списке редакций"
 
-#: builtin/grep.c:827
-msgid "show filenames relative to top directory"
-msgstr "выводить имена файлов относительно каталога репозитория"
+#: builtin/log.c:1439
+msgid "cannot get patch id"
+msgstr "не удалось получить идентификатор патча"
 
-#: builtin/grep.c:829
-msgid "show only filenames instead of matching lines"
-msgstr "выводить только имена файлов, а не совпадающие строки"
+#: builtin/log.c:1491
+msgid "failed to infer range-diff ranges"
+msgstr ""
 
-#: builtin/grep.c:831
-msgid "synonym for --files-with-matches"
-msgstr "синоним для --files-with-matches"
+#: builtin/log.c:1536
+msgid "use [PATCH n/m] even with a single patch"
+msgstr "выводить [PATCH n/m] даже когда один патч"
 
-#: builtin/grep.c:834
-msgid "show only the names of files without match"
-msgstr "выводить только несовпадающие имена файлов"
+#: builtin/log.c:1539
+msgid "use [PATCH] even with multiple patches"
+msgstr "выводить [PATCH] даже когда несколько патчей"
 
-#: builtin/grep.c:836
-msgid "print NUL after filenames"
-msgstr "выводить двоичный НОЛЬ после списка имен файлов"
+#: builtin/log.c:1543
+msgid "print patches to standard out"
+msgstr "выводить патчи на стандартный вывод"
 
-#: builtin/grep.c:838
-msgid "show the number of matches instead of matching lines"
-msgstr "выводить количество совпадений, а не совпадающие строки"
+#: builtin/log.c:1545
+msgid "generate a cover letter"
+msgstr "создать сопроводительное письмо"
 
-#: builtin/grep.c:839
-msgid "highlight matches"
-msgstr "подсвечивать совпадения"
+#: builtin/log.c:1547
+msgid "use simple number sequence for output file names"
+msgstr "использовать простую последовательность чисел для имен выходных файлов"
 
-#: builtin/grep.c:841
-msgid "print empty line between matches from different files"
-msgstr "выводить пустую строку после совпадений из разных файлов"
+#: builtin/log.c:1548
+msgid "sfx"
+msgstr "суффикс"
 
-#: builtin/grep.c:843
-msgid "show filename only once above matches from same file"
-msgstr "выводить имя файла только раз на несколько совпадений в одном файле"
+#: builtin/log.c:1549
+msgid "use <sfx> instead of '.patch'"
+msgstr "использовать суффикс <суффикс> вместо «.patch»"
 
-#: builtin/grep.c:846
-msgid "show <n> context lines before and after matches"
-msgstr "показать <n> строк контекста перед и после совпадения"
+#: builtin/log.c:1551
+msgid "start numbering patches at <n> instead of 1"
+msgstr "начать нумерацию патчей с <n>, а не с 1"
 
-#: builtin/grep.c:849
-msgid "show <n> context lines before matches"
-msgstr "показать <n> строк контекста перед совпадением"
+#: builtin/log.c:1553
+msgid "mark the series as Nth re-roll"
+msgstr "пометить серию как энную попытку"
 
-#: builtin/grep.c:851
-msgid "show <n> context lines after matches"
-msgstr "показать <n> строк контекста после совпадения"
+#: builtin/log.c:1555
+msgid "Use [RFC PATCH] instead of [PATCH]"
+msgstr "Использовать [RFC PATCH] вместо [PATCH]"
 
-#: builtin/grep.c:853
-msgid "use <n> worker threads"
-msgstr "использовать <кол> рабочих потоков"
+#: builtin/log.c:1558
+msgid "Use [<prefix>] instead of [PATCH]"
+msgstr "Использовать [<префикс>] вместо [PATCH]"
 
-#: builtin/grep.c:854
-msgid "shortcut for -C NUM"
-msgstr "тоже, что и -C КОЛИЧЕСТВО"
+#: builtin/log.c:1561
+msgid "store resulting files in <dir>"
+msgstr "сохранить результирующие файлы в <каталог>"
 
-#: builtin/grep.c:857
-msgid "show a line with the function name before matches"
-msgstr "показать строку с именем функции перед совпадением"
+#: builtin/log.c:1564
+msgid "don't strip/add [PATCH]"
+msgstr "не обрезать/добавлять [PATCH]"
 
-#: builtin/grep.c:859
-msgid "show the surrounding function"
-msgstr "показать окружающую функцию"
+#: builtin/log.c:1567
+msgid "don't output binary diffs"
+msgstr "не выводить двоичные изменения"
 
-#: builtin/grep.c:862
-msgid "read patterns from file"
-msgstr "прочитать шаблоны из файла"
+#: builtin/log.c:1569
+msgid "output all-zero hash in From header"
+msgstr "выводить нулевую хеш-сумму в заголовке From"
 
-#: builtin/grep.c:864
-msgid "match <pattern>"
-msgstr "поиск соответствий с <шаблоном>"
+#: builtin/log.c:1571
+msgid "don't include a patch matching a commit upstream"
+msgstr "не включать патч, если коммит уже есть в вышестоящей ветке"
 
-#: builtin/grep.c:866
-msgid "combine patterns specified with -e"
-msgstr "объединить шаблоны указанные с помощью -e"
+#: builtin/log.c:1573
+msgid "show patch format instead of default (patch + stat)"
+msgstr "выводить в формате патча, а не в стандартном (патч + статистика)"
 
-#: builtin/grep.c:878
-msgid "indicate hit with exit status without output"
-msgstr "ничего не выводить, указать на совпадение с помощью кода выхода"
+#: builtin/log.c:1575
+msgid "Messaging"
+msgstr "Передача сообщений"
 
-#: builtin/grep.c:880
-msgid "show only matches from files that match all patterns"
-msgstr "показать только совпадения из файлов в которых совпадают все шаблоны"
+#: builtin/log.c:1576
+msgid "header"
+msgstr "заголовок"
 
-#: builtin/grep.c:882
-msgid "show parse tree for grep expression"
-msgstr "показать дерево разбора для выражения поиска"
+#: builtin/log.c:1577
+msgid "add email header"
+msgstr "добавить заголовок сообщения"
 
-#: builtin/grep.c:886
-msgid "pager"
-msgstr "пейджер"
+#: builtin/log.c:1578 builtin/log.c:1580
+msgid "email"
+msgstr "почта"
 
-#: builtin/grep.c:886
-msgid "show matching files in the pager"
-msgstr "показать совпадающие файлы с помощью программы-пейджера"
+#: builtin/log.c:1578
+msgid "add To: header"
+msgstr "добавить заголовок To:"
 
-#: builtin/grep.c:889
-msgid "allow calling of grep(1) (ignored by this build)"
-msgstr "разрешить вызов grep(1) (игнорируется в этой сборке)"
+#: builtin/log.c:1580
+msgid "add Cc: header"
+msgstr "добавить заголовок Cc:"
 
-#: builtin/grep.c:952
-msgid "no pattern given."
-msgstr "не задан шаблон."
+#: builtin/log.c:1582
+msgid "ident"
+msgstr "идентификатор"
 
-#: builtin/grep.c:984
-msgid "--no-index or --untracked cannot be used with revs"
-msgstr "--no-index или --untracked нельзя использовать одновременно с указанием ревизии"
+#: builtin/log.c:1583
+msgid "set From address to <ident> (or committer ident if absent)"
+msgstr "установить адрес отправителя на <идентификатор> (или на идентификатор коммитера, если отсутствует)"
 
-#: builtin/grep.c:991
-#, c-format
-msgid "unable to resolve revision: %s"
-msgstr "не удалось определить редакцию: %s"
+#: builtin/log.c:1585
+msgid "message-id"
+msgstr "идентификатор-сообщения"
 
-#: builtin/grep.c:1026 builtin/index-pack.c:1491
-#, c-format
-msgid "invalid number of threads specified (%d)"
-msgstr "указано неправильное количество потоков (%d)"
+#: builtin/log.c:1586
+msgid "make first mail a reply to <message-id>"
+msgstr "сделать первое письмо ответом на <идентификатор-сообщения>"
 
-#: builtin/grep.c:1031
-msgid "no threads support, ignoring --threads"
-msgstr "нет поддержки потоков, игнорирование --threads"
+#: builtin/log.c:1587 builtin/log.c:1590
+msgid "boundary"
+msgstr "вложение"
 
-#: builtin/grep.c:1055
-msgid "--open-files-in-pager only works on the worktree"
-msgstr "--open-files-in-pager работает только в рабочем каталоге"
+#: builtin/log.c:1588
+msgid "attach the patch"
+msgstr "приложить патч"
 
-#: builtin/grep.c:1078
-msgid "option not supported with --recurse-submodules."
-msgstr "опция не поддерживается одновременно с --recurse-submodules."
-
-#: builtin/grep.c:1084
-msgid "--cached or --untracked cannot be used with --no-index."
-msgstr "--cached или --untracked нельзя использовать одновременно с --no-index."
-
-#: builtin/grep.c:1090
-msgid "--[no-]exclude-standard cannot be used for tracked contents."
-msgstr "--[no-]exclude-standard не может использоваться для отслеживаемого содержимого."
-
-#: builtin/grep.c:1098
-msgid "both --cached and trees are given."
-msgstr "указано одновременно --cached и дерево."
+#: builtin/log.c:1591
+msgid "inline the patch"
+msgstr "включить патч в текст письма"
 
-#: builtin/hash-object.c:82
-msgid ""
-"git hash-object [-t <type>] [-w] [--path=<file> | --no-filters] [--stdin] "
-"[--] <file>..."
-msgstr "git hash-object [-t <тип>] [-w] [--path=<файл> | --no-filters] [--stdin] [--] <файл>…"
+#: builtin/log.c:1595
+msgid "enable message threading, styles: shallow, deep"
+msgstr "включить в письмах иерархичность, стили: shallow (частичную), deep (глубокую)"
 
-#: builtin/hash-object.c:83
-msgid "git hash-object  --stdin-paths"
-msgstr "git hash-object  --stdin-paths"
+#: builtin/log.c:1597
+msgid "signature"
+msgstr "подпись"
 
-#: builtin/hash-object.c:95
-msgid "type"
-msgstr "тип"
+#: builtin/log.c:1598
+msgid "add a signature"
+msgstr "добавить подпись"
 
-#: builtin/hash-object.c:95
-msgid "object type"
-msgstr "тип объекта"
+#: builtin/log.c:1599
+msgid "base-commit"
+msgstr "базовый коммит"
 
-#: builtin/hash-object.c:96
-msgid "write the object into the object database"
-msgstr "запись объекта в базу данных объектов"
+#: builtin/log.c:1600
+msgid "add prerequisite tree info to the patch series"
+msgstr "добавить информацию о требовании дерева к серии патчей"
 
-#: builtin/hash-object.c:98
-msgid "read the object from stdin"
-msgstr "прочитать объект из стандартного ввода"
+#: builtin/log.c:1602
+msgid "add a signature from a file"
+msgstr "добавить подпись из файла"
 
-#: builtin/hash-object.c:100
-msgid "store file as is without filters"
-msgstr "сохранить файл без использования фильтров"
+#: builtin/log.c:1603
+msgid "don't print the patch filenames"
+msgstr "не выводить имена файлов патчей"
 
-#: builtin/hash-object.c:101
-msgid ""
-"just hash any random garbage to create corrupt objects for debugging Git"
-msgstr "хэшировать любой мусор и создавать поврежденные объекты для отладки Git"
+#: builtin/log.c:1605
+msgid "show progress while generating patches"
+msgstr "показать прогресс выполнения во создания патчей"
 
-#: builtin/hash-object.c:102
-msgid "process file as it were from this path"
-msgstr "обработать файл так, будто он находится по указанному пути"
+#: builtin/log.c:1606
+msgid "rev"
+msgstr ""
 
-#: builtin/help.c:43
-msgid "print all available commands"
-msgstr "вывести список всех доступных команд"
+#: builtin/log.c:1607
+msgid "show changes against <rev> in cover letter or single patch"
+msgstr ""
 
-#: builtin/help.c:44
-msgid "exclude guides"
-msgstr "исключить руководства"
+#: builtin/log.c:1610
+msgid "show changes against <refspec> in cover letter or single patch"
+msgstr ""
 
-#: builtin/help.c:45
-msgid "print list of useful guides"
-msgstr "вывести список полезных руководств"
+#: builtin/log.c:1612
+msgid "percentage by which creation is weighted"
+msgstr ""
 
-#: builtin/help.c:46
-msgid "show man page"
-msgstr "открыть руководство в формате man"
+#: builtin/log.c:1687
+#, c-format
+msgid "invalid ident line: %s"
+msgstr "неправильная строка идентификации: %s"
 
-#: builtin/help.c:47
-msgid "show manual in web browser"
-msgstr "открыть руководство в веб-браузере"
+#: builtin/log.c:1702
+msgid "-n and -k are mutually exclusive"
+msgstr ""
 
-#: builtin/help.c:49
-msgid "show info page"
-msgstr "открыть руководство в формате info"
+#: builtin/log.c:1704
+msgid "--subject-prefix/--rfc and -k are mutually exclusive"
+msgstr ""
 
-#: builtin/help.c:55
-msgid "git help [--all] [--guides] [--man | --web | --info] [<command>]"
-msgstr "git help [--all] [--guides] [--man | --web | --info] [<команда>]"
+#: builtin/log.c:1712
+msgid "--name-only does not make sense"
+msgstr "--name-only не имеет смысла"
 
-#: builtin/help.c:67
-#, c-format
-msgid "unrecognized help format '%s'"
-msgstr "неопознанный формат руководства «%s»"
+#: builtin/log.c:1714
+msgid "--name-status does not make sense"
+msgstr "--name-status не имеет смысла"
 
-#: builtin/help.c:94
-msgid "Failed to start emacsclient."
-msgstr "Сбой при запуске emacsclient."
+#: builtin/log.c:1716
+msgid "--check does not make sense"
+msgstr "--check не имеет смысла"
 
-#: builtin/help.c:107
-msgid "Failed to parse emacsclient version."
-msgstr "Сбой при определении версии emacsclient."
+#: builtin/log.c:1748
+msgid "standard output, or directory, which one?"
+msgstr "стандартный вывод или каталог?"
 
-#: builtin/help.c:115
-#, c-format
-msgid "emacsclient version '%d' too old (< 22)."
-msgstr "версия emacsclient «%d» слишком старая (< 22)."
+#: builtin/log.c:1837
+msgid "--interdiff requires --cover-letter or single patch"
+msgstr ""
 
-#: builtin/help.c:133 builtin/help.c:155 builtin/help.c:165 builtin/help.c:173
-#, c-format
-msgid "failed to exec '%s'"
-msgstr "сбой при запуске «%s»"
+#: builtin/log.c:1841
+msgid "Interdiff:"
+msgstr ""
 
-#: builtin/help.c:211
+#: builtin/log.c:1842
 #, c-format
-msgid ""
-"'%s': path for unsupported man viewer.\n"
-"Please consider using 'man.<tool>.cmd' instead."
-msgstr "«%s»: путь для неподдерживаемой программы просмотра man.\nВместо этого используйте «man.<программа>.cmd»."
+msgid "Interdiff against v%d:"
+msgstr ""
 
-#: builtin/help.c:223
-#, c-format
-msgid ""
-"'%s': cmd for supported man viewer.\n"
-"Please consider using 'man.<tool>.path' instead."
-msgstr "«%s»: команда для неподдерживаемой программы просмотра man.\nВместо этого используйте «man.<программа>.path»."
+#: builtin/log.c:1848
+msgid "--creation-factor requires --range-diff"
+msgstr ""
 
-#: builtin/help.c:340
-#, c-format
-msgid "'%s': unknown man viewer."
-msgstr "«%s»: неизвестная программа просмотра man."
+#: builtin/log.c:1852
+msgid "--range-diff requires --cover-letter or single patch"
+msgstr ""
 
-#: builtin/help.c:357
-msgid "no man viewer handled the request"
-msgstr "программа просмотра man не обработала запрос"
+#: builtin/log.c:1860
+msgid "Range-diff:"
+msgstr ""
 
-#: builtin/help.c:365
-msgid "no info viewer handled the request"
-msgstr "программа просмотра info не обработала запрос"
+#: builtin/log.c:1861
+#, c-format
+msgid "Range-diff against v%d:"
+msgstr ""
 
-#: builtin/help.c:407
-msgid "Defining attributes per path"
-msgstr "Определение атрибутов для путей файлов или каталогов"
+#: builtin/log.c:1872
+#, c-format
+msgid "unable to read signature file '%s'"
+msgstr "не удалось прочитать файл подписи «%s»"
 
-#: builtin/help.c:408
-msgid "Everyday Git With 20 Commands Or So"
-msgstr "Повседневный Git с 20 командами или около того"
+#: builtin/log.c:1908
+msgid "Generating patches"
+msgstr "Создание патчей"
 
-#: builtin/help.c:409
-msgid "A Git glossary"
-msgstr "Глоссарий Git"
+#: builtin/log.c:1952
+msgid "failed to create output files"
+msgstr ""
 
-#: builtin/help.c:410
-msgid "Specifies intentionally untracked files to ignore"
-msgstr "Указание специально игнорируемых файлов"
+#: builtin/log.c:2011
+msgid "git cherry [-v] [<upstream> [<head> [<limit>]]]"
+msgstr "git cherry [-v] [<вышестоящая-ветка> [<редакция> [<ограничение>]]]"
 
-#: builtin/help.c:411
-msgid "Defining submodule properties"
-msgstr "Определение свойств подмодулей"
+#: builtin/log.c:2065
+#, c-format
+msgid ""
+"Could not find a tracked remote branch, please specify <upstream> "
+"manually.\n"
+msgstr "Не удалось найти отслеживаемую внешнюю ветку, укажите <вышестоящую-ветку> вручную.\n"
 
-#: builtin/help.c:412
-msgid "Specifying revisions and ranges for Git"
-msgstr "Указание редакций и диапазонов для Git"
+#: builtin/ls-files.c:470
+msgid "git ls-files [<options>] [<file>...]"
+msgstr "git ls-files [<опции>] [<файл>…]"
 
-#: builtin/help.c:413
-msgid "A tutorial introduction to Git (for version 1.5.1 or newer)"
-msgstr "Учебное введение в Git (для версии 1.5.1 или новее)"
+#: builtin/ls-files.c:526
+msgid "identify the file status with tags"
+msgstr "выводить имена файлов с метками"
 
-#: builtin/help.c:414
-msgid "An overview of recommended workflows with Git"
-msgstr "Обзор рекомендуемых последовательностей выполняемых действий с Git"
+#: builtin/ls-files.c:528
+msgid "use lowercase letters for 'assume unchanged' files"
+msgstr "использовать символы в нижнем регистре для «предположительно без изменений» файлов"
 
-#: builtin/help.c:426
-msgid "The common Git guides are:\n"
-msgstr "Основные руководства Git:\n"
+#: builtin/ls-files.c:530
+msgid "use lowercase letters for 'fsmonitor clean' files"
+msgstr "использовать символы нижнего регистра для файлов «fsmonitor clean»"
 
-#: builtin/help.c:444
-#, c-format
-msgid "'%s' is aliased to '%s'"
-msgstr "«%s» — это сокращение для «%s»"
+#: builtin/ls-files.c:532
+msgid "show cached files in the output (default)"
+msgstr "показывать кэшированные файлы при выводе (по умолчанию)"
 
-#: builtin/help.c:466 builtin/help.c:483
-#, c-format
-msgid "usage: %s%s"
-msgstr "использование: %s%s"
+#: builtin/ls-files.c:534
+msgid "show deleted files in the output"
+msgstr "показывать удаленные файлы при выводе"
 
-#: builtin/index-pack.c:156
-#, c-format
-msgid "unable to open %s"
-msgstr "не удалось открыть %s"
+#: builtin/ls-files.c:536
+msgid "show modified files in the output"
+msgstr "показывать измененные файлы при выводе"
 
-#: builtin/index-pack.c:206
-#, c-format
-msgid "object type mismatch at %s"
-msgstr "несоответствие типа объекта на %s"
+#: builtin/ls-files.c:538
+msgid "show other files in the output"
+msgstr "показывать другие файлы при выводе"
 
-#: builtin/index-pack.c:226
-#, c-format
-msgid "did not receive expected object %s"
-msgstr "ожидаемый объект не получен на %s"
+#: builtin/ls-files.c:540
+msgid "show ignored files in the output"
+msgstr "показывать игнорируемые файлы при выводе"
 
-#: builtin/index-pack.c:229
-#, c-format
-msgid "object %s: expected type %s, found %s"
-msgstr "объект %s: ожидаемый тип %s, получен %s"
+#: builtin/ls-files.c:543
+msgid "show staged contents' object name in the output"
+msgstr "показывать имя индексированного объекта на выводе"
 
-#: builtin/index-pack.c:271
-#, c-format
-msgid "cannot fill %d byte"
-msgid_plural "cannot fill %d bytes"
-msgstr[0] "не удалось заполнить %d байт"
-msgstr[1] "не удалось заполнить %d байта"
-msgstr[2] "не удалось заполнить %d байтов"
-msgstr[3] "не удалось заполнить %d байтов"
+#: builtin/ls-files.c:545
+msgid "show files on the filesystem that need to be removed"
+msgstr "показывать файлы в файловой системе, которые должны быть удалены"
 
-#: builtin/index-pack.c:281
-msgid "early EOF"
-msgstr "неожиданный конец файла"
+#: builtin/ls-files.c:547
+msgid "show 'other' directories' names only"
+msgstr "показывать только имена у «других» каталогов"
 
-#: builtin/index-pack.c:282
-msgid "read error on input"
-msgstr "ошибка чтения ввода"
+#: builtin/ls-files.c:549
+msgid "show line endings of files"
+msgstr "показать концы строк файлов"
 
-#: builtin/index-pack.c:294
-msgid "used more bytes than were available"
-msgstr "использовано больше байт, чем было доступно"
+#: builtin/ls-files.c:551
+msgid "don't show empty directories"
+msgstr "не показывать пустые каталоги"
 
-#: builtin/index-pack.c:301
-msgid "pack too large for current definition of off_t"
-msgstr "пакет слишком большой для текущего определения off_t"
+#: builtin/ls-files.c:554
+msgid "show unmerged files in the output"
+msgstr "показывать не слитые файлы на выводе"
 
-#: builtin/index-pack.c:304 builtin/unpack-objects.c:93
-msgid "pack exceeds maximum allowed size"
-msgstr "размер пакета превышает максимальный допустимый"
+#: builtin/ls-files.c:556
+msgid "show resolve-undo information"
+msgstr "показывать информации о разрешении конфликтов и отмене"
 
-#: builtin/index-pack.c:319
-#, c-format
-msgid "unable to create '%s'"
-msgstr "не удалось создать «%s»"
+#: builtin/ls-files.c:558
+msgid "skip files matching pattern"
+msgstr "пропустить файлы, соответствующие шаблону"
 
-#: builtin/index-pack.c:325
-#, c-format
-msgid "cannot open packfile '%s'"
-msgstr "не удалось открыть файл пакета «%s»"
+#: builtin/ls-files.c:561
+msgid "exclude patterns are read from <file>"
+msgstr "прочитать шаблоны исключения из <файл>"
 
-#: builtin/index-pack.c:339
-msgid "pack signature mismatch"
-msgstr "несоответствие подписи пакета"
+#: builtin/ls-files.c:564
+msgid "read additional per-directory exclude patterns in <file>"
+msgstr "прочитать дополнительные покаталожные шаблоны исключения из <файл>"
 
-#: builtin/index-pack.c:341
-#, c-format
-msgid "pack version %<PRIu32> unsupported"
-msgstr "версия пакета %<PRIu32> не поддерживается"
+#: builtin/ls-files.c:566
+msgid "add the standard git exclusions"
+msgstr "добавить стандартные исключения git"
 
-#: builtin/index-pack.c:359
-#, c-format
-msgid "pack has bad object at offset %<PRIuMAX>: %s"
-msgstr "пакет содержит плохой объект по смещению %<PRIuMAX>: %s"
+#: builtin/ls-files.c:570
+msgid "make the output relative to the project top directory"
+msgstr "выводить пути относительно корневого каталога проекта"
 
-#: builtin/index-pack.c:480
-#, c-format
-msgid "inflate returned %d"
-msgstr "программа сжатия вернула %d"
+#: builtin/ls-files.c:573
+msgid "recurse through submodules"
+msgstr "рекурсивно по подмодулям"
 
-#: builtin/index-pack.c:529
-msgid "offset value overflow for delta base object"
-msgstr "переполнение значения смещения у базового объекта дельты"
+#: builtin/ls-files.c:575
+msgid "if any <file> is not in the index, treat this as an error"
+msgstr "если какой-либо <файл> не в индексе, считать это ошибкой"
 
-#: builtin/index-pack.c:537
-msgid "delta base offset is out of bound"
-msgstr "смещение базовой дельты вышло за допустимые пределы"
+#: builtin/ls-files.c:576
+msgid "tree-ish"
+msgstr "указатель-дерева"
 
-#: builtin/index-pack.c:545
-#, c-format
-msgid "unknown object type %d"
-msgstr "неизвестный тип объекта %d"
+#: builtin/ls-files.c:577
+msgid "pretend that paths removed since <tree-ish> are still present"
+msgstr "притвориться, что пути удалены, т.к. <указатель-дерева> еще существует"
 
-#: builtin/index-pack.c:576
-msgid "cannot pread pack file"
-msgstr "не удалось выполнить pread для файла пакета"
+#: builtin/ls-files.c:579
+msgid "show debugging data"
+msgstr "показать отладочную информацию"
 
-#: builtin/index-pack.c:578
-#, c-format
-msgid "premature end of pack file, %<PRIuMAX> byte missing"
-msgid_plural "premature end of pack file, %<PRIuMAX> bytes missing"
-msgstr[0] "преждевременное окончание файла пакета, %<PRIuMAX> байт отсутствует"
-msgstr[1] "преждевременное окончание файла пакета, %<PRIuMAX> байта отсутствует"
-msgstr[2] "преждевременное окончание файла пакета, %<PRIuMAX> байтов отсутствует"
-msgstr[3] "преждевременное окончание файла пакета, %<PRIuMAX> байтов отсутствует"
+#: builtin/ls-remote.c:9
+msgid ""
+"git ls-remote [--heads] [--tags] [--refs] [--upload-pack=<exec>]\n"
+"                     [-q | --quiet] [--exit-code] [--get-url]\n"
+"                     [--symref] [<repository> [<refs>...]]"
+msgstr "git ls-remote [--heads] [--tags] [--refs] [--upload-pack=<запуск>]\n                     [-q | --quiet] [--exit-code] [--get-url]\n                     [--symref] [<репозиторий> [<ссылки>…]]"
 
-#: builtin/index-pack.c:604
-msgid "serious inflate inconsistency"
-msgstr "серьезное несоответствие при распаковке"
+#: builtin/ls-remote.c:59
+msgid "do not print remote URL"
+msgstr "не выводить URL внешних репозиториев"
 
-#: builtin/index-pack.c:749 builtin/index-pack.c:755 builtin/index-pack.c:778
-#: builtin/index-pack.c:817 builtin/index-pack.c:826
-#, c-format
-msgid "SHA1 COLLISION FOUND WITH %s !"
-msgstr "НАЙДЕНА КОЛЛИЗИЯ SHA1 С %s !"
+#: builtin/ls-remote.c:60 builtin/ls-remote.c:62 builtin/rebase.c:1458
+msgid "exec"
+msgstr "запуск"
 
-#: builtin/index-pack.c:752 builtin/pack-objects.c:179
-#: builtin/pack-objects.c:273
-#, c-format
-msgid "unable to read %s"
-msgstr "не удалось прочитать %s"
+#: builtin/ls-remote.c:61 builtin/ls-remote.c:63
+msgid "path of git-upload-pack on the remote host"
+msgstr "путь к git-upload-pack на внешнем сервере"
 
-#: builtin/index-pack.c:815
-#, c-format
-msgid "cannot read existing object info %s"
-msgstr "не удалось прочитать информацию существующего объекта %s"
+#: builtin/ls-remote.c:65
+msgid "limit to tags"
+msgstr "ограничить вывод метками"
 
-#: builtin/index-pack.c:823
-#, c-format
-msgid "cannot read existing object %s"
-msgstr "не удалось прочитать существующий объект %s"
+#: builtin/ls-remote.c:66
+msgid "limit to heads"
+msgstr "ограничить вывод указателями на ветки"
 
-#: builtin/index-pack.c:837
-#, c-format
-msgid "invalid blob object %s"
-msgstr "неправильный файл двоичного объекта %s"
+#: builtin/ls-remote.c:67
+msgid "do not show peeled tags"
+msgstr "не показывать удалённые метки"
 
-#: builtin/index-pack.c:852
-#, c-format
-msgid "invalid %s"
-msgstr "неправильный %s"
+#: builtin/ls-remote.c:69
+msgid "take url.<base>.insteadOf into account"
+msgstr "учитывать url.<база>.insteadOf"
 
-#: builtin/index-pack.c:855
-msgid "Error in object"
-msgstr "Ошибка в объекте"
+#: builtin/ls-remote.c:72
+msgid "exit with exit code 2 if no matching refs are found"
+msgstr "выходить с кодом 2, если соответствующие ссылки не найдены"
 
-#: builtin/index-pack.c:857
-#, c-format
-msgid "Not all child objects of %s are reachable"
-msgstr "Не все дочерние объекты %s достижимы"
+#: builtin/ls-remote.c:75
+msgid "show underlying ref in addition to the object pointed by it"
+msgstr "показать также внутреннюю ссылку в дополнение к объекту, на который она указывает"
 
-#: builtin/index-pack.c:929 builtin/index-pack.c:960
-msgid "failed to apply delta"
-msgstr "сбой при применении дельты"
+#: builtin/ls-tree.c:30
+msgid "git ls-tree [<options>] <tree-ish> [<path>...]"
+msgstr "git ls-tree [<опции>] <указатель-дерева> [<путь>…]"
 
-#: builtin/index-pack.c:1131
-msgid "Receiving objects"
-msgstr "Получение объектов"
+#: builtin/ls-tree.c:128
+msgid "only show trees"
+msgstr "выводить только деревья"
 
-#: builtin/index-pack.c:1131
-msgid "Indexing objects"
-msgstr "Индексирование объектов"
+#: builtin/ls-tree.c:130
+msgid "recurse into subtrees"
+msgstr "проходить рекурсивно в поддеревья"
 
-#: builtin/index-pack.c:1165
-msgid "pack is corrupted (SHA1 mismatch)"
-msgstr "пакет поврежден (несоответствие SHA1)"
+#: builtin/ls-tree.c:132
+msgid "show trees when recursing"
+msgstr "выводить деревья при рекурсивном проходе"
 
-#: builtin/index-pack.c:1170
-msgid "cannot fstat packfile"
-msgstr "не удалось выполнить fstat для файла пакета"
+#: builtin/ls-tree.c:135
+msgid "terminate entries with NUL byte"
+msgstr "разделять записи с помощью НУЛЕВОГО байта"
 
-#: builtin/index-pack.c:1173
-msgid "pack has junk at the end"
-msgstr "файл пакета содержит мусор в конце"
+#: builtin/ls-tree.c:136
+msgid "include object size"
+msgstr "включить размер объекта"
 
-#: builtin/index-pack.c:1185
-msgid "confusion beyond insanity in parse_pack_objects()"
-msgstr "безумная путаница в parse_pack_objects()"
+#: builtin/ls-tree.c:138 builtin/ls-tree.c:140
+msgid "list only filenames"
+msgstr "выводить только имена файлов"
 
-#: builtin/index-pack.c:1208
-msgid "Resolving deltas"
-msgstr "Определение изменений"
+#: builtin/ls-tree.c:143
+msgid "use full path names"
+msgstr "использовать полные пути"
+
+#: builtin/ls-tree.c:145
+msgid "list entire tree; not just current directory (implies --full-name)"
+msgstr "вывести полное дерево; не только текущий каталог (включает в себя --full-name)"
 
-#: builtin/index-pack.c:1219
+#: builtin/mailsplit.c:241
 #, c-format
-msgid "unable to create thread: %s"
-msgstr "не удалось создать поток: %s"
+msgid "empty mbox: '%s'"
+msgstr "пустой mbox: «%s»"
 
-#: builtin/index-pack.c:1261
-msgid "confusion beyond insanity"
-msgstr "безумная путаница"
+#: builtin/merge.c:54
+msgid "git merge [<options>] [<commit>...]"
+msgstr "git merge [<опции>] [<коммит>…]"
 
-#: builtin/index-pack.c:1267
-#, c-format
-msgid "completed with %d local object"
-msgid_plural "completed with %d local objects"
-msgstr[0] "завершено с %d локальным объектом"
-msgstr[1] "завершено с %d локальными объектами"
-msgstr[2] "завершено с %d локальными объектами"
-msgstr[3] "завершено с %d локальными объектами"
+#: builtin/merge.c:55
+msgid "git merge --abort"
+msgstr "git merge --abort"
 
-#: builtin/index-pack.c:1279
-#, c-format
-msgid "Unexpected tail checksum for %s (disk corruption?)"
-msgstr "Неожиданная контрольная сумма в конце %s (диск поврежден?)"
+#: builtin/merge.c:56
+msgid "git merge --continue"
+msgstr "git merge --continue"
 
-#: builtin/index-pack.c:1283
-#, c-format
-msgid "pack has %d unresolved delta"
-msgid_plural "pack has %d unresolved deltas"
-msgstr[0] "пакет содержит %d неразрешенную дельту"
-msgstr[1] "пакет содержит %d неразрешенные дельты"
-msgstr[2] "пакет содержит %d неразрешенных дельт"
-msgstr[3] "пакет содержит %d неразрешенных дельт"
+#: builtin/merge.c:116
+msgid "switch `m' requires a value"
+msgstr "при указании параметра «m» требуется указать значение"
 
-#: builtin/index-pack.c:1307
+#: builtin/merge.c:139
 #, c-format
-msgid "unable to deflate appended object (%d)"
-msgstr "нельзя сжать присоединенный объект (%d)"
+msgid "option `%s' requires a value"
+msgstr ""
 
-#: builtin/index-pack.c:1383
+#: builtin/merge.c:185
 #, c-format
-msgid "local object %s is corrupt"
-msgstr "локальный объект %s поврежден"
-
-#: builtin/index-pack.c:1409
-msgid "error while closing pack file"
-msgstr "ошибка при закрытии файла пакета"
+msgid "Could not find merge strategy '%s'.\n"
+msgstr "Не удалось найти стратегию слияния «%s».\n"
 
-#: builtin/index-pack.c:1421
+#: builtin/merge.c:186
 #, c-format
-msgid "cannot write keep file '%s'"
-msgstr "не удалось записать файл удержания «%s»"
+msgid "Available strategies are:"
+msgstr "Доступные стратегии:"
 
-#: builtin/index-pack.c:1429
+#: builtin/merge.c:191
 #, c-format
-msgid "cannot close written keep file '%s'"
-msgstr "не удалось закрыть записанный файл удержания «%s»"
+msgid "Available custom strategies are:"
+msgstr "Доступные пользовательские стратегии:"
 
-#: builtin/index-pack.c:1439
-msgid "cannot store pack file"
-msgstr "не удалось сохранить файл пакета"
+#: builtin/merge.c:242 builtin/pull.c:150
+msgid "do not show a diffstat at the end of the merge"
+msgstr "не выводить статистику изменений после окончания слияния"
 
-#: builtin/index-pack.c:1447
-msgid "cannot store index file"
-msgstr "не удалось сохранить файл индекса"
+#: builtin/merge.c:245 builtin/pull.c:153
+msgid "show a diffstat at the end of the merge"
+msgstr "вывести статистику изменений после окончания слияния"
 
-#: builtin/index-pack.c:1485
-#, c-format
-msgid "bad pack.indexversion=%<PRIu32>"
-msgstr "плохой pack.indexversion=%<PRIu32>"
+#: builtin/merge.c:246 builtin/pull.c:156
+msgid "(synonym to --stat)"
+msgstr "(синоним для --stat)"
 
-#: builtin/index-pack.c:1553
-#, c-format
-msgid "Cannot open existing pack file '%s'"
-msgstr "Не удалось открыть существующий файл пакета «%s»"
+#: builtin/merge.c:248 builtin/pull.c:159
+msgid "add (at most <n>) entries from shortlog to merge commit message"
+msgstr "добавить (максимум <n>) записей из короткого журнала в сообщение коммита у слияния"
 
-#: builtin/index-pack.c:1555
-#, c-format
-msgid "Cannot open existing pack idx file for '%s'"
-msgstr "Не удалось открыть существующий файл индекса для «%s»"
+#: builtin/merge.c:251 builtin/pull.c:165
+msgid "create a single commit instead of doing a merge"
+msgstr "создать один коммит, вместо выполнения слияния"
 
-#: builtin/index-pack.c:1603
-#, c-format
-msgid "non delta: %d object"
-msgid_plural "non delta: %d objects"
-msgstr[0] "не дельты: %d объект"
-msgstr[1] "не дельты: %d объекта"
-msgstr[2] "не дельты: %d объектов"
-msgstr[3] "не дельты: %d объектов"
+#: builtin/merge.c:253 builtin/pull.c:168
+msgid "perform a commit if the merge succeeds (default)"
+msgstr "сделать коммит, если слияние прошло успешно (по умолчанию)"
 
-#: builtin/index-pack.c:1610
-#, c-format
-msgid "chain length = %d: %lu object"
-msgid_plural "chain length = %d: %lu objects"
-msgstr[0] "длина цепочки = %d: %lu объект"
-msgstr[1] "длина цепочки = %d: %lu объекта"
-msgstr[2] "длина цепочки = %d: %lu объектов"
-msgstr[3] "длина цепочки = %d: %lu объектов"
+#: builtin/merge.c:255 builtin/pull.c:171
+msgid "edit message before committing"
+msgstr "отредактировать сообщение перед выполнением коммита"
 
-#: builtin/index-pack.c:1623
-#, c-format
-msgid "packfile name '%s' does not end with '.pack'"
-msgstr "имя пакета «%s» не оканчивается на «.pack»"
+#: builtin/merge.c:257
+msgid "allow fast-forward (default)"
+msgstr "разрешить перемотку вперед (по умолчанию)"
 
-#: builtin/index-pack.c:1700 builtin/index-pack.c:1703
-#: builtin/index-pack.c:1719 builtin/index-pack.c:1723
-#, c-format
-msgid "bad %s"
-msgstr "плохой %s"
+#: builtin/merge.c:259 builtin/pull.c:178
+msgid "abort if fast-forward is not possible"
+msgstr "отменить выполнение слияния, если перемотка вперед невозможна"
 
-#: builtin/index-pack.c:1739
-msgid "--fix-thin cannot be used without --stdin"
-msgstr "--fix-thin нельзя использовать без --stdin"
+#: builtin/merge.c:263 builtin/pull.c:181
+msgid "verify that the named commit has a valid GPG signature"
+msgstr "проверить, что указанный коммит имеет верную электронную подпись GPG"
 
-#: builtin/index-pack.c:1741
-msgid "--stdin requires a git repository"
-msgstr "опция --stdin требует наличия репозитория git"
+#: builtin/merge.c:264 builtin/notes.c:787 builtin/pull.c:185
+#: builtin/rebase.c:492 builtin/rebase.c:1471 builtin/revert.c:113
+msgid "strategy"
+msgstr "стратегия"
 
-#: builtin/index-pack.c:1749
-msgid "--verify with no packfile name given"
-msgstr "--verify без указания имени файла пакета"
+#: builtin/merge.c:265 builtin/pull.c:186
+msgid "merge strategy to use"
+msgstr "используемая стратегия слияния"
 
-#: builtin/init-db.c:55
-#, c-format
-msgid "cannot stat '%s'"
-msgstr "не удалось выполнить stat для «%s»"
+#: builtin/merge.c:266 builtin/pull.c:189
+msgid "option=value"
+msgstr "опция=значение"
 
-#: builtin/init-db.c:61
-#, c-format
-msgid "cannot stat template '%s'"
-msgstr "не удалось выполнить stat для шаблона «%s»"
+#: builtin/merge.c:267 builtin/pull.c:190
+msgid "option for selected merge strategy"
+msgstr "опции для выбранной стратегии слияния"
 
-#: builtin/init-db.c:66
-#, c-format
-msgid "cannot opendir '%s'"
-msgstr "не удалось выполнить opendir для «%s»"
+#: builtin/merge.c:269
+msgid "merge commit message (for a non-fast-forward merge)"
+msgstr "сообщение коммита для слияния (для слияния без перемотки вперед)"
 
-#: builtin/init-db.c:77
-#, c-format
-msgid "cannot readlink '%s'"
-msgstr "не удалось выполнить readlink для «%s»"
+#: builtin/merge.c:276
+msgid "abort the current in-progress merge"
+msgstr "отменить выполнение происходящего слияния"
 
-#: builtin/init-db.c:79
-#, c-format
-msgid "cannot symlink '%s' '%s'"
-msgstr "не удалось создать символьную ссылку «%s» на «%s»"
+#: builtin/merge.c:278
+msgid "continue the current in-progress merge"
+msgstr "продолжить выполнение происходящего слияния"
 
-#: builtin/init-db.c:85
-#, c-format
-msgid "cannot copy '%s' to '%s'"
-msgstr "не удалось скопировать файл «%s» в «%s»"
+#: builtin/merge.c:280 builtin/pull.c:197
+msgid "allow merging unrelated histories"
+msgstr "разрешить слияние несвязанных историй изменений"
 
-#: builtin/init-db.c:89
-#, c-format
-msgid "ignoring template %s"
-msgstr "игнорирование шаблона %s"
+#: builtin/merge.c:286
+msgid "verify commit-msg hook"
+msgstr "проверить перехватчик commit-msg"
 
-#: builtin/init-db.c:120
-#, c-format
-msgid "templates not found %s"
-msgstr "шаблоны не найдены %s"
+#: builtin/merge.c:311
+msgid "could not run stash."
+msgstr "не удалось выполнить stash."
 
-#: builtin/init-db.c:135
-#, c-format
-msgid "not copying templates from '%s': %s"
-msgstr "не копирую шаблоны из «%s»: %s"
+#: builtin/merge.c:316
+msgid "stash failed"
+msgstr "сбой при выполнении stash"
 
-#: builtin/init-db.c:328
+#: builtin/merge.c:321
 #, c-format
-msgid "unable to handle file type %d"
-msgstr "не удается обработать файл типа %d"
+msgid "not a valid object: %s"
+msgstr "неправильный объект: %s"
 
-#: builtin/init-db.c:331
-#, c-format
-msgid "unable to move %s to %s"
-msgstr "не удается переместить файл %s в %s"
+#: builtin/merge.c:343 builtin/merge.c:360
+msgid "read-tree failed"
+msgstr "сбой при выполнении read-tree"
 
-#: builtin/init-db.c:348 builtin/init-db.c:351
-#, c-format
-msgid "%s already exists"
-msgstr "%s уже существует"
+#: builtin/merge.c:390
+msgid " (nothing to squash)"
+msgstr " (нечего уплотнять)"
 
-#: builtin/init-db.c:404
+#: builtin/merge.c:401
 #, c-format
-msgid "Reinitialized existing shared Git repository in %s%s\n"
-msgstr "Переинициализирован существующий общий репозиторий Git в %s%s\n"
+msgid "Squash commit -- not updating HEAD\n"
+msgstr "Уплотнение коммита — не обновляя HEAD\n"
 
-#: builtin/init-db.c:405
+#: builtin/merge.c:451
 #, c-format
-msgid "Reinitialized existing Git repository in %s%s\n"
-msgstr "Переинициализирован существующий репозиторий Git в %s%s\n"
+msgid "No merge message -- not updating HEAD\n"
+msgstr "Нет сообщения слияния — не обновляем HEAD\n"
 
-#: builtin/init-db.c:409
+#: builtin/merge.c:502
 #, c-format
-msgid "Initialized empty shared Git repository in %s%s\n"
-msgstr "Инициализирован пустой общий репозиторий Git в %s%s\n"
+msgid "'%s' does not point to a commit"
+msgstr "«%s» не указывает на коммит"
 
-#: builtin/init-db.c:410
+#: builtin/merge.c:589
 #, c-format
-msgid "Initialized empty Git repository in %s%s\n"
-msgstr "Инициализирован пустой репозиторий Git в %s%s\n"
-
-#: builtin/init-db.c:458
-msgid ""
-"git init [-q | --quiet] [--bare] [--template=<template-directory>] "
-"[--shared[=<permissions>]] [<directory>]"
-msgstr "git init [-q | --quiet] [--bare] [--template=<каталог-шаблонов>] [--shared[=<права-доступа>]] [<каталог>]"
-
-#: builtin/init-db.c:481
-msgid "permissions"
-msgstr "права-доступа"
+msgid "Bad branch.%s.mergeoptions string: %s"
+msgstr "Неправильная строка branch.%s.mergeoptions: %s"
 
-#: builtin/init-db.c:482
-msgid "specify that the git repository is to be shared amongst several users"
-msgstr "укажите, если репозиторий git будет использоваться несколькими пользователями"
+#: builtin/merge.c:712
+msgid "Not handling anything other than two heads merge."
+msgstr "Не обрабатываю ничего, кроме слияния двух указателей на ветки."
 
-#: builtin/init-db.c:516 builtin/init-db.c:521
+#: builtin/merge.c:726
 #, c-format
-msgid "cannot mkdir %s"
-msgstr "не удалось выполнить mkdir %s"
+msgid "Unknown option for merge-recursive: -X%s"
+msgstr "Неизвестный параметр merge-recursive: -X%s"
 
-#: builtin/init-db.c:525
+#: builtin/merge.c:741
 #, c-format
-msgid "cannot chdir to %s"
-msgstr "не удалось выполнить chdir в %s"
+msgid "unable to write %s"
+msgstr "не удалось записать %s"
 
-#: builtin/init-db.c:546
+#: builtin/merge.c:793
 #, c-format
-msgid ""
-"%s (or --work-tree=<directory>) not allowed without specifying %s (or --git-"
-"dir=<directory>)"
-msgstr "%s (или --work-tree=<каталог>) нельзя использовать без указания %s (или --git-dir=<каталог>)"
+msgid "Could not read from '%s'"
+msgstr "Не удалось прочесть из «%s»"
 
-#: builtin/init-db.c:574
+#: builtin/merge.c:802
 #, c-format
-msgid "Cannot access work tree '%s'"
-msgstr "Не удалось получить доступ к рабочему каталогу «%s»"
+msgid "Not committing merge; use 'git commit' to complete the merge.\n"
+msgstr "Не выполняю коммит слияния; используйте «git commit» для завершения слияния.\n"
 
-#: builtin/interpret-trailers.c:15
+#: builtin/merge.c:808
 msgid ""
-"git interpret-trailers [--in-place] [--trim-empty] [(--trailer "
-"<token>[(=|:)<value>])...] [<file>...]"
-msgstr "git interpret-trailers [--in-place] [--trim-empty] [(--trailer <ключ>[(=|:)<значение>])…] [<файл>…]"
-
-#: builtin/interpret-trailers.c:92
-msgid "edit files in place"
-msgstr "редактировать файлы на месте"
-
-#: builtin/interpret-trailers.c:93
-msgid "trim empty trailers"
-msgstr "удалять пустые завершители"
+"Please enter a commit message to explain why this merge is necessary,\n"
+"especially if it merges an updated upstream into a topic branch.\n"
+"\n"
+msgstr ""
 
-#: builtin/interpret-trailers.c:96
-msgid "where to place the new trailer"
-msgstr "где поместить новый завершитель"
+#: builtin/merge.c:813
+msgid "An empty message aborts the commit.\n"
+msgstr ""
 
-#: builtin/interpret-trailers.c:98
-msgid "action if trailer already exists"
-msgstr "действие, если завершитель уже существует"
+#: builtin/merge.c:816
+#, c-format
+msgid ""
+"Lines starting with '%c' will be ignored, and an empty message aborts\n"
+"the commit.\n"
+msgstr ""
 
-#: builtin/interpret-trailers.c:100
-msgid "action if trailer is missing"
-msgstr "действие, если завершитель не существует"
+#: builtin/merge.c:857
+msgid "Empty commit message."
+msgstr "Пустое сообщение коммита."
 
-#: builtin/interpret-trailers.c:102
-msgid "output only the trailers"
-msgstr "вывести только завершители"
+#: builtin/merge.c:876
+#, c-format
+msgid "Wonderful.\n"
+msgstr "Прекрасно.\n"
 
-#: builtin/interpret-trailers.c:103
-msgid "do not apply config rules"
-msgstr "не применять правила из файла конфигурации"
+#: builtin/merge.c:936
+#, c-format
+msgid "Automatic merge failed; fix conflicts and then commit the result.\n"
+msgstr "Не удалось провести автоматическое слияние; исправьте конфликты и сделайте коммит результата.\n"
 
-#: builtin/interpret-trailers.c:104
-msgid "join whitespace-continued values"
-msgstr "объединить значения разделенные пробелом"
+#: builtin/merge.c:975
+msgid "No current branch."
+msgstr "Нет текущей ветки."
 
-#: builtin/interpret-trailers.c:105
-msgid "set parsing options"
-msgstr "указание опций разбора"
+#: builtin/merge.c:977
+msgid "No remote for the current branch."
+msgstr "У текущей ветки нет внешнего репозитория."
 
-#: builtin/interpret-trailers.c:107
-msgid "trailer"
-msgstr "завершитель"
+#: builtin/merge.c:979
+msgid "No default upstream defined for the current branch."
+msgstr "Для текущей ветки не указана вышестоящая ветка по умолчанию."
 
-#: builtin/interpret-trailers.c:108
-msgid "trailer(s) to add"
-msgstr "завершители для добавления"
+#: builtin/merge.c:984
+#, c-format
+msgid "No remote-tracking branch for %s from %s"
+msgstr "Не указана внешняя отслеживаемая ветка для %s на %s"
 
-#: builtin/interpret-trailers.c:117
-msgid "--trailer with --only-input does not make sense"
-msgstr "--trailer одновременно с --only-input не имеет смысла"
+#: builtin/merge.c:1041
+#, c-format
+msgid "Bad value '%s' in environment '%s'"
+msgstr "Плохое значение «%s» в переменной окружения «%s»"
 
-#: builtin/interpret-trailers.c:127
-msgid "no input file given for in-place editing"
-msgstr "ничего не передано, для редактирования файлов на месте"
+#: builtin/merge.c:1144
+#, c-format
+msgid "not something we can merge in %s: %s"
+msgstr "не является тем, что можно слить в %s: %s"
 
-#: builtin/log.c:46
-msgid "git log [<options>] [<revision-range>] [[--] <path>...]"
-msgstr "git log [<опции>] [<диапазон-редакций>] [[--] <путь>…]"
+#: builtin/merge.c:1178
+msgid "not something we can merge"
+msgstr "не является тем, что можно слить"
 
-#: builtin/log.c:47
-msgid "git show [<options>] <object>..."
-msgstr "git show [<опции>] <объект>…"
+#: builtin/merge.c:1281
+msgid "--abort expects no arguments"
+msgstr "опция --abort не принимает аргументы"
 
-#: builtin/log.c:91
-#, c-format
-msgid "invalid --decorate option: %s"
-msgstr "неправильный параметр для --decorate: %s"
+#: builtin/merge.c:1285
+msgid "There is no merge to abort (MERGE_HEAD missing)."
+msgstr "Нет слияния, которое можно отменить (отсутствует файл MERGE_HEAD)."
 
-#: builtin/log.c:151
-msgid "suppress diff output"
-msgstr "не выводить различия"
+#: builtin/merge.c:1297
+msgid "--continue expects no arguments"
+msgstr "опция --continue не принимает аргументы"
 
-#: builtin/log.c:152
-msgid "show source"
-msgstr "показать источник"
+#: builtin/merge.c:1301
+msgid "There is no merge in progress (MERGE_HEAD missing)."
+msgstr "Сейчас не происходит слияние (отсутствует файл MERGE_HEAD)."
 
-#: builtin/log.c:153
-msgid "Use mail map file"
-msgstr "Использовать файл соответствия почтовых адресов"
+#: builtin/merge.c:1317
+msgid ""
+"You have not concluded your merge (MERGE_HEAD exists).\n"
+"Please, commit your changes before you merge."
+msgstr "Вы не завершили слияние (присутствует файл MERGE_HEAD).\nВыполните коммит ваших изменений, перед слиянием."
 
-#: builtin/log.c:155
-msgid "only decorate refs that match <pattern>"
-msgstr "декорировать только ссылки соответствующие <шаблону>"
+#: builtin/merge.c:1324
+msgid ""
+"You have not concluded your cherry-pick (CHERRY_PICK_HEAD exists).\n"
+"Please, commit your changes before you merge."
+msgstr "Вы не завершили копирование коммита (присутствует файл CHERRY_PICK_HEAD).\nПожалуйста, закоммитьте ваши изменения, перед слиянием."
 
-#: builtin/log.c:157
-msgid "do not decorate refs that match <pattern>"
-msgstr "не декорировать ссылки соответствующие <шаблону>"
+#: builtin/merge.c:1327
+msgid "You have not concluded your cherry-pick (CHERRY_PICK_HEAD exists)."
+msgstr "Вы не завершили копирование коммита (присутствует файл CHERRY_PICK_HEAD)."
 
-#: builtin/log.c:158
-msgid "decorate options"
-msgstr "опции формата вывода ссылок"
+#: builtin/merge.c:1341
+msgid "You cannot combine --squash with --no-ff."
+msgstr "Нельзя использовать одновременно --squash и --no-ff."
 
-#: builtin/log.c:161
-msgid "Process line range n,m in file, counting from 1"
-msgstr "Обработать диапазон строк n,m из файла, начиная с 1"
+#: builtin/merge.c:1349
+msgid "No commit specified and merge.defaultToUpstream not set."
+msgstr "Коммит не указан и параметр merge.defaultToUpstream не установлен."
 
-#: builtin/log.c:257
-#, c-format
-msgid "Final output: %d %s\n"
-msgstr "Финальный вывод: %d %s\n"
+#: builtin/merge.c:1366
+msgid "Squash commit into empty head not supported yet"
+msgstr "Уплотнение коммита в пустую ветку еще не поддерживается"
 
-#: builtin/log.c:508
-#, c-format
-msgid "git show %s: bad file"
-msgstr "git show %s: плохой файл"
+#: builtin/merge.c:1368
+msgid "Non-fast-forward commit does not make sense into an empty head"
+msgstr "Коммит, не являющийся перемоткой вперед, нет смысла делать в пустую ветку."
 
-#: builtin/log.c:523 builtin/log.c:617
+#: builtin/merge.c:1373
 #, c-format
-msgid "Could not read object %s"
-msgstr "Не удалось прочитать объект %s"
+msgid "%s - not something we can merge"
+msgstr "%s не является тем, что можно слить"
 
-#: builtin/log.c:641
-#, c-format
-msgid "Unknown type: %d"
-msgstr "Неизвестный тип объекта: %d"
+#: builtin/merge.c:1375
+msgid "Can merge only exactly one commit into empty head"
+msgstr "Можно только один коммит в пустую ветку."
 
-#: builtin/log.c:762
-msgid "format.headers without value"
-msgstr "в format.headers не указано значение"
+#: builtin/merge.c:1454
+msgid "refusing to merge unrelated histories"
+msgstr "отказ слияния несвязанных историй изменений"
 
-#: builtin/log.c:863
-msgid "name of output directory is too long"
-msgstr "слишком длинное имя выходного каталога"
+#: builtin/merge.c:1463
+msgid "Already up to date."
+msgstr "Уже обновлено."
 
-#: builtin/log.c:879
+#: builtin/merge.c:1473
 #, c-format
-msgid "Cannot open patch file %s"
-msgstr "Ну удалось открыть файл изменений %s"
-
-#: builtin/log.c:896
-msgid "Need exactly one range."
-msgstr "Нужен только один диапазон."
-
-#: builtin/log.c:906
-msgid "Not a range."
-msgstr "Не является диапазоном."
+msgid "Updating %s..%s\n"
+msgstr "Обновление %s..%s\n"
 
-#: builtin/log.c:1012
-msgid "Cover letter needs email format"
-msgstr "Сопроводительное письмо должно быть в формате электронной почты"
+#: builtin/merge.c:1515
+#, c-format
+msgid "Trying really trivial in-index merge...\n"
+msgstr "Попытка тривиального слияния в индексе…\n"
 
-#: builtin/log.c:1092
+#: builtin/merge.c:1522
 #, c-format
-msgid "insane in-reply-to: %s"
-msgstr "ошибка в поле in-reply-to: %s"
+msgid "Nope.\n"
+msgstr "Не вышло.\n"
 
-#: builtin/log.c:1119
-msgid "git format-patch [<options>] [<since> | <revision-range>]"
-msgstr "git format-patch [<опции>] [<начиная-с> | <диапазон-редакций>]"
+#: builtin/merge.c:1547
+msgid "Already up to date. Yeeah!"
+msgstr "Уже обновлено. Круто!"
 
-#: builtin/log.c:1169
-msgid "Two output directories?"
-msgstr "Два выходных каталога?"
+#: builtin/merge.c:1553
+msgid "Not possible to fast-forward, aborting."
+msgstr "Перемотка вперед невозможна, отмена."
 
-#: builtin/log.c:1276 builtin/log.c:1927 builtin/log.c:1929 builtin/log.c:1941
+#: builtin/merge.c:1576 builtin/merge.c:1655
 #, c-format
-msgid "Unknown commit %s"
-msgstr "Неизвестный коммит %s"
+msgid "Rewinding the tree to pristine...\n"
+msgstr "Перемотка дерева к исходному состоянию…\n"
 
-#: builtin/log.c:1286 builtin/notes.c:887 builtin/tag.c:516
+#: builtin/merge.c:1580
 #, c-format
-msgid "Failed to resolve '%s' as a valid ref."
-msgstr "Не удалось разрешить «%s» как ссылку."
-
-#: builtin/log.c:1291
-msgid "Could not find exact merge base."
-msgstr "Не удалось найти точную базу слияния."
+msgid "Trying merge strategy %s...\n"
+msgstr "Попытка слияния с помощью стратегии %s…\n"
 
-#: builtin/log.c:1295
-msgid ""
-"Failed to get upstream, if you want to record base commit automatically,\n"
-"please use git branch --set-upstream-to to track a remote branch.\n"
-"Or you could specify base commit by --base=<base-commit-id> manually."
-msgstr "Не удалось получить вышестоящую ветку. Если вы хотите записать базовый коммит автомитически, то используйте git branch --set-upstream-to для отслеживания внешней ветки.\nИли же вы можете указать базовый коммит указанием --base=<идентификатор-базового-коммита> вручную."
+#: builtin/merge.c:1646
+#, c-format
+msgid "No merge strategy handled the merge.\n"
+msgstr "Ни одна стратегия слияния не обработала слияние.\n"
 
-#: builtin/log.c:1315
-msgid "Failed to find exact merge base"
-msgstr "Не удалось найти точную базу слияния"
+#: builtin/merge.c:1648
+#, c-format
+msgid "Merge with strategy %s failed.\n"
+msgstr "Сбой при слиянии с помощью стратегии %s.\n"
 
-#: builtin/log.c:1326
-msgid "base commit should be the ancestor of revision list"
-msgstr "базовый коммит должен быть предком списка редакций"
+#: builtin/merge.c:1657
+#, c-format
+msgid "Using the %s to prepare resolving by hand.\n"
+msgstr "Использую %s для подготовки ручного разрешения конфликтов.\n"
 
-#: builtin/log.c:1330
-msgid "base commit shouldn't be in revision list"
-msgstr "базовый коммит не должен быть в списке редакций"
+#: builtin/merge.c:1669
+#, c-format
+msgid "Automatic merge went well; stopped before committing as requested\n"
+msgstr "Автоматическое слияние прошло успешно; как и запрашивали, остановлено перед выполнением коммита\n"
 
-#: builtin/log.c:1379
-msgid "cannot get patch id"
-msgstr "не удалось получить идентификатор патча"
+#: builtin/merge-base.c:32
+msgid "git merge-base [-a | --all] <commit> <commit>..."
+msgstr "git merge-base [-a | --all] <коммит> <коммит>…"
 
-#: builtin/log.c:1438
-msgid "use [PATCH n/m] even with a single patch"
-msgstr "выводить [PATCH n/m] даже когда один патч"
+#: builtin/merge-base.c:33
+msgid "git merge-base [-a | --all] --octopus <commit>..."
+msgstr "git merge-base [-a | --all] --octopus <коммит>…"
 
-#: builtin/log.c:1441
-msgid "use [PATCH] even with multiple patches"
-msgstr "выводить [PATCH] даже когда несколько патчей"
+#: builtin/merge-base.c:34
+msgid "git merge-base --independent <commit>..."
+msgstr "git merge-base --independent <коммит>…"
 
-#: builtin/log.c:1445
-msgid "print patches to standard out"
-msgstr "выводить патчи на стандартный вывод"
+#: builtin/merge-base.c:35
+msgid "git merge-base --is-ancestor <commit> <commit>"
+msgstr "git merge-base --is-ancestor <коммит> <коммит>"
 
-#: builtin/log.c:1447
-msgid "generate a cover letter"
-msgstr "создать сопроводительное письмо"
+#: builtin/merge-base.c:36
+msgid "git merge-base --fork-point <ref> [<commit>]"
+msgstr "git merge-base --fork-point <ссылка> [<коммит>]"
 
-#: builtin/log.c:1449
-msgid "use simple number sequence for output file names"
-msgstr "использовать простую последовательность чисел для имен выходных файлов"
+#: builtin/merge-base.c:153
+msgid "output all common ancestors"
+msgstr "вывести всех общих предков"
 
-#: builtin/log.c:1450
-msgid "sfx"
-msgstr "суффикс"
+#: builtin/merge-base.c:155
+msgid "find ancestors for a single n-way merge"
+msgstr "вывести предков для одного многоходового слияния"
 
-#: builtin/log.c:1451
-msgid "use <sfx> instead of '.patch'"
-msgstr "использовать суффикс <суффикс> вместо «.patch»"
+#: builtin/merge-base.c:157
+msgid "list revs not reachable from others"
+msgstr "вывести список редаций, которые не достижимы из друг друга"
 
-#: builtin/log.c:1453
-msgid "start numbering patches at <n> instead of 1"
-msgstr "начать нумерацию патчей с <n>, а не с 1"
+#: builtin/merge-base.c:159
+msgid "is the first one ancestor of the other?"
+msgstr "является первым предком второго указанного коммита?"
 
-#: builtin/log.c:1455
-msgid "mark the series as Nth re-roll"
-msgstr "пометить серию как энную попытку"
+#: builtin/merge-base.c:161
+msgid "find where <commit> forked from reflog of <ref>"
+msgstr "найти журнале ссылок <ссылка> где именно <коммит> разветвился"
 
-#: builtin/log.c:1457
-msgid "Use [RFC PATCH] instead of [PATCH]"
-msgstr "Использовать [RFC PATCH] вместо [PATCH]"
+#: builtin/merge-file.c:9
+msgid ""
+"git merge-file [<options>] [-L <name1> [-L <orig> [-L <name2>]]] <file1> "
+"<orig-file> <file2>"
+msgstr "git merge-file [<опции>] [-L имя1 [-L orig [-L имя2]]] <файл1> <ориг-файл> <файл2>"
 
-#: builtin/log.c:1460
-msgid "Use [<prefix>] instead of [PATCH]"
-msgstr "Использовать [<префикс>] вместо [PATCH]"
+#: builtin/merge-file.c:35
+msgid "send results to standard output"
+msgstr "вывести результат на стандартный вывод"
 
-#: builtin/log.c:1463
-msgid "store resulting files in <dir>"
-msgstr "сохранить результирующие файлы в <каталог>"
+#: builtin/merge-file.c:36
+msgid "use a diff3 based merge"
+msgstr "использовать diff3 слияние"
 
-#: builtin/log.c:1466
-msgid "don't strip/add [PATCH]"
-msgstr "не обрезать/добавлять [PATCH]"
+#: builtin/merge-file.c:37
+msgid "for conflicts, use our version"
+msgstr "при возникновении конфликтов, использовать нашу версию"
 
-#: builtin/log.c:1469
-msgid "don't output binary diffs"
-msgstr "не выводить двоичные различия"
+#: builtin/merge-file.c:39
+msgid "for conflicts, use their version"
+msgstr "при возникновении конфликтов, использовать их версию"
 
-#: builtin/log.c:1471
-msgid "output all-zero hash in From header"
-msgstr "выводить нулевую хэш-сумму в заголовке From"
+#: builtin/merge-file.c:41
+msgid "for conflicts, use a union version"
+msgstr "при возникновении конфликтов, использовать обе версии"
 
-#: builtin/log.c:1473
-msgid "don't include a patch matching a commit upstream"
-msgstr "не включать патч, если коммит уже есть в вышестоящей ветке"
+#: builtin/merge-file.c:44
+msgid "for conflicts, use this marker size"
+msgstr "при возникновении конфликтов, использовать этот размер маркера"
 
-#: builtin/log.c:1475
-msgid "show patch format instead of default (patch + stat)"
-msgstr "выводить в формате патча, а не в стандартном (патч + статистика)"
+#: builtin/merge-file.c:45
+msgid "do not warn about conflicts"
+msgstr "не предупреждать о конфликтах"
 
-#: builtin/log.c:1477
-msgid "Messaging"
-msgstr "Передача сообщений"
+#: builtin/merge-file.c:47
+msgid "set labels for file1/orig-file/file2"
+msgstr "установить метки для файл1/ориг-файл/файл2"
 
-#: builtin/log.c:1478
-msgid "header"
-msgstr "заголовок"
+#: builtin/merge-recursive.c:46
+#, c-format
+msgid "unknown option %s"
+msgstr "неизвестная опция %s"
 
-#: builtin/log.c:1479
-msgid "add email header"
-msgstr "добавить заголовок сообщения"
+#: builtin/merge-recursive.c:52
+#, c-format
+msgid "could not parse object '%s'"
+msgstr "не удалось разобрать объект «%s»"
 
-#: builtin/log.c:1480 builtin/log.c:1482
-msgid "email"
-msgstr "почта"
+#: builtin/merge-recursive.c:56
+#, c-format
+msgid "cannot handle more than %d base. Ignoring %s."
+msgid_plural "cannot handle more than %d bases. Ignoring %s."
+msgstr[0] "невозможно обработать больше %d базы. Игнорирую %s."
+msgstr[1] "невозможно обработать больше %d баз. Игнорирую %s."
+msgstr[2] "невозможно обработать больше %d баз. Игнорирую %s."
+msgstr[3] "невозможно обработать больше %d базы. Игнорирую %s."
 
-#: builtin/log.c:1480
-msgid "add To: header"
-msgstr "добавить заголовок To:"
+#: builtin/merge-recursive.c:64
+msgid "not handling anything other than two heads merge."
+msgstr "не обрабатываю ничего, кроме слияния двух указателей на ветки."
 
-#: builtin/log.c:1482
-msgid "add Cc: header"
-msgstr "добавить заголовок Cc:"
+#: builtin/merge-recursive.c:70 builtin/merge-recursive.c:72
+#, c-format
+msgid "could not resolve ref '%s'"
+msgstr "не удалось распознать ссылку «%s»"
 
-#: builtin/log.c:1484
-msgid "ident"
-msgstr "идентификатор"
+#: builtin/merge-recursive.c:78
+#, c-format
+msgid "Merging %s with %s\n"
+msgstr "Слияние %s и %s\n"
 
-#: builtin/log.c:1485
-msgid "set From address to <ident> (or committer ident if absent)"
-msgstr "установить адрес отправителя на <идентификатор> (или на идентификатор коммитера, если отсутствует)"
+#: builtin/mktree.c:66
+msgid "git mktree [-z] [--missing] [--batch]"
+msgstr "git mktree [-z] [--missing] [--batch]"
 
-#: builtin/log.c:1487
-msgid "message-id"
-msgstr "идентификатор-сообщения"
+#: builtin/mktree.c:154
+msgid "input is NUL terminated"
+msgstr "ввод отделённый НУЛЕВЫМИ символами"
 
-#: builtin/log.c:1488
-msgid "make first mail a reply to <message-id>"
-msgstr "сделать первое письмо ответом на <идентификатор-сообщения>"
+#: builtin/mktree.c:155 builtin/write-tree.c:26
+msgid "allow missing objects"
+msgstr "допустить отсутствие объектов"
 
-#: builtin/log.c:1489 builtin/log.c:1492
-msgid "boundary"
-msgstr "вложение"
+#: builtin/mktree.c:156
+msgid "allow creation of more than one tree"
+msgstr "допустить создание более одного дерева"
 
-#: builtin/log.c:1490
-msgid "attach the patch"
-msgstr "приложить патч"
+#: builtin/multi-pack-index.c:9
+msgid "git multi-pack-index [--object-dir=<dir>] (write|verify)"
+msgstr ""
 
-#: builtin/log.c:1493
-msgid "inline the patch"
-msgstr "включить патч в текст письма"
+#: builtin/multi-pack-index.c:22
+msgid "object directory containing set of packfile and pack-index pairs"
+msgstr ""
 
-#: builtin/log.c:1497
-msgid "enable message threading, styles: shallow, deep"
-msgstr "включить в письмах иерархичность, стили: shallow (частичную), deep (глубокую)"
+#: builtin/multi-pack-index.c:40 builtin/prune-packed.c:67
+msgid "too many arguments"
+msgstr ""
 
-#: builtin/log.c:1499
-msgid "signature"
-msgstr "подпись"
+#: builtin/multi-pack-index.c:51
+#, c-format
+msgid "unrecognized verb: %s"
+msgstr ""
 
-#: builtin/log.c:1500
-msgid "add a signature"
-msgstr "добавить подпись"
+#: builtin/mv.c:18
+msgid "git mv [<options>] <source>... <destination>"
+msgstr "git mv [<опции>] <источник>… <назначение>"
 
-#: builtin/log.c:1501
-msgid "base-commit"
-msgstr "базовый коммит"
+#: builtin/mv.c:83
+#, c-format
+msgid "Directory %s is in index and no submodule?"
+msgstr "Каталог %s в индексе и не является подмодулем?"
 
-#: builtin/log.c:1502
-msgid "add prerequisite tree info to the patch series"
-msgstr "добавить информацию о требовании дерева к серии патчей"
+#: builtin/mv.c:85
+msgid "Please stage your changes to .gitmodules or stash them to proceed"
+msgstr "Чтобы продолжить, проиндексируйте или спрячьте ваши изменения в файле .gitmodules"
 
-#: builtin/log.c:1504
-msgid "add a signature from a file"
-msgstr "добавить подпись из файла"
+#: builtin/mv.c:103
+#, c-format
+msgid "%.*s is in index"
+msgstr "%.*s в индесе"
 
-#: builtin/log.c:1505
-msgid "don't print the patch filenames"
-msgstr "не выводить имена файлов патчей"
+#: builtin/mv.c:125
+msgid "force move/rename even if target exists"
+msgstr "принудительно перемещать/переименовать, даже если цель существует"
 
-#: builtin/log.c:1507
-msgid "show progress while generating patches"
-msgstr "показать прогресс выполнения во создания патчей"
+#: builtin/mv.c:127
+msgid "skip move/rename errors"
+msgstr "пропускать ошибки при перемещении/переименовании"
 
-#: builtin/log.c:1582
+#: builtin/mv.c:169
 #, c-format
-msgid "invalid ident line: %s"
-msgstr "неправильная строка идентификации: %s"
+msgid "destination '%s' is not a directory"
+msgstr "целевой путь «%s» не является каталогом"
 
-#: builtin/log.c:1597
-msgid "-n and -k are mutually exclusive."
-msgstr "-n и -k нельзя использовать одновременно"
+#: builtin/mv.c:180
+#, c-format
+msgid "Checking rename of '%s' to '%s'\n"
+msgstr "Проверка переименования из «%s» в «%s»\n"
 
-#: builtin/log.c:1599
-msgid "--subject-prefix/--rfc and -k are mutually exclusive."
-msgstr "--subject-prefix/--rfc и -k нельзя использовать одновременно."
+#: builtin/mv.c:184
+msgid "bad source"
+msgstr "плохой источник"
 
-#: builtin/log.c:1607
-msgid "--name-only does not make sense"
-msgstr "--name-only не имеет смысла"
+#: builtin/mv.c:187
+msgid "can not move directory into itself"
+msgstr "нельзя переместить каталог в самого себя"
 
-#: builtin/log.c:1609
-msgid "--name-status does not make sense"
-msgstr "--name-status не имеет смысла"
+#: builtin/mv.c:190
+msgid "cannot move directory over file"
+msgstr "нельзя переместить каталог в файл"
 
-#: builtin/log.c:1611
-msgid "--check does not make sense"
-msgstr "--check не имеет смысла"
+#: builtin/mv.c:199
+msgid "source directory is empty"
+msgstr "исходный каталог пуст"
 
-#: builtin/log.c:1641
-msgid "standard output, or directory, which one?"
-msgstr "стандартный вывод или каталог?"
+#: builtin/mv.c:224
+msgid "not under version control"
+msgstr "не под версионным контролем"
 
-#: builtin/log.c:1643
-#, c-format
-msgid "Could not create directory '%s'"
-msgstr "Не удалось создать каталог «%s»"
+#: builtin/mv.c:227
+msgid "destination exists"
+msgstr "целевой путь уже существует"
 
-#: builtin/log.c:1736
+#: builtin/mv.c:235
 #, c-format
-msgid "unable to read signature file '%s'"
-msgstr "не удалось прочитать файл подписи «%s»"
+msgid "overwriting '%s'"
+msgstr "перезапись «%s»"
 
-#: builtin/log.c:1768
-msgid "Generating patches"
-msgstr "Создание патчей"
+#: builtin/mv.c:238
+msgid "Cannot overwrite"
+msgstr "Не удалось перезаписать"
 
-#: builtin/log.c:1812
-msgid "Failed to create output files"
-msgstr "Сбой при создании выходных файлов"
+#: builtin/mv.c:241
+msgid "multiple sources for the same target"
+msgstr "несколько источников для одного целевого пути"
 
-#: builtin/log.c:1862
-msgid "git cherry [-v] [<upstream> [<head> [<limit>]]]"
-msgstr "git cherry [-v] [<вышестоящая-ветка> [<голова> [<ограничение>]]]"
+#: builtin/mv.c:243
+msgid "destination directory does not exist"
+msgstr "целевой каталог не существует"
 
-#: builtin/log.c:1916
+#: builtin/mv.c:250
 #, c-format
-msgid ""
-"Could not find a tracked remote branch, please specify <upstream> "
-"manually.\n"
-msgstr "Не удалось найти отслеживаемую внешнюю ветку, укажите <вышестоящую-ветку> вручную.\n"
+msgid "%s, source=%s, destination=%s"
+msgstr "%s, откуда=%s, куда=%s"
 
-#: builtin/ls-files.c:468
-msgid "git ls-files [<options>] [<file>...]"
-msgstr "git ls-files [<опции>] [<файл>…]"
+#: builtin/mv.c:271
+#, c-format
+msgid "Renaming %s to %s\n"
+msgstr "Переименование %s в %s\n"
 
-#: builtin/ls-files.c:517
-msgid "identify the file status with tags"
-msgstr "выводить имена файлов с метками"
+#: builtin/mv.c:277 builtin/remote.c:717 builtin/repack.c:516
+#, c-format
+msgid "renaming '%s' failed"
+msgstr "сбой при переименовании «%s»"
 
-#: builtin/ls-files.c:519
-msgid "use lowercase letters for 'assume unchanged' files"
-msgstr "использовать символы в нижнем регистре для «предположительно без изменений» файлов"
+#: builtin/name-rev.c:355
+msgid "git name-rev [<options>] <commit>..."
+msgstr "git name-rev [<опции>] <коммит>…"
 
-#: builtin/ls-files.c:521
-msgid "use lowercase letters for 'fsmonitor clean' files"
-msgstr "использовать символы нижнего регистра для файлов «fsmonitor clean»"
+#: builtin/name-rev.c:356
+msgid "git name-rev [<options>] --all"
+msgstr "git name-rev [<опции>] --all"
 
-#: builtin/ls-files.c:523
-msgid "show cached files in the output (default)"
-msgstr "показывать кэшированные файлы при выводе (по умолчанию)"
+#: builtin/name-rev.c:357
+msgid "git name-rev [<options>] --stdin"
+msgstr "git name-rev [<опции>] --stdin"
 
-#: builtin/ls-files.c:525
-msgid "show deleted files in the output"
-msgstr "показывать удаленные файлы при выводе"
+#: builtin/name-rev.c:415
+msgid "print only names (no SHA-1)"
+msgstr "выводить только имена (без SHA-1)"
 
-#: builtin/ls-files.c:527
-msgid "show modified files in the output"
-msgstr "показывать измененные файлы при выводе"
+#: builtin/name-rev.c:416
+msgid "only use tags to name the commits"
+msgstr "использовать только метки для именования коммитов"
 
-#: builtin/ls-files.c:529
-msgid "show other files in the output"
-msgstr "показывать другие файлы при выводе"
+#: builtin/name-rev.c:418
+msgid "only use refs matching <pattern>"
+msgstr "использовать только ссылки, соответствующие <шаблону> "
 
-#: builtin/ls-files.c:531
-msgid "show ignored files in the output"
-msgstr "показывать игнорируемые файлы при выводе"
+#: builtin/name-rev.c:420
+msgid "ignore refs matching <pattern>"
+msgstr "игнорировать ссылки, соответствующие <шаблону>"
 
-#: builtin/ls-files.c:534
-msgid "show staged contents' object name in the output"
-msgstr "показывать имя индексированного объекта на выводе"
+#: builtin/name-rev.c:422
+msgid "list all commits reachable from all refs"
+msgstr "вывести список всех коммитов, достижимых со всех ссылок"
 
-#: builtin/ls-files.c:536
-msgid "show files on the filesystem that need to be removed"
-msgstr "показывать файлы в файловой системе, которые должны быть удалены"
+#: builtin/name-rev.c:423
+msgid "read from stdin"
+msgstr "прочитать из стандартного ввода"
 
-#: builtin/ls-files.c:538
-msgid "show 'other' directories' names only"
-msgstr "показывать только имена у «других» каталогов"
+#: builtin/name-rev.c:424
+msgid "allow to print `undefined` names (default)"
+msgstr "разрешить вывод «undefined», если не найдено (по умолчанию)"
 
-#: builtin/ls-files.c:540
-msgid "show line endings of files"
-msgstr "показать концы строк файлов"
+#: builtin/name-rev.c:430
+msgid "dereference tags in the input (internal use)"
+msgstr "разыменовывать введенные метки (для внутреннего использования)"
 
-#: builtin/ls-files.c:542
-msgid "don't show empty directories"
-msgstr "не показывать пустые каталоги"
+#: builtin/notes.c:28
+msgid "git notes [--ref <notes-ref>] [list [<object>]]"
+msgstr "git notes [--ref <ссылка-на-заметку>] [list [<объект>]]"
 
-#: builtin/ls-files.c:545
-msgid "show unmerged files in the output"
-msgstr "показывать не слитые файлы на выводе"
+#: builtin/notes.c:29
+msgid ""
+"git notes [--ref <notes-ref>] add [-f] [--allow-empty] [-m <msg> | -F <file>"
+" | (-c | -C) <object>] [<object>]"
+msgstr "git notes [--ref <ссылка-на-заметку>] add [-f] [--allow-empty] [-m <сообщение> | -F <файл> | (-c | -C) <объект>] [<объект>]"
 
-#: builtin/ls-files.c:547
-msgid "show resolve-undo information"
-msgstr "показывать информации о разрешении конфликтов и отмене"
+#: builtin/notes.c:30
+msgid "git notes [--ref <notes-ref>] copy [-f] <from-object> <to-object>"
+msgstr "git notes [--ref <ссылка-на-заметку>] copy [-f] <из-объекта> <в-объект>"
 
-#: builtin/ls-files.c:549
-msgid "skip files matching pattern"
-msgstr "пропустить файлы, соответствующие шаблону"
+#: builtin/notes.c:31
+msgid ""
+"git notes [--ref <notes-ref>] append [--allow-empty] [-m <msg> | -F <file> |"
+" (-c | -C) <object>] [<object>]"
+msgstr "git notes [--ref <ссылка-на-заметку>] append [--allow-empty] [-m <сообщение> | -F <файл> | (-c | -C) <объект>] [<объект>]"
 
-#: builtin/ls-files.c:552
-msgid "exclude patterns are read from <file>"
-msgstr "прочитать шаблоны исключения из <файл>"
+#: builtin/notes.c:32
+msgid "git notes [--ref <notes-ref>] edit [--allow-empty] [<object>]"
+msgstr "git notes [--ref <ссылка-на-заметку>] edit [--allow-empty] [<объект>]"
 
-#: builtin/ls-files.c:555
-msgid "read additional per-directory exclude patterns in <file>"
-msgstr "прочитать дополнительные покаталожные шаблоны исключения из <файл>"
+#: builtin/notes.c:33
+msgid "git notes [--ref <notes-ref>] show [<object>]"
+msgstr "git notes [--ref <ссылка-на-заметку>] show [<объект>]"
 
-#: builtin/ls-files.c:557
-msgid "add the standard git exclusions"
-msgstr "добавить стандартные исключения git"
+#: builtin/notes.c:34
+msgid ""
+"git notes [--ref <notes-ref>] merge [-v | -q] [-s <strategy>] <notes-ref>"
+msgstr "git notes [--ref <ссылка-на-заметку>] merge [-v | -q] [-s <стратегия>] <ссылка-на-заметку>"
 
-#: builtin/ls-files.c:560
-msgid "make the output relative to the project top directory"
-msgstr "выводить пути относительно корневого каталога проекта"
+#: builtin/notes.c:35
+msgid "git notes merge --commit [-v | -q]"
+msgstr "git notes merge --commit [-v | -q]"
 
-#: builtin/ls-files.c:563
-msgid "recurse through submodules"
-msgstr "рекурсивно по подмодулям"
+#: builtin/notes.c:36
+msgid "git notes merge --abort [-v | -q]"
+msgstr "git notes merge --abort [-v | -q]"
 
-#: builtin/ls-files.c:565
-msgid "if any <file> is not in the index, treat this as an error"
-msgstr "если какой-либо <файл> не в индексе, считать это ошибкой"
+#: builtin/notes.c:37
+msgid "git notes [--ref <notes-ref>] remove [<object>...]"
+msgstr "git notes [--ref <ссылка-на-заметку>] remove [<объект>…]"
 
-#: builtin/ls-files.c:566
-msgid "tree-ish"
-msgstr "указатель-дерева"
+#: builtin/notes.c:38
+msgid "git notes [--ref <notes-ref>] prune [-n] [-v]"
+msgstr "git notes [--ref <имя-заметки>] prune [-n] [-v]"
 
-#: builtin/ls-files.c:567
-msgid "pretend that paths removed since <tree-ish> are still present"
-msgstr "притвориться, что пути удалены, т.к. <указатель-дерева> еще существует"
+#: builtin/notes.c:39
+msgid "git notes [--ref <notes-ref>] get-ref"
+msgstr "git notes [--ref <ссылка-на-заметку>] get-ref"
 
-#: builtin/ls-files.c:569
-msgid "show debugging data"
-msgstr "показать отладочную информацию"
+#: builtin/notes.c:44
+msgid "git notes [list [<object>]]"
+msgstr "git notes [list [<объект>]]"
 
-#: builtin/ls-remote.c:7
-msgid ""
-"git ls-remote [--heads] [--tags] [--refs] [--upload-pack=<exec>]\n"
-"                     [-q | --quiet] [--exit-code] [--get-url]\n"
-"                     [--symref] [<repository> [<refs>...]]"
-msgstr "git ls-remote [--heads] [--tags] [--refs] [--upload-pack=<запуск>]\n                     [-q | --quiet] [--exit-code] [--get-url]\n                     [--symref] [<репозиторий> [<ссылки>…]]"
+#: builtin/notes.c:49
+msgid "git notes add [<options>] [<object>]"
+msgstr "git notes add [<опции>] [<объект>]"
 
-#: builtin/ls-remote.c:52
-msgid "do not print remote URL"
-msgstr "не выводить URL внешних репозиториев"
+#: builtin/notes.c:54
+msgid "git notes copy [<options>] <from-object> <to-object>"
+msgstr "git notes copy [<опции>] <из-объекта> <в-объект>"
 
-#: builtin/ls-remote.c:53 builtin/ls-remote.c:55
-msgid "exec"
-msgstr "запуск"
+#: builtin/notes.c:55
+msgid "git notes copy --stdin [<from-object> <to-object>]..."
+msgstr "git notes copy --stdin [<из-объекта> <в-объект>]…"
 
-#: builtin/ls-remote.c:54 builtin/ls-remote.c:56
-msgid "path of git-upload-pack on the remote host"
-msgstr "путь к git-upload-pack на внешнем сервере"
+#: builtin/notes.c:60
+msgid "git notes append [<options>] [<object>]"
+msgstr "git notes append [<опции>] [<объект>]"
 
-#: builtin/ls-remote.c:58
-msgid "limit to tags"
-msgstr "ограничить вывод метками"
+#: builtin/notes.c:65
+msgid "git notes edit [<object>]"
+msgstr "git notes edit [<объект>]"
 
-#: builtin/ls-remote.c:59
-msgid "limit to heads"
-msgstr "ограничить вывод указателями на ветки"
+#: builtin/notes.c:70
+msgid "git notes show [<object>]"
+msgstr "git notes show [<объект>]"
 
-#: builtin/ls-remote.c:60
-msgid "do not show peeled tags"
-msgstr "не показывать удалённые метки"
+#: builtin/notes.c:75
+msgid "git notes merge [<options>] <notes-ref>"
+msgstr "git notes merge [<опции>] <ссылка-на-заметку>"
 
-#: builtin/ls-remote.c:62
-msgid "take url.<base>.insteadOf into account"
-msgstr "учитывать url.<база>.insteadOf"
+#: builtin/notes.c:76
+msgid "git notes merge --commit [<options>]"
+msgstr "git notes merge --commit [<опции>]"
 
-#: builtin/ls-remote.c:64
-msgid "exit with exit code 2 if no matching refs are found"
-msgstr "выходить с кодом 2, если соответствующие ссылки не найдены"
+#: builtin/notes.c:77
+msgid "git notes merge --abort [<options>]"
+msgstr "git notes merge --abort [<опции>]"
 
-#: builtin/ls-remote.c:66
-msgid "show underlying ref in addition to the object pointed by it"
-msgstr "показать также внутреннюю ссылку в дополнение к объекту, на который она указывает"
+#: builtin/notes.c:82
+msgid "git notes remove [<object>]"
+msgstr "git notes remove [<опции>]"
 
-#: builtin/ls-tree.c:29
-msgid "git ls-tree [<options>] <tree-ish> [<path>...]"
-msgstr "git ls-tree [<опции>] <указатель-дерева> [<путь>…]"
+#: builtin/notes.c:87
+msgid "git notes prune [<options>]"
+msgstr "git notes prune [<опции>]"
 
-#: builtin/ls-tree.c:127
-msgid "only show trees"
-msgstr "выводить только деревья"
+#: builtin/notes.c:92
+msgid "git notes get-ref"
+msgstr "git notes get-ref"
 
-#: builtin/ls-tree.c:129
-msgid "recurse into subtrees"
-msgstr "проходить рекурсивно в поддеревья"
+#: builtin/notes.c:97
+msgid "Write/edit the notes for the following object:"
+msgstr "Записать/изменить заметки для следующего объекта:"
 
-#: builtin/ls-tree.c:131
-msgid "show trees when recursing"
-msgstr "выводить деревья при рекурсивном проходе"
+#: builtin/notes.c:150
+#, c-format
+msgid "unable to start 'show' for object '%s'"
+msgstr "не удалось запустить «show» для объекта «%s»"
 
-#: builtin/ls-tree.c:134
-msgid "terminate entries with NUL byte"
-msgstr "разделять записи с помощью НУЛЕВОГО байта"
+#: builtin/notes.c:154
+msgid "could not read 'show' output"
+msgstr "не удалось прочитать вывод «show»"
 
-#: builtin/ls-tree.c:135
-msgid "include object size"
-msgstr "включить размер объекта"
+#: builtin/notes.c:162
+#, c-format
+msgid "failed to finish 'show' for object '%s'"
+msgstr "не удалось завершить «show» для объекта «%s»"
 
-#: builtin/ls-tree.c:137 builtin/ls-tree.c:139
-msgid "list only filenames"
-msgstr "выводить только имена файлов"
+#: builtin/notes.c:197
+msgid "please supply the note contents using either -m or -F option"
+msgstr "пожалуйста, укажите содержимое заметки, используя опцию -m или -F"
 
-#: builtin/ls-tree.c:142
-msgid "use full path names"
-msgstr "использовать полные пути"
+#: builtin/notes.c:206
+msgid "unable to write note object"
+msgstr "не удалось записать объект заметки"
 
-#: builtin/ls-tree.c:144
-msgid "list entire tree; not just current directory (implies --full-name)"
-msgstr "вывести полное дерево; не только текущий каталог (включает в себя --full-name)"
+#: builtin/notes.c:208
+#, c-format
+msgid "the note contents have been left in %s"
+msgstr "содержимое заметки осталось в %s"
 
-#: builtin/mailsplit.c:241
+#: builtin/notes.c:242 builtin/tag.c:522
 #, c-format
-msgid "empty mbox: '%s'"
-msgstr "пустой mbox: «%s»"
+msgid "could not open or read '%s'"
+msgstr "не удалось открыть или прочитать «%s»"
 
-#: builtin/merge.c:48
-msgid "git merge [<options>] [<commit>...]"
-msgstr "git merge [<опции>] [<коммит>…]"
+#: builtin/notes.c:263 builtin/notes.c:313 builtin/notes.c:315
+#: builtin/notes.c:383 builtin/notes.c:438 builtin/notes.c:526
+#: builtin/notes.c:531 builtin/notes.c:610 builtin/notes.c:672
+#, c-format
+msgid "failed to resolve '%s' as a valid ref."
+msgstr "не удалось разрешить «%s» как ссылку."
 
-#: builtin/merge.c:49
-msgid "git merge --abort"
-msgstr "git merge --abort"
+#: builtin/notes.c:265
+#, c-format
+msgid "failed to read object '%s'."
+msgstr "не удалось прочитать объект «%s»."
 
-#: builtin/merge.c:50
-msgid "git merge --continue"
-msgstr "git merge --continue"
+#: builtin/notes.c:268
+#, c-format
+msgid "cannot read note data from non-blob object '%s'."
+msgstr "не удалось прочитать данные заметки из недвоичного объекта «%s»."
 
-#: builtin/merge.c:107
-msgid "switch `m' requires a value"
-msgstr "при указании параметра «m» требуется указать значение"
+#: builtin/notes.c:309
+#, c-format
+msgid "malformed input line: '%s'."
+msgstr "неправильная введенная строка: «%s»."
 
-#: builtin/merge.c:144
+#: builtin/notes.c:324
 #, c-format
-msgid "Could not find merge strategy '%s'.\n"
-msgstr "Не удалось найти стратегию слияния «%s».\n"
+msgid "failed to copy notes from '%s' to '%s'"
+msgstr "не удалось скопировать заметку из «%s» в «%s»"
 
-#: builtin/merge.c:145
+#. TRANSLATORS: the first %s will be replaced by a git
+#. notes command: 'add', 'merge', 'remove', etc.
+#: builtin/notes.c:356
 #, c-format
-msgid "Available strategies are:"
-msgstr "Доступные стратегии:"
+msgid "refusing to %s notes in %s (outside of refs/notes/)"
+msgstr "отказ в перезаписи %s заметок в %s (за пределами refs/notes/)"
+
+#: builtin/notes.c:376 builtin/notes.c:431 builtin/notes.c:509
+#: builtin/notes.c:521 builtin/notes.c:598 builtin/notes.c:665
+#: builtin/notes.c:815 builtin/notes.c:963 builtin/notes.c:985
+msgid "too many parameters"
+msgstr "передано слишком много параметров"
 
-#: builtin/merge.c:150
+#: builtin/notes.c:389 builtin/notes.c:678
 #, c-format
-msgid "Available custom strategies are:"
-msgstr "Доступные пользовательские стратегии:"
+msgid "no note found for object %s."
+msgstr "не найдена заметка для объекта %s."
 
-#: builtin/merge.c:200 builtin/pull.c:137
-msgid "do not show a diffstat at the end of the merge"
-msgstr "не выводить статистику изменений после окончания слияния"
+#: builtin/notes.c:410 builtin/notes.c:576
+msgid "note contents as a string"
+msgstr "текстовое содержимое заметки"
 
-#: builtin/merge.c:203 builtin/pull.c:140
-msgid "show a diffstat at the end of the merge"
-msgstr "вывести статистику изменений после окончания слияния"
+#: builtin/notes.c:413 builtin/notes.c:579
+msgid "note contents in a file"
+msgstr "содержимое заметки в файле"
 
-#: builtin/merge.c:204 builtin/pull.c:143
-msgid "(synonym to --stat)"
-msgstr "(синоним для --stat)"
+#: builtin/notes.c:416 builtin/notes.c:582
+msgid "reuse and edit specified note object"
+msgstr "использовать и отредактировать указанный объект заметки"
 
-#: builtin/merge.c:206 builtin/pull.c:146
-msgid "add (at most <n>) entries from shortlog to merge commit message"
-msgstr "добавить (максимум <n>) записей из короткого журнала в сообщение коммита у слияния"
+#: builtin/notes.c:419 builtin/notes.c:585
+msgid "reuse specified note object"
+msgstr "использовать указанный объект заметки"
 
-#: builtin/merge.c:209 builtin/pull.c:152
-msgid "create a single commit instead of doing a merge"
-msgstr "создать один коммит, вместо выполнения слияния"
+#: builtin/notes.c:422 builtin/notes.c:588
+msgid "allow storing empty note"
+msgstr "разрешить сохранение пустой заметки"
 
-#: builtin/merge.c:211 builtin/pull.c:155
-msgid "perform a commit if the merge succeeds (default)"
-msgstr "сделать коммит, если слияние прошло успешно (по умолчанию)"
+#: builtin/notes.c:423 builtin/notes.c:496
+msgid "replace existing notes"
+msgstr "заменить существующие заметки"
 
-#: builtin/merge.c:213 builtin/pull.c:158
-msgid "edit message before committing"
-msgstr "отредактировать сообщение перед выполнением коммита"
+#: builtin/notes.c:448
+#, c-format
+msgid ""
+"Cannot add notes. Found existing notes for object %s. Use '-f' to overwrite "
+"existing notes"
+msgstr "Не удалось добавить заметку. Найдена существующая заметка у объекта %s. Используйте параметр «-f» для перезаписи существующих заметок."
 
-#: builtin/merge.c:214
-msgid "allow fast-forward (default)"
-msgstr "разрешить перемотку вперед (по умолчанию)"
+#: builtin/notes.c:463 builtin/notes.c:544
+#, c-format
+msgid "Overwriting existing notes for object %s\n"
+msgstr "Перезапись существующих заметок у объекта %s\n"
 
-#: builtin/merge.c:216 builtin/pull.c:164
-msgid "abort if fast-forward is not possible"
-msgstr "отменить выполнение слияния, если перемотка вперед невозможна"
+#: builtin/notes.c:475 builtin/notes.c:637 builtin/notes.c:902
+#, c-format
+msgid "Removing note for object %s\n"
+msgstr "Удаление заметки у объекта %s\n"
 
-#: builtin/merge.c:220 builtin/pull.c:167
-msgid "verify that the named commit has a valid GPG signature"
-msgstr "проверить, что указанный коммит имеет верную электронную подпись GPG"
+#: builtin/notes.c:497
+msgid "read objects from stdin"
+msgstr "прочитать объекты из стандартного ввода"
 
-#: builtin/merge.c:221 builtin/notes.c:777 builtin/pull.c:171
-#: builtin/revert.c:109
-msgid "strategy"
-msgstr "стратегия"
+#: builtin/notes.c:499
+msgid "load rewriting config for <command> (implies --stdin)"
+msgstr "загрузить настройки перезаписи для команды <команда> (включает в себя --stdin)"
 
-#: builtin/merge.c:222 builtin/pull.c:172
-msgid "merge strategy to use"
-msgstr "используемая стратегия слияния"
+#: builtin/notes.c:517
+msgid "too few parameters"
+msgstr "передано слишком мало параметров"
 
-#: builtin/merge.c:223 builtin/pull.c:175
-msgid "option=value"
-msgstr "опция=значение"
+#: builtin/notes.c:538
+#, c-format
+msgid ""
+"Cannot copy notes. Found existing notes for object %s. Use '-f' to overwrite"
+" existing notes"
+msgstr "Не удалось скопировать заметку. Найдена существующая заметка у объекта %s. Используйте параметр «-f» для перезаписи существующих заметок."
 
-#: builtin/merge.c:224 builtin/pull.c:176
-msgid "option for selected merge strategy"
-msgstr "опции для выбранной стратегии слияния"
+#: builtin/notes.c:550
+#, c-format
+msgid "missing notes on source object %s. Cannot copy."
+msgstr "нет заметок у исходного объекта %s. Нельзя скопировать."
 
-#: builtin/merge.c:226
-msgid "merge commit message (for a non-fast-forward merge)"
-msgstr "сообщение коммита для слияния (для слияния без перемотки вперед)"
+#: builtin/notes.c:603
+#, c-format
+msgid ""
+"The -m/-F/-c/-C options have been deprecated for the 'edit' subcommand.\n"
+"Please use 'git notes add -f -m/-F/-c/-C' instead.\n"
+msgstr "Опции -m/-F/-c/-C для подкоманды «edit» устарели.\nИспользуйте вместо них «git notes add -f -m/-F/-c/-C».\n"
 
-#: builtin/merge.c:230
-msgid "abort the current in-progress merge"
-msgstr "отменить выполнение происходящего слияния"
+#: builtin/notes.c:698
+msgid "failed to delete ref NOTES_MERGE_PARTIAL"
+msgstr "не удалось удалить ссылку NOTES_MERGE_PARTIAL"
 
-#: builtin/merge.c:232
-msgid "continue the current in-progress merge"
-msgstr "продолжить выполнение происходящего слияния"
+#: builtin/notes.c:700
+msgid "failed to delete ref NOTES_MERGE_REF"
+msgstr "не удалось удалить ссылку NOTES_MERGE_REF"
 
-#: builtin/merge.c:234 builtin/pull.c:183
-msgid "allow merging unrelated histories"
-msgstr "разрешить слияние несвязанных историй изменений"
+#: builtin/notes.c:702
+msgid "failed to remove 'git notes merge' worktree"
+msgstr "не удалось удалить рабочий каталог «git notes merge»"
 
-#: builtin/merge.c:240
-msgid "verify commit-msg hook"
-msgstr "проверить перехватчик commit-msg"
+#: builtin/notes.c:722
+msgid "failed to read ref NOTES_MERGE_PARTIAL"
+msgstr "не удалось прочитать ссылку NOTES_MERGE_PARTIAL"
 
-#: builtin/merge.c:265
-msgid "could not run stash."
-msgstr "не удалось выполнить stash."
+#: builtin/notes.c:724
+msgid "could not find commit from NOTES_MERGE_PARTIAL."
+msgstr "не удалось найти коммит из NOTES_MERGE_PARTIAL."
+
+#: builtin/notes.c:726
+msgid "could not parse commit from NOTES_MERGE_PARTIAL."
+msgstr "не удалось разобрать коммит из NOTES_MERGE_PARTIAL."
 
-#: builtin/merge.c:270
-msgid "stash failed"
-msgstr "сбой при выполнении stash"
+#: builtin/notes.c:739
+msgid "failed to resolve NOTES_MERGE_REF"
+msgstr "не удалось разрешить NOTES_MERGE_REF"
 
-#: builtin/merge.c:275
+#: builtin/notes.c:742
+msgid "failed to finalize notes merge"
+msgstr "не удалось завершить слиние заметок"
+
+#: builtin/notes.c:768
 #, c-format
-msgid "not a valid object: %s"
-msgstr "неправильный объект: %s"
+msgid "unknown notes merge strategy %s"
+msgstr "неизвестная стратегия слияния заметок %s"
 
-#: builtin/merge.c:297 builtin/merge.c:314
-msgid "read-tree failed"
-msgstr "сбой при выполнении read-tree"
+#: builtin/notes.c:784
+msgid "General options"
+msgstr "Общие опции"
 
-#: builtin/merge.c:344
-msgid " (nothing to squash)"
-msgstr " (нечего уплотнять)"
+#: builtin/notes.c:786
+msgid "Merge options"
+msgstr "Опции слияния"
 
-#: builtin/merge.c:355
-#, c-format
-msgid "Squash commit -- not updating HEAD\n"
-msgstr "Уплотнение коммита — не обновляя HEAD\n"
+#: builtin/notes.c:788
+msgid ""
+"resolve notes conflicts using the given strategy "
+"(manual/ours/theirs/union/cat_sort_uniq)"
+msgstr "разрешить конфликты заметок с помощью указанной стратегии (manual/ours/theirs/union/cat_sort_uniq)"
 
-#: builtin/merge.c:405
-#, c-format
-msgid "No merge message -- not updating HEAD\n"
-msgstr "Нет сообщения слияния — не обновляем HEAD\n"
+#: builtin/notes.c:790
+msgid "Committing unmerged notes"
+msgstr "Коммит не слитых заметок"
 
-#: builtin/merge.c:455
-#, c-format
-msgid "'%s' does not point to a commit"
-msgstr "«%s» не указывает на коммит"
+#: builtin/notes.c:792
+msgid "finalize notes merge by committing unmerged notes"
+msgstr "завершить слияние заметок коммитом не слитых заметок"
 
-#: builtin/merge.c:545
-#, c-format
-msgid "Bad branch.%s.mergeoptions string: %s"
-msgstr "Неправильная строка branch.%s.mergeoptions: %s"
+#: builtin/notes.c:794
+msgid "Aborting notes merge resolution"
+msgstr "Отмена разрешения слияния заметок"
 
-#: builtin/merge.c:667
-msgid "Not handling anything other than two heads merge."
-msgstr "Не обрабатываю ничего, кроме слияния двух указателей на ветки."
+#: builtin/notes.c:796
+msgid "abort notes merge"
+msgstr "отменить слияние заметок"
 
-#: builtin/merge.c:681
-#, c-format
-msgid "Unknown option for merge-recursive: -X%s"
-msgstr "Неизвестный параметр merge-recursive: -X%s"
+#: builtin/notes.c:807
+msgid "cannot mix --commit, --abort or -s/--strategy"
+msgstr "нельзя использовать одновременно --commit, --abort и -s/--strategy"
 
-#: builtin/merge.c:696
+#: builtin/notes.c:812
+msgid "must specify a notes ref to merge"
+msgstr "вы должны указать ссылку заметки для слияния"
+
+#: builtin/notes.c:836
 #, c-format
-msgid "unable to write %s"
-msgstr "не удалось записать %s"
+msgid "unknown -s/--strategy: %s"
+msgstr "неизвестный параметр для -s/--strategy: %s"
 
-#: builtin/merge.c:748
+#: builtin/notes.c:873
 #, c-format
-msgid "Could not read from '%s'"
-msgstr "Не удалось прочесть из «%s»"
+msgid "a notes merge into %s is already in-progress at %s"
+msgstr "слияние заметок в %s уже выполняется на %s"
 
-#: builtin/merge.c:757
+#: builtin/notes.c:876
 #, c-format
-msgid "Not committing merge; use 'git commit' to complete the merge.\n"
-msgstr "Не выполняю коммит слияния; используйте «git commit» для завершения слияния.\n"
+msgid "failed to store link to current notes ref (%s)"
+msgstr "не удалось сохранить адрес текущей ссылки на заметку (%s)"
 
-#: builtin/merge.c:763
+#: builtin/notes.c:878
 #, c-format
 msgid ""
-"Please enter a commit message to explain why this merge is necessary,\n"
-"especially if it merges an updated upstream into a topic branch.\n"
-"\n"
-"Lines starting with '%c' will be ignored, and an empty message aborts\n"
-"the commit.\n"
-msgstr "Пожалуйста, введите сообщение коммита, для объяснения, зачем нужно\nэто слияние, особенно, если это слияние обновленной вышестоящей\nветки в тематическую ветку.\n\nСтроки, начинающиеся с «%c» будут проигнорированы, а пустое\nсообщение отменяет процесс коммита.\n"
-
-#: builtin/merge.c:799
-msgid "Empty commit message."
-msgstr "Пустое сообщение коммита."
+"Automatic notes merge failed. Fix conflicts in %s and commit the result with"
+" 'git notes merge --commit', or abort the merge with 'git notes merge "
+"--abort'.\n"
+msgstr "Не удалось автоматически слить заметки. Исправьте конфликты в %s и закоммитьте результат с помощью «git notes merge --commit», или прервите процесс слияния с помощью «git notes merge --abort».\n"
 
-#: builtin/merge.c:819
+#: builtin/notes.c:897 builtin/tag.c:535
 #, c-format
-msgid "Wonderful.\n"
-msgstr "Прекрасно.\n"
+msgid "Failed to resolve '%s' as a valid ref."
+msgstr "Не удалось разрешить «%s» как ссылку."
 
-#: builtin/merge.c:872
+#: builtin/notes.c:900
 #, c-format
-msgid "Automatic merge failed; fix conflicts and then commit the result.\n"
-msgstr "Не удалось провести автоматическое слияние; исправьте конфликты и сделайте коммит результата.\n"
+msgid "Object %s has no note\n"
+msgstr "У объекта %s нет заметки\n"
 
-#: builtin/merge.c:911
-msgid "No current branch."
-msgstr "Нет текущей ветки."
+#: builtin/notes.c:912
+msgid "attempt to remove non-existent note is not an error"
+msgstr "попытка удаления несуществующей заметки не является ошибкой"
 
-#: builtin/merge.c:913
-msgid "No remote for the current branch."
-msgstr "У текущей ветки нет внешнего репозитория."
+#: builtin/notes.c:915
+msgid "read object names from the standard input"
+msgstr "прочитать имена объектов из стандартного ввода"
 
-#: builtin/merge.c:915
-msgid "No default upstream defined for the current branch."
-msgstr "Для текущей ветки не указана вышестоящая ветка по умолчанию."
+#: builtin/notes.c:954 builtin/prune.c:130 builtin/worktree.c:165
+msgid "do not remove, show only"
+msgstr "не удалять, только показать список"
 
-#: builtin/merge.c:920
-#, c-format
-msgid "No remote-tracking branch for %s from %s"
-msgstr "Не указана внешняя отслеживаемая ветка для %s на %s"
+#: builtin/notes.c:955
+msgid "report pruned notes"
+msgstr "вывести список удаленных заметок"
 
-#: builtin/merge.c:973
-#, c-format
-msgid "Bad value '%s' in environment '%s'"
-msgstr "Плохое значение «%s» в переменной окружения «%s»"
+#: builtin/notes.c:998
+msgid "notes-ref"
+msgstr "ссылка-на-заметку"
+
+#: builtin/notes.c:999
+msgid "use notes from <notes-ref>"
+msgstr "использовать заметку из <ссылка-на-заметку>"
 
-#: builtin/merge.c:1075
+#: builtin/notes.c:1034 builtin/stash.c:1611
 #, c-format
-msgid "not something we can merge in %s: %s"
-msgstr "не является тем, что можно слить в %s: %s"
+msgid "unknown subcommand: %s"
+msgstr "неизвестная подкоманда: %s"
 
-#: builtin/merge.c:1109
-msgid "not something we can merge"
-msgstr "не является тем, что можно слить"
+#: builtin/pack-objects.c:52
+msgid ""
+"git pack-objects --stdout [<options>...] [< <ref-list> | < <object-list>]"
+msgstr "git pack-objects --stdout [<опции>…] [< <список-ссылок> | < <список-объектов>]"
 
-#: builtin/merge.c:1174
-msgid "--abort expects no arguments"
-msgstr "опция --abort не принимает аргументы"
+#: builtin/pack-objects.c:53
+msgid ""
+"git pack-objects [<options>...] <base-name> [< <ref-list> | < <object-list>]"
+msgstr "git pack-objects [<опции>…] <имя-базы> [< <список-ссылок> | < <список-объектов>]"
 
-#: builtin/merge.c:1178
-msgid "There is no merge to abort (MERGE_HEAD missing)."
-msgstr "Нет слияния, которое можно отменить (отсутствует файл MERGE_HEAD)."
+#: builtin/pack-objects.c:424
+#, c-format
+msgid "bad packed object CRC for %s"
+msgstr ""
 
-#: builtin/merge.c:1190
-msgid "--continue expects no arguments"
-msgstr "опция --continue не принимает аргументы"
+#: builtin/pack-objects.c:435
+#, c-format
+msgid "corrupt packed object for %s"
+msgstr ""
 
-#: builtin/merge.c:1194
-msgid "There is no merge in progress (MERGE_HEAD missing)."
-msgstr "Сейчас не происходит слияние (отсутствует файл MERGE_HEAD)."
+#: builtin/pack-objects.c:566
+#, c-format
+msgid "recursive delta detected for object %s"
+msgstr ""
 
-#: builtin/merge.c:1210
-msgid ""
-"You have not concluded your merge (MERGE_HEAD exists).\n"
-"Please, commit your changes before you merge."
-msgstr "Вы не завершили слияние (присутствует файл MERGE_HEAD).\nВыполните коммит ваших изменений, перед слиянием."
+#: builtin/pack-objects.c:777
+#, c-format
+msgid "ordered %u objects, expected %<PRIu32>"
+msgstr ""
 
-#: builtin/merge.c:1217
-msgid ""
-"You have not concluded your cherry-pick (CHERRY_PICK_HEAD exists).\n"
-"Please, commit your changes before you merge."
-msgstr "Вы не завершили копирование коммита (присутствует файл CHERRY_PICK_HEAD).\nПожалуйста, закоммитьте ваши изменения, перед слиянием."
+#: builtin/pack-objects.c:790
+#, c-format
+msgid "packfile is invalid: %s"
+msgstr ""
 
-#: builtin/merge.c:1220
-msgid "You have not concluded your cherry-pick (CHERRY_PICK_HEAD exists)."
-msgstr "Вы не завершили копирование коммита (присутствует файл CHERRY_PICK_HEAD)."
+#: builtin/pack-objects.c:794
+#, c-format
+msgid "unable to open packfile for reuse: %s"
+msgstr ""
 
-#: builtin/merge.c:1229
-msgid "You cannot combine --squash with --no-ff."
-msgstr "Нельзя использовать одновременно --squash и --no-ff."
+#: builtin/pack-objects.c:798
+msgid "unable to seek in reused packfile"
+msgstr ""
 
-#: builtin/merge.c:1237
-msgid "No commit specified and merge.defaultToUpstream not set."
-msgstr "Коммит не указан и параметр merge.defaultToUpstream не установлен."
+#: builtin/pack-objects.c:809
+msgid "unable to read from reused packfile"
+msgstr ""
 
-#: builtin/merge.c:1254
-msgid "Squash commit into empty head not supported yet"
-msgstr "Уплотнение коммита в пустую ветку еще не поддерживается"
+#: builtin/pack-objects.c:837
+msgid "disabling bitmap writing, packs are split due to pack.packSizeLimit"
+msgstr "отключение записи битовых карт, так как карты были разбиты на части из-за pack.packSizeLimit"
 
-#: builtin/merge.c:1256
-msgid "Non-fast-forward commit does not make sense into an empty head"
-msgstr "Коммит, не являющийся перемоткой вперед, нет смысла делать в пустую ветку."
+#: builtin/pack-objects.c:850
+msgid "Writing objects"
+msgstr "Запись объектов"
 
-#: builtin/merge.c:1261
+#: builtin/pack-objects.c:912 builtin/update-index.c:89
 #, c-format
-msgid "%s - not something we can merge"
-msgstr "%s не является тем, что можно слить"
-
-#: builtin/merge.c:1263
-msgid "Can merge only exactly one commit into empty head"
-msgstr "Можно только один коммит в пустую ветку."
+msgid "failed to stat %s"
+msgstr "не удалось выполнить stat %s"
 
-#: builtin/merge.c:1297
+#: builtin/pack-objects.c:965
 #, c-format
-msgid "Commit %s has an untrusted GPG signature, allegedly by %s."
-msgstr "Коммит %s содержит не доверенную GPG подпись, предположительно от %s."
+msgid "wrote %<PRIu32> objects while expecting %<PRIu32>"
+msgstr ""
 
-#: builtin/merge.c:1300
-#, c-format
-msgid "Commit %s has a bad GPG signature allegedly by %s."
-msgstr "Коммит %s содержит плохую GPG подпись, предположительно от %s."
+#: builtin/pack-objects.c:1161
+msgid "disabling bitmap writing, as some objects are not being packed"
+msgstr "отключение записи битовых карт, так как некоторые объекты не были упакованы"
 
-#: builtin/merge.c:1303
+#: builtin/pack-objects.c:1589
 #, c-format
-msgid "Commit %s does not have a GPG signature."
-msgstr "Коммит %s не содержит GPG подпись."
+msgid "delta base offset overflow in pack for %s"
+msgstr ""
 
-#: builtin/merge.c:1306
+#: builtin/pack-objects.c:1598
 #, c-format
-msgid "Commit %s has a good GPG signature by %s\n"
-msgstr "Коммит %s содержит действительную GPG подпись, от %s.\n"
-
-#: builtin/merge.c:1368
-msgid "refusing to merge unrelated histories"
-msgstr "отказ слияния несвязанных историй изменений"
+msgid "delta base offset out of bound for %s"
+msgstr ""
 
-#: builtin/merge.c:1377
-msgid "Already up to date."
-msgstr "Уже обновлено."
+#: builtin/pack-objects.c:1867
+msgid "Counting objects"
+msgstr "Подсчет объектов"
 
-#: builtin/merge.c:1387
+#: builtin/pack-objects.c:1997
 #, c-format
-msgid "Updating %s..%s\n"
-msgstr "Обновление %s..%s\n"
+msgid "unable to get size of %s"
+msgstr "не удалось получить размер %s"
 
-#: builtin/merge.c:1428
+#: builtin/pack-objects.c:2012
 #, c-format
-msgid "Trying really trivial in-index merge...\n"
-msgstr "Попытка тривиального слияния в индексе…\n"
+msgid "unable to parse object header of %s"
+msgstr "не удалось разобрать заголовок объекта %s"
 
-#: builtin/merge.c:1435
+#: builtin/pack-objects.c:2082 builtin/pack-objects.c:2098
+#: builtin/pack-objects.c:2108
 #, c-format
-msgid "Nope.\n"
-msgstr "Не вышло.\n"
+msgid "object %s cannot be read"
+msgstr ""
 
-#: builtin/merge.c:1460
-msgid "Already up to date. Yeeah!"
-msgstr "Уже обновлено. Круто!"
+#: builtin/pack-objects.c:2085 builtin/pack-objects.c:2112
+#, c-format
+msgid "object %s inconsistent object length (%<PRIuMAX> vs %<PRIuMAX>)"
+msgstr ""
 
-#: builtin/merge.c:1466
-msgid "Not possible to fast-forward, aborting."
-msgstr "Перемотка вперед невозможна, отмена."
+#: builtin/pack-objects.c:2122
+msgid "suboptimal pack - out of memory"
+msgstr ""
 
-#: builtin/merge.c:1489 builtin/merge.c:1568
+#: builtin/pack-objects.c:2448
 #, c-format
-msgid "Rewinding the tree to pristine...\n"
-msgstr "Перемотка дерева к исходному состоянию…\n"
+msgid "Delta compression using up to %d threads"
+msgstr "При сжатии изменений используется до %d потоков"
 
-#: builtin/merge.c:1493
+#: builtin/pack-objects.c:2580
 #, c-format
-msgid "Trying merge strategy %s...\n"
-msgstr "Попытка слияния с помощью стратегии %s…\n"
+msgid "unable to pack objects reachable from tag %s"
+msgstr ""
 
-#: builtin/merge.c:1559
-#, c-format
-msgid "No merge strategy handled the merge.\n"
-msgstr "Ни одна стратегия слияния не обработала слияние.\n"
+#: builtin/pack-objects.c:2667
+msgid "Compressing objects"
+msgstr "Сжатие объектов"
 
-#: builtin/merge.c:1561
-#, c-format
-msgid "Merge with strategy %s failed.\n"
-msgstr "Сбой при слиянии с помощью стратегии %s.\n"
+#: builtin/pack-objects.c:2673
+msgid "inconsistency with delta count"
+msgstr ""
 
-#: builtin/merge.c:1570
+#: builtin/pack-objects.c:2754
 #, c-format
-msgid "Using the %s to prepare resolving by hand.\n"
-msgstr "Использую %s для подготовки ручного разрешения конфликтов.\n"
+msgid ""
+"expected edge object ID, got garbage:\n"
+" %s"
+msgstr ""
 
-#: builtin/merge.c:1582
+#: builtin/pack-objects.c:2760
 #, c-format
-msgid "Automatic merge went well; stopped before committing as requested\n"
-msgstr "Автоматическое слияние прошло успешно; как и запрашивали, остановлено перед выполнением коммита\n"
+msgid ""
+"expected object ID, got garbage:\n"
+" %s"
+msgstr ""
 
-#: builtin/merge-base.c:30
-msgid "git merge-base [-a | --all] <commit> <commit>..."
-msgstr "git merge-base [-a | --all] <коммит> <коммит>…"
+#: builtin/pack-objects.c:2858
+msgid "invalid value for --missing"
+msgstr "недопустимое значение для --missing"
 
-#: builtin/merge-base.c:31
-msgid "git merge-base [-a | --all] --octopus <commit>..."
-msgstr "git merge-base [-a | --all] --octopus <коммит>…"
+#: builtin/pack-objects.c:2917 builtin/pack-objects.c:3025
+msgid "cannot open pack index"
+msgstr ""
 
-#: builtin/merge-base.c:32
-msgid "git merge-base --independent <commit>..."
-msgstr "git merge-base --independent <коммит>…"
+#: builtin/pack-objects.c:2948
+#, c-format
+msgid "loose object at %s could not be examined"
+msgstr ""
 
-#: builtin/merge-base.c:33
-msgid "git merge-base --is-ancestor <commit> <commit>"
-msgstr "git merge-base --is-ancestor <коммит> <коммит>"
+#: builtin/pack-objects.c:3033
+msgid "unable to force loose object"
+msgstr ""
 
-#: builtin/merge-base.c:34
-msgid "git merge-base --fork-point <ref> [<commit>]"
-msgstr "git merge-base --fork-point <ссылка> [<коммит>]"
+#: builtin/pack-objects.c:3125
+#, c-format
+msgid "not a rev '%s'"
+msgstr ""
 
-#: builtin/merge-base.c:220
-msgid "output all common ancestors"
-msgstr "вывести всех общих предков"
+#: builtin/pack-objects.c:3128
+#, c-format
+msgid "bad revision '%s'"
+msgstr ""
 
-#: builtin/merge-base.c:222
-msgid "find ancestors for a single n-way merge"
-msgstr "вывести предков для одного многоходового слияния"
+#: builtin/pack-objects.c:3153
+msgid "unable to add recent objects"
+msgstr ""
 
-#: builtin/merge-base.c:224
-msgid "list revs not reachable from others"
-msgstr "вывести список редаций, которые не достижимы из друг друга"
+#: builtin/pack-objects.c:3206
+#, c-format
+msgid "unsupported index version %s"
+msgstr "неподдерживаемая версия индекса %s"
 
-#: builtin/merge-base.c:226
-msgid "is the first one ancestor of the other?"
-msgstr "является первым предком второго указанного коммита?"
+#: builtin/pack-objects.c:3210
+#, c-format
+msgid "bad index version '%s'"
+msgstr "плохая версия индекса «%s»"
 
-#: builtin/merge-base.c:228
-msgid "find where <commit> forked from reflog of <ref>"
-msgstr "найти журнале ссылок <ссылка> где именно <коммит> разветвился"
+#: builtin/pack-objects.c:3240
+msgid "do not show progress meter"
+msgstr "не выводить прогресс выполнения"
 
-#: builtin/merge-file.c:9
-msgid ""
-"git merge-file [<options>] [-L <name1> [-L <orig> [-L <name2>]]] <file1> "
-"<orig-file> <file2>"
-msgstr "git merge-file [<опции>] [-L имя1 [-L orig [-L имя2]]] <файл1> <ориг-файл> <файл2>"
+#: builtin/pack-objects.c:3242
+msgid "show progress meter"
+msgstr "показать прогресс выполнения"
 
-#: builtin/merge-file.c:33
-msgid "send results to standard output"
-msgstr "вывести результат на стандартный вывод"
+#: builtin/pack-objects.c:3244
+msgid "show progress meter during object writing phase"
+msgstr "показать прогресс выполнения во время записи объектов"
 
-#: builtin/merge-file.c:34
-msgid "use a diff3 based merge"
-msgstr "использовать diff3 слияние"
+#: builtin/pack-objects.c:3247
+msgid "similar to --all-progress when progress meter is shown"
+msgstr "похоже на --all-progress при включенном прогрессе выполнения"
 
-#: builtin/merge-file.c:35
-msgid "for conflicts, use our version"
-msgstr "при возникновении конфликтов, использовать нашу версию"
+#: builtin/pack-objects.c:3248
+msgid "<version>[,<offset>]"
+msgstr ""
 
-#: builtin/merge-file.c:37
-msgid "for conflicts, use their version"
-msgstr "при возникновении конфликтов, использовать их версию"
+#: builtin/pack-objects.c:3249
+msgid "write the pack index file in the specified idx format version"
+msgstr "записать файл индекса пакета в указанной версии формата"
 
-#: builtin/merge-file.c:39
-msgid "for conflicts, use a union version"
-msgstr "при возникновении конфликтов, использовать обе версии"
+#: builtin/pack-objects.c:3252
+msgid "maximum size of each output pack file"
+msgstr "максимальный размер каждого выходного файла пакета"
 
-#: builtin/merge-file.c:42
-msgid "for conflicts, use this marker size"
-msgstr "при возникновении конфликтов, использовать этот размер маркера"
+#: builtin/pack-objects.c:3254
+msgid "ignore borrowed objects from alternate object store"
+msgstr "игнорировать чужие объекты, взятые из альтернативного хранилища объектов"
 
-#: builtin/merge-file.c:43
-msgid "do not warn about conflicts"
-msgstr "не предупреждать о конфликтах"
+#: builtin/pack-objects.c:3256
+msgid "ignore packed objects"
+msgstr "игнорировать упакованные объекты"
 
-#: builtin/merge-file.c:45
-msgid "set labels for file1/orig-file/file2"
-msgstr "установить метки для файл1/ориг-файл/файл2"
+#: builtin/pack-objects.c:3258
+msgid "limit pack window by objects"
+msgstr "ограничить окно пакета по количеству объектов"
 
-#: builtin/merge-recursive.c:45
-#, c-format
-msgid "unknown option %s"
-msgstr "неизвестная опция %s"
+#: builtin/pack-objects.c:3260
+msgid "limit pack window by memory in addition to object limit"
+msgstr "дополнительно к количеству объектов ограничить окно пакета по памяти"
 
-#: builtin/merge-recursive.c:51
-#, c-format
-msgid "could not parse object '%s'"
-msgstr "не удалось разобрать объект «%s»"
+#: builtin/pack-objects.c:3262
+msgid "maximum length of delta chain allowed in the resulting pack"
+msgstr "максимальная разрешенная длина цепочки дельт в результирующем пакете"
 
-#: builtin/merge-recursive.c:55
-#, c-format
-msgid "cannot handle more than %d base. Ignoring %s."
-msgid_plural "cannot handle more than %d bases. Ignoring %s."
-msgstr[0] "невозможно обработать больше %d базы. Игнорирую %s."
-msgstr[1] "невозможно обработать больше %d баз. Игнорирую %s."
-msgstr[2] "невозможно обработать больше %d баз. Игнорирую %s."
-msgstr[3] "невозможно обработать больше %d базы. Игнорирую %s."
+#: builtin/pack-objects.c:3264
+msgid "reuse existing deltas"
+msgstr "использовать повторно существующие дельты"
 
-#: builtin/merge-recursive.c:63
-msgid "not handling anything other than two heads merge."
-msgstr "не обрабатываю ничего, кроме слияния двух указателей на ветки."
+#: builtin/pack-objects.c:3266
+msgid "reuse existing objects"
+msgstr "использовать повторно существующие объекты"
 
-#: builtin/merge-recursive.c:69 builtin/merge-recursive.c:71
-#, c-format
-msgid "could not resolve ref '%s'"
-msgstr "не удалось распознать ссылку «%s»"
+#: builtin/pack-objects.c:3268
+msgid "use OFS_DELTA objects"
+msgstr "использовать объекты OFS_DELTA"
 
-#: builtin/merge-recursive.c:77
-#, c-format
-msgid "Merging %s with %s\n"
-msgstr "Слияние %s и %s\n"
+#: builtin/pack-objects.c:3270
+msgid "use threads when searching for best delta matches"
+msgstr "использовать многопоточность при поиске лучших совпадений дельт"
 
-#: builtin/mktree.c:65
-msgid "git mktree [-z] [--missing] [--batch]"
-msgstr "git mktree [-z] [--missing] [--batch]"
+#: builtin/pack-objects.c:3272
+msgid "do not create an empty pack output"
+msgstr "не создавать пустые выходные пакеты"
 
-#: builtin/mktree.c:153
-msgid "input is NUL terminated"
-msgstr "ввод отделённый НУЛЕВЫМИ символами"
+#: builtin/pack-objects.c:3274
+msgid "read revision arguments from standard input"
+msgstr "прочитать аргументы редакций из стандартного ввода"
 
-#: builtin/mktree.c:154 builtin/write-tree.c:25
-msgid "allow missing objects"
-msgstr "допустить отсутствие объектов"
+#: builtin/pack-objects.c:3276
+msgid "limit the objects to those that are not yet packed"
+msgstr "ограничиться объектами, которые еще не упакованы"
 
-#: builtin/mktree.c:155
-msgid "allow creation of more than one tree"
-msgstr "допустить создание более одного дерева"
+#: builtin/pack-objects.c:3279
+msgid "include objects reachable from any reference"
+msgstr "включить объекты, которые достижимы по любой из ссылок"
 
-#: builtin/mv.c:17
-msgid "git mv [<options>] <source>... <destination>"
-msgstr "git mv [<опции>] <источник>… <назначение>"
+#: builtin/pack-objects.c:3282
+msgid "include objects referred by reflog entries"
+msgstr "включить объекты, на которые ссылаются записи журнала ссылок"
 
-#: builtin/mv.c:83
-#, c-format
-msgid "Directory %s is in index and no submodule?"
-msgstr "Каталог %s в индексе и не является подмодулем?"
+#: builtin/pack-objects.c:3285
+msgid "include objects referred to by the index"
+msgstr "включить объекты, на которые ссылается индекс"
 
-#: builtin/mv.c:85 builtin/rm.c:289
-msgid "Please stage your changes to .gitmodules or stash them to proceed"
-msgstr "Чтобы продолжить, проиндексируйте или спрячьте ваши изменения в файле .gitmodules"
+#: builtin/pack-objects.c:3288
+msgid "output pack to stdout"
+msgstr "вывести пакет на  стандартный вывод"
 
-#: builtin/mv.c:103
-#, c-format
-msgid "%.*s is in index"
-msgstr "%.*s в индесе"
+#: builtin/pack-objects.c:3290
+msgid "include tag objects that refer to objects to be packed"
+msgstr "включить объекты меток, которые ссылаются на упаковываемые объекты"
 
-#: builtin/mv.c:125
-msgid "force move/rename even if target exists"
-msgstr "принудительно перемещать/переименовать, даже если цель существует"
+#: builtin/pack-objects.c:3292
+msgid "keep unreachable objects"
+msgstr "сохранять ссылки на недоступные объекты"
 
-#: builtin/mv.c:126
-msgid "skip move/rename errors"
-msgstr "пропускать ошибки при перемещении/переименовании"
+#: builtin/pack-objects.c:3294
+msgid "pack loose unreachable objects"
+msgstr "паковать недостижимые объекты"
 
-#: builtin/mv.c:167
-#, c-format
-msgid "destination '%s' is not a directory"
-msgstr "целевой путь «%s» не является каталогом"
+#: builtin/pack-objects.c:3296
+msgid "unpack unreachable objects newer than <time>"
+msgstr "распаковать недоступные объекты, которые новее, чем <время>"
 
-#: builtin/mv.c:178
-#, c-format
-msgid "Checking rename of '%s' to '%s'\n"
-msgstr "Проверка переименования из «%s» в «%s»\n"
+#: builtin/pack-objects.c:3299
+msgid "use the sparse reachability algorithm"
+msgstr ""
 
-#: builtin/mv.c:182
-msgid "bad source"
-msgstr "плохой источник"
+#: builtin/pack-objects.c:3301
+msgid "create thin packs"
+msgstr "создавать тонкие пакеты"
 
-#: builtin/mv.c:185
-msgid "can not move directory into itself"
-msgstr "нельзя переместить каталог в самого себя"
+#: builtin/pack-objects.c:3303
+msgid "create packs suitable for shallow fetches"
+msgstr "создавать пакеты, подходящие для частичных извлечений"
 
-#: builtin/mv.c:188
-msgid "cannot move directory over file"
-msgstr "нельзя переместить каталог в файл"
+#: builtin/pack-objects.c:3305
+msgid "ignore packs that have companion .keep file"
+msgstr "игнорировать пакеты, рядом с которыми лежит .keep файл"
 
-#: builtin/mv.c:197
-msgid "source directory is empty"
-msgstr "исходный каталог пуст"
+#: builtin/pack-objects.c:3307
+msgid "ignore this pack"
+msgstr "игнорировать этот пакет"
 
-#: builtin/mv.c:222
-msgid "not under version control"
-msgstr "не под версионным контролем"
+#: builtin/pack-objects.c:3309
+msgid "pack compression level"
+msgstr "уровень сжатия пакета"
 
-#: builtin/mv.c:225
-msgid "destination exists"
-msgstr "целевой путь уже существует"
+#: builtin/pack-objects.c:3311
+msgid "do not hide commits by grafts"
+msgstr "не скрывать коммиты сращениями"
 
-#: builtin/mv.c:233
-#, c-format
-msgid "overwriting '%s'"
-msgstr "перезапись «%s»"
+#: builtin/pack-objects.c:3313
+msgid "use a bitmap index if available to speed up counting objects"
+msgstr "по возможности использовать индекс в битовых картах, для ускорения подсчета объектов"
 
-#: builtin/mv.c:236
-msgid "Cannot overwrite"
-msgstr "Не удалось перезаписать"
+#: builtin/pack-objects.c:3315
+msgid "write a bitmap index together with the pack index"
+msgstr "запись индекса в битовых картах вместе с индексом пакета"
 
-#: builtin/mv.c:239
-msgid "multiple sources for the same target"
-msgstr "несколько источников для одного целевого пути"
+#: builtin/pack-objects.c:3318
+msgid "handling for missing objects"
+msgstr "обработка отсутствующих объектов"
 
-#: builtin/mv.c:241
-msgid "destination directory does not exist"
-msgstr "целевой каталог не существует"
+#: builtin/pack-objects.c:3321
+msgid "do not pack objects in promisor packfiles"
+msgstr "не упаковывать объекты в promisor файлы пакетов"
 
-#: builtin/mv.c:248
-#, c-format
-msgid "%s, source=%s, destination=%s"
-msgstr "%s, откуда=%s, куда=%s"
+#: builtin/pack-objects.c:3323
+msgid "respect islands during delta compression"
+msgstr ""
 
-#: builtin/mv.c:269
+#: builtin/pack-objects.c:3348
 #, c-format
-msgid "Renaming %s to %s\n"
-msgstr "Переименование %s в %s\n"
+msgid "delta chain depth %d is too deep, forcing %d"
+msgstr "глубина цепочки изменений %d слишком большая, использую принудительно %d"
 
-#: builtin/mv.c:275 builtin/remote.c:712 builtin/repack.c:390
+#: builtin/pack-objects.c:3353
 #, c-format
-msgid "renaming '%s' failed"
-msgstr "сбой при переименовании «%s»"
-
-#: builtin/name-rev.c:338
-msgid "git name-rev [<options>] <commit>..."
-msgstr "git name-rev [<опции>] <коммит>…"
+msgid "pack.deltaCacheLimit is too high, forcing %d"
+msgstr "лисит pack.deltaCacheLimit слишком высокий, использую принудительно %d"
 
-#: builtin/name-rev.c:339
-msgid "git name-rev [<options>] --all"
-msgstr "git name-rev [<опции>] --all"
-
-#: builtin/name-rev.c:340
-msgid "git name-rev [<options>] --stdin"
-msgstr "git name-rev [<опции>] --stdin"
-
-#: builtin/name-rev.c:395
-msgid "print only names (no SHA-1)"
-msgstr "выводить только имена (без SHA-1)"
+#: builtin/pack-objects.c:3407
+msgid "--max-pack-size cannot be used to build a pack for transfer"
+msgstr ""
 
-#: builtin/name-rev.c:396
-msgid "only use tags to name the commits"
-msgstr "использовать только метки для именования коммитов"
+#: builtin/pack-objects.c:3409
+msgid "minimum pack size limit is 1 MiB"
+msgstr ""
 
-#: builtin/name-rev.c:398
-msgid "only use refs matching <pattern>"
-msgstr "использовать только ссылки, соответствующие <шаблону> "
+#: builtin/pack-objects.c:3414
+msgid "--thin cannot be used to build an indexable pack"
+msgstr ""
 
-#: builtin/name-rev.c:400
-msgid "ignore refs matching <pattern>"
-msgstr "игнорировать ссылки, соответствующие <шаблону>"
+#: builtin/pack-objects.c:3417
+msgid "--keep-unreachable and --unpack-unreachable are incompatible"
+msgstr ""
 
-#: builtin/name-rev.c:402
-msgid "list all commits reachable from all refs"
-msgstr "вывести список всех коммитов, достижимых со всех ссылок"
+#: builtin/pack-objects.c:3423
+msgid "cannot use --filter without --stdout"
+msgstr ""
 
-#: builtin/name-rev.c:403
-msgid "read from stdin"
-msgstr "прочитать из стандартного ввода"
+#: builtin/pack-objects.c:3484
+msgid "Enumerating objects"
+msgstr "Перечисление объектов"
 
-#: builtin/name-rev.c:404
-msgid "allow to print `undefined` names (default)"
-msgstr "разрешить вывод «undefined», если не найдено (по умолчанию)"
+#: builtin/pack-objects.c:3514
+#, c-format
+msgid "Total %<PRIu32> (delta %<PRIu32>), reused %<PRIu32> (delta %<PRIu32>)"
+msgstr "Всего %<PRIu32> (изменения %<PRIu32>), повторно использовано %<PRIu32> (изменения %<PRIu32>)"
 
-#: builtin/name-rev.c:410
-msgid "dereference tags in the input (internal use)"
-msgstr "разыменовывать введенные метки (для внутреннего использования)"
+#: builtin/pack-refs.c:8
+msgid "git pack-refs [<options>]"
+msgstr "git pack-refs [<опции>]"
 
-#: builtin/notes.c:26
-msgid "git notes [--ref <notes-ref>] [list [<object>]]"
-msgstr "git notes [--ref <ссылка-на-заметку>] [list [<объект>]]"
+#: builtin/pack-refs.c:16
+msgid "pack everything"
+msgstr "паковать всё"
 
-#: builtin/notes.c:27
-msgid ""
-"git notes [--ref <notes-ref>] add [-f] [--allow-empty] [-m <msg> | -F <file>"
-" | (-c | -C) <object>] [<object>]"
-msgstr "git notes [--ref <ссылка-на-заметку>] add [-f] [--allow-empty] [-m <сообщение> | -F <файл> | (-c | -C) <объект>] [<объект>]"
+#: builtin/pack-refs.c:17
+msgid "prune loose refs (default)"
+msgstr "почистить слабые ссылки (по умолчанию)"
 
-#: builtin/notes.c:28
-msgid "git notes [--ref <notes-ref>] copy [-f] <from-object> <to-object>"
-msgstr "git notes [--ref <ссылка-на-заметку>] copy [-f] <из-объекта> <в-объект>"
+#: builtin/prune-packed.c:9
+msgid "git prune-packed [-n | --dry-run] [-q | --quiet]"
+msgstr "git prune-packed [-n | --dry-run] [-q | --quiet]"
 
-#: builtin/notes.c:29
-msgid ""
-"git notes [--ref <notes-ref>] append [--allow-empty] [-m <msg> | -F <file> |"
-" (-c | -C) <object>] [<object>]"
-msgstr "git notes [--ref <ссылка-на-заметку>] append [--allow-empty] [-m <сообщение> | -F <файл> | (-c | -C) <объект>] [<объект>]"
+#: builtin/prune-packed.c:42
+msgid "Removing duplicate objects"
+msgstr "Удаление дублирующихся объектов"
 
-#: builtin/notes.c:30
-msgid "git notes [--ref <notes-ref>] edit [--allow-empty] [<object>]"
-msgstr "git notes [--ref <ссылка-на-заметку>] edit [--allow-empty] [<объект>]"
+#: builtin/prune.c:12
+msgid "git prune [-n] [-v] [--progress] [--expire <time>] [--] [<head>...]"
+msgstr "git prune [-n] [-v] [--progress] [--expire <время>] [--] [<редакция>…]"
 
-#: builtin/notes.c:31
-msgid "git notes [--ref <notes-ref>] show [<object>]"
-msgstr "git notes [--ref <ссылка-на-заметку>] show [<объект>]"
+#: builtin/prune.c:131
+msgid "report pruned objects"
+msgstr "вывести список удаленных объектов"
 
-#: builtin/notes.c:32
-msgid ""
-"git notes [--ref <notes-ref>] merge [-v | -q] [-s <strategy>] <notes-ref>"
-msgstr "git notes [--ref <ссылка-на-заметку>] merge [-v | -q] [-s <стратегия>] <ссылка-на-заметку>"
+#: builtin/prune.c:134
+msgid "expire objects older than <time>"
+msgstr "удалить объекты старее чем <дата-окончания>"
 
-#: builtin/notes.c:33
-msgid "git notes merge --commit [-v | -q]"
-msgstr "git notes merge --commit [-v | -q]"
+#: builtin/prune.c:136
+msgid "limit traversal to objects outside promisor packfiles"
+msgstr "ограничить обход объектами вне promisor файлов пакетов"
 
-#: builtin/notes.c:34
-msgid "git notes merge --abort [-v | -q]"
-msgstr "git notes merge --abort [-v | -q]"
+#: builtin/prune.c:150
+msgid "cannot prune in a precious-objects repo"
+msgstr "нельзя почистить неиспользуемые объекты в precious-objects репозитории"
 
-#: builtin/notes.c:35
-msgid "git notes [--ref <notes-ref>] remove [<object>...]"
-msgstr "git notes [--ref <ссылка-на-заметку>] remove [<объект>…]"
+#: builtin/pull.c:66 builtin/pull.c:68
+#, c-format
+msgid "Invalid value for %s: %s"
+msgstr "Неправильное значение %s: %s"
 
-#: builtin/notes.c:36
-msgid "git notes [--ref <notes-ref>] prune [-n] [-v]"
-msgstr "git notes [--ref <имя-заметки>] prune [-n] [-v]"
+#: builtin/pull.c:88
+msgid "git pull [<options>] [<repository> [<refspec>...]]"
+msgstr "git pull [<опции>] [<репозиторий> [<спецификатор-ссылки>…]]"
 
-#: builtin/notes.c:37
-msgid "git notes [--ref <notes-ref>] get-ref"
-msgstr "git notes [--ref <ссылка-на-заметку>] get-ref"
+#: builtin/pull.c:140
+msgid "control for recursive fetching of submodules"
+msgstr "управление рекурсивным извлечением подмодулей"
 
-#: builtin/notes.c:42
-msgid "git notes [list [<object>]]"
-msgstr "git notes [list [<объект>]]"
+#: builtin/pull.c:144
+msgid "Options related to merging"
+msgstr "Опции, связанные со слиянием"
 
-#: builtin/notes.c:47
-msgid "git notes add [<options>] [<object>]"
-msgstr "git notes add [<опции>] [<объект>]"
+#: builtin/pull.c:147
+msgid "incorporate changes by rebasing rather than merging"
+msgstr "забрать изменения с помощью перемещения, а не слияния"
 
-#: builtin/notes.c:52
-msgid "git notes copy [<options>] <from-object> <to-object>"
-msgstr "git notes copy [<опции>] <из-объекта> <в-объект>"
+#: builtin/pull.c:175 builtin/rebase.c:447 builtin/revert.c:125
+msgid "allow fast-forward"
+msgstr "разрешить перемотку вперед"
 
-#: builtin/notes.c:53
-msgid "git notes copy --stdin [<from-object> <to-object>]..."
-msgstr "git notes copy --stdin [<из-объекта> <в-объект>]…"
+#: builtin/pull.c:184
+msgid "automatically stash/stash pop before and after rebase"
+msgstr "автоматически выполнять stash/stash pop до и после перемещения"
 
-#: builtin/notes.c:58
-msgid "git notes append [<options>] [<object>]"
-msgstr "git notes append [<опции>] [<объект>]"
+#: builtin/pull.c:200
+msgid "Options related to fetching"
+msgstr "Опции, связанные с извлечением изменений"
 
-#: builtin/notes.c:63
-msgid "git notes edit [<object>]"
-msgstr "git notes edit [<объект>]"
+#: builtin/pull.c:210
+msgid "force overwrite of local branch"
+msgstr "принудительная перезапись локальной ветки"
 
-#: builtin/notes.c:68
-msgid "git notes show [<object>]"
-msgstr "git notes show [<объект>]"
+#: builtin/pull.c:218
+msgid "number of submodules pulled in parallel"
+msgstr "количество подмодулей, которые будут получены парралельно"
 
-#: builtin/notes.c:73
-msgid "git notes merge [<options>] <notes-ref>"
-msgstr "git notes merge [<опции>] <ссылка-на-заметку>"
+#: builtin/pull.c:313
+#, c-format
+msgid "Invalid value for pull.ff: %s"
+msgstr "Неправильное значение для pull.ff: %s"
 
-#: builtin/notes.c:74
-msgid "git notes merge --commit [<options>]"
-msgstr "git notes merge --commit [<опции>]"
+#: builtin/pull.c:430
+msgid ""
+"There is no candidate for rebasing against among the refs that you just "
+"fetched."
+msgstr "Нет претендентов для перемещения среди ссылок, которые вы только что получили."
 
-#: builtin/notes.c:75
-msgid "git notes merge --abort [<options>]"
-msgstr "git notes merge --abort [<опции>]"
+#: builtin/pull.c:432
+msgid ""
+"There are no candidates for merging among the refs that you just fetched."
+msgstr "Нет претендентов для слияния среди ссылок, которые вы только что получили."
 
-#: builtin/notes.c:80
-msgid "git notes remove [<object>]"
-msgstr "git notes remove [<опции>]"
+#: builtin/pull.c:433
+msgid ""
+"Generally this means that you provided a wildcard refspec which had no\n"
+"matches on the remote end."
+msgstr "Обычно это означает, что вы передали спецификацию ссылки с помощью шаблона и этот шаблон ни с чем не совпал на внешнем репозитории."
 
-#: builtin/notes.c:85
-msgid "git notes prune [<options>]"
-msgstr "git notes prune [<опции>]"
+#: builtin/pull.c:436
+#, c-format
+msgid ""
+"You asked to pull from the remote '%s', but did not specify\n"
+"a branch. Because this is not the default configured remote\n"
+"for your current branch, you must specify a branch on the command line."
+msgstr "Вы попросили получить изменения со внешнего репозитория «%s», но не указали ветку. Так как это не репозиторий по умолчанию для  вашей текущей ветки, вы должны указать ветку в командной строке."
 
-#: builtin/notes.c:90
-msgid "git notes get-ref"
-msgstr "git notes get-ref"
+#: builtin/pull.c:441 builtin/rebase.c:1321 git-parse-remote.sh:73
+msgid "You are not currently on a branch."
+msgstr "Вы сейчас ни на одной из веток."
 
-#: builtin/notes.c:95
-msgid "Write/edit the notes for the following object:"
-msgstr "Записать/изменить заметки для следующего объекта:"
+#: builtin/pull.c:443 builtin/pull.c:458 git-parse-remote.sh:79
+msgid "Please specify which branch you want to rebase against."
+msgstr "Пожалуйста, укажите на какую ветку вы хотите переместить изменения."
 
-#: builtin/notes.c:148
-#, c-format
-msgid "unable to start 'show' for object '%s'"
-msgstr "не удалось запустить «show» для объекта «%s»"
+#: builtin/pull.c:445 builtin/pull.c:460 git-parse-remote.sh:82
+msgid "Please specify which branch you want to merge with."
+msgstr "Пожалуйста, укажите с какой веткой вы хотите слить изменения."
 
-#: builtin/notes.c:152
-msgid "could not read 'show' output"
-msgstr "не удалось прочитать вывод «show»"
+#: builtin/pull.c:446 builtin/pull.c:461
+msgid "See git-pull(1) for details."
+msgstr "Для дополнительной информации, смотрите git-pull(1)."
 
-#: builtin/notes.c:160
-#, c-format
-msgid "failed to finish 'show' for object '%s'"
-msgstr "не удалось завершить «show» для объекта «%s»"
+#: builtin/pull.c:448 builtin/pull.c:454 builtin/pull.c:463
+#: builtin/rebase.c:1327 git-parse-remote.sh:64
+msgid "<remote>"
+msgstr "<внешний-репозиторий>"
 
-#: builtin/notes.c:195
-msgid "please supply the note contents using either -m or -F option"
-msgstr "пожалуйста, укажите содержимое заметки, используя опцию -m или -F"
+#: builtin/pull.c:448 builtin/pull.c:463 builtin/pull.c:468
+#: git-parse-remote.sh:65
+msgid "<branch>"
+msgstr "<ветка>"
 
-#: builtin/notes.c:204
-msgid "unable to write note object"
-msgstr "не удалось записать объект заметки"
+#: builtin/pull.c:456 builtin/rebase.c:1319 git-parse-remote.sh:75
+msgid "There is no tracking information for the current branch."
+msgstr "У текущей ветки нет информации об отслеживании."
 
-#: builtin/notes.c:206
-#, c-format
-msgid "the note contents have been left in %s"
-msgstr "содержимое заметки осталось в %s"
+#: builtin/pull.c:465 git-parse-remote.sh:95
+msgid ""
+"If you wish to set tracking information for this branch you can do so with:"
+msgstr "Если вы хотите указать информацию о отслеживаемой ветке, выполните:"
 
-#: builtin/notes.c:234 builtin/tag.c:500
+#: builtin/pull.c:470
 #, c-format
-msgid "cannot read '%s'"
-msgstr "не удалось прочитать «%s»"
+msgid ""
+"Your configuration specifies to merge with the ref '%s'\n"
+"from the remote, but no such ref was fetched."
+msgstr "Ваша конфигурация указывает, что нужно слить изменения со ссылкой\n«%s» из внешнего репозитория, но такая ссылка не была получена."
 
-#: builtin/notes.c:236 builtin/tag.c:503
+#: builtin/pull.c:574
 #, c-format
-msgid "could not open or read '%s'"
-msgstr "не удалось открыть или прочитать «%s»"
+msgid "unable to access commit %s"
+msgstr ""
 
-#: builtin/notes.c:255 builtin/notes.c:306 builtin/notes.c:308
-#: builtin/notes.c:376 builtin/notes.c:431 builtin/notes.c:517
-#: builtin/notes.c:522 builtin/notes.c:600 builtin/notes.c:662
-#, c-format
-msgid "failed to resolve '%s' as a valid ref."
-msgstr "не удалось разрешить «%s» как ссылку."
+#: builtin/pull.c:854
+msgid "ignoring --verify-signatures for rebase"
+msgstr "игнорирование --verify-signatures при перемещении"
 
-#: builtin/notes.c:258
-#, c-format
-msgid "failed to read object '%s'."
-msgstr "не удалось прочитать объект «%s»."
+#: builtin/pull.c:909
+msgid "--[no-]autostash option is only valid with --rebase."
+msgstr "--[no-]autostash можно использовать только вместе с --rebase."
 
-#: builtin/notes.c:262
-#, c-format
-msgid "cannot read note data from non-blob object '%s'."
-msgstr "не удалось прочитать данные заметки из недвоичного объекта «%s»."
+#: builtin/pull.c:917
+msgid "Updating an unborn branch with changes added to the index."
+msgstr "Обновление еще не начавшейся ветки с изменениями, добавленными в индекс."
 
-#: builtin/notes.c:302
-#, c-format
-msgid "malformed input line: '%s'."
-msgstr "неправильная введенная строка: «%s»."
+#: builtin/pull.c:921
+msgid "pull with rebase"
+msgstr "получение с перемещением"
 
-#: builtin/notes.c:317
-#, c-format
-msgid "failed to copy notes from '%s' to '%s'"
-msgstr "не удалось скопировать заметку из «%s» в «%s»"
+#: builtin/pull.c:922
+msgid "please commit or stash them."
+msgstr "сделайте коммит или спрячьте их."
 
-#. TRANSLATORS: the first %s will be replaced by a git
-#. notes command: 'add', 'merge', 'remove', etc.
-#: builtin/notes.c:349
+#: builtin/pull.c:947
 #, c-format
-msgid "refusing to %s notes in %s (outside of refs/notes/)"
-msgstr "отказ в перезаписи %s заметок в %s (за пределами refs/notes/)"
-
-#: builtin/notes.c:369 builtin/notes.c:424 builtin/notes.c:500
-#: builtin/notes.c:512 builtin/notes.c:588 builtin/notes.c:655
-#: builtin/notes.c:805 builtin/notes.c:952 builtin/notes.c:973
-msgid "too many parameters"
-msgstr "передано слишком много параметров"
+msgid ""
+"fetch updated the current branch head.\n"
+"fast-forwarding your working tree from\n"
+"commit %s."
+msgstr "извлечение обновило указатель на вашу текущую ветку.\nперемотка вашего рабочего каталога\nс коммита %s."
 
-#: builtin/notes.c:382 builtin/notes.c:668
+#: builtin/pull.c:953
 #, c-format
-msgid "no note found for object %s."
-msgstr "не найдена заметка для объекта %s."
+msgid ""
+"Cannot fast-forward your working tree.\n"
+"After making sure that you saved anything precious from\n"
+"$ git diff %s\n"
+"output, run\n"
+"$ git reset --hard\n"
+"to recover."
+msgstr "Не удалось перемотать вперёд изменения в вашем рабочем каталоге.\nПосле того, как вы убедитесь, что вы сохранили всё необходимое из вывода\n$ git diff %s\n, запустите\n$ git reset --hard\nдля восстановления исходного состояния."
 
-#: builtin/notes.c:403 builtin/notes.c:566
-msgid "note contents as a string"
-msgstr "текстовое содержимое заметки"
+#: builtin/pull.c:968
+msgid "Cannot merge multiple branches into empty head."
+msgstr "Нельзя слить несколько веток в пустой указатель на ветку."
 
-#: builtin/notes.c:406 builtin/notes.c:569
-msgid "note contents in a file"
-msgstr "содержимое заметки в файле"
+#: builtin/pull.c:972
+msgid "Cannot rebase onto multiple branches."
+msgstr "Невозможно переместить над несколькими ветками."
 
-#: builtin/notes.c:409 builtin/notes.c:572
-msgid "reuse and edit specified note object"
-msgstr "использовать и отредактировать указанный объект заметки"
+#: builtin/pull.c:979
+msgid "cannot rebase with locally recorded submodule modifications"
+msgstr "невозможно выполнить перемещение с записанными локальными изменениями в подмодулях"
 
-#: builtin/notes.c:412 builtin/notes.c:575
-msgid "reuse specified note object"
-msgstr "использовать указанный объект заметки"
+#: builtin/push.c:19
+msgid "git push [<options>] [<repository> [<refspec>...]]"
+msgstr "git push [<опции>] [<репозиторий> [<спецификатор-ссылки>…]]"
 
-#: builtin/notes.c:415 builtin/notes.c:578
-msgid "allow storing empty note"
-msgstr "разрешить сохранение пустой заметки"
+#: builtin/push.c:111
+msgid "tag shorthand without <tag>"
+msgstr "указано сокращение tag, но не указана сама <метка>"
 
-#: builtin/notes.c:416 builtin/notes.c:487
-msgid "replace existing notes"
-msgstr "заменить существующие заметки"
+#: builtin/push.c:121
+msgid "--delete only accepts plain target ref names"
+msgstr "опция --delete принимает только простые целевые имена ссылок"
 
-#: builtin/notes.c:441
-#, c-format
+#: builtin/push.c:167
 msgid ""
-"Cannot add notes. Found existing notes for object %s. Use '-f' to overwrite "
-"existing notes"
-msgstr "Не удалось добавить заметку. Найдена существующая заметка у объекта %s. Используйте параметр «-f» для перезаписи существующих заметок."
+"\n"
+"To choose either option permanently, see push.default in 'git help config'."
+msgstr "\nЧтобы выбрать любую из опций на постоянной основе, смотрите push.default в «git help config»."
 
-#: builtin/notes.c:456 builtin/notes.c:535
+#: builtin/push.c:170
 #, c-format
-msgid "Overwriting existing notes for object %s\n"
-msgstr "Перезапись существующих заметок у объекта %s\n"
+msgid ""
+"The upstream branch of your current branch does not match\n"
+"the name of your current branch.  To push to the upstream branch\n"
+"on the remote, use\n"
+"\n"
+"    git push %s HEAD:%s\n"
+"\n"
+"To push to the branch of the same name on the remote, use\n"
+"\n"
+"    git push %s HEAD\n"
+"%s"
+msgstr ""
 
-#: builtin/notes.c:467 builtin/notes.c:627 builtin/notes.c:892
+#: builtin/push.c:185
 #, c-format
-msgid "Removing note for object %s\n"
-msgstr "Удаление заметки у объекта %s\n"
-
-#: builtin/notes.c:488
-msgid "read objects from stdin"
-msgstr "прочитать объекты из стандартного ввода"
-
-#: builtin/notes.c:490
-msgid "load rewriting config for <command> (implies --stdin)"
-msgstr "загрузить настройки перезаписи для команды <команда> (включает в себя --stdin)"
+msgid ""
+"You are not currently on a branch.\n"
+"To push the history leading to the current (detached HEAD)\n"
+"state now, use\n"
+"\n"
+"    git push %s HEAD:<name-of-remote-branch>\n"
+msgstr "Вы сейчас не находитесь ни на одной из веток.\nЧтобы отправить историю, ведущую к текущему (отделённый HEAD) состоянию, используйте\n\n    git push %s HEAD:<имя-внешней-ветки>\n"
 
-#: builtin/notes.c:508
-msgid "too few parameters"
-msgstr "передано слишком мало параметров"
+#: builtin/push.c:199
+#, c-format
+msgid ""
+"The current branch %s has no upstream branch.\n"
+"To push the current branch and set the remote as upstream, use\n"
+"\n"
+"    git push --set-upstream %s %s\n"
+msgstr "Текущая ветка %s не имеет вышестоящей ветки.\nЧтобы отправить текущую ветку и установить внешнюю ветку как вышестоящую для этой ветки, используйте\n\n    git push --set-upstream %s %s\n"
 
-#: builtin/notes.c:529
+#: builtin/push.c:207
 #, c-format
 msgid ""
-"Cannot copy notes. Found existing notes for object %s. Use '-f' to overwrite"
-" existing notes"
-msgstr "Не удалось скопировать заметку. Найдена существующая заметка у объекта %s. Используйте параметр «-f» для перезаписи существующих заметок."
-
-#: builtin/notes.c:541
-#, c-format
-msgid "missing notes on source object %s. Cannot copy."
-msgstr "нет заметок у исходного объекта %s. Нельзя скопировать."
+"The current branch %s has multiple upstream branches, refusing to push."
+msgstr "Ваша текущая ветка %s имеет несколько вышестоящих веток, отказ в отправке изменений."
 
-#: builtin/notes.c:593
+#: builtin/push.c:210
 #, c-format
 msgid ""
-"The -m/-F/-c/-C options have been deprecated for the 'edit' subcommand.\n"
-"Please use 'git notes add -f -m/-F/-c/-C' instead.\n"
-msgstr "Опции -m/-F/-c/-C для подкоманды «edit» устарели.\nИспользуйте вместо них «git notes add -f -m/-F/-c/-C».\n"
-
-#: builtin/notes.c:688
-msgid "failed to delete ref NOTES_MERGE_PARTIAL"
-msgstr "не удалось удалить ссылку NOTES_MERGE_PARTIAL"
-
-#: builtin/notes.c:690
-msgid "failed to delete ref NOTES_MERGE_REF"
-msgstr "не удалось удалить ссылку NOTES_MERGE_REF"
+"You are pushing to remote '%s', which is not the upstream of\n"
+"your current branch '%s', without telling me what to push\n"
+"to update which remote branch."
+msgstr "Вы сейчас отправляете изменения на внешний репозиторий «%s», который не является вышестоящим для вашей текущей ветки «%s», без указания того, что отправлять и в какую внешнюю ветку."
 
-#: builtin/notes.c:692
-msgid "failed to remove 'git notes merge' worktree"
-msgstr "не удалось удалить рабочий каталог «git notes merge»"
+#: builtin/push.c:269
+msgid "You didn't specify any refspecs to push, and push.default is \"nothing\"."
+msgstr "Вы не указали спецификацию ссылки для отправки, а push.default указан как «nothing»."
 
-#: builtin/notes.c:712
-msgid "failed to read ref NOTES_MERGE_PARTIAL"
-msgstr "не удалось прочитать ссылку NOTES_MERGE_PARTIAL"
+#: builtin/push.c:276
+msgid ""
+"Updates were rejected because the tip of your current branch is behind\n"
+"its remote counterpart. Integrate the remote changes (e.g.\n"
+"'git pull ...') before pushing again.\n"
+"See the 'Note about fast-forwards' in 'git push --help' for details."
+msgstr "Обновления были отклонены, так как верхушка вашей текущей ветки\nпозади ее внешней части. Заберите и слейте внешние изменения \n(например, с помощью «git pull …») перед повторной попыткой отправки\nизменений.\nДля дополнительной информации, смотрите «Note about fast-forwards»\nв «git push --help»."
 
-#: builtin/notes.c:714
-msgid "could not find commit from NOTES_MERGE_PARTIAL."
-msgstr "не удалось найти коммит из NOTES_MERGE_PARTIAL."
+#: builtin/push.c:282
+msgid ""
+"Updates were rejected because a pushed branch tip is behind its remote\n"
+"counterpart. Check out this branch and integrate the remote changes\n"
+"(e.g. 'git pull ...') before pushing again.\n"
+"See the 'Note about fast-forwards' in 'git push --help' for details."
+msgstr "Обновления были отклонены, так как верхушка отправляемой ветки\nпозади ее внешней части. Переключитесь на ветку и заберите внешние\nизменения (например, с помощью «git pull …») перед повторной\nпопыткой отправки изменений.\nДля дополнительной информации, смотрите «Note about fast-forwards»\nв «git push --help»."
 
-#: builtin/notes.c:716
-msgid "could not parse commit from NOTES_MERGE_PARTIAL."
-msgstr "не удалось разобрать коммит из NOTES_MERGE_PARTIAL."
+#: builtin/push.c:288
+msgid ""
+"Updates were rejected because the remote contains work that you do\n"
+"not have locally. This is usually caused by another repository pushing\n"
+"to the same ref. You may want to first integrate the remote changes\n"
+"(e.g., 'git pull ...') before pushing again.\n"
+"See the 'Note about fast-forwards' in 'git push --help' for details."
+msgstr "Обновления были отклонены, так как внешний репозиторий содержит\nизменения, которых у вас нет в вашем локальном репозитории.\nОбычно, это связанно с тем, что кто-то уже отправил изменения в \nто же место. Перед повторной отправкой ваших изменений, вам нужно\nзабрать и слить изменения из внешнего репозитория себе\n(например, с помощью «git pull …»).\nДля дополнительной информации, смотрите «Note about fast-forwards»\nв «git push --help»."
 
-#: builtin/notes.c:729
-msgid "failed to resolve NOTES_MERGE_REF"
-msgstr "не удалось разрешить NOTES_MERGE_REF"
+#: builtin/push.c:295
+msgid "Updates were rejected because the tag already exists in the remote."
+msgstr "Обновления были отклонены, так как метка уже существует во внешнем репозитории."
 
-#: builtin/notes.c:732
-msgid "failed to finalize notes merge"
-msgstr "не удалось завершить слиние заметок"
+#: builtin/push.c:298
+msgid ""
+"You cannot update a remote ref that points at a non-commit object,\n"
+"or update a remote ref to make it point at a non-commit object,\n"
+"without using the '--force' option.\n"
+msgstr "Вы не можете обновить внешнюю ссылку, которая указывает на объект, не являющийся коммитом или обновить внешнюю ссылку так, чтобы она указывала на объект, не являющийся коммитом, без указания опции «--force».\n"
 
-#: builtin/notes.c:758
+#: builtin/push.c:359
 #, c-format
-msgid "unknown notes merge strategy %s"
-msgstr "неизвестная стратегия слияния заметок %s"
+msgid "Pushing to %s\n"
+msgstr "Отправка в %s\n"
 
-#: builtin/notes.c:774
-msgid "General options"
-msgstr "Общие опции"
+#: builtin/push.c:364
+#, c-format
+msgid "failed to push some refs to '%s'"
+msgstr "не удалось отправить некоторые ссылки в «%s»"
 
-#: builtin/notes.c:776
-msgid "Merge options"
-msgstr "Опции слияния"
+#: builtin/push.c:398
+#, c-format
+msgid "bad repository '%s'"
+msgstr "плохой репозитория «%s»"
 
-#: builtin/notes.c:778
+#: builtin/push.c:399
 msgid ""
-"resolve notes conflicts using the given strategy "
-"(manual/ours/theirs/union/cat_sort_uniq)"
-msgstr "разрешить конфликты заметок с помощью указанной стратегии (manual/ours/theirs/union/cat_sort_uniq)"
-
-#: builtin/notes.c:780
-msgid "Committing unmerged notes"
-msgstr "Коммит не слитых заметок"
-
-#: builtin/notes.c:782
-msgid "finalize notes merge by committing unmerged notes"
-msgstr "завершить слияние заметок коммитом не слитых заметок"
-
-#: builtin/notes.c:784
-msgid "Aborting notes merge resolution"
-msgstr "Отмена разрешения слияния заметок"
-
-#: builtin/notes.c:786
-msgid "abort notes merge"
-msgstr "отменить слияние заметок"
+"No configured push destination.\n"
+"Either specify the URL from the command-line or configure a remote repository using\n"
+"\n"
+"    git remote add <name> <url>\n"
+"\n"
+"and then push using the remote name\n"
+"\n"
+"    git push <name>\n"
+msgstr "Не настроена точка назначения для отправки.\nЛибо укажите URL с помощью командной строки, либо настройте внешний репозиторий с помощью\n\n    git remote add <имя> <адрес>\n\nа затем отправьте изменения с помощью имени внешнего репозитория\n\n    git push <имя>\n"
 
-#: builtin/notes.c:797
-msgid "cannot mix --commit, --abort or -s/--strategy"
-msgstr "нельзя использовать одновременно --commit, --abort и -s/--strategy"
+#: builtin/push.c:554
+msgid "repository"
+msgstr "репозиторий"
 
-#: builtin/notes.c:802
-msgid "must specify a notes ref to merge"
-msgstr "вы должны указать ссылку заметки для слияния"
+#: builtin/push.c:555 builtin/send-pack.c:164
+msgid "push all refs"
+msgstr "отправить все ссылки"
 
-#: builtin/notes.c:826
-#, c-format
-msgid "unknown -s/--strategy: %s"
-msgstr "неизвестный параметр для -s/--strategy: %s"
+#: builtin/push.c:556 builtin/send-pack.c:166
+msgid "mirror all refs"
+msgstr "сделать зеркало всех ссылок"
 
-#: builtin/notes.c:863
-#, c-format
-msgid "a notes merge into %s is already in-progress at %s"
-msgstr "слияние заметок в %s уже выполняется на %s"
+#: builtin/push.c:558
+msgid "delete refs"
+msgstr "удалить ссылки"
 
-#: builtin/notes.c:866
-#, c-format
-msgid "failed to store link to current notes ref (%s)"
-msgstr "не удалось сохранить адрес текущей ссылки на заметку (%s)"
+#: builtin/push.c:559
+msgid "push tags (can't be used with --all or --mirror)"
+msgstr "отправить метки (нельзя использовать вместе с --all или --mirror)"
 
-#: builtin/notes.c:868
-#, c-format
-msgid ""
-"Automatic notes merge failed. Fix conflicts in %s and commit the result with"
-" 'git notes merge --commit', or abort the merge with 'git notes merge "
-"--abort'.\n"
-msgstr "Не удалось автоматически слить заметки. Исправьте конфликты в %s и закоммитьте результат с помощью «git notes merge --commit», или прервите процесс слияния с помощью «git notes merge --abort».\n"
+#: builtin/push.c:562 builtin/send-pack.c:167
+msgid "force updates"
+msgstr "принудительное обновление"
 
-#: builtin/notes.c:890
-#, c-format
-msgid "Object %s has no note\n"
-msgstr "У объекта %s нет заметки\n"
+#: builtin/push.c:564 builtin/send-pack.c:181
+msgid "<refname>:<expect>"
+msgstr ""
 
-#: builtin/notes.c:902
-msgid "attempt to remove non-existent note is not an error"
-msgstr "попытка удаления несуществующей заметки не является ошибкой"
+#: builtin/push.c:565 builtin/send-pack.c:182
+msgid "require old value of ref to be at this value"
+msgstr "требовать, чтобы старое значение ссылки было ожидаемым"
 
-#: builtin/notes.c:905
-msgid "read object names from the standard input"
-msgstr "прочитать имена объектов из стандартного ввода"
+#: builtin/push.c:568
+msgid "control recursive pushing of submodules"
+msgstr "управление рекурсивной отправкой подмодулей"
 
-#: builtin/notes.c:943 builtin/prune.c:105 builtin/worktree.c:158
-msgid "do not remove, show only"
-msgstr "не удалять, только показать список"
+#: builtin/push.c:570 builtin/send-pack.c:175
+msgid "use thin pack"
+msgstr "использовать тонкие пакеты"
 
-#: builtin/notes.c:944
-msgid "report pruned notes"
-msgstr "вывести список удаленных заметок"
+#: builtin/push.c:571 builtin/push.c:572 builtin/send-pack.c:161
+#: builtin/send-pack.c:162
+msgid "receive pack program"
+msgstr "путь к программе упаковки на сервере"
 
-#: builtin/notes.c:986
-msgid "notes-ref"
-msgstr "ссылка-на-заметку"
+#: builtin/push.c:573
+msgid "set upstream for git pull/status"
+msgstr "установить вышестоящую ветку для git pull/status"
 
-#: builtin/notes.c:987
-msgid "use notes from <notes-ref>"
-msgstr "использовать заметку из <ссылка-на-заметку>"
+#: builtin/push.c:576
+msgid "prune locally removed refs"
+msgstr "почистить локально удаленные ссылки"
 
-#: builtin/notes.c:1022
-#, c-format
-msgid "unknown subcommand: %s"
-msgstr "неизвестная подкоманда: %s"
+#: builtin/push.c:578
+msgid "bypass pre-push hook"
+msgstr "пропустить перехватчик pre-push"
 
-#: builtin/pack-objects.c:33
-msgid ""
-"git pack-objects --stdout [<options>...] [< <ref-list> | < <object-list>]"
-msgstr "git pack-objects --stdout [<опции>…] [< <список-ссылок> | < <список-объектов>]"
+#: builtin/push.c:579
+msgid "push missing but relevant tags"
+msgstr "отправить пропущенные, но нужные метки"
 
-#: builtin/pack-objects.c:34
-msgid ""
-"git pack-objects [<options>...] <base-name> [< <ref-list> | < <object-list>]"
-msgstr "git pack-objects [<опции>…] <имя-базы> [< <список-ссылок> | < <список-объектов>]"
+#: builtin/push.c:582 builtin/send-pack.c:169
+msgid "GPG sign the push"
+msgstr "подписать отправку с помощью GPG"
 
-#: builtin/pack-objects.c:192 builtin/pack-objects.c:195
-#, c-format
-msgid "deflate error (%d)"
-msgstr "ошибка сжатия (%d)"
+#: builtin/push.c:584 builtin/send-pack.c:176
+msgid "request atomic transaction on remote side"
+msgstr "запросить выполнение атомарной транзакции на внешней стороне"
 
-#: builtin/pack-objects.c:788
-msgid "disabling bitmap writing, packs are split due to pack.packSizeLimit"
-msgstr "отключение записи битовых карт, так как карты были разбиты на части из-за pack.packSizeLimit"
+#: builtin/push.c:602
+msgid "--delete is incompatible with --all, --mirror and --tags"
+msgstr "--delete несовместимо с  --all, --mirror и --tags"
 
-#: builtin/pack-objects.c:801
-msgid "Writing objects"
-msgstr "Запись объектов"
+#: builtin/push.c:604
+msgid "--delete doesn't make sense without any refs"
+msgstr "--delete не имеет смысла без указания ссылок"
 
-#: builtin/pack-objects.c:1081
-msgid "disabling bitmap writing, as some objects are not being packed"
-msgstr "отключение записи битовых карт, так как некоторые объекты не были упакованы"
+#: builtin/push.c:607
+msgid "--all and --tags are incompatible"
+msgstr "--all и --tags нельзя использовать одновременно"
 
-#: builtin/pack-objects.c:2451
-msgid "Compressing objects"
-msgstr "Сжатие объектов"
+#: builtin/push.c:609
+msgid "--all can't be combined with refspecs"
+msgstr "--all нельзя использовать вместе со спецификаторами ссылок"
 
-#: builtin/pack-objects.c:2599
-msgid "invalid value for --missing"
-msgstr "недопустимое значение для --missing"
+#: builtin/push.c:613
+msgid "--mirror and --tags are incompatible"
+msgstr "--mirror и --tags нельзя использовать одновременно"
 
-#: builtin/pack-objects.c:2902
-#, c-format
-msgid "unsupported index version %s"
-msgstr "неподдерживаемая версия индекса %s"
+#: builtin/push.c:615
+msgid "--mirror can't be combined with refspecs"
+msgstr "--mirror нельзя использовать вместе со спецификаторами ссылок"
 
-#: builtin/pack-objects.c:2906
-#, c-format
-msgid "bad index version '%s'"
-msgstr "плохая версия индекса «%s»"
+#: builtin/push.c:618
+msgid "--all and --mirror are incompatible"
+msgstr "--all и --mirror нельзя использовать одновременно"
 
-#: builtin/pack-objects.c:2936
-msgid "do not show progress meter"
-msgstr "не выводить прогресс выполнения"
+#: builtin/push.c:637
+msgid "push options must not have new line characters"
+msgstr "опции для отправки не должны содержать символы перевода строк"
 
-#: builtin/pack-objects.c:2938
-msgid "show progress meter"
-msgstr "показать прогресс выполнения"
+#: builtin/range-diff.c:8
+msgid "git range-diff [<options>] <old-base>..<old-tip> <new-base>..<new-tip>"
+msgstr ""
 
-#: builtin/pack-objects.c:2940
-msgid "show progress meter during object writing phase"
-msgstr "показать прогресс выполнения во время записи объектов"
+#: builtin/range-diff.c:9
+msgid "git range-diff [<options>] <old-tip>...<new-tip>"
+msgstr ""
 
-#: builtin/pack-objects.c:2943
-msgid "similar to --all-progress when progress meter is shown"
-msgstr "похоже на --all-progress при включенном прогрессе выполнения"
+#: builtin/range-diff.c:10
+msgid "git range-diff [<options>] <base> <old-tip> <new-tip>"
+msgstr ""
 
-#: builtin/pack-objects.c:2944
-msgid "version[,offset]"
-msgstr "версия[,смещение]"
+#: builtin/range-diff.c:21
+msgid "Percentage by which creation is weighted"
+msgstr ""
 
-#: builtin/pack-objects.c:2945
-msgid "write the pack index file in the specified idx format version"
-msgstr "записать файл индекса пакета в указанной версии формата"
+#: builtin/range-diff.c:23
+msgid "use simple diff colors"
+msgstr ""
 
-#: builtin/pack-objects.c:2948
-msgid "maximum size of each output pack file"
-msgstr "максимальный размер каждого выходного файла пакета"
+#: builtin/range-diff.c:46 builtin/range-diff.c:50
+#, c-format
+msgid "no .. in range: '%s'"
+msgstr ""
 
-#: builtin/pack-objects.c:2950
-msgid "ignore borrowed objects from alternate object store"
-msgstr "игнорировать чужие объекты, взятые из альтернативного хранилища объектов"
+#: builtin/range-diff.c:60
+msgid "single arg format must be symmetric range"
+msgstr ""
 
-#: builtin/pack-objects.c:2952
-msgid "ignore packed objects"
-msgstr "игнорировать упакованные объекты"
+#: builtin/range-diff.c:75
+msgid "need two commit ranges"
+msgstr ""
 
-#: builtin/pack-objects.c:2954
-msgid "limit pack window by objects"
-msgstr "ограничить окно пакета по количеству объектов"
+#: builtin/read-tree.c:41
+msgid ""
+"git read-tree [(-m [--trivial] [--aggressive] | --reset | --prefix=<prefix>)"
+" [-u [--exclude-per-directory=<gitignore>] | -i]] [--no-sparse-checkout] "
+"[--index-output=<file>] (--empty | <tree-ish1> [<tree-ish2> [<tree-ish3>]])"
+msgstr "git read-tree [(-m [--trivial] [--aggressive] | --reset | --prefix=<префикс>) [-u [--exclude-per-directory=<gitignore>] | -i]] [--no-sparse-checkout] [--index-output=<файл>] (--empty | <указатель-дерева-1> [<указатель-дерева-2> [<указатель-дерева-3>]])"
 
-#: builtin/pack-objects.c:2956
-msgid "limit pack window by memory in addition to object limit"
-msgstr "дополнительно к количеству объектов ограничить окно пакета по памяти"
+#: builtin/read-tree.c:124
+msgid "write resulting index to <file>"
+msgstr "записать результирующий индекс в <файл>"
 
-#: builtin/pack-objects.c:2958
-msgid "maximum length of delta chain allowed in the resulting pack"
-msgstr "максимальная разрешенная длина цепочки дельт в результирующем пакете"
+#: builtin/read-tree.c:127
+msgid "only empty the index"
+msgstr "просто очистить индекс"
 
-#: builtin/pack-objects.c:2960
-msgid "reuse existing deltas"
-msgstr "использовать повторно существующие дельты"
+#: builtin/read-tree.c:129
+msgid "Merging"
+msgstr "Слияние"
 
-#: builtin/pack-objects.c:2962
-msgid "reuse existing objects"
-msgstr "использовать повторно существующие объекты"
+#: builtin/read-tree.c:131
+msgid "perform a merge in addition to a read"
+msgstr "выполнить слияние в дополнение к чтению"
 
-#: builtin/pack-objects.c:2964
-msgid "use OFS_DELTA objects"
-msgstr "использовать объекты OFS_DELTA"
+#: builtin/read-tree.c:133
+msgid "3-way merge if no file level merging required"
+msgstr "трехходовое слияние, если не требуется слияние на уровне файлов"
 
-#: builtin/pack-objects.c:2966
-msgid "use threads when searching for best delta matches"
-msgstr "использовать многопоточность при поиске лучших совпадений дельт"
+#: builtin/read-tree.c:135
+msgid "3-way merge in presence of adds and removes"
+msgstr "трехходовое слияние в случае присутствия добавлений или удалений файлов"
 
-#: builtin/pack-objects.c:2968
-msgid "do not create an empty pack output"
-msgstr "не создавать пустые выходные пакеты"
+#: builtin/read-tree.c:137
+msgid "same as -m, but discard unmerged entries"
+msgstr "тоже, что и -m, но отменяет изменения не слитых записей"
 
-#: builtin/pack-objects.c:2970
-msgid "read revision arguments from standard input"
-msgstr "прочитать аргументы редакций из стандартного ввода"
+#: builtin/read-tree.c:138
+msgid "<subdirectory>/"
+msgstr "<подкаталог>/"
 
-#: builtin/pack-objects.c:2972
-msgid "limit the objects to those that are not yet packed"
-msgstr "ограничиться объектами, которые еще не упакованы"
+#: builtin/read-tree.c:139
+msgid "read the tree into the index under <subdirectory>/"
+msgstr "прочитать дерево в индекс в <подкаталог>/"
 
-#: builtin/pack-objects.c:2975
-msgid "include objects reachable from any reference"
-msgstr "включить объекты, которые достижимы по любой из ссылок"
+#: builtin/read-tree.c:142
+msgid "update working tree with merge result"
+msgstr "обновить рабочий каталог результатом слияния"
 
-#: builtin/pack-objects.c:2978
-msgid "include objects referred by reflog entries"
-msgstr "включить объекты, на которые ссылаются записи журнала ссылок"
+#: builtin/read-tree.c:144
+msgid "gitignore"
+msgstr "gitignore"
 
-#: builtin/pack-objects.c:2981
-msgid "include objects referred to by the index"
-msgstr "включить объекты, на которые ссылается индекс"
+#: builtin/read-tree.c:145
+msgid "allow explicitly ignored files to be overwritten"
+msgstr "разрешить перезапись явно игнорируемых файлов"
 
-#: builtin/pack-objects.c:2984
-msgid "output pack to stdout"
-msgstr "вывести пакет на  стандартный вывод"
+#: builtin/read-tree.c:148
+msgid "don't check the working tree after merging"
+msgstr "не проверять рабочий каталог после слияния"
 
-#: builtin/pack-objects.c:2986
-msgid "include tag objects that refer to objects to be packed"
-msgstr "включить объекты меток, которые ссылаются на упаковываемые объекты"
+#: builtin/read-tree.c:149
+msgid "don't update the index or the work tree"
+msgstr "не обновлять индекс или рабочий каталог"
 
-#: builtin/pack-objects.c:2988
-msgid "keep unreachable objects"
-msgstr "сохранять ссылки на недоступные объекты"
+#: builtin/read-tree.c:151
+msgid "skip applying sparse checkout filter"
+msgstr "пропустить применение фильтра частичного переключения на состояние"
 
-#: builtin/pack-objects.c:2990
-msgid "pack loose unreachable objects"
-msgstr "паковать недостижимые объекты"
+#: builtin/read-tree.c:153
+msgid "debug unpack-trees"
+msgstr "отладка unpack-trees"
 
-#: builtin/pack-objects.c:2992
-msgid "unpack unreachable objects newer than <time>"
-msgstr "распаковать недоступные объекты, которые новее, чем <время>"
+#: builtin/read-tree.c:157
+msgid "suppress feedback messages"
+msgstr ""
 
-#: builtin/pack-objects.c:2995
-msgid "create thin packs"
-msgstr "создавать тонкие пакеты"
+#: builtin/rebase.c:32
+msgid ""
+"git rebase [-i] [options] [--exec <cmd>] [--onto <newbase>] [<upstream>] "
+"[<branch>]"
+msgstr ""
 
-#: builtin/pack-objects.c:2997
-msgid "create packs suitable for shallow fetches"
-msgstr "создавать пакеты, подходящие для частичных извлечений"
+#: builtin/rebase.c:34
+msgid ""
+"git rebase [-i] [options] [--exec <cmd>] [--onto <newbase>] --root "
+"[<branch>]"
+msgstr ""
 
-#: builtin/pack-objects.c:2999
-msgid "ignore packs that have companion .keep file"
-msgstr "игнорировать пакеты, рядом с которыми лежит .keep файл"
+#: builtin/rebase.c:36
+msgid "git rebase --continue | --abort | --skip | --edit-todo"
+msgstr ""
 
-#: builtin/pack-objects.c:3001
-msgid "pack compression level"
-msgstr "уровень сжатия пакета"
+#: builtin/rebase.c:158 builtin/rebase.c:182 builtin/rebase.c:209
+#, c-format
+msgid "unusable todo list: '%s'"
+msgstr "непригодный для использования список дел: «%s»"
 
-#: builtin/pack-objects.c:3003
-msgid "do not hide commits by grafts"
-msgstr "не скрывать коммиты сращениями"
+#: builtin/rebase.c:167 builtin/rebase.c:193 builtin/rebase.c:217
+#, c-format
+msgid "could not write '%s'."
+msgstr ""
 
-#: builtin/pack-objects.c:3005
-msgid "use a bitmap index if available to speed up counting objects"
-msgstr "по возможности использовать индекс в битовых картах, для ускорения подсчета объектов"
+#: builtin/rebase.c:252
+msgid "no HEAD?"
+msgstr ""
 
-#: builtin/pack-objects.c:3007
-msgid "write a bitmap index together with the pack index"
-msgstr "запись индекса в битовых картах вместе с индексом пакета"
+#: builtin/rebase.c:279
+#, c-format
+msgid "could not create temporary %s"
+msgstr ""
 
-#: builtin/pack-objects.c:3010
-msgid "handling for missing objects"
-msgstr "обработка отсутствующих объектов"
+#: builtin/rebase.c:285
+msgid "could not mark as interactive"
+msgstr ""
 
-#: builtin/pack-objects.c:3144
-msgid "Counting objects"
-msgstr "Подсчет объектов"
+#: builtin/rebase.c:343
+msgid "could not generate todo list"
+msgstr ""
 
-#: builtin/pack-refs.c:6
-msgid "git pack-refs [<options>]"
-msgstr "git pack-refs [<опции>]"
+#: builtin/rebase.c:382
+msgid "a base commit must be provided with --upstream or --onto"
+msgstr ""
 
-#: builtin/pack-refs.c:14
-msgid "pack everything"
-msgstr "паковать всё"
+#: builtin/rebase.c:437
+msgid "git rebase--interactive [<options>]"
+msgstr ""
 
-#: builtin/pack-refs.c:15
-msgid "prune loose refs (default)"
-msgstr "почистить слабые ссылки (по умолчанию)"
+#: builtin/rebase.c:449
+msgid "keep empty commits"
+msgstr "оставить пустые коммиты"
 
-#: builtin/prune-packed.c:8
-msgid "git prune-packed [-n | --dry-run] [-q | --quiet]"
-msgstr "git prune-packed [-n | --dry-run] [-q | --quiet]"
+#: builtin/rebase.c:451 builtin/revert.c:127
+msgid "allow commits with empty messages"
+msgstr "разрешить коммиты с пустыми сообщениями"
 
-#: builtin/prune-packed.c:41
-msgid "Removing duplicate objects"
-msgstr "Удаление дублирующихся объектов"
+#: builtin/rebase.c:452
+msgid "rebase merge commits"
+msgstr ""
 
-#: builtin/prune.c:11
-msgid "git prune [-n] [-v] [--progress] [--expire <time>] [--] [<head>...]"
-msgstr "git prune [-n] [-v] [--progress] [--expire <время>] [--] [<ветка>…]"
+#: builtin/rebase.c:454
+msgid "keep original branch points of cousins"
+msgstr ""
 
-#: builtin/prune.c:106
-msgid "report pruned objects"
-msgstr "вывести список удаленных объектов"
+#: builtin/rebase.c:456
+msgid "move commits that begin with squash!/fixup!"
+msgstr ""
 
-#: builtin/prune.c:109
-msgid "expire objects older than <time>"
-msgstr "удалить объекты старее чем <дата-окончания>"
+#: builtin/rebase.c:457
+msgid "sign commits"
+msgstr ""
 
-#: builtin/prune.c:123
-msgid "cannot prune in a precious-objects repo"
-msgstr "нельзя почистить неиспользуемые объекты в precious-objects репозитории"
+#: builtin/rebase.c:459 builtin/rebase.c:1397
+msgid "display a diffstat of what changed upstream"
+msgstr ""
 
-#: builtin/pull.c:54 builtin/pull.c:56
-#, c-format
-msgid "Invalid value for %s: %s"
-msgstr "Неправильное значение %s: %s"
+#: builtin/rebase.c:461
+msgid "continue rebase"
+msgstr "продолжить перемещение"
 
-#: builtin/pull.c:76
-msgid "git pull [<options>] [<repository> [<refspec>...]]"
-msgstr "git pull [<опции>] [<репозиторий> [<спецификатор-ссылки>…]]"
+#: builtin/rebase.c:463
+msgid "skip commit"
+msgstr ""
 
-#: builtin/pull.c:127
-msgid "control for recursive fetching of submodules"
-msgstr "управление рекурсивным извлечением подмодулей"
+#: builtin/rebase.c:464
+msgid "edit the todo list"
+msgstr ""
 
-#: builtin/pull.c:131
-msgid "Options related to merging"
-msgstr "Опции, связанные со слиянием"
+#: builtin/rebase.c:466
+msgid "show the current patch"
+msgstr ""
 
-#: builtin/pull.c:134
-msgid "incorporate changes by rebasing rather than merging"
-msgstr "забрать изменения с помощью перемещения, а не слияния"
+#: builtin/rebase.c:469
+msgid "shorten commit ids in the todo list"
+msgstr "вывести короткие идентификаторы коммитов в списке действий"
 
-#: builtin/pull.c:161 builtin/rebase--helper.c:23 builtin/revert.c:121
-msgid "allow fast-forward"
-msgstr "разрешить перемотку вперед"
+#: builtin/rebase.c:471
+msgid "expand commit ids in the todo list"
+msgstr "вывести полные идентификаторы коммитов в списке действий"
 
-#: builtin/pull.c:170
-msgid "automatically stash/stash pop before and after rebase"
-msgstr "автоматически выполнять stash/stash pop до и после перемещения"
+#: builtin/rebase.c:473
+msgid "check the todo list"
+msgstr "проверить список дел"
 
-#: builtin/pull.c:186
-msgid "Options related to fetching"
-msgstr "Опции, связанные с извлечением изменений"
+#: builtin/rebase.c:475
+msgid "rearrange fixup/squash lines"
+msgstr "переставить строки fixup/squash"
 
-#: builtin/pull.c:204
-msgid "number of submodules pulled in parallel"
-msgstr "количество подмодулей, которые будут получены парралельно"
+#: builtin/rebase.c:477
+msgid "insert exec commands in todo list"
+msgstr "вставить команды исполнения коммитов в списке действий"
 
-#: builtin/pull.c:299
-#, c-format
-msgid "Invalid value for pull.ff: %s"
-msgstr "Неправильное значение для pull.ff: %s"
+#: builtin/rebase.c:478
+msgid "onto"
+msgstr ""
 
-#: builtin/pull.c:415
-msgid ""
-"There is no candidate for rebasing against among the refs that you just "
-"fetched."
-msgstr "Нет претендентов для перемещения среди ссылок, которые вы только что получили."
+#: builtin/rebase.c:481
+msgid "restrict-revision"
+msgstr ""
 
-#: builtin/pull.c:417
-msgid ""
-"There are no candidates for merging among the refs that you just fetched."
-msgstr "Нет претендентов для слияния среди ссылок, которые вы только что получили."
+#: builtin/rebase.c:481
+msgid "restrict revision"
+msgstr ""
 
-#: builtin/pull.c:418
-msgid ""
-"Generally this means that you provided a wildcard refspec which had no\n"
-"matches on the remote end."
-msgstr "Обычно это означает, что вы передали спецификацию ссылки с помощью шаблона и этот шаблон ни с чем не совпал на внешнем репозитории."
+#: builtin/rebase.c:483
+msgid "squash-onto"
+msgstr ""
 
-#: builtin/pull.c:421
-#, c-format
-msgid ""
-"You asked to pull from the remote '%s', but did not specify\n"
-"a branch. Because this is not the default configured remote\n"
-"for your current branch, you must specify a branch on the command line."
-msgstr "Вы попросили получить изменения со внешнего репозитория «%s», но не указали ветку. Так как это не репозиторий по умолчанию для  вашей текущей ветки, вы должны указать ветку в командной строке."
+#: builtin/rebase.c:484
+msgid "squash onto"
+msgstr ""
 
-#: builtin/pull.c:426 git-parse-remote.sh:73
-msgid "You are not currently on a branch."
-msgstr "Вы сейчас ни на одной из веток."
+#: builtin/rebase.c:486
+msgid "the upstream commit"
+msgstr ""
 
-#: builtin/pull.c:428 builtin/pull.c:443 git-parse-remote.sh:79
-msgid "Please specify which branch you want to rebase against."
-msgstr "Пожалуйста, укажите на какую ветку вы хотите переместить изменения."
+#: builtin/rebase.c:488
+msgid "head-name"
+msgstr ""
 
-#: builtin/pull.c:430 builtin/pull.c:445 git-parse-remote.sh:82
-msgid "Please specify which branch you want to merge with."
-msgstr "Пожалуйста, укажите с какой веткой вы хотите слить изменения."
+#: builtin/rebase.c:488
+msgid "head name"
+msgstr ""
 
-#: builtin/pull.c:431 builtin/pull.c:446
-msgid "See git-pull(1) for details."
-msgstr "Для дополнительной информации, смотрите git-pull(1)."
+#: builtin/rebase.c:493
+msgid "rebase strategy"
+msgstr ""
 
-#: builtin/pull.c:433 builtin/pull.c:439 builtin/pull.c:448
-#: git-parse-remote.sh:64
-msgid "<remote>"
-msgstr "<внешний-репозиторий>"
+#: builtin/rebase.c:494
+msgid "strategy-opts"
+msgstr ""
 
-#: builtin/pull.c:433 builtin/pull.c:448 builtin/pull.c:453 git-rebase.sh:466
-#: git-parse-remote.sh:65
-msgid "<branch>"
-msgstr "<ветка>"
+#: builtin/rebase.c:495
+msgid "strategy options"
+msgstr ""
 
-#: builtin/pull.c:441 git-parse-remote.sh:75
-msgid "There is no tracking information for the current branch."
-msgstr "У текущей ветки нет информации об отслеживании."
+#: builtin/rebase.c:496
+msgid "switch-to"
+msgstr ""
 
-#: builtin/pull.c:450 git-parse-remote.sh:95
-msgid ""
-"If you wish to set tracking information for this branch you can do so with:"
-msgstr "Если вы хотите указать информацию о отслеживаемой ветке, выполните:"
+#: builtin/rebase.c:497
+msgid "the branch or commit to checkout"
+msgstr ""
 
-#: builtin/pull.c:455
-#, c-format
-msgid ""
-"Your configuration specifies to merge with the ref '%s'\n"
-"from the remote, but no such ref was fetched."
-msgstr "Ваша конфигурация указывает, что нужно слить изменения со ссылкой\n«%s» из внешнего репозитория, но такая ссылка не была получена."
+#: builtin/rebase.c:498
+msgid "onto-name"
+msgstr ""
 
-#: builtin/pull.c:817
-msgid "ignoring --verify-signatures for rebase"
-msgstr "игнорирование --verify-signatures при перемещении"
+#: builtin/rebase.c:498
+msgid "onto name"
+msgstr ""
 
-#: builtin/pull.c:865
-msgid "--[no-]autostash option is only valid with --rebase."
-msgstr "--[no-]autostash можно использовать только вместе с --rebase."
+#: builtin/rebase.c:499
+msgid "cmd"
+msgstr ""
 
-#: builtin/pull.c:873
-msgid "Updating an unborn branch with changes added to the index."
-msgstr "Обновление еще не начавшейся ветки с изменениями, добавленными в индекс."
+#: builtin/rebase.c:499
+msgid "the command to run"
+msgstr ""
 
-#: builtin/pull.c:876
-msgid "pull with rebase"
-msgstr "получение с перемещением"
+#: builtin/rebase.c:502 builtin/rebase.c:1480
+msgid "automatically re-schedule any `exec` that fails"
+msgstr ""
 
-#: builtin/pull.c:877
-msgid "please commit or stash them."
-msgstr "сделайте коммит или спрячьте их."
+#: builtin/rebase.c:518
+msgid "--[no-]rebase-cousins has no effect without --rebase-merges"
+msgstr "--[no-]rebase-cousins не имеет смысла без указания --rebase-merges"
 
-#: builtin/pull.c:902
+#: builtin/rebase.c:534 builtin/rebase.c:1787
 #, c-format
-msgid ""
-"fetch updated the current branch head.\n"
-"fast-forwarding your working tree from\n"
-"commit %s."
-msgstr "извлечение обновило указатель на вашу текущую ветку.\nперемотка вашего рабочего каталога\nс коммита %s."
+msgid "%s requires an interactive rebase"
+msgstr ""
 
-#: builtin/pull.c:907
+#: builtin/rebase.c:586
 #, c-format
-msgid ""
-"Cannot fast-forward your working tree.\n"
-"After making sure that you saved anything precious from\n"
-"$ git diff %s\n"
-"output, run\n"
-"$ git reset --hard\n"
-"to recover."
-msgstr "Не удалось перемотать вперёд изменения в вашем рабочем каталоге.\nПосле того, как вы убедитесь, что вы сохранили всё необходимое из вывода\n$ git diff %s\n, запустите\n$ git reset --hard\nдля восстановления исходного состояния."
-
-#: builtin/pull.c:922
-msgid "Cannot merge multiple branches into empty head."
-msgstr "Нельзя слить несколько веток в пустой указатель на ветку."
+msgid "could not get 'onto': '%s'"
+msgstr ""
 
-#: builtin/pull.c:926
-msgid "Cannot rebase onto multiple branches."
-msgstr "Невозможно переместить над несколькими ветками."
+#: builtin/rebase.c:601
+#, c-format
+msgid "invalid orig-head: '%s'"
+msgstr ""
 
-#: builtin/pull.c:933
-msgid "cannot rebase with locally recorded submodule modifications"
-msgstr "невозможно выполнить перемещение с записанными локальными изменениями в подмодулях"
+#: builtin/rebase.c:626
+#, c-format
+msgid "ignoring invalid allow_rerere_autoupdate: '%s'"
+msgstr ""
 
-#: builtin/push.c:17
-msgid "git push [<options>] [<repository> [<refspec>...]]"
-msgstr "git push [<опции>] [<репозиторий> [<спецификатор-ссылки>…]]"
+#: builtin/rebase.c:702
+#, c-format
+msgid "Could not read '%s'"
+msgstr ""
 
-#: builtin/push.c:92
-msgid "tag shorthand without <tag>"
-msgstr "указано сокращение tag, но не указана сама <метка>"
+#: builtin/rebase.c:720
+#, c-format
+msgid "Cannot store %s"
+msgstr ""
 
-#: builtin/push.c:102
-msgid "--delete only accepts plain target ref names"
-msgstr "опция --delete принимает только простые целевые имена ссылок"
+#: builtin/rebase.c:817
+msgid "could not determine HEAD revision"
+msgstr ""
 
-#: builtin/push.c:146
+#: builtin/rebase.c:940
 msgid ""
-"\n"
-"To choose either option permanently, see push.default in 'git help config'."
-msgstr "\nЧтобы выбрать любую из опций на постоянной основе, смотрите push.default в «git help config»."
+"Resolve all conflicts manually, mark them as resolved with\n"
+"\"git add/rm <conflicted_files>\", then run \"git rebase --continue\".\n"
+"You can instead skip this commit: run \"git rebase --skip\".\n"
+"To abort and get back to the state before \"git rebase\", run \"git rebase --abort\"."
+msgstr "Разрешите все конфликты вручную, пометьте их разрешёнными с помощью «git add/rm <конфликтующие-файлы>», а затем запустите «git rebase --continue».\nЕсли вы хотите пропустить этот коммит, то запустите «git rebase --skip».\nЧтобы вернуться на состояние до «git rebase», запустите «git rebase --abort»."
 
-#: builtin/push.c:149
+#: builtin/rebase.c:1021
 #, c-format
 msgid ""
-"The upstream branch of your current branch does not match\n"
-"the name of your current branch.  To push to the upstream branch\n"
-"on the remote, use\n"
 "\n"
-"    git push %s HEAD:%s\n"
+"git encountered an error while preparing the patches to replay\n"
+"these revisions:\n"
 "\n"
-"To push to the branch of the same name on the remote, use\n"
+"    %s\n"
 "\n"
-"    git push %s %s\n"
-"%s"
-msgstr "Имя вышестоящей ветки и вашей текущей ветки различаются. Чтобы отправить изменения в вышестоящую ветку на внешнем репозитории, используйте:\n\n    git push %s HEAD:%s\n\nЧтобы отправить изменения в ветку с таким же именем на внешнем репозитории, используйте:\n\n    git push %s %s\n%s"
+"As a result, git cannot rebase them."
+msgstr ""
 
-#: builtin/push.c:164
+#: builtin/rebase.c:1313
 #, c-format
 msgid ""
-"You are not currently on a branch.\n"
-"To push the history leading to the current (detached HEAD)\n"
-"state now, use\n"
+"%s\n"
+"Please specify which branch you want to rebase against.\n"
+"See git-rebase(1) for details.\n"
 "\n"
-"    git push %s HEAD:<name-of-remote-branch>\n"
-msgstr "Вы сейчас не находитесь ни на одной из веток.\nЧтобы отправить историю, ведущую к текущему (отделённый HEAD) состоянию, используйте\n\n    git push %s HEAD:<имя-внешней-ветки>\n"
+"    git rebase '<branch>'\n"
+"\n"
+msgstr ""
 
-#: builtin/push.c:178
+#: builtin/rebase.c:1329
 #, c-format
 msgid ""
-"The current branch %s has no upstream branch.\n"
-"To push the current branch and set the remote as upstream, use\n"
+"If you wish to set tracking information for this branch you can do so with:\n"
 "\n"
-"    git push --set-upstream %s %s\n"
-msgstr "Текущая ветка %s не имеет вышестоящей ветки.\nЧтобы отправить текущую ветку и установить внешнюю ветку как вышестоящую для этой ветки, используйте\n\n    git push --set-upstream %s %s\n"
+"    git branch --set-upstream-to=%s/<branch> %s\n"
+"\n"
+msgstr ""
 
-#: builtin/push.c:186
-#, c-format
-msgid ""
-"The current branch %s has multiple upstream branches, refusing to push."
-msgstr "Ваша текущая ветка %s имеет несколько вышестоящих веток, отказ в отправке изменений."
+#: builtin/rebase.c:1359
+msgid "exec commands cannot contain newlines"
+msgstr ""
 
-#: builtin/push.c:189
-#, c-format
-msgid ""
-"You are pushing to remote '%s', which is not the upstream of\n"
-"your current branch '%s', without telling me what to push\n"
-"to update which remote branch."
-msgstr "Вы сейчас отправляете изменения на внешний репозиторий «%s», который не является вышестоящим для вашей текущей ветки «%s», без указания того, что отправлять и в какую внешнюю ветку."
+#: builtin/rebase.c:1363
+msgid "empty exec command"
+msgstr ""
 
-#: builtin/push.c:248
-msgid "You didn't specify any refspecs to push, and push.default is \"nothing\"."
-msgstr "Вы не указали спецификацию ссылки для отправки, а push.default указан как «nothing»."
+#: builtin/rebase.c:1390
+msgid "rebase onto given branch instead of upstream"
+msgstr ""
 
-#: builtin/push.c:255
-msgid ""
-"Updates were rejected because the tip of your current branch is behind\n"
-"its remote counterpart. Integrate the remote changes (e.g.\n"
-"'git pull ...') before pushing again.\n"
-"See the 'Note about fast-forwards' in 'git push --help' for details."
-msgstr "Обновления были отклонены, так как верхушка вашей текущей ветки\nпозади ее внешней части. Заберите и слейте внешние изменения \n(например, с помощью «git pull …») перед повторной попыткой отправки\nизменений.\nДля дополнительной информации, смотрите «Note about fast-forwards»\nв «git push --help»."
+#: builtin/rebase.c:1392
+msgid "allow pre-rebase hook to run"
+msgstr ""
 
-#: builtin/push.c:261
-msgid ""
-"Updates were rejected because a pushed branch tip is behind its remote\n"
-"counterpart. Check out this branch and integrate the remote changes\n"
-"(e.g. 'git pull ...') before pushing again.\n"
-"See the 'Note about fast-forwards' in 'git push --help' for details."
-msgstr "Обновления были отклонены, так как верхушка отправляемой ветки\nпозади ее внешней части. Переключитесь на ветку и заберите внешние\nизменения (например, с помощью «git pull …») перед повторной\nпопыткой отправки изменений.\nДля дополнительной информации, смотрите «Note about fast-forwards»\nв «git push --help»."
+#: builtin/rebase.c:1394
+msgid "be quiet. implies --no-stat"
+msgstr ""
 
-#: builtin/push.c:267
-msgid ""
-"Updates were rejected because the remote contains work that you do\n"
-"not have locally. This is usually caused by another repository pushing\n"
-"to the same ref. You may want to first integrate the remote changes\n"
-"(e.g., 'git pull ...') before pushing again.\n"
-"See the 'Note about fast-forwards' in 'git push --help' for details."
-msgstr "Обновления были отклонены, так как внешний репозиторий содержит\nизменения, которых у вас нет в вашем локальном репозитории.\nОбычно, это связанно с тем, что кто-то уже отправил изменения в \nто же место. Перед повторной отправкой ваших изменений, вам нужно\nзабрать и слить изменения из внешнего репозитория себе\n(например, с помощью «git pull …»).\nДля дополнительной информации, смотрите «Note about fast-forwards»\nв «git push --help»."
+#: builtin/rebase.c:1400
+msgid "do not show diffstat of what changed upstream"
+msgstr ""
 
-#: builtin/push.c:274
-msgid "Updates were rejected because the tag already exists in the remote."
-msgstr "Обновления были отклонены, так как метка уже существует во внешнем репозитории."
+#: builtin/rebase.c:1403
+msgid "add a Signed-off-by: line to each commit"
+msgstr ""
 
-#: builtin/push.c:277
-msgid ""
-"You cannot update a remote ref that points at a non-commit object,\n"
-"or update a remote ref to make it point at a non-commit object,\n"
-"without using the '--force' option.\n"
-msgstr "Вы не можете обновить внешнюю ссылку, которая указывает на объект, не являющийся коммитом или обновить внешнюю ссылку так, чтобы она указывала на объект, не являющийся коммитом, без указания опции «--force».\n"
+#: builtin/rebase.c:1405 builtin/rebase.c:1409 builtin/rebase.c:1411
+msgid "passed to 'git am'"
+msgstr ""
 
-#: builtin/push.c:337
-#, c-format
-msgid "Pushing to %s\n"
-msgstr "Отправка в %s\n"
+#: builtin/rebase.c:1413 builtin/rebase.c:1415
+msgid "passed to 'git apply'"
+msgstr ""
 
-#: builtin/push.c:341
-#, c-format
-msgid "failed to push some refs to '%s'"
-msgstr "не удалось отправить некоторые ссылки в «%s»"
+#: builtin/rebase.c:1417 builtin/rebase.c:1420
+msgid "cherry-pick all commits, even if unchanged"
+msgstr ""
 
-#: builtin/push.c:372
-#, c-format
-msgid "bad repository '%s'"
-msgstr "плохой репозитория «%s»"
+#: builtin/rebase.c:1422
+msgid "continue"
+msgstr ""
 
-#: builtin/push.c:373
-msgid ""
-"No configured push destination.\n"
-"Either specify the URL from the command-line or configure a remote repository using\n"
-"\n"
-"    git remote add <name> <url>\n"
-"\n"
-"and then push using the remote name\n"
-"\n"
-"    git push <name>\n"
-msgstr "Не настроена точка назначения для отправки.\nЛибо укажите URL с помощью командной строки, либо настройте внешний репозиторий с помощью\n\n    git remote add <имя> <адрес>\n\nа затем отправьте изменения с помощью имени внешнего репозитория\n\n    git push <имя>\n"
+#: builtin/rebase.c:1425
+msgid "skip current patch and continue"
+msgstr ""
 
-#: builtin/push.c:391
-msgid "--all and --tags are incompatible"
-msgstr "--all и --tags нельзя использовать одновременно"
+#: builtin/rebase.c:1427
+msgid "abort and check out the original branch"
+msgstr ""
 
-#: builtin/push.c:392
-msgid "--all can't be combined with refspecs"
-msgstr "--all нельзя использовать вместе со спецификаторами ссылок"
+#: builtin/rebase.c:1430
+msgid "abort but keep HEAD where it is"
+msgstr ""
 
-#: builtin/push.c:397
-msgid "--mirror and --tags are incompatible"
-msgstr "--mirror и --tags нельзя использовать одновременно"
+#: builtin/rebase.c:1431
+msgid "edit the todo list during an interactive rebase"
+msgstr ""
 
-#: builtin/push.c:398
-msgid "--mirror can't be combined with refspecs"
-msgstr "--mirror нельзя использовать вместе со спецификаторами ссылок"
+#: builtin/rebase.c:1434
+msgid "show the patch file being applied or merged"
+msgstr ""
 
-#: builtin/push.c:403
-msgid "--all and --mirror are incompatible"
-msgstr "--all и --mirror нельзя использовать одновременно"
+#: builtin/rebase.c:1437
+msgid "use merging strategies to rebase"
+msgstr ""
 
-#: builtin/push.c:535
-msgid "repository"
-msgstr "репозиторий"
+#: builtin/rebase.c:1441
+msgid "let the user edit the list of commits to rebase"
+msgstr ""
 
-#: builtin/push.c:536 builtin/send-pack.c:163
-msgid "push all refs"
-msgstr "отправить все ссылки"
+#: builtin/rebase.c:1445
+msgid "(DEPRECATED) try to recreate merges instead of ignoring them"
+msgstr ""
 
-#: builtin/push.c:537 builtin/send-pack.c:165
-msgid "mirror all refs"
-msgstr "сделать зеркало всех ссылок"
+#: builtin/rebase.c:1449
+msgid "preserve empty commits during rebase"
+msgstr ""
 
-#: builtin/push.c:539
-msgid "delete refs"
-msgstr "удалить ссылки"
+#: builtin/rebase.c:1451
+msgid "move commits that begin with squash!/fixup! under -i"
+msgstr ""
 
-#: builtin/push.c:540
-msgid "push tags (can't be used with --all or --mirror)"
-msgstr "отправить метки (нельзя использовать вместе с --all или --mirror)"
+#: builtin/rebase.c:1457
+msgid "automatically stash/stash pop before and after"
+msgstr ""
 
-#: builtin/push.c:543 builtin/send-pack.c:166
-msgid "force updates"
-msgstr "принудительное обновление"
+#: builtin/rebase.c:1459
+msgid "add exec lines after each commit of the editable list"
+msgstr ""
 
-#: builtin/push.c:545 builtin/send-pack.c:180
-msgid "refname>:<expect"
-msgstr "имя-ссылки>:<ожидается"
+#: builtin/rebase.c:1463
+msgid "allow rebasing commits with empty messages"
+msgstr ""
 
-#: builtin/push.c:546 builtin/send-pack.c:181
-msgid "require old value of ref to be at this value"
-msgstr "требовать, чтобы старое значение ссылки было ожидаемым"
+#: builtin/rebase.c:1466
+msgid "try to rebase merges instead of skipping them"
+msgstr ""
 
-#: builtin/push.c:549
-msgid "control recursive pushing of submodules"
-msgstr "управление рекурсивной отправкой подмодулей"
+#: builtin/rebase.c:1469
+msgid "use 'merge-base --fork-point' to refine upstream"
+msgstr ""
 
-#: builtin/push.c:551 builtin/send-pack.c:174
-msgid "use thin pack"
-msgstr "использовать тонкие пакеты"
+#: builtin/rebase.c:1471
+msgid "use the given merge strategy"
+msgstr ""
 
-#: builtin/push.c:552 builtin/push.c:553 builtin/send-pack.c:160
-#: builtin/send-pack.c:161
-msgid "receive pack program"
-msgstr "путь к программе упаковки на сервере"
+#: builtin/rebase.c:1473 builtin/revert.c:114
+msgid "option"
+msgstr "опция"
 
-#: builtin/push.c:554
-msgid "set upstream for git pull/status"
-msgstr "установить вышестоящую ветку для git pull/status"
+#: builtin/rebase.c:1474
+msgid "pass the argument through to the merge strategy"
+msgstr ""
 
-#: builtin/push.c:557
-msgid "prune locally removed refs"
-msgstr "почистить локально удаленные ссылки"
+#: builtin/rebase.c:1477
+msgid "rebase all reachable commits up to the root(s)"
+msgstr ""
 
-#: builtin/push.c:559
-msgid "bypass pre-push hook"
-msgstr "пропустить перехватчик pre-push"
+#: builtin/rebase.c:1498
+msgid ""
+"the rebase.useBuiltin support has been removed!\n"
+"See its entry in 'git help config' for details."
+msgstr ""
 
-#: builtin/push.c:560
-msgid "push missing but relevant tags"
-msgstr "отправить пропущенные, но нужные метки"
+#: builtin/rebase.c:1504
+msgid "It looks like 'git am' is in progress. Cannot rebase."
+msgstr "Похоже, что выполняется «git am». Невозможно выполнить перемещение."
 
-#: builtin/push.c:563 builtin/send-pack.c:168
-msgid "GPG sign the push"
-msgstr "подписать отправку с помощью GPG"
+#: builtin/rebase.c:1545
+msgid ""
+"git rebase --preserve-merges is deprecated. Use --rebase-merges instead."
+msgstr ""
 
-#: builtin/push.c:565 builtin/send-pack.c:175
-msgid "request atomic transaction on remote side"
-msgstr "запросить выполнение атомарной транзакции на внешней стороне"
+#: builtin/rebase.c:1549
+msgid "No rebase in progress?"
+msgstr "Нет перемещения в процессе?"
 
-#: builtin/push.c:566 builtin/send-pack.c:171
-msgid "server-specific"
-msgstr "зависит-от-сервера"
+#: builtin/rebase.c:1553
+msgid "The --edit-todo action can only be used during interactive rebase."
+msgstr "Действие --edit-todo может использоваться только при интерактивном перемещении."
 
-#: builtin/push.c:566 builtin/send-pack.c:172
-msgid "option to transmit"
-msgstr "передаваемые опции"
+#: builtin/rebase.c:1576
+msgid "Cannot read HEAD"
+msgstr "Не удалось прочитать HEAD"
 
-#: builtin/push.c:583
-msgid "--delete is incompatible with --all, --mirror and --tags"
-msgstr "--delete несовместимо с  --all, --mirror и --tags"
+#: builtin/rebase.c:1588
+msgid ""
+"You must edit all merge conflicts and then\n"
+"mark them as resolved using git add"
+msgstr "Вы должны отредактировать все\nконфликты слияния, а потом пометить\nих как разрешенные с помощью git add"
 
-#: builtin/push.c:585
-msgid "--delete doesn't make sense without any refs"
-msgstr "--delete не имеет смысла без указания ссылок"
+#: builtin/rebase.c:1607
+msgid "could not discard worktree changes"
+msgstr ""
 
-#: builtin/push.c:604
-msgid "push options must not have new line characters"
-msgstr "опции для отправки не должны содержать символы перевода строк"
+#: builtin/rebase.c:1626
+#, c-format
+msgid "could not move back to %s"
+msgstr ""
+
+#: builtin/rebase.c:1637 builtin/rm.c:369
+#, c-format
+msgid "could not remove '%s'"
+msgstr "не удалось удалить «%s»"
 
-#: builtin/read-tree.c:40
+#: builtin/rebase.c:1663
+#, c-format
 msgid ""
-"git read-tree [(-m [--trivial] [--aggressive] | --reset | --prefix=<prefix>)"
-" [-u [--exclude-per-directory=<gitignore>] | -i]] [--no-sparse-checkout] "
-"[--index-output=<file>] (--empty | <tree-ish1> [<tree-ish2> [<tree-ish3>]])"
-msgstr "git read-tree [(-m [--trivial] [--aggressive] | --reset | --prefix=<префикс>) [-u [--exclude-per-directory=<gitignore>] | -i]] [--no-sparse-checkout] [--index-output=<файл>] (--empty | <указатель-дерева-1> [<указатель-дерева-2> [<указатель-дерева-3>]])"
+"It seems that there is already a %s directory, and\n"
+"I wonder if you are in the middle of another rebase.  If that is the\n"
+"case, please try\n"
+"\t%s\n"
+"If that is not the case, please\n"
+"\t%s\n"
+"and run me again.  I am stopping in case you still have something\n"
+"valuable there.\n"
+msgstr ""
 
-#: builtin/read-tree.c:121
-msgid "write resulting index to <file>"
-msgstr "записать результирующий индекс в <файл>"
+#: builtin/rebase.c:1684
+msgid "switch `C' expects a numerical value"
+msgstr ""
 
-#: builtin/read-tree.c:124
-msgid "only empty the index"
-msgstr "просто очистить индекс"
+#: builtin/rebase.c:1725
+#, c-format
+msgid "Unknown mode: %s"
+msgstr ""
 
-#: builtin/read-tree.c:126
-msgid "Merging"
-msgstr "Слияние"
+#: builtin/rebase.c:1747
+msgid "--strategy requires --merge or --interactive"
+msgstr ""
 
-#: builtin/read-tree.c:128
-msgid "perform a merge in addition to a read"
-msgstr "выполнить слияние в дополнение к чтению"
+#: builtin/rebase.c:1796
+msgid "cannot combine am options with either interactive or merge options"
+msgstr ""
+
+#: builtin/rebase.c:1815
+msgid "cannot combine '--preserve-merges' with '--rebase-merges'"
+msgstr ""
+
+#: builtin/rebase.c:1819
+msgid ""
+"error: cannot combine '--preserve-merges' with '--reschedule-failed-exec'"
+msgstr ""
+
+#: builtin/rebase.c:1825
+msgid "cannot combine '--rebase-merges' with '--strategy-option'"
+msgstr ""
+
+#: builtin/rebase.c:1828
+msgid "cannot combine '--rebase-merges' with '--strategy'"
+msgstr ""
+
+#: builtin/rebase.c:1852
+#, c-format
+msgid "invalid upstream '%s'"
+msgstr ""
+
+#: builtin/rebase.c:1858
+msgid "Could not create new root commit"
+msgstr ""
+
+#: builtin/rebase.c:1876
+#, c-format
+msgid "'%s': need exactly one merge base"
+msgstr ""
 
-#: builtin/read-tree.c:130
-msgid "3-way merge if no file level merging required"
-msgstr "трехходовое слияние, если не требуется слияние на уровне файлов"
+#: builtin/rebase.c:1883
+#, c-format
+msgid "Does not point to a valid commit '%s'"
+msgstr ""
 
-#: builtin/read-tree.c:132
-msgid "3-way merge in presence of adds and removes"
-msgstr "трехходовое слияние в случае присутствия добавлений или удалений файлов"
+#: builtin/rebase.c:1908
+#, c-format
+msgid "fatal: no such branch/commit '%s'"
+msgstr ""
 
-#: builtin/read-tree.c:134
-msgid "same as -m, but discard unmerged entries"
-msgstr "тоже, что и -m, но отменяет изменения не слитых записей"
+#: builtin/rebase.c:1916 builtin/submodule--helper.c:38
+#: builtin/submodule--helper.c:1933
+#, c-format
+msgid "No such ref: %s"
+msgstr "Нет такой ссылки: %s"
 
-#: builtin/read-tree.c:135
-msgid "<subdirectory>/"
-msgstr "<подкаталог>/"
+#: builtin/rebase.c:1927
+msgid "Could not resolve HEAD to a revision"
+msgstr ""
 
-#: builtin/read-tree.c:136
-msgid "read the tree into the index under <subdirectory>/"
-msgstr "прочитать дерево в индекс в <подкаталог>/"
+#: builtin/rebase.c:1968
+msgid "Cannot autostash"
+msgstr "Не удалось автоматически спрятать изменения"
 
-#: builtin/read-tree.c:139
-msgid "update working tree with merge result"
-msgstr "обновить рабочий каталог результатом слияния"
+#: builtin/rebase.c:1971
+#, c-format
+msgid "Unexpected stash response: '%s'"
+msgstr ""
 
-#: builtin/read-tree.c:141
-msgid "gitignore"
-msgstr "gitignore"
+#: builtin/rebase.c:1977
+#, c-format
+msgid "Could not create directory for '%s'"
+msgstr ""
 
-#: builtin/read-tree.c:142
-msgid "allow explicitly ignored files to be overwritten"
-msgstr "разрешить перезапись явно игнорируемых файлов"
+#: builtin/rebase.c:1980
+#, c-format
+msgid "Created autostash: %s\n"
+msgstr ""
 
-#: builtin/read-tree.c:145
-msgid "don't check the working tree after merging"
-msgstr "не проверять рабочий каталог после слияния"
+#: builtin/rebase.c:1983
+msgid "could not reset --hard"
+msgstr ""
 
-#: builtin/read-tree.c:146
-msgid "don't update the index or the work tree"
-msgstr "не обновлять индекс или рабочий каталог"
+#: builtin/rebase.c:1984 builtin/reset.c:114
+#, c-format
+msgid "HEAD is now at %s"
+msgstr "HEAD сейчас на %s"
 
-#: builtin/read-tree.c:148
-msgid "skip applying sparse checkout filter"
-msgstr "пропустить применение фильтра частичного переключения на состояние"
+#: builtin/rebase.c:2000
+msgid "Please commit or stash them."
+msgstr "Сделайте коммит или спрячьте их."
 
-#: builtin/read-tree.c:150
-msgid "debug unpack-trees"
-msgstr "отладка unpack-trees"
+#: builtin/rebase.c:2027
+#, c-format
+msgid "could not parse '%s'"
+msgstr ""
 
-#: builtin/rebase--helper.c:8
-msgid "git rebase--helper [<options>]"
-msgstr "git rebase--helper [<опции>]"
+#: builtin/rebase.c:2040
+#, c-format
+msgid "could not switch to %s"
+msgstr ""
 
-#: builtin/rebase--helper.c:24
-msgid "keep empty commits"
-msgstr "оставить пустые коммиты"
+#: builtin/rebase.c:2051
+msgid "HEAD is up to date."
+msgstr "HEAD уже в актуальном состоянии."
 
-#: builtin/rebase--helper.c:25
-msgid "continue rebase"
-msgstr "продолжить перемещение"
+#: builtin/rebase.c:2053
+#, c-format
+msgid "Current branch %s is up to date.\n"
+msgstr ""
+
+#: builtin/rebase.c:2061
+msgid "HEAD is up to date, rebase forced."
+msgstr "HEAD уже в актуальном состоянии, принудительное перемещение."
 
-#: builtin/rebase--helper.c:27
-msgid "abort rebase"
-msgstr "остановить перемещение"
-
-#: builtin/rebase--helper.c:30
-msgid "make rebase script"
-msgstr "создать сценарий перемещения"
+#: builtin/rebase.c:2063
+#, c-format
+msgid "Current branch %s is up to date, rebase forced.\n"
+msgstr ""
 
-#: builtin/rebase--helper.c:32
-msgid "shorten commit ids in the todo list"
-msgstr "вывести короткие идентификаторы коммитов в списке действий"
+#: builtin/rebase.c:2071
+msgid "The pre-rebase hook refused to rebase."
+msgstr "Перехватчик pre-rebase отказал в перемещении."
 
-#: builtin/rebase--helper.c:34
-msgid "expand commit ids in the todo list"
-msgstr "вывести полные идентификаторы коммитов в списке действий"
+#: builtin/rebase.c:2078
+#, c-format
+msgid "Changes to %s:\n"
+msgstr ""
 
-#: builtin/rebase--helper.c:36
-msgid "check the todo list"
-msgstr "проверить список дел"
+#: builtin/rebase.c:2081
+#, c-format
+msgid "Changes from %s to %s:\n"
+msgstr ""
 
-#: builtin/rebase--helper.c:38
-msgid "skip unnecessary picks"
-msgstr "пропустить ненужные команды pick"
+#: builtin/rebase.c:2106
+#, c-format
+msgid "First, rewinding head to replay your work on top of it...\n"
+msgstr ""
 
-#: builtin/rebase--helper.c:40
-msgid "rearrange fixup/squash lines"
-msgstr "переставить строки fixup/squash"
+#: builtin/rebase.c:2115
+msgid "Could not detach HEAD"
+msgstr ""
 
-#: builtin/rebase--helper.c:42
-msgid "insert exec commands in todo list"
-msgstr "вставить команды исполнения коммитов в списке действий"
+#: builtin/rebase.c:2124
+#, c-format
+msgid "Fast-forwarded %s to %s.\n"
+msgstr ""
 
-#: builtin/receive-pack.c:30
+#: builtin/receive-pack.c:33
 msgid "git receive-pack <git-dir>"
 msgstr "git receive-pack <каталог-git>"
 
-#: builtin/receive-pack.c:840
+#: builtin/receive-pack.c:833
 msgid ""
 "By default, updating the current branch in a non-bare repository\n"
 "is denied, because it will make the index and work tree inconsistent\n"
@@ -11386,7 +16262,7 @@ msgid ""
 "'receive.denyCurrentBranch' configuration variable to 'refuse'."
 msgstr "По умолчанию, обновлять текущую ветку в репозитории с рабочей\nкопией (не голом) запрещено, так как это сделает состояние индекса\nи рабочего каталога противоречивым, и вам прийдется выполнить\n«git reset --hard», чтобы состояние рабочего каталога снова\nсоответствовало HEAD.\n\nВы можете установить значение опции «receive.denyCurrentBranch»\nв «ignore» или «warn» во внешнем репозитории, чтобы разрешить\nотправку в его текущую ветку; но это не рекомендуется, если только\nвы не намерены обновить его рабочий каталог способом подобным\nвышеописанному.\n\nЧтобы пропустить это сообщение и все равно оставить поведение\nпо умолчанию, установите значение опции «receive.denyCurrentBranch»\nв «refuse»."
 
-#: builtin/receive-pack.c:860
+#: builtin/receive-pack.c:853
 msgid ""
 "By default, deleting the current branch is denied, because the next\n"
 "'git clone' won't result in any file checked out, causing confusion.\n"
@@ -11398,189 +16274,235 @@ msgid ""
 "To squelch this message, you can set it to 'refuse'."
 msgstr "По умолчанию, удаление текущей ветки запрещено, так как последующий\n«git clone» не сможет получить никаких файлов, что приведет к путанице.\n\nВы можете установить значение опции «receive.denyDeleteCurrent»\nв «warn» или «ignore», во внешнем репозитории,  чтобы разрешить\nудаление текущей ветки с или без предупреждающего сообщения.\n\nЧтобы пропустить это сообщение, вы можете установить значение опции\nв «refuse»."
 
-#: builtin/receive-pack.c:1933
+#: builtin/receive-pack.c:1940
 msgid "quiet"
 msgstr "тихий режим"
 
-#: builtin/receive-pack.c:1947
+#: builtin/receive-pack.c:1954
 msgid "You must specify a directory."
 msgstr "Вы должны указать каталог."
 
-#: builtin/reflog.c:531 builtin/reflog.c:536
+#: builtin/reflog.c:17
+msgid ""
+"git reflog expire [--expire=<time>] [--expire-unreachable=<time>] "
+"[--rewrite] [--updateref] [--stale-fix] [--dry-run | -n] [--verbose] [--all]"
+" <refs>..."
+msgstr ""
+
+#: builtin/reflog.c:22
+msgid ""
+"git reflog delete [--rewrite] [--updateref] [--dry-run | -n] [--verbose] "
+"<refs>..."
+msgstr ""
+
+#: builtin/reflog.c:25
+msgid "git reflog exists <ref>"
+msgstr ""
+
+#: builtin/reflog.c:567 builtin/reflog.c:572
 #, c-format
 msgid "'%s' is not a valid timestamp"
 msgstr "«%s» не является допустимой меткой даты/времени"
 
-#: builtin/remote.c:13
+#: builtin/reflog.c:605
+#, c-format
+msgid "Marking reachable objects..."
+msgstr ""
+
+#: builtin/reflog.c:643
+#, c-format
+msgid "%s points nowhere!"
+msgstr ""
+
+#: builtin/reflog.c:695
+msgid "no reflog specified to delete"
+msgstr ""
+
+#: builtin/reflog.c:704
+#, c-format
+msgid "not a reflog: %s"
+msgstr ""
+
+#: builtin/reflog.c:709
+#, c-format
+msgid "no reflog for '%s'"
+msgstr ""
+
+#: builtin/reflog.c:755
+#, c-format
+msgid "invalid ref format: %s"
+msgstr ""
+
+#: builtin/reflog.c:764
+msgid "git reflog [ show | expire | delete | exists ]"
+msgstr ""
+
+#: builtin/remote.c:16
 msgid "git remote [-v | --verbose]"
 msgstr "git remote [-v | --verbose]"
 
-#: builtin/remote.c:14
+#: builtin/remote.c:17
 msgid ""
 "git remote add [-t <branch>] [-m <master>] [-f] [--tags | --no-tags] "
 "[--mirror=<fetch|push>] <name> <url>"
 msgstr "git remote add [-t <ветка>] [-m <мастер-ветка>] [-f] [--tags | --no-tags] [--mirror=<fetch|push>] <имя> <адрес>"
 
-#: builtin/remote.c:15 builtin/remote.c:35
+#: builtin/remote.c:18 builtin/remote.c:38
 msgid "git remote rename <old> <new>"
 msgstr "git remote rename <старое-название> <новое-название>"
 
-#: builtin/remote.c:16 builtin/remote.c:40
+#: builtin/remote.c:19 builtin/remote.c:43
 msgid "git remote remove <name>"
 msgstr "git remote remove <имя>"
 
-#: builtin/remote.c:17 builtin/remote.c:45
+#: builtin/remote.c:20 builtin/remote.c:48
 msgid "git remote set-head <name> (-a | --auto | -d | --delete | <branch>)"
 msgstr "git remote set-head <имя> (-a | --auto | -d | --delete | <ветка>)"
 
-#: builtin/remote.c:18
+#: builtin/remote.c:21
 msgid "git remote [-v | --verbose] show [-n] <name>"
 msgstr "git remote [-v | --verbose] show [-n] <имя>"
 
-#: builtin/remote.c:19
+#: builtin/remote.c:22
 msgid "git remote prune [-n | --dry-run] <name>"
 msgstr "git remote prune [-n | --dry-run] <имя>"
 
-#: builtin/remote.c:20
+#: builtin/remote.c:23
 msgid ""
 "git remote [-v | --verbose] update [-p | --prune] [(<group> | <remote>)...]"
 msgstr "git remote [-v | --verbose] update [-p | --prune] [(<группа> | <имя-внешнего-репозитория>)…]"
 
-#: builtin/remote.c:21
+#: builtin/remote.c:24
 msgid "git remote set-branches [--add] <name> <branch>..."
 msgstr "git remote set-branches [--add] <имя> <ветка>…"
 
-#: builtin/remote.c:22 builtin/remote.c:71
+#: builtin/remote.c:25 builtin/remote.c:74
 msgid "git remote get-url [--push] [--all] <name>"
 msgstr "git remote get-url [--push] [--all] <имя>"
 
-#: builtin/remote.c:23 builtin/remote.c:76
+#: builtin/remote.c:26 builtin/remote.c:79
 msgid "git remote set-url [--push] <name> <newurl> [<oldurl>]"
 msgstr "git remote set-url [--push] <имя> <новый-url> [<старый-url>]"
 
-#: builtin/remote.c:24 builtin/remote.c:77
+#: builtin/remote.c:27 builtin/remote.c:80
 msgid "git remote set-url --add <name> <newurl>"
 msgstr "git remote set-url --add <имя> <новый-url>"
 
-#: builtin/remote.c:25 builtin/remote.c:78
+#: builtin/remote.c:28 builtin/remote.c:81
 msgid "git remote set-url --delete <name> <url>"
 msgstr "git remote set-url --delete <имя> <url>"
 
-#: builtin/remote.c:30
+#: builtin/remote.c:33
 msgid "git remote add [<options>] <name> <url>"
 msgstr "git remote add [<опции>] <имя> <url>"
 
-#: builtin/remote.c:50
+#: builtin/remote.c:53
 msgid "git remote set-branches <name> <branch>..."
 msgstr "git remote set-branches <имя> <ветка>…"
 
-#: builtin/remote.c:51
+#: builtin/remote.c:54
 msgid "git remote set-branches --add <name> <branch>..."
 msgstr "git remote set-branches --add <имя> <ветка>…"
 
-#: builtin/remote.c:56
+#: builtin/remote.c:59
 msgid "git remote show [<options>] <name>"
 msgstr "git remote show [<опции>] <имя>"
 
-#: builtin/remote.c:61
+#: builtin/remote.c:64
 msgid "git remote prune [<options>] <name>"
 msgstr "git remote prune [<опции>] <имя>"
 
-#: builtin/remote.c:66
+#: builtin/remote.c:69
 msgid "git remote update [<options>] [<group> | <remote>]..."
 msgstr "git remote update [<опции>] [<группа> | <имя-внешнего-репозитория>]…"
 
-#: builtin/remote.c:95
+#: builtin/remote.c:98
 #, c-format
 msgid "Updating %s"
 msgstr "Обновление %s"
 
-#: builtin/remote.c:127
+#: builtin/remote.c:130
 msgid ""
 "--mirror is dangerous and deprecated; please\n"
 "\t use --mirror=fetch or --mirror=push instead"
 msgstr "ключ --mirror небезопасен и не рекомендуется к использованию;\nиспользуйте вместо него --mirror=fetch или --mirror=push"
 
-#: builtin/remote.c:144
+#: builtin/remote.c:147
 #, c-format
 msgid "unknown mirror argument: %s"
 msgstr "неизвестный аргумент для mirror: %s"
 
-#: builtin/remote.c:160
+#: builtin/remote.c:163
 msgid "fetch the remote branches"
 msgstr "извлечь внешние ветки"
 
-#: builtin/remote.c:162
+#: builtin/remote.c:165
 msgid "import all tags and associated objects when fetching"
 msgstr "импортировать все метки и ассоциированные объекты при извлечении"
 
-#: builtin/remote.c:165
+#: builtin/remote.c:168
 msgid "or do not fetch any tag at all (--no-tags)"
 msgstr "или не извлекать метки вообще (--no-tags)"
 
-#: builtin/remote.c:167
+#: builtin/remote.c:170
 msgid "branch(es) to track"
 msgstr "отслеживаемые ветки"
 
-#: builtin/remote.c:168
+#: builtin/remote.c:171
 msgid "master branch"
 msgstr "мастер ветка"
 
-#: builtin/remote.c:169
-msgid "push|fetch"
-msgstr "push|fetch"
-
-#: builtin/remote.c:170
+#: builtin/remote.c:173
 msgid "set up remote as a mirror to push to or fetch from"
 msgstr "настроить внешний репозиторий как зеркало для отправки или извлечения изменений"
 
-#: builtin/remote.c:182
+#: builtin/remote.c:185
 msgid "specifying a master branch makes no sense with --mirror"
 msgstr "указание мастер ветки не имеет смысла с параметром --mirror"
 
-#: builtin/remote.c:184
+#: builtin/remote.c:187
 msgid "specifying branches to track makes sense only with fetch mirrors"
 msgstr "указание отслеживаемых веток имеет смысл только при зеркальном извлечении"
 
-#: builtin/remote.c:191 builtin/remote.c:631
+#: builtin/remote.c:194 builtin/remote.c:636
 #, c-format
 msgid "remote %s already exists."
 msgstr "внешний репозиторий %s уже существует"
 
-#: builtin/remote.c:195 builtin/remote.c:635
+#: builtin/remote.c:198 builtin/remote.c:640
 #, c-format
 msgid "'%s' is not a valid remote name"
 msgstr "«%s» не является допустимым именем внешнего репозитория."
 
-#: builtin/remote.c:235
+#: builtin/remote.c:238
 #, c-format
 msgid "Could not setup master '%s'"
 msgstr "Не удалось настроить мастер ветку «%s»"
 
-#: builtin/remote.c:337
+#: builtin/remote.c:344
 #, c-format
 msgid "Could not get fetch map for refspec %s"
 msgstr "Не удалось извлечь карту для спецификатора ссылки %s"
 
-#: builtin/remote.c:438 builtin/remote.c:446
+#: builtin/remote.c:443 builtin/remote.c:451
 msgid "(matching)"
 msgstr "(соответствующая)"
 
-#: builtin/remote.c:450
+#: builtin/remote.c:455
 msgid "(delete)"
 msgstr "(удаленная)"
 
-#: builtin/remote.c:624 builtin/remote.c:759 builtin/remote.c:858
+#: builtin/remote.c:629 builtin/remote.c:765 builtin/remote.c:864
 #, c-format
-msgid "No such remote: %s"
-msgstr "Нет такого внешнего репозитория: %s"
+msgid "No such remote: '%s'"
+msgstr ""
 
-#: builtin/remote.c:641
+#: builtin/remote.c:646
 #, c-format
 msgid "Could not rename config section '%s' to '%s'"
 msgstr "Не удалось переименовать секцию конфигурации с «%s» на «%s»"
 
-#: builtin/remote.c:661
+#: builtin/remote.c:666
 #, c-format
 msgid ""
 "Not updating non-default fetch refspec\n"
@@ -11588,17 +16510,17 @@ msgid ""
 "\tPlease update the configuration manually if necessary."
 msgstr "Не обновляю нестандартную спецификатор ссылки для извлечения\n\t%s\n\tПожалуйста, если требуется, обновите конфигурацию вручную."
 
-#: builtin/remote.c:697
+#: builtin/remote.c:702
 #, c-format
 msgid "deleting '%s' failed"
 msgstr "не удалось удалить «%s»"
 
-#: builtin/remote.c:731
+#: builtin/remote.c:736
 #, c-format
 msgid "creating '%s' failed"
 msgstr "не удалось создать «%s»"
 
-#: builtin/remote.c:796
+#: builtin/remote.c:802
 msgid ""
 "Note: A branch outside the refs/remotes/ hierarchy was not removed;\n"
 "to delete it, use:"
@@ -11610,143 +16532,148 @@ msgstr[1] "Примечание: Нек
 msgstr[2] "Примечание: Некоторые ветки вне иерархии refs/remotes/ не будут удалены;\nчтобы удалить их, используйте:"
 msgstr[3] "Примечание: Некоторые ветки вне иерархии refs/remotes/ не будут удалены;\nчтобы удалить их, используйте:"
 
-#: builtin/remote.c:810
+#: builtin/remote.c:816
 #, c-format
 msgid "Could not remove config section '%s'"
 msgstr "Не удалось удалить секцию файла конфигурации «%s»"
 
-#: builtin/remote.c:911
+#: builtin/remote.c:917
 #, c-format
 msgid " new (next fetch will store in remotes/%s)"
 msgstr " новая (следующее извлечение сохранит ее в remotes/%s)"
 
-#: builtin/remote.c:914
+#: builtin/remote.c:920
 msgid " tracked"
 msgstr " отслеживается"
 
-#: builtin/remote.c:916
+#: builtin/remote.c:922
 msgid " stale (use 'git remote prune' to remove)"
 msgstr " недействительна (используйте «git remote prune», чтобы удалить)"
 
-#: builtin/remote.c:918
+#: builtin/remote.c:924
 msgid " ???"
 msgstr " ???"
 
-#: builtin/remote.c:959
+#: builtin/remote.c:965
 #, c-format
 msgid "invalid branch.%s.merge; cannot rebase onto > 1 branch"
 msgstr "неправильный параметр конфигурации branch.%s.merge; невозможно переместить более чем над 1 веткой"
 
-#: builtin/remote.c:967
+#: builtin/remote.c:974
 #, c-format
 msgid "rebases interactively onto remote %s"
 msgstr "перемещается интерактивно над внешней веткой %s"
 
-#: builtin/remote.c:968
+#: builtin/remote.c:976
+#, c-format
+msgid "rebases interactively (with merges) onto remote %s"
+msgstr ""
+
+#: builtin/remote.c:979
 #, c-format
 msgid "rebases onto remote %s"
 msgstr "перемещается над внешней веткой %s"
 
-#: builtin/remote.c:971
+#: builtin/remote.c:983
 #, c-format
 msgid " merges with remote %s"
 msgstr " будет слита с внешней веткой %s"
 
-#: builtin/remote.c:974
+#: builtin/remote.c:986
 #, c-format
 msgid "merges with remote %s"
 msgstr "будет слита с внешней веткой %s"
 
-#: builtin/remote.c:977
+#: builtin/remote.c:989
 #, c-format
 msgid "%-*s    and with remote %s\n"
 msgstr "%-*s    и с внешней веткой %s\n"
 
-#: builtin/remote.c:1020
+#: builtin/remote.c:1032
 msgid "create"
 msgstr "создана"
 
-#: builtin/remote.c:1023
+#: builtin/remote.c:1035
 msgid "delete"
 msgstr "удалена"
 
-#: builtin/remote.c:1027
+#: builtin/remote.c:1039
 msgid "up to date"
 msgstr "уже актуальна"
 
-#: builtin/remote.c:1030
+#: builtin/remote.c:1042
 msgid "fast-forwardable"
 msgstr "возможна перемотка вперед"
 
-#: builtin/remote.c:1033
+#: builtin/remote.c:1045
 msgid "local out of date"
 msgstr "локальная ветка устарела"
 
-#: builtin/remote.c:1040
+#: builtin/remote.c:1052
 #, c-format
 msgid "    %-*s forces to %-*s (%s)"
 msgstr "    %-*s будет принудительно отправлена в %-*s (%s)"
 
-#: builtin/remote.c:1043
+#: builtin/remote.c:1055
 #, c-format
 msgid "    %-*s pushes to %-*s (%s)"
 msgstr "    %-*s будет отправлена в %-*s (%s)"
 
-#: builtin/remote.c:1047
+#: builtin/remote.c:1059
 #, c-format
 msgid "    %-*s forces to %s"
 msgstr "    %-*s будет принудительно отправлена в %s"
 
-#: builtin/remote.c:1050
+#: builtin/remote.c:1062
 #, c-format
 msgid "    %-*s pushes to %s"
 msgstr "    %-*s будет отправлена в %s"
 
-#: builtin/remote.c:1118
+#: builtin/remote.c:1130
 msgid "do not query remotes"
 msgstr "не опрашивать внешние репозитории"
 
-#: builtin/remote.c:1145
+#: builtin/remote.c:1157
 #, c-format
 msgid "* remote %s"
 msgstr "* внешний репозиторий %s"
 
-#: builtin/remote.c:1146
+#: builtin/remote.c:1158
 #, c-format
 msgid "  Fetch URL: %s"
 msgstr "  URL для извлечения: %s"
 
-#: builtin/remote.c:1147 builtin/remote.c:1163 builtin/remote.c:1302
+#: builtin/remote.c:1159 builtin/remote.c:1175 builtin/remote.c:1314
 msgid "(no URL)"
 msgstr "(нет URL)"
 
 #. TRANSLATORS: the colon ':' should align
 #. with the one in " Fetch URL: %s"
 #. translation.
-#: builtin/remote.c:1161 builtin/remote.c:1163
+#: builtin/remote.c:1173 builtin/remote.c:1175
 #, c-format
 msgid "  Push  URL: %s"
 msgstr "    URL для отправки: %s"
 
-#: builtin/remote.c:1165 builtin/remote.c:1167 builtin/remote.c:1169
+#: builtin/remote.c:1177 builtin/remote.c:1179 builtin/remote.c:1181
 #, c-format
 msgid "  HEAD branch: %s"
 msgstr "  HEAD ветка: %s"
 
-#: builtin/remote.c:1165
+#: builtin/remote.c:1177
 msgid "(not queried)"
 msgstr "(не запрашивался)"
 
-#: builtin/remote.c:1167
+#: builtin/remote.c:1179
 msgid "(unknown)"
 msgstr "(неизвестно)"
 
-#: builtin/remote.c:1171
+#: builtin/remote.c:1183
 #, c-format
 msgid "  HEAD branch (remote HEAD is ambiguous, may be one of the following):\n"
 msgstr "  HEAD ветка (HEAD внешнего репозитория неоднозначный, может быть одним из):\n"
 
-#: builtin/remote.c:1183
+#: builtin/remote.c:1195
 #, c-format
 msgid "  Remote branch:%s"
 msgid_plural "  Remote branches:%s"
@@ -11755,11 +16682,11 @@ msgstr[1] "  Внешние ветки:%
 msgstr[2] "  Внешние ветки:%s"
 msgstr[3] "  Внешние ветки:%s"
 
-#: builtin/remote.c:1186 builtin/remote.c:1212
+#: builtin/remote.c:1198 builtin/remote.c:1224
 msgid " (status not queried)"
 msgstr " (статус не запрашивался)"
 
-#: builtin/remote.c:1195
+#: builtin/remote.c:1207
 msgid "  Local branch configured for 'git pull':"
 msgid_plural "  Local branches configured for 'git pull':"
 msgstr[0] "  Локальная ветка, настроенная для «git pull»:"
@@ -11767,11 +16694,11 @@ msgstr[1] "  Локальные ветк
 msgstr[2] "  Локальные ветки, настроенные для «git pull»:"
 msgstr[3] "  Локальные ветки, настроенные для «git pull»:"
 
-#: builtin/remote.c:1203
+#: builtin/remote.c:1215
 msgid "  Local refs will be mirrored by 'git push'"
 msgstr " Локальные ссылки, зеркалируемые с помощью «git push»"
 
-#: builtin/remote.c:1209
+#: builtin/remote.c:1221
 #, c-format
 msgid "  Local ref configured for 'git push'%s:"
 msgid_plural "  Local refs configured for 'git push'%s:"
@@ -11780,482 +16707,691 @@ msgstr[1] "  Локальные ссыл
 msgstr[2] "  Локальные ссылки, настроенные для «git push»%s:"
 msgstr[3] "  Локальные ссылки, настроенные для «git push»%s:"
 
-#: builtin/remote.c:1230
+#: builtin/remote.c:1242
 msgid "set refs/remotes/<name>/HEAD according to remote"
 msgstr "установить refs/remotes/<имя>/HEAD в зависимости от внешнего репозитория"
 
-#: builtin/remote.c:1232
+#: builtin/remote.c:1244
 msgid "delete refs/remotes/<name>/HEAD"
 msgstr "удалить refs/remotes/<имя>/HEAD"
 
-#: builtin/remote.c:1247
+#: builtin/remote.c:1259
 msgid "Cannot determine remote HEAD"
 msgstr "Не удалось определить внешний HEAD"
 
-#: builtin/remote.c:1249
+#: builtin/remote.c:1261
 msgid "Multiple remote HEAD branches. Please choose one explicitly with:"
 msgstr "Несколько внешних HEAD веток. Укажите явно одну из них:"
 
-#: builtin/remote.c:1259
+#: builtin/remote.c:1271
 #, c-format
 msgid "Could not delete %s"
 msgstr "Не удалось удалить %s"
 
-#: builtin/remote.c:1267
+#: builtin/remote.c:1279
 #, c-format
 msgid "Not a valid ref: %s"
 msgstr "Недопустимая ссылка: %s"
 
-#: builtin/remote.c:1269
+#: builtin/remote.c:1281
 #, c-format
 msgid "Could not setup %s"
 msgstr "Не удалось настроить %s"
 
-#: builtin/remote.c:1287
+#: builtin/remote.c:1299
 #, c-format
 msgid " %s will become dangling!"
 msgstr " %s будет висящей веткой!"
 
-#: builtin/remote.c:1288
+#: builtin/remote.c:1300
 #, c-format
 msgid " %s has become dangling!"
 msgstr " %s стала висящей веткой!"
 
-#: builtin/remote.c:1298
+#: builtin/remote.c:1310
 #, c-format
 msgid "Pruning %s"
 msgstr "Очистка %s"
 
-#: builtin/remote.c:1299
+#: builtin/remote.c:1311
 #, c-format
 msgid "URL: %s"
 msgstr "URL: %s"
 
-#: builtin/remote.c:1315
+#: builtin/remote.c:1327
 #, c-format
 msgid " * [would prune] %s"
 msgstr " * [будет удалена] %s"
 
-#: builtin/remote.c:1318
+#: builtin/remote.c:1330
 #, c-format
 msgid " * [pruned] %s"
 msgstr " * [удалена] %s"
 
-#: builtin/remote.c:1363
+#: builtin/remote.c:1375
 msgid "prune remotes after fetching"
 msgstr "почистить внешние репозитории после извлечения"
 
-#: builtin/remote.c:1426 builtin/remote.c:1480 builtin/remote.c:1548
+#: builtin/remote.c:1438 builtin/remote.c:1492 builtin/remote.c:1560
 #, c-format
 msgid "No such remote '%s'"
 msgstr "Нет такого внешнего репозитория «%s»"
 
-#: builtin/remote.c:1442
+#: builtin/remote.c:1454
 msgid "add branch"
 msgstr "добавить ветку"
 
-#: builtin/remote.c:1449
+#: builtin/remote.c:1461
 msgid "no remote specified"
 msgstr "не указан внешний репозиторий"
 
-#: builtin/remote.c:1466
+#: builtin/remote.c:1478
 msgid "query push URLs rather than fetch URLs"
 msgstr "запросить URL отправки, вместо URL извлечения"
 
-#: builtin/remote.c:1468
+#: builtin/remote.c:1480
 msgid "return all URLs"
 msgstr "вернуть все URL"
 
-#: builtin/remote.c:1496
+#: builtin/remote.c:1508
 #, c-format
 msgid "no URLs configured for remote '%s'"
 msgstr "URL не настроены для внешнего репозитория «%s»"
 
-#: builtin/remote.c:1522
+#: builtin/remote.c:1534
 msgid "manipulate push URLs"
 msgstr "управление URL отправки"
 
-#: builtin/remote.c:1524
+#: builtin/remote.c:1536
 msgid "add URL"
 msgstr "добавить URL"
 
-#: builtin/remote.c:1526
+#: builtin/remote.c:1538
 msgid "delete URLs"
 msgstr "удалить URL"
 
-#: builtin/remote.c:1533
+#: builtin/remote.c:1545
 msgid "--add --delete doesn't make sense"
 msgstr "--add нельзя использовать одновременно с --delete"
 
-#: builtin/remote.c:1572
+#: builtin/remote.c:1584
 #, c-format
 msgid "Invalid old URL pattern: %s"
 msgstr "Неправильный шаблон старого URL: %s"
 
-#: builtin/remote.c:1580
+#: builtin/remote.c:1592
 #, c-format
 msgid "No such URL found: %s"
 msgstr "Не найдены совпадения URL: %s"
 
-#: builtin/remote.c:1582
+#: builtin/remote.c:1594
 msgid "Will not delete all non-push URLs"
 msgstr "Нельзя удалить все URL не-отправки"
 
-#: builtin/remote.c:1598
+#: builtin/remote.c:1610
 msgid "be verbose; must be placed before a subcommand"
 msgstr "быть многословнее; должно стоять перед подкомандой"
 
-#: builtin/remote.c:1629
+#: builtin/remote.c:1641
 #, c-format
 msgid "Unknown subcommand: %s"
 msgstr "Неизвестная подкоманда: %s"
 
-#: builtin/repack.c:18
+#: builtin/repack.c:22
 msgid "git repack [<options>]"
 msgstr "git repack [<опции>]"
 
-#: builtin/repack.c:23
+#: builtin/repack.c:27
 msgid ""
 "Incremental repacks are incompatible with bitmap indexes.  Use\n"
 "--no-write-bitmap-index or disable the pack.writebitmaps configuration."
 msgstr "Инкрементальные перепаковки не совместимы с индексами в битовых картах.  Используйте опцию --no-write-bitmap-index или отключите параметр конфигурации pack.writebitmaps."
 
-#: builtin/repack.c:168
+#: builtin/repack.c:200
+msgid "could not start pack-objects to repack promisor objects"
+msgstr ""
+
+#: builtin/repack.c:239 builtin/repack.c:414
+msgid "repack: Expecting full hex object ID lines only from pack-objects."
+msgstr ""
+
+#: builtin/repack.c:256
+msgid "could not finish pack-objects to repack promisor objects"
+msgstr ""
+
+#: builtin/repack.c:294
 msgid "pack everything in a single pack"
 msgstr "упаковать всё в один пакет"
 
-#: builtin/repack.c:170
+#: builtin/repack.c:296
 msgid "same as -a, and turn unreachable objects loose"
 msgstr "тоже, что и -a, но дополнительно отбросить недостижимые объекты"
 
-#: builtin/repack.c:173
+#: builtin/repack.c:299
 msgid "remove redundant packs, and run git-prune-packed"
 msgstr "удалите лишние пакеты и запустите git-prune-packed"
 
-#: builtin/repack.c:175
+#: builtin/repack.c:301
 msgid "pass --no-reuse-delta to git-pack-objects"
 msgstr "передать опцию --no-reuse-delta в git-pack-objects"
 
-#: builtin/repack.c:177
+#: builtin/repack.c:303
 msgid "pass --no-reuse-object to git-pack-objects"
 msgstr "передать опцию --no-reuse-object в git-pack-objects"
 
-#: builtin/repack.c:179
+#: builtin/repack.c:305
 msgid "do not run git-update-server-info"
 msgstr "не запускать git-update-server-info"
 
-#: builtin/repack.c:182
+#: builtin/repack.c:308
 msgid "pass --local to git-pack-objects"
 msgstr "передать опцию --local в git-pack-objects"
 
-#: builtin/repack.c:184
+#: builtin/repack.c:310
 msgid "write bitmap index"
 msgstr "запись индекса в битовых картах"
 
-#: builtin/repack.c:185
+#: builtin/repack.c:312
+msgid "pass --delta-islands to git-pack-objects"
+msgstr ""
+
+#: builtin/repack.c:313
 msgid "approxidate"
 msgstr "примерная-дата"
 
-#: builtin/repack.c:186
+#: builtin/repack.c:314
 msgid "with -A, do not loosen objects older than this"
 msgstr "с опцией -A, не отбрасывать объекты старее, чем указано"
 
-#: builtin/repack.c:188
+#: builtin/repack.c:316
 msgid "with -a, repack unreachable objects"
 msgstr "с параметром -a, перепаковать недоступные объекты"
 
-#: builtin/repack.c:190
+#: builtin/repack.c:318
 msgid "size of the window used for delta compression"
 msgstr "размер окна, используемый для компрессии дельт"
 
-#: builtin/repack.c:191 builtin/repack.c:197
+#: builtin/repack.c:319 builtin/repack.c:325
 msgid "bytes"
 msgstr "количество-байт"
 
-#: builtin/repack.c:192
+#: builtin/repack.c:320
 msgid "same as the above, but limit memory size instead of entries count"
 msgstr "тоже, что и выше, но ограничить размер памяти, а не количество записей"
 
-#: builtin/repack.c:194
+#: builtin/repack.c:322
 msgid "limits the maximum delta depth"
 msgstr "ограничение на максимальную глубину дельт"
 
-#: builtin/repack.c:196
+#: builtin/repack.c:324
 msgid "limits the maximum number of threads"
 msgstr "ограничение на максимальное количество потоков"
 
-#: builtin/repack.c:198
+#: builtin/repack.c:326
 msgid "maximum size of each packfile"
 msgstr "максимальный размер каждого из файлов пакета"
 
-#: builtin/repack.c:200
+#: builtin/repack.c:328
 msgid "repack objects in packs marked with .keep"
 msgstr "переупаковать объекты в пакеты, помеченные файлом .keep"
 
-#: builtin/repack.c:210
+#: builtin/repack.c:330
+msgid "do not repack this pack"
+msgstr ""
+
+#: builtin/repack.c:340
 msgid "cannot delete packs in a precious-objects repo"
 msgstr "нельзя удалять пакеты в precious-objects репозитории"
 
-#: builtin/repack.c:214
+#: builtin/repack.c:344
 msgid "--keep-unreachable and -A are incompatible"
 msgstr "--keep-unreachable и -A нельзя использовать одновременно"
 
-#: builtin/repack.c:406 builtin/worktree.c:146
+#: builtin/repack.c:423
+msgid "Nothing new to pack."
+msgstr ""
+
+#: builtin/repack.c:484
+#, c-format
+msgid ""
+"WARNING: Some packs in use have been renamed by\n"
+"WARNING: prefixing old- to their name, in order to\n"
+"WARNING: replace them with the new version of the\n"
+"WARNING: file.  But the operation failed, and the\n"
+"WARNING: attempt to rename them back to their\n"
+"WARNING: original names also failed.\n"
+"WARNING: Please rename them in %s manually:\n"
+msgstr ""
+
+#: builtin/repack.c:532
 #, c-format
 msgid "failed to remove '%s'"
 msgstr "сбой удаления «%s»"
 
-#: builtin/replace.c:20
+#: builtin/replace.c:22
 msgid "git replace [-f] <object> <replacement>"
 msgstr "git replace [-f] <объект> <замена>"
 
-#: builtin/replace.c:21
+#: builtin/replace.c:23
 msgid "git replace [-f] --edit <object>"
 msgstr "git replace [-f] --edit <объект>"
 
-#: builtin/replace.c:22
+#: builtin/replace.c:24
 msgid "git replace [-f] --graft <commit> [<parent>...]"
 msgstr "git replace [-f] --graft <коммит> [<родитель>…]"
 
-#: builtin/replace.c:23
+#: builtin/replace.c:25
+msgid "git replace [-f] --convert-graft-file"
+msgstr ""
+
+#: builtin/replace.c:26
 msgid "git replace -d <object>..."
 msgstr "git replace -d <объект>…"
 
-#: builtin/replace.c:24
+#: builtin/replace.c:27
 msgid "git replace [--format=<format>] [-l [<pattern>]]"
 msgstr "git replace [--format=<формат>] [-l [<шаблон>]]"
 
-#: builtin/replace.c:331 builtin/replace.c:369 builtin/replace.c:397
+#: builtin/replace.c:90
+#, c-format
+msgid ""
+"invalid replace format '%s'\n"
+"valid formats are 'short', 'medium' and 'long'"
+msgstr ""
+
+#: builtin/replace.c:125
+#, c-format
+msgid "replace ref '%s' not found"
+msgstr ""
+
+#: builtin/replace.c:141
+#, c-format
+msgid "Deleted replace ref '%s'"
+msgstr ""
+
+#: builtin/replace.c:153
+#, c-format
+msgid "'%s' is not a valid ref name"
+msgstr ""
+
+#: builtin/replace.c:158
+#, c-format
+msgid "replace ref '%s' already exists"
+msgstr ""
+
+#: builtin/replace.c:178
+#, c-format
+msgid ""
+"Objects must be of the same type.\n"
+"'%s' points to a replaced object of type '%s'\n"
+"while '%s' points to a replacement object of type '%s'."
+msgstr ""
+
+#: builtin/replace.c:229
+#, c-format
+msgid "unable to open %s for writing"
+msgstr ""
+
+#: builtin/replace.c:242
+msgid "cat-file reported failure"
+msgstr ""
+
+#: builtin/replace.c:258
+#, c-format
+msgid "unable to open %s for reading"
+msgstr ""
+
+#: builtin/replace.c:272
+msgid "unable to spawn mktree"
+msgstr ""
+
+#: builtin/replace.c:276
+msgid "unable to read from mktree"
+msgstr ""
+
+#: builtin/replace.c:285
+msgid "mktree reported failure"
+msgstr ""
+
+#: builtin/replace.c:289
+msgid "mktree did not return an object name"
+msgstr ""
+
+#: builtin/replace.c:298
+#, c-format
+msgid "unable to fstat %s"
+msgstr ""
+
+#: builtin/replace.c:303
+msgid "unable to write object to database"
+msgstr ""
+
+#: builtin/replace.c:322 builtin/replace.c:377 builtin/replace.c:422
+#: builtin/replace.c:452
+#, c-format
+msgid "not a valid object name: '%s'"
+msgstr ""
+
+#: builtin/replace.c:326
+#, c-format
+msgid "unable to get object type for %s"
+msgstr ""
+
+#: builtin/replace.c:342
+msgid "editing object file failed"
+msgstr ""
+
+#: builtin/replace.c:351
+#, c-format
+msgid "new object is the same as the old one: '%s'"
+msgstr ""
+
+#: builtin/replace.c:383
 #, c-format
-msgid "Not a valid object name: '%s'"
-msgstr "Недопустимое имя объекта: «%s»"
+msgid "could not parse %s as a commit"
+msgstr ""
 
-#: builtin/replace.c:361
+#: builtin/replace.c:414
 #, c-format
 msgid "bad mergetag in commit '%s'"
 msgstr "плохая метка слияния в коммите «%s»"
 
-#: builtin/replace.c:363
+#: builtin/replace.c:416
 #, c-format
 msgid "malformed mergetag in commit '%s'"
 msgstr "повреждённая метка слияния в коммите «%s»"
 
-#: builtin/replace.c:374
+#: builtin/replace.c:428
 #, c-format
 msgid ""
 "original commit '%s' contains mergetag '%s' that is discarded; use --edit "
 "instead of --graft"
 msgstr "оригинальный коммит «%s» содержит метку слияния «%s», которая была отброшена; используйте --edit вместо --graft"
 
-#: builtin/replace.c:407
+#: builtin/replace.c:467
 #, c-format
-msgid "the original commit '%s' has a gpg signature."
-msgstr "оригинальный коммит «%s» содержит подпись gpg."
+msgid "the original commit '%s' has a gpg signature"
+msgstr ""
 
-#: builtin/replace.c:408
+#: builtin/replace.c:468
 msgid "the signature will be removed in the replacement commit!"
 msgstr "подпись будет удалена в замененном коммите!"
 
-#: builtin/replace.c:414
+#: builtin/replace.c:478
 #, c-format
 msgid "could not write replacement commit for: '%s'"
 msgstr "не удалось записать замену для коммита: «%s»"
 
-#: builtin/replace.c:438
+#: builtin/replace.c:486
+#, c-format
+msgid "graft for '%s' unnecessary"
+msgstr ""
+
+#: builtin/replace.c:490
+#, c-format
+msgid "new commit is the same as the old one: '%s'"
+msgstr ""
+
+#: builtin/replace.c:525
+#, c-format
+msgid ""
+"could not convert the following graft(s):\n"
+"%s"
+msgstr ""
+
+#: builtin/replace.c:546
 msgid "list replace refs"
 msgstr "вывести список заменяемых ссылок"
 
-#: builtin/replace.c:439
+#: builtin/replace.c:547
 msgid "delete replace refs"
 msgstr "удаление заменяемых ссылок"
 
-#: builtin/replace.c:440
+#: builtin/replace.c:548
 msgid "edit existing object"
 msgstr "изменение существующего объекта"
 
-#: builtin/replace.c:441
+#: builtin/replace.c:549
 msgid "change a commit's parents"
 msgstr "изменение родителя коммита"
 
-#: builtin/replace.c:442
+#: builtin/replace.c:550
+msgid "convert existing graft file"
+msgstr ""
+
+#: builtin/replace.c:551
 msgid "replace the ref if it exists"
 msgstr "замена ссылки, если она существует"
 
-#: builtin/replace.c:443
+#: builtin/replace.c:553
 msgid "do not pretty-print contents for --edit"
 msgstr "не делать структурированный вывод содержимого для --edit"
 
-#: builtin/replace.c:444
+#: builtin/replace.c:554
 msgid "use this format"
 msgstr "использовать этот формат"
 
+#: builtin/replace.c:567
+msgid "--format cannot be used when not listing"
+msgstr ""
+
+#: builtin/replace.c:575
+msgid "-f only makes sense when writing a replacement"
+msgstr ""
+
+#: builtin/replace.c:579
+msgid "--raw only makes sense with --edit"
+msgstr ""
+
+#: builtin/replace.c:585
+msgid "-d needs at least one argument"
+msgstr ""
+
+#: builtin/replace.c:591
+msgid "bad number of arguments"
+msgstr ""
+
+#: builtin/replace.c:597
+msgid "-e needs exactly one argument"
+msgstr ""
+
+#: builtin/replace.c:603
+msgid "-g needs at least one argument"
+msgstr ""
+
+#: builtin/replace.c:609
+msgid "--convert-graft-file takes no argument"
+msgstr ""
+
+#: builtin/replace.c:615
+msgid "only one pattern can be given with -l"
+msgstr ""
+
 #: builtin/rerere.c:13
 msgid "git rerere [clear | forget <path>... | status | remaining | diff | gc]"
 msgstr "git rerere [clear | forget <путь>… | status | remaining | diff | gc]"
 
-#: builtin/rerere.c:59
+#: builtin/rerere.c:60
 msgid "register clean resolutions in index"
 msgstr "записать чистые разрешения конфликтов в индекс"
 
-#: builtin/reset.c:29
+#: builtin/rerere.c:79
+msgid "'git rerere forget' without paths is deprecated"
+msgstr ""
+
+#: builtin/rerere.c:113
+#, c-format
+msgid "unable to generate diff for '%s'"
+msgstr ""
+
+#: builtin/reset.c:32
 msgid ""
 "git reset [--mixed | --soft | --hard | --merge | --keep] [-q] [<commit>]"
 msgstr "git reset [--mixed | --soft | --hard | --merge | --keep] [-q] [<коммит>]"
 
-#: builtin/reset.c:30
+#: builtin/reset.c:33
 msgid "git reset [-q] [<tree-ish>] [--] <paths>..."
 msgstr "git reset [-q] [<указатель-дерева>] [--] <пути>…"
 
-#: builtin/reset.c:31
+#: builtin/reset.c:34
 msgid "git reset --patch [<tree-ish>] [--] [<paths>...]"
 msgstr "git reset --patch [<указатель-дерева>] [--] [<пути>…]"
 
-#: builtin/reset.c:37
+#: builtin/reset.c:40
 msgid "mixed"
 msgstr "смешанный"
 
-#: builtin/reset.c:37
+#: builtin/reset.c:40
 msgid "soft"
 msgstr "мягкий"
 
-#: builtin/reset.c:37
+#: builtin/reset.c:40
 msgid "hard"
 msgstr "жесткий"
 
-#: builtin/reset.c:37
+#: builtin/reset.c:40
 msgid "merge"
 msgstr "слиянием"
 
-#: builtin/reset.c:37
+#: builtin/reset.c:40
 msgid "keep"
 msgstr "оставлением"
 
-#: builtin/reset.c:78
+#: builtin/reset.c:81
 msgid "You do not have a valid HEAD."
 msgstr "У вас нет верного HEAD."
 
-#: builtin/reset.c:80
+#: builtin/reset.c:83
 msgid "Failed to find tree of HEAD."
 msgstr "Не удалось найти дерево у HEAD."
 
-#: builtin/reset.c:86
+#: builtin/reset.c:89
 #, c-format
 msgid "Failed to find tree of %s."
 msgstr "Не удалось найти дерево у %s."
 
-#: builtin/reset.c:113
-#, c-format
-msgid "HEAD is now at %s"
-msgstr "HEAD сейчас на %s"
-
-#: builtin/reset.c:197
+#: builtin/reset.c:193
 #, c-format
 msgid "Cannot do a %s reset in the middle of a merge."
 msgstr "Нельзя выполнить сброс в режиме «%s» во время слияния."
 
-#: builtin/reset.c:297
+#: builtin/reset.c:293 builtin/stash.c:514 builtin/stash.c:589
+#: builtin/stash.c:613
 msgid "be quiet, only report errors"
 msgstr "тихий режим, выводить только ошибки"
 
-#: builtin/reset.c:299
+#: builtin/reset.c:295
 msgid "reset HEAD and index"
 msgstr "сбросить HEAD и индекс"
 
-#: builtin/reset.c:300
+#: builtin/reset.c:296
 msgid "reset only HEAD"
 msgstr "сбросить только HEAD"
 
-#: builtin/reset.c:302 builtin/reset.c:304
+#: builtin/reset.c:298 builtin/reset.c:300
 msgid "reset HEAD, index and working tree"
 msgstr "сбросить HEAD, индекс и рабочий каталог"
 
-#: builtin/reset.c:306
+#: builtin/reset.c:302
 msgid "reset HEAD but keep local changes"
 msgstr "сбросить HEAD, но оставить локальные изменения"
 
-#: builtin/reset.c:312
+#: builtin/reset.c:308
 msgid "record only the fact that removed paths will be added later"
 msgstr "записать только факт того, что удаленные пути будут добавлены позже"
 
-#: builtin/reset.c:329
+#: builtin/reset.c:326
 #, c-format
 msgid "Failed to resolve '%s' as a valid revision."
 msgstr "Не удалось распознать «%s» как действительную редакцию."
 
-#: builtin/reset.c:337
+#: builtin/reset.c:334
 #, c-format
 msgid "Failed to resolve '%s' as a valid tree."
 msgstr "Не удалось распознать «%s» как действительное дерево."
 
-#: builtin/reset.c:346
+#: builtin/reset.c:343
 msgid "--patch is incompatible with --{hard,mixed,soft}"
 msgstr "--patch нельзя использовать одновременно с --{hard,mixed,soft}"
 
-#: builtin/reset.c:355
+#: builtin/reset.c:353
 msgid "--mixed with paths is deprecated; use 'git reset -- <paths>' instead."
 msgstr "использование опции --mixed с путями устарело; используйте «git reset -- <пути>» instead."
 
-#: builtin/reset.c:357
+#: builtin/reset.c:355
 #, c-format
 msgid "Cannot do %s reset with paths."
 msgstr "Нельзя выполнить сброс в режиме «%s» вместе с указанием пути."
 
-#: builtin/reset.c:367
+#: builtin/reset.c:370
 #, c-format
 msgid "%s reset is not allowed in a bare repository"
 msgstr "сброс «%s» разрешен только с голым репозиторием"
 
-#: builtin/reset.c:371
+#: builtin/reset.c:374
 msgid "-N can only be used with --mixed"
 msgstr "-N можно использовать вместе с --mixed"
 
-#: builtin/reset.c:388
+#: builtin/reset.c:395
 msgid "Unstaged changes after reset:"
 msgstr "Непроиндексированные изменения после сброса:"
 
-#: builtin/reset.c:394
+#: builtin/reset.c:398
+#, c-format
+msgid ""
+"\n"
+"It took %.2f seconds to enumerate unstaged changes after reset.  You can\n"
+"use '--quiet' to avoid this.  Set the config setting reset.quiet to true\n"
+"to make this the default.\n"
+msgstr ""
+
+#: builtin/reset.c:408
 #, c-format
 msgid "Could not reset index file to revision '%s'."
 msgstr "Не удалось сбросить файл индекса на редакцию «%s»."
 
-#: builtin/reset.c:398
+#: builtin/reset.c:412
 msgid "Could not write new index file."
 msgstr "Не удалось записать новый файл индекса."
 
-#: builtin/rev-list.c:399
+#: builtin/rev-list.c:405
+msgid "cannot combine --exclude-promisor-objects and --missing"
+msgstr ""
+
+#: builtin/rev-list.c:466
 msgid "object filtering requires --objects"
 msgstr "фильтрация объектов требует указания параметра --objects"
 
-#: builtin/rev-list.c:402
+#: builtin/rev-list.c:469
 #, c-format
 msgid "invalid sparse value '%s'"
 msgstr "недопустимое частичное значение «%s»"
 
-#: builtin/rev-list.c:442
+#: builtin/rev-list.c:510
 msgid "rev-list does not support display of notes"
 msgstr "rev-list не поддерживает отображение заметок"
 
-#: builtin/rev-list.c:445
+#: builtin/rev-list.c:513
 msgid "cannot combine --use-bitmap-index with object filtering"
 msgstr "нельзя использовать --use-bitmap-index одновременно с фильтрацией объектов"
 
-#: builtin/rev-parse.c:402
+#: builtin/rev-parse.c:408
 msgid "git rev-parse --parseopt [<options>] -- [<args>...]"
 msgstr "git rev-parse --parseopt [<опции>] -- [<аргументы>…]"
 
-#: builtin/rev-parse.c:407
+#: builtin/rev-parse.c:413
 msgid "keep the `--` passed as an arg"
 msgstr "передавать далее «--» как аргумент"
 
-#: builtin/rev-parse.c:409
+#: builtin/rev-parse.c:415
 msgid "stop parsing after the first non-option argument"
 msgstr "остановить разбор после первого аргумента не являющегося опцией"
 
-#: builtin/rev-parse.c:412
+#: builtin/rev-parse.c:418
 msgid "output in stuck long form"
 msgstr "выводить аргументы в длинном формате"
 
-#: builtin/rev-parse.c:545
+#: builtin/rev-parse.c:551
 msgid ""
 "git rev-parse --parseopt [<options>] -- [<args>...]\n"
 "   or: git rev-parse --sq-quote [<arg>...]\n"
@@ -12264,96 +17400,93 @@ msgid ""
 "Run \"git rev-parse --parseopt -h\" for more information on the first usage."
 msgstr "git rev-parse --parseopt [<опции>] -- [<аргументы>…]\n   or: git rev-parse --sq-quote [<аргумент>…]\n   or: git rev-parse [<опции>] [<аргумент>…]\n\nЗапустите команду «git rev-parse --parseopt -h» для получения подробной информации о первом использовании."
 
-#: builtin/revert.c:23
+#: builtin/revert.c:24
 msgid "git revert [<options>] <commit-ish>..."
 msgstr "git revert [<опции>] <указатель-коммита>…"
 
-#: builtin/revert.c:24
+#: builtin/revert.c:25
 msgid "git revert <subcommand>"
 msgstr "git revert <подкоманда>"
 
-#: builtin/revert.c:29
+#: builtin/revert.c:30
 msgid "git cherry-pick [<options>] <commit-ish>..."
 msgstr "git cherry-pick [<опции>] <указатель-коммита>…"
 
-#: builtin/revert.c:30
+#: builtin/revert.c:31
 msgid "git cherry-pick <subcommand>"
 msgstr "git cherry-pick <подкоманда>"
 
-#: builtin/revert.c:90
+#: builtin/revert.c:72
+#, c-format
+msgid "option `%s' expects a number greater than zero"
+msgstr ""
+
+#: builtin/revert.c:92
 #, c-format
 msgid "%s: %s cannot be used with %s"
 msgstr "%s: %s нельзя использовать одновременно с %s"
 
-#: builtin/revert.c:99
+#: builtin/revert.c:102
 msgid "end revert or cherry-pick sequence"
 msgstr "конец последовательности копирования или обращения изменений коммитов"
 
-#: builtin/revert.c:100
+#: builtin/revert.c:103
 msgid "resume revert or cherry-pick sequence"
 msgstr "продолжить последовательность копирования или обращения изменений коммитов"
 
-#: builtin/revert.c:101
+#: builtin/revert.c:104
 msgid "cancel revert or cherry-pick sequence"
 msgstr "отмена последовательности копирования или обращения изменений коммитов"
 
-#: builtin/revert.c:102
+#: builtin/revert.c:106
 msgid "don't automatically commit"
 msgstr "не коммитить автоматически"
 
-#: builtin/revert.c:103
+#: builtin/revert.c:107
 msgid "edit the commit message"
 msgstr "изменить сообщение коммита"
 
-#: builtin/revert.c:106
+#: builtin/revert.c:110
 msgid "parent-number"
 msgstr "номер-родителя"
 
-#: builtin/revert.c:107
+#: builtin/revert.c:111
 msgid "select mainline parent"
 msgstr "выбор основного родителя"
 
-#: builtin/revert.c:109
+#: builtin/revert.c:113
 msgid "merge strategy"
 msgstr "стратегия слияния"
 
-#: builtin/revert.c:110
-msgid "option"
-msgstr "опция"
-
-#: builtin/revert.c:111
+#: builtin/revert.c:115
 msgid "option for merge strategy"
 msgstr "опция для стратегии слияния"
 
-#: builtin/revert.c:120
+#: builtin/revert.c:124
 msgid "append commit name"
 msgstr "добавить имя коммита"
 
-#: builtin/revert.c:122
+#: builtin/revert.c:126
 msgid "preserve initially empty commits"
 msgstr "сохранить изначально пустые коммиты"
 
-#: builtin/revert.c:123
-msgid "allow commits with empty messages"
-msgstr "разрешить коммиты с пустыми сообщениями"
-
-#: builtin/revert.c:124
+#: builtin/revert.c:128
 msgid "keep redundant, empty commits"
 msgstr "оставить избыточные, пустые коммиты"
 
-#: builtin/revert.c:214
+#: builtin/revert.c:227
 msgid "revert failed"
 msgstr "сбой обращения изменений коммита"
 
-#: builtin/revert.c:227
+#: builtin/revert.c:240
 msgid "cherry-pick failed"
 msgstr "сбой при копировании коммита"
 
-#: builtin/rm.c:18
+#: builtin/rm.c:19
 msgid "git rm [<options>] [--] <file>..."
 msgstr "git rm [<опции>] [--] <файл>…"
 
-#: builtin/rm.c:206
+#: builtin/rm.c:207
 msgid ""
 "the following file has staged content different from both the\n"
 "file and the HEAD:"
@@ -12365,13 +17498,13 @@ msgstr[1] "следующие файлы
 msgstr[2] "следующие файлы содержат проиндексированные изменения отличающиеся и от файла, и от HEAD:"
 msgstr[3] "следующие файлы содержат проиндексированные изменения отличающиеся и от файла, и от HEAD:"
 
-#: builtin/rm.c:211
+#: builtin/rm.c:212
 msgid ""
 "\n"
 "(use -f to force removal)"
 msgstr "\n(используйте опцию «-f» для принудительного удаления)"
 
-#: builtin/rm.c:215
+#: builtin/rm.c:216
 msgid "the following file has changes staged in the index:"
 msgid_plural "the following files have changes staged in the index:"
 msgstr[0] "следующие файлы содержат проиндексированные изменения в индексе:"
@@ -12379,13 +17512,13 @@ msgstr[1] "следующие файлы
 msgstr[2] "следующие файлы содержат проиндексированные изменения в индексе:"
 msgstr[3] "следующие файлы содержат проиндексированные изменения в индексе:"
 
-#: builtin/rm.c:219 builtin/rm.c:228
+#: builtin/rm.c:220 builtin/rm.c:229
 msgid ""
 "\n"
 "(use --cached to keep the file, or -f to force removal)"
 msgstr "\n(используйте опцию «--cached» для оставления файла, или «-f» для принудительного удаления)"
 
-#: builtin/rm.c:225
+#: builtin/rm.c:226
 msgid "the following file has local modifications:"
 msgid_plural "the following files have local modifications:"
 msgstr[0] "следующие файлы содержат локальные изменения:"
@@ -12393,26 +17526,30 @@ msgstr[1] "следующие файлы
 msgstr[2] "следующие файлы содержат локальные изменения:"
 msgstr[3] "следующие файлы содержат локальные изменения:"
 
-#: builtin/rm.c:243
+#: builtin/rm.c:242
 msgid "do not list removed files"
 msgstr "не выводить список удаленных файлов"
 
-#: builtin/rm.c:244
+#: builtin/rm.c:243
 msgid "only remove from the index"
 msgstr "удалить только из индекса"
 
-#: builtin/rm.c:245
+#: builtin/rm.c:244
 msgid "override the up-to-date check"
 msgstr "пропустить проверку актуальности"
 
-#: builtin/rm.c:246
+#: builtin/rm.c:245
 msgid "allow recursive removal"
 msgstr "разрешить рекурсивное удаление"
 
-#: builtin/rm.c:248
+#: builtin/rm.c:247
 msgid "exit with a zero status even if nothing matched"
 msgstr "выход с нулевым кодом возврата, даже если ничего не найдено"
 
+#: builtin/rm.c:289
+msgid "please stage your changes to .gitmodules or stash them to proceed"
+msgstr ""
+
 #: builtin/rm.c:307
 #, c-format
 msgid "not removing '%s' recursively without -r"
@@ -12423,62 +17560,65 @@ msgstr "не удаляю рекурси
 msgid "git rm: unable to remove %s"
 msgstr "git rm: не удалось удалить %s"
 
-#: builtin/rm.c:369
-#, c-format
-msgid "could not remove '%s'"
-msgstr "не удалось удалить «%s»"
-
-#: builtin/send-pack.c:19
+#: builtin/send-pack.c:20
 msgid ""
 "git send-pack [--all | --mirror] [--dry-run] [--force] [--receive-pack=<git-receive-pack>] [--verbose] [--thin] [--atomic] [<host>:]<directory> [<ref>...]\n"
 "  --all and explicit <ref> specification are mutually exclusive."
 msgstr "git send-pack [--all | --mirror] [--dry-run] [--force] [--receive-pack=<git-receive-pack>] [--verbose] [--thin] [--atomic] [<сервер>:]<каталог> [<ссылка>…]\n  --all и явный спецификатор <ссылки> взаимно исключающие."
 
-#: builtin/send-pack.c:162
+#: builtin/send-pack.c:163
 msgid "remote name"
 msgstr "имя внешнего репозитория"
 
-#: builtin/send-pack.c:176
+#: builtin/send-pack.c:177
 msgid "use stateless RPC protocol"
 msgstr "протокол без сохранения состояния для RPC"
 
-#: builtin/send-pack.c:177
+#: builtin/send-pack.c:178
 msgid "read refs from stdin"
 msgstr "прочитать ссылки из стандартного ввода"
 
-#: builtin/send-pack.c:178
+#: builtin/send-pack.c:179
 msgid "print status from remote helper"
 msgstr "вывести статус от скрипта внешнего сервера"
 
 #: builtin/shortlog.c:14
-msgid "git shortlog [<options>] [<revision-range>] [[--] [<path>...]]"
-msgstr "git shortlog [<опции>] [<диапазон-редакций>] [[--] [<путь>…]]"
+msgid "git shortlog [<options>] [<revision-range>] [[--] <path>...]"
+msgstr "git shortlog [<опции>] [<диапазон-редакций>] [[--] <путь>…]"
 
-#: builtin/shortlog.c:263
+#: builtin/shortlog.c:15
+msgid "git log --pretty=short | git shortlog [<options>]"
+msgstr "git log --pretty=short | git shortlog [<опции>]"
+
+#: builtin/shortlog.c:264
 msgid "Group by committer rather than author"
 msgstr "Группировать по коммитеру, а не по автору"
 
-#: builtin/shortlog.c:265
+#: builtin/shortlog.c:266
 msgid "sort output according to the number of commits per author"
 msgstr "отсортировать вывод по количеству коммитов у автора"
 
-#: builtin/shortlog.c:267
+#: builtin/shortlog.c:268
 msgid "Suppress commit descriptions, only provides commit count"
 msgstr "Не выводить описания коммитов, а только их количество"
 
-#: builtin/shortlog.c:269
+#: builtin/shortlog.c:270
 msgid "Show the email address of each author"
 msgstr "Показать почту каждого из авторов"
 
-#: builtin/shortlog.c:270
-msgid "w[,i1[,i2]]"
-msgstr "w[,i1[,i2]]"
-
 #: builtin/shortlog.c:271
+msgid "<w>[,<i1>[,<i2>]]"
+msgstr "<w>[,<i1>[,<i2>]]"
+
+#: builtin/shortlog.c:272
 msgid "Linewrap output"
 msgstr "Перенос строк на выводе"
 
-#: builtin/show-branch.c:12
+#: builtin/shortlog.c:301
+msgid "too many arguments given outside repository"
+msgstr ""
+
+#: builtin/show-branch.c:13
 msgid ""
 "git show-branch [-a | --all] [-r | --remotes] [--topo-order | --date-order]\n"
 "\t\t[--current] [--color[=<when>] | --no-color] [--sparse]\n"
@@ -12486,11 +17626,11 @@ msgid ""
 "\t\t[--no-name | --sha1-name] [--topics] [(<rev> | <glob>)...]"
 msgstr "git show-branch [-a | --all] [-r | --remotes] [--topo-order | --date-order]\n\t\t[--current] [--color[=<когда>] | --no-color] [--sparse]\n\t\t[--more=<n> | --list | --independent | --merge-base]\n\t\t[--no-name | --sha1-name] [--topics] [(<редакция> | <шаблон>)…]"
 
-#: builtin/show-branch.c:16
+#: builtin/show-branch.c:17
 msgid "git show-branch (-g | --reflog)[=<n>[,<base>]] [--list] [<ref>]"
 msgstr "git show-branch (-g | --reflog)[=<n>[,<база>]] [--list] [<ссылка>]"
 
-#: builtin/show-branch.c:376
+#: builtin/show-branch.c:395
 #, c-format
 msgid "ignoring %s; cannot handle more than %d ref"
 msgid_plural "ignoring %s; cannot handle more than %d refs"
@@ -12499,90 +17639,90 @@ msgstr[1] "игнорирование %s
 msgstr[2] "игнорирование %s; невозможно обработать больше %d ссылок"
 msgstr[3] "игнорирование %s; невозможно обработать больше %d ссылки"
 
-#: builtin/show-branch.c:530
+#: builtin/show-branch.c:549
 #, c-format
 msgid "no matching refs with %s"
 msgstr "нет совпадающих записей с %s"
 
-#: builtin/show-branch.c:626
+#: builtin/show-branch.c:646
 msgid "show remote-tracking and local branches"
 msgstr "показать список и отслеживаемых внешних и локальных веток"
 
-#: builtin/show-branch.c:628
+#: builtin/show-branch.c:648
 msgid "show remote-tracking branches"
 msgstr "показать список отслеживаемых внешних веток"
 
-#: builtin/show-branch.c:630
+#: builtin/show-branch.c:650
 msgid "color '*!+-' corresponding to the branch"
 msgstr "окрашивать «*!+-» в соответствии с веткой"
 
-#: builtin/show-branch.c:632
+#: builtin/show-branch.c:652
 msgid "show <n> more commits after the common ancestor"
 msgstr "показать <n> коммитов после общего предка"
 
-#: builtin/show-branch.c:634
+#: builtin/show-branch.c:654
 msgid "synonym to more=-1"
 msgstr "синоним для more=-1"
 
-#: builtin/show-branch.c:635
+#: builtin/show-branch.c:655
 msgid "suppress naming strings"
 msgstr "не выводить именованные строки"
 
-#: builtin/show-branch.c:637
+#: builtin/show-branch.c:657
 msgid "include the current branch"
 msgstr "включить в вывод текущую ветку"
 
-#: builtin/show-branch.c:639
+#: builtin/show-branch.c:659
 msgid "name commits with their object names"
 msgstr "именовать коммиты их именами объектов"
 
-#: builtin/show-branch.c:641
+#: builtin/show-branch.c:661
 msgid "show possible merge bases"
 msgstr "вывести возможные базы слияния"
 
-#: builtin/show-branch.c:643
+#: builtin/show-branch.c:663
 msgid "show refs unreachable from any other ref"
 msgstr "вывести ссылки, недоступные из любых других ссылок"
 
-#: builtin/show-branch.c:645
+#: builtin/show-branch.c:665
 msgid "show commits in topological order"
 msgstr "вывести коммиты в топологическом порядке"
 
-#: builtin/show-branch.c:648
+#: builtin/show-branch.c:668
 msgid "show only commits not on the first branch"
 msgstr "вывести только коммиты, отсутствующие в первой ветке"
 
-#: builtin/show-branch.c:650
+#: builtin/show-branch.c:670
 msgid "show merges reachable from only one tip"
 msgstr "вывести слияния, достижимые только из одной из верхушек"
 
-#: builtin/show-branch.c:652
+#: builtin/show-branch.c:672
 msgid "topologically sort, maintaining date order where possible"
 msgstr "топологическая сортировка, с сохранением порядка дат, если возможно"
 
-#: builtin/show-branch.c:655
+#: builtin/show-branch.c:675
 msgid "<n>[,<base>]"
 msgstr "<n>[,<база>]"
 
-#: builtin/show-branch.c:656
+#: builtin/show-branch.c:676
 msgid "show <n> most recent ref-log entries starting at base"
 msgstr "показать <n> последних записей в журнале ссылок, начиная с базы"
 
-#: builtin/show-branch.c:690
+#: builtin/show-branch.c:712
 msgid ""
 "--reflog is incompatible with --all, --remotes, --independent or --merge-"
 "base"
 msgstr "--reflog несовместимо с --all, --remotes, --independent и --merge-base"
 
-#: builtin/show-branch.c:714
+#: builtin/show-branch.c:736
 msgid "no branches given, and HEAD is not valid"
 msgstr "не указаны ветки и HEAD не действительный"
 
-#: builtin/show-branch.c:717
+#: builtin/show-branch.c:739
 msgid "--reflog option needs one branch name"
 msgstr "параметр --reflog требует указания имени одной ветки"
 
-#: builtin/show-branch.c:720
+#: builtin/show-branch.c:742
 #, c-format
 msgid "only %d entry can be shown at one time."
 msgid_plural "only %d entries can be shown at one time."
@@ -12591,12 +17731,12 @@ msgstr[1] "только %d записи
 msgstr[2] "только %d записей могут быть показаны одновременно."
 msgstr[3] "только %d записи могут быть показаны одновременно."
 
-#: builtin/show-branch.c:724
+#: builtin/show-branch.c:746
 #, c-format
 msgid "no such ref %s"
 msgstr "нет такой ссылки %s"
 
-#: builtin/show-branch.c:808
+#: builtin/show-branch.c:832
 #, c-format
 msgid "cannot handle more than %d rev."
 msgid_plural "cannot handle more than %d revs."
@@ -12605,58 +17745,279 @@ msgstr[1] "невозможно обра
 msgstr[2] "невозможно обработать больше %d редакций."
 msgstr[3] "невозможно обработать больше %d редакции."
 
-#: builtin/show-branch.c:812
+#: builtin/show-branch.c:836
 #, c-format
 msgid "'%s' is not a valid ref."
 msgstr "«%s» не является допустимой ссылкой на коммит."
 
-#: builtin/show-branch.c:815
+#: builtin/show-branch.c:839
 #, c-format
 msgid "cannot find commit %s (%s)"
 msgstr "не удалось найти коммит %s (%s)"
 
-#: builtin/show-ref.c:10
+#: builtin/show-ref.c:12
 msgid ""
 "git show-ref [-q | --quiet] [--verify] [--head] [-d | --dereference] [-s | "
 "--hash[=<n>]] [--abbrev[=<n>]] [--tags] [--heads] [--] [<pattern>...]"
 msgstr "git show-ref [-q | --quiet] [--verify] [--head] [-d | --dereference] [-s | --hash[=<n>]] [--abbrev[=<n>]] [--tags] [--heads] [--] [<шаблон>…]"
 
-#: builtin/show-ref.c:11
+#: builtin/show-ref.c:13
 msgid "git show-ref --exclude-existing[=<pattern>]"
 msgstr "git show-ref --exclude-existing[=<шаблон>]"
 
-#: builtin/show-ref.c:159
+#: builtin/show-ref.c:162
 msgid "only show tags (can be combined with heads)"
 msgstr "вывести только метки (можно использовать одновременно с --heads)"
 
-#: builtin/show-ref.c:160
+#: builtin/show-ref.c:163
 msgid "only show heads (can be combined with tags)"
 msgstr "вывести только головы (можно использовать одновременно с --tags)"
 
-#: builtin/show-ref.c:161
+#: builtin/show-ref.c:164
 msgid "stricter reference checking, requires exact ref path"
 msgstr "более строгая проверка ссылок, требует точный путь ссылки"
 
-#: builtin/show-ref.c:164 builtin/show-ref.c:166
+#: builtin/show-ref.c:167 builtin/show-ref.c:169
 msgid "show the HEAD reference, even if it would be filtered out"
 msgstr "вывести ссылку HEAD, даже если она будет отфильтрована"
 
-#: builtin/show-ref.c:168
+#: builtin/show-ref.c:171
 msgid "dereference tags into object IDs"
 msgstr "разыменовать метки в идентификаторы объектов"
 
-#: builtin/show-ref.c:170
+#: builtin/show-ref.c:173
 msgid "only show SHA1 hash using <n> digits"
-msgstr "использовать <n> цифр для вывода SHA-1"
+msgstr "использовать <n> символов для вывода SHA-1 хеш-суммы"
 
-#: builtin/show-ref.c:174
+#: builtin/show-ref.c:177
 msgid "do not print results to stdout (useful with --verify)"
 msgstr "не печатать результат на стандартный вывод (полезно с опцией «--verify»)"
 
-#: builtin/show-ref.c:176
+#: builtin/show-ref.c:179
 msgid "show refs from stdin that aren't in local repository"
 msgstr "вывести ссылки со стандартного ввода, которых нет в локальном репозитории"
 
+#: builtin/stash.c:22 builtin/stash.c:37
+msgid "git stash list [<options>]"
+msgstr "git stash list [<опции>]"
+
+#: builtin/stash.c:23 builtin/stash.c:42
+msgid "git stash show [<options>] [<stash>]"
+msgstr "git stash show [<опциии>] [<спрятанные-изменения>]"
+
+#: builtin/stash.c:24 builtin/stash.c:47
+msgid "git stash drop [-q|--quiet] [<stash>]"
+msgstr "git stash drop [-q|--quiet] [<спрятанные-изменения>]"
+
+#: builtin/stash.c:25
+msgid "git stash ( pop | apply ) [--index] [-q|--quiet] [<stash>]"
+msgstr "git stash ( pop | apply ) [--index] [-q|--quiet] [<спрятанные-изменения>]"
+
+#: builtin/stash.c:26 builtin/stash.c:62
+msgid "git stash branch <branchname> [<stash>]"
+msgstr "git stash branch <имя-ветки> [<спрятанные-изменения>]"
+
+#: builtin/stash.c:27 builtin/stash.c:67
+msgid "git stash clear"
+msgstr "git stash clear"
+
+#: builtin/stash.c:28 builtin/stash.c:77
+msgid ""
+"git stash [push [-p|--patch] [-k|--[no-]keep-index] [-q|--quiet]\n"
+"          [-u|--include-untracked] [-a|--all] [-m|--message <message>]\n"
+"          [--] [<pathspec>...]]"
+msgstr "git stash [push [-p|--patch] [-k|--[no-]keep-index] [-q|--quiet]\n          [-u|--include-untracked] [-a|--all] [-m|--message <сообщение>]\n          [--] [<спецификатор-пути>…]]"
+
+#: builtin/stash.c:31 builtin/stash.c:84
+msgid ""
+"git stash save [-p|--patch] [-k|--[no-]keep-index] [-q|--quiet]\n"
+"          [-u|--include-untracked] [-a|--all] [<message>]"
+msgstr "git stash save [-p|--patch] [-k|--[no-]keep-index] [-q|--quiet]\n          [-u|--include-untracked] [-a|--all] [<сообщение>]"
+
+#: builtin/stash.c:52
+msgid "git stash pop [--index] [-q|--quiet] [<stash>]"
+msgstr "git stash pop [--index] [-q|--quiet] [<спрятанные-изменения>]"
+
+#: builtin/stash.c:57
+msgid "git stash apply [--index] [-q|--quiet] [<stash>]"
+msgstr "git stash apply [--index] [-q|--quiet] [<спрятанные-изменения>]"
+
+#: builtin/stash.c:72
+msgid "git stash store [-m|--message <message>] [-q|--quiet] <commit>"
+msgstr "git stash store [-m|--message <сообщение>] [-q|--quiet] <коммит>"
+
+#: builtin/stash.c:127
+#, c-format
+msgid "'%s' is not a stash-like commit"
+msgstr "«%s» не является коммитом со спрятанными изменениями"
+
+#: builtin/stash.c:147
+#, c-format
+msgid "Too many revisions specified:%s"
+msgstr "Передано слишком много редакций:%s"
+
+#: builtin/stash.c:161 git-legacy-stash.sh:548
+msgid "No stash entries found."
+msgstr "Не найдены спрятанные изменения."
+
+#: builtin/stash.c:175
+#, c-format
+msgid "%s is not a valid reference"
+msgstr "%s не является допустимой ссылкой на коммит"
+
+#: builtin/stash.c:224 git-legacy-stash.sh:75
+msgid "git stash clear with parameters is unimplemented"
+msgstr "git stash очистка с параметрами не реализована"
+
+#: builtin/stash.c:403
+msgid "cannot apply a stash in the middle of a merge"
+msgstr "нельзя применить спрятанные изменения во время выполнения слияния"
+
+#: builtin/stash.c:414
+#, c-format
+msgid "could not generate diff %s^!."
+msgstr "не удалось сгенерировать список изменений %s^!."
+
+#: builtin/stash.c:421
+msgid "conflicts in index.Try without --index."
+msgstr "конфликты в индексе. Попробуйте без --index."
+
+#: builtin/stash.c:427
+msgid "could not save index tree"
+msgstr "не удалось сохранить дерево индекса"
+
+#: builtin/stash.c:434
+msgid "could not restore untracked files from stash"
+msgstr "невозможно восстановить неотслеживаемые файлы из спрятанных файлов"
+
+#: builtin/stash.c:448
+#, c-format
+msgid "Merging %s with %s"
+msgstr "Слияние %s и %s"
+
+#: builtin/stash.c:458 git-legacy-stash.sh:680
+msgid "Index was not unstashed."
+msgstr "Индекс не был извлечён из спрятанных изменений."
+
+#: builtin/stash.c:516 builtin/stash.c:615
+msgid "attempt to recreate the index"
+msgstr "попытка пересоздания индекса"
+
+#: builtin/stash.c:549
+#, c-format
+msgid "Dropped %s (%s)"
+msgstr "Отброшено %s (%s)"
+
+#: builtin/stash.c:552
+#, c-format
+msgid "%s: Could not drop stash entry"
+msgstr "%s: Не удалось отбросить запись из спрятанных изменений"
+
+#: builtin/stash.c:577
+#, c-format
+msgid "'%s' is not a stash reference"
+msgstr "«%s» не является ссылкой на спрятанные изменения"
+
+#: builtin/stash.c:627 git-legacy-stash.sh:694
+msgid "The stash entry is kept in case you need it again."
+msgstr "Спрятанные изменения сохранены, на случай если они снова вам понадобятся."
+
+#: builtin/stash.c:650 git-legacy-stash.sh:712
+msgid "No branch name specified"
+msgstr "Не указано имя ветки"
+
+#: builtin/stash.c:789 builtin/stash.c:826
+#, c-format
+msgid "Cannot update %s with %s"
+msgstr "Не удолось обновить %s с %s"
+
+#: builtin/stash.c:807 builtin/stash.c:1474 builtin/stash.c:1510
+msgid "stash message"
+msgstr "описание спрятанных изменений"
+
+#: builtin/stash.c:817
+msgid "\"git stash store\" requires one <commit> argument"
+msgstr "«git stash store» требует указания одного аргумента <коммит>"
+
+#: builtin/stash.c:1039 git-legacy-stash.sh:217
+msgid "No changes selected"
+msgstr "Изменения не выбраны"
+
+#: builtin/stash.c:1135 git-legacy-stash.sh:150
+msgid "You do not have the initial commit yet"
+msgstr "У вас еще нет начального коммита"
+
+#: builtin/stash.c:1162 git-legacy-stash.sh:165
+msgid "Cannot save the current index state"
+msgstr "Не удалось сохранить текущее состояние индекса"
+
+#: builtin/stash.c:1171 git-legacy-stash.sh:180
+msgid "Cannot save the untracked files"
+msgstr "Невозможно сохранить неотслеживаемые файлы"
+
+#: builtin/stash.c:1182 builtin/stash.c:1191 git-legacy-stash.sh:200
+#: git-legacy-stash.sh:213
+msgid "Cannot save the current worktree state"
+msgstr "Не удалось сохранить текущее состояние рабочего каталога"
+
+#: builtin/stash.c:1219 git-legacy-stash.sh:233
+msgid "Cannot record working tree state"
+msgstr "Не удалось записать состояние рабочего каталога"
+
+#: builtin/stash.c:1268 git-legacy-stash.sh:337
+msgid "Can't use --patch and --include-untracked or --all at the same time"
+msgstr "Нельзя использовать --patch и --include-untracked или --all одновременно"
+
+#: builtin/stash.c:1284
+msgid "Did you forget to 'git add'?"
+msgstr "Возможно, вы забыли выполнить «git add»?"
+
+#: builtin/stash.c:1299 git-legacy-stash.sh:345
+msgid "No local changes to save"
+msgstr "Нет локальных изменений для сохранения"
+
+#: builtin/stash.c:1306 git-legacy-stash.sh:350
+msgid "Cannot initialize stash"
+msgstr "Не удалось инициализировать спрятанные изменения"
+
+#: builtin/stash.c:1321 git-legacy-stash.sh:354
+msgid "Cannot save the current status"
+msgstr "Не удалось сохранить текущий статус"
+
+#: builtin/stash.c:1326
+#, c-format
+msgid "Saved working directory and index state %s"
+msgstr "Рабочий каталог и состояние индекса сохранены %s"
+
+#: builtin/stash.c:1430 git-legacy-stash.sh:384
+msgid "Cannot remove worktree changes"
+msgstr "Не удалось удалить изменения рабочего каталога"
+
+#: builtin/stash.c:1465 builtin/stash.c:1501
+msgid "keep index"
+msgstr ""
+
+#: builtin/stash.c:1467 builtin/stash.c:1503
+msgid "stash in patch mode"
+msgstr ""
+
+#: builtin/stash.c:1468 builtin/stash.c:1504
+msgid "quiet mode"
+msgstr ""
+
+#: builtin/stash.c:1470 builtin/stash.c:1506
+msgid "include untracked files in stash"
+msgstr ""
+
+#: builtin/stash.c:1472 builtin/stash.c:1508
+msgid "include ignore files"
+msgstr ""
+
+#: builtin/stash.c:1568
+#, c-format
+msgid "could not exec %s"
+msgstr ""
+
 #: builtin/stripspace.c:18
 msgid "git stripspace [-s | --strip-comments]"
 msgstr "git stripspace [-s | --strip-comments]"
@@ -12665,251 +18026,401 @@ msgstr "git stripspace [-s | --strip-com
 msgid "git stripspace [-c | --comment-lines]"
 msgstr "git stripspace [-c | --comment-lines]"
 
-#: builtin/stripspace.c:36
+#: builtin/stripspace.c:37
 msgid "skip and remove all lines starting with comment character"
 msgstr "пропустить и удалить все строки, начинающиеся с символа комметария"
 
-#: builtin/stripspace.c:39
+#: builtin/stripspace.c:40
 msgid "prepend comment character and space to each line"
 msgstr "добавить перед каждой строкой символ комметария и пробел"
 
-#: builtin/submodule--helper.c:34 builtin/submodule--helper.c:1332
-#, c-format
-msgid "No such ref: %s"
-msgstr "Нет такой ссылки: %s"
-
-#: builtin/submodule--helper.c:41 builtin/submodule--helper.c:1341
+#: builtin/submodule--helper.c:45 builtin/submodule--helper.c:1942
 #, c-format
 msgid "Expecting a full ref name, got %s"
 msgstr "Ожидалось полное имя ссылки, а получено %s"
 
-#: builtin/submodule--helper.c:81
+#: builtin/submodule--helper.c:62
+msgid "submodule--helper print-default-remote takes no arguments"
+msgstr ""
+
+#: builtin/submodule--helper.c:100
 #, c-format
 msgid "cannot strip one component off url '%s'"
 msgstr "не удалось обрезать один компонент url «%s»"
 
-#: builtin/submodule--helper.c:370 builtin/submodule--helper.c:861
+#: builtin/submodule--helper.c:408 builtin/submodule--helper.c:1367
 msgid "alternative anchor for relative paths"
 msgstr "альтернативный символ для относительных путей"
 
-#: builtin/submodule--helper.c:375
+#: builtin/submodule--helper.c:413
 msgid "git submodule--helper list [--prefix=<path>] [<path>...]"
 msgstr "git submodule--helper list [--prefix=<путь>] [<путь>…]"
 
-#: builtin/submodule--helper.c:426 builtin/submodule--helper.c:449
+#: builtin/submodule--helper.c:470 builtin/submodule--helper.c:627
+#: builtin/submodule--helper.c:650
 #, c-format
 msgid "No url found for submodule path '%s' in .gitmodules"
 msgstr "URL для подмодуля по пути «%s» не найден в .gitmodules"
 
-#: builtin/submodule--helper.c:464
+#: builtin/submodule--helper.c:522
+#, c-format
+msgid "Entering '%s'\n"
+msgstr ""
+
+#: builtin/submodule--helper.c:525
+#, c-format
+msgid ""
+"run_command returned non-zero status for %s\n"
+"."
+msgstr ""
+
+#: builtin/submodule--helper.c:546
+#, c-format
+msgid ""
+"run_command returned non-zero status while recursing in the nested submodules of %s\n"
+"."
+msgstr ""
+
+#: builtin/submodule--helper.c:562
+msgid "Suppress output of entering each submodule command"
+msgstr ""
+
+#: builtin/submodule--helper.c:564 builtin/submodule--helper.c:1049
+msgid "Recurse into nested submodules"
+msgstr ""
+
+#: builtin/submodule--helper.c:569
+msgid "git submodule--helper foreach [--quiet] [--recursive] [--] <command>"
+msgstr ""
+
+#: builtin/submodule--helper.c:596
 #, c-format
 msgid ""
-"could not lookup configuration '%s'. Assuming this repository is its own "
+"could not look up configuration '%s'. Assuming this repository is its own "
 "authoritative upstream."
-msgstr "не удалось запросить конфигурацию «%s». Предполагаю, что этот репозиторий имеет свой собственный вышестоящий репозиторий."
+msgstr ""
 
-#: builtin/submodule--helper.c:475
+#: builtin/submodule--helper.c:664
 #, c-format
 msgid "Failed to register url for submodule path '%s'"
 msgstr "Сбой регистрации адреса для пути подмодуля «%s»"
 
-#: builtin/submodule--helper.c:479
+#: builtin/submodule--helper.c:668
 #, c-format
 msgid "Submodule '%s' (%s) registered for path '%s'\n"
 msgstr "Подмодуль «%s» (%s) зарегистрирован по пути «%s»\n"
 
-#: builtin/submodule--helper.c:489
+#: builtin/submodule--helper.c:678
 #, c-format
 msgid "warning: command update mode suggested for submodule '%s'\n"
 msgstr "внимание: предполагаемый режим обновления для подмодуля «%s»\n"
 
-#: builtin/submodule--helper.c:496
+#: builtin/submodule--helper.c:685
 #, c-format
 msgid "Failed to register update mode for submodule path '%s'"
 msgstr "Сбой регистрации режима обновления для пути подмодуля «%s»"
 
-#: builtin/submodule--helper.c:518
+#: builtin/submodule--helper.c:707
 msgid "Suppress output for initializing a submodule"
 msgstr "Не выводить информацию о инициализации подмодуля"
 
-#: builtin/submodule--helper.c:523
-msgid "git submodule--helper init [<path>]"
-msgstr "git submodule--helper init [<путь>]"
+#: builtin/submodule--helper.c:712
+msgid "git submodule--helper init [<options>] [<path>]"
+msgstr ""
+
+#: builtin/submodule--helper.c:784 builtin/submodule--helper.c:910
+#, c-format
+msgid "no submodule mapping found in .gitmodules for path '%s'"
+msgstr "не найдено соответствие подмодулей в .gitmodules для пути «%s»"
+
+#: builtin/submodule--helper.c:823
+#, c-format
+msgid "could not resolve HEAD ref inside the submodule '%s'"
+msgstr "не удалось найти HEAD ссылку внутри подмодуля «%s»"
+
+#: builtin/submodule--helper.c:850 builtin/submodule--helper.c:1019
+#, c-format
+msgid "failed to recurse into submodule '%s'"
+msgstr "не удалось перейти вглубь подмодуля «%s»"
+
+#: builtin/submodule--helper.c:874 builtin/submodule--helper.c:1185
+msgid "Suppress submodule status output"
+msgstr "Не выводить статус подмодуля"
+
+#: builtin/submodule--helper.c:875
+msgid ""
+"Use commit stored in the index instead of the one stored in the submodule "
+"HEAD"
+msgstr "Использовать коммит хранящийся в индексе вместо коммита хранящегося в HEAD подмодуля"
+
+#: builtin/submodule--helper.c:876
+msgid "recurse into nested submodules"
+msgstr "проходить вглубь вложенных подмодулей"
+
+#: builtin/submodule--helper.c:881
+msgid "git submodule status [--quiet] [--cached] [--recursive] [<path>...]"
+msgstr "git submodule status [--quiet] [--cached] [--recursive] [<путь>…]"
+
+#: builtin/submodule--helper.c:905
+msgid "git submodule--helper name <path>"
+msgstr "git submodule--helper name <путь>"
+
+#: builtin/submodule--helper.c:969
+#, c-format
+msgid "Synchronizing submodule url for '%s'\n"
+msgstr ""
+
+#: builtin/submodule--helper.c:975
+#, c-format
+msgid "failed to register url for submodule path '%s'"
+msgstr ""
+
+#: builtin/submodule--helper.c:989
+#, c-format
+msgid "failed to get the default remote for submodule '%s'"
+msgstr ""
+
+#: builtin/submodule--helper.c:1000
+#, c-format
+msgid "failed to update remote for submodule '%s'"
+msgstr ""
+
+#: builtin/submodule--helper.c:1047
+msgid "Suppress output of synchronizing submodule url"
+msgstr ""
+
+#: builtin/submodule--helper.c:1054
+msgid "git submodule--helper sync [--quiet] [--recursive] [<path>]"
+msgstr "git submodule--helper sync [--quiet] [--recursive] [<путь>]"
+
+#: builtin/submodule--helper.c:1108
+#, c-format
+msgid ""
+"Submodule work tree '%s' contains a .git directory (use 'rm -rf' if you "
+"really want to remove it including all of its history)"
+msgstr ""
+
+#: builtin/submodule--helper.c:1120
+#, c-format
+msgid ""
+"Submodule work tree '%s' contains local modifications; use '-f' to discard "
+"them"
+msgstr ""
 
-#: builtin/submodule--helper.c:591 builtin/submodule--helper.c:713
+#: builtin/submodule--helper.c:1128
 #, c-format
-msgid "no submodule mapping found in .gitmodules for path '%s'"
-msgstr "не найдено соответствие подмодулей в .gitmodules для пути «%s»"
+msgid "Cleared directory '%s'\n"
+msgstr ""
 
-#: builtin/submodule--helper.c:626
+#: builtin/submodule--helper.c:1130
 #, c-format
-msgid "could not resolve HEAD ref inside the submodule '%s'"
-msgstr "не удалось найти HEAD ссылку внутри подмодуля «%s»"
+msgid "Could not remove submodule work tree '%s'\n"
+msgstr ""
 
-#: builtin/submodule--helper.c:653
+#: builtin/submodule--helper.c:1141
 #, c-format
-msgid "failed to recurse into submodule '%s'"
-msgstr "не удалось перейти вглубь подмодуля «%s»"
+msgid "could not create empty submodule directory %s"
+msgstr ""
 
-#: builtin/submodule--helper.c:677
-msgid "Suppress submodule status output"
-msgstr "Не выводить статус подмодуля"
+#: builtin/submodule--helper.c:1157
+#, c-format
+msgid "Submodule '%s' (%s) unregistered for path '%s'\n"
+msgstr ""
 
-#: builtin/submodule--helper.c:678
-msgid ""
-"Use commit stored in the index instead of the one stored in the submodule "
-"HEAD"
-msgstr "Использовать коммит хранящийся в индексе вместо коммита хранящегося в HEAD подмодуля"
+#: builtin/submodule--helper.c:1186
+msgid "Remove submodule working trees even if they contain local changes"
+msgstr ""
 
-#: builtin/submodule--helper.c:679
-msgid "recurse into nested submodules"
-msgstr "проходить вглубь вложенных подмодулей"
+#: builtin/submodule--helper.c:1187
+msgid "Unregister all submodules"
+msgstr ""
 
-#: builtin/submodule--helper.c:684
-msgid "git submodule status [--quiet] [--cached] [--recursive] [<path>...]"
-msgstr "git submodule status [--quiet] [--cached] [--recursive] [<путь>…]"
+#: builtin/submodule--helper.c:1192
+msgid ""
+"git submodule deinit [--quiet] [-f | --force] [--all | [--] [<path>...]]"
+msgstr "git submodule deinit [--quiet] [-f | --force] [--all | [--] [<путь>…]]"
 
-#: builtin/submodule--helper.c:708
-msgid "git submodule--helper name <path>"
-msgstr "git submodule--helper name <путь>"
+#: builtin/submodule--helper.c:1206
+msgid "Use '--all' if you really want to deinitialize all submodules"
+msgstr "Используйте «--all», если вы действительно хотите деинициализировать все подмодули"
 
-#: builtin/submodule--helper.c:796 builtin/submodule--helper.c:799
+#: builtin/submodule--helper.c:1301 builtin/submodule--helper.c:1304
 #, c-format
 msgid "submodule '%s' cannot add alternate: %s"
 msgstr "подмодулю «%s» не удалось добавить альтернативу: %s"
 
-#: builtin/submodule--helper.c:835
+#: builtin/submodule--helper.c:1340
 #, c-format
 msgid "Value '%s' for submodule.alternateErrorStrategy is not recognized"
 msgstr "Значение «%s» для параметра submodule.alternateErrorStrategy не рапознано"
 
-#: builtin/submodule--helper.c:842
+#: builtin/submodule--helper.c:1347
 #, c-format
 msgid "Value '%s' for submodule.alternateLocation is not recognized"
 msgstr "Значение «%s» для параметра submodule.alternateLocation не рапознано"
 
-#: builtin/submodule--helper.c:864
+#: builtin/submodule--helper.c:1370
 msgid "where the new submodule will be cloned to"
 msgstr "куда должен быть склонирован новый подмодуль"
 
-#: builtin/submodule--helper.c:867
+#: builtin/submodule--helper.c:1373
 msgid "name of the new submodule"
 msgstr "имя нового подмодуля"
 
-#: builtin/submodule--helper.c:870
+#: builtin/submodule--helper.c:1376
 msgid "url where to clone the submodule from"
 msgstr "url откуда должен был склонирован новый подмодуль"
 
-#: builtin/submodule--helper.c:876
+#: builtin/submodule--helper.c:1384
 msgid "depth for shallow clones"
 msgstr "глубина для частичного клона"
 
-#: builtin/submodule--helper.c:879 builtin/submodule--helper.c:1250
+#: builtin/submodule--helper.c:1387 builtin/submodule--helper.c:1871
 msgid "force cloning progress"
 msgstr "принудительно выводить прогресс клонирования"
 
-#: builtin/submodule--helper.c:884
+#: builtin/submodule--helper.c:1392
 msgid ""
 "git submodule--helper clone [--prefix=<path>] [--quiet] [--reference "
 "<repository>] [--name <name>] [--depth <depth>] --url <url> --path <path>"
 msgstr "git submodule--helper clone [--prefix=<путь>] [--quiet] [--reference <репозиторий>] [--name <имя>] [--depth <глубина>] --url <url> --path <путь>"
 
-#: builtin/submodule--helper.c:915
+#: builtin/submodule--helper.c:1423
 #, c-format
 msgid "clone of '%s' into submodule path '%s' failed"
 msgstr "не удалось клонировать «%s» в подмодуль по пути «%s»"
 
-#: builtin/submodule--helper.c:930
+#: builtin/submodule--helper.c:1437
 #, c-format
 msgid "could not get submodule directory for '%s'"
 msgstr "не удалось получить каталог для подмодуля «%s»"
 
-#: builtin/submodule--helper.c:995
+#: builtin/submodule--helper.c:1473
+#, c-format
+msgid "Invalid update mode '%s' for submodule path '%s'"
+msgstr ""
+
+#: builtin/submodule--helper.c:1477
+#, c-format
+msgid "Invalid update mode '%s' configured for submodule path '%s'"
+msgstr ""
+
+#: builtin/submodule--helper.c:1570
 #, c-format
 msgid "Submodule path '%s' not initialized"
 msgstr "Подмодуль по пути «%s» не инициализирован"
 
-#: builtin/submodule--helper.c:999
+#: builtin/submodule--helper.c:1574
 msgid "Maybe you want to use 'update --init'?"
 msgstr "Возможно, вы хотели использовать «update --init»?"
 
-#: builtin/submodule--helper.c:1028
+#: builtin/submodule--helper.c:1604
 #, c-format
 msgid "Skipping unmerged submodule %s"
 msgstr "Пропуск не слитого подмодуля %s"
 
-#: builtin/submodule--helper.c:1057
+#: builtin/submodule--helper.c:1633
 #, c-format
 msgid "Skipping submodule '%s'"
 msgstr "Пропуск подмодуля «%s»"
 
-#: builtin/submodule--helper.c:1190
+#: builtin/submodule--helper.c:1777
 #, c-format
 msgid "Failed to clone '%s'. Retry scheduled"
 msgstr "Не удалось клонировать «%s». Запланирована повторная попытка"
 
-#: builtin/submodule--helper.c:1201
+#: builtin/submodule--helper.c:1788
 #, c-format
 msgid "Failed to clone '%s' a second time, aborting"
 msgstr "Не удалось клонировать «%s» со второй попытки, отмена"
 
-#: builtin/submodule--helper.c:1231 builtin/submodule--helper.c:1451
+#: builtin/submodule--helper.c:1850 builtin/submodule--helper.c:2092
 msgid "path into the working tree"
 msgstr "путь в рабочем каталоге"
 
-#: builtin/submodule--helper.c:1234
+#: builtin/submodule--helper.c:1853
 msgid "path into the working tree, across nested submodule boundaries"
 msgstr "путь в рабочем каталоге, в пределах границ подмодуля"
 
-#: builtin/submodule--helper.c:1238
+#: builtin/submodule--helper.c:1857
 msgid "rebase, merge, checkout or none"
 msgstr "rebase, merge, checkout или none"
 
-#: builtin/submodule--helper.c:1242
+#: builtin/submodule--helper.c:1863
 msgid "Create a shallow clone truncated to the specified number of revisions"
 msgstr "Создать частичный клон, ограниченный указанным количеством редакций"
 
-#: builtin/submodule--helper.c:1245
+#: builtin/submodule--helper.c:1866
 msgid "parallel jobs"
 msgstr "параллельные задачи"
 
-#: builtin/submodule--helper.c:1247
+#: builtin/submodule--helper.c:1868
 msgid "whether the initial clone should follow the shallow recommendation"
 msgstr "должен ли изначальный процесс клонирования следовать рекомендации о частичности"
 
-#: builtin/submodule--helper.c:1248
+#: builtin/submodule--helper.c:1869
 msgid "don't print cloning progress"
 msgstr "вы выводить прогресс клонирования"
 
-#: builtin/submodule--helper.c:1255
+#: builtin/submodule--helper.c:1876
 msgid "git submodule--helper update_clone [--prefix=<path>] [<path>...]"
 msgstr "git submodule--helper update_clone [--prefix=<путь>] [<путь>…]"
 
-#: builtin/submodule--helper.c:1268
+#: builtin/submodule--helper.c:1889
 msgid "bad value for update parameter"
 msgstr "плохое значение для параметра update"
 
-#: builtin/submodule--helper.c:1336
+#: builtin/submodule--helper.c:1937
 #, c-format
 msgid ""
 "Submodule (%s) branch configured to inherit branch from superproject, but "
 "the superproject is not on any branch"
 msgstr "Ветка подмодуля (%s) настроена на наследование ветки из родительского проекта, но он не находится ни на одной ветке"
 
-#: builtin/submodule--helper.c:1452
+#: builtin/submodule--helper.c:2060
+#, c-format
+msgid "could not get a repository handle for submodule '%s'"
+msgstr ""
+
+#: builtin/submodule--helper.c:2093
 msgid "recurse into submodules"
 msgstr "рекурсивно по подмодулям"
 
-#: builtin/submodule--helper.c:1458
-msgid "git submodule--helper embed-git-dir [<path>...]"
-msgstr "git submodule--helper embed-git-dir [<путь>…]"
+#: builtin/submodule--helper.c:2099
+msgid "git submodule--helper absorb-git-dirs [<options>] [<path>...]"
+msgstr "git submodule--helper absorb-git-dirs [<опции>] [<путь>…]"
+
+#: builtin/submodule--helper.c:2156
+msgid "check if it is safe to write to the .gitmodules file"
+msgstr ""
+
+#: builtin/submodule--helper.c:2159
+msgid "unset the config in the .gitmodules file"
+msgstr ""
+
+#: builtin/submodule--helper.c:2164
+msgid "git submodule--helper config <name> [<value>]"
+msgstr "git submodule--helper config <имя> [<значение>]"
+
+#: builtin/submodule--helper.c:2165
+msgid "git submodule--helper config --unset <name>"
+msgstr "git submodule--helper config --unset <имя>"
+
+#: builtin/submodule--helper.c:2166
+msgid "git submodule--helper config --check-writeable"
+msgstr "git submodule--helper config --check-writeable"
+
+#: builtin/submodule--helper.c:2185 git-submodule.sh:171
+#, sh-format
+msgid "please make sure that the .gitmodules file is in the working tree"
+msgstr ""
 
-#: builtin/submodule--helper.c:1517
+#: builtin/submodule--helper.c:2235 git.c:433 git.c:685
 #, c-format
 msgid "%s doesn't support --super-prefix"
 msgstr "%s не поддерживает параметр --super-prefix"
 
-#: builtin/submodule--helper.c:1523
+#: builtin/submodule--helper.c:2241
 #, c-format
 msgid "'%s' is not a valid submodule--helper subcommand"
 msgstr "«%s» не является подкомандой submodule--helper"
@@ -12934,45 +18445,45 @@ msgstr "удалить символьн
 msgid "shorten ref output"
 msgstr "укороченный вывод ссылок"
 
-#: builtin/symbolic-ref.c:43 builtin/update-ref.c:362
+#: builtin/symbolic-ref.c:43 builtin/update-ref.c:363
 msgid "reason"
 msgstr "причина"
 
-#: builtin/symbolic-ref.c:43 builtin/update-ref.c:362
+#: builtin/symbolic-ref.c:43 builtin/update-ref.c:363
 msgid "reason of the update"
 msgstr "причина обновления"
 
-#: builtin/tag.c:24
+#: builtin/tag.c:25
 msgid ""
-"git tag [-a | -s | -u <key-id>] [-f] [-m <msg> | -F <file>] <tagname> "
-"[<head>]"
-msgstr "git tag [-a | -s | -u <идентификатор-ключа>] [-f] [-m <сообщение> | -F <файл>] <имя-метки> [<редакция>]"
+"git tag [-a | -s | -u <key-id>] [-f] [-m <msg> | -F <file>]\n"
+"\t\t<tagname> [<head>]"
+msgstr "git tag [-a | -s | -u <key-id>] [-f] [-m <сообщение> | -F <файл>]\n\t\t<имя-метка> [<редакция>]"
 
-#: builtin/tag.c:25
+#: builtin/tag.c:27
 msgid "git tag -d <tagname>..."
 msgstr "git tag -d <имя-метки>…"
 
-#: builtin/tag.c:26
+#: builtin/tag.c:28
 msgid ""
 "git tag -l [-n[<num>]] [--contains <commit>] [--no-contains <commit>] [--points-at <object>]\n"
 "\t\t[--format=<format>] [--[no-]merged [<commit>]] [<pattern>...]"
 msgstr "git tag -l [-n[<количество>]] [--contains <коммит>] [--no-contains <коммит>] [--points-at <объект>]\n\t\t[--format=<формат>] [--[no-]merged [<коммит>]] [<шаблон>…]"
 
-#: builtin/tag.c:28
+#: builtin/tag.c:30
 msgid "git tag -v [--format=<format>] <tagname>..."
 msgstr "git tag -v [--format=<формат>] <имя-метки>…"
 
-#: builtin/tag.c:86
+#: builtin/tag.c:88
 #, c-format
 msgid "tag '%s' not found."
 msgstr "метка  «%s» не найдена."
 
-#: builtin/tag.c:102
+#: builtin/tag.c:104
 #, c-format
 msgid "Deleted tag '%s' (was %s)\n"
 msgstr "Метка «%s» удалена (была %s)\n"
 
-#: builtin/tag.c:131
+#: builtin/tag.c:134
 #, c-format
 msgid ""
 "\n"
@@ -12981,7 +18492,7 @@ msgid ""
 "Lines starting with '%c' will be ignored.\n"
 msgstr "\nВведите сообщение для метки:\n  %s\nСтроки, начинающиеся с «%c» будут проигнорированы.\n"
 
-#: builtin/tag.c:135
+#: builtin/tag.c:138
 #, c-format
 msgid ""
 "\n"
@@ -12990,391 +18501,399 @@ msgid ""
 "Lines starting with '%c' will be kept; you may remove them yourself if you want to.\n"
 msgstr "\nВведите сообщение для метки:\n  %s\nСтроки, начинающиеся с «%c» будут оставлены; вы можете удалить их вручную, если хотите.\n"
 
-#: builtin/tag.c:189
+#: builtin/tag.c:192
 msgid "unable to sign the tag"
 msgstr "не удалось подписать метку"
 
-#: builtin/tag.c:191
+#: builtin/tag.c:194
 msgid "unable to write tag file"
 msgstr "не удалось записать файл метки"
 
-#: builtin/tag.c:215
+#: builtin/tag.c:210
+#, c-format
+msgid ""
+"You have created a nested tag. The object referred to by your new tag is\n"
+"already a tag. If you meant to tag the object that it points to, use:\n"
+"\n"
+"\tgit tag -f %s %s^{}"
+msgstr ""
+
+#: builtin/tag.c:226
 msgid "bad object type."
 msgstr "неправильный тип объекта"
 
-#: builtin/tag.c:261
+#: builtin/tag.c:278
 msgid "no tag message?"
 msgstr "нет описания метки?"
 
-#: builtin/tag.c:268
+#: builtin/tag.c:285
 #, c-format
 msgid "The tag message has been left in %s\n"
 msgstr "Сообщение метки было оставлено в %s\n"
 
-#: builtin/tag.c:376
+#: builtin/tag.c:396
 msgid "list tag names"
 msgstr "список названий меток"
 
-#: builtin/tag.c:378
+#: builtin/tag.c:398
 msgid "print <n> lines of each tag message"
 msgstr "печатать <n> строк описания от каждой метки"
 
-#: builtin/tag.c:380
+#: builtin/tag.c:400
 msgid "delete tags"
 msgstr "удалить метки"
 
-#: builtin/tag.c:381
+#: builtin/tag.c:401
 msgid "verify tags"
 msgstr "проверить метки"
 
-#: builtin/tag.c:383
+#: builtin/tag.c:403
 msgid "Tag creation options"
 msgstr "Настройки создания метки"
 
-#: builtin/tag.c:385
+#: builtin/tag.c:405
 msgid "annotated tag, needs a message"
 msgstr "для аннотированной метки нужно сообщение"
 
-#: builtin/tag.c:387
+#: builtin/tag.c:407
 msgid "tag message"
 msgstr "описание метки"
 
-#: builtin/tag.c:389
+#: builtin/tag.c:409
+msgid "force edit of tag message"
+msgstr ""
+
+#: builtin/tag.c:410
 msgid "annotated and GPG-signed tag"
 msgstr "аннотированная и подписанная с помощью GPG метка"
 
-#: builtin/tag.c:393
+#: builtin/tag.c:413
 msgid "use another key to sign the tag"
 msgstr "использовать другой ключ для подписания метки"
 
-#: builtin/tag.c:394
+#: builtin/tag.c:414
 msgid "replace the tag if exists"
 msgstr "замена метки, если она существует"
 
-#: builtin/tag.c:395 builtin/update-ref.c:368
+#: builtin/tag.c:415 builtin/update-ref.c:369
 msgid "create a reflog"
 msgstr "создать журнал ссылок"
 
-#: builtin/tag.c:397
+#: builtin/tag.c:417
 msgid "Tag listing options"
 msgstr "Настройки вывода списка меток"
 
-#: builtin/tag.c:398
+#: builtin/tag.c:418
 msgid "show tag list in columns"
 msgstr "показать список меток по столбцам"
 
-#: builtin/tag.c:399 builtin/tag.c:401
+#: builtin/tag.c:419 builtin/tag.c:421
 msgid "print only tags that contain the commit"
 msgstr "вывод только меток, которые содержат коммит"
 
-#: builtin/tag.c:400 builtin/tag.c:402
+#: builtin/tag.c:420 builtin/tag.c:422
 msgid "print only tags that don't contain the commit"
 msgstr "вывод только меток, которые не содержат коммит"
 
-#: builtin/tag.c:403
+#: builtin/tag.c:423
 msgid "print only tags that are merged"
 msgstr "вывод только слитых меток"
 
-#: builtin/tag.c:404
+#: builtin/tag.c:424
 msgid "print only tags that are not merged"
 msgstr "вывод только не слитых меток"
 
-#: builtin/tag.c:409
+#: builtin/tag.c:428
 msgid "print only tags of the object"
 msgstr "вывод только меток, определенного объекта"
 
-#: builtin/tag.c:453
+#: builtin/tag.c:472
 msgid "--column and -n are incompatible"
 msgstr "--column и -n нельзя использовать одновременно"
 
-#: builtin/tag.c:475
+#: builtin/tag.c:494
 msgid "-n option is only allowed in list mode"
 msgstr "опцию -n можно использовать только в режиме списка"
 
-#: builtin/tag.c:477
+#: builtin/tag.c:496
 msgid "--contains option is only allowed in list mode"
 msgstr "опцию --contains можно использовать только в режиме списка"
 
-#: builtin/tag.c:479
+#: builtin/tag.c:498
 msgid "--no-contains option is only allowed in list mode"
 msgstr "опцию --no-contains можно использовать только в режиме списка"
 
-#: builtin/tag.c:481
+#: builtin/tag.c:500
 msgid "--points-at option is only allowed in list mode"
 msgstr "опцию --points-at можно использовать только в режиме списка"
 
-#: builtin/tag.c:483
+#: builtin/tag.c:502
 msgid "--merged and --no-merged options are only allowed in list mode"
 msgstr "опции --merged и --no-merged можно использовать только в режиме списка"
 
-#: builtin/tag.c:494
+#: builtin/tag.c:513
 msgid "only one -F or -m option is allowed."
 msgstr "-F и -m нельзя использовать одновременно."
 
-#: builtin/tag.c:513
+#: builtin/tag.c:532
 msgid "too many params"
 msgstr "передано слишком много параметров"
 
-#: builtin/tag.c:519
+#: builtin/tag.c:538
 #, c-format
 msgid "'%s' is not a valid tag name."
 msgstr "«%s» не является допустимым именем метки."
 
-#: builtin/tag.c:524
+#: builtin/tag.c:543
 #, c-format
 msgid "tag '%s' already exists"
 msgstr "метка «%s» уже существует"
 
-#: builtin/tag.c:554
+#: builtin/tag.c:574
 #, c-format
 msgid "Updated tag '%s' (was %s)\n"
 msgstr "Метка «%s» обновлена (была %s)\n"
 
-#: builtin/unpack-objects.c:494
+#: builtin/unpack-objects.c:500
 msgid "Unpacking objects"
 msgstr "Распаковка объектов"
 
-#: builtin/update-index.c:82
+#: builtin/update-index.c:83
 #, c-format
 msgid "failed to create directory %s"
 msgstr "не удалось создать каталог %s"
 
-#: builtin/update-index.c:88
-#, c-format
-msgid "failed to stat %s"
-msgstr "не удалось выполнить stat %s"
-
-#: builtin/update-index.c:98
+#: builtin/update-index.c:99
 #, c-format
 msgid "failed to create file %s"
 msgstr "не удалось создать файл %s"
 
-#: builtin/update-index.c:106
+#: builtin/update-index.c:107
 #, c-format
 msgid "failed to delete file %s"
 msgstr "не удалось удалить файл %s"
 
-#: builtin/update-index.c:113 builtin/update-index.c:219
+#: builtin/update-index.c:114 builtin/update-index.c:220
 #, c-format
 msgid "failed to delete directory %s"
 msgstr "не удалось удалить каталог %s"
 
-#: builtin/update-index.c:138
+#: builtin/update-index.c:139
 #, c-format
 msgid "Testing mtime in '%s' "
 msgstr "Проверка mtime в «%s» "
 
-#: builtin/update-index.c:152
+#: builtin/update-index.c:153
 msgid "directory stat info does not change after adding a new file"
 msgstr "информация статистики каталога не изменяется после добавления нового файла"
 
-#: builtin/update-index.c:165
+#: builtin/update-index.c:166
 msgid "directory stat info does not change after adding a new directory"
 msgstr "информация статистики каталога не изменяется после добавления нового каталога"
 
-#: builtin/update-index.c:178
+#: builtin/update-index.c:179
 msgid "directory stat info changes after updating a file"
 msgstr "информация статистики каталога изменяется после добавления нового файла"
 
-#: builtin/update-index.c:189
+#: builtin/update-index.c:190
 msgid "directory stat info changes after adding a file inside subdirectory"
 msgstr "информация статистики каталога изменяется после добавления нового файла внутри подкаталога"
 
-#: builtin/update-index.c:200
+#: builtin/update-index.c:201
 msgid "directory stat info does not change after deleting a file"
 msgstr "информация статистики каталога не изменяется после удаления файла"
 
-#: builtin/update-index.c:213
+#: builtin/update-index.c:214
 msgid "directory stat info does not change after deleting a directory"
 msgstr "информация статистики каталога не изменяется после удаления каталога"
 
-#: builtin/update-index.c:220
+#: builtin/update-index.c:221
 msgid " OK"
 msgstr " OK"
 
-#: builtin/update-index.c:579
+#: builtin/update-index.c:589
 msgid "git update-index [<options>] [--] [<file>...]"
 msgstr "git update-index [<опции>] [--] [<файл>…]"
 
-#: builtin/update-index.c:936
+#: builtin/update-index.c:971
 msgid "continue refresh even when index needs update"
 msgstr "продолжить обновление, даже если индекс требует обновления"
 
-#: builtin/update-index.c:939
+#: builtin/update-index.c:974
 msgid "refresh: ignore submodules"
 msgstr "обновление: игнорировать подмодули"
 
-#: builtin/update-index.c:942
+#: builtin/update-index.c:977
 msgid "do not ignore new files"
 msgstr "не игнорировать новые файлы"
 
-#: builtin/update-index.c:944
+#: builtin/update-index.c:979
 msgid "let files replace directories and vice-versa"
 msgstr "разрешить файлам заменять каталоги и наоборот"
 
-#: builtin/update-index.c:946
+#: builtin/update-index.c:981
 msgid "notice files missing from worktree"
 msgstr "замечать файлы отсутствующие в рабочем каталоге"
 
-#: builtin/update-index.c:948
+#: builtin/update-index.c:983
 msgid "refresh even if index contains unmerged entries"
 msgstr "обновить, даже если в индексе имеются не слитые записи"
 
-#: builtin/update-index.c:951
+#: builtin/update-index.c:986
 msgid "refresh stat information"
 msgstr "обновить информацию о статусе файлов"
 
-#: builtin/update-index.c:955
+#: builtin/update-index.c:990
 msgid "like --refresh, but ignore assume-unchanged setting"
 msgstr "как --refresh, но игнорировать настройку assume-unchanged"
 
-#: builtin/update-index.c:959
+#: builtin/update-index.c:994
 msgid "<mode>,<object>,<path>"
 msgstr "<режим доступа>,<объект>,<путь>"
 
-#: builtin/update-index.c:960
+#: builtin/update-index.c:995
 msgid "add the specified entry to the index"
 msgstr "добавить указанную запись в индекс"
 
-#: builtin/update-index.c:969
+#: builtin/update-index.c:1005
 msgid "mark files as \"not changing\""
 msgstr "пометить файлы как «не измененные»"
 
-#: builtin/update-index.c:972
+#: builtin/update-index.c:1008
 msgid "clear assumed-unchanged bit"
 msgstr "убрать пометку assumed-unchanged"
 
-#: builtin/update-index.c:975
+#: builtin/update-index.c:1011
 msgid "mark files as \"index-only\""
 msgstr "пометить файлы как «только в индексе»"
 
-#: builtin/update-index.c:978
+#: builtin/update-index.c:1014
 msgid "clear skip-worktree bit"
 msgstr "убрать пометку skip-worktree"
 
-#: builtin/update-index.c:981
+#: builtin/update-index.c:1017
 msgid "add to index only; do not add content to object database"
 msgstr "только добавить в индекс; не добавлять содержимое в базу данных объектов"
 
-#: builtin/update-index.c:983
+#: builtin/update-index.c:1019
 msgid "remove named paths even if present in worktree"
 msgstr "удалить указанные пути, даже если они существуют в рабочем каталоге"
 
-#: builtin/update-index.c:985
+#: builtin/update-index.c:1021
 msgid "with --stdin: input lines are terminated by null bytes"
 msgstr "с опцией --stdin: строки на вводе отделяются НУЛЕВЫМ байтом"
 
-#: builtin/update-index.c:987
+#: builtin/update-index.c:1023
 msgid "read list of paths to be updated from standard input"
 msgstr "прочитать список обновляемых путей из стандартного ввода"
 
-#: builtin/update-index.c:991
+#: builtin/update-index.c:1027
 msgid "add entries from standard input to the index"
 msgstr "добавить записи из стандартного ввода в индекс"
 
-#: builtin/update-index.c:995
+#: builtin/update-index.c:1031
 msgid "repopulate stages #2 and #3 for the listed paths"
 msgstr "заново заполнить индекс #2 и #3 для указанных путей"
 
-#: builtin/update-index.c:999
+#: builtin/update-index.c:1035
 msgid "only update entries that differ from HEAD"
 msgstr "обновить только записи, которые отличаются от HEAD"
 
-#: builtin/update-index.c:1003
+#: builtin/update-index.c:1039
 msgid "ignore files missing from worktree"
 msgstr "игнорировать файлы, отсутствующие в рабочем каталоге"
 
-#: builtin/update-index.c:1006
+#: builtin/update-index.c:1042
 msgid "report actions to standard output"
 msgstr "вывести выполняемые действия на стандартный вывод"
 
-#: builtin/update-index.c:1008
+#: builtin/update-index.c:1044
 msgid "(for porcelains) forget saved unresolved conflicts"
 msgstr "(для машинной обработки) забыть сохраненные неразрешенные конфликты"
 
-#: builtin/update-index.c:1012
+#: builtin/update-index.c:1048
 msgid "write index in this format"
 msgstr "записать индекс в указанном формате"
 
-#: builtin/update-index.c:1014
+#: builtin/update-index.c:1050
 msgid "enable or disable split index"
 msgstr "разрешить или запретить раздельный индекс"
 
-#: builtin/update-index.c:1016
+#: builtin/update-index.c:1052
 msgid "enable/disable untracked cache"
 msgstr "включить/отключить кэш неотслеживаемых файлов"
 
-#: builtin/update-index.c:1018
+#: builtin/update-index.c:1054
 msgid "test if the filesystem supports untracked cache"
 msgstr "проверить, что файловая система поддерживает кэш неотслеживаемых файлов"
 
-#: builtin/update-index.c:1020
+#: builtin/update-index.c:1056
 msgid "enable untracked cache without testing the filesystem"
 msgstr "включить кэш неотслеживаемых файлов без проверки файловой системы"
 
-#: builtin/update-index.c:1022
+#: builtin/update-index.c:1058
 msgid "write out the index even if is not flagged as changed"
 msgstr "записать индекс, даже если он не помечен как измененный"
 
-#: builtin/update-index.c:1024
+#: builtin/update-index.c:1060
 msgid "enable or disable file system monitor"
 msgstr "включить или выключить мониторинг файловой системы"
 
-#: builtin/update-index.c:1026
+#: builtin/update-index.c:1062
 msgid "mark files as fsmonitor valid"
 msgstr "пометить файл как действительный в мониторе файловой системы"
 
-#: builtin/update-index.c:1029
+#: builtin/update-index.c:1065
 msgid "clear fsmonitor valid bit"
 msgstr "снять пометку действительности мониторе файловой системы"
 
-#: builtin/update-index.c:1127
+#: builtin/update-index.c:1168
 msgid ""
 "core.splitIndex is set to false; remove or change it, if you really want to "
 "enable split index"
 msgstr "параметр  core.splitIndex установлен в false; удалите или измените его, если вы действительно хотите включить разделенный индекс"
 
-#: builtin/update-index.c:1136
+#: builtin/update-index.c:1177
 msgid ""
 "core.splitIndex is set to true; remove or change it, if you really want to "
 "disable split index"
 msgstr "параметр  core.splitIndex установлен в true; удалите или измените его, если вы действительно хотите отключить разделенный индекс"
 
-#: builtin/update-index.c:1147
+#: builtin/update-index.c:1188
 msgid ""
 "core.untrackedCache is set to true; remove or change it, if you really want "
 "to disable the untracked cache"
 msgstr "параметр core.untrackedCache установлен true; удалите или измените его, если вы действительно хотите удалить кэш неотслеживаемых файлов"
 
-#: builtin/update-index.c:1151
+#: builtin/update-index.c:1192
 msgid "Untracked cache disabled"
 msgstr "Кэш неотслеживаемых файлов отключен"
 
-#: builtin/update-index.c:1159
+#: builtin/update-index.c:1200
 msgid ""
 "core.untrackedCache is set to false; remove or change it, if you really want"
 " to enable the untracked cache"
 msgstr "параметр core.untrackedCache установлен false; удалите или измените его, если вы действительно хотите включить кэш неотслеживаемых файлов"
 
-#: builtin/update-index.c:1163
+#: builtin/update-index.c:1204
 #, c-format
 msgid "Untracked cache enabled for '%s'"
 msgstr "Кэш неотслеживаемых файлов включен для «%s»"
 
-#: builtin/update-index.c:1171
+#: builtin/update-index.c:1212
 msgid "core.fsmonitor is unset; set it if you really want to enable fsmonitor"
 msgstr "параметр core.fsmonitor не установлен; установите его если вы действительно хотите включить мониторинг файловой системы"
 
-#: builtin/update-index.c:1175
+#: builtin/update-index.c:1216
 msgid "fsmonitor enabled"
 msgstr "мониторинг файловой системы включён"
 
-#: builtin/update-index.c:1178
+#: builtin/update-index.c:1219
 msgid ""
 "core.fsmonitor is set; remove it if you really want to disable fsmonitor"
 msgstr "параметр core.fsmonitor установлен; удалите его если вы действительно хотите выключить мониторинг файловой системы"
 
-#: builtin/update-index.c:1182
+#: builtin/update-index.c:1223
 msgid "fsmonitor disabled"
 msgstr "мониторинг файловой системы выключён"
 
@@ -13390,19 +18909,19 @@ msgstr "git update-ref [<опции>]
 msgid "git update-ref [<options>] --stdin [-z]"
 msgstr "git update-ref [<опции>] --stdin [-z]"
 
-#: builtin/update-ref.c:363
+#: builtin/update-ref.c:364
 msgid "delete the reference"
 msgstr "удалить ссылку"
 
-#: builtin/update-ref.c:365
+#: builtin/update-ref.c:366
 msgid "update <refname> not the one it points to"
 msgstr "обновить <имя-ссылки> а не то, на что она указывает"
 
-#: builtin/update-ref.c:366
+#: builtin/update-ref.c:367
 msgid "stdin has NUL-terminated arguments"
 msgstr "ввод отделённый НУЛЕВЫМИ символами"
 
-#: builtin/update-ref.c:367
+#: builtin/update-ref.c:368
 msgid "read updates from stdin"
 msgstr "прочитать обновления из стандартного ввода"
 
@@ -13414,15 +18933,35 @@ msgstr "git update-server-info [--force]
 msgid "update the info files from scratch"
 msgstr "обновить информацию о серверах с нуля"
 
-#: builtin/verify-commit.c:18
+#: builtin/upload-pack.c:11
+msgid "git upload-pack [<options>] <dir>"
+msgstr "git upload-pack [<опции>] <каталог>"
+
+#: builtin/upload-pack.c:23 t/helper/test-serve-v2.c:17
+msgid "quit after a single request/response exchange"
+msgstr "выход после обмена одним запросом/ответом"
+
+#: builtin/upload-pack.c:25
+msgid "exit immediately after initial ref advertisement"
+msgstr "выходить сразу после начального объявления списка ссылок"
+
+#: builtin/upload-pack.c:27
+msgid "do not try <directory>/.git/ if <directory> is no Git directory"
+msgstr "не проверять <каталог>/.git/ если <каталог> не является каталогом Git"
+
+#: builtin/upload-pack.c:29
+msgid "interrupt transfer after <n> seconds of inactivity"
+msgstr "прервать передачу после <кол> секунд простоя"
+
+#: builtin/verify-commit.c:20
 msgid "git verify-commit [-v | --verbose] <commit>..."
 msgstr "git verify-commit [-v | --verbose] <коммит>…"
 
-#: builtin/verify-commit.c:73
+#: builtin/verify-commit.c:76
 msgid "print commit contents"
 msgstr "вывести содержимое коммита"
 
-#: builtin/verify-commit.c:74 builtin/verify-tag.c:38
+#: builtin/verify-commit.c:77 builtin/verify-tag.c:38
 msgid "print raw gpg status output"
 msgstr "выводить сырой вывод статуса от gpg"
 
@@ -13446,215 +18985,471 @@ msgstr "git verify-tag [-v | --verbose]
 msgid "print tag contents"
 msgstr "вывести содержимое метки"
 
-#: builtin/worktree.c:17
-msgid "git worktree add [<options>] <path> [<branch>]"
-msgstr "git worktree add [<опции>] <путь> [<ветка>]"
-
 #: builtin/worktree.c:18
+msgid "git worktree add [<options>] <path> [<commit-ish>]"
+msgstr "git worktree add [<опции>] <путь> [<указатель-коммита>]"
+
+#: builtin/worktree.c:19
 msgid "git worktree list [<options>]"
 msgstr "git worktree list [<опции>]"
 
-#: builtin/worktree.c:19
+#: builtin/worktree.c:20
 msgid "git worktree lock [<options>] <path>"
 msgstr "git worktree lock [<опции>] <путь>"
 
-#: builtin/worktree.c:20
+#: builtin/worktree.c:21
+msgid "git worktree move <worktree> <new-path>"
+msgstr "git worktree move <рабочий-каталог> <новый-путь>"
+
+#: builtin/worktree.c:22
 msgid "git worktree prune [<options>]"
 msgstr "git worktree prune [<опции>]"
 
-#: builtin/worktree.c:21
+#: builtin/worktree.c:23
+msgid "git worktree remove [<options>] <worktree>"
+msgstr "git worktree remove [<опции>] <рабочий-каталог>"
+
+#: builtin/worktree.c:24
 msgid "git worktree unlock <path>"
 msgstr "git worktree unlock <путь>"
 
-#: builtin/worktree.c:58
+#: builtin/worktree.c:61 builtin/worktree.c:891
+#, c-format
+msgid "failed to delete '%s'"
+msgstr "не удалось удалить «%s»"
+
+#: builtin/worktree.c:80
 #, c-format
 msgid "Removing worktrees/%s: not a valid directory"
 msgstr "Удаление рабочих каталогов/%s: не является каталогом"
 
-#: builtin/worktree.c:64
+#: builtin/worktree.c:86
 #, c-format
 msgid "Removing worktrees/%s: gitdir file does not exist"
 msgstr "Удаление рабочих каталогов/%s: файл gitdir не существует"
 
-#: builtin/worktree.c:69 builtin/worktree.c:78
+#: builtin/worktree.c:91 builtin/worktree.c:100
 #, c-format
 msgid "Removing worktrees/%s: unable to read gitdir file (%s)"
 msgstr "Удаление рабочих каталогов/%s: не удалось прочитать файл gitdir (%s)"
 
-#: builtin/worktree.c:88
+#: builtin/worktree.c:110
 #, c-format
 msgid ""
 "Removing worktrees/%s: short read (expected %<PRIuMAX> bytes, read "
 "%<PRIuMAX>)"
 msgstr "Удаление рабочего каталога/%s: прочитано мало данных (ожидалось %<PRIuMAX> байт, прочитано %<PRIuMAX>)"
 
-#: builtin/worktree.c:96
+#: builtin/worktree.c:118
 #, c-format
 msgid "Removing worktrees/%s: invalid gitdir file"
 msgstr "Удаление рабочих каталогов/%s: недействительный файл gitdir"
 
-#: builtin/worktree.c:112
+#: builtin/worktree.c:127
 #, c-format
 msgid "Removing worktrees/%s: gitdir file points to non-existent location"
 msgstr "Удаление рабочих каталогов/%s: gitdir указывает на несуществующее расположение"
 
-#: builtin/worktree.c:159
+#: builtin/worktree.c:166
 msgid "report pruned working trees"
 msgstr "вывести список удаленных рабочих каталогов"
 
-#: builtin/worktree.c:161
+#: builtin/worktree.c:168
 msgid "expire working trees older than <time>"
 msgstr "удалить рабочие каталоги старее чем <дата-окончания>"
 
-#: builtin/worktree.c:236
+#: builtin/worktree.c:235
 #, c-format
 msgid "'%s' already exists"
 msgstr "«%s» уже существует"
 
-#: builtin/worktree.c:267
+#: builtin/worktree.c:252
+#, c-format
+msgid "unable to re-add worktree '%s'"
+msgstr ""
+
+#: builtin/worktree.c:257
+#, c-format
+msgid ""
+"'%s' is a missing but locked worktree;\n"
+"use 'add -f -f' to override, or 'unlock' and 'prune' or 'remove' to clear"
+msgstr ""
+
+#: builtin/worktree.c:259
+#, c-format
+msgid ""
+"'%s' is a missing but already registered worktree;\n"
+"use 'add -f' to override, or 'prune' or 'remove' to clear"
+msgstr ""
+
+#: builtin/worktree.c:302
 #, c-format
 msgid "could not create directory of '%s'"
 msgstr "не удалось создать каталог «%s»"
 
-#: builtin/worktree.c:306
+#: builtin/worktree.c:432 builtin/worktree.c:438
+#, c-format
+msgid "Preparing worktree (new branch '%s')"
+msgstr ""
+
+#: builtin/worktree.c:434
+#, c-format
+msgid "Preparing worktree (resetting branch '%s'; was at %s)"
+msgstr ""
+
+#: builtin/worktree.c:443
+#, c-format
+msgid "Preparing worktree (checking out '%s')"
+msgstr ""
+
+#: builtin/worktree.c:449
 #, c-format
-msgid "Preparing %s (identifier %s)"
-msgstr "Подготовка %s (идентификатор %s)"
+msgid "Preparing worktree (detached HEAD %s)"
+msgstr ""
 
-#: builtin/worktree.c:368
+#: builtin/worktree.c:490
 msgid "checkout <branch> even if already checked out in other worktree"
 msgstr "переключиться на <ветка> даже если она уже активна в другом рабочесм каталоге"
 
-#: builtin/worktree.c:370
+#: builtin/worktree.c:493
 msgid "create a new branch"
 msgstr "создать новую ветку"
 
-#: builtin/worktree.c:372
+#: builtin/worktree.c:495
 msgid "create or reset a branch"
 msgstr "создать или перейти на ветку"
 
-#: builtin/worktree.c:374
+#: builtin/worktree.c:497
 msgid "populate the new working tree"
 msgstr "наполнить новый рабочий каталог"
 
-#: builtin/worktree.c:375
+#: builtin/worktree.c:498
 msgid "keep the new working tree locked"
 msgstr "держать рабочий каталог заблокированным"
 
-#: builtin/worktree.c:377
+#: builtin/worktree.c:501
 msgid "set up tracking mode (see git-branch(1))"
 msgstr "настроить режим отслеживания ветки (смотрите git-branch(1))"
 
-#: builtin/worktree.c:380
+#: builtin/worktree.c:504
 msgid "try to match the new branch name with a remote-tracking branch"
 msgstr "пытаться найти соответствие имени новой ветки с именем внешней ветки"
 
-#: builtin/worktree.c:388
+#: builtin/worktree.c:512
 msgid "-b, -B, and --detach are mutually exclusive"
 msgstr "-b, -B и --detach нельзя использовать одновременно"
 
-#: builtin/worktree.c:453
+#: builtin/worktree.c:573
 msgid "--[no-]track can only be used if a new branch is created"
 msgstr "--[no-]track можно использовать только когда вы создаёте новую ветку"
 
-#: builtin/worktree.c:553
+#: builtin/worktree.c:673
 msgid "reason for locking"
 msgstr "причина блокировки"
 
-#: builtin/worktree.c:565 builtin/worktree.c:598
+#: builtin/worktree.c:685 builtin/worktree.c:718 builtin/worktree.c:792
+#: builtin/worktree.c:919
+#, c-format
+msgid "'%s' is not a working tree"
+msgstr "«%s» не является рабочим каталогом"
+
+#: builtin/worktree.c:687 builtin/worktree.c:720
+msgid "The main working tree cannot be locked or unlocked"
+msgstr "Главный рабочий каталог не может быть заблокирован или разблокирован"
+
+#: builtin/worktree.c:692
+#, c-format
+msgid "'%s' is already locked, reason: %s"
+msgstr "«%s» уже заблокирован, причина: %s"
+
+#: builtin/worktree.c:694
+#, c-format
+msgid "'%s' is already locked"
+msgstr "«%s» уже заблокирован"
+
+#: builtin/worktree.c:722
+#, c-format
+msgid "'%s' is not locked"
+msgstr "«%s» не заблокирован"
+
+#: builtin/worktree.c:763
+msgid "working trees containing submodules cannot be moved or removed"
+msgstr ""
+
+#: builtin/worktree.c:771
+msgid "force move even if worktree is dirty or locked"
+msgstr ""
+
+#: builtin/worktree.c:794 builtin/worktree.c:921
+#, c-format
+msgid "'%s' is a main working tree"
+msgstr ""
+
+#: builtin/worktree.c:799
+#, c-format
+msgid "could not figure out destination name from '%s'"
+msgstr ""
+
+#: builtin/worktree.c:805
+#, c-format
+msgid "target '%s' already exists"
+msgstr ""
+
+#: builtin/worktree.c:813
+#, c-format
+msgid ""
+"cannot move a locked working tree, lock reason: %s\n"
+"use 'move -f -f' to override or unlock first"
+msgstr ""
+
+#: builtin/worktree.c:815
+msgid ""
+"cannot move a locked working tree;\n"
+"use 'move -f -f' to override or unlock first"
+msgstr ""
+
+#: builtin/worktree.c:818
+#, c-format
+msgid "validation failed, cannot move working tree: %s"
+msgstr ""
+
+#: builtin/worktree.c:823
+#, c-format
+msgid "failed to move '%s' to '%s'"
+msgstr ""
+
+#: builtin/worktree.c:871
+#, c-format
+msgid "failed to run 'git status' on '%s'"
+msgstr ""
+
+#: builtin/worktree.c:875
+#, c-format
+msgid "'%s' is dirty, use --force to delete it"
+msgstr ""
+
+#: builtin/worktree.c:880
+#, c-format
+msgid "failed to run 'git status' on '%s', code %d"
+msgstr ""
+
+#: builtin/worktree.c:903
+msgid "force removal even if worktree is dirty or locked"
+msgstr ""
+
+#: builtin/worktree.c:926
+#, c-format
+msgid ""
+"cannot remove a locked working tree, lock reason: %s\n"
+"use 'remove -f -f' to override or unlock first"
+msgstr ""
+
+#: builtin/worktree.c:928
+msgid ""
+"cannot remove a locked working tree;\n"
+"use 'remove -f -f' to override or unlock first"
+msgstr ""
+
+#: builtin/worktree.c:931
+#, c-format
+msgid "validation failed, cannot remove working tree: %s"
+msgstr ""
+
+#: builtin/write-tree.c:15
+msgid "git write-tree [--missing-ok] [--prefix=<prefix>/]"
+msgstr "git write-tree [--missing-ok] [--prefix=<префикс>/]"
+
+#: builtin/write-tree.c:28
+msgid "<prefix>/"
+msgstr "<префикс>/"
+
+#: builtin/write-tree.c:29
+msgid "write tree object for a subdirectory <prefix>"
+msgstr "вывести объект дерева для подкаталога с <префикс>"
+
+#: builtin/write-tree.c:31
+msgid "only useful for debugging"
+msgstr "используется только при отладке"
+
+#: credential-cache--daemon.c:223
+#, c-format
+msgid ""
+"The permissions on your socket directory are too loose; other\n"
+"users may be able to read your cached credentials. Consider running:\n"
+"\n"
+"\tchmod 0700 %s"
+msgstr "Права доступа к вашему каталогу сокетов слишком свободны; друге пользователи могуи читать ваши закэшированные пароли доступа. Обдумайте запуск команды:\n\n\tchmod 0700 %s"
+
+#: credential-cache--daemon.c:272
+msgid "print debugging messages to stderr"
+msgstr "вывод отладочных сообщений на stderr"
+
+#: t/helper/test-reach.c:152
+#, c-format
+msgid "commit %s is not marked reachable"
+msgstr ""
+
+#: t/helper/test-reach.c:162
+msgid "too many commits marked reachable"
+msgstr ""
+
+#: t/helper/test-serve-v2.c:7
+msgid "test-tool serve-v2 [<options>]"
+msgstr ""
+
+#: t/helper/test-serve-v2.c:19
+msgid "exit immediately after advertising capabilities"
+msgstr ""
+
+#: git.c:27
+msgid ""
+"git [--version] [--help] [-C <path>] [-c <name>=<value>]\n"
+"           [--exec-path[=<path>]] [--html-path] [--man-path] [--info-path]\n"
+"           [-p | --paginate | -P | --no-pager] [--no-replace-objects] [--bare]\n"
+"           [--git-dir=<path>] [--work-tree=<path>] [--namespace=<name>]\n"
+"           <command> [<args>]"
+msgstr "git [--version] [--help] [-C <путь>] [-c <имя>=<значение>]\n           [--exec-path[=<путь>]] [--html-path] [--man-path] [--info-path]\n           [-p | --paginate | -P | --no-pager] [--no-replace-objects] [--bare]\n           [--git-dir=<путь>] [--work-tree=<путь>] [--namespace=<имя>]\n           <команда> [<аргументы>]"
+
+#: git.c:34
+msgid ""
+"'git help -a' and 'git help -g' list available subcommands and some\n"
+"concept guides. See 'git help <command>' or 'git help <concept>'\n"
+"to read about a specific subcommand or concept."
+msgstr "«git help -а» и «git help -g» выводит список доступных подкоманд и\nнекоторые руководства по темам. Запустите «git help <команда>» или\n«git help <термин>», чтобы прочесть о конкретных подкоманде или теме."
+
+#: git.c:185
+#, c-format
+msgid "no directory given for --git-dir\n"
+msgstr ""
+
+#: git.c:199
+#, c-format
+msgid "no namespace given for --namespace\n"
+msgstr ""
+
+#: git.c:213
 #, c-format
-msgid "'%s' is not a working tree"
-msgstr "«%s» не является рабочим каталогом"
+msgid "no directory given for --work-tree\n"
+msgstr ""
 
-#: builtin/worktree.c:567 builtin/worktree.c:600
-msgid "The main working tree cannot be locked or unlocked"
-msgstr "Главный рабочий каталог не может быть заблокирован или разблокирован"
+#: git.c:227
+#, c-format
+msgid "no prefix given for --super-prefix\n"
+msgstr ""
 
-#: builtin/worktree.c:572
+#: git.c:249
 #, c-format
-msgid "'%s' is already locked, reason: %s"
-msgstr "«%s» уже заблокирован, причина: %s"
+msgid "-c expects a configuration string\n"
+msgstr ""
 
-#: builtin/worktree.c:574
+#: git.c:287
 #, c-format
-msgid "'%s' is already locked"
-msgstr "«%s» уже заблокирован"
+msgid "no directory given for -C\n"
+msgstr ""
 
-#: builtin/worktree.c:602
+#: git.c:313
 #, c-format
-msgid "'%s' is not locked"
-msgstr "«%s» не заблокирован"
+msgid "unknown option: %s\n"
+msgstr ""
 
-#: builtin/write-tree.c:14
-msgid "git write-tree [--missing-ok] [--prefix=<prefix>/]"
-msgstr "git write-tree [--missing-ok] [--prefix=<префикс>/]"
+#: git.c:359
+#, c-format
+msgid "while expanding alias '%s': '%s'"
+msgstr ""
 
-#: builtin/write-tree.c:27
-msgid "<prefix>/"
-msgstr "<префикс>/"
+#: git.c:368
+#, c-format
+msgid ""
+"alias '%s' changes environment variables.\n"
+"You can use '!git' in the alias to do this"
+msgstr ""
 
-#: builtin/write-tree.c:28
-msgid "write tree object for a subdirectory <prefix>"
-msgstr "вывести объект дерева для подкаталога с <префикс>"
+#: git.c:376
+#, c-format
+msgid "empty alias for %s"
+msgstr ""
 
-#: builtin/write-tree.c:31
-msgid "only useful for debugging"
-msgstr "используется только при отладке"
+#: git.c:379
+#, c-format
+msgid "recursive alias: %s"
+msgstr ""
 
-#: upload-pack.c:24
-msgid "git upload-pack [<options>] <dir>"
-msgstr "git upload-pack [<опции>] <каталог>"
+#: git.c:459
+msgid "write failure on standard output"
+msgstr ""
 
-#: upload-pack.c:1041
-msgid "quit after a single request/response exchange"
-msgstr "выход после обмена одним запросом/ответом"
+#: git.c:461
+msgid "unknown write failure on standard output"
+msgstr ""
 
-#: upload-pack.c:1043
-msgid "exit immediately after initial ref advertisement"
-msgstr "выходить сразу после начального объявления списка ссылок"
+#: git.c:463
+msgid "close failed on standard output"
+msgstr ""
 
-#: upload-pack.c:1045
-msgid "do not try <directory>/.git/ if <directory> is no Git directory"
-msgstr "не проверять <каталог>/.git/ если <каталог> не является каталогом Git"
+#: git.c:797
+#, c-format
+msgid "alias loop detected: expansion of '%s' does not terminate:%s"
+msgstr ""
 
-#: upload-pack.c:1047
-msgid "interrupt transfer after <n> seconds of inactivity"
-msgstr "прервать передачу после <кол> секунд простоя"
+#: git.c:847
+#, c-format
+msgid "cannot handle %s as a builtin"
+msgstr ""
 
-#: credential-cache--daemon.c:222
+#: git.c:860
 #, c-format
 msgid ""
-"The permissions on your socket directory are too loose; other\n"
-"users may be able to read your cached credentials. Consider running:\n"
+"usage: %s\n"
 "\n"
-"\tchmod 0700 %s"
-msgstr "Права доступа к вашему каталогу сокетов слишком свободны; друге пользователи могуи читать ваши закэшированные пароли доступа. Обдумайте запуск команды:\n\n\tchmod 0700 %s"
+msgstr ""
 
-#: credential-cache--daemon.c:271
-msgid "print debugging messages to stderr"
-msgstr "вывод отладочных сообщений на stderr"
+#: git.c:880
+#, c-format
+msgid "expansion of alias '%s' failed; '%s' is not a git command\n"
+msgstr ""
 
-#: git.c:15
-msgid ""
-"'git help -a' and 'git help -g' list available subcommands and some\n"
-"concept guides. See 'git help <command>' or 'git help <concept>'\n"
-"to read about a specific subcommand or concept."
-msgstr "«git help -а» и «git help -g» выводит список доступных подкоманд и\nнекоторые руководства по темам. Запустите «git help <команда>» или\n«git help <термин>», чтобы прочесть о конкретных подкоманде или теме."
+#: git.c:892
+#, c-format
+msgid "failed to run command '%s': %s\n"
+msgstr ""
 
-#: http.c:339
+#: http.c:378
 #, c-format
 msgid "negative value for http.postbuffer; defaulting to %d"
 msgstr "отрицательное значение http.postbuffer; использую стандартное значение %d"
 
-#: http.c:360
+#: http.c:399
 msgid "Delegation control is not supported with cURL < 7.22.0"
 msgstr "Делегация проверки полномочий не поддерживается с cURL < 7.22.0"
 
-#: http.c:369
+#: http.c:408
 msgid "Public key pinning not supported with cURL < 7.44.0"
 msgstr "Public key pinning не поддерживается с cURL < 7.44.0"
 
-#: http.c:1791
+#: http.c:876
+msgid "CURLSSLOPT_NO_REVOKE not supported with cURL < 7.44.0"
+msgstr ""
+
+#: http.c:949
+msgid "Protocol restrictions not supported with cURL < 7.19.4"
+msgstr ""
+
+#: http.c:1085
+#, c-format
+msgid "Unsupported SSL backend '%s'. Supported SSL backends:"
+msgstr ""
+
+#: http.c:1092
+#, c-format
+msgid "Could not set SSL backend to '%s': cURL was built without SSL backends"
+msgstr ""
+
+#: http.c:1096
+#, c-format
+msgid "Could not set SSL backend to '%s': already set"
+msgstr ""
+
+#: http.c:1965
 #, c-format
 msgid ""
 "unable to update url base from redirection:\n"
@@ -13662,146 +19457,794 @@ msgid ""
 "   redirect: %s"
 msgstr "не удалось обновить базовый url из переадресации:\n  запрошено: %s\n   переадресовано: %s"
 
-#: remote-curl.c:324
+#: remote-curl.c:157
+#, c-format
+msgid "invalid quoting in push-option value: '%s'"
+msgstr ""
+
+#: remote-curl.c:254
+#, c-format
+msgid "%sinfo/refs not valid: is this a git repository?"
+msgstr ""
+
+#: remote-curl.c:355
+msgid "invalid server response; expected service, got flush packet"
+msgstr ""
+
+#: remote-curl.c:386
+#, c-format
+msgid "invalid server response; got '%s'"
+msgstr ""
+
+#: remote-curl.c:446
+#, c-format
+msgid "repository '%s' not found"
+msgstr ""
+
+#: remote-curl.c:450
+#, c-format
+msgid "Authentication failed for '%s'"
+msgstr ""
+
+#: remote-curl.c:454
+#, c-format
+msgid "unable to access '%s': %s"
+msgstr "«%s» недоступно: %s"
+
+#: remote-curl.c:460
 #, c-format
 msgid "redirecting to %s"
 msgstr "переадресация на %s"
 
-#: list-objects-filter-options.h:54
+#: remote-curl.c:584
+msgid "shouldn't have EOF when not gentle on EOF"
+msgstr ""
+
+#: remote-curl.c:664
+msgid "unable to rewind rpc post data - try increasing http.postBuffer"
+msgstr ""
+
+#: remote-curl.c:724
+#, c-format
+msgid "RPC failed; %s"
+msgstr ""
+
+#: remote-curl.c:764
+msgid "cannot handle pushes this big"
+msgstr ""
+
+#: remote-curl.c:879
+#, c-format
+msgid "cannot deflate request; zlib deflate error %d"
+msgstr ""
+
+#: remote-curl.c:883
+#, c-format
+msgid "cannot deflate request; zlib end error %d"
+msgstr ""
+
+#: remote-curl.c:1014
+msgid "dumb http transport does not support shallow capabilities"
+msgstr ""
+
+#: remote-curl.c:1028
+msgid "fetch failed."
+msgstr ""
+
+#: remote-curl.c:1076
+msgid "cannot fetch by sha1 over smart http"
+msgstr ""
+
+#: remote-curl.c:1120 remote-curl.c:1126
+#, c-format
+msgid "protocol error: expected sha/ref, got '%s'"
+msgstr ""
+
+#: remote-curl.c:1138 remote-curl.c:1252
+#, c-format
+msgid "http transport does not support %s"
+msgstr ""
+
+#: remote-curl.c:1174
+msgid "git-http-push failed"
+msgstr ""
+
+#: remote-curl.c:1360
+msgid "remote-curl: usage: git remote-curl <remote> [<url>]"
+msgstr ""
+
+#: remote-curl.c:1392
+msgid "remote-curl: error reading command stream from git"
+msgstr ""
+
+#: remote-curl.c:1399
+msgid "remote-curl: fetch attempted without a local repo"
+msgstr ""
+
+#: remote-curl.c:1439
+#, c-format
+msgid "remote-curl: unknown command '%s' from git"
+msgstr ""
+
+#: list-objects-filter-options.h:61
 msgid "args"
 msgstr "аргументы"
 
-#: list-objects-filter-options.h:55
+#: list-objects-filter-options.h:62
 msgid "object filtering"
 msgstr "фильтрация объектов"
 
-#: common-cmds.h:9
-msgid "start a working area (see also: git help tutorial)"
-msgstr "создание рабочей области (смотрите также: git help tutorial)"
+#: parse-options.h:170
+msgid "expiry-date"
+msgstr "дата-окончания"
 
-#: common-cmds.h:10
-msgid "work on the current change (see also: git help everyday)"
-msgstr "работа с текущими изменениями (смотрите также: git help everyday)"
+#: parse-options.h:184
+msgid "no-op (backward compatibility)"
+msgstr "ничего не делает (оставлено для обратной совместимости)"
 
-#: common-cmds.h:11
-msgid "examine the history and state (see also: git help revisions)"
-msgstr "просмотр истории и текущего состояния (смотрите также: git help revisions)"
+#: parse-options.h:304
+msgid "be more verbose"
+msgstr "быть многословнее"
 
-#: common-cmds.h:12
-msgid "grow, mark and tweak your common history"
-msgstr "выращивание, отметка и настройка вашей общей истории"
+#: parse-options.h:306
+msgid "be more quiet"
+msgstr "тихий режим"
 
-#: common-cmds.h:13
-msgid "collaborate (see also: git help workflows)"
-msgstr "совместная работа (смотрите также: git help workflows)"
+#: parse-options.h:312
+msgid "use <n> digits to display SHA-1s"
+msgstr "использовать <n> цифр для вывода SHA-1"
+
+#: parse-options.h:331
+msgid "how to strip spaces and #comments from message"
+msgstr "как удалять пробелы и #комментарии из сообщения коммита"
+
+#: ref-filter.h:101
+msgid "key"
+msgstr "ключ"
+
+#: ref-filter.h:101
+msgid "field name to sort on"
+msgstr "имя поля, по которому выполнить сортировку"
+
+#: rerere.h:44
+msgid "update the index with reused conflict resolution if possible"
+msgstr "обновить индекс с помощью переиспользования разрешения конфликта, если возможно"
 
-#: common-cmds.h:17
+#: command-list.h:50
 msgid "Add file contents to the index"
 msgstr "Добавление содержимого файла в индекс"
 
-#: common-cmds.h:18
+#: command-list.h:51
+msgid "Apply a series of patches from a mailbox"
+msgstr "Применение серии патчей из почтового сообщения"
+
+#: command-list.h:52
+msgid "Annotate file lines with commit information"
+msgstr "Аннотирование строк файла информацией о коммитах"
+
+#: command-list.h:53
+msgid "Apply a patch to files and/or to the index"
+msgstr "Применение патча к файлам и/или индексу"
+
+#: command-list.h:54
+msgid "Import a GNU Arch repository into Git"
+msgstr "Импортирование GNU Arch репозитория в Git"
+
+#: command-list.h:55
+msgid "Create an archive of files from a named tree"
+msgstr "Создание архива файлов из указанного дерева"
+
+#: command-list.h:56
 msgid "Use binary search to find the commit that introduced a bug"
-msgstr "Выполнить двоичный поиск изменения, которое вносит ошибку"
+msgstr "Выполнение двоичного поиска коммита, который вносит ошибку"
+
+#: command-list.h:57
+msgid "Show what revision and author last modified each line of a file"
+msgstr "Показ редакции и автора последнего изменившего каждую строку файла"
 
-#: common-cmds.h:19
+#: command-list.h:58
 msgid "List, create, or delete branches"
-msgstr "Вывод списка веток,  их создание или удаление"
+msgstr "Вывод списка, создание или удаление веток"
+
+#: command-list.h:59
+msgid "Move objects and refs by archive"
+msgstr "Перемещение объектов и ссылок по архиву"
+
+#: command-list.h:60
+msgid "Provide content or type and size information for repository objects"
+msgstr "Вывод содержимого или типа и информации о размере для объектов репозитория"
+
+#: command-list.h:61
+msgid "Display gitattributes information"
+msgstr "Вывод информации из gitattributes"
+
+#: command-list.h:62
+msgid "Debug gitignore / exclude files"
+msgstr "Отладка файлов gitignore / exclude"
 
-#: common-cmds.h:20
+#: command-list.h:63
+msgid "Show canonical names and email addresses of contacts"
+msgstr "Вывод каноничных имён и адресов электронной почты контактов"
+
+#: command-list.h:64
 msgid "Switch branches or restore working tree files"
 msgstr "Переключение веток или восстановление файлов в рабочем каталоге"
 
-#: common-cmds.h:21
+#: command-list.h:65
+msgid "Copy files from the index to the working tree"
+msgstr "Копирование файлов из индекса в рабочий каталог"
+
+#: command-list.h:66
+msgid "Ensures that a reference name is well formed"
+msgstr "Удостовериться, что имя ссылки правильно сформировано"
+
+#: command-list.h:67
+msgid "Find commits yet to be applied to upstream"
+msgstr "Поиск коммитов которые еще не применены вышестоящим репозиторием"
+
+#: command-list.h:68
+msgid "Apply the changes introduced by some existing commits"
+msgstr "Применение изменений, сделанных в каком-то существующем коммите"
+
+#: command-list.h:69
+msgid "Graphical alternative to git-commit"
+msgstr "Графическая альтернатива для git-commit"
+
+#: command-list.h:70
+msgid "Remove untracked files from the working tree"
+msgstr "Удаление неотслеживаемых файлов из рабочего каталога"
+
+#: command-list.h:71
 msgid "Clone a repository into a new directory"
 msgstr "Клонирование репозитория в новый каталог"
 
-#: common-cmds.h:22
+#: command-list.h:72
+msgid "Display data in columns"
+msgstr "Вывод данных по колонкам"
+
+#: command-list.h:73
 msgid "Record changes to the repository"
 msgstr "Запись изменений в репозиторий"
 
-#: common-cmds.h:23
+#: command-list.h:74
+msgid "Write and verify Git commit-graph files"
+msgstr "Запись и проверка commit-graph файлов Git"
+
+#: command-list.h:75
+msgid "Create a new commit object"
+msgstr "Создание нового объекта коммита"
+
+#: command-list.h:76
+msgid "Get and set repository or global options"
+msgstr "Получение и установка глобальных опций или опций репозитория"
+
+#: command-list.h:77
+msgid "Count unpacked number of objects and their disk consumption"
+msgstr "Подсчет количества неупакованных объектов и их потребления диска"
+
+#: command-list.h:78
+msgid "Retrieve and store user credentials"
+msgstr "Получение и сохранение учетных записей пользователя"
+
+#: command-list.h:79
+msgid "Helper to temporarily store passwords in memory"
+msgstr "Помощник для временного хранения паролей в памяти"
+
+#: command-list.h:80
+msgid "Helper to store credentials on disk"
+msgstr "Помощник для хранения учетных записей на диске"
+
+#: command-list.h:81
+msgid "Export a single commit to a CVS checkout"
+msgstr "Экспорт единственного коммита в виде рабочей копии CVS"
+
+#: command-list.h:82
+msgid "Salvage your data out of another SCM people love to hate"
+msgstr "Спасение ваших данных из другой СКВ которую люди любят ненавидеть"
+
+#: command-list.h:83
+msgid "A CVS server emulator for Git"
+msgstr "Эмулятор сервера CVS для Git"
+
+#: command-list.h:84
+msgid "A really simple server for Git repositories"
+msgstr "Очень простой сервер для Git репозиториев"
+
+#: command-list.h:85
+msgid "Give an object a human readable name based on an available ref"
+msgstr "Присвоение объекту удобочитаемое имя на основе доступной ссылки"
+
+#: command-list.h:86
 msgid "Show changes between commits, commit and working tree, etc"
 msgstr "Вывод разницы между коммитами, коммитом и рабочим каталогом и т.д."
 
-#: common-cmds.h:24
+#: command-list.h:87
+msgid "Compares files in the working tree and the index"
+msgstr "Сравнение седержимого файлов в рабочем каталоге с файлами в индексе"
+
+#: command-list.h:88
+msgid "Compare a tree to the working tree or index"
+msgstr "Сравнение дерева файлов с рабочим каталогом или индексом"
+
+#: command-list.h:89
+msgid "Compares the content and mode of blobs found via two tree objects"
+msgstr "Сравнение содержимого и режима двоичных объектов, найденных по двум объектам дерева"
+
+#: command-list.h:90
+msgid "Show changes using common diff tools"
+msgstr "Показ изменений с помощью распространенных утилит сравнения"
+
+#: command-list.h:91
+msgid "Git data exporter"
+msgstr "Экспорт данных Git"
+
+#: command-list.h:92
+msgid "Backend for fast Git data importers"
+msgstr "Внутренний интерфейс для быстрого импорта данных Git"
+
+#: command-list.h:93
 msgid "Download objects and refs from another repository"
 msgstr "Загрузка объектов и ссылок из другого репозитория"
 
-#: common-cmds.h:25
+#: command-list.h:94
+msgid "Receive missing objects from another repository"
+msgstr "Получение недостающих объектов из другого репозитория"
+
+#: command-list.h:95
+msgid "Rewrite branches"
+msgstr "Перезапись веток"
+
+#: command-list.h:96
+msgid "Produce a merge commit message"
+msgstr "Создание сообщения коммита для слияния"
+
+#: command-list.h:97
+msgid "Output information on each ref"
+msgstr "Вывод информации о каждой ссылке"
+
+#: command-list.h:98
+msgid "Prepare patches for e-mail submission"
+msgstr "Подготовка патчей для отправки по электронной почте"
+
+#: command-list.h:99
+msgid "Verifies the connectivity and validity of the objects in the database"
+msgstr "Проверка связности и валидности объектов в базе данных"
+
+#: command-list.h:100
+msgid "Cleanup unnecessary files and optimize the local repository"
+msgstr "Очистка ненужных файлов и оптимизация локального репозитория"
+
+#: command-list.h:101
+msgid "Extract commit ID from an archive created using git-archive"
+msgstr "Извлечение идентификатора коммита из архива, созданного с помощью git-archive"
+
+#: command-list.h:102
 msgid "Print lines matching a pattern"
 msgstr "Вывод строк, соответствующих шаблону"
 
-#: common-cmds.h:26
+#: command-list.h:103
+msgid "A portable graphical interface to Git"
+msgstr "Портативный графический интерфейс для Git"
+
+#: command-list.h:104
+msgid "Compute object ID and optionally creates a blob from a file"
+msgstr "Вычисление идентификатора объекта и возможное создание двоичного объекта из файла"
+
+#: command-list.h:105
+msgid "Display help information about Git"
+msgstr "Отображение справочной информации о Git"
+
+#: command-list.h:106
+msgid "Server side implementation of Git over HTTP"
+msgstr "Серверная реализация протокола Git над HTTP"
+
+#: command-list.h:107
+msgid "Download from a remote Git repository via HTTP"
+msgstr "Загрузка из внешнего репозитория Git с помощью HTTP"
+
+#: command-list.h:108
+msgid "Push objects over HTTP/DAV to another repository"
+msgstr "Отправка объектов в другой репозиторий с помощью HTTP/DAV"
+
+#: command-list.h:109
+msgid "Send a collection of patches from stdin to an IMAP folder"
+msgstr "Отправка коллекции патчей из стандартного ввода в папку IMAP"
+
+#: command-list.h:110
+msgid "Build pack index file for an existing packed archive"
+msgstr "Построение файла индекса для существующего упакованного архива"
+
+#: command-list.h:111
 msgid "Create an empty Git repository or reinitialize an existing one"
 msgstr "Создание пустого репозитория Git или переинициализация существующего"
 
-#: common-cmds.h:27
+#: command-list.h:112
+msgid "Instantly browse your working repository in gitweb"
+msgstr "Мгновенный просмотр вашего рабочего репозитория в gitweb"
+
+#: command-list.h:113
+msgid "Add or parse structured information in commit messages"
+msgstr "Добавление или разбор структурированной информации в сообщениях коммита"
+
+#: command-list.h:114
+msgid "The Git repository browser"
+msgstr "Браузер репозитория Git"
+
+#: command-list.h:115
 msgid "Show commit logs"
 msgstr "Вывод истории коммитов"
 
-#: common-cmds.h:28
+#: command-list.h:116
+msgid "Show information about files in the index and the working tree"
+msgstr "Вывод информации о файлах в индексе и в рабочем каталоге"
+
+#: command-list.h:117
+msgid "List references in a remote repository"
+msgstr "Вывод списка ссылок во внешнем репозитории"
+
+#: command-list.h:118
+msgid "List the contents of a tree object"
+msgstr "Вывод содержимого объекта дерева"
+
+#: command-list.h:119
+msgid "Extracts patch and authorship from a single e-mail message"
+msgstr "Извлекает патч и авторство из одного сообщения электронной почты"
+
+#: command-list.h:120
+msgid "Simple UNIX mbox splitter program"
+msgstr "Простая программа UNIX для разбора файла mbox"
+
+#: command-list.h:121
 msgid "Join two or more development histories together"
 msgstr "Объединение одной или нескольких историй разработки вместе"
 
-#: common-cmds.h:29
+#: command-list.h:122
+msgid "Find as good common ancestors as possible for a merge"
+msgstr "Поиск подходящих общих предков для возможного слияния"
+
+#: command-list.h:123
+msgid "Run a three-way file merge"
+msgstr "Запуск трёхходового слияния файлов"
+
+#: command-list.h:124
+msgid "Run a merge for files needing merging"
+msgstr "Запуск слияния для файлов, которые требуют слияния"
+
+#: command-list.h:125
+msgid "The standard helper program to use with git-merge-index"
+msgstr "Стандартная программа-помощник для использования совместно с git-merge-index"
+
+#: command-list.h:126
+msgid "Run merge conflict resolution tools to resolve merge conflicts"
+msgstr "Запуск инструментов разрешения конфликтов слияния"
+
+#: command-list.h:127
+msgid "Show three-way merge without touching index"
+msgstr "Вывод трёхходового слияние без затрагивания индекса"
+
+#: command-list.h:128
+msgid "Write and verify multi-pack-indexes"
+msgstr "Запись и проверка файлов multi-pack-index"
+
+#: command-list.h:129
+msgid "Creates a tag object"
+msgstr "Создание объектов меток"
+
+#: command-list.h:130
+msgid "Build a tree-object from ls-tree formatted text"
+msgstr "Построение объекта дерева из текста формата ls-tree"
+
+#: command-list.h:131
 msgid "Move or rename a file, a directory, or a symlink"
 msgstr "Перемещение или переименование файла, каталога или символьной ссылки"
 
-#: common-cmds.h:30
+#: command-list.h:132
+msgid "Find symbolic names for given revs"
+msgstr "Поиск символьных имён для указанных редакций"
+
+#: command-list.h:133
+msgid "Add or inspect object notes"
+msgstr "Добавление или просмотр заметок объекта"
+
+#: command-list.h:134
+msgid "Import from and submit to Perforce repositories"
+msgstr "Импорт и отправка в репозитории Perforce"
+
+#: command-list.h:135
+msgid "Create a packed archive of objects"
+msgstr "Создание упакованного архива объектов"
+
+#: command-list.h:136
+msgid "Find redundant pack files"
+msgstr "Поиск избыточных файлов пакетов"
+
+#: command-list.h:137
+msgid "Pack heads and tags for efficient repository access"
+msgstr "Упаковка указателей на ветки и меток для эффективного доступа к репозиторию"
+
+#: command-list.h:138
+msgid "Routines to help parsing remote repository access parameters"
+msgstr "Подпрограммы для помощи разбора параметров доступа внешнего репозитория"
+
+#: command-list.h:139
+msgid "Compute unique ID for a patch"
+msgstr "Вычисление уникального идентификатора для патча"
+
+#: command-list.h:140
+msgid "Prune all unreachable objects from the object database"
+msgstr "Очистка всех недостижимых объектов из базы данных объектов"
+
+#: command-list.h:141
+msgid "Remove extra objects that are already in pack files"
+msgstr "Удаление дополнительных объектов, которые уже содержатся в файлах пакетов"
+
+#: command-list.h:142
 msgid "Fetch from and integrate with another repository or a local branch"
 msgstr "Извлечение изменений и объединение с другим репозиторием или локальной веткой"
 
-#: common-cmds.h:31
+#: command-list.h:143
 msgid "Update remote refs along with associated objects"
 msgstr "Обновление внешних ссылок и связанных объектов"
 
-#: common-cmds.h:32
+#: command-list.h:144
+msgid "Applies a quilt patchset onto the current branch"
+msgstr "Применение упорядоченного списка патчей над текущей веткой"
+
+#: command-list.h:145
+msgid "Compare two commit ranges (e.g. two versions of a branch)"
+msgstr "Сравнение двух диапазонов коммитов (например двух версий ветки)"
+
+#: command-list.h:146
+msgid "Reads tree information into the index"
+msgstr "Чтение информации о дереве в индекс"
+
+#: command-list.h:147
 msgid "Reapply commits on top of another base tip"
-msgstr "Повторно применить коммиты над верхушкой другой ветки"
+msgstr "Повторное применение коммитов над верхушкой другой ветки"
+
+#: command-list.h:148
+msgid "Receive what is pushed into the repository"
+msgstr "Получение того, что было отправлено в репозиторий"
+
+#: command-list.h:149
+msgid "Manage reflog information"
+msgstr "Управление информацией журнала ссылок"
+
+#: command-list.h:150
+msgid "Manage set of tracked repositories"
+msgstr "Управление набором отслеживаемых репозиториев"
+
+#: command-list.h:151
+msgid "Pack unpacked objects in a repository"
+msgstr "Упаковка неупакованных объектов в репозитории"
 
-#: common-cmds.h:33
+#: command-list.h:152
+msgid "Create, list, delete refs to replace objects"
+msgstr "Создание, вывод списка, удаление ссылок для замены объектов"
+
+#: command-list.h:153
+msgid "Generates a summary of pending changes"
+msgstr "Генерация сводки предстоящих изменений"
+
+#: command-list.h:154
+msgid "Reuse recorded resolution of conflicted merges"
+msgstr "Повторное использование записанных разрешений конфликтов при слияниях"
+
+#: command-list.h:155
 msgid "Reset current HEAD to the specified state"
 msgstr "Сброс текущего состояния HEAD на указанное состояние"
 
-#: common-cmds.h:34
+#: command-list.h:156
+msgid "Revert some existing commits"
+msgstr "Обращение изменений существующих коммитов"
+
+#: command-list.h:157
+msgid "Lists commit objects in reverse chronological order"
+msgstr "Вывод списка объектов коммита в обратном хронологическом порядке"
+
+#: command-list.h:158
+msgid "Pick out and massage parameters"
+msgstr "Разбор и обработка параметров"
+
+#: command-list.h:159
 msgid "Remove files from the working tree and from the index"
 msgstr "Удаление файлов из рабочего каталога и индекса"
 
-#: common-cmds.h:35
+#: command-list.h:160
+msgid "Send a collection of patches as emails"
+msgstr "Отправка коллекции патчей на электронную почту"
+
+#: command-list.h:161
+msgid "Push objects over Git protocol to another repository"
+msgstr "Отправка объектов в другой репозиторий с помощью протокола Git"
+
+#: command-list.h:162
+msgid "Restricted login shell for Git-only SSH access"
+msgstr "Ограниченная оболочка входа в систему для доступа Git через SSH"
+
+#: command-list.h:163
+msgid "Summarize 'git log' output"
+msgstr "Обобщение вывода «git log»"
+
+#: command-list.h:164
 msgid "Show various types of objects"
 msgstr "Вывод различных типов объектов"
 
-#: common-cmds.h:36
+#: command-list.h:165
+msgid "Show branches and their commits"
+msgstr "Вывод веток и их коммитов"
+
+#: command-list.h:166
+msgid "Show packed archive index"
+msgstr "Вывод индекса упакованного архива"
+
+#: command-list.h:167
+msgid "List references in a local repository"
+msgstr "Вывод ссылок в локальном репозитории"
+
+#: command-list.h:168
+msgid "Git's i18n setup code for shell scripts"
+msgstr "Код настройки интернационализации для сценариев оболочки Git"
+
+#: command-list.h:169
+msgid "Common Git shell script setup code"
+msgstr "Общий код настройки для сценариев оболочки Git"
+
+#: command-list.h:170
+msgid "Stash the changes in a dirty working directory away"
+msgstr "Спрятать изменения в изменённом рабочем каталоге"
+
+#: command-list.h:171
+msgid "Add file contents to the staging area"
+msgstr "Добавление содержимого файлов в индекс"
+
+#: command-list.h:172
 msgid "Show the working tree status"
 msgstr "Вывод состояния рабочего каталога"
 
-#: common-cmds.h:37
+#: command-list.h:173
+msgid "Remove unnecessary whitespace"
+msgstr "Удаление ненужных пробелов"
+
+#: command-list.h:174
+msgid "Initialize, update or inspect submodules"
+msgstr "Инициализация, обновление или просмотр подмодулей"
+
+#: command-list.h:175
+msgid "Bidirectional operation between a Subversion repository and Git"
+msgstr "Двухсторонние операции между репозиториями Subversion и Git"
+
+#: command-list.h:176
+msgid "Read, modify and delete symbolic refs"
+msgstr "Чтение, изменение и удаление символических ссылок"
+
+#: command-list.h:177
 msgid "Create, list, delete or verify a tag object signed with GPG"
-msgstr "Создание метки, вывод списка, удаление или проверка метки, подписанной с помощью GPG"
+msgstr "Создание, вывод списка, удаление или проверка метки, подписанной с помощью GPG"
 
-#: parse-options.h:145
-msgid "expiry-date"
-msgstr "дата-окончания"
+#: command-list.h:178
+msgid "Creates a temporary file with a blob's contents"
+msgstr "Создание временного файла с содержимым двоичного объекта"
 
-#: parse-options.h:160
-msgid "no-op (backward compatibility)"
-msgstr "ничего не делает (оставлено для обратной совместимости)"
+#: command-list.h:179
+msgid "Unpack objects from a packed archive"
+msgstr "Распаковка объектов из упакованного архива"
 
-#: parse-options.h:238
-msgid "be more verbose"
-msgstr "быть многословнее"
+#: command-list.h:180
+msgid "Register file contents in the working tree to the index"
+msgstr "Регистрация содержимого файла из рабочего каталога в индекс"
 
-#: parse-options.h:240
-msgid "be more quiet"
-msgstr "тихий режим"
+#: command-list.h:181
+msgid "Update the object name stored in a ref safely"
+msgstr "Безопасное обновление имени объекта хранящегося в ссылке"
 
-#: parse-options.h:246
-msgid "use <n> digits to display SHA-1s"
-msgstr "использовать <n> цифр для вывода SHA-1"
+#: command-list.h:182
+msgid "Update auxiliary info file to help dumb servers"
+msgstr "Обновление файла со вспомогательной информацией для глупых серверов"
 
-#: rerere.h:40
-msgid "update the index with reused conflict resolution if possible"
-msgstr "обновить индекс с помощью переиспользования разрешения конфликта, если возможно"
+#: command-list.h:183
+msgid "Send archive back to git-archive"
+msgstr "Отправка архива обратно в git-archive"
+
+#: command-list.h:184
+msgid "Send objects packed back to git-fetch-pack"
+msgstr "Отправка упакованных объектов обратно в git-fetch-pack"
+
+#: command-list.h:185
+msgid "Show a Git logical variable"
+msgstr "Вывод логической переменной Git"
+
+#: command-list.h:186
+msgid "Check the GPG signature of commits"
+msgstr "Проверка подписи GPG коммитов"
+
+#: command-list.h:187
+msgid "Validate packed Git archive files"
+msgstr "Проверка файлов упакованных архивов Git"
+
+#: command-list.h:188
+msgid "Check the GPG signature of tags"
+msgstr "Проверка подписи GPG меток"
+
+#: command-list.h:189
+msgid "Git web interface (web frontend to Git repositories)"
+msgstr "Веб интерфейс Git (веб-интерфейс для Git репозиториев)"
+
+#: command-list.h:190
+msgid "Show logs with difference each commit introduces"
+msgstr "Вывод журнала с изменениями, которые вводил каждый из коммитов"
+
+#: command-list.h:191
+msgid "Manage multiple working trees"
+msgstr "Управление несколькими рабочими каталогами"
+
+#: command-list.h:192
+msgid "Create a tree object from the current index"
+msgstr "Создание объекта дерева из текущего индекса"
+
+#: command-list.h:193
+msgid "Defining attributes per path"
+msgstr "Определение атрибутов для путей файлов или каталогов"
+
+#: command-list.h:194
+msgid "Git command-line interface and conventions"
+msgstr "Интерфейс коммандной строки Git и соглашения"
+
+#: command-list.h:195
+msgid "A Git core tutorial for developers"
+msgstr "Учебник по ядру Git для разработчиков"
+
+#: command-list.h:196
+msgid "Git for CVS users"
+msgstr "Git для пользователей CVS"
+
+#: command-list.h:197
+msgid "Tweaking diff output"
+msgstr "Подстройка вывода списка изменений"
+
+#: command-list.h:198
+msgid "A useful minimum set of commands for Everyday Git"
+msgstr "Полезный минимум команд для каждодневного использования Git"
+
+#: command-list.h:199
+msgid "A Git Glossary"
+msgstr "Глоссарий Git"
+
+#: command-list.h:200
+msgid "Hooks used by Git"
+msgstr "Перехватчики используемые Git"
+
+#: command-list.h:201
+msgid "Specifies intentionally untracked files to ignore"
+msgstr "Указание специально игнорируемых файлов"
+
+#: command-list.h:202
+msgid "Defining submodule properties"
+msgstr "Определение свойств подмодулей"
+
+#: command-list.h:203
+msgid "Git namespaces"
+msgstr "Пространства имён Git"
+
+#: command-list.h:204
+msgid "Git Repository Layout"
+msgstr "Содержимое репозитория Git"
+
+#: command-list.h:205
+msgid "Specifying revisions and ranges for Git"
+msgstr "Указание редакций и диапазонов для Git"
+
+#: command-list.h:206
+msgid "A tutorial introduction to Git: part two"
+msgstr "Обучающее введение в Git: часть вторая"
+
+#: command-list.h:207
+msgid "A tutorial introduction to Git"
+msgstr "Обучающее введение в Git"
+
+#: command-list.h:208
+msgid "An overview of recommended workflows with Git"
+msgstr "Обзор рекомендуемых последовательностей выполняемых действий с Git"
 
 #: git-bisect.sh:54
 msgid "You need to start by \"git bisect start\""
@@ -13814,161 +20257,73 @@ msgstr "Вам нужно начать 
 msgid "Do you want me to do it for you [Y/n]? "
 msgstr "Вы уверены, что хотите, чтобы я сделал это [Y - да/n - нет]? "
 
-#: git-bisect.sh:121
-#, sh-format
-msgid "unrecognised option: '$arg'"
-msgstr "неопознанная опция: «$arg»"
-
-#: git-bisect.sh:125
-#, sh-format
-msgid "'$arg' does not appear to be a valid revision"
-msgstr "«$arg» не похоже на действительную редакцию"
-
-#: git-bisect.sh:154
-msgid "Bad HEAD - I need a HEAD"
-msgstr "Плохой указатель HEAD — Необходим указатель HEAD"
-
-#: git-bisect.sh:167
-#, sh-format
-msgid ""
-"Checking out '$start_head' failed. Try 'git bisect reset <valid-branch>'."
-msgstr "Сбой перехода на «$start_head». Попробуйте выполнить «git bisect reset <существующая-ветка>»."
-
-#: git-bisect.sh:177
-msgid "won't bisect on cg-seek'ed tree"
-msgstr "нельзя выполнить двоичный поиск на дереве после cg-seek"
-
-#: git-bisect.sh:181
-msgid "Bad HEAD - strange symbolic ref"
-msgstr "Плохой указатель HEAD — странная символьная ссылка"
-
-#: git-bisect.sh:233
-#, sh-format
-msgid "Bad bisect_write argument: $state"
-msgstr "Плохой аргумент bisect_write: $state"
-
-#: git-bisect.sh:246
+#: git-bisect.sh:101
 #, sh-format
 msgid "Bad rev input: $arg"
 msgstr "Плохой ввод номера редакции: $arg"
 
-#: git-bisect.sh:265
+#: git-bisect.sh:121
 #, sh-format
 msgid "Bad rev input: $bisected_head"
 msgstr "Плохой ввод номера редакции: $bisected_head"
 
-#: git-bisect.sh:274
+#: git-bisect.sh:130
 #, sh-format
 msgid "Bad rev input: $rev"
 msgstr "Плохой ввод номера редакции: $rev"
 
-#: git-bisect.sh:283
+#: git-bisect.sh:139
 #, sh-format
 msgid "'git bisect $TERM_BAD' can take only one argument."
 msgstr "«git bisect $TERM_BAD» может принимать только один аргумент."
 
-#: git-bisect.sh:306
-#, sh-format
-msgid "Warning: bisecting only with a $TERM_BAD commit."
-msgstr "Предупреждение: попытка двоичного поиска с указанием только $TERM_BAD коммита."
-
-#. TRANSLATORS: Make sure to include [Y] and [n] in your
-#. translation. The program will only accept English input
-#. at this point.
-#: git-bisect.sh:312
-msgid "Are you sure [Y/n]? "
-msgstr "Вы уверены [Y - да/n - нет]? "
-
-#: git-bisect.sh:324
-#, sh-format
-msgid ""
-"You need to give me at least one $bad_syn and one $good_syn revision.\n"
-"(You can use \"git bisect $bad_syn\" and \"git bisect $good_syn\" for that.)"
-msgstr "Вам нужно передать мне как минимум одну $bad_syn и одну $good_syn редакцию.\n(Для этого вы можете использовать команды «git bisect $bad_syn» и «git bisect $good_syn».)"
-
-#: git-bisect.sh:327
-#, sh-format
-msgid ""
-"You need to start by \"git bisect start\".\n"
-"You then need to give me at least one $good_syn and one $bad_syn revision.\n"
-"(You can use \"git bisect $bad_syn\" and \"git bisect $good_syn\" for that.)"
-msgstr "Для начала нужно запустить «git bisect start».\nПосле этого, вам нужно передать мне как минимум одну $good_syn и одну $bad_syn редакцию.\n(Для этого вы можете использовать команды «git bisect $good_syn» и «git bisect $good_syn».)"
-
-#: git-bisect.sh:398 git-bisect.sh:512
-msgid "We are not bisecting."
-msgstr "Вы сейчас не в процессе бинарного поиска."
-
-#: git-bisect.sh:405
-#, sh-format
-msgid "'$invalid' is not a valid commit"
-msgstr "«$invalid» не является действительным коммитом"
-
-#: git-bisect.sh:414
-#, sh-format
-msgid ""
-"Could not check out original HEAD '$branch'.\n"
-"Try 'git bisect reset <commit>'."
-msgstr "Не удалось перейти на оригинальную ветку HEAD «$branch».\nПопробуйте запустить «git bisect reset <коммит>»."
-
-#: git-bisect.sh:422
+#: git-bisect.sh:209
 msgid "No logfile given"
 msgstr "Не передан файл журнала"
 
-#: git-bisect.sh:423
+#: git-bisect.sh:210
 #, sh-format
 msgid "cannot read $file for replaying"
 msgstr "не удалось прочитать $file для повтора изменений"
 
-#: git-bisect.sh:444
+#: git-bisect.sh:232
 msgid "?? what are you talking about?"
 msgstr "?? вы о чем?"
 
-#: git-bisect.sh:453
+#: git-bisect.sh:241
 msgid "bisect run failed: no command provided."
 msgstr "сбой при выполнении двоичного поиска: не передана команда."
 
-#: git-bisect.sh:458
+#: git-bisect.sh:246
 #, sh-format
 msgid "running $command"
 msgstr "запускаю $command"
 
-#: git-bisect.sh:465
+#: git-bisect.sh:253
 #, sh-format
 msgid ""
 "bisect run failed:\n"
 "exit code $res from '$command' is < 0 or >= 128"
 msgstr "не удалось выполнить двоичный поиск:\nкод завершения $res от «$command» оказался < 0 или >= 128"
 
-#: git-bisect.sh:491
+#: git-bisect.sh:279
 msgid "bisect run cannot continue any more"
 msgstr "bisect run больше не может продолжать"
 
-#: git-bisect.sh:497
+#: git-bisect.sh:285
 #, sh-format
 msgid ""
 "bisect run failed:\n"
 "'bisect_state $state' exited with error code $res"
 msgstr "не удалось выполнить двоичный поиск:\n«bisect_state $state» завершился с кодом ошибки $res"
 
-#: git-bisect.sh:504
+#: git-bisect.sh:292
 msgid "bisect run success"
 msgstr "bisect run выполнен успешно"
 
-#: git-bisect.sh:533
-#, sh-format
-msgid "Invalid command: you're currently in a $TERM_BAD/$TERM_GOOD bisect."
-msgstr "Недопустимая команда: вы сейчас находитесь на $TERM_BAD/$TERM_GOOD двоичном поиске."
-
-#: git-bisect.sh:567
-msgid "no terms defined"
-msgstr "определения не заданы"
-
-#: git-bisect.sh:584
-#, sh-format
-msgid ""
-"invalid argument $arg for 'git bisect terms'.\n"
-"Supported options are: --term-good|--term-old and --term-bad|--term-new."
-msgstr "недопустимый аргумент $arg для «git bisect terms».\nПоддерживаемые параметры: --term-good|--term-old и --term-bad|--term-new."
+#: git-bisect.sh:300
+msgid "We are not bisecting."
+msgstr "Вы сейчас не в процессе бинарного поиска."
 
 #: git-merge-octopus.sh:46
 msgid ""
@@ -14008,305 +20363,113 @@ msgstr "Попытка простого
 msgid "Simple merge did not work, trying automatic merge."
 msgstr "Простое слияние не удалось, попытка автоматического слияния."
 
-#: git-rebase.sh:58
-msgid ""
-"Resolve all conflicts manually, mark them as resolved with\n"
-"\"git add/rm <conflicted_files>\", then run \"git rebase --continue\".\n"
-"You can instead skip this commit: run \"git rebase --skip\".\n"
-"To abort and get back to the state before \"git rebase\", run \"git rebase --abort\"."
-msgstr "Разрешите все конфликты вручную, пометьте их разрешёнными с помощью «git add/rm <конфликтующие-файлы>», а затем запустите «git rebase --continue».\nЕсли вы хотите пропустить этот коммит, то запустите «git rebase --skip».\nЧтобы вернуться на состояние до «git rebase», запустите «git rebase --abort»."
-
-#: git-rebase.sh:160 git-rebase.sh:402
-#, sh-format
-msgid "Could not move back to $head_name"
-msgstr "Не удалось перейти назад на $head_name"
-
-#: git-rebase.sh:171
-msgid "Applied autostash."
-msgstr "Применены автоматически спрятанные изменения."
-
-#: git-rebase.sh:174
-#, sh-format
-msgid "Cannot store $stash_sha1"
-msgstr "Не удалось сохранить $stash_sha1"
-
-#: git-rebase.sh:214
-msgid "The pre-rebase hook refused to rebase."
-msgstr "Перехватчик pre-rebase отказал в перемещении."
-
-#: git-rebase.sh:219
-msgid "It looks like 'git am' is in progress. Cannot rebase."
-msgstr "Похоже, что выполняется «git am». Невозможно выполнить перемещение."
-
-#: git-rebase.sh:363
-msgid "No rebase in progress?"
-msgstr "Нет перемещения в процессе?"
-
-#: git-rebase.sh:374
-msgid "The --edit-todo action can only be used during interactive rebase."
-msgstr "Действие --edit-todo может использоваться только при интерактивном перемещении."
-
-#: git-rebase.sh:381
-msgid "Cannot read HEAD"
-msgstr "Не удалось прочитать HEAD"
-
-#: git-rebase.sh:384
-msgid ""
-"You must edit all merge conflicts and then\n"
-"mark them as resolved using git add"
-msgstr "Вы должны отредактировать все\nконфликты слияния, а потом пометить\nих как разрешенные с помощью git add"
-
-#: git-rebase.sh:424
-#, sh-format
-msgid ""
-"It seems that there is already a $state_dir_base directory, and\n"
-"I wonder if you are in the middle of another rebase.  If that is the\n"
-"case, please try\n"
-"\t$cmd_live_rebase\n"
-"If that is not the case, please\n"
-"\t$cmd_clear_stale_rebase\n"
-"and run me again.  I am stopping in case you still have something\n"
-"valuable there."
-msgstr "Похоже, каталог $state_dir_base уже существует и я предполагаю, что вы в процессе другого перемещения.  Если это так, попробуйте\n\t$cmd_live_rebase\nЕсли нет\n\t$cmd_clear_stale_rebase\nи запустите меня снова.  Я останавливаюсь, чтобы вы не потеряли что-то важное."
-
-#: git-rebase.sh:480
-#, sh-format
-msgid "invalid upstream '$upstream_name'"
-msgstr "недействительная вышестоящая ветка «$upstream_name»"
-
-#: git-rebase.sh:504
-#, sh-format
-msgid "$onto_name: there are more than one merge bases"
-msgstr "$onto_name: имеется больше одной базы слияния"
-
-#: git-rebase.sh:507 git-rebase.sh:511
-#, sh-format
-msgid "$onto_name: there is no merge base"
-msgstr "$onto_name: нет базы слияния"
-
-#: git-rebase.sh:516
-#, sh-format
-msgid "Does not point to a valid commit: $onto_name"
-msgstr "Не указывает на действительный коммит: $onto_name"
-
-#: git-rebase.sh:542
-#, sh-format
-msgid "fatal: no such branch/commit '$branch_name'"
-msgstr "критическая ошибка: нет такой ветки/коммита «$branch_name»"
-
-#: git-rebase.sh:575
-msgid "Cannot autostash"
-msgstr "Не удалось автоматически спрятать изменения"
-
-#: git-rebase.sh:580
-#, sh-format
-msgid "Created autostash: $stash_abbrev"
-msgstr "Изменения автоматически спрятаны: $stash_abbrev"
-
-#: git-rebase.sh:584
-msgid "Please commit or stash them."
-msgstr "Сделайте коммит или спрячьте их."
-
-#: git-rebase.sh:607
-#, sh-format
-msgid "HEAD is up to date."
-msgstr "HEAD уже в актуальном состоянии."
-
-#: git-rebase.sh:609
-#, sh-format
-msgid "Current branch $branch_name is up to date."
-msgstr "Текущая ветка $branch_name уже в актуальном состоянии."
-
-#: git-rebase.sh:617
-#, sh-format
-msgid "HEAD is up to date, rebase forced."
-msgstr "HEAD уже в актуальном состоянии, принудительное перемещение."
-
-#: git-rebase.sh:619
-#, sh-format
-msgid "Current branch $branch_name is up to date, rebase forced."
-msgstr "Текущая ветка $branch_name уже в актуальном состоянии, принудительное перемещение."
-
-#: git-rebase.sh:631
-#, sh-format
-msgid "Changes from $mb to $onto:"
-msgstr "Изменения от $mb до $onto:"
-
-#: git-rebase.sh:640
-msgid "First, rewinding head to replay your work on top of it..."
-msgstr "Сначала перематываем указатель текущего коммита, чтобы применить ваши изменения поверх него…"
-
-#: git-rebase.sh:650
-#, sh-format
-msgid "Fast-forwarded $branch_name to $onto_name."
-msgstr "Перемотана вперед $branch_name до $onto_name."
-
-#: git-stash.sh:61
-msgid "git stash clear with parameters is unimplemented"
-msgstr "git stash очистка с параметрами не реализована"
-
-#: git-stash.sh:108
-msgid "You do not have the initial commit yet"
-msgstr "У вас еще нет начального коммита"
-
-#: git-stash.sh:123
-msgid "Cannot save the current index state"
-msgstr "Не удалось сохранить текущее состояние индекса"
-
-#: git-stash.sh:138
-msgid "Cannot save the untracked files"
-msgstr "Невозможно сохранить неотслеживаемые файлы"
-
-#: git-stash.sh:158 git-stash.sh:171
-msgid "Cannot save the current worktree state"
-msgstr "Не удалось сохранить текущее состояние рабочего каталога"
-
-#: git-stash.sh:175
-msgid "No changes selected"
-msgstr "Изменения не выбраны"
-
-#: git-stash.sh:178
+#: git-legacy-stash.sh:220
 msgid "Cannot remove temporary index (can't happen)"
 msgstr "Не удалось удалить временный индекс (не должно случаться)"
 
-#: git-stash.sh:191
-msgid "Cannot record working tree state"
-msgstr "Не удалось записать состояние рабочего каталога"
-
-#: git-stash.sh:229
+#: git-legacy-stash.sh:271
 #, sh-format
 msgid "Cannot update $ref_stash with $w_commit"
 msgstr "Не удалось обновить $ref_stash с помощью $w_commit"
 
-#: git-stash.sh:281
+#: git-legacy-stash.sh:323
 #, sh-format
 msgid "error: unknown option for 'stash push': $option"
 msgstr "ошибка: неизвестный параметр для «stash push»: $option"
 
-#: git-stash.sh:295
-msgid "Can't use --patch and --include-untracked or --all at the same time"
-msgstr "Нельзя использовать --patch и --include-untracked или --all одновременно"
-
-#: git-stash.sh:303
-msgid "No local changes to save"
-msgstr "Нет локальных изменений для сохранения"
-
-#: git-stash.sh:308
-msgid "Cannot initialize stash"
-msgstr "Не удалось инициализировать спрятанные изменения"
-
-#: git-stash.sh:312
-msgid "Cannot save the current status"
-msgstr "Не удалось сохранить текущий статус"
-
-#: git-stash.sh:313
+#: git-legacy-stash.sh:355
 #, sh-format
 msgid "Saved working directory and index state $stash_msg"
 msgstr "Рабочий каталог и состояние индекса сохранены $stash_msg"
 
-#: git-stash.sh:341
-msgid "Cannot remove worktree changes"
-msgstr "Не удалось удалить изменения рабочего каталога"
-
-#: git-stash.sh:489
+#: git-legacy-stash.sh:535
 #, sh-format
 msgid "unknown option: $opt"
 msgstr "неизвестная опция: $opt"
 
-#: git-stash.sh:502
-msgid "No stash entries found."
-msgstr "Не найдены спрятанные изменения."
-
-#: git-stash.sh:509
+#: git-legacy-stash.sh:555
 #, sh-format
 msgid "Too many revisions specified: $REV"
 msgstr "Передано слишком много редакций: $REV"
 
-#: git-stash.sh:524
+#: git-legacy-stash.sh:570
 #, sh-format
 msgid "$reference is not a valid reference"
 msgstr "$reference не является действительной ссылкой"
 
-#: git-stash.sh:552
+#: git-legacy-stash.sh:598
 #, sh-format
 msgid "'$args' is not a stash-like commit"
 msgstr "«$args» не похоже на коммит со спрятанными изменениями"
 
-#: git-stash.sh:563
+#: git-legacy-stash.sh:609
 #, sh-format
 msgid "'$args' is not a stash reference"
 msgstr "«$args» не является ссылкой на спрятанные изменения"
 
-#: git-stash.sh:571
+#: git-legacy-stash.sh:617
 msgid "unable to refresh index"
 msgstr "не удалось обновить индекс"
 
-#: git-stash.sh:575
+#: git-legacy-stash.sh:621
 msgid "Cannot apply a stash in the middle of a merge"
 msgstr "Нельзя применить спрятанные изменения во время выполнения слияния"
 
-#: git-stash.sh:583
+#: git-legacy-stash.sh:629
 msgid "Conflicts in index. Try without --index."
 msgstr "Конфликты в индексе. Попробуйте без --index."
 
-#: git-stash.sh:585
+#: git-legacy-stash.sh:631
 msgid "Could not save index tree"
 msgstr "Не удалось сохранить дерево индекса"
 
-#: git-stash.sh:594
+#: git-legacy-stash.sh:640
 msgid "Could not restore untracked files from stash entry"
 msgstr "Невозможно восстановить неотслеживаемые файлы из спрятанных изменений"
 
-#: git-stash.sh:619
+#: git-legacy-stash.sh:665
 msgid "Cannot unstage modified files"
 msgstr "Невозможно убрать из индекса измененные файлы"
 
-#: git-stash.sh:634
-msgid "Index was not unstashed."
-msgstr "Индекс не был извлечён из спрятанных изменений."
-
-#: git-stash.sh:648
-msgid "The stash entry is kept in case you need it again."
-msgstr "Спрятанные изменения сохранены, на случай если они снова вам понадобятся."
-
-#: git-stash.sh:657
+#: git-legacy-stash.sh:703
 #, sh-format
 msgid "Dropped ${REV} ($s)"
 msgstr "Отброшено ${REV} ($s)"
 
-#: git-stash.sh:658
+#: git-legacy-stash.sh:704
 #, sh-format
 msgid "${REV}: Could not drop stash entry"
 msgstr "${REV}: Не удалось отбросить запись из спрятанных изменений"
 
-#: git-stash.sh:666
-msgid "No branch name specified"
-msgstr "Не указано имя ветки"
-
-#: git-stash.sh:745
+#: git-legacy-stash.sh:791
 msgid "(To restore them type \"git stash apply\")"
 msgstr "(Чтобы восстановить их, наберите «git stash apply»)"
 
-#: git-submodule.sh:181
+#: git-submodule.sh:200
 msgid "Relative path can only be used from the toplevel of the working tree"
 msgstr "Относительный путь можно использовать только находясь на вершине рабочего каталога"
 
-#: git-submodule.sh:191
+#: git-submodule.sh:210
 #, sh-format
 msgid "repo URL: '$repo' must be absolute or begin with ./|../"
 msgstr "URL репозитория: «$repo» должен быть абсолютным или начинаться с ./|../"
 
-#: git-submodule.sh:210
+#: git-submodule.sh:229
 #, sh-format
 msgid "'$sm_path' already exists in the index"
 msgstr "«$sm_path» уже содержится в индексе"
 
-#: git-submodule.sh:213
+#: git-submodule.sh:232
 #, sh-format
 msgid "'$sm_path' already exists in the index and is not a submodule"
 msgstr "«$sm_path» уже содержится в индексе и не является подмодулем"
 
-#: git-submodule.sh:219
+#: git-submodule.sh:239
+#, sh-format
+msgid "'$sm_path' does not have a commit checked out"
+msgstr ""
+
+#: git-submodule.sh:245
 #, sh-format
 msgid ""
 "The following path is ignored by one of your .gitignore files:\n"
@@ -14314,22 +20477,22 @@ msgid ""
 "Use -f if you really want to add it."
 msgstr "Следующие пути игнорируются одним из ваших файлов .gitignore:\n$sm_path\nИспользуйте опцию -f, если вы действительно хотите его добавить."
 
-#: git-submodule.sh:237
+#: git-submodule.sh:268
 #, sh-format
 msgid "Adding existing repo at '$sm_path' to the index"
 msgstr "Добавляю существующий репозиторий из «$sm_path» в индекс"
 
-#: git-submodule.sh:239
+#: git-submodule.sh:270
 #, sh-format
 msgid "'$sm_path' already exists and is not a valid git repo"
 msgstr "«$sm_path» уже существует и не является действительным репозиторием git"
 
-#: git-submodule.sh:247
+#: git-submodule.sh:278
 #, sh-format
 msgid "A git directory for '$sm_name' is found locally with remote(s):"
 msgstr "Каталог git для «$sm_name» найден локально на внешних репозиториях:"
 
-#: git-submodule.sh:249
+#: git-submodule.sh:280
 #, sh-format
 msgid ""
 "If you want to reuse this local git directory instead of cloning again from\n"
@@ -14338,221 +20501,158 @@ msgid ""
 "or you are unsure what this means choose another name with the '--name' option."
 msgstr "Если вы хотите повторно использовать локальный каталог git вместо повторного клонирования из\n  $realrepo\nто используйте параметр «--force». Если же локальный каталог git не является нужным репозиторием или если вы не уверены, что это значит, то укажите другое имя для подмодуля с помощью параметра «--name»."
 
-#: git-submodule.sh:255
+#: git-submodule.sh:286
 #, sh-format
 msgid "Reactivating local git directory for submodule '$sm_name'."
 msgstr "Восстановление локального каталога git для подмодуля «$sm_name»."
 
-#: git-submodule.sh:267
+#: git-submodule.sh:298
 #, sh-format
 msgid "Unable to checkout submodule '$sm_path'"
 msgstr "Не удалось переключиться на состояние у подмодуля «$sm_path»"
 
-#: git-submodule.sh:272
+#: git-submodule.sh:303
 #, sh-format
 msgid "Failed to add submodule '$sm_path'"
 msgstr "Сбой добавления подмодуля «$sm_path»"
 
-#: git-submodule.sh:281
+#: git-submodule.sh:312
 #, sh-format
 msgid "Failed to register submodule '$sm_path'"
 msgstr "Не удалось зарегистрировать подмодуль «$sm_path»"
 
-#: git-submodule.sh:342
-#, sh-format
-msgid "Entering '$displaypath'"
-msgstr "Заходим в «$displaypath»"
-
-#: git-submodule.sh:362
-#, sh-format
-msgid "Stopping at '$displaypath'; script returned non-zero status."
-msgstr "Останавливаемся на «$displaypath»; сценарий вернул не нулевой код возврата."
-
-#: git-submodule.sh:433
-#, sh-format
-msgid "pathspec and --all are incompatible"
-msgstr "спецификатор пути и --all нельзя использовать одновременно"
-
-#: git-submodule.sh:438
-#, sh-format
-msgid "Use '--all' if you really want to deinitialize all submodules"
-msgstr "Используйте «--all», если вы действительно хотите деинициализировать все подмодули"
-
-#: git-submodule.sh:458
-#, sh-format
-msgid ""
-"Submodule work tree '$displaypath' contains a .git directory\n"
-"(use 'rm -rf' if you really want to remove it including all of its history)"
-msgstr "Рабочий каталог подмодуля «$displaypath» уже содержит каталог .git\n(используйте «rm -rf», если вы действительно хотите удалить его со всей историей изменений)"
-
-#: git-submodule.sh:466
-#, sh-format
-msgid ""
-"Submodule work tree '$displaypath' contains local modifications; use '-f' to"
-" discard them"
-msgstr "Рабочий каталог подмодуля «$displaypath» содержит локальные изменения; используйте «-f», чтобы отменить их"
-
-#: git-submodule.sh:469
-#, sh-format
-msgid "Cleared directory '$displaypath'"
-msgstr "Очищен каталог «$displaypath»"
-
-#: git-submodule.sh:470
-#, sh-format
-msgid "Could not remove submodule work tree '$displaypath'"
-msgstr "Не удалось удалить рабочий каталог подмодуля «$displaypath»"
-
-#: git-submodule.sh:473
-#, sh-format
-msgid "Could not create empty submodule directory '$displaypath'"
-msgstr "Не удалось создать пустой каталог подмодуля «$displaypath»"
-
-#: git-submodule.sh:482
-#, sh-format
-msgid "Submodule '$name' ($url) unregistered for path '$displaypath'"
-msgstr "Подмодуль «$name» ($url) был снят с регистрации по пути «$displaypath»"
-
-#: git-submodule.sh:637
+#: git-submodule.sh:573
 #, sh-format
 msgid "Unable to find current revision in submodule path '$displaypath'"
 msgstr "Не удалось найти текущую редакцию для подмодуля по пути «$displaypath»"
 
-#: git-submodule.sh:647
+#: git-submodule.sh:583
 #, sh-format
 msgid "Unable to fetch in submodule path '$sm_path'"
 msgstr "Не удалось выполнить извлечение для подмодуля по пути «$sm_path»"
 
-#: git-submodule.sh:652
+#: git-submodule.sh:588
 #, sh-format
 msgid ""
 "Unable to find current ${remote_name}/${branch} revision in submodule path "
 "'$sm_path'"
 msgstr "Не удалось найти текущую редакцию ${remote_name}/${branch} для подмодуля по пути «$sm_path»"
 
-#: git-submodule.sh:670
+#: git-submodule.sh:606
 #, sh-format
-msgid "Unable to fetch in submodule path '$displaypath'"
-msgstr "Не удалось выполнить извлечение для подмодуля по пути «$displaypath»"
+msgid ""
+"Unable to fetch in submodule path '$displaypath'; trying to directly fetch "
+"$sha1:"
+msgstr ""
 
-#: git-submodule.sh:676
+#: git-submodule.sh:612
 #, sh-format
 msgid ""
 "Fetched in submodule path '$displaypath', but it did not contain $sha1. "
 "Direct fetching of that commit failed."
 msgstr "Получен по пути подмодуля «$displaypath», но не содержит $sha1. Сбой при прямом получении коммита."
 
-#: git-submodule.sh:683
+#: git-submodule.sh:619
 #, sh-format
 msgid "Unable to checkout '$sha1' in submodule path '$displaypath'"
 msgstr "Не удалось переключиться на состояние «$sha1» для подмодуля по пути «$displaypath»"
 
-#: git-submodule.sh:684
+#: git-submodule.sh:620
 #, sh-format
 msgid "Submodule path '$displaypath': checked out '$sha1'"
 msgstr "Подмодуль по пути «$displaypath»: забрано состояние «$sha1»"
 
-#: git-submodule.sh:688
+#: git-submodule.sh:624
 #, sh-format
 msgid "Unable to rebase '$sha1' in submodule path '$displaypath'"
 msgstr "Не удалось переместить «$sha1» для подмодуля по пути «$displaypath»"
 
-#: git-submodule.sh:689
+#: git-submodule.sh:625
 #, sh-format
 msgid "Submodule path '$displaypath': rebased into '$sha1'"
 msgstr "Подмодуль по пути «$displaypath»: перемещен над «$sha1»"
 
-#: git-submodule.sh:694
+#: git-submodule.sh:630
 #, sh-format
 msgid "Unable to merge '$sha1' in submodule path '$displaypath'"
 msgstr "Не удалось выполнить слияние с «$sha1» для подмодуля по пути «$displaypath»"
 
-#: git-submodule.sh:695
+#: git-submodule.sh:631
 #, sh-format
 msgid "Submodule path '$displaypath': merged in '$sha1'"
 msgstr "Подмодуль по пути «$displaypath»: слито с «$sha1»"
 
-#: git-submodule.sh:700
+#: git-submodule.sh:636
 #, sh-format
 msgid "Execution of '$command $sha1' failed in submodule path '$displaypath'"
 msgstr "Сбой выполнения «$command $sha1» для подмодуля по пути «$displaypath»"
 
-#: git-submodule.sh:701
+#: git-submodule.sh:637
 #, sh-format
 msgid "Submodule path '$displaypath': '$command $sha1'"
 msgstr "Подмодуль по пути «$displaypath»: «$command $sha1»"
 
-#: git-submodule.sh:732
+#: git-submodule.sh:668
 #, sh-format
 msgid "Failed to recurse into submodule path '$displaypath'"
 msgstr "Не удалось выполнить рекурсивно для подмодуля по пути «$displaypath»"
 
-#: git-submodule.sh:828
+#: git-submodule.sh:830
 msgid "The --cached option cannot be used with the --files option"
 msgstr "Опцию --cached нельзя использовать одновременно с опцией --files"
 
-#: git-submodule.sh:880
+#: git-submodule.sh:882
 #, sh-format
 msgid "unexpected mode $mod_dst"
 msgstr "неизвестный режим $mod_dst"
 
-#: git-submodule.sh:900
+#: git-submodule.sh:902
 #, sh-format
 msgid "  Warn: $display_name doesn't contain commit $sha1_src"
 msgstr "  Предупреждение: $display_name не содержит коммит $sha1_src"
 
-#: git-submodule.sh:903
+#: git-submodule.sh:905
 #, sh-format
 msgid "  Warn: $display_name doesn't contain commit $sha1_dst"
 msgstr "  Предупреждение: $display_name не содержит коммит $sha1_dst"
 
-#: git-submodule.sh:906
+#: git-submodule.sh:908
 #, sh-format
 msgid "  Warn: $display_name doesn't contain commits $sha1_src and $sha1_dst"
 msgstr "  Предупреждение: $display_name не содержит коммиты $sha1_src и $sha1_dst"
 
-#: git-submodule.sh:1077
-#, sh-format
-msgid "Synchronizing submodule url for '$displaypath'"
-msgstr "Синхронизация url для подмодуля «$displaypath»"
-
 #: git-parse-remote.sh:89
 #, sh-format
 msgid "See git-${cmd}(1) for details."
 msgstr "Для дополнительной информации, смотрите git-${cmd}(1)."
 
-#: git-rebase--interactive.sh:140
+#: git-rebase--preserve-merges.sh:136
 #, sh-format
 msgid "Rebasing ($new_count/$total)"
 msgstr "Перемещение ($new_count/$total)"
 
-#: git-rebase--interactive.sh:156
+#: git-rebase--preserve-merges.sh:152
 msgid ""
 "\n"
 "Commands:\n"
-"p, pick = use commit\n"
-"r, reword = use commit, but edit the commit message\n"
-"e, edit = use commit, but stop for amending\n"
-"s, squash = use commit, but meld into previous commit\n"
-"f, fixup = like \"squash\", but discard this commit's log message\n"
-"x, exec = run command (the rest of the line) using shell\n"
-"d, drop = remove commit\n"
+"p, pick <commit> = use commit\n"
+"r, reword <commit> = use commit, but edit the commit message\n"
+"e, edit <commit> = use commit, but stop for amending\n"
+"s, squash <commit> = use commit, but meld into previous commit\n"
+"f, fixup <commit> = like \"squash\", but discard this commit's log message\n"
+"x, exec <commit> = run command (the rest of the line) using shell\n"
+"d, drop <commit> = remove commit\n"
+"l, label <label> = label current HEAD with a name\n"
+"t, reset <label> = reset HEAD to a label\n"
+"m, merge [-C <commit> | -c <commit>] <label> [# <oneline>]\n"
+".       create a merge commit using the original merge commit's\n"
+".       message (or the oneline, if no original merge commit was\n"
+".       specified). Use -c <commit> to reword the commit message.\n"
 "\n"
 "These lines can be re-ordered; they are executed from top to bottom.\n"
-msgstr "\nКоманды:\np, pick = использовать коммит\nr, reword = использовать коммит, но изменить сообщение коммита\ne, edit = использовать коммит, но остановиться для внесения правок\ns, squash = использовать коммит, но объединить его с предыдущим коммитом\nf, fixup = как «squash», но отбросить сообщение этого коммита\nx, exec = выполнить команду (остаток строки) с помощью командной оболочки\nd, drop = удалить коммит\n\nЭти строки могут быть перемещены; выполняются по очереди сверху вниз.\n"
-
-#: git-rebase--interactive.sh:171
-msgid ""
-"\n"
-"Do not remove any line. Use 'drop' explicitly to remove a commit.\n"
-msgstr "\nНе удаляйте строки. Используйте «drop», чтобы явно удалить коммит.\n"
+msgstr "\nКоманды:\np, pick <коммит> = использовать коммит\nr, reword <коммит> = использовать коммит, но изменить сообщение коммита\ne, edit <коммит> = использовать коммит, но остановиться для исправления\ns, squash <коммит> = использовать коммит, но объединить с предыдущим коммитом\nf, fixup <коммит> = как «squash», но пропустить сообщение коммита\nx, exec <команда> = выполнить команду (остаток строки) с помощью командной оболочки\nd, drop <коммит> = удалить коммит\nl, label <метка> = дать имя текущему HEAD\nt, reset <метка> = сбросить HEAD к указанной метке\nm, merge [-C <коммит> | -c <коммит>] <метка> [# <строка>]\n. создать слияние используя сообщение коммита оригинального\n. слияния (или использовать указанную строку, если оригинальное\n. слияние не указано). Используйте -c <коммит> чтобы изменить\n. сообщение коммита.\n\nЭти строки можно перемещать; они будут выполнены сверху вниз.\n"
 
-#: git-rebase--interactive.sh:175
-msgid ""
-"\n"
-"If you remove a line here THAT COMMIT WILL BE LOST.\n"
-msgstr "\nЕсли вы удалите строку здесь, то УКАЗАННЫЙ КОММИТ БУДЕТ УТЕРЯН.\n"
-
-#: git-rebase--interactive.sh:211
+#: git-rebase--preserve-merges.sh:215
 #, sh-format
 msgid ""
 "You can amend the commit now, with\n"
@@ -14564,61 +20664,61 @@ msgid ""
 "\tgit rebase --continue"
 msgstr "Теперь вы можете исправить коммит с помощью\n\n\tgit commit --amend $gpg_sign_opt_quoted\n\nКак только вы будете довольны результатом, запустите\n\n\tgit rebase --continue"
 
-#: git-rebase--interactive.sh:236
+#: git-rebase--preserve-merges.sh:240
 #, sh-format
 msgid "$sha1: not a commit that can be picked"
 msgstr "$sha1: не является коммитом, который можно взять"
 
-#: git-rebase--interactive.sh:275
+#: git-rebase--preserve-merges.sh:279
 #, sh-format
 msgid "Invalid commit name: $sha1"
 msgstr "Недопустимое имя коммита: $sha1"
 
-#: git-rebase--interactive.sh:317
+#: git-rebase--preserve-merges.sh:309
 msgid "Cannot write current commit's replacement sha1"
 msgstr "Не удалось записать замену sha1 текущего коммита"
 
-#: git-rebase--interactive.sh:369
+#: git-rebase--preserve-merges.sh:360
 #, sh-format
 msgid "Fast-forward to $sha1"
 msgstr "Перемотка вперед до $sha1"
 
-#: git-rebase--interactive.sh:371
+#: git-rebase--preserve-merges.sh:362
 #, sh-format
 msgid "Cannot fast-forward to $sha1"
 msgstr "Не удалось перемотать вперед до $sha1"
 
-#: git-rebase--interactive.sh:380
+#: git-rebase--preserve-merges.sh:371
 #, sh-format
 msgid "Cannot move HEAD to $first_parent"
 msgstr "Не удалось переместить HEAD на $first_parent"
 
-#: git-rebase--interactive.sh:385
+#: git-rebase--preserve-merges.sh:376
 #, sh-format
 msgid "Refusing to squash a merge: $sha1"
 msgstr "Нельзя уплотнить слияние: $sha1"
 
-#: git-rebase--interactive.sh:400
+#: git-rebase--preserve-merges.sh:394
 #, sh-format
 msgid "Error redoing merge $sha1"
 msgstr "Ошибка при повторении слияния $sha1"
 
-#: git-rebase--interactive.sh:408
+#: git-rebase--preserve-merges.sh:403
 #, sh-format
 msgid "Could not pick $sha1"
 msgstr "Не удалось взять $sha1"
 
-#: git-rebase--interactive.sh:417
+#: git-rebase--preserve-merges.sh:412
 #, sh-format
 msgid "This is the commit message #${n}:"
 msgstr "Это сообщение коммита номер #${n}:"
 
-#: git-rebase--interactive.sh:422
+#: git-rebase--preserve-merges.sh:417
 #, sh-format
 msgid "The commit message #${n} will be skipped:"
 msgstr "Сообщение коммита номер #${n} будет пропущено:"
 
-#: git-rebase--interactive.sh:433
+#: git-rebase--preserve-merges.sh:428
 #, sh-format
 msgid "This is a combination of $count commit."
 msgid_plural "This is a combination of $count commits."
@@ -14627,55 +20727,55 @@ msgstr[1] "Это объединение
 msgstr[2] "Это объединение $count коммитов"
 msgstr[3] "Это объединение $count коммитов"
 
-#: git-rebase--interactive.sh:442
+#: git-rebase--preserve-merges.sh:437
 #, sh-format
 msgid "Cannot write $fixup_msg"
 msgstr "Не удалось записать $fixup_msg"
 
-#: git-rebase--interactive.sh:445
+#: git-rebase--preserve-merges.sh:440
 msgid "This is a combination of 2 commits."
 msgstr "Это объединение 2 коммитов"
 
-#: git-rebase--interactive.sh:486 git-rebase--interactive.sh:529
-#: git-rebase--interactive.sh:532
+#: git-rebase--preserve-merges.sh:481 git-rebase--preserve-merges.sh:524
+#: git-rebase--preserve-merges.sh:527
 #, sh-format
 msgid "Could not apply $sha1... $rest"
 msgstr "Не удалось применить $sha1… $rest"
 
-#: git-rebase--interactive.sh:560
+#: git-rebase--preserve-merges.sh:556
 #, sh-format
 msgid ""
 "Could not amend commit after successfully picking $sha1... $rest\n"
 "This is most likely due to an empty commit message, or the pre-commit hook\n"
 "failed. If the pre-commit hook failed, you may need to resolve the issue before\n"
 "you are able to reword the commit."
-msgstr "Не удолось исправить коммит после успешного перехода на $sha1… $rest\nЭто произошло, скорее всего, из-за пустого сообщения коммита или из-за перехватчика перед коммитом. Если же это произошло из-за перехватчика перед коммитом, то вам нужно решить с ним проблему и повторить попытку снова."
+msgstr "Не удалось исправить коммит после успешного перехода на $sha1… $rest\nЭто произошло, скорее всего, из-за пустого сообщения коммита или из-за перехватчика перед коммитом. Если же это произошло из-за перехватчика перед коммитом, то вам нужно решить с ним проблему и повторить попытку снова."
 
-#: git-rebase--interactive.sh:575
+#: git-rebase--preserve-merges.sh:571
 #, sh-format
 msgid "Stopped at $sha1_abbrev... $rest"
 msgstr "Остановлено на $sha1_abbrev… $rest"
 
-#: git-rebase--interactive.sh:590
+#: git-rebase--preserve-merges.sh:586
 #, sh-format
 msgid "Cannot '$squash_style' without a previous commit"
 msgstr "Нельзя сделать «$squash_style» без указания предыдущего коммита"
 
-#: git-rebase--interactive.sh:632
+#: git-rebase--preserve-merges.sh:628
 #, sh-format
 msgid "Executing: $rest"
 msgstr "Выполнение: $rest"
 
-#: git-rebase--interactive.sh:640
+#: git-rebase--preserve-merges.sh:636
 #, sh-format
 msgid "Execution failed: $rest"
 msgstr "Не удалось выполнить: $rest"
 
-#: git-rebase--interactive.sh:642
+#: git-rebase--preserve-merges.sh:638
 msgid "and made changes to the index and/or the working tree"
 msgstr "и были сделаны изменения в индексе и/или в рабочем каталоге"
 
-#: git-rebase--interactive.sh:644
+#: git-rebase--preserve-merges.sh:640
 msgid ""
 "You can fix the problem, and then run\n"
 "\n"
@@ -14683,7 +20783,7 @@ msgid ""
 msgstr "Вы можете исправить ошибку, а затем запустить\n\n\tgit rebase --continue"
 
 #. TRANSLATORS: after these lines is a command to be issued by the user
-#: git-rebase--interactive.sh:657
+#: git-rebase--preserve-merges.sh:653
 #, sh-format
 msgid ""
 "Execution succeeded: $rest\n"
@@ -14693,29 +20793,25 @@ msgid ""
 "\tgit rebase --continue"
 msgstr "Успешное выполнение: $rest\nно остались изменения в индексе и/или в рабочем каталоге\nСделайте коммит или спрячьте ваши изменения, а затем выполните\n\n\tgit rebase --continue"
 
-#: git-rebase--interactive.sh:668
+#: git-rebase--preserve-merges.sh:664
 #, sh-format
 msgid "Unknown command: $command $sha1 $rest"
 msgstr "Неопознанная команда: $command $sha1 $rest"
 
-#: git-rebase--interactive.sh:669
+#: git-rebase--preserve-merges.sh:665
 msgid "Please fix this using 'git rebase --edit-todo'."
 msgstr "Пожалуйста исправьте это с помощью «git rebase --edit-todo»."
 
-#: git-rebase--interactive.sh:704
+#: git-rebase--preserve-merges.sh:700
 #, sh-format
 msgid "Successfully rebased and updated $head_name."
 msgstr "Успешно перемещён и обновлён $head_name."
 
-#: git-rebase--interactive.sh:728
-msgid "could not detach HEAD"
-msgstr "не удалось отделить HEAD"
-
-#: git-rebase--interactive.sh:763
+#: git-rebase--preserve-merges.sh:757
 msgid "Could not remove CHERRY_PICK_HEAD"
 msgstr "Не удалось удалить CHERRY_PICK_HEAD"
 
-#: git-rebase--interactive.sh:768
+#: git-rebase--preserve-merges.sh:762
 #, sh-format
 msgid ""
 "You have staged changes in your working tree.\n"
@@ -14733,60 +20829,43 @@ msgid ""
 "  git rebase --continue\n"
 msgstr "У вас имеются проиндексированные изменения в рабочем каталоге.\nЕсли эти изменения должны быть объеденены с предыдущим коммитом, то запустите:\n\n  git commit --amend $gpg_sign_opt_quoted\n\nЕсли же они должны быть помещены в новый коммит, то запустите:\n\n  git commit $gpg_sign_opt_quoted\n\nВ любом случае, после того как вы закончите, продолжить перемещение можно выполнив:\n\n  git rebase --continue\n"
 
-#: git-rebase--interactive.sh:785
+#: git-rebase--preserve-merges.sh:779
 msgid "Error trying to find the author identity to amend commit"
 msgstr "Произошла ошибка при поиске автора для исправления коммита"
 
-#: git-rebase--interactive.sh:790
+#: git-rebase--preserve-merges.sh:784
 msgid ""
 "You have uncommitted changes in your working tree. Please commit them\n"
 "first and then run 'git rebase --continue' again."
 msgstr "У вас имеются незакоммиченные изменения в рабочем каталоге. Сделайте коммит, а затем запустите «git rebase --continue» снова."
 
-#: git-rebase--interactive.sh:795 git-rebase--interactive.sh:799
+#: git-rebase--preserve-merges.sh:789 git-rebase--preserve-merges.sh:793
 msgid "Could not commit staged changes."
 msgstr "Не удалось закоммитить проиндексированные изменения."
 
-#: git-rebase--interactive.sh:827
-msgid ""
-"\n"
-"You are editing the todo file of an ongoing interactive rebase.\n"
-"To continue rebase after editing, run:\n"
-"    git rebase --continue\n"
-"\n"
-msgstr "\nВы сейчас редактируете файл со списком дел для интерактивного перемещения.\nДля продолжения перемещения, после редактирования файла запустите:\n    git rebase --continue\n\n"
-
-#: git-rebase--interactive.sh:835 git-rebase--interactive.sh:995
+#: git-rebase--preserve-merges.sh:824 git-rebase--preserve-merges.sh:910
 msgid "Could not execute editor"
 msgstr "Не удалось запустить редактор"
 
-#: git-rebase--interactive.sh:848
+#: git-rebase--preserve-merges.sh:845
 #, sh-format
 msgid "Could not checkout $switch_to"
 msgstr "Не удалось перейти на версию $switch_to"
 
-#: git-rebase--interactive.sh:853
+#: git-rebase--preserve-merges.sh:852
 msgid "No HEAD?"
 msgstr "Нет указателя HEAD?"
 
-#: git-rebase--interactive.sh:854
+#: git-rebase--preserve-merges.sh:853
 #, sh-format
 msgid "Could not create temporary $state_dir"
 msgstr "Не удалось создать временный каталог $state_dir"
 
-#: git-rebase--interactive.sh:856
+#: git-rebase--preserve-merges.sh:856
 msgid "Could not mark as interactive"
 msgstr "Не удалось пометить как интерактивный"
 
-#: git-rebase--interactive.sh:866 git-rebase--interactive.sh:871
-msgid "Could not init rewritten commits"
-msgstr "Не удалось инициализировать перезаписанные коммиты"
-
-#: git-rebase--interactive.sh:897
-msgid "Could not generate todo list"
-msgstr "Не удалось сгенерировать список дел"
-
-#: git-rebase--interactive.sh:973
+#: git-rebase--preserve-merges.sh:888
 #, sh-format
 msgid "Rebase $shortrevisions onto $shortonto ($todocount command)"
 msgid_plural "Rebase $shortrevisions onto $shortonto ($todocount commands)"
@@ -14795,71 +20874,64 @@ msgstr[1] "Перемещение $short
 msgstr[2] "Перемещение $shortrevisions над $shortonto ($todocount команд)"
 msgstr[3] "Перемещение $shortrevisions над $shortonto ($todocount команд)"
 
-#: git-rebase--interactive.sh:978
-msgid ""
-"\n"
-"However, if you remove everything, the rebase will be aborted.\n"
-"\n"
-msgstr "\nНо если вы удалите все, то процесс перемещения будет будет прерван.\n\n"
-
-#: git-rebase--interactive.sh:985
-msgid "Note that empty commits are commented out"
-msgstr "Заметьте, что пустые коммиты закомментированны"
+#: git-rebase--preserve-merges.sh:942 git-rebase--preserve-merges.sh:947
+msgid "Could not init rewritten commits"
+msgstr "Не удалось инициализировать перезаписанные коммиты"
 
 #: git-sh-setup.sh:89 git-sh-setup.sh:94
 #, sh-format
 msgid "usage: $dashless $USAGE"
 msgstr "использование: $dashless $USAGE"
 
-#: git-sh-setup.sh:190
+#: git-sh-setup.sh:191
 #, sh-format
 msgid "Cannot chdir to $cdup, the toplevel of the working tree"
 msgstr "Не удалось выполнить chdir в $cdup, вершину рабочего каталога"
 
-#: git-sh-setup.sh:199 git-sh-setup.sh:206
+#: git-sh-setup.sh:200 git-sh-setup.sh:207
 #, sh-format
 msgid "fatal: $program_name cannot be used without a working tree."
 msgstr "критическая ошибка: $program_name нельзя использовать не имея рабочего каталога."
 
-#: git-sh-setup.sh:220
+#: git-sh-setup.sh:221
 msgid "Cannot rebase: You have unstaged changes."
 msgstr "Не удалось выполнить перемещение коммитов: У вас есть непроиндексированные изменения."
 
-#: git-sh-setup.sh:223
+#: git-sh-setup.sh:224
 msgid "Cannot rewrite branches: You have unstaged changes."
 msgstr "Не удалось выполнить перезапись веток: У вас есть непроиндексированные изменения."
 
-#: git-sh-setup.sh:226
+#: git-sh-setup.sh:227
 msgid "Cannot pull with rebase: You have unstaged changes."
 msgstr "Не удалось получить с перемещением: У вас есть непроиндексированные изменения."
 
-#: git-sh-setup.sh:229
+#: git-sh-setup.sh:230
 #, sh-format
 msgid "Cannot $action: You have unstaged changes."
 msgstr "Не удалось выполнить $action: У вас есть непроиндексированные изменения."
 
-#: git-sh-setup.sh:242
+#: git-sh-setup.sh:243
 msgid "Cannot rebase: Your index contains uncommitted changes."
 msgstr "Не удалось выполнить перемещение коммитов: В вашем индексе есть незакоммиченные изменения."
 
-#: git-sh-setup.sh:245
+#: git-sh-setup.sh:246
 msgid "Cannot pull with rebase: Your index contains uncommitted changes."
 msgstr "Не удалось получить с перемещением: В вашем индексе есть незакоммиченные изменения."
 
-#: git-sh-setup.sh:248
+#: git-sh-setup.sh:249
 #, sh-format
 msgid "Cannot $action: Your index contains uncommitted changes."
 msgstr "Не удалось выполнить $action: В вашем индексе есть незакоммиченные изменения."
 
-#: git-sh-setup.sh:252
+#: git-sh-setup.sh:253
 msgid "Additionally, your index contains uncommitted changes."
 msgstr "К тому же, в вашем индексе есть незакоммиченные изменения."
 
-#: git-sh-setup.sh:372
+#: git-sh-setup.sh:373
 msgid "You need to run this command from the toplevel of the working tree."
 msgstr "Вам нужно запускать эту команду находясь на вершине рабочего каталога."
 
-#: git-sh-setup.sh:377
+#: git-sh-setup.sh:378
 msgid "Unable to determine absolute path of git directory"
 msgstr "Не удалось определить абсолютный путь к каталогу git"
 
@@ -14877,19 +20949,19 @@ msgstr "в индексе"
 msgid "unstaged"
 msgstr "не в индексе"
 
-#: git-add--interactive.perl:246 git-add--interactive.perl:271
+#: git-add--interactive.perl:253 git-add--interactive.perl:278
 msgid "binary"
 msgstr "двоичный"
 
-#: git-add--interactive.perl:255 git-add--interactive.perl:309
+#: git-add--interactive.perl:262 git-add--interactive.perl:316
 msgid "nothing"
 msgstr "ничего"
 
-#: git-add--interactive.perl:291 git-add--interactive.perl:306
+#: git-add--interactive.perl:298 git-add--interactive.perl:313
 msgid "unchanged"
 msgstr "нет изменений"
 
-#: git-add--interactive.perl:602
+#: git-add--interactive.perl:609
 #, perl-format
 msgid "added %d path\n"
 msgid_plural "added %d paths\n"
@@ -14898,7 +20970,7 @@ msgstr[1] "добавлено %d пут
 msgstr[2] "добавлено %d путей\n"
 msgstr[3] "добавлено %d пути\n"
 
-#: git-add--interactive.perl:605
+#: git-add--interactive.perl:612
 #, perl-format
 msgid "updated %d path\n"
 msgid_plural "updated %d paths\n"
@@ -14907,7 +20979,7 @@ msgstr[1] "обновлено %d пут
 msgstr[2] "обновлено %d путей\n"
 msgstr[3] "обновлено %d пути\n"
 
-#: git-add--interactive.perl:608
+#: git-add--interactive.perl:615
 #, perl-format
 msgid "reverted %d path\n"
 msgid_plural "reverted %d paths\n"
@@ -14916,7 +20988,7 @@ msgstr[1] "обращены измене
 msgstr[2] "обращены изменения %d путей\n"
 msgstr[3] "обращены изменения %d путей\n"
 
-#: git-add--interactive.perl:611
+#: git-add--interactive.perl:618
 #, perl-format
 msgid "touched %d path\n"
 msgid_plural "touched %d paths\n"
@@ -14925,67 +20997,67 @@ msgstr[1] "тронуты %d пути\n"
 msgstr[2] "тронуты %d путей\n"
 msgstr[3] "тронуты %d пути\n"
 
-#: git-add--interactive.perl:620
+#: git-add--interactive.perl:627
 msgid "Update"
 msgstr "Обновить"
 
-#: git-add--interactive.perl:632
+#: git-add--interactive.perl:639
 msgid "Revert"
 msgstr "Обратить изменения"
 
-#: git-add--interactive.perl:655
+#: git-add--interactive.perl:662
 #, perl-format
 msgid "note: %s is untracked now.\n"
 msgstr "примечание: %s теперь неотслеживаемый.\n"
 
-#: git-add--interactive.perl:666
+#: git-add--interactive.perl:673
 msgid "Add untracked"
 msgstr "Добавить неотслеживаемый"
 
-#: git-add--interactive.perl:672
+#: git-add--interactive.perl:679
 msgid "No untracked files.\n"
 msgstr "Нет неотслеживаемых файлов.\n"
 
-#: git-add--interactive.perl:985
+#: git-add--interactive.perl:1033
 msgid ""
 "If the patch applies cleanly, the edited hunk will immediately be\n"
 "marked for staging."
 msgstr "Если патч применяется без ошибок, то изменённый блок будет сразу помечен для индексирования."
 
-#: git-add--interactive.perl:988
+#: git-add--interactive.perl:1036
 msgid ""
 "If the patch applies cleanly, the edited hunk will immediately be\n"
 "marked for stashing."
 msgstr "Если патч применяется без ошибок, то изменённый блок будет сразу помечен для прятанья."
 
-#: git-add--interactive.perl:991
+#: git-add--interactive.perl:1039
 msgid ""
 "If the patch applies cleanly, the edited hunk will immediately be\n"
 "marked for unstaging."
 msgstr "Если патч применяется без ошибок, то изменённый блок будет сразу помечен для убирания из индекса."
 
-#: git-add--interactive.perl:994 git-add--interactive.perl:1003
+#: git-add--interactive.perl:1042 git-add--interactive.perl:1051
 msgid ""
 "If the patch applies cleanly, the edited hunk will immediately be\n"
 "marked for applying."
 msgstr "Если патч применяется без ошибок, то изменённый блок будет сразу помечен для применения."
 
-#: git-add--interactive.perl:997 git-add--interactive.perl:1000
+#: git-add--interactive.perl:1045 git-add--interactive.perl:1048
 msgid ""
 "If the patch applies cleanly, the edited hunk will immediately be\n"
 "marked for discarding."
 msgstr "Если патч применяется без ошибок, то изменённый блок будет сразу помечен для отмены изменений."
 
-#: git-add--interactive.perl:1013
+#: git-add--interactive.perl:1085
 #, perl-format
 msgid "failed to open hunk edit file for writing: %s"
 msgstr "не удалось открыть файл редактирования блока изменений для записи: %s"
 
-#: git-add--interactive.perl:1014
+#: git-add--interactive.perl:1086
 msgid "Manual hunk edit mode -- see bottom for a quick guide.\n"
 msgstr "Ручной режим редактирования блока изменений — смотрите ниже для небольшого руководства.\n"
 
-#: git-add--interactive.perl:1020
+#: git-add--interactive.perl:1092
 #, perl-format
 msgid ""
 "---\n"
@@ -14995,14 +21067,14 @@ msgid ""
 msgstr "---\nЧтобы удалить «%s» строки, сделайте их ' ' строками (контекст).\nЧтобы удалить «%s» строки, удалите их.\nСтроки, начинающиеся с %s будут удалены.\n"
 
 #. TRANSLATORS: 'it' refers to the patch mentioned in the previous messages.
-#: git-add--interactive.perl:1028
+#: git-add--interactive.perl:1100
 msgid ""
 "If it does not apply cleanly, you will be given an opportunity to\n"
 "edit again.  If all lines of the hunk are removed, then the edit is\n"
 "aborted and the hunk is left unchanged.\n"
 msgstr "Если патч не применяется без ошибок, вам будет дана\nвозможность изменить его снова. Если все строки блока\nизменений удалены, то редактирование будет отменено\nи блок останется без изменений.\n"
 
-#: git-add--interactive.perl:1042
+#: git-add--interactive.perl:1114
 #, perl-format
 msgid "failed to open hunk edit file for reading: %s"
 msgstr "не удалось открыть файл редактирования блока изменений для чтения: %s"
@@ -15013,13 +21085,13 @@ msgstr "не удалось открыт
 #. Consider translating (saying "no" discards!) as
 #. (saying "n" for "no" discards!) if the translation
 #. of the word "no" does not start with n.
-#: git-add--interactive.perl:1134
+#: git-add--interactive.perl:1213
 msgid ""
 "Your edited hunk does not apply. Edit again (saying \"no\" discards!) [y/n]?"
 " "
 msgstr "Изменённый вами блок не применяется. Редактировать снова (ответ «y» означает «нет»!) [y/n]? "
 
-#: git-add--interactive.perl:1143
+#: git-add--interactive.perl:1222
 msgid ""
 "y - stage this hunk\n"
 "n - do not stage this hunk\n"
@@ -15028,7 +21100,7 @@ msgid ""
 "d - do not stage this hunk or any of the later hunks in the file"
 msgstr "y - проиндексировать блок изменений\nn - не индексировать этот блок изменений\nq - выход; не индексировать этот и последующие блоки\na - проиндексировать этот и все последующие блоки файла\nd - не индексировать этот и последующие блоки файла"
 
-#: git-add--interactive.perl:1149
+#: git-add--interactive.perl:1228
 msgid ""
 "y - stash this hunk\n"
 "n - do not stash this hunk\n"
@@ -15037,7 +21109,7 @@ msgid ""
 "d - do not stash this hunk or any of the later hunks in the file"
 msgstr "y - спрятать изменения блока\nq - выход; не прятать изменения этого и последующих блоков\na - спрятать этот и все последующие блоки файла\nd - не прятать этот и последующие блоки файла"
 
-#: git-add--interactive.perl:1155
+#: git-add--interactive.perl:1234
 msgid ""
 "y - unstage this hunk\n"
 "n - do not unstage this hunk\n"
@@ -15046,7 +21118,7 @@ msgid ""
 "d - do not unstage this hunk or any of the later hunks in the file"
 msgstr "y - убрать из индекса этот блок изменений\nn - не убирать из индекса этот блок изменений\nq - выход; не убирать из индекса этот и последующие блоки\na - убрать из индекса этот и все последующие блоки файла\nd - не убирать из индекса этот и последующие блоки файла"
 
-#: git-add--interactive.perl:1161
+#: git-add--interactive.perl:1240
 msgid ""
 "y - apply this hunk to index\n"
 "n - do not apply this hunk to index\n"
@@ -15055,7 +21127,7 @@ msgid ""
 "d - do not apply this hunk or any of the later hunks in the file"
 msgstr "y - применить блок изменений к индексу\nn - не применять этот блок изменений к индексу\nq - выход; не применять этот и последующие блоки\na - применить этот блок и все последующие блоки файла\nd - не применять этот и последующие блоки файла"
 
-#: git-add--interactive.perl:1167
+#: git-add--interactive.perl:1246
 msgid ""
 "y - discard this hunk from worktree\n"
 "n - do not discard this hunk from worktree\n"
@@ -15064,7 +21136,7 @@ msgid ""
 "d - do not discard this hunk or any of the later hunks in the file"
 msgstr "y - отменить изменения этого блока в рабочем каталоге\nn - не отменять изменения этого блока в рабочем каталоге\nq - выход; не отменять изменения этого блока и всех последующих\na - отменить изменения этого и всех последующих блоков файла\nd - не отменять изменения этого и всех последующих блоков файла"
 
-#: git-add--interactive.perl:1173
+#: git-add--interactive.perl:1252
 msgid ""
 "y - discard this hunk from index and worktree\n"
 "n - do not discard this hunk from index and worktree\n"
@@ -15073,7 +21145,7 @@ msgid ""
 "d - do not discard this hunk or any of the later hunks in the file"
 msgstr "y - отменить изменения этого блока в индексе и рабочем каталоге\nn - не отменять изменения этого блока в индексе и рабочем каталоге\nq - выход; не отменять изменения этого блока и всех последующих\na - отменить изменения этого и всех последующих блоков файла\nd - не отменять изменения этого и всех последующих блоков файла"
 
-#: git-add--interactive.perl:1179
+#: git-add--interactive.perl:1258
 msgid ""
 "y - apply this hunk to index and worktree\n"
 "n - do not apply this hunk to index and worktree\n"
@@ -15082,7 +21154,7 @@ msgid ""
 "d - do not apply this hunk or any of the later hunks in the file"
 msgstr "y - применить блок изменений к индексу и рабочему каталогу\nn - не применять этот блок изменений к индексу и рабочему каталогу\nq - выход; не применять этот и последующие блоки\na - применить этот блок и все последующие блоки файла\nd - не применять этот и последующие блоки файла"
 
-#: git-add--interactive.perl:1188
+#: git-add--interactive.perl:1273
 msgid ""
 "g - select a hunk to go to\n"
 "/ - search for a hunk matching the given regex\n"
@@ -15095,154 +21167,158 @@ msgid ""
 "? - print help\n"
 msgstr "g - выбрать блок изменений на который нужно перейти\n/ - поиск блока изменений с помощью регулярного выражения\nj - не принимать решение по этому блоку, перейти на следующий без решения\nJ - не принимать решение по этому блоку, перейти на следующий\nk - не принимать решение по этому блоку, перейти на предыдущий без решения\nK - не принимать решение по этому блоку, перейти на предыдущий\ns - разделить текущий блок на блоки меньшего размера\ne - вручную отредактировать текущий блок\n? - вывести справку\n"
 
-#: git-add--interactive.perl:1219
+#: git-add--interactive.perl:1304
 msgid "The selected hunks do not apply to the index!\n"
 msgstr "Выбранные блоки не применяются без ошибок к индексу!\n"
 
-#: git-add--interactive.perl:1220
+#: git-add--interactive.perl:1305
 msgid "Apply them to the worktree anyway? "
 msgstr "Все равно применить их к рабочему каталогу?"
 
-#: git-add--interactive.perl:1223
+#: git-add--interactive.perl:1308
 msgid "Nothing was applied.\n"
 msgstr "Ничего не применено.\n"
 
-#: git-add--interactive.perl:1234
+#: git-add--interactive.perl:1319
 #, perl-format
 msgid "ignoring unmerged: %s\n"
 msgstr "игнорирую не слитое: %s\n"
 
-#: git-add--interactive.perl:1243
+#: git-add--interactive.perl:1328
 msgid "Only binary files changed.\n"
 msgstr "Только изменения двоичных файлов.\n"
 
-#: git-add--interactive.perl:1245
+#: git-add--interactive.perl:1330
 msgid "No changes.\n"
 msgstr "Нет изменений.\n"
 
-#: git-add--interactive.perl:1253
+#: git-add--interactive.perl:1338
 msgid "Patch update"
 msgstr "Обновление патча"
 
-#: git-add--interactive.perl:1305
+#: git-add--interactive.perl:1390
 #, perl-format
-msgid "Stage mode change [y,n,q,a,d,/%s,?]? "
-msgstr "Проиндексировать изменение режима доступа [y,n,q,a,d,/%s,?]? "
+msgid "Stage mode change [y,n,q,a,d%s,?]? "
+msgstr "Проиндексировать изменение режима доступа [y,n,q,a,d%s,?]? "
 
-#: git-add--interactive.perl:1306
+#: git-add--interactive.perl:1391
 #, perl-format
-msgid "Stage deletion [y,n,q,a,d,/%s,?]? "
-msgstr "Проиндексировать удаление [y,n,q,a,d,/%s,?]? "
+msgid "Stage deletion [y,n,q,a,d%s,?]? "
+msgstr "Проиндексировать удаление [y,n,q,a,d%s,?]? "
 
-#: git-add--interactive.perl:1307
+#: git-add--interactive.perl:1392
 #, perl-format
-msgid "Stage this hunk [y,n,q,a,d,/%s,?]? "
-msgstr "Проиндексировать этот блок изменений [y,n,q,a,d,/%s,?]? "
+msgid "Stage this hunk [y,n,q,a,d%s,?]? "
+msgstr "Проиндексировать этот блок изменений [y,n,q,a,d%s,?]? "
 
-#: git-add--interactive.perl:1310
+#: git-add--interactive.perl:1395
 #, perl-format
-msgid "Stash mode change [y,n,q,a,d,/%s,?]? "
-msgstr "Спрятать изменение режима доступа [y,n,q,a,d,/%s,?]? "
+msgid "Stash mode change [y,n,q,a,d%s,?]? "
+msgstr "Спрятать изменение режима доступа [y,n,q,a,d%s,?]? "
 
-#: git-add--interactive.perl:1311
+#: git-add--interactive.perl:1396
 #, perl-format
-msgid "Stash deletion [y,n,q,a,d,/%s,?]? "
-msgstr "Спрятать удаление файла [y,n,q,a,d,/%s,?]? "
+msgid "Stash deletion [y,n,q,a,d%s,?]? "
+msgstr "Спрятать удаление файла [y,n,q,a,d%s,?]? "
 
-#: git-add--interactive.perl:1312
+#: git-add--interactive.perl:1397
 #, perl-format
-msgid "Stash this hunk [y,n,q,a,d,/%s,?]? "
-msgstr "Спрятать этот блок изменений [y,n,q,a,d,/%s,?]? "
+msgid "Stash this hunk [y,n,q,a,d%s,?]? "
+msgstr "Спрятать этот блок изменений [y,n,q,a,d%s,?]? "
 
-#: git-add--interactive.perl:1315
+#: git-add--interactive.perl:1400
 #, perl-format
-msgid "Unstage mode change [y,n,q,a,d,/%s,?]? "
-msgstr "Убрать изменения режима доступа из индекса [y,n,q,a,d,/%s,?]? "
+msgid "Unstage mode change [y,n,q,a,d%s,?]? "
+msgstr "Убрать изменения режима доступа из индекса [y,n,q,a,d%s,?]? "
 
-#: git-add--interactive.perl:1316
+#: git-add--interactive.perl:1401
 #, perl-format
-msgid "Unstage deletion [y,n,q,a,d,/%s,?]? "
-msgstr "Убрать удаление из индекса [y,n,q,a,d,/%s,?]? "
+msgid "Unstage deletion [y,n,q,a,d%s,?]? "
+msgstr "Убрать удаление из индекса [y,n,q,a,d%s,?]? "
 
-#: git-add--interactive.perl:1317
+#: git-add--interactive.perl:1402
 #, perl-format
-msgid "Unstage this hunk [y,n,q,a,d,/%s,?]? "
-msgstr "Убрать из индекса этот блок измений [y,n,q,a,d,/%s,?]? "
+msgid "Unstage this hunk [y,n,q,a,d%s,?]? "
+msgstr "Убрать из индекса этот блок измений [y,n,q,a,d%s,?]? "
 
-#: git-add--interactive.perl:1320
+#: git-add--interactive.perl:1405
 #, perl-format
-msgid "Apply mode change to index [y,n,q,a,d,/%s,?]? "
-msgstr "Применить изменение режима доступа к индексу [y,n,q,a,d,/%s,?]? "
+msgid "Apply mode change to index [y,n,q,a,d%s,?]? "
+msgstr "Применить изменение режима доступа к индексу [y,n,q,a,d%s,?]? "
 
-#: git-add--interactive.perl:1321
+#: git-add--interactive.perl:1406
 #, perl-format
-msgid "Apply deletion to index [y,n,q,a,d,/%s,?]? "
-msgstr "Применить удаление к индексу [y,n,q,a,d,/%s,?]? "
+msgid "Apply deletion to index [y,n,q,a,d%s,?]? "
+msgstr "Применить удаление к индексу [y,n,q,a,d%s,?]? "
 
-#: git-add--interactive.perl:1322
+#: git-add--interactive.perl:1407
 #, perl-format
-msgid "Apply this hunk to index [y,n,q,a,d,/%s,?]? "
-msgstr "Применить этот блок к индексу [y,n,q,a,d,/%s,?]? "
+msgid "Apply this hunk to index [y,n,q,a,d%s,?]? "
+msgstr "Применить этот блок к индексу [y,n,q,a,d%s,?]? "
 
-#: git-add--interactive.perl:1325
+#: git-add--interactive.perl:1410
 #, perl-format
-msgid "Discard mode change from worktree [y,n,q,a,d,/%s,?]? "
-msgstr "Отменить изменения режима доступа в рабочем каталоге [y,n,q,a,d,/%s,?]? "
+msgid "Discard mode change from worktree [y,n,q,a,d%s,?]? "
+msgstr "Отменить изменения режима доступа в рабочем каталоге [y,n,q,a,d%s,?]? "
 
-#: git-add--interactive.perl:1326
+#: git-add--interactive.perl:1411
 #, perl-format
-msgid "Discard deletion from worktree [y,n,q,a,d,/%s,?]? "
-msgstr "Отменить удаление в рабочем каталоге [y,n,q,a,d,/%s,?]? "
+msgid "Discard deletion from worktree [y,n,q,a,d%s,?]? "
+msgstr "Отменить удаление в рабочем каталоге [y,n,q,a,d%s,?]? "
 
-#: git-add--interactive.perl:1327
+#: git-add--interactive.perl:1412
 #, perl-format
-msgid "Discard this hunk from worktree [y,n,q,a,d,/%s,?]? "
-msgstr "Отменить изменения этого блока в рабочем каталоге [y,n,q,a,d,/%s,?]? "
+msgid "Discard this hunk from worktree [y,n,q,a,d%s,?]? "
+msgstr "Отменить изменения этого блока в рабочем каталоге [y,n,q,a,d%s,?]? "
 
-#: git-add--interactive.perl:1330
+#: git-add--interactive.perl:1415
 #, perl-format
-msgid "Discard mode change from index and worktree [y,n,q,a,d,/%s,?]? "
-msgstr "Отменить изменения режима доступа в индексе и рабочем каталоге [y,n,q,a,d,/%s,?]? "
+msgid "Discard mode change from index and worktree [y,n,q,a,d%s,?]? "
+msgstr "Отменить изменения режима доступа в индексе и рабочем каталоге [y,n,q,a,d%s,?]? "
 
-#: git-add--interactive.perl:1331
+#: git-add--interactive.perl:1416
 #, perl-format
-msgid "Discard deletion from index and worktree [y,n,q,a,d,/%s,?]? "
-msgstr "Отменить удаление в индексе и рабочем каталоге [y,n,q,a,d,/%s,?]? "
+msgid "Discard deletion from index and worktree [y,n,q,a,d%s,?]? "
+msgstr "Отменить удаление в индексе и рабочем каталоге [y,n,q,a,d%s,?]? "
 
-#: git-add--interactive.perl:1332
+#: git-add--interactive.perl:1417
 #, perl-format
-msgid "Discard this hunk from index and worktree [y,n,q,a,d,/%s,?]? "
-msgstr "Отменить изменения этого блока в индексе и рабочем каталоге [y,n,q,a,d,/%s,?]? "
+msgid "Discard this hunk from index and worktree [y,n,q,a,d%s,?]? "
+msgstr "Отменить изменения этого блока в индексе и рабочем каталоге [y,n,q,a,d%s,?]? "
 
-#: git-add--interactive.perl:1335
+#: git-add--interactive.perl:1420
 #, perl-format
-msgid "Apply mode change to index and worktree [y,n,q,a,d,/%s,?]? "
-msgstr "Применить изменения режима доступа к индексу и рабочему каталогу [y,n,q,a,d,/%s,?]? "
+msgid "Apply mode change to index and worktree [y,n,q,a,d%s,?]? "
+msgstr "Применить изменения режима доступа к индексу и рабочему каталогу [y,n,q,a,d%s,?]? "
 
-#: git-add--interactive.perl:1336
+#: git-add--interactive.perl:1421
 #, perl-format
-msgid "Apply deletion to index and worktree [y,n,q,a,d,/%s,?]? "
-msgstr "Применить удаление к индексу и рабочему каталогу [y,n,q,a,d,/%s,?]? "
+msgid "Apply deletion to index and worktree [y,n,q,a,d%s,?]? "
+msgstr "Применить удаление к индексу и рабочему каталогу [y,n,q,a,d%s,?]? "
 
-#: git-add--interactive.perl:1337
+#: git-add--interactive.perl:1422
 #, perl-format
-msgid "Apply this hunk to index and worktree [y,n,q,a,d,/%s,?]? "
-msgstr "Применить изменения этого блока к индексу и рабочему каталогу [y,n,q,a,d,/%s,?]? "
+msgid "Apply this hunk to index and worktree [y,n,q,a,d%s,?]? "
+msgstr "Применить изменения этого блока к индексу и рабочему каталогу [y,n,q,a,d%s,?]? "
 
-#: git-add--interactive.perl:1440
+#: git-add--interactive.perl:1522
+msgid "No other hunks to goto\n"
+msgstr ""
+
+#: git-add--interactive.perl:1529
 msgid "go to which hunk (<ret> to see more)? "
 msgstr "на какой блок перейти (нажмите <ввод> чтобы увидеть еще)? "
 
-#: git-add--interactive.perl:1442
+#: git-add--interactive.perl:1531
 msgid "go to which hunk? "
 msgstr "на какой блок перейти? "
 
-#: git-add--interactive.perl:1451
+#: git-add--interactive.perl:1540
 #, perl-format
 msgid "Invalid number: '%s'\n"
 msgstr "Неверный номер: «%s»\n"
 
-#: git-add--interactive.perl:1456
+#: git-add--interactive.perl:1545
 #, perl-format
 msgid "Sorry, only %d hunk available.\n"
 msgid_plural "Sorry, only %d hunks available.\n"
@@ -15251,28 +21327,36 @@ msgstr[1] "Простите, но тол
 msgstr[2] "Простите, но только %d блоков изменений доступно.\n"
 msgstr[3] "Простите, но только %d блока изменений доступно.\n"
 
-#: git-add--interactive.perl:1482
+#: git-add--interactive.perl:1571
+msgid "No other hunks to search\n"
+msgstr ""
+
+#: git-add--interactive.perl:1575
 msgid "search for regex? "
 msgstr "искать с помощью регулярного выражения? "
 
-#: git-add--interactive.perl:1495
+#: git-add--interactive.perl:1588
 #, perl-format
 msgid "Malformed search regexp %s: %s\n"
 msgstr "Регулярное выражение для поиска в неверном формате %s: %s\n"
 
-#: git-add--interactive.perl:1505
+#: git-add--interactive.perl:1598
 msgid "No hunk matches the given pattern\n"
 msgstr "Не найдены блоки, которые соответствуют указанному шаблону\n"
 
-#: git-add--interactive.perl:1517 git-add--interactive.perl:1539
+#: git-add--interactive.perl:1610 git-add--interactive.perl:1632
 msgid "No previous hunk\n"
 msgstr "Нет предыдущего блока\n"
 
-#: git-add--interactive.perl:1526 git-add--interactive.perl:1545
+#: git-add--interactive.perl:1619 git-add--interactive.perl:1638
 msgid "No next hunk\n"
 msgstr "Не следующего блока\n"
 
-#: git-add--interactive.perl:1553
+#: git-add--interactive.perl:1644
+msgid "Sorry, cannot split this hunk\n"
+msgstr ""
+
+#: git-add--interactive.perl:1650
 #, perl-format
 msgid "Split into %d hunk.\n"
 msgid_plural "Split into %d hunks.\n"
@@ -15281,13 +21365,17 @@ msgstr[1] "Разбито на %d бло
 msgstr[2] "Разбито на %d блоков изменений.\n"
 msgstr[3] "Разбито на %d блока изменений.\n"
 
-#: git-add--interactive.perl:1605
+#: git-add--interactive.perl:1660
+msgid "Sorry, cannot edit this hunk\n"
+msgstr ""
+
+#: git-add--interactive.perl:1706
 msgid "Review diff"
 msgstr "Просмотреть изменения"
 
 #. TRANSLATORS: please do not translate the command names
 #. 'status', 'update', 'revert', etc.
-#: git-add--interactive.perl:1624
+#: git-add--interactive.perl:1725
 msgid ""
 "status        - show paths with changes\n"
 "update        - add working tree state to the staged set of changes\n"
@@ -15295,85 +21383,91 @@ msgid ""
 "patch         - pick hunks and update selectively\n"
 "diff          - view diff between HEAD and index\n"
 "add untracked - add contents of untracked files to the staged set of changes\n"
-msgstr "status        - показать пути с изменениями\nupdate        - добавить состояние рабочего каталога индекс\nrevert        - вернуть проиндексированный набор изменений к HEAD версии\npatch         - выбрать и выборочно обновить блоки\ndiff          - просмотреть различия между HEAD и индексом\nadd untracked - добавить содержимое неотслеживаемых файлов в индекс\n"
+msgstr "status        - показать пути с изменениями\nupdate        - добавить состояние рабочего каталога индекс\nrevert        - вернуть проиндексированный набор изменений к HEAD версии\npatch         - выбрать и выборочно обновить блоки\ndiff          - просмотреть изменения между HEAD и индексом\nadd untracked - добавить содержимое неотслеживаемых файлов в индекс\n"
 
-#: git-add--interactive.perl:1641 git-add--interactive.perl:1646
-#: git-add--interactive.perl:1649 git-add--interactive.perl:1656
-#: git-add--interactive.perl:1660 git-add--interactive.perl:1666
+#: git-add--interactive.perl:1742 git-add--interactive.perl:1747
+#: git-add--interactive.perl:1750 git-add--interactive.perl:1757
+#: git-add--interactive.perl:1761 git-add--interactive.perl:1767
 msgid "missing --"
 msgstr "отсутствует --"
 
-#: git-add--interactive.perl:1662
+#: git-add--interactive.perl:1763
 #, perl-format
 msgid "unknown --patch mode: %s"
 msgstr "неизвестный режим для --patch: %s"
 
-#: git-add--interactive.perl:1668 git-add--interactive.perl:1674
+#: git-add--interactive.perl:1769 git-add--interactive.perl:1775
 #, perl-format
 msgid "invalid argument %s, expecting --"
 msgstr "недопустимый аргумент %s, ожидается --"
 
-#: git-send-email.perl:126
+#: git-send-email.perl:138
 msgid "local zone differs from GMT by a non-minute interval\n"
 msgstr "локальный часовой пояс отличается от GMT на не минутный интервал\n"
 
-#: git-send-email.perl:133 git-send-email.perl:139
+#: git-send-email.perl:145 git-send-email.perl:151
 msgid "local time offset greater than or equal to 24 hours\n"
 msgstr "локальный сдвиг времени больше или равен 24 часа\n"
 
-#: git-send-email.perl:207 git-send-email.perl:213
+#: git-send-email.perl:219 git-send-email.perl:225
 msgid "the editor exited uncleanly, aborting everything"
 msgstr "редактор был завершен с ошибкой, отменяю всё"
 
-#: git-send-email.perl:290
+#: git-send-email.perl:302
 #, perl-format
 msgid "'%s' contains an intermediate version of the email you were composing.\n"
 msgstr "«%s» содержит промежуточную версию письма, которое вы готовите.\n"
 
-#: git-send-email.perl:295
+#: git-send-email.perl:307
 #, perl-format
 msgid "'%s.final' contains the composed email.\n"
 msgstr "«%s.final» содержит подготовленное письмо.\n"
 
-#: git-send-email.perl:313
+#: git-send-email.perl:326
 msgid "--dump-aliases incompatible with other options\n"
 msgstr "--dump-aliases не совместимо с другими опциями\n"
 
-#: git-send-email.perl:378 git-send-email.perl:629
+#: git-send-email.perl:395 git-send-email.perl:656
 msgid "Cannot run git format-patch from outside a repository\n"
 msgstr "Нельзя запускать git format-patch вне репозитория\n"
 
-#: git-send-email.perl:447
+#: git-send-email.perl:398
+msgid ""
+"`batch-size` and `relogin` must be specified together (via command-line or "
+"configuration option)\n"
+msgstr ""
+
+#: git-send-email.perl:470
 #, perl-format
 msgid "Unknown --suppress-cc field: '%s'\n"
 msgstr "Неизвестное поле --suppress-cc: «%s»\n"
 
-#: git-send-email.perl:476
+#: git-send-email.perl:501
 #, perl-format
 msgid "Unknown --confirm setting: '%s'\n"
 msgstr "Неизвестный параметр --confirm: «%s»\n"
 
-#: git-send-email.perl:504
+#: git-send-email.perl:529
 #, perl-format
 msgid "warning: sendmail alias with quotes is not supported: %s\n"
 msgstr "предупреждение: сокращение для sendmail с кавычками не поддерживается: %s\n"
 
-#: git-send-email.perl:506
+#: git-send-email.perl:531
 #, perl-format
 msgid "warning: `:include:` not supported: %s\n"
 msgstr "предупреждение: «:include:» не поддерживается: %s\n"
 
-#: git-send-email.perl:508
+#: git-send-email.perl:533
 #, perl-format
 msgid "warning: `/file` or `|pipe` redirection not supported: %s\n"
 msgstr "предупреждение: перенаправление «/file» или «|pipe» не поддерживается: %s\n"
 
-#: git-send-email.perl:513
+#: git-send-email.perl:538
 #, perl-format
 msgid "warning: sendmail line is not recognized: %s\n"
 msgstr "предупреждение: строка sendmail не распознана: %s\n"
 
-#: git-send-email.perl:595
+#: git-send-email.perl:622
 #, perl-format
 msgid ""
 "File '%s' exists but it could also be the range of commits\n"
@@ -15383,79 +21477,75 @@ msgid ""
 "    * Giving --format-patch option if you mean a range.\n"
 msgstr "Файл «%s» существует, но это также может быть и\nдиапазоном коммитов для которых нужно сделать патчи. \nУстраните неоднозначность…\n\n    * Указав \"./%s\" если вы имеете в виду имя файла; или\n    * Передав опцию --format-patch если вы имеете в виду диапазон коммитов.\n"
 
-#: git-send-email.perl:616
+#: git-send-email.perl:643
 #, perl-format
 msgid "Failed to opendir %s: %s"
 msgstr "Не удалось выполнить opendir %s: %s"
 
-#: git-send-email.perl:640
+#: git-send-email.perl:667
 #, perl-format
 msgid ""
 "fatal: %s: %s\n"
 "warning: no patches were sent\n"
 msgstr "критическая ошибка: %s: %s\nпредупреждение: патчи не были отправлены\n"
 
-#: git-send-email.perl:651
+#: git-send-email.perl:678
 msgid ""
 "\n"
 "No patch files specified!\n"
 "\n"
 msgstr "\nФайл с патчем не указан!\n\n"
 
-#: git-send-email.perl:664
+#: git-send-email.perl:691
 #, perl-format
 msgid "No subject line in %s?"
 msgstr "Нет строки с темой в %s?"
 
-#: git-send-email.perl:674
+#: git-send-email.perl:701
 #, perl-format
 msgid "Failed to open for writing %s: %s"
 msgstr "Не удалось открыть для записи %s: %s"
 
-#: git-send-email.perl:684
+#: git-send-email.perl:712
 msgid ""
 "Lines beginning in \"GIT:\" will be removed.\n"
 "Consider including an overall diffstat or table of contents\n"
 "for the patch you are writing.\n"
 "\n"
 "Clear the body content if you don't wish to send a summary.\n"
-msgstr "Строки, начинающиеся с «GIT:» будут удалены.\nВозможно будет полезно включить статистику добавлений\nи удалений или таблицу содержимого в патч, который вы пишете.\n\nОчистите содержимое, если вы не хотите отправлять письмо с краткой информацией.\n"
-
-#: git-send-email.perl:707
-#, perl-format
-msgid "Failed to open %s.final: %s"
-msgstr "Не удалось открыть %s.final: %s"
+msgstr "Строки, начинающиеся с «GIT:» будут удалены.\nВозможно будет полезно включить статистику добавлений\nи удалений или таблицу содержимого к создаваемому патчу.\n\nОчистите содержимое, если вы не хотите отправлять письмо со сводкой изменений.\n"
 
-#: git-send-email.perl:710
+#: git-send-email.perl:736
 #, perl-format
 msgid "Failed to open %s: %s"
 msgstr "Не удалось открыть %s: %s"
 
-#: git-send-email.perl:745
-msgid "To/Cc/Bcc fields are not interpreted yet, they have been ignored\n"
-msgstr "Поля To/Cc/Bcc пока еще не обрабатываются и будут проигнорированы\n"
+#: git-send-email.perl:753
+#, perl-format
+msgid "Failed to open %s.final: %s"
+msgstr "Не удалось открыть %s.final: %s"
 
-#: git-send-email.perl:754
+#: git-send-email.perl:796
 msgid "Summary email is empty, skipping it\n"
-msgstr "Письмо с краткой информацией пустое, попускаю его\n"
+msgstr "Письмо со сводкой изменений пустое, попускаю его\n"
 
 #. TRANSLATORS: please keep [y/N] as is.
-#: git-send-email.perl:786
+#: git-send-email.perl:831
 #, perl-format
 msgid "Are you sure you want to use <%s> [y/N]? "
 msgstr "Вы уверены, что хотите использовать <%s> [y/N]? "
 
-#: git-send-email.perl:815
+#: git-send-email.perl:886
 msgid ""
 "The following files are 8bit, but do not declare a Content-Transfer-"
 "Encoding.\n"
 msgstr "Следующие файлы 8 битные, но не содержат Content-Transfer-Encoding.\n"
 
-#: git-send-email.perl:820
+#: git-send-email.perl:891
 msgid "Which 8bit encoding should I declare [UTF-8]? "
 msgstr "Какую 8 битную кодировку нужно указать [UTF-8]? "
 
-#: git-send-email.perl:828
+#: git-send-email.perl:899
 #, perl-format
 msgid ""
 "Refusing to send because the patch\n"
@@ -15463,20 +21553,20 @@ msgid ""
 "has the template subject '*** SUBJECT HERE ***'. Pass --force if you really want to send.\n"
 msgstr "Отказываюсь отправить, т.к. патч\n\t%s\nсодержит шаблонный заголовок «*** SUBJECT HERE ***». Укажите параметр --force, если вы  действительно хотите отправить его.\n"
 
-#: git-send-email.perl:847
+#: git-send-email.perl:918
 msgid "To whom should the emails be sent (if anyone)?"
 msgstr "Кому должны быть отправлены письма (если нужно)?"
 
-#: git-send-email.perl:865
+#: git-send-email.perl:936
 #, perl-format
 msgid "fatal: alias '%s' expands to itself\n"
 msgstr "критическая ошибка: сокращение «%s» раскрывается само в себя\n"
 
-#: git-send-email.perl:877
+#: git-send-email.perl:948
 msgid "Message-ID to be used as In-Reply-To for the first email (if any)? "
 msgstr "Message-ID который нужно использовать в поле In-Reply-To для первого письма (если нужно)? "
 
-#: git-send-email.perl:929 git-send-email.perl:937
+#: git-send-email.perl:1006 git-send-email.perl:1014
 #, perl-format
 msgid "error: unable to extract a valid address from: %s\n"
 msgstr "ошибка: не удалось выделить действительный адрес из: %s\n"
@@ -15484,16 +21574,16 @@ msgstr "ошибка: не удалос
 #. TRANSLATORS: Make sure to include [q] [d] [e] in your
 #. translation. The program will only accept English input
 #. at this point.
-#: git-send-email.perl:941
+#: git-send-email.perl:1018
 msgid "What to do with this address? ([q]uit|[d]rop|[e]dit): "
 msgstr "Что нужно сделать с этим адресом? ([q] - выход|[d] - отбросить|[e] - редактировать): "
 
-#: git-send-email.perl:1262
+#: git-send-email.perl:1335
 #, perl-format
 msgid "CA path \"%s\" does not exist"
 msgstr "путь CA «%s» не существует"
 
-#: git-send-email.perl:1337
+#: git-send-email.perl:1418
 msgid ""
 "    The Cc list above has been expanded by additional\n"
 "    addresses found in the patch commit message. By default\n"
@@ -15505,133 +21595,133 @@ msgid ""
 "    To retain the current behavior, but squelch this message,\n"
 "    run 'git config --global sendemail.confirm auto'.\n"
 "\n"
-msgstr "    Список Cc (получателей копии письма) был расширен дополнительными\n    адресами, найденными в сообщении коммита патча. По умолчанию\n    send-email переспашивает перед отправкой, когда она происходит.\n   Это поведение может быть изменено параметром файла конфигурации\n    sendemail.confirm.\n\n    Для дополнительной информации, запустите «git send-email --help».\n    Чтобы оставить текущее поведение, но скрыть это сообщение,\n    запустите «git config --global sendemail.confirm auto».\n\n"
+msgstr "    Список Cc (получателей копии письма) был расширен дополнительными\n    адресами, найденными в сообщении коммита патча. По умолчанию\n    send-email переспрашивает перед отправкой, когда она происходит.\n   Это поведение может быть изменено параметром файла конфигурации\n    sendemail.confirm.\n\n    Для дополнительной информации, запустите «git send-email --help».\n    Чтобы оставить текущее поведение, но скрыть это сообщение,\n    запустите «git config --global sendemail.confirm auto».\n\n"
 
-#. TRANSLATORS: Make sure to include [y] [n] [q] [a] in your
+#. TRANSLATORS: Make sure to include [y] [n] [e] [q] [a] in your
 #. translation. The program will only accept English input
 #. at this point.
-#: git-send-email.perl:1352
-msgid "Send this email? ([y]es|[n]o|[q]uit|[a]ll): "
-msgstr "Отправить это письмо? ([y] - да|[n] - нет|[q] - выход|[a] - все): "
+#: git-send-email.perl:1433
+msgid "Send this email? ([y]es|[n]o|[e]dit|[q]uit|[a]ll): "
+msgstr "Отправить это письмо? ([y] - да|[n] - нет|[e] - изменить|[q] - выход|[a] - все): "
 
-#: git-send-email.perl:1355
+#: git-send-email.perl:1436
 msgid "Send this email reply required"
 msgstr "Отправка этого ответа на письмо обязательна"
 
-#: git-send-email.perl:1381
+#: git-send-email.perl:1464
 msgid "The required SMTP server is not properly defined."
 msgstr "Требуемый SMTP сервер не был правильно объявлен."
 
-#: git-send-email.perl:1428
+#: git-send-email.perl:1511
 #, perl-format
 msgid "Server does not support STARTTLS! %s"
 msgstr "Сервер не поддерживает STARTTLS! %s"
 
-#: git-send-email.perl:1433 git-send-email.perl:1437
+#: git-send-email.perl:1516 git-send-email.perl:1520
 #, perl-format
 msgid "STARTTLS failed! %s"
 msgstr "Ошибка STARTTLS! %s"
 
-#: git-send-email.perl:1447
+#: git-send-email.perl:1529
 msgid "Unable to initialize SMTP properly. Check config and use --smtp-debug."
 msgstr "Не удалось инициализировать SMTP. Проверьте ваши настройки и попробуйте запустить в параметром --smtp-debug."
 
-#: git-send-email.perl:1465
+#: git-send-email.perl:1547
 #, perl-format
 msgid "Failed to send %s\n"
 msgstr "Не удалось отправить %s\n"
 
-#: git-send-email.perl:1468
+#: git-send-email.perl:1550
 #, perl-format
 msgid "Dry-Sent %s\n"
 msgstr "Имитация отправки %s\n"
 
-#: git-send-email.perl:1468
+#: git-send-email.perl:1550
 #, perl-format
 msgid "Sent %s\n"
 msgstr "Отправлено %s\n"
 
-#: git-send-email.perl:1470
+#: git-send-email.perl:1552
 msgid "Dry-OK. Log says:\n"
 msgstr "Имитация OK. Журнал содержит:\n"
 
-#: git-send-email.perl:1470
+#: git-send-email.perl:1552
 msgid "OK. Log says:\n"
 msgstr "OK. Журнал содержит:\n"
 
-#: git-send-email.perl:1482
+#: git-send-email.perl:1564
 msgid "Result: "
 msgstr "Результат: "
 
-#: git-send-email.perl:1485
+#: git-send-email.perl:1567
 msgid "Result: OK\n"
 msgstr "Результат: OK\n"
 
-#: git-send-email.perl:1498
+#: git-send-email.perl:1585
 #, perl-format
 msgid "can't open file %s"
 msgstr "не удалось открыть файл %s"
 
-#: git-send-email.perl:1545 git-send-email.perl:1565
+#: git-send-email.perl:1632 git-send-email.perl:1652
 #, perl-format
 msgid "(mbox) Adding cc: %s from line '%s'\n"
 msgstr "(mbox) Добавление cc: %s со строки «%s»\n"
 
-#: git-send-email.perl:1551
+#: git-send-email.perl:1638
 #, perl-format
 msgid "(mbox) Adding to: %s from line '%s'\n"
 msgstr "(mbox) Добавление to: %s со строки «%s»\n"
 
-#: git-send-email.perl:1599
+#: git-send-email.perl:1691
 #, perl-format
 msgid "(non-mbox) Adding cc: %s from line '%s'\n"
 msgstr "(non-mbox) Добавление cc: %s со строки «%s»\n"
 
-#: git-send-email.perl:1624
+#: git-send-email.perl:1726
 #, perl-format
 msgid "(body) Adding cc: %s from line '%s'\n"
 msgstr "(body) Добавление cc: %s со строки «%s»\n"
 
-#: git-send-email.perl:1730
+#: git-send-email.perl:1837
 #, perl-format
 msgid "(%s) Could not execute '%s'"
 msgstr "(%s) Не удалось выполнить «%s»"
 
-#: git-send-email.perl:1737
+#: git-send-email.perl:1844
 #, perl-format
 msgid "(%s) Adding %s: %s from: '%s'\n"
 msgstr "(%s) Добавление %s: %s из: «%s»\n"
 
-#: git-send-email.perl:1741
+#: git-send-email.perl:1848
 #, perl-format
 msgid "(%s) failed to close pipe to '%s'"
 msgstr "(%s) не удалось закрыть поток к «%s»"
 
-#: git-send-email.perl:1768
+#: git-send-email.perl:1878
 msgid "cannot send message as 7bit"
 msgstr "не удалось отправить сообщение в 7 битной кодировке"
 
-#: git-send-email.perl:1776
+#: git-send-email.perl:1886
 msgid "invalid transfer encoding"
 msgstr "недопустимая кодировка передачи"
 
-#: git-send-email.perl:1814 git-send-email.perl:1865 git-send-email.perl:1875
+#: git-send-email.perl:1927 git-send-email.perl:1979 git-send-email.perl:1989
 #, perl-format
 msgid "unable to open %s: %s\n"
 msgstr "не удалось открыть %s: %s\n"
 
-#: git-send-email.perl:1817
+#: git-send-email.perl:1930
 #, perl-format
 msgid "%s: patch contains a line longer than 998 characters"
 msgstr "%s: патч содержит строку длиннее чем 998 символов"
 
-#: git-send-email.perl:1833
+#: git-send-email.perl:1947
 #, perl-format
 msgid "Skipping %s with backup suffix '%s'.\n"
 msgstr "Пропускаю %s с окончанием резервной копии «%s».\n"
 
 #. TRANSLATORS: please keep "[y|N]" as is.
-#: git-send-email.perl:1837
+#: git-send-email.perl:1951
 #, perl-format
 msgid "Do you really want to send %s? [y|N]: "
 msgstr "Вы действительно хотите отправить %s? [y - да|N - нет]: "
diff -pruN 1.2.1+git2.18.0-1/git/po/sv.po 1.2.3+git2.25.1-1/git/po/sv.po
--- 1.2.1+git2.18.0-1/git/po/sv.po	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/po/sv.po	2020-02-17 04:47:35.000000000 +0000
@@ -1,14 +1,14 @@
 # Swedish translations for Git.
-# Copyright (C) 2010-2018 Peter Krefting <peter@softwolves.pp.se>
+# Copyright (C) 2010-2020 Peter Krefting <peter@softwolves.pp.se>
 # This file is distributed under the same license as the Git package.
-# Peter Krefting <peter@softwolves.pp.se>, 2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018.
+# Peter Krefting <peter@softwolves.pp.se>, 2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019, 2020.
 #
 msgid ""
 msgstr ""
-"Project-Id-Version: git 2.18.0\n"
+"Project-Id-Version: git 2.25.0\n"
 "Report-Msgid-Bugs-To: Git Mailing List <git@vger.kernel.org>\n"
-"POT-Creation-Date: 2018-06-08 09:03+0800\n"
-"PO-Revision-Date: 2018-06-08 22:53+0100\n"
+"POT-Creation-Date: 2019-12-30 08:48+0800\n"
+"PO-Revision-Date: 2020-01-04 19:51+0100\n"
 "Last-Translator: Peter Krefting <peter@softwolves.pp.se>\n"
 "Language-Team: Swedish <tp-sv@listor.tp-sv.se>\n"
 "Language: sv\n"
@@ -18,47 +18,473 @@ msgstr ""
 "Plural-Forms: nplurals=2; plural=(n != 1);\n"
 "X-Generator: Gtranslator 2.91.7\n"
 
-#: advice.c:92
+#: add-interactive.c:347
+#, c-format
+msgid "Huh (%s)?"
+msgstr "Vadå (%s)?"
+
+#: add-interactive.c:500 add-interactive.c:801 sequencer.c:3216
+#: sequencer.c:3656 builtin/rebase.c:871 builtin/rebase.c:1643
+#: builtin/rebase.c:2019 builtin/rebase.c:2063
+msgid "could not read index"
+msgstr "kunde inte läsa indexet"
+
+#: add-interactive.c:555 git-add--interactive.perl:269
+#: git-add--interactive.perl:294
+msgid "binary"
+msgstr "binär"
+
+#: add-interactive.c:613 git-add--interactive.perl:278
+#: git-add--interactive.perl:332
+msgid "nothing"
+msgstr "ingenting"
+
+#: add-interactive.c:614 git-add--interactive.perl:314
+#: git-add--interactive.perl:329
+msgid "unchanged"
+msgstr "oändrad"
+
+#: add-interactive.c:651 git-add--interactive.perl:643
+msgid "Update"
+msgstr "Uppdatera"
+
+#: add-interactive.c:668 add-interactive.c:856
+#, c-format
+msgid "could not stage '%s'"
+msgstr "kunde inte köa \"%s\""
+
+#: add-interactive.c:674 add-interactive.c:863 sequencer.c:3409
+#: builtin/rebase.c:895
+msgid "could not write index"
+msgstr "kunde inte skriva indexet"
+
+#: add-interactive.c:677 git-add--interactive.perl:628
+#, c-format, perl-format
+msgid "updated %d path\n"
+msgid_plural "updated %d paths\n"
+msgstr[0] "uppdaterade %d sökväg\n"
+msgstr[1] "uppdaterade %d sökvägar\n"
+
+#: add-interactive.c:695 git-add--interactive.perl:678
+#, c-format, perl-format
+msgid "note: %s is untracked now.\n"
+msgstr "observera: %s spåras inte längre.\n"
+
+#: add-interactive.c:700 apply.c:4108 builtin/checkout.c:281
+#: builtin/reset.c:144
+#, c-format
+msgid "make_cache_entry failed for path '%s'"
+msgstr "make_cache_entry misslyckades för sökvägen \"%s\""
+
+#: add-interactive.c:730 git-add--interactive.perl:655
+msgid "Revert"
+msgstr "Återställ"
+
+#: add-interactive.c:746
+msgid "Could not parse HEAD^{tree}"
+msgstr "kunde inte tolka HEAD^{tree}"
+
+#: add-interactive.c:784 git-add--interactive.perl:631
+#, c-format, perl-format
+msgid "reverted %d path\n"
+msgid_plural "reverted %d paths\n"
+msgstr[0] "återställde %d sökväg\n"
+msgstr[1] "återställde %d sökvägar\n"
+
+#: add-interactive.c:835 git-add--interactive.perl:695
+#, c-format
+msgid "No untracked files.\n"
+msgstr "Inga ospårade filer.\n"
+
+#: add-interactive.c:839 git-add--interactive.perl:689
+msgid "Add untracked"
+msgstr "Lägg till ospårad"
+
+#: add-interactive.c:866 git-add--interactive.perl:625
+#, c-format, perl-format
+msgid "added %d path\n"
+msgid_plural "added %d paths\n"
+msgstr[0] "lade till %d sökväg\n"
+msgstr[1] "lade till %d sökvägar\n"
+
+#: add-interactive.c:896
+#, c-format
+msgid "ignoring unmerged: %s"
+msgstr "ignorerar ej sammanslagen: %s"
+
+#: add-interactive.c:908 add-patch.c:1331 git-add--interactive.perl:1366
+#, c-format
+msgid "Only binary files changed.\n"
+msgstr "Endast binära filer ändrade.\n"
+
+#: add-interactive.c:910 add-patch.c:1329 git-add--interactive.perl:1368
+#, c-format
+msgid "No changes.\n"
+msgstr "Inga ändringar.\n"
+
+#: add-interactive.c:914 git-add--interactive.perl:1376
+msgid "Patch update"
+msgstr "Uppdatera patch"
+
+#: add-interactive.c:953 git-add--interactive.perl:1754
+msgid "Review diff"
+msgstr "Granska diff"
+
+#: add-interactive.c:981
+msgid "show paths with changes"
+msgstr "visa sökvägar med ändringar"
+
+#: add-interactive.c:983
+msgid "add working tree state to the staged set of changes"
+msgstr "lägg arbetskatalogens tillstånd till köade ändringar"
+
+#: add-interactive.c:985
+msgid "revert staged set of changes back to the HEAD version"
+msgstr "återställ köade ändringar tillbaka till HEAD-versionen"
+
+#: add-interactive.c:987
+msgid "pick hunks and update selectively"
+msgstr "välj stycken och uppdatera selektivt"
+
+#: add-interactive.c:989
+msgid "view diff between HEAD and index"
+msgstr "visa skillnad mellan HEAD och index"
+
+#: add-interactive.c:991
+msgid "add contents of untracked files to the staged set of changes"
+msgstr "lägg innehåll i ospårade filer till köade ändringar"
+
+#: add-interactive.c:999 add-interactive.c:1048
+msgid "Prompt help:"
+msgstr "Kommandoradshjälp:"
+
+#: add-interactive.c:1001
+msgid "select a single item"
+msgstr "markera en post"
+
+#: add-interactive.c:1003
+msgid "select a range of items"
+msgstr "markera intervall av poster"
+
+#: add-interactive.c:1005
+msgid "select multiple ranges"
+msgstr "markera flera intervall"
+
+#: add-interactive.c:1007 add-interactive.c:1052
+msgid "select item based on unique prefix"
+msgstr "markera post baserad på unikt prefix"
+
+#: add-interactive.c:1009
+msgid "unselect specified items"
+msgstr "avmarkera angivna poster"
+
+#: add-interactive.c:1011
+msgid "choose all items"
+msgstr "välj alla poster"
+
+#: add-interactive.c:1013
+msgid "(empty) finish selecting"
+msgstr "(tomt) avsluta markering"
+
+#: add-interactive.c:1050
+msgid "select a numbered item"
+msgstr "markera en numrerad post"
+
+#: add-interactive.c:1054
+msgid "(empty) select nothing"
+msgstr "(tomt) markera ingenting"
+
+#: add-interactive.c:1062 builtin/clean.c:822 git-add--interactive.perl:1851
+msgid "*** Commands ***"
+msgstr "*** Kommandon ***"
+
+#: add-interactive.c:1063 builtin/clean.c:823 git-add--interactive.perl:1848
+msgid "What now"
+msgstr "Vad nu"
+
+#: add-interactive.c:1115 git-add--interactive.perl:213
+msgid "staged"
+msgstr "köad"
+
+#: add-interactive.c:1115 git-add--interactive.perl:213
+msgid "unstaged"
+msgstr "ej köad"
+
+#: add-interactive.c:1115 apply.c:4965 apply.c:4968 builtin/am.c:2197
+#: builtin/am.c:2200 builtin/clone.c:123 builtin/fetch.c:144
+#: builtin/merge.c:273 builtin/pull.c:209 builtin/submodule--helper.c:409
+#: builtin/submodule--helper.c:1379 builtin/submodule--helper.c:1382
+#: builtin/submodule--helper.c:1875 builtin/submodule--helper.c:1878
+#: builtin/submodule--helper.c:2119 git-add--interactive.perl:213
+msgid "path"
+msgstr "sökväg"
+
+#: add-interactive.c:1122
+msgid "could not refresh index"
+msgstr "kunde inte uppdatera indexet"
+
+#: add-interactive.c:1136 builtin/clean.c:787 git-add--interactive.perl:1765
+#, c-format
+msgid "Bye.\n"
+msgstr "Hej då.\n"
+
+#: add-patch.c:15
+#, c-format
+msgid "Stage mode change [y,n,a,q,d%s,?]? "
+msgstr "Köa ändrat läge [y,n,a,q,d%s,?]? "
+
+#: add-patch.c:16
+#, c-format
+msgid "Stage deletion [y,n,a,q,d%s,?]? "
+msgstr "Köa borttagning [y,n,a,q,d%s,?]? "
+
+#: add-patch.c:17
+#, c-format
+msgid "Stage this hunk [y,n,a,q,d%s,?]? "
+msgstr "Köa stycket [y,n,a,q,d%s,?]? "
+
+#: add-patch.c:111
+#, c-format
+msgid "could not parse hunk header '%.*s'"
+msgstr "kunde inte tolka styckehuvudet \"%.*s\""
+
+#: add-patch.c:130 add-patch.c:134
+#, c-format
+msgid "could not parse colored hunk header '%.*s'"
+msgstr "kunde inte tolka färgat styckehuvud \"%.*s\""
+
+#: add-patch.c:176
+msgid "could not parse diff"
+msgstr "kunde inte tolka diff"
+
+#: add-patch.c:194
+msgid "could not parse colored diff"
+msgstr "kunde inte tolka färgad diff"
+
+#: add-patch.c:508
+#, c-format
+msgid ""
+"expected context line #%d in\n"
+"%.*s"
+msgstr ""
+"förväntade sammanhangsrad %d i\n"
+"%.*s"
+
+#: add-patch.c:523
+#, c-format
+msgid ""
+"hunks do not overlap:\n"
+"%.*s\n"
+"\tdoes not end with:\n"
+"%.*s"
+msgstr ""
+"stycken överlappar inte:\n"
+"%.*s\n"
+"\tavslutas inte med:\n"
+"%.*s"
+
+#: add-patch.c:799 git-add--interactive.perl:1112
+msgid "Manual hunk edit mode -- see bottom for a quick guide.\n"
+msgstr "Manuellt styckeredigeringsläge -- se nederst för snabbguide.\n"
+
+#: add-patch.c:803
+#, c-format
+msgid ""
+"---\n"
+"To remove '%c' lines, make them ' ' lines (context).\n"
+"To remove '%c' lines, delete them.\n"
+"Lines starting with %c will be removed.\n"
+msgstr ""
+"---\n"
+"Ta bort \"%c\" rader genom att göra dem \" \"-rader (sammanhang).\n"
+"Ta bort \"%c\" rader genom att radera dem.\n"
+"Rader som börjar med %c kommer att tas bort.\n"
+
+#: add-patch.c:810
+msgid ""
+"If the patch applies cleanly, the edited hunk will immediately be\n"
+"marked for staging.\n"
+msgstr ""
+"Om patchen kan appliceras rent kommer det redigerade stycket att\n"
+"köas omedelbart.\n"
+
+#. TRANSLATORS: 'it' refers to the patch mentioned in the previous messages.
+#: add-patch.c:818 git-add--interactive.perl:1126
+msgid ""
+"If it does not apply cleanly, you will be given an opportunity to\n"
+"edit again.  If all lines of the hunk are removed, then the edit is\n"
+"aborted and the hunk is left unchanged.\n"
+msgstr ""
+"Om patchen inte kan appliceras rent kommer du få en möjlighet att\n"
+"redigera den igen. Om alla rader i ett stycke tas bort avbryts\n"
+"redigeringen och stycket lämnas oförändrat.\n"
+
+#: add-patch.c:851
+msgid "could not parse hunk header"
+msgstr "kunde inte tolka styckehuvud"
+
+#: add-patch.c:895 add-patch.c:1294
+msgid "'git apply --cached' failed"
+msgstr "\"git apply --cached\" misslyckades"
+
+#. TRANSLATORS: do not translate [y/n]
+#. The program will only accept that input at this point.
+#. Consider translating (saying "no" discards!) as
+#. (saying "n" for "no" discards!) if the translation
+#. of the word "no" does not start with n.
+#.
+#. TRANSLATORS: do not translate [y/n]
+#. The program will only accept that input
+#. at this point.
+#. Consider translating (saying "no" discards!) as
+#. (saying "n" for "no" discards!) if the translation
+#. of the word "no" does not start with n.
+#: add-patch.c:952 git-add--interactive.perl:1239
+msgid ""
+"Your edited hunk does not apply. Edit again (saying \"no\" discards!) [y/n]? "
+msgstr ""
+"Ditt redigerade stycke kan inte appliceras. Redigera igen (\"nej\" kastar!) "
+"[y/n]? "
+
+#: add-patch.c:1009
+msgid ""
+"y - stage this hunk\n"
+"n - do not stage this hunk\n"
+"q - quit; do not stage this hunk or any of the remaining ones\n"
+"a - stage this and all the remaining hunks\n"
+"d - do not stage this hunk nor any of the remaining hunks\n"
+msgstr ""
+"y - köa stycket\n"
+"n - köa inte stycket\n"
+"q - avsluta; köa inte stycket eller något av de följande\n"
+"a - köa detta och alla följande stycken\n"
+"d - köa inte stycket eller något av de stycken som följer\n"
+
+#: add-patch.c:1016
+msgid ""
+"j - leave this hunk undecided, see next undecided hunk\n"
+"J - leave this hunk undecided, see next hunk\n"
+"k - leave this hunk undecided, see previous undecided hunk\n"
+"K - leave this hunk undecided, see previous hunk\n"
+"g - select a hunk to go to\n"
+"/ - search for a hunk matching the given regex\n"
+"s - split the current hunk into smaller hunks\n"
+"e - manually edit the current hunk\n"
+"? - print help\n"
+msgstr ""
+"j - lämna stycket obestämt, se nästa obestämda stycke\n"
+"J - lämna stycket obestämt, se nästa stycke\n"
+"k - lämna stycket obestämt, se föregående obestämda stycke\n"
+"K - lämna stycket obestämt, se föregående stycke\n"
+"g - välj ett stycke att gå till\n"
+"/ - sök efter stycke som motsvarar angivet reguljärt uttryck\n"
+"s - dela aktuellt stycke i mindre styckens\n"
+"e - redigera aktuellt stycke manuellt\n"
+"? - visa hjälp\n"
+
+#: add-patch.c:1137 add-patch.c:1147
+msgid "No previous hunk"
+msgstr "Inget föregående stycke"
+
+#: add-patch.c:1142 add-patch.c:1152
+msgid "No next hunk"
+msgstr "Inget följande stycke"
+
+#: add-patch.c:1158
+msgid "No other hunks to goto"
+msgstr "Inga andra stycken att gå till"
+
+#: add-patch.c:1169 git-add--interactive.perl:1577
+msgid "go to which hunk (<ret> to see more)? "
+msgstr "gå till vilket stycke (<ret> för att se fler)? "
+
+#: add-patch.c:1170 git-add--interactive.perl:1579
+msgid "go to which hunk? "
+msgstr "gå till vilket stycke? "
+
+#: add-patch.c:1181
+#, c-format
+msgid "Invalid number: '%s'"
+msgstr "Ogiltigt siffervärde: \"%s\""
+
+#: add-patch.c:1186
+#, c-format
+msgid "Sorry, only %d hunk available."
+msgid_plural "Sorry, only %d hunks available."
+msgstr[0] "Beklagar, det finns bara %d stycke."
+msgstr[1] "Beklagar, det finns bara %d stycken."
+
+#: add-patch.c:1195
+msgid "No other hunks to search"
+msgstr "Inga andra stycken att söka efter"
+
+#: add-patch.c:1201 git-add--interactive.perl:1623
+msgid "search for regex? "
+msgstr "sök efter reguljärt uttryck? "
+
+#: add-patch.c:1216
+#, c-format
+msgid "Malformed search regexp %s: %s"
+msgstr "Felaktigt format på reguljärt sökuttryck %s: %s"
+
+#: add-patch.c:1233
+msgid "No hunk matches the given pattern"
+msgstr "Inga stycken motsvarar givet mönster"
+
+#: add-patch.c:1240
+msgid "Sorry, cannot split this hunk"
+msgstr "Beklagar, kan inte dela stycket"
+
+#: add-patch.c:1244
+#, c-format
+msgid "Split into %d hunks."
+msgstr "Dela i %d stycken."
+
+#: add-patch.c:1248
+msgid "Sorry, cannot edit this hunk"
+msgstr "Beklagar, kan inte redigera stycket"
+
+#: advice.c:111
 #, c-format
 msgid "%shint: %.*s%s\n"
 msgstr "%stips: %.*s%s\n"
 
-#: advice.c:137
+#: advice.c:164
 msgid "Cherry-picking is not possible because you have unmerged files."
 msgstr ""
 "Du kan inte utföra en cherry-pick eftersom du har filer som inte slagits "
 "samman."
 
-#: advice.c:139
+#: advice.c:166
 msgid "Committing is not possible because you have unmerged files."
 msgstr ""
 "Du kan inte utföra en incheckning eftersom du har filer som inte slagits "
 "samman."
 
-#: advice.c:141
+#: advice.c:168
 msgid "Merging is not possible because you have unmerged files."
 msgstr ""
 "Du kan inte utföra en sammanslagning eftersom du har filer som inte slagits "
 "samman."
 
-#: advice.c:143
+#: advice.c:170
 msgid "Pulling is not possible because you have unmerged files."
 msgstr ""
 "Du kan inte utföra en \"pull\" eftersom du har filer som inte slagits samman."
 
-#: advice.c:145
+#: advice.c:172
 msgid "Reverting is not possible because you have unmerged files."
 msgstr ""
 "Du kan inte utföra en \"revert\" eftersom du har filer som inte slagits "
 "samman."
 
-#: advice.c:147
+#: advice.c:174
 #, c-format
 msgid "It is not possible to %s because you have unmerged files."
 msgstr ""
 "Du kan inte utföra en \"%s\" eftersom du har filer som inte slagits samman."
 
-#: advice.c:155
+#: advice.c:182
 msgid ""
 "Fix them up in the work tree, and then use 'git add/rm <file>'\n"
 "as appropriate to mark resolution and make a commit."
@@ -66,137 +492,149 @@ msgstr ""
 "Rätta dem i din arbetskatalog och använd sedan \"git add/rm <fil>\"\n"
 "som lämpligt för att ange lösning och checka in."
 
-#: advice.c:163
+#: advice.c:190
 msgid "Exiting because of an unresolved conflict."
 msgstr "Avslutar på grund av olöst konflikgt."
 
-#: advice.c:168 builtin/merge.c:1250
+#: advice.c:195 builtin/merge.c:1332
 msgid "You have not concluded your merge (MERGE_HEAD exists)."
 msgstr "Du har inte avslutat sammanslagningen (MERGE_HEAD finns)."
 
-#: advice.c:170
+#: advice.c:197
 msgid "Please, commit your changes before merging."
 msgstr "Checka in dina ändringar innan du utför sammanslagningen."
 
-#: advice.c:171
+#: advice.c:198
 msgid "Exiting because of unfinished merge."
 msgstr "Avslutar på grund av ofullbordad sammanslagning."
 
-#: advice.c:177
+#: advice.c:204
 #, c-format
 msgid ""
-"Note: checking out '%s'.\n"
+"Note: switching to '%s'.\n"
 "\n"
 "You are in 'detached HEAD' state. You can look around, make experimental\n"
 "changes and commit them, and you can discard any commits you make in this\n"
-"state without impacting any branches by performing another checkout.\n"
+"state without impacting any branches by switching back to a branch.\n"
 "\n"
 "If you want to create a new branch to retain commits you create, you may\n"
-"do so (now or later) by using -b with the checkout command again. Example:\n"
+"do so (now or later) by using -c with the switch command. Example:\n"
 "\n"
-"  git checkout -b <new-branch-name>\n"
+"  git switch -c <new-branch-name>\n"
+"\n"
+"Or undo this operation with:\n"
+"\n"
+"  git switch -\n"
+"\n"
+"Turn off this advice by setting config variable advice.detachedHead to "
+"false\n"
 "\n"
 msgstr ""
 "Observera: checkar ut \"%s\".\n"
 "\n"
 "Du har nu ett \"frånkopplat HEAD\". Du kan se dig omkring, experimentera\n"
 "med ändringar och checka in dem, och du kan kasta incheckningar du gör\n"
-"i det här läget utan att det påverkar grenar genom att checka ut på\n"
-"nytt.\n"
+"i det här läget utan att det påverkar grenar genom att växla tillbaka\n"
+"till en gren.\n"
 "\n"
 "Om du vill skapa en ny gren för att behålla ändringarna du skapar, kan\n"
-"du göra det (nu eller senare) genom att använda checkout-kommandot igen\n"
-"med -b. Till exempel:\n"
+"du göra det (nu eller senare) genom att använda switch-kommandot med -c.\n"
+"Exempel:\n"
+"\n"
+"  git switch -c <namn-på-ny-gren>\n"
 "\n"
-"  git checkout -b <namn-på-ny-gren>\n"
+"Eller gör den här ändringen ogjord med:\n"
 "\n"
+"  git switch -\n"
+"\n"
+"Stäng av den här hjälptexten genom att sätta konfigurationsvariabeln\n"
+"advice.detachedHead till false\n"
+"\n"
+
+#: alias.c:50
+msgid "cmdline ends with \\"
+msgstr "kommandorad avslutas med \\"
+
+#: alias.c:51
+msgid "unclosed quote"
+msgstr "citat ej stängt"
 
-#: apply.c:58
+#: apply.c:69
 #, c-format
 msgid "unrecognized whitespace option '%s'"
 msgstr "okänt alternativ för whitespace: \"%s\""
 
-#: apply.c:74
+#: apply.c:85
 #, c-format
 msgid "unrecognized whitespace ignore option '%s'"
 msgstr "okänt alternativ för ignore-whitespace: \"%s\""
 
-#: apply.c:122
+#: apply.c:135
 msgid "--reject and --3way cannot be used together."
 msgstr "--reject och --3way kan inte användas samtidigt."
 
-#: apply.c:124
+#: apply.c:137
 msgid "--cached and --3way cannot be used together."
 msgstr "--cached och --3way kan inte användas samtidigt."
 
-#: apply.c:127
+#: apply.c:140
 msgid "--3way outside a repository"
 msgstr "--3way utanför arkiv"
 
-#: apply.c:138
+#: apply.c:151
 msgid "--index outside a repository"
 msgstr "--index utanför arkiv"
 
-#: apply.c:141
+#: apply.c:154
 msgid "--cached outside a repository"
 msgstr "--cached utanför arkiv"
 
-#: apply.c:821
+#: apply.c:801
 #, c-format
 msgid "Cannot prepare timestamp regexp %s"
 msgstr "Kan inte förbereda reguljärt uttryck för tidsstämpeln %s"
 
-#: apply.c:830
+#: apply.c:810
 #, c-format
 msgid "regexec returned %d for input: %s"
 msgstr "regexec returnerade %d för indata: %s"
 
-#: apply.c:904
+#: apply.c:884
 #, c-format
 msgid "unable to find filename in patch at line %d"
 msgstr "kan inte hitta filnamn i patchen på rad %d"
 
-#: apply.c:942
+#: apply.c:922
 #, c-format
 msgid "git apply: bad git-diff - expected /dev/null, got %s on line %d"
 msgstr "git apply: dålig git-diff - förväntade /dev/null, fick %s på rad %d"
 
-#: apply.c:948
+#: apply.c:928
 #, c-format
 msgid "git apply: bad git-diff - inconsistent new filename on line %d"
 msgstr "git apply: dålig git-diff - motsägande nytt filnamn på rad %d"
 
-#: apply.c:949
+#: apply.c:929
 #, c-format
 msgid "git apply: bad git-diff - inconsistent old filename on line %d"
 msgstr "git apply: dålig git-diff - motsägande gammalt filnamn på rad %d"
 
-#: apply.c:954
+#: apply.c:934
 #, c-format
 msgid "git apply: bad git-diff - expected /dev/null on line %d"
 msgstr "git apply: dålig git-diff - förväntade /dev/null på rad %d"
 
-#: apply.c:983
+#: apply.c:963
 #, c-format
 msgid "invalid mode on line %d: %s"
 msgstr "ogiltigt läge på rad %d: %s"
 
-#: apply.c:1301
+#: apply.c:1282
 #, c-format
 msgid "inconsistent header lines %d and %d"
 msgstr "huvudet är inkonsekvent mellan rad %d och %d"
 
-#: apply.c:1473
-#, c-format
-msgid "recount: unexpected line: %.*s"
-msgstr "recount: förväntade rad: %.*s"
-
-#: apply.c:1542
-#, c-format
-msgid "patch fragment without header at line %d: %.*s"
-msgstr "patch-fragment utan huvud på rad %d: %.*s"
-
-#: apply.c:1562
+#: apply.c:1372
 #, c-format
 msgid ""
 "git diff header lacks filename information when removing %d leading pathname "
@@ -212,82 +650,92 @@ msgstr[1] ""
 "sökvägskomponenter\n"
 "tas bort (rad %d)"
 
-#: apply.c:1575
+#: apply.c:1385
 #, c-format
 msgid "git diff header lacks filename information (line %d)"
 msgstr "git-diff-huvudet saknar filnamnsinformation (rad %d)"
 
-#: apply.c:1763
+#: apply.c:1481
+#, c-format
+msgid "recount: unexpected line: %.*s"
+msgstr "recount: förväntade rad: %.*s"
+
+#: apply.c:1550
+#, c-format
+msgid "patch fragment without header at line %d: %.*s"
+msgstr "patch-fragment utan huvud på rad %d: %.*s"
+
+#: apply.c:1753
 msgid "new file depends on old contents"
 msgstr "ny fil beror på gammalt innehåll"
 
-#: apply.c:1765
+#: apply.c:1755
 msgid "deleted file still has contents"
 msgstr "borttagen fil har fortfarande innehåll"
 
-#: apply.c:1799
+#: apply.c:1789
 #, c-format
 msgid "corrupt patch at line %d"
 msgstr "trasig patch på rad %d"
 
-#: apply.c:1836
+#: apply.c:1826
 #, c-format
 msgid "new file %s depends on old contents"
 msgstr "nya filen %s beror på gammalt innehåll"
 
-#: apply.c:1838
+#: apply.c:1828
 #, c-format
 msgid "deleted file %s still has contents"
 msgstr "borttagna filen %s har fortfarande innehåll"
 
-#: apply.c:1841
+#: apply.c:1831
 #, c-format
 msgid "** warning: file %s becomes empty but is not deleted"
 msgstr "** varning: filen %s blir tom men har inte tagits bort"
 
-#: apply.c:1988
+#: apply.c:1978
 #, c-format
 msgid "corrupt binary patch at line %d: %.*s"
 msgstr "trasig binärpatch på rad %d: %.*s"
 
-#: apply.c:2025
+#: apply.c:2015
 #, c-format
 msgid "unrecognized binary patch at line %d"
 msgstr "binärpatchen på rad %d känns inte igen"
 
-#: apply.c:2185
+#: apply.c:2177
 #, c-format
 msgid "patch with only garbage at line %d"
 msgstr "patch med bara skräp på rad %d"
 
-#: apply.c:2271
+#: apply.c:2263
 #, c-format
 msgid "unable to read symlink %s"
 msgstr "kunde inte läsa symboliska länken %s"
 
-#: apply.c:2275
+#: apply.c:2267
 #, c-format
 msgid "unable to open or read %s"
 msgstr "kunde inte öppna eller läsa %s"
 
-#: apply.c:2934
+#: apply.c:2936
 #, c-format
 msgid "invalid start of line: '%c'"
 msgstr "felaktig inledning på rad: \"%c\""
 
-#: apply.c:3055
+#: apply.c:3057
 #, c-format
 msgid "Hunk #%d succeeded at %d (offset %d line)."
 msgid_plural "Hunk #%d succeeded at %d (offset %d lines)."
 msgstr[0] "Stycke %d lyckades på %d (offset %d rad)."
 msgstr[1] "Stycke %d lyckades på %d (offset %d rader)."
 
-#: apply.c:3067
+#: apply.c:3069
 #, c-format
 msgid "Context reduced to (%ld/%ld) to apply fragment at %d"
 msgstr "Sammanhang reducerat till (%ld/%ld) för att tillämpa fragment vid %d"
 
-#: apply.c:3073
+#: apply.c:3075
 #, c-format
 msgid ""
 "while searching for:\n"
@@ -296,25 +744,25 @@ msgstr ""
 "vid sökning efter:\n"
 "%.*s"
 
-#: apply.c:3095
+#: apply.c:3097
 #, c-format
 msgid "missing binary patch data for '%s'"
 msgstr "saknar binära patchdata för \"%s\""
 
-#: apply.c:3103
+#: apply.c:3105
 #, c-format
 msgid "cannot reverse-apply a binary patch without the reverse hunk to '%s'"
 msgstr ""
 "kan inte applicera en binärpatch baklänges utan den omvända patchen för \"%s"
 "\""
 
-#: apply.c:3149
+#: apply.c:3152
 #, c-format
 msgid "cannot apply binary patch to '%s' without full index line"
 msgstr ""
 "kan inte applicera binärpatch på \"%s\" utan den fullständiga indexraden"
 
-#: apply.c:3159
+#: apply.c:3162
 #, c-format
 msgid ""
 "the patch applies to '%s' (%s), which does not match the current contents."
@@ -322,545 +770,611 @@ msgstr ""
 "patchen appliceras på \"%s\" (%s), som inte motsvarar det nuvarande "
 "innehållet."
 
-#: apply.c:3167
+#: apply.c:3170
 #, c-format
 msgid "the patch applies to an empty '%s' but it is not empty"
 msgstr "patchen appliceras på en tom \"%s\", men den är inte tom"
 
-#: apply.c:3185
+#: apply.c:3188
 #, c-format
 msgid "the necessary postimage %s for '%s' cannot be read"
 msgstr "nödvändig efterbild %s för \"%s\" kan inte läsas"
 
-#: apply.c:3198
+#: apply.c:3201
 #, c-format
 msgid "binary patch does not apply to '%s'"
 msgstr "binärpatchen kan inte tillämpas på \"%s\""
 
-#: apply.c:3204
+#: apply.c:3207
 #, c-format
 msgid "binary patch to '%s' creates incorrect result (expecting %s, got %s)"
 msgstr "binärpatchen på \"%s\" ger felaktigt resultat (förväntade %s, fick %s)"
 
-#: apply.c:3225
+#: apply.c:3228
 #, c-format
 msgid "patch failed: %s:%ld"
 msgstr "patch misslyckades: %s:%ld"
 
-#: apply.c:3347
+#: apply.c:3351
 #, c-format
 msgid "cannot checkout %s"
 msgstr "kan inte checka ut %s"
 
-#: apply.c:3396 apply.c:3407 apply.c:3453 setup.c:278
+#: apply.c:3403 apply.c:3414 apply.c:3460 midx.c:61 setup.c:280
 #, c-format
 msgid "failed to read %s"
 msgstr "misslyckades läsa %s"
 
-#: apply.c:3404
+#: apply.c:3411
 #, c-format
 msgid "reading from '%s' beyond a symbolic link"
 msgstr "läser från \"%s\" som är på andra sidan av en symbolisk länk"
 
-#: apply.c:3433 apply.c:3673
+#: apply.c:3440 apply.c:3683
 #, c-format
 msgid "path %s has been renamed/deleted"
 msgstr "sökvägen %s har ändrat namn/tagits bort"
 
-#: apply.c:3516 apply.c:3687
+#: apply.c:3526 apply.c:3698
 #, c-format
 msgid "%s: does not exist in index"
 msgstr "%s: finns inte i indexet"
 
-#: apply.c:3525 apply.c:3695
+#: apply.c:3535 apply.c:3706
 #, c-format
 msgid "%s: does not match index"
 msgstr "%s: motsvarar inte indexet"
 
-#: apply.c:3560
+#: apply.c:3570
 msgid "repository lacks the necessary blob to fall back on 3-way merge."
 msgstr ""
 "arkivet saknar objekt som behövs för att falla tillbaka på 3-"
 "vägssammanslagning."
 
-#: apply.c:3563
+#: apply.c:3573
 #, c-format
 msgid "Falling back to three-way merge...\n"
 msgstr "Faller tillbaka på trevägssammanslagning...\n"
 
-#: apply.c:3579 apply.c:3583
+#: apply.c:3589 apply.c:3593
 #, c-format
 msgid "cannot read the current contents of '%s'"
 msgstr "kunde inte läsa aktuellt innehåll i \"%s\""
 
-#: apply.c:3595
+#: apply.c:3605
 #, c-format
 msgid "Failed to fall back on three-way merge...\n"
 msgstr "Misslyckades falla tillbaka på trevägssammanslagning...\n"
 
-#: apply.c:3609
+#: apply.c:3619
 #, c-format
 msgid "Applied patch to '%s' with conflicts.\n"
 msgstr "Applicerade patchen på \"%s\" med konflikter.\n"
 
-#: apply.c:3614
+#: apply.c:3624
 #, c-format
 msgid "Applied patch to '%s' cleanly.\n"
 msgstr "Tillämpade patchen på  \"%s\" rent.\n"
 
-#: apply.c:3640
+#: apply.c:3650
 msgid "removal patch leaves file contents"
 msgstr "patch för borttagning lämnar kvar filinnehåll"
 
-#: apply.c:3712
+#: apply.c:3723
 #, c-format
 msgid "%s: wrong type"
 msgstr "%s: fel typ"
 
-#: apply.c:3714
+#: apply.c:3725
 #, c-format
 msgid "%s has type %o, expected %o"
 msgstr "%s har typen %o, förväntade %o"
 
-#: apply.c:3864 apply.c:3866
+#: apply.c:3876 apply.c:3878 read-cache.c:830 read-cache.c:856
+#: read-cache.c:1320
 #, c-format
 msgid "invalid path '%s'"
-msgstr "ogiltig sökväg ”%s”"
+msgstr "ogiltig sökväg \"%s\""
 
-#: apply.c:3922
+#: apply.c:3934
 #, c-format
 msgid "%s: already exists in index"
 msgstr "%s: finns redan i indexet"
 
-#: apply.c:3925
+#: apply.c:3937
 #, c-format
 msgid "%s: already exists in working directory"
 msgstr "%s: finns redan i arbetskatalogen"
 
-#: apply.c:3945
+#: apply.c:3957
 #, c-format
 msgid "new mode (%o) of %s does not match old mode (%o)"
 msgstr "nytt läge (%o) för %s motsvarar inte gammalt läge (%o)"
 
-#: apply.c:3950
+#: apply.c:3962
 #, c-format
 msgid "new mode (%o) of %s does not match old mode (%o) of %s"
 msgstr "nytt läge (%o) för %s motsvarar inte gammalt läge (%o) för %s"
 
-#: apply.c:3970
+#: apply.c:3982
 #, c-format
 msgid "affected file '%s' is beyond a symbolic link"
 msgstr "den berörda filen \"%s\" är på andra sidan av en symbolisk länk"
 
-#: apply.c:3974
+#: apply.c:3986
 #, c-format
 msgid "%s: patch does not apply"
 msgstr "%s: patchen kan inte tillämpas"
 
-#: apply.c:3989
+#: apply.c:4001
 #, c-format
 msgid "Checking patch %s..."
 msgstr "Kontrollerar patchen %s..."
 
-#: apply.c:4080
+#: apply.c:4093
 #, c-format
 msgid "sha1 information is lacking or useless for submodule %s"
 msgstr "sha1-informationen saknas eller är oanvändbar för undermodulen %s"
 
-#: apply.c:4087
+#: apply.c:4100
 #, c-format
 msgid "mode change for %s, which is not in current HEAD"
 msgstr "nytt läge för %s, som inte finns i nuvarande HEAD"
 
-#: apply.c:4090
+#: apply.c:4103
 #, c-format
 msgid "sha1 information is lacking or useless (%s)."
 msgstr "sha1-informationen saknas eller är oanvändbar (%s)."
 
-#: apply.c:4095 builtin/checkout.c:235 builtin/reset.c:140
-#, c-format
-msgid "make_cache_entry failed for path '%s'"
-msgstr "make_cache_entry misslyckades för sökvägen \"%s\""
-
-#: apply.c:4099
+#: apply.c:4112
 #, c-format
 msgid "could not add %s to temporary index"
 msgstr "kunde inte lägga till %s till temporärt index"
 
-#: apply.c:4109
+#: apply.c:4122
 #, c-format
 msgid "could not write temporary index to %s"
 msgstr "kunde inte skriva temporärt index till %s"
 
-#: apply.c:4247
+#: apply.c:4260
 #, c-format
 msgid "unable to remove %s from index"
 msgstr "kan inte ta bort %s från indexet"
 
-#: apply.c:4282
+#: apply.c:4294
 #, c-format
 msgid "corrupt patch for submodule %s"
 msgstr "trasig patch för undermodulen %s"
 
-#: apply.c:4288
+#: apply.c:4300
 #, c-format
 msgid "unable to stat newly created file '%s'"
 msgstr "kan inte ta status på nyligen skapade filen \"%s\""
 
-#: apply.c:4296
+#: apply.c:4308
 #, c-format
 msgid "unable to create backing store for newly created file %s"
 msgstr "kan inte skapa säkerhetsminne för nyligen skapade filen %s"
 
-#: apply.c:4302 apply.c:4446
+#: apply.c:4314 apply.c:4459
 #, c-format
 msgid "unable to add cache entry for %s"
 msgstr "kan inte lägga till cachepost för %s"
 
-#: apply.c:4343
+#: apply.c:4357
 #, c-format
 msgid "failed to write to '%s'"
 msgstr "misslyckades skriva till \"%s\""
 
-#: apply.c:4347
+#: apply.c:4361
 #, c-format
 msgid "closing file '%s'"
 msgstr "stänger filen \"%s\""
 
-#: apply.c:4417
+#: apply.c:4431
 #, c-format
 msgid "unable to write file '%s' mode %o"
 msgstr "kan inte skriva filen \"%s\" läge %o"
 
-#: apply.c:4515
+#: apply.c:4529
 #, c-format
 msgid "Applied patch %s cleanly."
 msgstr "Tillämpade patchen %s rent."
 
-#: apply.c:4523
+#: apply.c:4537
 msgid "internal error"
 msgstr "internt fel"
 
-#: apply.c:4526
+#: apply.c:4540
 #, c-format
 msgid "Applying patch %%s with %d reject..."
 msgid_plural "Applying patch %%s with %d rejects..."
 msgstr[0] "Tillämpade patchen %%s med %d refuserad..."
 msgstr[1] "Tillämpade patchen %%s med %d refuserade..."
 
-#: apply.c:4537
+#: apply.c:4551
 #, c-format
 msgid "truncating .rej filename to %.*s.rej"
 msgstr "trunkerar .rej-filnamnet till %.*s.rej"
 
-#: apply.c:4545 builtin/fetch.c:786 builtin/fetch.c:1036
+#: apply.c:4559 builtin/fetch.c:901 builtin/fetch.c:1192
 #, c-format
 msgid "cannot open %s"
 msgstr "kan inte öppna %s"
 
-#: apply.c:4559
+#: apply.c:4573
 #, c-format
 msgid "Hunk #%d applied cleanly."
 msgstr "Stycke %d tillämpades rent."
 
-#: apply.c:4563
+#: apply.c:4577
 #, c-format
 msgid "Rejected hunk #%d."
 msgstr "Refuserar stycke %d."
 
-#: apply.c:4673
+#: apply.c:4696
 #, c-format
 msgid "Skipped patch '%s'."
 msgstr "Ignorerar patch \"%s\"."
 
-#: apply.c:4681
+#: apply.c:4704
 msgid "unrecognized input"
 msgstr "indata känns inte igen"
 
-#: apply.c:4700
+#: apply.c:4724
 msgid "unable to read index file"
 msgstr "kan inte läsa indexfilen"
 
-#: apply.c:4837
+#: apply.c:4881
 #, c-format
 msgid "can't open patch '%s': %s"
 msgstr "kan inte öppna patchen \"%s\": %s"
 
-#: apply.c:4864
+#: apply.c:4908
 #, c-format
 msgid "squelched %d whitespace error"
 msgid_plural "squelched %d whitespace errors"
 msgstr[0] "undertryckte %d fel i blanksteg"
 msgstr[1] "undertryckte %d fel i blanksteg"
 
-#: apply.c:4870 apply.c:4885
+#: apply.c:4914 apply.c:4929
 #, c-format
 msgid "%d line adds whitespace errors."
 msgid_plural "%d lines add whitespace errors."
 msgstr[0] "%d rad lägger till fel i blanksteg."
 msgstr[1] "%d rader lägger till fel i blanksteg."
 
-#: apply.c:4878
+#: apply.c:4922
 #, c-format
 msgid "%d line applied after fixing whitespace errors."
 msgid_plural "%d lines applied after fixing whitespace errors."
 msgstr[0] "%d rad applicerade efter att ha rättat fel i blanksteg."
 msgstr[1] "%d rader applicerade efter att ha rättat fel i blanksteg."
 
-#: apply.c:4894 builtin/add.c:538 builtin/mv.c:300 builtin/rm.c:389
+#: apply.c:4938 builtin/add.c:579 builtin/mv.c:301 builtin/rm.c:390
 msgid "Unable to write new index file"
 msgstr "Kunde inte skriva ny indexfil"
 
-#: apply.c:4921 apply.c:4924 builtin/am.c:2254 builtin/am.c:2257
-#: builtin/clone.c:120 builtin/fetch.c:126 builtin/pull.c:198
-#: builtin/submodule--helper.c:405 builtin/submodule--helper.c:1210
-#: builtin/submodule--helper.c:1213 builtin/submodule--helper.c:1584
-#: builtin/submodule--helper.c:1587 builtin/submodule--helper.c:1807
-#: git-add--interactive.perl:197
-msgid "path"
-msgstr "sökväg"
-
-#: apply.c:4922
+#: apply.c:4966
 msgid "don't apply changes matching the given path"
 msgstr "tillämpa inte ändringar som motsvarar given sökväg"
 
-#: apply.c:4925
+#: apply.c:4969
 msgid "apply changes matching the given path"
 msgstr "tillämpa ändringar som motsvarar given sökväg"
 
-#: apply.c:4927 builtin/am.c:2263
+#: apply.c:4971 builtin/am.c:2206
 msgid "num"
 msgstr "antal"
 
-#: apply.c:4928
+#: apply.c:4972
 msgid "remove <num> leading slashes from traditional diff paths"
 msgstr "ta bort <antal> inledande snedstreck från traditionella diff-sökvägar"
 
-#: apply.c:4931
+#: apply.c:4975
 msgid "ignore additions made by the patch"
 msgstr "ignorera tillägg gjorda av patchen"
 
-#: apply.c:4933
+#: apply.c:4977
 msgid "instead of applying the patch, output diffstat for the input"
 msgstr "istället för att tillämpa patchen, skriv ut diffstat för indata"
 
-#: apply.c:4937
+#: apply.c:4981
 msgid "show number of added and deleted lines in decimal notation"
 msgstr "visa antal tillagda och borttagna rader decimalt"
 
-#: apply.c:4939
+#: apply.c:4983
 msgid "instead of applying the patch, output a summary for the input"
 msgstr "istället för att tillämpa patchen, skriv ut en summering av indata"
 
-#: apply.c:4941
+#: apply.c:4985
 msgid "instead of applying the patch, see if the patch is applicable"
 msgstr "istället för att tillämpa patchen, se om patchen kan tillämpas"
 
-#: apply.c:4943
+#: apply.c:4987
 msgid "make sure the patch is applicable to the current index"
 msgstr "se till att patchen kan tillämpas på aktuellt index"
 
-#: apply.c:4945
+#: apply.c:4989
+msgid "mark new files with `git add --intent-to-add`"
+msgstr "markera nya filer med \"git add --intent-to-add\""
+
+#: apply.c:4991
 msgid "apply a patch without touching the working tree"
 msgstr "tillämpa en patch utan att röra arbetskatalogen"
 
-#: apply.c:4947
+#: apply.c:4993
 msgid "accept a patch that touches outside the working area"
 msgstr "godta en patch som rör filer utanför arbetskatalogen"
 
-#: apply.c:4950
+#: apply.c:4996
 msgid "also apply the patch (use with --stat/--summary/--check)"
 msgstr "tillämpa också patchen (använd med --stat/--summary/--check)"
 
-#: apply.c:4952
+#: apply.c:4998
 msgid "attempt three-way merge if a patch does not apply"
 msgstr "försök en trevägssammanslagning om patchen inte kan tillämpas"
 
-#: apply.c:4954
+#: apply.c:5000
 msgid "build a temporary index based on embedded index information"
 msgstr "bygg ett temporärt index baserat på inbyggd indexinformation"
 
-#: apply.c:4957 builtin/checkout-index.c:168 builtin/ls-files.c:515
+#: apply.c:5003 builtin/checkout-index.c:173 builtin/ls-files.c:524
 msgid "paths are separated with NUL character"
 msgstr "sökvägar avdelas med NUL-tecken"
 
-#: apply.c:4959
+#: apply.c:5005
 msgid "ensure at least <n> lines of context match"
 msgstr "se till att åtminstone <n> rader sammanhang är lika"
 
-#: apply.c:4960 builtin/am.c:2242 builtin/interpret-trailers.c:95
-#: builtin/interpret-trailers.c:97 builtin/interpret-trailers.c:99
-#: builtin/pack-objects.c:3177
+#: apply.c:5006 builtin/am.c:2185 builtin/interpret-trailers.c:98
+#: builtin/interpret-trailers.c:100 builtin/interpret-trailers.c:102
+#: builtin/pack-objects.c:3310 builtin/rebase.c:1474
 msgid "action"
 msgstr "åtgärd"
 
-#: apply.c:4961
+#: apply.c:5007
 msgid "detect new or modified lines that have whitespace errors"
 msgstr "detektera nya eller ändrade rader som har fel i blanktecken"
 
-#: apply.c:4964 apply.c:4967
+#: apply.c:5010 apply.c:5013
 msgid "ignore changes in whitespace when finding context"
 msgstr "ignorera ändringar i blanktecken för sammanhang"
 
-#: apply.c:4970
+#: apply.c:5016
 msgid "apply the patch in reverse"
 msgstr "tillämpa patchen baklänges"
 
-#: apply.c:4972
+#: apply.c:5018
 msgid "don't expect at least one line of context"
 msgstr "förvänta inte minst en rad sammanhang"
 
-#: apply.c:4974
+#: apply.c:5020
 msgid "leave the rejected hunks in corresponding *.rej files"
 msgstr "lämna refuserade stycken i motsvarande *.rej-filer"
 
-#: apply.c:4976
+#: apply.c:5022
 msgid "allow overlapping hunks"
 msgstr "tillåt överlappande stycken"
 
-#: apply.c:4977 builtin/add.c:290 builtin/check-ignore.c:21
-#: builtin/commit.c:1301 builtin/count-objects.c:98 builtin/fsck.c:666
-#: builtin/log.c:1901 builtin/mv.c:122 builtin/read-tree.c:124
+#: apply.c:5023 builtin/add.c:309 builtin/check-ignore.c:22
+#: builtin/commit.c:1355 builtin/count-objects.c:98 builtin/fsck.c:774
+#: builtin/log.c:2166 builtin/mv.c:123 builtin/read-tree.c:128
 msgid "be verbose"
 msgstr "var pratsam"
 
-#: apply.c:4979
+#: apply.c:5025
 msgid "tolerate incorrectly detected missing new-line at the end of file"
 msgstr "tolerera felaktigt detekterade saknade nyradstecken vid filslut"
 
-#: apply.c:4982
+#: apply.c:5028
 msgid "do not trust the line counts in the hunk headers"
 msgstr "lite inte på antalet linjer i styckehuvuden"
 
-#: apply.c:4984 builtin/am.c:2251
+#: apply.c:5030 builtin/am.c:2194
 msgid "root"
 msgstr "rot"
 
-#: apply.c:4985
+#: apply.c:5031
 msgid "prepend <root> to all filenames"
 msgstr "lägg till <rot> i alla filnamn"
 
-#: archive.c:13
+#: archive.c:14
 msgid "git archive [<options>] <tree-ish> [<path>...]"
 msgstr "git archive [<flaggor>] <träd-igt> [<sökväg>...]"
 
-#: archive.c:14
+#: archive.c:15
 msgid "git archive --list"
 msgstr "git archive --list"
 
-#: archive.c:15
+#: archive.c:16
 msgid ""
 "git archive --remote <repo> [--exec <cmd>] [<options>] <tree-ish> [<path>...]"
 msgstr ""
 "git archive --remote <arkiv> [--exec <kmd>] [<flaggor>] <träd-igt> "
 "[<sökväg>...]"
 
-#: archive.c:16
+#: archive.c:17
 msgid "git archive --remote <repo> [--exec <cmd>] --list"
 msgstr "git archive --remote <arkiv> [--exec <kmd>] --list"
 
-#: archive.c:351 builtin/add.c:176 builtin/add.c:514 builtin/rm.c:298
+#: archive.c:372 builtin/add.c:180 builtin/add.c:555 builtin/rm.c:299
 #, c-format
 msgid "pathspec '%s' did not match any files"
 msgstr "sökvägsangivelsen \"%s\" motsvarade inte några filer"
 
-#: archive.c:434
+#: archive.c:396
+#, c-format
+msgid "no such ref: %.*s"
+msgstr "ingen sådan referens: %.*s"
+
+#: archive.c:401
+#, c-format
+msgid "not a valid object name: %s"
+msgstr "objektnamnet är inte giltigt: %s"
+
+#: archive.c:414
+#, c-format
+msgid "not a tree object: %s"
+msgstr "inte ett trädobjekt: %s"
+
+#: archive.c:426
+msgid "current working directory is untracked"
+msgstr "aktuell arbetskatalog är inte spårad"
+
+#: archive.c:457
 msgid "fmt"
 msgstr "fmt"
 
-#: archive.c:434
+#: archive.c:457
 msgid "archive format"
 msgstr "arkivformat"
 
-#: archive.c:435 builtin/log.c:1462
+#: archive.c:458 builtin/log.c:1653
 msgid "prefix"
 msgstr "prefix"
 
-#: archive.c:436
+#: archive.c:459
 msgid "prepend prefix to each pathname in the archive"
 msgstr "lägg till prefix till varje sökväg i arkivet"
 
-#: archive.c:437 builtin/blame.c:813 builtin/blame.c:814 builtin/config.c:127
-#: builtin/fast-export.c:1007 builtin/fast-export.c:1009 builtin/grep.c:869
-#: builtin/hash-object.c:103 builtin/ls-files.c:551 builtin/ls-files.c:554
-#: builtin/notes.c:405 builtin/notes.c:568 builtin/read-tree.c:119
-#: parse-options.h:165
+#: archive.c:460 builtin/blame.c:861 builtin/blame.c:865 builtin/blame.c:866
+#: builtin/commit-tree.c:117 builtin/config.c:129 builtin/fast-export.c:1162
+#: builtin/fast-export.c:1164 builtin/fast-export.c:1168 builtin/grep.c:899
+#: builtin/hash-object.c:105 builtin/ls-files.c:560 builtin/ls-files.c:563
+#: builtin/notes.c:412 builtin/notes.c:578 builtin/read-tree.c:123
+#: parse-options.h:190
 msgid "file"
 msgstr "fil"
 
-#: archive.c:438 builtin/archive.c:89
+#: archive.c:461 builtin/archive.c:90
 msgid "write the archive to this file"
 msgstr "skriv arkivet till filen"
 
-#: archive.c:440
+#: archive.c:463
 msgid "read .gitattributes in working directory"
 msgstr "läs .gitattributes i arbetskatalogen"
 
-#: archive.c:441
+#: archive.c:464
 msgid "report archived files on stderr"
 msgstr "rapportera arkiverade filer på standard fel"
 
-#: archive.c:442
+#: archive.c:465
 msgid "store only"
 msgstr "endast spara"
 
-#: archive.c:443
+#: archive.c:466
 msgid "compress faster"
 msgstr "komprimera snabbare"
 
-#: archive.c:451
+#: archive.c:474
 msgid "compress better"
 msgstr "komprimera bättre"
 
-#: archive.c:454
+#: archive.c:477
 msgid "list supported archive formats"
 msgstr "visa understödda arkivformat"
 
-#: archive.c:456 builtin/archive.c:90 builtin/clone.c:110 builtin/clone.c:113
-#: builtin/submodule--helper.c:1222 builtin/submodule--helper.c:1593
+#: archive.c:479 builtin/archive.c:91 builtin/clone.c:113 builtin/clone.c:116
+#: builtin/submodule--helper.c:1391 builtin/submodule--helper.c:1884
 msgid "repo"
 msgstr "arkiv"
 
-#: archive.c:457 builtin/archive.c:91
+#: archive.c:480 builtin/archive.c:92
 msgid "retrieve the archive from remote repository <repo>"
 msgstr "hämta arkivet från fjärrarkivet <arkiv>"
 
-#: archive.c:458 builtin/archive.c:92 builtin/notes.c:489
+#: archive.c:481 builtin/archive.c:93 builtin/difftool.c:715
+#: builtin/notes.c:498
 msgid "command"
 msgstr "kommando"
 
-#: archive.c:459 builtin/archive.c:93
+#: archive.c:482 builtin/archive.c:94
 msgid "path to the remote git-upload-archive command"
 msgstr "sökväg till kommandot git-upload-archive på fjärren"
 
-#: archive.c:466
+#: archive.c:489
 msgid "Unexpected option --remote"
 msgstr "Oväntad flagga --remote"
 
-#: archive.c:468
+#: archive.c:491
 msgid "Option --exec can only be used together with --remote"
 msgstr "Flaggan --exec kan endast användas tillsammans med --remote"
 
-#: archive.c:470
+#: archive.c:493
 msgid "Unexpected option --output"
 msgstr "Oväntad flagga --output"
 
-#: archive.c:492
+#: archive.c:515
 #, c-format
 msgid "Unknown archive format '%s'"
 msgstr "Okänt arkivformat \"%s\""
 
-#: archive.c:499
+#: archive.c:522
 #, c-format
 msgid "Argument not supported for format '%s': -%d"
 msgstr "Argumentet stöd inte för formatet \"%s\": -%d"
 
-#: attr.c:218
+#: archive-tar.c:125 archive-zip.c:350
+#, c-format
+msgid "cannot stream blob %s"
+msgstr "kan inte strömma blob:en %s"
+
+#: archive-tar.c:266 archive-zip.c:368
+#, c-format
+msgid "unsupported file mode: 0%o (SHA1: %s)"
+msgstr "filens läge stöds ej: 0%o (SHA1: %s)"
+
+#: archive-tar.c:293 archive-zip.c:358
+#, c-format
+msgid "cannot read %s"
+msgstr "kan inte läsa %s"
+
+#: archive-tar.c:465
+#, c-format
+msgid "unable to start '%s' filter"
+msgstr "kunde inte starta filtret \"%s\""
+
+#: archive-tar.c:468
+msgid "unable to redirect descriptor"
+msgstr "kan inte omdirigera handtag"
+
+#: archive-tar.c:475
+#, c-format
+msgid "'%s' filter reported error"
+msgstr "filtret \"%s\" rapporterade fel"
+
+#: archive-zip.c:319
+#, c-format
+msgid "path is not valid UTF-8: %s"
+msgstr "sökvägen är inte giltig UTF-8: %s"
+
+#: archive-zip.c:323
+#, c-format
+msgid "path too long (%d chars, SHA1: %s): %s"
+msgstr "sökvägen för lång (%d tecken, SHA1: %s): %s"
+
+#: archive-zip.c:479 builtin/pack-objects.c:230 builtin/pack-objects.c:233
+#, c-format
+msgid "deflate error (%d)"
+msgstr "fel i deflate (%d)"
+
+#: archive-zip.c:614
+#, c-format
+msgid "timestamp too large for this system: %<PRIuMAX>"
+msgstr "tidsstämpeln för stor för detta system: %<PRIuMAX>"
+
+#: attr.c:212
 #, c-format
 msgid "%.*s is not a valid attribute name"
 msgstr "%-*s är inte ett giltigt namn på attribut"
 
-#: attr.c:415
+#: attr.c:369
+#, c-format
+msgid "%s not allowed: %s:%d"
+msgstr "%s inte tillåtet: %s:%d"
+
+#: attr.c:409
 msgid ""
 "Negative patterns are ignored in git attributes\n"
 "Use '\\!' for literal leading exclamation."
@@ -868,22 +1382,22 @@ msgstr ""
 "Negativa mönster ignoreras i git-attribut\n"
 "Använd '\\!' för att inleda med ett utropstecken."
 
-#: bisect.c:461
+#: bisect.c:468
 #, c-format
 msgid "Badly quoted content in file '%s': %s"
 msgstr "Felaktigt citerat innehåll i filen \"%s\": %s"
 
-#: bisect.c:669
+#: bisect.c:678
 #, c-format
 msgid "We cannot bisect more!\n"
 msgstr "Det finns inte mer att göra \"bisect\" på!\n"
 
-#: bisect.c:723
+#: bisect.c:733
 #, c-format
 msgid "Not a valid commit name %s"
 msgstr "Namnet på incheckningen är inte giltigt: %s"
 
-#: bisect.c:747
+#: bisect.c:758
 #, c-format
 msgid ""
 "The merge base %s is bad.\n"
@@ -892,7 +1406,7 @@ msgstr ""
 "Sammanslagningsbasen %s är trasig.\n"
 "Det betyder att felet har rättats mellan %s och [%s].\n"
 
-#: bisect.c:752
+#: bisect.c:763
 #, c-format
 msgid ""
 "The merge base %s is new.\n"
@@ -901,7 +1415,7 @@ msgstr ""
 "Sammanslagningsbasen %s är ny.\n"
 "Egenskapen har ändrats mellan %s och [%s].\n"
 
-#: bisect.c:757
+#: bisect.c:768
 #, c-format
 msgid ""
 "The merge base %s is %s.\n"
@@ -910,7 +1424,7 @@ msgstr ""
 "Sammanslagningsbasen %s är %s.\n"
 "Det betyder att den första \"%s\" incheckningen är mellan %s och [%s].\n"
 
-#: bisect.c:765
+#: bisect.c:776
 #, c-format
 msgid ""
 "Some %s revs are not ancestors of the %s rev.\n"
@@ -921,7 +1435,7 @@ msgstr ""
 "git bisect kan inte fungera korrekt i detta fall.\n"
 "Kanske du skrev fel %s- och %s-revisioner?\n"
 
-#: bisect.c:778
+#: bisect.c:789
 #, c-format
 msgid ""
 "the merge base between %s and [%s] must be skipped.\n"
@@ -933,36 +1447,36 @@ msgstr ""
 "%s.\n"
 "Vi fortsätter ändå."
 
-#: bisect.c:811
+#: bisect.c:822
 #, c-format
 msgid "Bisecting: a merge base must be tested\n"
 msgstr "Bisect: en sammanslagningsbas måste testas\n"
 
-#: bisect.c:851
+#: bisect.c:865
 #, c-format
 msgid "a %s revision is needed"
 msgstr "en %s-revision behövs"
 
-#: bisect.c:870 builtin/notes.c:175 builtin/tag.c:236
+#: bisect.c:884 builtin/notes.c:177 builtin/tag.c:254
 #, c-format
 msgid "could not create file '%s'"
 msgstr "kunde inte skapa filen \"%s\""
 
-#: bisect.c:921
+#: bisect.c:928 builtin/merge.c:148
 #, c-format
 msgid "could not read file '%s'"
 msgstr "kunde inte läsa filen \"%s\""
 
-#: bisect.c:951
+#: bisect.c:958
 msgid "reading bisect refs failed"
 msgstr "misslyckades läsa bisect-referenser"
 
-#: bisect.c:970
+#: bisect.c:977
 #, c-format
 msgid "%s was both %s and %s\n"
 msgstr "%s var både %s och %s\n"
 
-#: bisect.c:978
+#: bisect.c:985
 #, c-format
 msgid ""
 "No testable commit found.\n"
@@ -971,7 +1485,7 @@ msgstr ""
 "Ingen testbar incheckning hittades.\n"
 "Kanske du startade med felaktiga sökvägsparametrar?\n"
 
-#: bisect.c:997
+#: bisect.c:1004
 #, c-format
 msgid "(roughly %d step)"
 msgid_plural "(roughly %d steps)"
@@ -981,52 +1495,53 @@ msgstr[1] "(ungefär %d steg)"
 #. TRANSLATORS: the last %s will be replaced with "(roughly %d
 #. steps)" translation.
 #.
-#: bisect.c:1003
+#: bisect.c:1010
 #, c-format
 msgid "Bisecting: %d revision left to test after this %s\n"
 msgid_plural "Bisecting: %d revisions left to test after this %s\n"
 msgstr[0] "Bisect: %d revision kvar att testa efter denna %s\n"
 msgstr[1] "Bisect: %d revisioner kvar att testa efter denna %s\n"
 
-#: blame.c:1756
+#: blame.c:2700
 msgid "--contents and --reverse do not blend well."
 msgstr "--contents och --reverse fungerar inte så bra tillsammans."
 
-#: blame.c:1767
+#: blame.c:2714
 msgid "cannot use --contents with final commit object name"
 msgstr "kan inte använda --contents med namn på slutgiltigt incheckningsobjekt"
 
-#: blame.c:1787
+#: blame.c:2735
 msgid "--reverse and --first-parent together require specified latest commit"
 msgstr ""
 "--reverse och --first-parent tillsammans kräver att du anger senaste "
 "incheckningen"
 
-#: blame.c:1796 bundle.c:160 ref-filter.c:2075 sequencer.c:1861
-#: sequencer.c:3632 builtin/commit.c:981 builtin/log.c:366 builtin/log.c:920
-#: builtin/log.c:1371 builtin/log.c:1702 builtin/log.c:1950 builtin/merge.c:372
+#: blame.c:2744 bundle.c:167 ref-filter.c:2203 remote.c:1941 sequencer.c:2093
+#: sequencer.c:4460 builtin/commit.c:1040 builtin/log.c:388 builtin/log.c:991
+#: builtin/log.c:1520 builtin/log.c:1925 builtin/log.c:2215 builtin/merge.c:411
+#: builtin/pack-objects.c:3128 builtin/pack-objects.c:3143
 #: builtin/shortlog.c:192
 msgid "revision walk setup failed"
 msgstr "misslyckades skapa revisionstraversering"
 
-#: blame.c:1814
+#: blame.c:2762
 msgid ""
 "--reverse --first-parent together require range along first-parent chain"
 msgstr ""
 "--reverse --first-parent tillsammans kräver ett intervall på första-förälder-"
 "kedjan"
 
-#: blame.c:1825
+#: blame.c:2773
 #, c-format
 msgid "no such path %s in %s"
 msgstr "sökvägen %s i %s finns inte"
 
-#: blame.c:1836
+#: blame.c:2784
 #, c-format
 msgid "cannot read blob %s for path %s"
 msgstr "kan inte läsa objektet %s för sökvägen %s"
 
-#: branch.c:54
+#: branch.c:53
 #, c-format
 msgid ""
 "\n"
@@ -1039,92 +1554,92 @@ msgstr ""
 "fjärrspårningsinformationen genom att utföra\n"
 "\"git branch --set-upstream-to=%s%s%s\"."
 
-#: branch.c:68
+#: branch.c:67
 #, c-format
 msgid "Not setting branch %s as its own upstream."
 msgstr "Ställer inte in grenen %s som sin egen uppströmsgren."
 
-#: branch.c:94
+#: branch.c:93
 #, c-format
 msgid "Branch '%s' set up to track remote branch '%s' from '%s' by rebasing."
 msgstr ""
 "Grenen %s ställdes in att spåra fjärrgrenen \"%s\" från \"%s\" genom "
 "ombasering."
 
-#: branch.c:95
+#: branch.c:94
 #, c-format
 msgid "Branch '%s' set up to track remote branch '%s' from '%s'."
 msgstr "Grenen %s ställdes in att spåra fjärrgrenen \"%s\" från \"%s\"."
 
-#: branch.c:99
+#: branch.c:98
 #, c-format
 msgid "Branch '%s' set up to track local branch '%s' by rebasing."
 msgstr ""
 "Grenen \"%s\" ställdes in att spåra den lokala grenen \"%s\"  genom "
 "ombasering."
 
-#: branch.c:100
+#: branch.c:99
 #, c-format
 msgid "Branch '%s' set up to track local branch '%s'."
 msgstr "Grenen \"%s\" ställdes in att spåra den lokala grenen \"%s\"."
 
-#: branch.c:105
+#: branch.c:104
 #, c-format
 msgid "Branch '%s' set up to track remote ref '%s' by rebasing."
 msgstr ""
 "Grenen \"%s\" ställdes in att spåra fjärreferensen \"%s\" genom ombasering."
 
-#: branch.c:106
+#: branch.c:105
 #, c-format
 msgid "Branch '%s' set up to track remote ref '%s'."
 msgstr "Grenen \"%s\" ställdes in att spåra fjärreferensen \"%s\"."
 
-#: branch.c:110
+#: branch.c:109
 #, c-format
 msgid "Branch '%s' set up to track local ref '%s' by rebasing."
 msgstr ""
 "Grenen \"%s\" ställdes in att spåra den lokala referensen \"%s\" genom "
 "ombasering."
 
-#: branch.c:111
+#: branch.c:110
 #, c-format
 msgid "Branch '%s' set up to track local ref '%s'."
 msgstr "Grenen \"%s\" ställdes in att spåra den lokala referensen \"%s\"."
 
-#: branch.c:120
+#: branch.c:119
 msgid "Unable to write upstream branch configuration"
 msgstr "Kan inte skriva inställningar för uppströmsgren"
 
-#: branch.c:157
+#: branch.c:156
 #, c-format
 msgid "Not tracking: ambiguous information for ref %s"
 msgstr "Spårar inte: tvetydig information för referensen %s"
 
-#: branch.c:190
+#: branch.c:189
 #, c-format
 msgid "'%s' is not a valid branch name."
 msgstr "\"%s\" är inte ett giltigt grennamn."
 
-#: branch.c:209
+#: branch.c:208
 #, c-format
 msgid "A branch named '%s' already exists."
-msgstr "Det finns redan en gren som heter ”%s”."
+msgstr "Det finns redan en gren som heter \"%s\"."
 
-#: branch.c:214
+#: branch.c:213
 msgid "Cannot force update the current branch."
 msgstr "Kan inte tvinga uppdatering av aktuell gren."
 
-#: branch.c:234
+#: branch.c:233
 #, c-format
 msgid "Cannot setup tracking information; starting point '%s' is not a branch."
 msgstr "Kan inte ställa in spårning; startpunkten \"%s\" är inte en gren."
 
-#: branch.c:236
+#: branch.c:235
 #, c-format
 msgid "the requested upstream branch '%s' does not exist"
 msgstr "den efterfrågade uppströmsgrenen \"%s\" finns inte"
 
-#: branch.c:238
+#: branch.c:237
 msgid ""
 "\n"
 "If you are planning on basing your work on an upstream\n"
@@ -1157,87 +1672,96 @@ msgstr "Objektnamnet är tvetydigt: \"%s
 #: branch.c:306
 #, c-format
 msgid "Not a valid branch point: '%s'."
-msgstr "Avgreningspunkten är inte giltig: ”%s”."
+msgstr "Avgreningspunkten är inte giltig: \"%s\"."
 
-#: branch.c:360
+#: branch.c:364
 #, c-format
 msgid "'%s' is already checked out at '%s'"
 msgstr "\"%s\" är redan utcheckad på \"%s\""
 
-#: branch.c:383
+#: branch.c:387
 #, c-format
 msgid "HEAD of working tree %s is not updated"
 msgstr "HEAD i arbetskatalogen %s har inte uppdaterats"
 
-#: bundle.c:34
+#: bundle.c:36
 #, c-format
 msgid "'%s' does not look like a v2 bundle file"
 msgstr "'%s' ser inte ut som en v2-bundle-fil"
 
-#: bundle.c:62
+#: bundle.c:64
 #, c-format
 msgid "unrecognized header: %s%s (%d)"
 msgstr "okänt huvud: %s%s (%d)"
 
-#: bundle.c:88 sequencer.c:2081 sequencer.c:2558 builtin/commit.c:755
+#: bundle.c:90 rerere.c:480 rerere.c:690 sequencer.c:2344 sequencer.c:3108
+#: builtin/commit.c:811
 #, c-format
 msgid "could not open '%s'"
 msgstr "kunde inte öppna \"%s\""
 
-#: bundle.c:139
+#: bundle.c:143
 msgid "Repository lacks these prerequisite commits:"
 msgstr "Arkivet saknar dessa nödvändiga incheckningar:"
 
-#: bundle.c:190
+#: bundle.c:146
+msgid "need a repository to verify a bundle"
+msgstr "behöver ett arkiv för att verifiera ett paket (bundle)."
+
+#: bundle.c:197
 #, c-format
 msgid "The bundle contains this ref:"
 msgid_plural "The bundle contains these %d refs:"
 msgstr[0] "Paketet (bundlen) innehåller denna referens:"
 msgstr[1] "Paketet (bundlen) innehåller dessa %d referenser:"
 
-#: bundle.c:197
+#: bundle.c:204
 msgid "The bundle records a complete history."
 msgstr "Paketet (bundlen) beskriver en komplett historik."
 
-#: bundle.c:199
+#: bundle.c:206
 #, c-format
 msgid "The bundle requires this ref:"
 msgid_plural "The bundle requires these %d refs:"
 msgstr[0] "Paketet (bundlen) kräver denna referens:"
 msgstr[1] "Paketet (bundlen) kräver dessa %d referenser:"
 
-#: bundle.c:258
+#: bundle.c:273
+msgid "unable to dup bundle descriptor"
+msgstr "kan inte duplicera pakethandtag"
+
+#: bundle.c:280
 msgid "Could not spawn pack-objects"
 msgstr "Kunde inte starta pack-objects"
 
-#: bundle.c:269
+#: bundle.c:291
 msgid "pack-objects died"
 msgstr "pack-objects misslyckades"
 
-#: bundle.c:311
+#: bundle.c:333
 msgid "rev-list died"
 msgstr "rev-list dog"
 
-#: bundle.c:360
+#: bundle.c:382
 #, c-format
 msgid "ref '%s' is excluded by the rev-list options"
 msgstr "referensen \"%s\" exkluderas av argumenten till rev-list"
 
-#: bundle.c:450 builtin/log.c:183 builtin/log.c:1607 builtin/shortlog.c:303
+#: bundle.c:461 builtin/log.c:203 builtin/log.c:1814 builtin/shortlog.c:306
 #, c-format
 msgid "unrecognized argument: %s"
 msgstr "okänt argument: %s"
 
-#: bundle.c:458
+#: bundle.c:469
 msgid "Refusing to create empty bundle."
 msgstr "Vägrar skapa ett tomt paket (bundle)."
 
-#: bundle.c:470
+#: bundle.c:479
 #, c-format
 msgid "cannot create '%s'"
 msgstr "kan inte skapa \"%s\""
 
-#: bundle.c:498
+#: bundle.c:504
 msgid "index-pack died"
 msgstr "index-pack dog"
 
@@ -1246,19 +1770,18 @@ msgstr "index-pack dog"
 msgid "invalid color value: %.*s"
 msgstr "felaktigt färgvärde: %.*s"
 
-#: commit.c:43 sequencer.c:2364 builtin/am.c:421 builtin/am.c:465
-#: builtin/am.c:1436 builtin/am.c:2072 builtin/replace.c:376
-#: builtin/replace.c:448
+#: commit.c:51 sequencer.c:2811 builtin/am.c:354 builtin/am.c:398
+#: builtin/am.c:1366 builtin/am.c:2009 builtin/replace.c:456
 #, c-format
 msgid "could not parse %s"
 msgstr "kunde inte tolka %s"
 
-#: commit.c:45
+#: commit.c:53
 #, c-format
 msgid "%s %s is not a commit!"
 msgstr "%s %s är inte en incheckning!"
 
-#: commit.c:182
+#: commit.c:193
 msgid ""
 "Support for <GIT_DIR>/info/grafts is deprecated\n"
 "and will be removed in a future Git version.\n"
@@ -1278,7 +1801,29 @@ msgstr ""
 "Slå av detta meddelande genom att skriva\n"
 "\"git config advice.graftFileDeprecated false\""
 
-#: commit.c:1537
+#: commit.c:1152
+#, c-format
+msgid "Commit %s has an untrusted GPG signature, allegedly by %s."
+msgstr ""
+"Incheckningen %s har en obetrodd GPG-signatur som påstås vara gjord av %s."
+
+#: commit.c:1155
+#, c-format
+msgid "Commit %s has a bad GPG signature allegedly by %s."
+msgstr ""
+"Incheckningen %s har en felaktig GPG-signatur som påstås vara gjord av %s."
+
+#: commit.c:1158
+#, c-format
+msgid "Commit %s does not have a GPG signature."
+msgstr "Incheckning %s har inte någon GPG-signatur."
+
+#: commit.c:1161
+#, c-format
+msgid "Commit %s has a good GPG signature by %s\n"
+msgstr "Incheckningen %s har en korrekt GPG-signatur av %s\n"
+
+#: commit.c:1415
 msgid ""
 "Warning: commit message did not conform to UTF-8.\n"
 "You may want to amend it after fixing the message, or set the config\n"
@@ -1288,190 +1833,585 @@ msgstr ""
 "Uppdatera det efter att ha rättat meddelandet, eller ändra variabeln\n"
 "i18n.commitencoding till den teckenkodning som används i ditt projekt.\n"
 
-#: commit-graph.c:669
+#: commit-graph.c:130
+msgid "commit-graph file is too small"
+msgstr "incheckningsgraffilen %s är för liten"
+
+#: commit-graph.c:195
+#, c-format
+msgid "commit-graph signature %X does not match signature %X"
+msgstr "incheckningsgrafens signatur %X stämmer inte med signaturen %X"
+
+#: commit-graph.c:202
+#, c-format
+msgid "commit-graph version %X does not match version %X"
+msgstr "incheckningsgrafens version %X stämmer inte med versionen %X"
+
+#: commit-graph.c:209
+#, c-format
+msgid "commit-graph hash version %X does not match version %X"
+msgstr "incheckningsgrafens hashversion %X stämmer inte med versionen %X"
+
+#: commit-graph.c:232
+msgid "commit-graph chunk lookup table entry missing; file may be incomplete"
+msgstr ""
+"incheckningsgrafen saknar post i styckeuppslagningstabell; filen kan vara "
+"ofullständig"
+
+#: commit-graph.c:243
+#, c-format
+msgid "commit-graph improper chunk offset %08x%08x"
+msgstr "felaktigt offset för stycke %08x%08x i incheckningsgraffilen"
+
+#: commit-graph.c:286
+#, c-format
+msgid "commit-graph chunk id %08x appears multiple times"
+msgstr "incheckningsgrafens stycke-id %08x förekommer flera gånger"
+
+#: commit-graph.c:350
+msgid "commit-graph has no base graphs chunk"
+msgstr "incheckningsgrafen har inga bas-graf-stycken"
+
+#: commit-graph.c:360
+msgid "commit-graph chain does not match"
+msgstr "incheckningsgrafens kedja stämmer inte"
+
+#: commit-graph.c:407
+#, c-format
+msgid "invalid commit-graph chain: line '%s' not a hash"
+msgstr "ogiltig incheckingsgrafkedja: rad \"%s\" är inte ett hash-värde"
+
+#: commit-graph.c:433
+msgid "unable to find all commit-graph files"
+msgstr "kan inte hitta alla incheckingsgraffiler"
+
+#: commit-graph.c:564 commit-graph.c:624
+msgid "invalid commit position. commit-graph is likely corrupt"
+msgstr "ogiltig incheckningsposition. incheckningsgrafen är troligtvis trasig"
+
+#: commit-graph.c:585
+#, c-format
+msgid "could not find commit %s"
+msgstr "kunde inte hitta incheckningen %s"
+
+#: commit-graph.c:858 builtin/am.c:1287
+#, c-format
+msgid "unable to parse commit %s"
+msgstr "kunde inte tolka incheckningen %s"
+
+#: commit-graph.c:1017 builtin/pack-objects.c:2641
+#, c-format
+msgid "unable to get type of object %s"
+msgstr "kunde inte hämta typ för objektet %s"
+
+#: commit-graph.c:1049
+msgid "Loading known commits in commit graph"
+msgstr "Läser in kända incheckningar i incheckningsgraf"
+
+#: commit-graph.c:1066
+msgid "Expanding reachable commits in commit graph"
+msgstr "Expanderar nåbara incheckningar i incheckningsgraf"
+
+#: commit-graph.c:1085
+msgid "Clearing commit marks in commit graph"
+msgstr "Rensar incheckningsmärken i incheckningsgraf"
+
+#: commit-graph.c:1104
+msgid "Computing commit graph generation numbers"
+msgstr "Beräknar generationsvärden för incheckningsgraf"
+
+#: commit-graph.c:1179
+#, c-format
+msgid "Finding commits for commit graph in %d pack"
+msgid_plural "Finding commits for commit graph in %d packs"
+msgstr[0] "Söker incheckningar för incheckingsgraf i %d paket"
+msgstr[1] "Söker incheckningar för incheckingsgraf i %d paket"
+
+#: commit-graph.c:1192
+#, c-format
+msgid "error adding pack %s"
+msgstr "fel vid tillägg av paketet %s"
+
+#: commit-graph.c:1196
+#, c-format
+msgid "error opening index for %s"
+msgstr "fel vid öppning av indexet för %s"
+
+#: commit-graph.c:1220
+#, c-format
+msgid "Finding commits for commit graph from %d ref"
+msgid_plural "Finding commits for commit graph from %d refs"
+msgstr[0] "Söker incheckningar för incheckingsgraf från %d referens"
+msgstr[1] "Söker incheckningar för incheckingsgraf från %d referenser"
+
+#: commit-graph.c:1240
+#, c-format
+msgid "invalid commit object id: %s"
+msgstr "ogiltigt inchecknings-objekt-id %s"
+
+#: commit-graph.c:1255
+msgid "Finding commits for commit graph among packed objects"
+msgstr "Söker incheckningar för incheckingsgraf i packade objekt"
+
+#: commit-graph.c:1270
+msgid "Counting distinct commits in commit graph"
+msgstr "Räknar olika incheckningar i incheckningsgraf"
+
+#: commit-graph.c:1300
+msgid "Finding extra edges in commit graph"
+msgstr "Söker ytterligare kanter i incheckingsgraf"
+
+#: commit-graph.c:1346
+msgid "failed to write correct number of base graph ids"
+msgstr "kunde inte skriva korrekt antal bas-graf-id:n"
+
+#: commit-graph.c:1379 midx.c:814
+#, c-format
+msgid "unable to create leading directories of %s"
+msgstr "kunde inte skapa inledande kataloger för %s"
+
+#: commit-graph.c:1391 builtin/index-pack.c:306 builtin/repack.c:248
+#, c-format
+msgid "unable to create '%s'"
+msgstr "kunde inte skapa \"%s\""
+
+#: commit-graph.c:1451
+#, c-format
+msgid "Writing out commit graph in %d pass"
+msgid_plural "Writing out commit graph in %d passes"
+msgstr[0] "Skriver ut incheckningsgraf i %d pass"
+msgstr[1] "Skriver ut incheckningsgraf i %d pass"
+
+#: commit-graph.c:1492
+msgid "unable to open commit-graph chain file"
+msgstr "Kunde inte öppna incheckningsgrafkedjefilen"
+
+#: commit-graph.c:1504
+msgid "failed to rename base commit-graph file"
+msgstr "kunde inte byta namn på bas-incheckingsgraffilen"
+
+#: commit-graph.c:1524
+msgid "failed to rename temporary commit-graph file"
+msgstr "kunde inte byta namn på temporär incheckningsgraffil"
+
+#: commit-graph.c:1635
+msgid "Scanning merged commits"
+msgstr "Söker sammanslagna incheckningar"
+
+#: commit-graph.c:1646
+#, c-format
+msgid "unexpected duplicate commit id %s"
+msgstr "oväntat duplicerat inchecknings-id %s"
+
+#: commit-graph.c:1670
+msgid "Merging commit-graph"
+msgstr "Slår ihop incheckningsgraf"
+
+#: commit-graph.c:1860
 #, c-format
 msgid "the commit graph format cannot write %d commits"
 msgstr "formatet på incheckningsgrafen kan inte visa %d incheckningar"
 
-#: commit-graph.c:696
+#: commit-graph.c:1871
 msgid "too many commits to write graph"
 msgstr "för många incheckningar för att skriva graf"
 
-#: commit-graph.c:707 builtin/init-db.c:516 builtin/init-db.c:521
+#: commit-graph.c:1961
+msgid "the commit-graph file has incorrect checksum and is likely corrupt"
+msgstr ""
+"filen med incheckningsgraf har felaktig checksumma och är troligtvis trasig"
+
+#: commit-graph.c:1971
 #, c-format
-msgid "cannot mkdir %s"
-msgstr "kan inte skapa katalogen (mkdir) %s"
+msgid "commit-graph has incorrect OID order: %s then %s"
+msgstr "incheckningsgrafen har felaktig OID-ordning: %s så %s"
+
+#: commit-graph.c:1981 commit-graph.c:1996
+#, c-format
+msgid "commit-graph has incorrect fanout value: fanout[%d] = %u != %u"
+msgstr ""
+"incheckningsgrafen har felaktig utbredningsvärde: fanout[%d] = %u != %u"
+
+#: commit-graph.c:1988
+#, c-format
+msgid "failed to parse commit %s from commit-graph"
+msgstr "kunde inte tolka incheckning %s från incheckningsgraf"
+
+#: commit-graph.c:2006
+msgid "Verifying commits in commit graph"
+msgstr "Bekräftar incheckningar i incheckningsgrafen"
+
+#: commit-graph.c:2020
+#, c-format
+msgid "failed to parse commit %s from object database for commit-graph"
+msgstr ""
+"misslyckades tolka incheckning %s från objektdatabasen för incheckningsgraf"
+
+#: commit-graph.c:2027
+#, c-format
+msgid "root tree OID for commit %s in commit-graph is %s != %s"
+msgstr "rot-trädets OID för incheckningen %s i incheckningsgrafen är %s != %s"
+
+#: commit-graph.c:2037
+#, c-format
+msgid "commit-graph parent list for commit %s is too long"
+msgstr "incheckningsgrafens föräldralista för incheckningen %s är för lång"
+
+#: commit-graph.c:2046
+#, c-format
+msgid "commit-graph parent for %s is %s != %s"
+msgstr "incheckningsgrafens förälder för %s är %s != %s"
+
+#: commit-graph.c:2059
+#, c-format
+msgid "commit-graph parent list for commit %s terminates early"
+msgstr ""
+"incheckningsgrafens föräldralista för incheckningen %s avslutas för tidigt"
+
+#: commit-graph.c:2064
+#, c-format
+msgid ""
+"commit-graph has generation number zero for commit %s, but non-zero elsewhere"
+msgstr ""
+"incheckningsgrafen har generationsnummer noll för incheckningen %s, men icke-"
+"noll på annan plats"
+
+#: commit-graph.c:2068
+#, c-format
+msgid ""
+"commit-graph has non-zero generation number for commit %s, but zero elsewhere"
+msgstr ""
+"incheckningsgrafen har generationsnummer skilt från noll för incheckningen "
+"%s, men noll på annan plats"
+
+#: commit-graph.c:2083
+#, c-format
+msgid "commit-graph generation for commit %s is %u != %u"
+msgstr "incheckningsgrafens generation för incheckningen %s är %u != %u"
 
-#: compat/obstack.c:405 compat/obstack.c:407
+#: commit-graph.c:2089
+#, c-format
+msgid "commit date for commit %s in commit-graph is %<PRIuMAX> != %<PRIuMAX>"
+msgstr ""
+"incheckningsdatumet för incheckningen %s i incheckningsgrafen är %<PRIuMAX> !"
+"= %<PRIuMAX>"
+
+#: compat/obstack.c:406 compat/obstack.c:408
 msgid "memory exhausted"
 msgstr "minnet slut"
 
-#: config.c:187
+#: config.c:124
+#, c-format
+msgid ""
+"exceeded maximum include depth (%d) while including\n"
+"\t%s\n"
+"from\n"
+"\t%s\n"
+"This might be due to circular includes."
+msgstr ""
+"överskred maximalt inkluderingsdjup (%d) när\n"
+"\t%s\n"
+"inkluderades från\n"
+"\t%s\n"
+"Det kan bero på cirkulära inkluderingar."
+
+#: config.c:140
+#, c-format
+msgid "could not expand include path '%s'"
+msgstr "kunde inte expandera inkluderingssökväg \"%s\""
+
+#: config.c:151
+msgid "relative config includes must come from files"
+msgstr "relativa konfigureringsinkluderingar måste komma från filer"
+
+#: config.c:197
 msgid "relative config include conditionals must come from files"
 msgstr "relativa konfigureringsinkluderingsvillkor måste komma från filer"
 
-#: config.c:788
+#: config.c:376
+#, c-format
+msgid "key does not contain a section: %s"
+msgstr "nyckeln innehåller inte ett stycke: %s"
+
+#: config.c:382
+#, c-format
+msgid "key does not contain variable name: %s"
+msgstr "nyckeln innehåller inte variabelnamn: %s"
+
+#: config.c:406 sequencer.c:2530
+#, c-format
+msgid "invalid key: %s"
+msgstr "felaktig nyckel: %s"
+
+#: config.c:412
+#, c-format
+msgid "invalid key (newline): %s"
+msgstr "ogiltig nyckel (nyradstecken): %s"
+
+#: config.c:448 config.c:460
+#, c-format
+msgid "bogus config parameter: %s"
+msgstr "falsk konfigureringsparameter: %s"
+
+#: config.c:495
+#, c-format
+msgid "bogus format in %s"
+msgstr "felaktigt format i %s"
+
+#: config.c:821
 #, c-format
 msgid "bad config line %d in blob %s"
 msgstr "felaktig konfigurationsfil rad %d i blob:en %s"
 
-#: config.c:792
+#: config.c:825
 #, c-format
 msgid "bad config line %d in file %s"
 msgstr "felaktig konfigurationsfil rad %d i filen %s"
 
-#: config.c:796
+#: config.c:829
 #, c-format
 msgid "bad config line %d in standard input"
 msgstr "felaktig konfigurationsfil rad %d i standard in"
 
-#: config.c:800
+#: config.c:833
 #, c-format
 msgid "bad config line %d in submodule-blob %s"
 msgstr "felaktig konfigurationsfil rad %d i undermoduls-blob:en %s"
 
-#: config.c:804
+#: config.c:837
 #, c-format
 msgid "bad config line %d in command line %s"
 msgstr "felaktig konfigurationsfil rad %d i kommandoraden %s"
 
-#: config.c:808
+#: config.c:841
 #, c-format
 msgid "bad config line %d in %s"
 msgstr "felaktig konfigurationsfil rad %d i %s"
 
-#: config.c:936
+#: config.c:978
 msgid "out of range"
 msgstr "utanför intervallet"
 
-#: config.c:936
+#: config.c:978
 msgid "invalid unit"
 msgstr "ogiltig enhet"
 
-#: config.c:942
+#: config.c:979
 #, c-format
 msgid "bad numeric config value '%s' for '%s': %s"
 msgstr "felaktigt numeriskt konfigurationsvärde \"%s\" för \"%s\": %s"
 
-#: config.c:947
+#: config.c:998
 #, c-format
 msgid "bad numeric config value '%s' for '%s' in blob %s: %s"
 msgstr ""
 "felaktigt numeriskt konfigurationsvärde \"%s\" för \"%s\" i blob:en %s: %s"
 
-#: config.c:950
+#: config.c:1001
 #, c-format
 msgid "bad numeric config value '%s' for '%s' in file %s: %s"
 msgstr ""
 "felaktigt numeriskt konfigurationsvärde \"%s\" för \"%s\" i filen %s: %s"
 
-#: config.c:953
+#: config.c:1004
 #, c-format
 msgid "bad numeric config value '%s' for '%s' in standard input: %s"
 msgstr ""
 "felaktigt numeriskt konfigurationsvärde \"%s\" för \"%s\" i standard in: %s"
 
-#: config.c:956
+#: config.c:1007
 #, c-format
 msgid "bad numeric config value '%s' for '%s' in submodule-blob %s: %s"
 msgstr ""
 "felaktigt numeriskt konfigurationsvärde \"%s\" för \"%s\" i undermodul-blob:"
 "en %s: %s"
 
-#: config.c:959
+#: config.c:1010
 #, c-format
 msgid "bad numeric config value '%s' for '%s' in command line %s: %s"
 msgstr ""
 "felaktigt numeriskt konfigurationsvärde \"%s\" för \"%s\" i kommandoraden "
 "%s: %s"
 
-#: config.c:962
+#: config.c:1013
 #, c-format
 msgid "bad numeric config value '%s' for '%s' in %s: %s"
 msgstr "felaktigt numeriskt konfigurationsvärde \"%s\" för \"%s\" i %s: %s"
 
-#: config.c:1057
+#: config.c:1108
 #, c-format
 msgid "failed to expand user dir in: '%s'"
 msgstr "misslyckades expandera användarkatalog i: \"%s\""
 
-#: config.c:1066
+#: config.c:1117
 #, c-format
 msgid "'%s' for '%s' is not a valid timestamp"
 msgstr "\"%s\" för \"%s\" är inte en giltig tidsstämpel"
 
-#: config.c:1171 config.c:1182
+#: config.c:1208
+#, c-format
+msgid "abbrev length out of range: %d"
+msgstr "förkortningslängd utanför intervallet: %d"
+
+#: config.c:1222 config.c:1233
 #, c-format
 msgid "bad zlib compression level %d"
 msgstr "felaktigt zlib-komprimeringsgrad %d"
 
-#: config.c:1307
+#: config.c:1325
+msgid "core.commentChar should only be one character"
+msgstr "core.commentChar kan bara vara ett tecken"
+
+#: config.c:1358
 #, c-format
 msgid "invalid mode for object creation: %s"
 msgstr "felaktigt läge för skapande av objekt: %s"
 
-#: config.c:1473
+#: config.c:1430
+#, c-format
+msgid "malformed value for %s"
+msgstr "felformat värde för %s"
+
+#: config.c:1456
+#, c-format
+msgid "malformed value for %s: %s"
+msgstr "felformat värde för %s: %s"
+
+#: config.c:1457
+msgid "must be one of nothing, matching, simple, upstream or current"
+msgstr "måste vara en av nothing, matching, simple, upstream eller current"
+
+#: config.c:1518 builtin/pack-objects.c:3394
 #, c-format
 msgid "bad pack compression level %d"
 msgstr "felaktig paketkomprimeringsgrad %d"
 
-#: config.c:1681
+#: config.c:1639
+#, c-format
+msgid "unable to load config blob object '%s'"
+msgstr "kunde inte läsa konfigurerings-blobobjektet \"%s\""
+
+#: config.c:1642
+#, c-format
+msgid "reference '%s' does not point to a blob"
+msgstr "referensen \"%s\" pekar inte på en blob"
+
+#: config.c:1659
+#, c-format
+msgid "unable to resolve config blob '%s'"
+msgstr "kan inte slå upp konfigurerings-bloben \"%s\""
+
+#: config.c:1689
+#, c-format
+msgid "failed to parse %s"
+msgstr "kunde inte tolka %s"
+
+#: config.c:1745
 msgid "unable to parse command-line config"
 msgstr "kan inte tolka kommandoradskonfiguration"
 
-#: config.c:2013
+#: config.c:2096
 msgid "unknown error occurred while reading the configuration files"
 msgstr "okänt fel uppstod vid läsning av konfigurationsfilerna"
 
-#: config.c:2200
+#: config.c:2266
 #, c-format
 msgid "Invalid %s: '%s'"
 msgstr "Felaktigt %s: \"%s\""
 
-#: config.c:2243
-#, c-format
-msgid "unknown core.untrackedCache value '%s'; using 'keep' default value"
-msgstr ""
-"okänt värde \"%s\" för core.untrackedCache; använder standardvärdet \"keep\""
-
-#: config.c:2269
+#: config.c:2311
 #, c-format
 msgid "splitIndex.maxPercentChange value '%d' should be between 0 and 100"
 msgstr "värdet \"%d\" för splitIndex.maxPercentage borde vara mellan 0 och 100"
 
-#: config.c:2294
+#: config.c:2357
 #, c-format
 msgid "unable to parse '%s' from command-line config"
 msgstr "kunde inte tolka värdet \"%s\" från kommandoradskonfiguration"
 
-#: config.c:2296
+#: config.c:2359
 #, c-format
 msgid "bad config variable '%s' in file '%s' at line %d"
 msgstr "felaktig konfigurationsvariabel \"%s\" i filen \"%s\" på rad %d"
 
-#: config.c:2402
+#: config.c:2440
+#, c-format
+msgid "invalid section name '%s'"
+msgstr "felaktigt sektionsnamn \"%s\""
+
+#: config.c:2472
 #, c-format
 msgid "%s has multiple values"
 msgstr "%s har flera värden"
 
-#: config.c:2766 config.c:3019
+#: config.c:2501
+#, c-format
+msgid "failed to write new configuration file %s"
+msgstr "kan inte skriva nya konfigurationsfilen \"%s\""
+
+#: config.c:2753 config.c:3077
+#, c-format
+msgid "could not lock config file %s"
+msgstr "kunde inte låsa konfigurationsfilen %s"
+
+#: config.c:2764
+#, c-format
+msgid "opening %s"
+msgstr "öppnar %s"
+
+#: config.c:2799 builtin/config.c:328
+#, c-format
+msgid "invalid pattern: %s"
+msgstr "ogiltigt mönster: %s"
+
+#: config.c:2824
+#, c-format
+msgid "invalid config file %s"
+msgstr "ogiltig konfigurationsfil: \"%s\""
+
+#: config.c:2837 config.c:3090
 #, c-format
 msgid "fstat on %s failed"
 msgstr "fstat misslyckades på %s"
 
-#: config.c:2905
+#: config.c:2848
+#, c-format
+msgid "unable to mmap '%s'"
+msgstr "kunde inte utföra mmap på \"%s\""
+
+#: config.c:2857 config.c:3095
+#, c-format
+msgid "chmod on %s failed"
+msgstr "chmod misslyckades på %s"
+
+#: config.c:2942 config.c:3192
+#, c-format
+msgid "could not write config file %s"
+msgstr "kunde inte skriva konfigurationsfilen %s"
+
+#: config.c:2976
 #, c-format
 msgid "could not set '%s' to '%s'"
 msgstr "kunde inte ställa in \"%s\" till \"%s\""
 
-#: config.c:2907 builtin/remote.c:779
+#: config.c:2978 builtin/remote.c:781
 #, c-format
 msgid "could not unset '%s'"
 msgstr "kunde inte ta bort inställning för \"%s\""
 
+#: config.c:3068
+#, c-format
+msgid "invalid section name: %s"
+msgstr "felaktigt namn på stycke: %s"
+
+#: config.c:3235
+#, c-format
+msgid "missing value for '%s'"
+msgstr "värde saknas för \"%s\""
+
 #: connect.c:61
-msgid "The remote end hung up upon initial contact"
-msgstr "Fjärren lade på vid inledande kontakt"
+msgid "the remote end hung up upon initial contact"
+msgstr "fjärren lade på vid inledande kontakt"
 
 #: connect.c:63
 msgid ""
@@ -1485,64 +2425,212 @@ msgstr ""
 "Se till att du har korrekt åtkomstbehörighet\n"
 "och att arkivet existerar."
 
-# Vague original, not networking-related, but rather related to the actual
-# objects in the database.
-#: connected.c:66 builtin/fsck.c:201 builtin/prune.c:145
-msgid "Checking connectivity"
-msgstr "Kontrollerar konnektivitet"
-
-#: connected.c:78
-msgid "Could not run 'git rev-list'"
-msgstr "Kunde inte köra \"git rev-list\""
+#: connect.c:81
+#, c-format
+msgid "server doesn't support '%s'"
+msgstr "Servern stöder inte \"%s\""
 
-#: connected.c:98
-msgid "failed write to rev-list"
-msgstr "kunde inte skriva till rev-list"
+#: connect.c:103
+#, c-format
+msgid "server doesn't support feature '%s'"
+msgstr "servern stöder inte funktionen \"%s\""
 
-#: connected.c:105
-msgid "failed to close rev-list's stdin"
-msgstr "kunde inte stänga rev-list:s standard in"
+#: connect.c:114
+msgid "expected flush after capabilities"
+msgstr "förväntade \"flush\" efter förmågor"
 
-#: convert.c:206
+#: connect.c:233
 #, c-format
-msgid "CRLF would be replaced by LF in %s."
-msgstr "CRLF skulle ersättas av LF i %s."
+msgid "ignoring capabilities after first line '%s'"
+msgstr "ignorerar förmågor efter första raden \"%s\""
 
-#: convert.c:208
-#, c-format
-msgid ""
-"CRLF will be replaced by LF in %s.\n"
-"The file will have its original line endings in your working directory."
-msgstr ""
-"CRLF kommer att ersättas av LF i %s.\n"
-"Filen kommer att ha sina ursprungliga radbrytningar i din arbetskatalog."
+#: connect.c:252
+msgid "protocol error: unexpected capabilities^{}"
+msgstr "protokollfel: förväntade inte capabilities^{}"
 
-#: convert.c:216
+#: connect.c:273
 #, c-format
-msgid "LF would be replaced by CRLF in %s"
-msgstr "LF skulle ersättas av CRLF i %s"
+msgid "protocol error: expected shallow sha-1, got '%s'"
+msgstr "protokollfel: förväntade \"shallow sha-1\" fick \"%s\""
+
+#: connect.c:275
+msgid "repository on the other end cannot be shallow"
+msgstr "arkivet på andra sidan kan inte vara grunt"
+
+#: connect.c:313
+msgid "invalid packet"
+msgstr "ogiltigt paket"
 
-#: convert.c:218
+#: connect.c:333
 #, c-format
-msgid ""
-"LF will be replaced by CRLF in %s.\n"
-"The file will have its original line endings in your working directory."
-msgstr ""
-"LF kommer att ersättas av CRLF i %s.\n"
-"Filen kommer att ha sina ursprungliga radbrytningar i din arbetskatalog."
+msgid "protocol error: unexpected '%s'"
+msgstr "protokollfel: förväntade inte \"%s\""
 
-#: convert.c:279
+#: connect.c:441
+#, c-format
+msgid "invalid ls-refs response: %s"
+msgstr "ogiltigt svar på ls-refs: %s"
+
+#: connect.c:445
+msgid "expected flush after ref listing"
+msgstr "oväntad \"flush\" efter ref-listan"
+
+#: connect.c:544
+#, c-format
+msgid "protocol '%s' is not supported"
+msgstr "protokollet \"%s\" stöds inte"
+
+#: connect.c:595
+msgid "unable to set SO_KEEPALIVE on socket"
+msgstr "kunde inte sätta SO_KEEPALIVE på uttaget"
+
+#: connect.c:635 connect.c:698
+#, c-format
+msgid "Looking up %s ... "
+msgstr "Slår upp %s..."
+
+#: connect.c:639
+#, c-format
+msgid "unable to look up %s (port %s) (%s)"
+msgstr "kan inte slå upp %s (port %s) (%s)"
+
+#. TRANSLATORS: this is the end of "Looking up %s ... "
+#: connect.c:643 connect.c:714
+#, c-format
+msgid ""
+"done.\n"
+"Connecting to %s (port %s) ... "
+msgstr ""
+"klart.\n"
+"Ansluter till %s (port %s)..."
+
+#: connect.c:665 connect.c:742
+#, c-format
+msgid ""
+"unable to connect to %s:\n"
+"%s"
+msgstr ""
+"kunde inte ansluta till %s:\n"
+"%s"
+
+#. TRANSLATORS: this is the end of "Connecting to %s (port %s) ... "
+#: connect.c:671 connect.c:748
+msgid "done."
+msgstr "klart."
+
+#: connect.c:702
+#, c-format
+msgid "unable to look up %s (%s)"
+msgstr "kunde inte slå upp %s (%s)"
+
+#: connect.c:708
+#, c-format
+msgid "unknown port %s"
+msgstr "okänd port %s"
+
+#: connect.c:845 connect.c:1175
+#, c-format
+msgid "strange hostname '%s' blocked"
+msgstr "konstigt värdnamn \"%s\" blockerat"
+
+#: connect.c:847
+#, c-format
+msgid "strange port '%s' blocked"
+msgstr "konstig port \"%s\" blockerad"
+
+#: connect.c:857
+#, c-format
+msgid "cannot start proxy %s"
+msgstr "kan inte starta mellanserver (proxy) %s"
+
+#: connect.c:928
+msgid "no path specified; see 'git help pull' for valid url syntax"
+msgstr "ingen sökväg angavs; se \"git help pull\" för giltig URL-syntax"
+
+#: connect.c:1123
+msgid "ssh variant 'simple' does not support -4"
+msgstr "ssh-varianten \"simple\" stöder inte -4"
+
+#: connect.c:1135
+msgid "ssh variant 'simple' does not support -6"
+msgstr "ssh-varianten \"simple\" stöder inte -6"
+
+#: connect.c:1152
+msgid "ssh variant 'simple' does not support setting port"
+msgstr "ssh-varianten \"simple\" stöder inte val av port"
+
+#: connect.c:1264
+#, c-format
+msgid "strange pathname '%s' blocked"
+msgstr "konstigt sökvägsnamn \"%s\" blockerat"
+
+#: connect.c:1311
+msgid "unable to fork"
+msgstr "kunde inte grena (fork)"
+
+# Vague original, not networking-related, but rather related to the actual
+# objects in the database.
+#: connected.c:89 builtin/fsck.c:208 builtin/prune.c:43
+msgid "Checking connectivity"
+msgstr "Kontrollerar konnektivitet"
+
+#: connected.c:101
+msgid "Could not run 'git rev-list'"
+msgstr "Kunde inte köra \"git rev-list\""
+
+#: connected.c:121
+msgid "failed write to rev-list"
+msgstr "kunde inte skriva till rev-list"
+
+#: connected.c:128
+msgid "failed to close rev-list's stdin"
+msgstr "kunde inte stänga rev-list:s standard in"
+
+#: convert.c:194
+#, c-format
+msgid "illegal crlf_action %d"
+msgstr "felaktig crlf_action %d"
+
+#: convert.c:207
+#, c-format
+msgid "CRLF would be replaced by LF in %s"
+msgstr "CRLF skulle ersättas av LF i %s"
+
+#: convert.c:209
+#, c-format
+msgid ""
+"CRLF will be replaced by LF in %s.\n"
+"The file will have its original line endings in your working directory"
+msgstr ""
+"CRLF kommer att ersättas av LF i %s.\n"
+"Filen kommer att ha sina ursprungliga radbrytningar i din arbetskatalog"
+
+#: convert.c:217
+#, c-format
+msgid "LF would be replaced by CRLF in %s"
+msgstr "LF skulle ersättas av CRLF i %s"
+
+#: convert.c:219
+#, c-format
+msgid ""
+"LF will be replaced by CRLF in %s.\n"
+"The file will have its original line endings in your working directory"
+msgstr ""
+"LF kommer att ersättas av CRLF i %s.\n"
+"Filen kommer att ha sina ursprungliga radbrytningar i din arbetskatalog"
+
+#: convert.c:284
 #, c-format
 msgid "BOM is prohibited in '%s' if encoded as %s"
 msgstr "BOM är förbjudet i \"%s\" om kodat som %s"
 
-#: convert.c:286
+#: convert.c:291
 #, c-format
 msgid ""
-"The file '%s' contains a byte order mark (BOM). Please use UTF-%s as working-"
-"tree-encoding."
+"The file '%s' contains a byte order mark (BOM). Please use UTF-%.*s as "
+"working-tree-encoding."
 msgstr ""
-"Filen \"%s\" innehåller byte order mark (BOM). Använd UTF-%s som "
+"Filen \"%s\" innehåller byte order mark (BOM). Använd UTF-%.*s som "
 "teckenkodning i arbetskatalogen."
 
 #: convert.c:304
@@ -1559,68 +2647,120 @@ msgstr ""
 "Filen \"%s\" saknar byte order mark (BOM). Använd UTF-%sBE eller UTF-%sLE "
 "(beroende på byteordning) som teckenkodning i arbetskatalogen."
 
-#: convert.c:424
+#: convert.c:419 convert.c:490
 #, c-format
 msgid "failed to encode '%s' from %s to %s"
 msgstr "misslyckades omkoda \"%s\" från %s till %s"
 
-#: convert.c:467
+#: convert.c:462
 #, c-format
 msgid "encoding '%s' from %s to %s and back is not the same"
 msgstr ""
 "omkodning av \"%s\" från %s till %s och tillbaka ger inte samma resultat"
 
-#: convert.c:1225
+#: convert.c:668
+#, c-format
+msgid "cannot fork to run external filter '%s'"
+msgstr "kan inte grena (fork) för att köra externt filter \"%s\""
+
+#: convert.c:688
+#, c-format
+msgid "cannot feed the input to external filter '%s'"
+msgstr "kunde inte skicka indata till externt filter \"%s\""
+
+#: convert.c:695
+#, c-format
+msgid "external filter '%s' failed %d"
+msgstr "externt filter \"%s\" misslyckades %d"
+
+#: convert.c:730 convert.c:733
+#, c-format
+msgid "read from external filter '%s' failed"
+msgstr "läsning från externt filter \"%s\" misslyckades"
+
+#: convert.c:736 convert.c:791
+#, c-format
+msgid "external filter '%s' failed"
+msgstr "externt filter \"%s\" misslyckades"
+
+#: convert.c:839
+msgid "unexpected filter type"
+msgstr "oväntad filtertyp"
+
+#: convert.c:850
+msgid "path name too long for external filter"
+msgstr "sökvägen för lång för externt filter"
+
+#: convert.c:924
+#, c-format
+msgid ""
+"external filter '%s' is not available anymore although not all paths have "
+"been filtered"
+msgstr ""
+"externt filter \"%s\" är inte längre tillgängligt trots att alla sökvägar "
+"inte har filtrerats"
+
+#: convert.c:1223
 msgid "true/false are no valid working-tree-encodings"
 msgstr "true/false är inte giltig teckenkodning för arbetskatalogen"
 
-#: date.c:116
+#: convert.c:1411 convert.c:1445
+#, c-format
+msgid "%s: clean filter '%s' failed"
+msgstr "%s: \"clean\"-filtret \"%s\" misslyckades"
+
+#: convert.c:1489
+#, c-format
+msgid "%s: smudge filter %s failed"
+msgstr "%s: \"smudge\"-filtret \"%s\" misslyckades"
+
+#: date.c:138
 msgid "in the future"
 msgstr "i framtiden"
 
-#: date.c:122
+#: date.c:144
 #, c-format
 msgid "%<PRIuMAX> second ago"
 msgid_plural "%<PRIuMAX> seconds ago"
 msgstr[0] "%<PRIuMAX> sekund sedan"
 msgstr[1] "%<PRIuMAX> sekunder sedan"
 
-#: date.c:129
+#: date.c:151
 #, c-format
 msgid "%<PRIuMAX> minute ago"
 msgid_plural "%<PRIuMAX> minutes ago"
 msgstr[0] "%<PRIuMAX> minut sedan"
 msgstr[1] "%<PRIuMAX> minuter sedan"
 
-#: date.c:136
+#: date.c:158
 #, c-format
 msgid "%<PRIuMAX> hour ago"
 msgid_plural "%<PRIuMAX> hours ago"
 msgstr[0] "%<PRIuMAX> timme sedan"
 msgstr[1] "%<PRIuMAX> timmar sedan"
 
-#: date.c:143
+#: date.c:165
 #, c-format
 msgid "%<PRIuMAX> day ago"
 msgid_plural "%<PRIuMAX> days ago"
 msgstr[0] "%<PRIuMAX> dag sedan"
 msgstr[1] "%<PRIuMAX> dagar sedan"
 
-#: date.c:149
+#: date.c:171
 #, c-format
 msgid "%<PRIuMAX> week ago"
 msgid_plural "%<PRIuMAX> weeks ago"
 msgstr[0] "%<PRIuMAX> vecka sedan"
 msgstr[1] "%<PRIuMAX> veckor sedan"
 
-#: date.c:156
+#: date.c:178
 #, c-format
 msgid "%<PRIuMAX> month ago"
 msgid_plural "%<PRIuMAX> months ago"
 msgstr[0] "%<PRIuMAX> månad sedan"
 msgstr[1] "%<PRIuMAX> månader sedan"
 
-#: date.c:167
+#: date.c:189
 #, c-format
 msgid "%<PRIuMAX> year"
 msgid_plural "%<PRIuMAX> years"
@@ -1628,58 +2768,107 @@ msgstr[0] "%<PRIuMAX> år"
 msgstr[1] "%<PRIuMAX> år"
 
 #. TRANSLATORS: "%s" is "<n> years"
-#: date.c:170
+#: date.c:192
 #, c-format
 msgid "%s, %<PRIuMAX> month ago"
 msgid_plural "%s, %<PRIuMAX> months ago"
 msgstr[0] "%s, %<PRIuMAX> månad sedan"
 msgstr[1] "%s, %<PRIuMAX> månader sedan"
 
-#: date.c:175 date.c:180
+#: date.c:197 date.c:202
 #, c-format
 msgid "%<PRIuMAX> year ago"
 msgid_plural "%<PRIuMAX> years ago"
 msgstr[0] "%<PRIuMAX> år sedan"
 msgstr[1] "%<PRIuMAX> år sedan"
 
+#: delta-islands.c:272
+msgid "Propagating island marks"
+msgstr "Sprider ö-markeringar"
+
+#: delta-islands.c:290
+#, c-format
+msgid "bad tree object %s"
+msgstr "felaktigt trädobjektet %s"
+
+#: delta-islands.c:334
+#, c-format
+msgid "failed to load island regex for '%s': %s"
+msgstr "kunde inte hämta ö-regex för \"%s\": %s"
+
+#: delta-islands.c:390
+#, c-format
+msgid "island regex from config has too many capture groups (max=%d)"
+msgstr "ö-regex från konfiguration har för många fångstgrupper (max=%d)"
+
+#: delta-islands.c:467
+#, c-format
+msgid "Marked %d islands, done.\n"
+msgstr "Markerade %d öar, klar.\n"
+
 #: diffcore-order.c:24
 #, c-format
 msgid "failed to read orderfile '%s'"
 msgstr "kunde inte läsa orderfilen \"%s\""
 
-#: diffcore-rename.c:535
+#: diffcore-rename.c:543
 msgid "Performing inexact rename detection"
 msgstr "Utför onöjaktig namnbytesdetektering"
 
-#: diff.c:74
-#, c-format
-msgid "option '%s' requires a value"
-msgstr "flaggan \"%s\" behöver ett värde"
+#: diff-no-index.c:238
+msgid "git diff --no-index [<options>] <path> <path>"
+msgstr "git diff --no-index [<flaggor>] <sökväg> <sökväg>"
+
+#: diff-no-index.c:263
+msgid ""
+"Not a git repository. Use --no-index to compare two paths outside a working "
+"tree"
+msgstr ""
+"Inte ett git-arkiv. Använd --no-index för att jämföra två sökvägar utanför "
+"en arbetskatalog."
 
-#: diff.c:152
+#: diff.c:155
 #, c-format
 msgid "  Failed to parse dirstat cut-off percentage '%s'\n"
 msgstr "  Misslyckades tolka dirstat-avskärningsprocentandel \"%s\"\n"
 
-#: diff.c:157
+#: diff.c:160
 #, c-format
 msgid "  Unknown dirstat parameter '%s'\n"
 msgstr "  Okänd dirstat-parameter \"%s\"\n"
 
-#: diff.c:281
+#: diff.c:296
 msgid ""
-"color moved setting must be one of 'no', 'default', 'zebra', 'dimmed_zebra', "
-"'plain'"
+"color moved setting must be one of 'no', 'default', 'blocks', 'zebra', "
+"'dimmed-zebra', 'plain'"
 msgstr ""
 "färginställningen för flyttade block måste vara en av \"no\", \"default\", "
-"\"zebra\", \"dimmed_zebra\", \"plain\""
+"\"blocks\", \"zebra\", \"dimmed_zebra\", \"plain\""
+
+#: diff.c:324
+#, c-format
+msgid ""
+"unknown color-moved-ws mode '%s', possible values are 'ignore-space-change', "
+"'ignore-space-at-eol', 'ignore-all-space', 'allow-indentation-change'"
+msgstr ""
+"okänt läge \"%s\" för color-moved-ws, möjliga värden är \"ignore-space-change"
+"\", \"ignore-space-at-eol\", \"ignore-all-space\", \"allow-indentation-change"
+"\""
+
+#: diff.c:332
+msgid ""
+"color-moved-ws: allow-indentation-change cannot be combined with other "
+"whitespace modes"
+msgstr ""
+"color-moved-ws: allow-indentation-change kan inte kombineras med andra "
+"blankstegslägen"
 
-#: diff.c:341
+#: diff.c:405
 #, c-format
 msgid "Unknown value for 'diff.submodule' config variable: '%s'"
 msgstr "Okänt värde för konfigurationsvariabeln \"diff.submodule\": \"%s\""
 
-#: diff.c:401
+#: diff.c:465
 #, c-format
 msgid ""
 "Found errors in 'diff.dirstat' config variable:\n"
@@ -1688,24 +2877,35 @@ msgstr ""
 "Hittade fel i konfigurationsvariabeln \"diff.dirstat\":\n"
 "%s"
 
-#: diff.c:3823
+#: diff.c:4202
 #, c-format
 msgid "external diff died, stopping at %s"
 msgstr "extern diff dog, stannar vid %s"
 
-#: diff.c:4153
+#: diff.c:4547
 msgid "--name-only, --name-status, --check and -s are mutually exclusive"
 msgstr "--name-only, --name-status, -check och -s är ömsesidigt uteslutande"
 
-#: diff.c:4156
+#: diff.c:4550
 msgid "-G, -S and --find-object are mutually exclusive"
 msgstr "-G, -S och --find-object är ömsesidigt uteslutande"
 
-#: diff.c:4244
+#: diff.c:4628
 msgid "--follow requires exactly one pathspec"
 msgstr "--follow kräver exakt en sökvägsangivelse"
 
-#: diff.c:4410
+#: diff.c:4676
+#, c-format
+msgid "invalid --stat value: %s"
+msgstr "ogiltigt värde för --stat: %s"
+
+#: diff.c:4681 diff.c:4686 diff.c:4691 diff.c:4696 diff.c:5209
+#: parse-options.c:199 parse-options.c:203
+#, c-format
+msgid "%s expects a numerical value"
+msgstr "%s förväntar ett numeriskt värde"
+
+#: diff.c:4713
 #, c-format
 msgid ""
 "Failed to parse --dirstat/-X option parameter:\n"
@@ -1714,10996 +2914,15338 @@ msgstr ""
 "Misslyckades tolka argument till flaggan --dirstat/-X;\n"
 "%s"
 
-#: diff.c:4424
+#: diff.c:4798
 #, c-format
-msgid "Failed to parse --submodule option parameter: '%s'"
-msgstr "Misslyckades tolka argument till flaggan --submodule: \"%s\""
+msgid "unknown change class '%c' in --diff-filter=%s"
+msgstr "okänd ändringsklass \"%c\" i --diff-filter=%s"
 
-#: diff.c:5500
-msgid "inexact rename detection was skipped due to too many files."
-msgstr ""
-"onöjaktig namnbytesdetektering utfördes inte på grund av för många filer."
+#: diff.c:4822
+#, c-format
+msgid "unknown value after ws-error-highlight=%.*s"
+msgstr "okänt värde efter ws-error-highlight=%.*s"
 
-#: diff.c:5503
-msgid "only found copies from modified paths due to too many files."
-msgstr "hittade bara kopior från ändrade sökvägar på grund av för många filer."
+#: diff.c:4836
+#, c-format
+msgid "unable to resolve '%s'"
+msgstr "kunde inte slå upp \"%s\""
 
-#: diff.c:5506
+#: diff.c:4886 diff.c:4892
 #, c-format
-msgid ""
-"you may want to set your %s variable to at least %d and retry the command."
-msgstr ""
-"du kan sätta variabeln %s till åtminstone %d och försöka kommandot på nytt."
+msgid "%s expects <n>/<m> form"
+msgstr "%s förväntar formen <n>/<m>"
 
-#: dir.c:1867
+#: diff.c:4904
 #, c-format
-msgid "could not open directory '%s'"
-msgstr "kunde inte öppna katalogen \"%s\""
+msgid "%s expects a character, got '%s'"
+msgstr "%s förväntar ett tecken, fick \"%s\""
 
-#: dir.c:2109
-msgid "failed to get kernel name and information"
-msgstr "misslyckades hämta kärnans namn och information"
+#: diff.c:4925
+#, c-format
+msgid "bad --color-moved argument: %s"
+msgstr "felaktigt argument till --color-moved: %s"
 
-#: dir.c:2233
-msgid "Untracked cache is disabled on this system or location."
-msgstr "Ospårad cache är inaktiverad på systemet eller platsen."
+#: diff.c:4944
+#, c-format
+msgid "invalid mode '%s' in --color-moved-ws"
+msgstr "ogiltigt läge %s\" i --color-moved-ws"
+
+#: diff.c:4984
+msgid ""
+"option diff-algorithm accepts \"myers\", \"minimal\", \"patience\" and "
+"\"histogram\""
+msgstr ""
+"flaggan diff-algorithm godtar\"myers\", \"minimal\", \"patience\" och "
+"\"histogram\""
 
-#: dir.c:3075 dir.c:3080
+#: diff.c:5020 diff.c:5040
 #, c-format
-msgid "could not create directories for %s"
-msgstr "kunde inte skapa kataloger för %s"
+msgid "invalid argument to %s"
+msgstr "ogiltigt argument för %s"
 
-#: dir.c:3109
+#: diff.c:5178
 #, c-format
-msgid "could not migrate git directory from '%s' to '%s'"
-msgstr "kunde inte migrera git-katalog från \"%s\" till \"%s\""
+msgid "failed to parse --submodule option parameter: '%s'"
+msgstr "misslyckades tolka argument till flaggan --submodule: \"%s\""
 
-#: editor.c:61
+#: diff.c:5234
 #, c-format
-msgid "hint: Waiting for your editor to close the file...%c"
-msgstr "tips: Väntar på att textredigeringsprogrammet skall stänga filen...%c"
+msgid "bad --word-diff argument: %s"
+msgstr "felaktigt argument --word-diff: %s"
 
-#: entry.c:177
-msgid "Filtering content"
-msgstr "Filtrerar innehåll"
+#: diff.c:5257
+msgid "Diff output format options"
+msgstr "Formatflaggor för diff-utdata"
 
-#: entry.c:435
-#, c-format
-msgid "could not stat file '%s'"
-msgstr "kunde inte ta status på filen \"%s\""
+#: diff.c:5259 diff.c:5265
+msgid "generate patch"
+msgstr "skapar patch"
 
-#: fetch-object.c:17
-msgid "Remote with no URL"
-msgstr "Fjärr utan URL"
+#: diff.c:5262 builtin/log.c:173
+msgid "suppress diff output"
+msgstr "undertryck diff-utdata"
 
-#: fetch-pack.c:254
-msgid "git fetch-pack: expected shallow list"
-msgstr "git fetch-pack: förväntade grund lista"
+#: diff.c:5267 diff.c:5381 diff.c:5388
+msgid "<n>"
+msgstr "<n>"
 
-#: fetch-pack.c:266
-msgid "git fetch-pack: expected ACK/NAK, got a flush packet"
-msgstr "git fetch-pack: förväntade ACK/NAK, fick flush-paket"
+#: diff.c:5268 diff.c:5271
+msgid "generate diffs with <n> lines context"
+msgstr "skapa diffar med <n> rader sammanhang"
 
-#: fetch-pack.c:285 builtin/archive.c:63
-#, c-format
-msgid "remote error: %s"
-msgstr "fjärrfel: %s"
+#: diff.c:5273
+msgid "generate the diff in raw format"
+msgstr "generera diff i råformat"
 
-#: fetch-pack.c:286
-#, c-format
-msgid "git fetch-pack: expected ACK/NAK, got '%s'"
-msgstr "git fetch-pack: förväntade ACK/NAK, fick \"%s\""
+#: diff.c:5276
+msgid "synonym for '-p --raw'"
+msgstr "synonym till \"-p --raw\""
 
-#: fetch-pack.c:338
-msgid "--stateless-rpc requires multi_ack_detailed"
-msgstr "--stateless-rpc kräver ”multi_ack_detailed”"
+#: diff.c:5280
+msgid "synonym for '-p --stat'"
+msgstr "synonym till \"-p --stat\""
 
-#: fetch-pack.c:429 fetch-pack.c:1310
-#, c-format
-msgid "invalid shallow line: %s"
-msgstr "ogiltig \"shallow\"-rad: %s"
+#: diff.c:5284
+msgid "machine friendly --stat"
+msgstr "maskinläsbar --stat"
 
-#: fetch-pack.c:435 fetch-pack.c:1316
-#, c-format
-msgid "invalid unshallow line: %s"
-msgstr "ogiltig \"unshallow\"-rad: %s"
+#: diff.c:5287
+msgid "output only the last line of --stat"
+msgstr "skriv bara ut den sista raden för --stat"
 
-#: fetch-pack.c:437 fetch-pack.c:1318
-#, c-format
-msgid "object not found: %s"
-msgstr "objektet hittades inte: %s"
+#: diff.c:5289 diff.c:5297
+msgid "<param1,param2>..."
+msgstr "<param1,param2>..."
 
-#: fetch-pack.c:440 fetch-pack.c:1321
-#, c-format
-msgid "error in object: %s"
-msgstr "fel i objekt: %s"
+#: diff.c:5290
+msgid ""
+"output the distribution of relative amount of changes for each sub-directory"
+msgstr ""
+"skriv ut distributionen av relativa mängder ändringar för varje underkatalog"
 
-#: fetch-pack.c:442 fetch-pack.c:1323
-#, c-format
-msgid "no shallow found: %s"
-msgstr "ingen \"shallow\" hittades: %s"
+#: diff.c:5294
+msgid "synonym for --dirstat=cumulative"
+msgstr "synonym för --dirstat=cumulative"
 
-#: fetch-pack.c:445 fetch-pack.c:1326
-#, c-format
-msgid "expected shallow/unshallow, got %s"
-msgstr "förväntade shallow/unshallow, fick %s"
+#: diff.c:5298
+msgid "synonym for --dirstat=files,param1,param2..."
+msgstr "synonym för --dirstat=filer,param1,param2..."
 
-#: fetch-pack.c:486
-#, c-format
-msgid "got %s %d %s"
-msgstr "fick %s %d %s"
+#: diff.c:5302
+msgid "warn if changes introduce conflict markers or whitespace errors"
+msgstr "varna om ändringar introducerar konfliktmarkörer eller blankstegsfel"
 
-#: fetch-pack.c:500
-#, c-format
-msgid "invalid commit %s"
-msgstr "ogiltig incheckning %s"
+#: diff.c:5305
+msgid "condensed summary such as creations, renames and mode changes"
+msgstr "kortfattad summering såsom skapade, namnbyten och ändrade lägen"
 
-#: fetch-pack.c:533
-msgid "giving up"
-msgstr "ger upp"
+#: diff.c:5308
+msgid "show only names of changed files"
+msgstr "visa endast namnen på ändrade filer"
 
-#: fetch-pack.c:543 progress.c:229
-msgid "done"
-msgstr "klart"
+#: diff.c:5311
+msgid "show only names and status of changed files"
+msgstr "visa endast namn och status för ändrade filer"
 
-#: fetch-pack.c:555
-#, c-format
-msgid "got %s (%d) %s"
-msgstr "fick %s (%d) %s"
+#: diff.c:5313
+msgid "<width>[,<name-width>[,<count>]]"
+msgstr "<bredd>[,<namn-bredd>[,<antal>]]"
 
-#: fetch-pack.c:601
-#, c-format
-msgid "Marking %s as complete"
-msgstr "Markerar %s som komplett"
+#: diff.c:5314
+msgid "generate diffstat"
+msgstr "skapa diffstat"
 
-#: fetch-pack.c:828
-#, c-format
-msgid "already have %s (%s)"
-msgstr "har redan %s (%s)"
+#: diff.c:5316 diff.c:5319 diff.c:5322
+msgid "<width>"
+msgstr "<bredd>"
 
-#: fetch-pack.c:869
-msgid "fetch-pack: unable to fork off sideband demultiplexer"
-msgstr "fetch-patch: kunde inte grena av sidbandsmultiplexare"
+#: diff.c:5317
+msgid "generate diffstat with a given width"
+msgstr "generera en diffstat med given bredd"
 
-#: fetch-pack.c:877
-msgid "protocol error: bad pack header"
-msgstr "protokollfel: felaktigt packhuvud"
+#: diff.c:5320
+msgid "generate diffstat with a given name width"
+msgstr "generera en diffstat med given namnbredd"
 
-#: fetch-pack.c:944
-#, c-format
-msgid "fetch-pack: unable to fork off %s"
-msgstr "fetch-patch: kunde inte grena av %s"
+#: diff.c:5323
+msgid "generate diffstat with a given graph width"
+msgstr "generera en diffstat med given grafbredd"
 
-#: fetch-pack.c:960
-#, c-format
-msgid "%s failed"
-msgstr "%s misslyckades"
+#: diff.c:5325
+msgid "<count>"
+msgstr "<antal>"
 
-#: fetch-pack.c:962
-msgid "error in sideband demultiplexer"
-msgstr "fel i sidbands-avmultiplexare"
+#: diff.c:5326
+msgid "generate diffstat with limited lines"
+msgstr "generera diffstat med begränsade rader"
 
-#: fetch-pack.c:989
-msgid "Server does not support shallow clients"
-msgstr "Servern stöder inte klienter med grunda arkiv"
+#: diff.c:5329
+msgid "generate compact summary in diffstat"
+msgstr "skapa kompakt översikt i diffstat"
 
-#: fetch-pack.c:993
-msgid "Server supports multi_ack_detailed"
-msgstr "Servern stöder \"multi_ack_detailed\""
-
-#: fetch-pack.c:996
-msgid "Server supports no-done"
-msgstr "Servern stöder \"no-done\""
-
-#: fetch-pack.c:1002
-msgid "Server supports multi_ack"
-msgstr "Servern stöder \"multi_ack\""
-
-#: fetch-pack.c:1006
-msgid "Server supports side-band-64k"
-msgstr "Servern stöder \"side-band-64k\""
-
-#: fetch-pack.c:1010
-msgid "Server supports side-band"
-msgstr "Servern stöder \"side-band\""
-
-#: fetch-pack.c:1014
-msgid "Server supports allow-tip-sha1-in-want"
-msgstr "Servern stöder \"allow-tip-sha1-in-want\""
-
-#: fetch-pack.c:1018
-msgid "Server supports allow-reachable-sha1-in-want"
-msgstr "Servern stöder \"allow-reachable-sha1-in-want\""
-
-#: fetch-pack.c:1028
-msgid "Server supports ofs-delta"
-msgstr "Servern stöder \"ofs-delta\""
+#: diff.c:5332
+msgid "output a binary diff that can be applied"
+msgstr "skapa en binärdiff som kan appliceras"
 
-#: fetch-pack.c:1034 fetch-pack.c:1204
-msgid "Server supports filter"
-msgstr "Servern stöder filter"
+#: diff.c:5335
+msgid "show full pre- and post-image object names on the \"index\" lines"
+msgstr ""
+"visa fullständiga objektnamn i \"index\"-rader för läget både före och efter"
 
-#: fetch-pack.c:1042
-#, c-format
-msgid "Server version is %.*s"
-msgstr "Serverversionen är %.*s"
+#: diff.c:5337
+msgid "show colored diff"
+msgstr "visa färgad diff"
 
-#: fetch-pack.c:1048
-msgid "Server does not support --shallow-since"
-msgstr "Servern stöder inte --shallow-since"
+#: diff.c:5338
+msgid "<kind>"
+msgstr "<typ>"
 
-#: fetch-pack.c:1052
-msgid "Server does not support --shallow-exclude"
-msgstr "Servern stöder inte --shallow-exclude"
+#: diff.c:5339
+msgid ""
+"highlight whitespace errors in the 'context', 'old' or 'new' lines in the "
+"diff"
+msgstr ""
+"ljusmarkera blankstegsfel i \"context\" (sammanhang), \"old\" (gamla) eller "
+"\"new\" (nya) rader i diffen"
 
-#: fetch-pack.c:1054
-msgid "Server does not support --deepen"
-msgstr "Servern stöder inte --deepen"
+#: diff.c:5342
+msgid ""
+"do not munge pathnames and use NULs as output field terminators in --raw or "
+"--numstat"
+msgstr ""
+"skriv inte om sökvägsnamn och använd NUL-tecken som fältseparerare i --raw "
+"eller --numstat"
 
-#: fetch-pack.c:1065
-msgid "no common commits"
-msgstr "inga gemensamma incheckningar"
+#: diff.c:5345 diff.c:5348 diff.c:5351 diff.c:5457
+msgid "<prefix>"
+msgstr "<prefix>"
 
-#: fetch-pack.c:1077 fetch-pack.c:1414
-msgid "git fetch-pack: fetch failed."
-msgstr "git fetch-patch: hämtning misslyckades."
+#: diff.c:5346
+msgid "show the given source prefix instead of \"a/\""
+msgstr "visa givet källprefix istället för \"a/\""
 
-#: fetch-pack.c:1199
-msgid "Server does not support shallow requests"
-msgstr "Servern stöder inte grunda förfrågningar"
+#: diff.c:5349
+msgid "show the given destination prefix instead of \"b/\""
+msgstr "visa givet målprefix istället för \"b/\""
 
-#: fetch-pack.c:1584
-msgid "no matching remote head"
-msgstr "inget motsvarande fjärrhuvud"
+#: diff.c:5352
+msgid "prepend an additional prefix to every line of output"
+msgstr "lägg till ytterligare prefix på alla rader i utdata"
 
-#: fetch-pack.c:1610
-#, c-format
-msgid "no such remote ref %s"
-msgstr "ingen sådan fjärreferens: %s"
+#: diff.c:5355
+msgid "do not show any source or destination prefix"
+msgstr "visa inte käll- eller målprefix"
 
-#: fetch-pack.c:1613
-#, c-format
-msgid "Server does not allow request for unadvertised object %s"
-msgstr "Servern tillåter inte förfrågan om ej tillkännagivet objekt %s"
+#: diff.c:5358
+msgid "show context between diff hunks up to the specified number of lines"
+msgstr "visa sammnhang mellan diff-stycken upp till angivet antal rader"
 
-#: gpg-interface.c:185
-msgid "gpg failed to sign the data"
-msgstr "gpg misslyckades signera data"
+#: diff.c:5362 diff.c:5367 diff.c:5372
+msgid "<char>"
+msgstr "<tecken>"
 
-#: gpg-interface.c:210
-msgid "could not create temporary file"
-msgstr "kunde inte skapa temporära fil"
+#: diff.c:5363
+msgid "specify the character to indicate a new line instead of '+'"
+msgstr "ange tecken för att ange ny rad istället för \"+\""
 
-#: gpg-interface.c:213
-#, c-format
-msgid "failed writing detached signature to '%s'"
-msgstr "misslyckades skriva fristående signatur till \"%s\""
+#: diff.c:5368
+msgid "specify the character to indicate an old line instead of '-'"
+msgstr "ange tecken för att ange gammal rad istället för \"-\""
 
-#: graph.c:97
-#, c-format
-msgid "ignore invalid color '%.*s' in log.graphColors"
-msgstr "ignorera felaktig färg \"%.*s\" i log.graphColors"
+#: diff.c:5373
+msgid "specify the character to indicate a context instead of ' '"
+msgstr "ange tecken för att ange sammanhang istället för \" \""
 
-#: grep.c:2020
-#, c-format
-msgid "'%s': unable to read %s"
-msgstr "\"%s\" kunde inte läsa %s"
+#: diff.c:5376
+msgid "Diff rename options"
+msgstr "Diff-namnbytesflaggor"
 
-#: grep.c:2037 setup.c:164 builtin/clone.c:409 builtin/diff.c:81
-#: builtin/rm.c:134
-#, c-format
-msgid "failed to stat '%s'"
-msgstr "misslyckades ta status på \"%s\""
+#: diff.c:5377
+msgid "<n>[/<m>]"
+msgstr "<n>[/<m>]"
 
-#: grep.c:2048
-#, c-format
-msgid "'%s': short read"
-msgstr "\"%s\": kort läsning"
+#: diff.c:5378
+msgid "break complete rewrite changes into pairs of delete and create"
+msgstr "dela upp kompletta omskrivningar till ta bort och skapa-par"
 
-#: help.c:23
-msgid "start a working area (see also: git help tutorial)"
-msgstr "starta arbetskatalog (se också: git help tutorial)"
+#: diff.c:5382
+msgid "detect renames"
+msgstr "detektera namnändringar"
 
-#: help.c:24
-msgid "work on the current change (see also: git help everyday)"
-msgstr "jobba med aktuell förändring (se också: git help everyday)"
+#: diff.c:5386
+msgid "omit the preimage for deletes"
+msgstr "ta bort för-version för borttagningar"
 
-#: help.c:25
-msgid "examine the history and state (see also: git help revisions)"
-msgstr "utforska historiken och tillståndet (se också: git help revisions)"
+#: diff.c:5389
+msgid "detect copies"
+msgstr "detektera kopior"
 
-#: help.c:26
-msgid "grow, mark and tweak your common history"
-msgstr "utöka, markera och justera din gemensamma historik"
+#: diff.c:5393
+msgid "use unmodified files as source to find copies"
+msgstr "använd oförändrade som källa för att hitta kopior"
 
-#: help.c:27
-msgid "collaborate (see also: git help workflows)"
-msgstr "samarbeta (se också: git help workflows)"
+#: diff.c:5395
+msgid "disable rename detection"
+msgstr "inaktivera detektering av namnbyten"
 
-#: help.c:31
-msgid "Main Porcelain Commands"
-msgstr "Huvudsakliga porslinskommandon"
+#: diff.c:5398
+msgid "use empty blobs as rename source"
+msgstr "använd tomma blob:ar som namnändringskälla"
 
-#: help.c:32
-msgid "Ancillary Commands / Manipulators"
-msgstr "Tilläggskommandon / manipulerare"
+#: diff.c:5400
+msgid "continue listing the history of a file beyond renames"
+msgstr "fortsätt lista historiken för en fil bortom namnändringar"
 
-#: help.c:33
-msgid "Ancillary Commands / Interrogators"
-msgstr "Tilläggskommandon / frågare"
+#: diff.c:5403
+msgid ""
+"prevent rename/copy detection if the number of rename/copy targets exceeds "
+"given limit"
+msgstr ""
+"förhindra namnbyte/kopie-detektering om antalet namnbyten/kopior överskriver "
+"given gräns"
 
-#: help.c:34
-msgid "Interacting with Others"
-msgstr "Interaktion med andra"
+#: diff.c:5405
+msgid "Diff algorithm options"
+msgstr "Alternativ för diff-algoritm"
 
-#: help.c:35
-msgid "Low-level Commands / Manipulators"
-msgstr "Lågnivåkommandon / maniupulerare"
+#: diff.c:5407
+msgid "produce the smallest possible diff"
+msgstr "skapa minsta möjliga diff"
 
-#: help.c:36
-msgid "Low-level Commands / Interrogators"
-msgstr "Lågnivåkommandon / frågare"
+#: diff.c:5410
+msgid "ignore whitespace when comparing lines"
+msgstr "ignorera blanktecken vid radjämförelse"
 
-#: help.c:37
-msgid "Low-level Commands / Synching Repositories"
-msgstr "Lågnivåkommandon / synka arkiv"
+#: diff.c:5413
+msgid "ignore changes in amount of whitespace"
+msgstr "ignorera ändringar i antal blanktecken vid radjämförelse"
 
-#: help.c:38
-msgid "Low-level Commands / Internal Helpers"
-msgstr "Lågnivåkommandon / interna hjälpare"
+#: diff.c:5416
+msgid "ignore changes in whitespace at EOL"
+msgstr "ignorera blanktecken vid radslut"
 
-#: help.c:293
-#, c-format
-msgid "available git commands in '%s'"
-msgstr "git-kommandon tillgängliga i \"%s\""
+#: diff.c:5419
+msgid "ignore carrier-return at the end of line"
+msgstr "ignorera CR-tecken vid radslut"
 
-#: help.c:300
-msgid "git commands available from elsewhere on your $PATH"
-msgstr "git-kommandon från andra platser i din $PATH"
+#: diff.c:5422
+msgid "ignore changes whose lines are all blank"
+msgstr "ignorera ändringar i rader som är helt blanka"
 
-#: help.c:309
-msgid "These are common Git commands used in various situations:"
-msgstr "Dessa vanliga Git-kommandon används i olika situationer:"
+#: diff.c:5425
+msgid "heuristic to shift diff hunk boundaries for easy reading"
+msgstr "heuristik för att flytta diff-gränser för lättare läsning"
 
-#: help.c:358 git.c:90
-#, c-format
-msgid "unsupported command listing type '%s'"
-msgstr "okänd kommandolisttyp \"%s\""
+#: diff.c:5428
+msgid "generate diff using the \"patience diff\" algorithm"
+msgstr "skapa diffar med algoritmen \"patience diff\""
 
-#: help.c:405
-msgid "The common Git guides are:"
-msgstr "De vanliga Git-vägledningarna är:"
+#: diff.c:5432
+msgid "generate diff using the \"histogram diff\" algorithm"
+msgstr "skapa diffar med algoritmen \"histogram diff\""
 
-#: help.c:467
-#, c-format
-msgid ""
-"'%s' appears to be a git command, but we were not\n"
-"able to execute it. Maybe git-%s is broken?"
-msgstr ""
-"\"%s\" verkar vara ett git-kommando, men vi kan inte\n"
-"köra det. Kanske git-%s är trasigt?"
+#: diff.c:5434
+msgid "<algorithm>"
+msgstr "<algoritm>"
 
-#: help.c:526
-msgid "Uh oh. Your system reports no Git commands at all."
-msgstr "Oj då. Ditt system rapporterar inga Git-kommandon alls."
+#: diff.c:5435
+msgid "choose a diff algorithm"
+msgstr "välj en diff-algoritm"
 
-#: help.c:548
-#, c-format
-msgid "WARNING: You called a Git command named '%s', which does not exist."
-msgstr "VARNING: Du anropade ett Git-kommando vid namn \"%s\", som inte finns."
+#: diff.c:5437
+msgid "<text>"
+msgstr "<text>"
 
-#: help.c:553
-#, c-format
-msgid "Continuing under the assumption that you meant '%s'."
-msgstr "Fortsätter under förutsättningen att du menade ”%s”."
+#: diff.c:5438
+msgid "generate diff using the \"anchored diff\" algorithm"
+msgstr "skapa diffar med algoritmen \"anchored diff\""
 
-#: help.c:558
-#, c-format
-msgid "Continuing in %0.1f seconds, assuming that you meant '%s'."
+#: diff.c:5440 diff.c:5449 diff.c:5452
+msgid "<mode>"
+msgstr "<läge>"
+
+#: diff.c:5441
+msgid "show word diff, using <mode> to delimit changed words"
+msgstr "visa orddiff, där <läge> avgränsar ändrade ord"
+
+#: diff.c:5443 diff.c:5446 diff.c:5491
+msgid "<regex>"
+msgstr "<reguttr>"
+
+#: diff.c:5444
+msgid "use <regex> to decide what a word is"
+msgstr "använd <reguttr> för att bestämma vad som är ett ord"
+
+#: diff.c:5447
+msgid "equivalent to --word-diff=color --word-diff-regex=<regex>"
+msgstr "motsvarar --word-diff=color --word-diff-regex=<reguttr>"
+
+#: diff.c:5450
+msgid "moved lines of code are colored differently"
+msgstr "flyttade kodrader färgas på annat sätt"
+
+#: diff.c:5453
+msgid "how white spaces are ignored in --color-moved"
+msgstr "hur blanktecken ignoreras i --color-moved"
+
+#: diff.c:5456
+msgid "Other diff options"
+msgstr "Andra diff-flaggor"
+
+#: diff.c:5458
+msgid "when run from subdir, exclude changes outside and show relative paths"
 msgstr ""
-"Fortsätter om %0.1f sekunder, under förutsättningen att du menade ”%s”."
+"vid start från underkatalog, uteslut ändringar utanför och visa relativa "
+"sökvägar"
 
-#: help.c:566
-#, c-format
-msgid "git: '%s' is not a git command. See 'git --help'."
-msgstr "git: \"%s\" är inte ett git-kommando. Se \"git --help\"."
+#: diff.c:5462
+msgid "treat all files as text"
+msgstr "hantera alla filer som text"
 
-#: help.c:570
-msgid ""
-"\n"
-"The most similar command is"
-msgid_plural ""
-"\n"
-"The most similar commands are"
-msgstr[0] ""
-"\n"
-"Mest likt kommando är"
-msgstr[1] ""
-"\n"
-"Mest lika kommandon är"
+#: diff.c:5464
+msgid "swap two inputs, reverse the diff"
+msgstr "växla två indatafiler, vänd diffen"
 
-#: help.c:585
-msgid "git version [<options>]"
-msgstr "git version [<flaggor>]"
+#: diff.c:5466
+msgid "exit with 1 if there were differences, 0 otherwise"
+msgstr "avsluta med 1 vid ändringar, annars 0"
 
-#: help.c:652
-#, c-format
-msgid "%s: %s - %s"
-msgstr "%s: %s - %s"
+#: diff.c:5468
+msgid "disable all output of the program"
+msgstr "slå av alla utdata från programmet"
+
+#: diff.c:5470
+msgid "allow an external diff helper to be executed"
+msgstr "tillåt köra en extern diff-hjälpare"
+
+#: diff.c:5472
+msgid "run external text conversion filters when comparing binary files"
+msgstr "kör externt textkonverteringsfiler när binärfiler jämförs"
+
+#: diff.c:5474
+msgid "<when>"
+msgstr "<när>"
 
-#: help.c:656
+#: diff.c:5475
+msgid "ignore changes to submodules in the diff generation"
+msgstr "ignorera ändringar i undermoduler när diffen skapas"
+
+#: diff.c:5478
+msgid "<format>"
+msgstr "<format>"
+
+#: diff.c:5479
+msgid "specify how differences in submodules are shown"
+msgstr "ange hur ändringar i undermoduler visas"
+
+#: diff.c:5483
+msgid "hide 'git add -N' entries from the index"
+msgstr "dölj \"git add -N\"-poster från indexet"
+
+#: diff.c:5486
+msgid "treat 'git add -N' entries as real in the index"
+msgstr "tolka \"git add -N\"-poster som äkta i indexet"
+
+#: diff.c:5488
+msgid "<string>"
+msgstr "<sträng>"
+
+#: diff.c:5489
 msgid ""
-"\n"
-"Did you mean this?"
-msgid_plural ""
-"\n"
-"Did you mean one of these?"
-msgstr[0] ""
-"\n"
-"Menade du detta?"
-msgstr[1] ""
-"\n"
-"Menade du ett av dessa?"
+"look for differences that change the number of occurrences of the specified "
+"string"
+msgstr "se efter ändringar som ändrar antalet förekomster av angiven sträng"
 
-#: ident.c:342
+#: diff.c:5492
 msgid ""
-"\n"
-"*** Please tell me who you are.\n"
-"\n"
-"Run\n"
-"\n"
-"  git config --global user.email \"you@example.com\"\n"
-"  git config --global user.name \"Your Name\"\n"
-"\n"
-"to set your account's default identity.\n"
-"Omit --global to set the identity only in this repository.\n"
-"\n"
+"look for differences that change the number of occurrences of the specified "
+"regex"
 msgstr ""
-"\n"
-"*** Vänligen berätta vem du är.\n"
-"\n"
-"Kör\n"
-"\n"
-"  git config --global user.email \"du@example.com\"\n"
-"  git config --global user.name \"Ditt Namn\"\n"
-"\n"
-"för att ställa in ditt kontos standardidentitet.\n"
-"Kör utan --global för att endast ändra i aktuellt arkiv.\n"
-"\n"
+"se efter ändringar som ändrar antalet förekomster av angivet reguljärt "
+"uttryck"
 
-#: ident.c:366
-msgid "no email was given and auto-detection is disabled"
-msgstr "ingen e-post angavs och autodetektering är inaktiverad"
+#: diff.c:5495
+msgid "show all changes in the changeset with -S or -G"
+msgstr "visa alla ändringar i ändringsuppsättningen med -S eller -G"
 
-#: ident.c:371
-#, c-format
-msgid "unable to auto-detect email address (got '%s')"
-msgstr "kunde inte autodetektera e-postadress (fick \"%s\")"
+#: diff.c:5498
+msgid "treat <string> in -S as extended POSIX regular expression"
+msgstr "tolka <sträng> i -S som utökade POSIX-reguljära uttryck"
 
-#: ident.c:381
-msgid "no name was given and auto-detection is disabled"
-msgstr "inget namn angavs och autodetektering är inaktiverad"
+#: diff.c:5501
+msgid "control the order in which files appear in the output"
+msgstr "styr ordningen i vilken filer visas i utdata"
 
-#: ident.c:387
-#, c-format
-msgid "unable to auto-detect name (got '%s')"
-msgstr "kunde inte autodetektera namn (fick \"%s\")"
+#: diff.c:5502
+msgid "<object-id>"
+msgstr "<objekt-id>"
 
-#: ident.c:395
-#, c-format
-msgid "empty ident name (for <%s>) not allowed"
-msgstr "tomt ident-namn (för <%s>) ej tillåtet"
+#: diff.c:5503
+msgid ""
+"look for differences that change the number of occurrences of the specified "
+"object"
+msgstr "se efter ändringar som ändrar antalet förekomster av angivet objekt"
+
+#: diff.c:5505
+msgid "[(A|C|D|M|R|T|U|X|B)...[*]]"
+msgstr "[(A|C|D|M|R|T|U|X|B)...[*]]"
 
-#: ident.c:401
-#, c-format
-msgid "name consists only of disallowed characters: %s"
-msgstr "namnet består enbart av ej tillåtna tecken: %s"
+#: diff.c:5506
+msgid "select files by diff type"
+msgstr "välj filter efter diff-typ"
 
-#: ident.c:416 builtin/commit.c:587
-#, c-format
-msgid "invalid date format: %s"
-msgstr "felaktigt datumformat: %s"
+#: diff.c:5508
+msgid "<file>"
+msgstr "<fil>"
+
+#: diff.c:5509
+msgid "Output to a specific file"
+msgstr "Skriv utdata till en specifik fil"
 
-#: list-objects-filter-options.c:36
-msgid "multiple filter-specs cannot be combined"
-msgstr "flera filterspecifikationer kan inte kombineras"
+#: diff.c:6164
+msgid "inexact rename detection was skipped due to too many files."
+msgstr ""
+"onöjaktig namnbytesdetektering utfördes inte på grund av för många filer."
 
-#: list-objects-filter-options.c:126
-msgid "cannot change partial clone promisor remote"
-msgstr "kan inte ändra kontraktsfjärr för delvis kloning"
+#: diff.c:6167
+msgid "only found copies from modified paths due to too many files."
+msgstr "hittade bara kopior från ändrade sökvägar på grund av för många filer."
 
-#: lockfile.c:151
+#: diff.c:6170
 #, c-format
 msgid ""
-"Unable to create '%s.lock': %s.\n"
-"\n"
-"Another git process seems to be running in this repository, e.g.\n"
-"an editor opened by 'git commit'. Please make sure all processes\n"
-"are terminated then try again. If it still fails, a git process\n"
-"may have crashed in this repository earlier:\n"
-"remove the file manually to continue."
+"you may want to set your %s variable to at least %d and retry the command."
 msgstr ""
-"Kunde inte skapa \"%s.lock\": %s.\n"
-"\n"
-"Det verkar som en annan git-process kör i det här arkivet, t.ex.\n"
-"ett textredigeringsprogram startat av \"git commit\". Se till att\n"
-"alla processer avslutats och försök sedan igen. Om det fortfarande\n"
-"misslyckas kanske en git-process har kraschat i det här arkivet\n"
-"tidigare:\n"
-"ta bort filen manuellt för att fortsätta."
+"du kan sätta variabeln %s till åtminstone %d och försöka kommandot på nytt."
 
-#: lockfile.c:159
+#: dir.c:554
 #, c-format
-msgid "Unable to create '%s.lock': %s"
-msgstr "Kunde inte skapa \"%s.lock\": %s"
-
-#: merge.c:71
-msgid "failed to read the cache"
-msgstr "misslyckades läsa cachen"
-
-#: merge.c:136 builtin/am.c:1946 builtin/am.c:1980 builtin/checkout.c:378
-#: builtin/checkout.c:606 builtin/clone.c:761
-msgid "unable to write new index file"
-msgstr "kunde inte skriva ny indexfil"
+msgid "pathspec '%s' did not match any file(s) known to git"
+msgstr "sökvägsangivelsen \"%s\" motsvarade inte några av git kända filer"
 
-#: merge-recursive.c:298
-msgid "(bad commit)\n"
-msgstr "(felaktig incheckning)\n"
+#: dir.c:664
+#, c-format
+msgid "unrecognized pattern: '%s'"
+msgstr "okänt mönster: %s"
 
-#: merge-recursive.c:320
+#: dir.c:682 dir.c:696
 #, c-format
-msgid "add_cacheinfo failed for path '%s'; merge aborting."
-msgstr ""
-"add_cahceinfo misslyckades för sökvägen \"%s\"; avslutar sammanslagningen."
+msgid "unrecognized negative pattern: '%s'"
+msgstr "okänt negativt mönster: %s"
 
-#: merge-recursive.c:328
+#: dir.c:714
 #, c-format
-msgid "add_cacheinfo failed to refresh for path '%s'; merge aborting."
+msgid "your sparse-checkout file may have issues: pattern '%s' is repeated"
 msgstr ""
-"add_cacheinfo misslyckades uppdatera för sökvägen \"%s\"; avslutar "
-"sammanslagningen."
+"din \"sparse-checkout\"-fil kan ha problem: mönstret \"%s\" förekommer flera "
+"gånger"
 
-#: merge-recursive.c:410
-msgid "error building trees"
-msgstr "fel vid byggande av träd"
+#: dir.c:724
+msgid "disabling cone pattern matching"
+msgstr "inaktiverar konmönstermatchning"
 
-#: merge-recursive.c:881
+#: dir.c:1101
 #, c-format
-msgid "failed to create path '%s'%s"
-msgstr "misslyckades skapa sökvägen \"%s\"%s"
+msgid "cannot use %s as an exclude file"
+msgstr "kan inte använda %s som exkluderingsfil"
 
-#: merge-recursive.c:892
+#: dir.c:2078
 #, c-format
-msgid "Removing %s to make room for subdirectory\n"
-msgstr "Tar bort %s för att göra plats för underkatalog\n"
+msgid "could not open directory '%s'"
+msgstr "kunde inte öppna katalogen \"%s\""
 
-#: merge-recursive.c:906 merge-recursive.c:925
-msgid ": perhaps a D/F conflict?"
-msgstr ": kanske en K/F-konflikt?"
+#: dir.c:2415
+msgid "failed to get kernel name and information"
+msgstr "misslyckades hämta kärnans namn och information"
 
-#: merge-recursive.c:915
-#, c-format
-msgid "refusing to lose untracked file at '%s'"
-msgstr "vägrar förlora ospårad fil vid \"%s\""
+#: dir.c:2539
+msgid "untracked cache is disabled on this system or location"
+msgstr "ospårad cache är inaktiverad på systemet eller platsen"
 
-#: merge-recursive.c:957 builtin/cat-file.c:37
+#: dir.c:3343
 #, c-format
-msgid "cannot read object %s '%s'"
-msgstr "kan inte läsa objektet %s: \"%s\""
+msgid "index file corrupt in repo %s"
+msgstr "indexfilen trasig i arkivet %s"
 
-#: merge-recursive.c:959
+#: dir.c:3388 dir.c:3393
 #, c-format
-msgid "blob expected for %s '%s'"
-msgstr "blob förväntades för %s \"%s\""
+msgid "could not create directories for %s"
+msgstr "kunde inte skapa kataloger för %s"
 
-#: merge-recursive.c:983
+#: dir.c:3422
 #, c-format
-msgid "failed to open '%s': %s"
-msgstr "misslyckades öppna \"%s\": %s"
+msgid "could not migrate git directory from '%s' to '%s'"
+msgstr "kunde inte migrera git-katalog från \"%s\" till \"%s\""
 
-#: merge-recursive.c:994
+#: editor.c:73
 #, c-format
-msgid "failed to symlink '%s': %s"
-msgstr "misslyckades skapa symboliska länken \"%s\": %s"
+msgid "hint: Waiting for your editor to close the file...%c"
+msgstr "tips: Väntar på att textredigeringsprogrammet skall stänga filen...%c"
 
-#: merge-recursive.c:999
+#: entry.c:178
+msgid "Filtering content"
+msgstr "Filtrerar innehåll"
+
+#: entry.c:476
 #, c-format
-msgid "do not know what to do with %06o %s '%s'"
-msgstr "vet inte hur %06o %s \"%s\" skall hanteras"
+msgid "could not stat file '%s'"
+msgstr "kunde inte ta status på filen \"%s\""
 
-#: merge-recursive.c:1186
+#: environment.c:149
 #, c-format
-msgid "Failed to merge submodule %s (not checked out)"
-msgstr "Misslyckades slå ihop undermodulen %s (ej utcheckad)"
+msgid "bad git namespace path \"%s\""
+msgstr "felaktig git-namnrymdssökväg \"%s\""
 
-#: merge-recursive.c:1193
+#: environment.c:331
 #, c-format
-msgid "Failed to merge submodule %s (commits not present)"
-msgstr "Misslyckades slå ihop undermodulen %s (incheckningar saknas)"
+msgid "could not set GIT_DIR to '%s'"
+msgstr "kunde inte ställa in GIT_DIR till \"%s\""
 
-#: merge-recursive.c:1200
+#: exec-cmd.c:363
 #, c-format
-msgid "Failed to merge submodule %s (commits don't follow merge-base)"
-msgstr ""
-"Misslyckades slå ihop undermodulen %s (incheckningar följer inte "
-"sammanslagningsbasen)"
+msgid "too many args to run %s"
+msgstr "för många flaggor för att köra %s"
 
-#: merge-recursive.c:1208 merge-recursive.c:1220
-#, c-format
-msgid "Fast-forwarding submodule %s to the following commit:"
-msgstr "Snabbspolar undermodulen %s till följande incheckning:"
+#: fetch-pack.c:150
+msgid "git fetch-pack: expected shallow list"
+msgstr "git fetch-pack: förväntade grund lista"
 
-#: merge-recursive.c:1211 merge-recursive.c:1223
-#, c-format
-msgid "Fast-forwarding submodule %s to %s"
-msgstr "Snabbspolar undermodulen %s till %s"
+#: fetch-pack.c:153
+msgid "git fetch-pack: expected a flush packet after shallow list"
+msgstr "git fetch-pack: förväntade ett flush-paket efter grund lista"
 
-#: merge-recursive.c:1245
-#, c-format
-msgid "Failed to merge submodule %s (merge following commits not found)"
-msgstr ""
-"Misslyckades slå ihop undermodulen %s (sammanslagning efter incheckningar "
-"hittades inte)"
+#: fetch-pack.c:164
+msgid "git fetch-pack: expected ACK/NAK, got a flush packet"
+msgstr "git fetch-pack: förväntade ACK/NAK, fick flush-paket"
 
-#: merge-recursive.c:1249
+#: fetch-pack.c:184
 #, c-format
-msgid "Failed to merge submodule %s (not fast-forward)"
-msgstr "Misslyckades slå ihop undermodulen %s (ej snabbspolning)"
+msgid "git fetch-pack: expected ACK/NAK, got '%s'"
+msgstr "git fetch-pack: förväntade ACK/NAK, fick \"%s\""
 
-#: merge-recursive.c:1250
-msgid "Found a possible merge resolution for the submodule:\n"
-msgstr "Hittade en möjlig lösning av sammanslagning för undermodulen:\n"
+#: fetch-pack.c:195
+msgid "unable to write to remote"
+msgstr "kunde inte skriva till fjärren"
 
-#: merge-recursive.c:1253
-#, c-format
-msgid ""
-"If this is correct simply add it to the index for example\n"
-"by using:\n"
-"\n"
-"  git update-index --cacheinfo 160000 %s \"%s\"\n"
-"\n"
-"which will accept this suggestion.\n"
-msgstr ""
-"Om detta är riktigt lägger du bara till det i indexet, till\n"
-"exempel så här:\n"
-"\n"
-"  git update-index --cacheinfo 160000 %s \"%s\"\n"
-"\n"
-"vilket godtar lösningen.\n"
+#: fetch-pack.c:257
+msgid "--stateless-rpc requires multi_ack_detailed"
+msgstr "--stateless-rpc kräver \"multi_ack_detailed\""
 
-#: merge-recursive.c:1262
+#: fetch-pack.c:356 fetch-pack.c:1340
 #, c-format
-msgid "Failed to merge submodule %s (multiple merges found)"
-msgstr ""
-"Misslyckades slå ihop undermodulen %s (flera sammanslagningar hittades)"
-
-#: merge-recursive.c:1321
-msgid "Failed to execute internal merge"
-msgstr "Misslyckades exekvera intern sammanslagning"
+msgid "invalid shallow line: %s"
+msgstr "ogiltig \"shallow\"-rad: %s"
 
-#: merge-recursive.c:1326
+#: fetch-pack.c:362 fetch-pack.c:1346
 #, c-format
-msgid "Unable to add %s to database"
-msgstr "Kunde inte lägga till %s till databasen"
+msgid "invalid unshallow line: %s"
+msgstr "ogiltig \"unshallow\"-rad: %s"
 
-#: merge-recursive.c:1358
+#: fetch-pack.c:364 fetch-pack.c:1348
 #, c-format
-msgid "Auto-merging %s"
-msgstr "Slår ihop %s automatiskt"
+msgid "object not found: %s"
+msgstr "objektet hittades inte: %s"
 
-#: merge-recursive.c:1423
+#: fetch-pack.c:367 fetch-pack.c:1351
 #, c-format
-msgid "Error: Refusing to lose untracked file at %s; writing to %s instead."
-msgstr "Fel: Vägrar förlora ospårad fil vid %s; skriver till %s istället."
+msgid "error in object: %s"
+msgstr "fel i objekt: %s"
 
-#: merge-recursive.c:1475
+#: fetch-pack.c:369 fetch-pack.c:1353
 #, c-format
-msgid ""
-"CONFLICT (%s/delete): %s deleted in %s and %s in %s. Version %s of %s left "
-"in tree."
-msgstr ""
-"KONFLIKT (%s/radera): %s raderad i %s och %s i %s. Versionen %s av %s lämnad "
-"i trädet."
+msgid "no shallow found: %s"
+msgstr "ingen \"shallow\" hittades: %s"
 
-#: merge-recursive.c:1480
+#: fetch-pack.c:372 fetch-pack.c:1357
 #, c-format
-msgid ""
-"CONFLICT (%s/delete): %s deleted in %s and %s to %s in %s. Version %s of %s "
-"left in tree."
-msgstr ""
-"KONFLIKT (%s/radera): %s raderad i %s och %s till %s i %s. Versionen %s av "
-"%s lämnad i trädet."
+msgid "expected shallow/unshallow, got %s"
+msgstr "förväntade shallow/unshallow, fick %s"
 
-#: merge-recursive.c:1487
+#: fetch-pack.c:414
 #, c-format
-msgid ""
-"CONFLICT (%s/delete): %s deleted in %s and %s in %s. Version %s of %s left "
-"in tree at %s."
-msgstr ""
-"KONFLIKT (%s/radera): %s raderad i %s och %s i %s. Versionen %s av %s lämnad "
-"i trädet vid %s."
+msgid "got %s %d %s"
+msgstr "fick %s %d %s"
 
-#: merge-recursive.c:1492
+#: fetch-pack.c:431
 #, c-format
-msgid ""
-"CONFLICT (%s/delete): %s deleted in %s and %s to %s in %s. Version %s of %s "
-"left in tree at %s."
-msgstr ""
-"KONFLIKT (%s/radera): %s raderad i %s och %s till %s i %s. Versionen %s av "
-"%s lämnad i trädet vid %s."
+msgid "invalid commit %s"
+msgstr "ogiltig incheckning %s"
 
-#: merge-recursive.c:1526
-msgid "rename"
-msgstr "namnbyte"
+#: fetch-pack.c:462
+msgid "giving up"
+msgstr "ger upp"
 
-#: merge-recursive.c:1526
-msgid "renamed"
-msgstr "namnbytt"
+#: fetch-pack.c:475 progress.c:323
+msgid "done"
+msgstr "klart"
 
-#: merge-recursive.c:1580 merge-recursive.c:1736 merge-recursive.c:2368
-#: merge-recursive.c:3086
+#: fetch-pack.c:487
 #, c-format
-msgid "Refusing to lose dirty file at %s"
-msgstr "Vägrar förlora lortig fil vid \"%s\""
+msgid "got %s (%d) %s"
+msgstr "fick %s (%d) %s"
 
-#: merge-recursive.c:1594
+#: fetch-pack.c:533
 #, c-format
-msgid "%s is a directory in %s adding as %s instead"
-msgstr "%s är en katalog i %s lägger till som %s istället"
+msgid "Marking %s as complete"
+msgstr "Markerar %s som komplett"
 
-#: merge-recursive.c:1599
+#: fetch-pack.c:754
 #, c-format
-msgid "Refusing to lose untracked file at %s; adding as %s instead"
-msgstr "Vägrar förlora ospårad fil vid %s; lägger till som %s istället"
+msgid "already have %s (%s)"
+msgstr "har redan %s (%s)"
 
-#: merge-recursive.c:1625
-#, c-format
-msgid ""
-"CONFLICT (rename/rename): Rename \"%s\"->\"%s\" in branch \"%s\" rename \"%s"
-"\"->\"%s\" in \"%s\"%s"
-msgstr ""
-"KONFLIKT (namnbyte/namnbyte): Namnbyte \"%s\"->\"%s\" på grenen \"%s\" "
-"namnbyte \"%s\"->\"%s\" i \"%s\"%s"
+#: fetch-pack.c:818
+msgid "fetch-pack: unable to fork off sideband demultiplexer"
+msgstr "fetch-patch: kunde inte grena av sidbandsmultiplexare"
 
-#: merge-recursive.c:1630
-msgid " (left unresolved)"
-msgstr " (lämnad olöst)"
+#: fetch-pack.c:826
+msgid "protocol error: bad pack header"
+msgstr "protokollfel: felaktigt packhuvud"
 
-#: merge-recursive.c:1694
+#: fetch-pack.c:900
 #, c-format
-msgid "CONFLICT (rename/rename): Rename %s->%s in %s. Rename %s->%s in %s"
-msgstr ""
-"KONFLIKT (namnbyte/namnbyte): Namnbyte %s->%s i %s. Namnbyte %s->%s i %s"
+msgid "fetch-pack: unable to fork off %s"
+msgstr "fetch-patch: kunde inte grena av %s"
 
-#: merge-recursive.c:1733
+#: fetch-pack.c:916
 #, c-format
-msgid "Renaming %s to %s and %s to %s instead"
-msgstr "Byter namn på %s till %s och %s till %s istället"
+msgid "%s failed"
+msgstr "%s misslyckades"
 
-#: merge-recursive.c:1745
-#, c-format
-msgid "Refusing to lose untracked file at %s, even though it's in the way."
-msgstr "Vägrar förlora ospårad fil vid %s, trots att den är i vägen."
+#: fetch-pack.c:918
+msgid "error in sideband demultiplexer"
+msgstr "fel i sidbands-avmultiplexare"
 
-#: merge-recursive.c:1951
+#: fetch-pack.c:965
 #, c-format
-msgid ""
-"CONFLICT (directory rename split): Unclear where to place %s because "
-"directory %s was renamed to multiple other directories, with no destination "
-"getting a majority of the files."
-msgstr ""
-"KONFLIKT (namnändrad delad katalog): Osäker på var %s skall placeras då "
-"katalogen %s bytte namn till flera andra kataloger, utan att någon "
-"destination fick en majoritet av filerna."
+msgid "Server version is %.*s"
+msgstr "Serverversionen är %.*s"
 
-#: merge-recursive.c:1983
+#: fetch-pack.c:970 fetch-pack.c:976 fetch-pack.c:979 fetch-pack.c:985
+#: fetch-pack.c:989 fetch-pack.c:993 fetch-pack.c:997 fetch-pack.c:1001
+#: fetch-pack.c:1005 fetch-pack.c:1009 fetch-pack.c:1013 fetch-pack.c:1017
+#: fetch-pack.c:1023 fetch-pack.c:1029 fetch-pack.c:1034 fetch-pack.c:1039
 #, c-format
-msgid ""
-"CONFLICT (implicit dir rename): Existing file/dir at %s in the way of "
-"implicit directory rename(s) putting the following path(s) there: %s."
-msgstr ""
-"KONFLIKT (implicit nämnändrad kat): Befintlig fil/kat vid %s är i vägen för "
-"implicit namnändrad(e) katalog(er) som lägger dit följande sökväg(ar): %s."
+msgid "Server supports %s"
+msgstr "Servern stöder %s"
 
-#: merge-recursive.c:1993
-#, c-format
-msgid ""
-"CONFLICT (implicit dir rename): Cannot map more than one path to %s; "
-"implicit directory renames tried to put these paths there: %s"
-msgstr ""
-"KONFLIKT (implicit namnändrad kat): Kan inte koppla mer än en sökväg till "
-"%s; implicita katalognamnändringar försökte lägga följande sökvägar där: %s"
+#: fetch-pack.c:972
+msgid "Server does not support shallow clients"
+msgstr "Servern stöder inte klienter med grunda arkiv"
 
-#: merge-recursive.c:2085
-#, c-format
-msgid ""
-"CONFLICT (rename/rename): Rename directory %s->%s in %s. Rename directory %s-"
-">%s in %s"
-msgstr ""
-"KONFLIKT (namnbyte/namnbyte): Namnbytt katalog %s->%s i %s. Namnbytt katalog "
-"%s->%s i %s"
+#: fetch-pack.c:1032
+msgid "Server does not support --shallow-since"
+msgstr "Servern stöder inte --shallow-since"
 
-#: merge-recursive.c:2330
-#, c-format
-msgid ""
-"WARNING: Avoiding applying %s -> %s rename to %s, because %s itself was "
-"renamed."
-msgstr ""
-"VARNING: Undviker att applicera namnändring %s -> %s på %s, då %s själv har "
-"bytt namn."
+#: fetch-pack.c:1037
+msgid "Server does not support --shallow-exclude"
+msgstr "Servern stöder inte --shallow-exclude"
 
-#: merge-recursive.c:2736
-#, c-format
-msgid "CONFLICT (rename/add): Rename %s->%s in %s. %s added in %s"
-msgstr "KONFLIKT (namnbyte/tillägg): Namnbyte %s->%s i %s. %s tillagd i %s"
+#: fetch-pack.c:1041
+msgid "Server does not support --deepen"
+msgstr "Servern stöder inte --deepen"
 
-#: merge-recursive.c:2751
-#, c-format
-msgid "Adding merged %s"
-msgstr "Lägger till sammanslagen %s"
+#: fetch-pack.c:1058
+msgid "no common commits"
+msgstr "inga gemensamma incheckningar"
 
-#: merge-recursive.c:2758 merge-recursive.c:3089
-#, c-format
-msgid "Adding as %s instead"
-msgstr "Lägger till som %s istället"
+#: fetch-pack.c:1070 fetch-pack.c:1536
+msgid "git fetch-pack: fetch failed."
+msgstr "git fetch-patch: hämtning misslyckades."
 
-#: merge-recursive.c:2914
+#: fetch-pack.c:1209
+msgid "Server does not support shallow requests"
+msgstr "Servern stöder inte grunda förfrågningar"
+
+#: fetch-pack.c:1216
+msgid "Server supports filter"
+msgstr "Servern stöder filter"
+
+#: fetch-pack.c:1239
+msgid "unable to write request to remote"
+msgstr "kunde inte skriva anrop till fjärren"
+
+#: fetch-pack.c:1257
 #, c-format
-msgid "cannot read object %s"
-msgstr "kan inte läsa objektet %s"
+msgid "error reading section header '%s'"
+msgstr "fel vid läsning av styckehuvudet \"%s\""
 
-#: merge-recursive.c:2917
+#: fetch-pack.c:1263
 #, c-format
-msgid "object %s is not a blob"
-msgstr "objektet %s är inte en blob"
+msgid "expected '%s', received '%s'"
+msgstr "förväntade \"%s\", tog emot \"%s\""
 
-#: merge-recursive.c:2986
-msgid "modify"
-msgstr "ändra"
+#: fetch-pack.c:1303
+#, c-format
+msgid "unexpected acknowledgment line: '%s'"
+msgstr "förväntade bekräftelserad: \"%s\""
 
-#: merge-recursive.c:2986
-msgid "modified"
-msgstr "ändrad"
+#: fetch-pack.c:1308
+#, c-format
+msgid "error processing acks: %d"
+msgstr "fel vid hantering av bekräftelser: %d"
 
-#: merge-recursive.c:2997
-msgid "content"
-msgstr "innehåll"
+#: fetch-pack.c:1318
+msgid "expected packfile to be sent after 'ready'"
+msgstr "väntade att paketfil skulle sändas efter \"ready\""
 
-#: merge-recursive.c:3004
-msgid "add/add"
-msgstr "tillägg/tillägg"
+#: fetch-pack.c:1320
+msgid "expected no other sections to be sent after no 'ready'"
+msgstr ""
+"väntade inte att några ytterligare sektioner skulle sändas efter \"ready\""
 
-#: merge-recursive.c:3046
+#: fetch-pack.c:1362
 #, c-format
-msgid "Skipped %s (merged same as existing)"
-msgstr "Hoppade över %s (sammanslagen samma som befintlig)"
+msgid "error processing shallow info: %d"
+msgstr "fel vid hantering av grund (\"shallow\") info: %d"
 
-#: merge-recursive.c:3055 git-submodule.sh:895
-msgid "submodule"
-msgstr "undermodul"
-
-#: merge-recursive.c:3056
+#: fetch-pack.c:1409
 #, c-format
-msgid "CONFLICT (%s): Merge conflict in %s"
-msgstr "KONFLIKT (%s): Sammanslagningskonflikt i %s"
+msgid "expected wanted-ref, got '%s'"
+msgstr "förväntade wanted-ref, fick %s"
 
-#: merge-recursive.c:3178
+#: fetch-pack.c:1414
 #, c-format
-msgid "Removing %s"
-msgstr "Tar bort %s"
+msgid "unexpected wanted-ref: '%s'"
+msgstr "oväntad wanted-ref: \"%s\""
 
-#: merge-recursive.c:3204
-msgid "file/directory"
-msgstr "fil/katalog"
+#: fetch-pack.c:1419
+#, c-format
+msgid "error processing wanted refs: %d"
+msgstr "fel vid hantering av önskade referenser: %d"
 
-#: merge-recursive.c:3210
-msgid "directory/file"
-msgstr "katalog/fil"
+#: fetch-pack.c:1762
+msgid "no matching remote head"
+msgstr "inget motsvarande fjärrhuvud"
 
-#: merge-recursive.c:3217
-#, c-format
-msgid "CONFLICT (%s): There is a directory with name %s in %s. Adding %s as %s"
-msgstr ""
-"KONFLIKT (%s): Det finns en katalog med namnet %s i %s. Lägger till %s som %s"
+#: fetch-pack.c:1785 builtin/clone.c:688
+msgid "remote did not send all necessary objects"
+msgstr "fjärren sände inte alla nödvändiga objekt"
 
-#: merge-recursive.c:3226
+#: fetch-pack.c:1812
 #, c-format
-msgid "Adding %s"
-msgstr "Lägger till %s"
+msgid "no such remote ref %s"
+msgstr "ingen sådan fjärreferens: %s"
 
-#: merge-recursive.c:3267
+#: fetch-pack.c:1815
 #, c-format
-msgid "Dirty index: cannot merge (dirty: %s)"
-msgstr "Smutsigt index: kan inte slå ihop (smutsiga: %s)"
+msgid "Server does not allow request for unadvertised object %s"
+msgstr "Servern tillåter inte förfrågan om ej tillkännagivet objekt %s"
 
-#: merge-recursive.c:3271
-msgid "Already up to date!"
-msgstr "Redan à jour!"
+#: gpg-interface.c:223
+msgid "could not create temporary file"
+msgstr "kunde inte skapa temporära fil"
 
-#: merge-recursive.c:3280
+#: gpg-interface.c:226
 #, c-format
-msgid "merging of trees %s and %s failed"
-msgstr "sammanslagning av träden %s och %s misslyckades"
+msgid "failed writing detached signature to '%s'"
+msgstr "misslyckades skriva fristående signatur till \"%s\""
 
-#: merge-recursive.c:3379
-msgid "Merging:"
-msgstr "Slår ihop:"
+#: gpg-interface.c:390
+msgid "gpg failed to sign the data"
+msgstr "gpg misslyckades signera data"
 
-#: merge-recursive.c:3392
+#: graph.c:98
 #, c-format
-msgid "found %u common ancestor:"
-msgid_plural "found %u common ancestors:"
-msgstr[0] "hittade %u gemensam förfader:"
-msgstr[1] "hittade %u gemensamma förfäder:"
+msgid "ignore invalid color '%.*s' in log.graphColors"
+msgstr "ignorera felaktig färg \"%.*s\" i log.graphColors"
 
-#: merge-recursive.c:3431
-msgid "merge returned no commit"
-msgstr "sammanslagningen returnerade ingen incheckning"
+#: grep.c:668
+msgid ""
+"given pattern contains NULL byte (via -f <file>). This is only supported "
+"with -P under PCRE v2"
+msgstr ""
+"angivet mönster innehåller NULL-byte (via -f <fil>). Detta stöds endast med -"
+"P under PCRE v2"
 
-#: merge-recursive.c:3495
+#: grep.c:2124
 #, c-format
-msgid "Could not parse object '%s'"
-msgstr "Kunde inte tolka objektet \"%s\""
-
-#: merge-recursive.c:3511 builtin/merge.c:659 builtin/merge.c:816
-msgid "Unable to write index."
-msgstr "Kunde inte skriva indexet."
+msgid "'%s': unable to read %s"
+msgstr "\"%s\" kunde inte läsa %s"
 
-#: notes-merge.c:272
+#: grep.c:2141 setup.c:165 builtin/clone.c:411 builtin/diff.c:82
+#: builtin/rm.c:135
 #, c-format
-msgid ""
-"You have not concluded your previous notes merge (%s exists).\n"
-"Please, use 'git notes merge --commit' or 'git notes merge --abort' to "
-"commit/abort the previous merge before you start a new notes merge."
-msgstr ""
-"Du har inte avslutat föregående antecknings-sammanslagning (%s finns).\n"
-"Använd \"git notes merge --commit\" eller \"git notes merge --abort\" för "
-"att checka in eller avbryta föregående sammanslagning innan du påbörjar en "
-"ny antecknings-sammanslagning."
+msgid "failed to stat '%s'"
+msgstr "misslyckades ta status på \"%s\""
 
-#: notes-merge.c:279
+#: grep.c:2152
 #, c-format
-msgid "You have not concluded your notes merge (%s exists)."
-msgstr "Du har inte avslutat antecknings-sammanslagningen (%s finns)."
+msgid "'%s': short read"
+msgstr "\"%s\": kort läsning"
 
-#: notes-utils.c:43
-msgid "Cannot commit uninitialized/unreferenced notes tree"
-msgstr "Kan inte checka in oinitierat/orefererat anteckningsträd"
+#: help.c:23
+msgid "start a working area (see also: git help tutorial)"
+msgstr "starta arbetskatalog (se också: git help tutorial)"
 
-#: notes-utils.c:102
-#, c-format
-msgid "Bad notes.rewriteMode value: '%s'"
-msgstr "Felaktigt värde för notes.rewriteMode: '%s'"
+#: help.c:24
+msgid "work on the current change (see also: git help everyday)"
+msgstr "jobba med aktuell förändring (se också: git help everyday)"
 
-#: notes-utils.c:112
-#, c-format
-msgid "Refusing to rewrite notes in %s (outside of refs/notes/)"
-msgstr "Vägrar skriva över anteckningar i %s (utanför refs/notes/)"
+#: help.c:25
+msgid "examine the history and state (see also: git help revisions)"
+msgstr "utforska historiken och tillståndet (se också: git help revisions)"
 
-#. TRANSLATORS: The first %s is the name of
-#. the environment variable, the second %s is
-#. its value.
-#.
-#: notes-utils.c:142
-#, c-format
-msgid "Bad %s value: '%s'"
-msgstr "Felaktigt värde på %s: \"%s\""
+#: help.c:26
+msgid "grow, mark and tweak your common history"
+msgstr "utöka, markera och justera din gemensamma historik"
 
-#: object.c:242
-#, c-format
-msgid "unable to parse object: %s"
-msgstr "kunde inte tolka objektet: %s"
+#: help.c:27
+msgid "collaborate (see also: git help workflows)"
+msgstr "samarbeta (se också: git help workflows)"
 
-#: packfile.c:563
-msgid "offset before end of packfile (broken .idx?)"
-msgstr "offset före slutet av packfilen (trasig .idx?)"
+#: help.c:31
+msgid "Main Porcelain Commands"
+msgstr "Huvudsakliga porslinskommandon"
 
-#: packfile.c:1742
-#, c-format
-msgid "offset before start of pack index for %s (corrupt index?)"
-msgstr "offset före slutet av packindex för %s (trasigt index?)"
+#: help.c:32
+msgid "Ancillary Commands / Manipulators"
+msgstr "Tilläggskommandon / manipulerare"
 
-#: packfile.c:1746
-#, c-format
-msgid "offset beyond end of pack index for %s (truncated index?)"
-msgstr "offset borton slutet av packindex för %s (trunkerat index?)"
+#: help.c:33
+msgid "Ancillary Commands / Interrogators"
+msgstr "Tilläggskommandon / frågare"
 
-#: parse-options.c:621
-msgid "..."
-msgstr "..."
+#: help.c:34
+msgid "Interacting with Others"
+msgstr "Interaktion med andra"
+
+#: help.c:35
+msgid "Low-level Commands / Manipulators"
+msgstr "Lågnivåkommandon / maniupulerare"
+
+#: help.c:36
+msgid "Low-level Commands / Interrogators"
+msgstr "Lågnivåkommandon / frågare"
+
+#: help.c:37
+msgid "Low-level Commands / Syncing Repositories"
+msgstr "Lågnivåkommandon / synka arkiv"
+
+#: help.c:38
+msgid "Low-level Commands / Internal Helpers"
+msgstr "Lågnivåkommandon / interna hjälpare"
 
-#: parse-options.c:640
+#: help.c:298
 #, c-format
-msgid "usage: %s"
-msgstr "användning: %s"
+msgid "available git commands in '%s'"
+msgstr "git-kommandon tillgängliga i \"%s\""
 
-#. TRANSLATORS: the colon here should align with the
-#. one in "usage: %s" translation.
-#.
-#: parse-options.c:646
+#: help.c:305
+msgid "git commands available from elsewhere on your $PATH"
+msgstr "git-kommandon från andra platser i din $PATH"
+
+#: help.c:314
+msgid "These are common Git commands used in various situations:"
+msgstr "Dessa vanliga Git-kommandon används i olika situationer:"
+
+#: help.c:363 git.c:98
 #, c-format
-msgid "   or: %s"
-msgstr "     eller: %s"
+msgid "unsupported command listing type '%s'"
+msgstr "okänd kommandolisttyp \"%s\""
+
+#: help.c:403
+msgid "The common Git guides are:"
+msgstr "De vanliga Git-vägledningarna är:"
 
-#: parse-options.c:649
+#: help.c:512
+msgid "See 'git help <command>' to read about a specific subcommand"
+msgstr "Se \"git help <kommando>\" för att läsa om ett specifikt underkommando"
+
+#: help.c:517
+msgid "External commands"
+msgstr "Externa kommandon"
+
+#: help.c:532
+msgid "Command aliases"
+msgstr "Kommadoalias"
+
+#: help.c:596
 #, c-format
-msgid "    %s"
-msgstr "    %s"
+msgid ""
+"'%s' appears to be a git command, but we were not\n"
+"able to execute it. Maybe git-%s is broken?"
+msgstr ""
+"\"%s\" verkar vara ett git-kommando, men vi kan inte\n"
+"köra det. Kanske git-%s är trasigt?"
 
-#: parse-options.c:688
-msgid "-NUM"
-msgstr "-TAL"
+#: help.c:655
+msgid "Uh oh. Your system reports no Git commands at all."
+msgstr "Oj då. Ditt system rapporterar inga Git-kommandon alls."
 
-#: parse-options-cb.c:44
+#: help.c:677
 #, c-format
-msgid "malformed expiration date '%s'"
-msgstr "trasigt utlöpsdatum: ”%s”"
+msgid "WARNING: You called a Git command named '%s', which does not exist."
+msgstr "VARNING: Du anropade ett Git-kommando vid namn \"%s\", som inte finns."
 
-#: parse-options-cb.c:112
+#: help.c:682
 #, c-format
-msgid "malformed object name '%s'"
-msgstr "felformat objektnamn \"%s\""
+msgid "Continuing under the assumption that you meant '%s'."
+msgstr "Fortsätter under förutsättningen att du menade \"%s\"."
 
-#: path.c:892
+#: help.c:687
 #, c-format
-msgid "Could not make %s writable by group"
-msgstr "Kunde inte göra %s skrivbar för gruppen"
+msgid "Continuing in %0.1f seconds, assuming that you meant '%s'."
+msgstr ""
+"Fortsätter om %0.1f sekunder, under förutsättningen att du menade \"%s\"."
 
-#: pathspec.c:129
-msgid "Escape character '\\' not allowed as last character in attr value"
-msgstr "Specialtecknet \"\\\" tillåts inte som sista tecken i attributvärde"
+#: help.c:695
+#, c-format
+msgid "git: '%s' is not a git command. See 'git --help'."
+msgstr "git: \"%s\" är inte ett git-kommando. Se \"git --help\"."
 
-#: pathspec.c:147
-msgid "Only one 'attr:' specification is allowed."
-msgstr "Endast en \"attr:\"-angivelse tillåten."
+#: help.c:699
+msgid ""
+"\n"
+"The most similar command is"
+msgid_plural ""
+"\n"
+"The most similar commands are"
+msgstr[0] ""
+"\n"
+"Mest likt kommando är"
+msgstr[1] ""
+"\n"
+"Mest lika kommandon är"
 
-#: pathspec.c:150
-msgid "attr spec must not be empty"
-msgstr "attr-angivelse kan inte vara tom"
+#: help.c:714
+msgid "git version [<options>]"
+msgstr "git version [<flaggor>]"
 
-#: pathspec.c:193
+#: help.c:783
 #, c-format
-msgid "invalid attribute name %s"
-msgstr "ogiltigt attributnamn %s"
+msgid "%s: %s - %s"
+msgstr "%s: %s - %s"
 
-#: pathspec.c:258
-msgid "global 'glob' and 'noglob' pathspec settings are incompatible"
-msgstr ""
-"de globala sökvägsinställningarna \"glob\" och \"noglob\" är inkompatibla"
+#: help.c:787
+msgid ""
+"\n"
+"Did you mean this?"
+msgid_plural ""
+"\n"
+"Did you mean one of these?"
+msgstr[0] ""
+"\n"
+"Menade du detta?"
+msgstr[1] ""
+"\n"
+"Menade du ett av dessa?"
 
-#: pathspec.c:265
+#: ident.c:349
 msgid ""
-"global 'literal' pathspec setting is incompatible with all other global "
-"pathspec settings"
+"\n"
+"*** Please tell me who you are.\n"
+"\n"
+"Run\n"
+"\n"
+"  git config --global user.email \"you@example.com\"\n"
+"  git config --global user.name \"Your Name\"\n"
+"\n"
+"to set your account's default identity.\n"
+"Omit --global to set the identity only in this repository.\n"
+"\n"
 msgstr ""
-"den globala sökvägsinställningen \"literal\" är inkompatibel med alla andra "
-"globala sökvägsinställningar"
+"\n"
+"*** Vänligen berätta vem du är.\n"
+"\n"
+"Kör\n"
+"\n"
+"  git config --global user.email \"du@example.com\"\n"
+"  git config --global user.name \"Ditt Namn\"\n"
+"\n"
+"för att ställa in ditt kontos standardidentitet.\n"
+"Kör utan --global för att endast ändra i aktuellt arkiv.\n"
+"\n"
 
-#: pathspec.c:305
-msgid "invalid parameter for pathspec magic 'prefix'"
-msgstr "ogiltig parameter för sökvägsuttrycket för \"prefix\""
+#: ident.c:379
+msgid "no email was given and auto-detection is disabled"
+msgstr "ingen e-post angavs och autodetektering är inaktiverad"
 
-#: pathspec.c:326
+#: ident.c:384
 #, c-format
-msgid "Invalid pathspec magic '%.*s' in '%s'"
-msgstr "Felaktigt sökvägsuttryck \"%.*s\" i \"%s\""
+msgid "unable to auto-detect email address (got '%s')"
+msgstr "kunde inte autodetektera e-postadress (fick \"%s\")"
 
-#: pathspec.c:331
-#, c-format
-msgid "Missing ')' at the end of pathspec magic in '%s'"
-msgstr "\")\" saknas i slutet av sökvägsuttrycket för \"%s\""
+#: ident.c:401
+msgid "no name was given and auto-detection is disabled"
+msgstr "inget namn angavs och autodetektering är inaktiverad"
 
-#: pathspec.c:369
+#: ident.c:407
 #, c-format
-msgid "Unimplemented pathspec magic '%c' in '%s'"
-msgstr "Ej implementerat sökvägsuttryckmagi ”%c” i ”%s”"
+msgid "unable to auto-detect name (got '%s')"
+msgstr "kunde inte autodetektera namn (fick \"%s\")"
 
-#: pathspec.c:428
+#: ident.c:415
 #, c-format
-msgid "%s: 'literal' and 'glob' are incompatible"
-msgstr "%s: \"literal\" och \"glob\" är inkompatibla"
+msgid "empty ident name (for <%s>) not allowed"
+msgstr "tomt ident-namn (för <%s>) ej tillåtet"
 
-#: pathspec.c:441
+#: ident.c:421
 #, c-format
-msgid "%s: '%s' is outside repository"
-msgstr "%s: \"%s\" är utanför arkivet"
+msgid "name consists only of disallowed characters: %s"
+msgstr "namnet består enbart av ej tillåtna tecken: %s"
 
-#: pathspec.c:515
+#: ident.c:436 builtin/commit.c:631
 #, c-format
-msgid "'%s' (mnemonic: '%c')"
-msgstr "\"%s\" (minnesstöd: \"%c\")"
+msgid "invalid date format: %s"
+msgstr "felaktigt datumformat: %s"
 
-#: pathspec.c:525
+#: list-objects.c:127
 #, c-format
-msgid "%s: pathspec magic not supported by this command: %s"
-msgstr "%s: sökvägsuttrycket hanteras inte av det här kommandot: %s"
+msgid "entry '%s' in tree %s has tree mode, but is not a tree"
+msgstr "posten \"%s\" i trädet %s har träd-läge, men är inte ett träd"
 
-#: pathspec.c:592
+#: list-objects.c:140
 #, c-format
-msgid "pathspec '%s' is beyond a symbolic link"
-msgstr "sökvägsangivelsen \"%s\" är på andra sidan av en symbolisk länk"
+msgid "entry '%s' in tree %s has blob mode, but is not a blob"
+msgstr "posten \"%s\" i trädet %s har blob-läge, men är inte en blob"
 
-#: pretty.c:962
-msgid "unable to parse --pretty format"
-msgstr "kunde inte tolka format för --pretty"
+#: list-objects.c:375
+#, c-format
+msgid "unable to load root tree for commit %s"
+msgstr "kunde inte läsa in rot-trädet för incheckningen %s"
 
-#: read-cache.c:1500
+#: list-objects-filter.c:492
 #, c-format
-msgid ""
-"index.version set, but the value is invalid.\n"
-"Using version %i"
-msgstr ""
-"index.version satt, men värdet är ogiltigt.\n"
-"Använder version %i"
+msgid "unable to access sparse blob in '%s'"
+msgstr "kunde inte nå gles blob på \"%s\""
 
-#: read-cache.c:1510
+#: list-objects-filter.c:495
 #, c-format
-msgid ""
-"GIT_INDEX_VERSION set, but the value is invalid.\n"
-"Using version %i"
-msgstr ""
-"GIT_INDEX_VERSION satt, men värdet är ogiltigt.\n"
-"Använder version %i"
+msgid "unable to parse sparse filter data in %s"
+msgstr "kunde inte tolka gles filterdata i %s"
 
-#: read-cache.c:2404 sequencer.c:4338 wrapper.c:658 builtin/merge.c:1048
-#, c-format
-msgid "could not close '%s'"
-msgstr "kunde inte stänga \"%s\""
+#: list-objects-filter-options.c:58
+msgid "expected 'tree:<depth>'"
+msgstr "förväntade \"tree:<djup>\""
 
-#: read-cache.c:2477 sequencer.c:2102 sequencer.c:3234
-#, c-format
-msgid "could not stat '%s'"
-msgstr "kunde inte ta status på \"%s\""
+#: list-objects-filter-options.c:73
+msgid "sparse:path filters support has been dropped"
+msgstr "sparse:sökväg-filter stöds inte längre"
 
-#: read-cache.c:2490
+#: list-objects-filter-options.c:86
 #, c-format
-msgid "unable to open git dir: %s"
-msgstr "kunde inte öppna git-katalog: %s"
+msgid "invalid filter-spec '%s'"
+msgstr "felaktig filterspecifikation: \"%s\""
 
-#: read-cache.c:2502
+#: list-objects-filter-options.c:102
 #, c-format
-msgid "unable to unlink: %s"
-msgstr "misslyckades ta bort länken: %s"
+msgid "must escape char in sub-filter-spec: '%c'"
+msgstr "måste använda specialsekvens i delfilter-spec: \"%c\""
 
-#: refs.c:732 sequencer.c:4334 sequencer.c:4393 wrapper.c:225 wrapper.c:395
-#: builtin/am.c:779
-#, c-format
-msgid "could not open '%s' for writing"
-msgstr "kunde inte öppna \"%s\" för skrivning"
+#: list-objects-filter-options.c:144
+msgid "expected something after combine:"
+msgstr "förväntade någonting efter combine:"
 
-#: refs.c:1880
-msgid "ref updates forbidden inside quarantine environment"
-msgstr "referensuppdateringar förbjudna i karantänmiljö"
+#: list-objects-filter-options.c:226
+msgid "multiple filter-specs cannot be combined"
+msgstr "flera filterspecifikationer kan inte kombineras"
 
-#: refs/files-backend.c:1191
+#: lockfile.c:151
 #, c-format
-msgid "could not remove reference %s"
-msgstr "kunde inte ta bort referensen %s"
+msgid ""
+"Unable to create '%s.lock': %s.\n"
+"\n"
+"Another git process seems to be running in this repository, e.g.\n"
+"an editor opened by 'git commit'. Please make sure all processes\n"
+"are terminated then try again. If it still fails, a git process\n"
+"may have crashed in this repository earlier:\n"
+"remove the file manually to continue."
+msgstr ""
+"Kunde inte skapa \"%s.lock\": %s.\n"
+"\n"
+"Det verkar som en annan git-process kör i det här arkivet, t.ex.\n"
+"ett textredigeringsprogram startat av \"git commit\". Se till att\n"
+"alla processer avslutats och försök sedan igen. Om det fortfarande\n"
+"misslyckas kanske en git-process har kraschat i det här arkivet\n"
+"tidigare:\n"
+"ta bort filen manuellt för att fortsätta."
 
-#: refs/files-backend.c:1205 refs/packed-backend.c:1531
-#: refs/packed-backend.c:1541
+#: lockfile.c:159
 #, c-format
-msgid "could not delete reference %s: %s"
-msgstr "kunde inte ta bort referensen %s: %s"
+msgid "Unable to create '%s.lock': %s"
+msgstr "Kunde inte skapa \"%s.lock\": %s"
 
-#: refs/files-backend.c:1208 refs/packed-backend.c:1544
-#, c-format
-msgid "could not delete references: %s"
-msgstr "kunde inte ta bort referenser: %s"
+#: merge.c:41
+msgid "failed to read the cache"
+msgstr "misslyckades läsa cachen"
 
-#: ref-filter.c:35 wt-status.c:1850
-msgid "gone"
-msgstr "försvunnen"
+#: merge.c:107 rerere.c:720 builtin/am.c:1874 builtin/am.c:1908
+#: builtin/checkout.c:539 builtin/checkout.c:798 builtin/clone.c:809
+#: builtin/stash.c:264
+msgid "unable to write new index file"
+msgstr "kunde inte skriva ny indexfil"
 
-#: ref-filter.c:36
-#, c-format
-msgid "ahead %d"
-msgstr "före %d"
+#: merge-recursive.c:367
+msgid "(bad commit)\n"
+msgstr "(felaktig incheckning)\n"
 
-#: ref-filter.c:37
+#: merge-recursive.c:390
 #, c-format
-msgid "behind %d"
-msgstr "bakom %d"
+msgid "add_cacheinfo failed for path '%s'; merge aborting."
+msgstr ""
+"add_cahceinfo misslyckades för sökvägen \"%s\"; avslutar sammanslagningen."
 
-#: ref-filter.c:38
+#: merge-recursive.c:399
 #, c-format
-msgid "ahead %d, behind %d"
-msgstr "före %d, bakom %d"
+msgid "add_cacheinfo failed to refresh for path '%s'; merge aborting."
+msgstr ""
+"add_cacheinfo misslyckades uppdatera för sökvägen \"%s\"; avslutar "
+"sammanslagningen."
 
-#: ref-filter.c:121
+#: merge-recursive.c:885
 #, c-format
-msgid "expected format: %%(color:<color>)"
-msgstr "förväntat format: %%(color:<color>)"
+msgid "failed to create path '%s'%s"
+msgstr "misslyckades skapa sökvägen \"%s\"%s"
 
-#: ref-filter.c:123
+#: merge-recursive.c:896
 #, c-format
-msgid "unrecognized color: %%(color:%s)"
-msgstr "okänd färg: %%(color:%s)"
+msgid "Removing %s to make room for subdirectory\n"
+msgstr "Tar bort %s för att göra plats för underkatalog\n"
 
-#: ref-filter.c:145
-#, c-format
-msgid "Integer value expected refname:lstrip=%s"
-msgstr "Heltalsvärde förväntades refname:lstrip=%s"
+#: merge-recursive.c:910 merge-recursive.c:929
+msgid ": perhaps a D/F conflict?"
+msgstr ": kanske en K/F-konflikt?"
 
-#: ref-filter.c:149
+#: merge-recursive.c:919
 #, c-format
-msgid "Integer value expected refname:rstrip=%s"
-msgstr "Heltalsvärde förväntades refname:rstrip=%s"
+msgid "refusing to lose untracked file at '%s'"
+msgstr "vägrar förlora ospårad fil vid \"%s\""
 
-#: ref-filter.c:151
+#: merge-recursive.c:960 builtin/cat-file.c:41
 #, c-format
-msgid "unrecognized %%(%s) argument: %s"
-msgstr "okänt %%(%s)-argument: %s"
+msgid "cannot read object %s '%s'"
+msgstr "kan inte läsa objektet %s: \"%s\""
 
-#: ref-filter.c:206
+#: merge-recursive.c:965
 #, c-format
-msgid "%%(body) does not take arguments"
-msgstr "%%(body) tar inte argument"
+msgid "blob expected for %s '%s'"
+msgstr "blob förväntades för %s \"%s\""
 
-#: ref-filter.c:215
+#: merge-recursive.c:990
 #, c-format
-msgid "%%(subject) does not take arguments"
-msgstr "%%(subject) tar inte argument"
+msgid "failed to open '%s': %s"
+msgstr "misslyckades öppna \"%s\": %s"
 
-#: ref-filter.c:235
+#: merge-recursive.c:1001
 #, c-format
-msgid "unknown %%(trailers) argument: %s"
-msgstr "okänt %%(trailers)-argument: %s"
+msgid "failed to symlink '%s': %s"
+msgstr "misslyckades skapa symboliska länken \"%s\": %s"
 
-#: ref-filter.c:264
+#: merge-recursive.c:1006
 #, c-format
-msgid "positive value expected contents:lines=%s"
-msgstr "positivt värde förväntat contents:lines=%s"
+msgid "do not know what to do with %06o %s '%s'"
+msgstr "vet inte hur %06o %s \"%s\" skall hanteras"
 
-#: ref-filter.c:266
+#: merge-recursive.c:1199
 #, c-format
-msgid "unrecognized %%(contents) argument: %s"
-msgstr "okänt %%(contents)-argument: %s"
+msgid "Failed to merge submodule %s (not checked out)"
+msgstr "Misslyckades slå ihop undermodulen %s (ej utcheckad)"
 
-#: ref-filter.c:281
+#: merge-recursive.c:1206
 #, c-format
-msgid "positive value expected objectname:short=%s"
-msgstr "positivt värde förväntat objectname:short=%s"
+msgid "Failed to merge submodule %s (commits not present)"
+msgstr "Misslyckades slå ihop undermodulen %s (incheckningar saknas)"
 
-#: ref-filter.c:285
+#: merge-recursive.c:1213
 #, c-format
-msgid "unrecognized %%(objectname) argument: %s"
-msgstr "okänt %%(objectname)-argument: %s"
+msgid "Failed to merge submodule %s (commits don't follow merge-base)"
+msgstr ""
+"Misslyckades slå ihop undermodulen %s (incheckningar följer inte "
+"sammanslagningsbasen)"
 
-#: ref-filter.c:315
+#: merge-recursive.c:1221 merge-recursive.c:1233
 #, c-format
-msgid "expected format: %%(align:<width>,<position>)"
-msgstr "förväntat format: %%(align:<bredd>,<position>)"
+msgid "Fast-forwarding submodule %s to the following commit:"
+msgstr "Snabbspolar undermodulen %s till följande incheckning:"
 
-#: ref-filter.c:327
+#: merge-recursive.c:1224 merge-recursive.c:1236
 #, c-format
-msgid "unrecognized position:%s"
-msgstr "okänd position:%s"
+msgid "Fast-forwarding submodule %s"
+msgstr "Snabbspolar undermodulen %s"
 
-#: ref-filter.c:334
+#: merge-recursive.c:1259
 #, c-format
-msgid "unrecognized width:%s"
-msgstr "okänd bredd:%s"
+msgid "Failed to merge submodule %s (merge following commits not found)"
+msgstr ""
+"Misslyckades slå ihop undermodulen %s (sammanslagning efter incheckningar "
+"hittades inte)"
 
-#: ref-filter.c:343
+#: merge-recursive.c:1263
 #, c-format
-msgid "unrecognized %%(align) argument: %s"
-msgstr "okänt %%(align)-argument: %s"
+msgid "Failed to merge submodule %s (not fast-forward)"
+msgstr "Misslyckades slå ihop undermodulen %s (ej snabbspolning)"
 
-#: ref-filter.c:351
-#, c-format
-msgid "positive width expected with the %%(align) atom"
-msgstr "positiv bredd förväntad med atomen %%(align)"
+#: merge-recursive.c:1264
+msgid "Found a possible merge resolution for the submodule:\n"
+msgstr "Hittade en möjlig lösning av sammanslagning för undermodulen:\n"
 
-#: ref-filter.c:369
+#: merge-recursive.c:1267
 #, c-format
-msgid "unrecognized %%(if) argument: %s"
-msgstr "okänt %%(if)-argument: %s"
+msgid ""
+"If this is correct simply add it to the index for example\n"
+"by using:\n"
+"\n"
+"  git update-index --cacheinfo 160000 %s \"%s\"\n"
+"\n"
+"which will accept this suggestion.\n"
+msgstr ""
+"Om detta är riktigt lägger du bara till det i indexet, till\n"
+"exempel så här:\n"
+"\n"
+"  git update-index --cacheinfo 160000 %s \"%s\"\n"
+"\n"
+"vilket godtar lösningen.\n"
 
-#: ref-filter.c:464
+#: merge-recursive.c:1276
 #, c-format
-msgid "malformed field name: %.*s"
-msgstr "felformat fältnamn: %.*s"
+msgid "Failed to merge submodule %s (multiple merges found)"
+msgstr ""
+"Misslyckades slå ihop undermodulen %s (flera sammanslagningar hittades)"
 
-#: ref-filter.c:491
-#, c-format
-msgid "unknown field name: %.*s"
-msgstr "okänt fältnamn: %.*s"
+#: merge-recursive.c:1349
+msgid "Failed to execute internal merge"
+msgstr "Misslyckades exekvera intern sammanslagning"
 
-#: ref-filter.c:608
+#: merge-recursive.c:1354
 #, c-format
-msgid "format: %%(if) atom used without a %%(then) atom"
-msgstr "format: atomen %%(if) använd utan en %%(then)-atom"
+msgid "Unable to add %s to database"
+msgstr "Kunde inte lägga till %s till databasen"
 
-#: ref-filter.c:671
+#: merge-recursive.c:1386
 #, c-format
-msgid "format: %%(then) atom used without an %%(if) atom"
-msgstr "format: atomen %%(then) använd utan en %%(if)-atom"
+msgid "Auto-merging %s"
+msgstr "Slår ihop %s automatiskt"
 
-#: ref-filter.c:673
+#: merge-recursive.c:1410
 #, c-format
-msgid "format: %%(then) atom used more than once"
-msgstr "format: atomen %%(then) använd mer än en gång"
+msgid "Error: Refusing to lose untracked file at %s; writing to %s instead."
+msgstr "Fel: Vägrar förlora ospårad fil vid %s; skriver till %s istället."
 
-#: ref-filter.c:675
+#: merge-recursive.c:1482
 #, c-format
-msgid "format: %%(then) atom used after %%(else)"
-msgstr "format: atomen %%(then) använd efter %%(else)"
+msgid ""
+"CONFLICT (%s/delete): %s deleted in %s and %s in %s. Version %s of %s left "
+"in tree."
+msgstr ""
+"KONFLIKT (%s/radera): %s raderad i %s och %s i %s. Versionen %s av %s lämnad "
+"i trädet."
 
-#: ref-filter.c:703
+#: merge-recursive.c:1487
 #, c-format
-msgid "format: %%(else) atom used without an %%(if) atom"
-msgstr "format: atomen %%(else) använd utan en %%(if)-atom"
+msgid ""
+"CONFLICT (%s/delete): %s deleted in %s and %s to %s in %s. Version %s of %s "
+"left in tree."
+msgstr ""
+"KONFLIKT (%s/radera): %s raderad i %s och %s till %s i %s. Versionen %s av "
+"%s lämnad i trädet."
 
-#: ref-filter.c:705
+#: merge-recursive.c:1494
 #, c-format
-msgid "format: %%(else) atom used without a %%(then) atom"
-msgstr "format: atomen %%(else) använd utan en %%(then)-atom"
+msgid ""
+"CONFLICT (%s/delete): %s deleted in %s and %s in %s. Version %s of %s left "
+"in tree at %s."
+msgstr ""
+"KONFLIKT (%s/radera): %s raderad i %s och %s i %s. Versionen %s av %s lämnad "
+"i trädet vid %s."
 
-#: ref-filter.c:707
+#: merge-recursive.c:1499
 #, c-format
-msgid "format: %%(else) atom used more than once"
-msgstr "format: atomen %%(else) använd mer än en gång"
+msgid ""
+"CONFLICT (%s/delete): %s deleted in %s and %s to %s in %s. Version %s of %s "
+"left in tree at %s."
+msgstr ""
+"KONFLIKT (%s/radera): %s raderad i %s och %s till %s i %s. Versionen %s av "
+"%s lämnad i trädet vid %s."
 
-#: ref-filter.c:722
-#, c-format
-msgid "format: %%(end) atom used without corresponding atom"
-msgstr "format: atomen %%(end) använd utan motsvarande atom"
+#: merge-recursive.c:1534
+msgid "rename"
+msgstr "namnbyte"
 
-#: ref-filter.c:779
-#, c-format
-msgid "malformed format string %s"
-msgstr "felformad formatsträng %s"
+#: merge-recursive.c:1534
+msgid "renamed"
+msgstr "namnbytt"
 
-#: ref-filter.c:1387
+#: merge-recursive.c:1614 merge-recursive.c:2530 merge-recursive.c:3175
 #, c-format
-msgid "(no branch, rebasing %s)"
-msgstr "(ingen gren, ombaserar %s)"
+msgid "Refusing to lose dirty file at %s"
+msgstr "Vägrar förlora lortig fil vid \"%s\""
 
-#: ref-filter.c:1390
+#: merge-recursive.c:1624
 #, c-format
-msgid "(no branch, rebasing detached HEAD %s)"
-msgstr "(ingen gren, ombaserar frånkopplat HEAD %s)"
+msgid "Refusing to lose untracked file at %s, even though it's in the way."
+msgstr "Vägrar förlora ospårad fil vid %s, trots att den är i vägen."
 
-#: ref-filter.c:1393
+#: merge-recursive.c:1682
 #, c-format
-msgid "(no branch, bisect started on %s)"
-msgstr "(ingen gren, \"bisect\" startad på %s)"
+msgid "CONFLICT (rename/add): Rename %s->%s in %s.  Added %s in %s"
+msgstr "KONFLIKT (namnbyte/tillägg): Namnbyte %s->%s i %s. Lade till %s i %s"
 
-#. TRANSLATORS: make sure this matches "HEAD
-#. detached at " in wt-status.c
-#.
-#: ref-filter.c:1401
+#: merge-recursive.c:1713
 #, c-format
-msgid "(HEAD detached at %s)"
-msgstr "(HEAD frånkopplat vid %s)"
+msgid "%s is a directory in %s adding as %s instead"
+msgstr "%s är en katalog i %s lägger till som %s istället"
 
-#. TRANSLATORS: make sure this matches "HEAD
-#. detached from " in wt-status.c
-#.
-#: ref-filter.c:1408
+#: merge-recursive.c:1718
 #, c-format
-msgid "(HEAD detached from %s)"
-msgstr "(HEAD frånkopplat från %s)"
-
-#: ref-filter.c:1412
-msgid "(no branch)"
-msgstr "(ingen gren)"
+msgid "Refusing to lose untracked file at %s; adding as %s instead"
+msgstr "Vägrar förlora ospårad fil vid %s; lägger till som %s istället"
 
-#: ref-filter.c:1442
+#: merge-recursive.c:1737
 #, c-format
-msgid "missing object %s for %s"
-msgstr "objektet %s saknas för %s"
+msgid ""
+"CONFLICT (rename/rename): Rename \"%s\"->\"%s\" in branch \"%s\" rename \"%s"
+"\"->\"%s\" in \"%s\"%s"
+msgstr ""
+"KONFLIKT (namnbyte/namnbyte): Namnbyte \"%s\"->\"%s\" på grenen \"%s\" "
+"namnbyte \"%s\"->\"%s\" i \"%s\"%s"
 
-#: ref-filter.c:1445
-#, c-format
-msgid "parse_object_buffer failed on %s for %s"
-msgstr "parse_object_buffer misslyckades på %s för %s"
+#: merge-recursive.c:1742
+msgid " (left unresolved)"
+msgstr " (lämnad olöst)"
 
-#: ref-filter.c:1902
+#: merge-recursive.c:1851
 #, c-format
-msgid "malformed object at '%s'"
-msgstr "felformat objekt vid \"%s\""
+msgid "CONFLICT (rename/rename): Rename %s->%s in %s. Rename %s->%s in %s"
+msgstr ""
+"KONFLIKT (namnbyte/namnbyte): Namnbyte %s->%s i %s. Namnbyte %s->%s i %s"
 
-#: ref-filter.c:1984
+#: merge-recursive.c:2114
 #, c-format
-msgid "ignoring ref with broken name %s"
-msgstr "ignorerar referens med trasigt namn %s"
+msgid ""
+"CONFLICT (directory rename split): Unclear where to place %s because "
+"directory %s was renamed to multiple other directories, with no destination "
+"getting a majority of the files."
+msgstr ""
+"KONFLIKT (namnändrad delad katalog): Osäker på var %s skall placeras då "
+"katalogen %s bytte namn till flera andra kataloger, utan att någon "
+"destination fick en majoritet av filerna."
 
-#: ref-filter.c:1989
+#: merge-recursive.c:2146
 #, c-format
-msgid "ignoring broken ref %s"
-msgstr "ignorerar trasig referens %s"
+msgid ""
+"CONFLICT (implicit dir rename): Existing file/dir at %s in the way of "
+"implicit directory rename(s) putting the following path(s) there: %s."
+msgstr ""
+"KONFLIKT (implicit nämnändrad kat): Befintlig fil/kat vid %s är i vägen för "
+"implicit namnändrad(e) katalog(er) som lägger dit följande sökväg(ar): %s."
 
-#: ref-filter.c:2261
+#: merge-recursive.c:2156
 #, c-format
-msgid "format: %%(end) atom missing"
-msgstr "format: atomen %%(end) saknas"
+msgid ""
+"CONFLICT (implicit dir rename): Cannot map more than one path to %s; "
+"implicit directory renames tried to put these paths there: %s"
+msgstr ""
+"KONFLIKT (implicit namnändrad kat): Kan inte koppla mer än en sökväg till "
+"%s; implicita katalognamnändringar försökte lägga följande sökvägar där: %s"
 
-#: ref-filter.c:2365
+#: merge-recursive.c:2248
 #, c-format
-msgid "malformed object name %s"
-msgstr "felformat objektnamn %s"
+msgid ""
+"CONFLICT (rename/rename): Rename directory %s->%s in %s. Rename directory %s-"
+">%s in %s"
+msgstr ""
+"KONFLIKT (namnbyte/namnbyte): Namnbytt katalog %s->%s i %s. Namnbytt katalog "
+"%s->%s i %s"
 
-#: remote.c:605
+#: merge-recursive.c:2493
 #, c-format
-msgid "Cannot fetch both %s and %s to %s"
-msgstr "Kan inte hämta både %s och %s till %s"
+msgid ""
+"WARNING: Avoiding applying %s -> %s rename to %s, because %s itself was "
+"renamed."
+msgstr ""
+"VARNING: Undviker att applicera namnändring %s -> %s på %s, då %s själv har "
+"bytt namn."
 
-#: remote.c:609
+#: merge-recursive.c:3019
 #, c-format
-msgid "%s usually tracks %s, not %s"
-msgstr "%s spårar vanligtvis %s, inte %s"
+msgid "cannot read object %s"
+msgstr "kan inte läsa objektet %s"
 
-#: remote.c:613
+#: merge-recursive.c:3022
 #, c-format
-msgid "%s tracks both %s and %s"
-msgstr "%s spårar både %s och %s"
+msgid "object %s is not a blob"
+msgstr "objektet %s är inte en blob"
 
-#: remote.c:621
-msgid "Internal error"
-msgstr "Internt fel"
+#: merge-recursive.c:3086
+msgid "modify"
+msgstr "ändra"
 
-#: remote.c:1534 remote.c:1635
-msgid "HEAD does not point to a branch"
-msgstr "HEAD pekar inte på en gren"
+#: merge-recursive.c:3086
+msgid "modified"
+msgstr "ändrad"
 
-#: remote.c:1543
-#, c-format
-msgid "no such branch: '%s'"
-msgstr "okänd gren: \"%s\""
+#: merge-recursive.c:3098
+msgid "content"
+msgstr "innehåll"
+
+#: merge-recursive.c:3102
+msgid "add/add"
+msgstr "tillägg/tillägg"
 
-#: remote.c:1546
+#: merge-recursive.c:3125
 #, c-format
-msgid "no upstream configured for branch '%s'"
-msgstr "ingen standarduppström angiven för grenen \"%s\""
+msgid "Skipped %s (merged same as existing)"
+msgstr "Hoppade över %s (sammanslagen samma som befintlig)"
+
+#: merge-recursive.c:3147 git-submodule.sh:993
+msgid "submodule"
+msgstr "undermodul"
 
-#: remote.c:1552
+#: merge-recursive.c:3148
 #, c-format
-msgid "upstream branch '%s' not stored as a remote-tracking branch"
-msgstr "uppströmsgrenen \"%s\" är inte lagrad som en fjärrspårande gren"
+msgid "CONFLICT (%s): Merge conflict in %s"
+msgstr "KONFLIKT (%s): Sammanslagningskonflikt i %s"
 
-#: remote.c:1567
+#: merge-recursive.c:3178
 #, c-format
-msgid "push destination '%s' on remote '%s' has no local tracking branch"
-msgstr "push-målet \"%s\" på fjärren \"%s\" har ingen lokalt spårande gren"
+msgid "Adding as %s instead"
+msgstr "Lägger till som %s istället"
 
-#: remote.c:1579
+#: merge-recursive.c:3261
 #, c-format
-msgid "branch '%s' has no remote for pushing"
-msgstr "grenen \"%s\" har ingen fjärr för \"push\""
+msgid ""
+"Path updated: %s added in %s inside a directory that was renamed in %s; "
+"moving it to %s."
+msgstr ""
+"Uppdaterad sökväg: %s lade till %s inuti en katalog som bytte namn i %s; "
+"flyttar den till %s."
 
-#: remote.c:1589
+#: merge-recursive.c:3264
 #, c-format
-msgid "push refspecs for '%s' do not include '%s'"
-msgstr "\"push\"-referensspecifikation för \"%s\" innehåller inte \"%s\""
+msgid ""
+"CONFLICT (file location): %s added in %s inside a directory that was renamed "
+"in %s, suggesting it should perhaps be moved to %s."
+msgstr ""
+"KONFLIKT (filplacering): %s lade till %s inuti en katalog som bytte namn i "
+"%s, föreslår att den bör flyttas till%s."
 
-#: remote.c:1602
-msgid "push has no destination (push.default is 'nothing')"
-msgstr "\"push\" har inget mål (push.default är \"ingenting\")"
+#: merge-recursive.c:3268
+#, c-format
+msgid ""
+"Path updated: %s renamed to %s in %s, inside a directory that was renamed in "
+"%s; moving it to %s."
+msgstr ""
+"Uppdaterad sökväg: %s bytte namn till %s i %s, inuti en katalog som bytte "
+"namn i %s; flyttar den till %s."
 
-#: remote.c:1624
-msgid "cannot resolve 'simple' push to a single destination"
-msgstr "\"enkel push\" motsvarar flera olika mål"
+#: merge-recursive.c:3271
+#, c-format
+msgid ""
+"CONFLICT (file location): %s renamed to %s in %s, inside a directory that "
+"was renamed in %s, suggesting it should perhaps be moved to %s."
+msgstr ""
+"KONFLIKT (filplacering): %s bytte namn till %s i %s, inuti en katalog som "
+"bytte namn i %s; flyttar den till %s."
 
-#: remote.c:1939
+#: merge-recursive.c:3385
 #, c-format
-msgid "Your branch is based on '%s', but the upstream is gone.\n"
-msgstr "Din gren är baserad på \"%s\", men den har försvunnit uppströms.\n"
+msgid "Removing %s"
+msgstr "Tar bort %s"
 
-#: remote.c:1943
-msgid "  (use \"git branch --unset-upstream\" to fixup)\n"
-msgstr "  (använd \"git branch --unset-upstream\" för att rätta)\n"
+#: merge-recursive.c:3408
+msgid "file/directory"
+msgstr "fil/katalog"
+
+#: merge-recursive.c:3413
+msgid "directory/file"
+msgstr "katalog/fil"
 
-#: remote.c:1946
+#: merge-recursive.c:3420
 #, c-format
-msgid "Your branch is up to date with '%s'.\n"
-msgstr "Din gren är à jour med \"%s\".\n"
+msgid "CONFLICT (%s): There is a directory with name %s in %s. Adding %s as %s"
+msgstr ""
+"KONFLIKT (%s): Det finns en katalog med namnet %s i %s. Lägger till %s som %s"
 
-#: remote.c:1950
+#: merge-recursive.c:3429
 #, c-format
-msgid "Your branch and '%s' refer to different commits.\n"
-msgstr "Din gren och \"%s\" pekar på olika incheckningar.\n"
+msgid "Adding %s"
+msgstr "Lägger till %s"
 
-#: remote.c:1953
+#: merge-recursive.c:3438
 #, c-format
-msgid "  (use \"%s\" for details)\n"
-msgstr "  (använd \"%s\" för detaljer)\n"
+msgid "CONFLICT (add/add): Merge conflict in %s"
+msgstr "KONFLIKT (tillägg/tillägg): Sammanslagningskonflikt i %s"
+
+#: merge-recursive.c:3482
+msgid "Already up to date!"
+msgstr "Redan à jour!"
 
-#: remote.c:1957
+#: merge-recursive.c:3491
 #, c-format
-msgid "Your branch is ahead of '%s' by %d commit.\n"
-msgid_plural "Your branch is ahead of '%s' by %d commits.\n"
-msgstr[0] "Din gren ligger före \"%s\" med %d incheckning.\n"
-msgstr[1] "Din gren ligger före \"%s\" med %d incheckningar.\n"
+msgid "merging of trees %s and %s failed"
+msgstr "sammanslagning av träden %s och %s misslyckades"
 
-#: remote.c:1963
-msgid "  (use \"git push\" to publish your local commits)\n"
-msgstr "  (använd \"git push\" för att publicera dina lokala incheckningar)\n"
+#: merge-recursive.c:3595
+msgid "Merging:"
+msgstr "Slår ihop:"
 
-#: remote.c:1966
+#: merge-recursive.c:3608
 #, c-format
-msgid "Your branch is behind '%s' by %d commit, and can be fast-forwarded.\n"
-msgid_plural ""
-"Your branch is behind '%s' by %d commits, and can be fast-forwarded.\n"
-msgstr[0] ""
-"Din gren ligger efter \"%s\" med %d incheckning, och kan snabbspolas.\n"
-msgstr[1] ""
-"Din gren ligger efter \"%s\" med %d incheckningar, och kan snabbspolas.\n"
+msgid "found %u common ancestor:"
+msgid_plural "found %u common ancestors:"
+msgstr[0] "hittade %u gemensam förfader:"
+msgstr[1] "hittade %u gemensamma förfäder:"
 
-#: remote.c:1974
-msgid "  (use \"git pull\" to update your local branch)\n"
-msgstr "  (använd \"git pull\" för att uppdatera din lokala gren)\n"
+#: merge-recursive.c:3658
+msgid "merge returned no commit"
+msgstr "sammanslagningen returnerade ingen incheckning"
 
-#: remote.c:1977
+#: merge-recursive.c:3717
 #, c-format
 msgid ""
-"Your branch and '%s' have diverged,\n"
-"and have %d and %d different commit each, respectively.\n"
-msgid_plural ""
-"Your branch and '%s' have diverged,\n"
-"and have %d and %d different commits each, respectively.\n"
-msgstr[0] ""
-"Din gren och \"%s\" har divergerat,\n"
-"och har %d respektive %d olika incheckning.\n"
-msgstr[1] ""
-"Din gren och \"%s\" har divergerat,\n"
-"och har %d respektive %d olika incheckningar.\n"
+"Your local changes to the following files would be overwritten by merge:\n"
+"  %s"
+msgstr ""
+"Dina lokala ändringar av följande filer skulle skrivas över av "
+"sammanslagning:\n"
+"  %s"
 
-#: remote.c:1987
-msgid "  (use \"git pull\" to merge the remote branch into yours)\n"
-msgstr "  (använd \"git pull\" för att slå ihop fjärrgrenen med din egen)\n"
+#: merge-recursive.c:3814
+#, c-format
+msgid "Could not parse object '%s'"
+msgstr "Kunde inte tolka objektet \"%s\""
 
-#: revision.c:2289
-msgid "your current branch appears to be broken"
-msgstr "din nuvarande gren verkar vara trasig"
+#: merge-recursive.c:3832 builtin/merge.c:694 builtin/merge.c:874
+msgid "Unable to write index."
+msgstr "Kunde inte skriva indexet."
 
-#: revision.c:2292
+#: midx.c:68
 #, c-format
-msgid "your current branch '%s' does not have any commits yet"
-msgstr "din nuvarande gren \"%s\" innehåller ännu inte några incheckningar"
+msgid "multi-pack-index file %s is too small"
+msgstr "multi-pack-indexfilen %s är för liten"
 
-#: revision.c:2489
-msgid "--first-parent is incompatible with --bisect"
-msgstr "--first-parent är inkompatibelt med --bisect"
+#: midx.c:84
+#, c-format
+msgid "multi-pack-index signature 0x%08x does not match signature 0x%08x"
+msgstr "multi-pack-indexsignaturen 0x%08x stämmer inte med signaturen 0x%08x"
 
-#: run-command.c:728
-msgid "open /dev/null failed"
-msgstr "misslyckades öppna /dev/null"
+#: midx.c:89
+#, c-format
+msgid "multi-pack-index version %d not recognized"
+msgstr "multi-pack-indexversionen %d stöds inte"
 
-#: run-command.c:1271
+#: midx.c:94
 #, c-format
-msgid ""
-"The '%s' hook was ignored because it's not set as executable.\n"
-"You can disable this warning with `git config advice.ignoredHook false`."
-msgstr ""
-"Kroken \"%s\" ignorerades eftersom den inte är markerad som körbar.\n"
-"Du kan inaktivera varningen med \"git config advice.ignoredHook false\"."
+msgid "hash version %u does not match"
+msgstr "hash-versionen %u stämmer inte"
 
-#: send-pack.c:141
-msgid "unexpected flush packet while reading remote unpack status"
-msgstr "oväntat flush-paket vid läsning av fjärruppackningsstatus"
+#: midx.c:108
+msgid "invalid chunk offset (too large)"
+msgstr "felaktigt offset för stycke (för stort)"
 
-#: send-pack.c:143
-#, c-format
-msgid "unable to parse remote unpack status: %s"
-msgstr "kunde inte tolka fjärruppackningsstatus: %s"
+#: midx.c:132
+msgid "terminating multi-pack-index chunk id appears earlier than expected"
+msgstr "avslutande multi-pack-index-stycke-id förekommer tidigare än förväntat"
 
-#: send-pack.c:145
-#, c-format
-msgid "remote unpack failed: %s"
-msgstr "fjärruppackning misslyckades: %s"
+#: midx.c:145
+msgid "multi-pack-index missing required pack-name chunk"
+msgstr "multi-pack-index saknar krävd paketnamn-stycke"
 
-#: send-pack.c:308
-msgid "failed to sign the push certificate"
-msgstr "misslyckades underteckna push-certifikatet"
+#: midx.c:147
+msgid "multi-pack-index missing required OID fanout chunk"
+msgstr "multi-pack-index saknar krävt OID-utbredningsstycke"
 
-#: send-pack.c:421
-msgid "the receiving end does not support --signed push"
-msgstr "mottagarsidan stöder inte push med --signed"
+#: midx.c:149
+msgid "multi-pack-index missing required OID lookup chunk"
+msgstr "multi-pack-index saknar krävt OID-uppslagnignsstycke"
 
-#: send-pack.c:423
-msgid ""
-"not sending a push certificate since the receiving end does not support --"
-"signed push"
-msgstr ""
-"sänder inte push-certifikat eftersom mottagarsidan inte stlder push med --"
-"signed"
+#: midx.c:151
+msgid "multi-pack-index missing required object offsets chunk"
+msgstr "multi-pack-index saknar krävt objekt-offsetstycke"
 
-#: send-pack.c:435
-msgid "the receiving end does not support --atomic push"
-msgstr "mottagarsidan stöder inte push med --atomic"
+#: midx.c:165
+#, c-format
+msgid "multi-pack-index pack names out of order: '%s' before '%s'"
+msgstr "multi-pack-index-paketnamn i fel ordning: \"%s\" före \"%s\""
 
-#: send-pack.c:440
-msgid "the receiving end does not support push options"
-msgstr "mottagarsidan stöder inte push-flaggor"
+#: midx.c:210
+#, c-format
+msgid "bad pack-int-id: %u (%u total packs)"
+msgstr "bad pack-int-id: %u (%u paket totalt)"
+
+#: midx.c:260
+msgid "multi-pack-index stores a 64-bit offset, but off_t is too small"
+msgstr "multi-pack-index skriver 64-bitars offset, men off_t är för liten"
+
+#: midx.c:288
+msgid "error preparing packfile from multi-pack-index"
+msgstr "fel när paketfiler från multi-pack-index skulle förberedas"
 
-#: sequencer.c:175
+#: midx.c:472
 #, c-format
-msgid "invalid commit message cleanup mode '%s'"
-msgstr "felaktigt incheckningsmeddelandestädningsläge \"%s\""
+msgid "failed to add packfile '%s'"
+msgstr "misslyckades läsa paketfilen \"%s\""
 
-#: sequencer.c:275
+#: midx.c:478
 #, c-format
-msgid "could not delete '%s'"
-msgstr "kunde inte ta bort \"%s\""
+msgid "failed to open pack-index '%s'"
+msgstr "misslyckades öppna paketindexet \"%s\""
 
-#: sequencer.c:301
-msgid "revert"
-msgstr "revert"
+#: midx.c:538
+#, c-format
+msgid "failed to locate object %d in packfile"
+msgstr "misslyckades hitta objekt %d i paketfilen"
 
-#: sequencer.c:303
-msgid "cherry-pick"
-msgstr "cherry-pick"
+#: midx.c:842
+msgid "Adding packfiles to multi-pack-index"
+msgstr "Lägger till paketfiler till multi-pack-index"
 
-#: sequencer.c:305
-msgid "rebase -i"
-msgstr "rebase -i"
+#: midx.c:875
+#, c-format
+msgid "did not see pack-file %s to drop"
+msgstr "såg inte paketfilen %s som skulle kastas"
 
-#: sequencer.c:307
+#: midx.c:973
+msgid "Writing chunks to multi-pack-index"
+msgstr "Skriver stycken till multi-pack-index"
+
+#: midx.c:1052
 #, c-format
-msgid "Unknown action: %d"
-msgstr "Okänd funktion: %d"
+msgid "failed to clear multi-pack-index at %s"
+msgstr "misslyckades städa multi-pack-index på %s"
 
-#: sequencer.c:364
-msgid ""
-"after resolving the conflicts, mark the corrected paths\n"
-"with 'git add <paths>' or 'git rm <paths>'"
-msgstr ""
-"efter att ha löst konflikterna, markera de rättade sökvägarna\n"
-"med \"git add <sökvägar>\" eller \"git rm <sökvägar>\""
+#: midx.c:1108
+msgid "Looking for referenced packfiles"
+msgstr "Ser efter refererade packfiler"
 
-#: sequencer.c:367
+#: midx.c:1123
+#, c-format
 msgid ""
-"after resolving the conflicts, mark the corrected paths\n"
-"with 'git add <paths>' or 'git rm <paths>'\n"
-"and commit the result with 'git commit'"
+"oid fanout out of order: fanout[%d] = %<PRIx32> > %<PRIx32> = fanout[%d]"
 msgstr ""
-"efter att ha löst konflikterna, markera de rättade sökvägarna\n"
-"med \"git add <sökvägar>\" eller \"git rm <sökvägar>\"\n"
-"och checka in resultatet med \"git commit\""
+"oid-utbredning i fel ordning: fanout[%d] = %<PRIx32> > %<PRIx32> = fanout[%d]"
 
-#: sequencer.c:380 sequencer.c:2468
-#, c-format
-msgid "could not lock '%s'"
-msgstr "kunde inte låsa \"%s\""
+#: midx.c:1128
+msgid "Verifying OID order in multi-pack-index"
+msgstr "Bekräftar OID-ordning i multi-pack-index"
 
-#: sequencer.c:382 sequencer.c:2346 sequencer.c:2472 sequencer.c:2486
-#: sequencer.c:2694 sequencer.c:4336 sequencer.c:4399 wrapper.c:656
+#: midx.c:1137
 #, c-format
-msgid "could not write to '%s'"
-msgstr "kunde inte skriva till \"%s\""
+msgid "oid lookup out of order: oid[%d] = %s >= %s = oid[%d]"
+msgstr "oid-uppslagning i fel ordning: oid[%d] = %s >= %s = oid[%d]"
 
-#: sequencer.c:387
-#, c-format
-msgid "could not write eol to '%s'"
-msgstr "kunde inte skriva radslut till \"%s\""
+#: midx.c:1157
+msgid "Sorting objects by packfile"
+msgstr "Sorterar objekt efter packfil"
+
+#: midx.c:1164
+msgid "Verifying object offsets"
+msgstr "Bekräftar offset för objekt"
 
-#: sequencer.c:392 sequencer.c:2351 sequencer.c:2474 sequencer.c:2488
-#: sequencer.c:2702
+#: midx.c:1180
 #, c-format
-msgid "failed to finalize '%s'"
-msgstr "misslyckades färdigställa \"%s\""
+msgid "failed to load pack entry for oid[%d] = %s"
+msgstr "misslyckades läsa paketpost för oid[%d] = %s"
 
-#: sequencer.c:415 sequencer.c:804 sequencer.c:1493 sequencer.c:2371
-#: sequencer.c:2684 sequencer.c:2788 builtin/am.c:259 builtin/commit.c:727
-#: builtin/merge.c:1046
+#: midx.c:1186
 #, c-format
-msgid "could not read '%s'"
-msgstr "kunde inte läsa \"%s\""
+msgid "failed to load pack-index for packfile %s"
+msgstr "misslyckades läsa paketindex för paketfil %s"
 
-#: sequencer.c:441
+#: midx.c:1195
 #, c-format
-msgid "your local changes would be overwritten by %s."
-msgstr "dina lokala ändringar skulle skrivas över av %s."
-
-#: sequencer.c:445
-msgid "commit your changes or stash them to proceed."
-msgstr "checka in dina ändringar eller använd \"stash\" för att fortsätta."
+msgid "incorrect object offset for oid[%d] = %s: %<PRIx64> != %<PRIx64>"
+msgstr "felaktigt objekt-offset för oid[%d] = %s: %<PRIx64> != %<PRIx64>"
 
-#: sequencer.c:474
-#, c-format
-msgid "%s: fast-forward"
-msgstr "%s: snabbspola"
+#: midx.c:1220
+msgid "Counting referenced objects"
+msgstr "Räknar refererade objekt"
 
-#. TRANSLATORS: %s will be "revert", "cherry-pick" or
-#. "rebase -i".
-#.
-#: sequencer.c:563
-#, c-format
-msgid "%s: Unable to write new index file"
-msgstr "%s: Kunde inte skriva ny indexfil"
+#: midx.c:1230
+msgid "Finding and deleting unreferenced packfiles"
+msgstr "Ser efter och tar bort orefererade packfiler"
 
-#: sequencer.c:579
-msgid "unable to update cache tree"
-msgstr "kan inte uppdatera cacheträd"
+#: midx.c:1388
+msgid "could not start pack-objects"
+msgstr "kunde inte starta pack-objects"
 
-#: sequencer.c:592
-msgid "could not resolve HEAD commit"
-msgstr "kunde inte bestämma HEAD:s incheckning"
+#: midx.c:1407
+msgid "could not finish pack-objects"
+msgstr "kunde inte avsluta pack-objects"
 
-#: sequencer.c:749
+#: name-hash.c:537
 #, c-format
-msgid ""
-"you have staged changes in your working tree\n"
-"If these changes are meant to be squashed into the previous commit, run:\n"
-"\n"
-"  git commit --amend %s\n"
-"\n"
-"If they are meant to go into a new commit, run:\n"
-"\n"
-"  git commit %s\n"
-"\n"
-"In both cases, once you're done, continue with:\n"
-"\n"
-"  git rebase --continue\n"
-msgstr ""
-"du har köade ändringar i din arbetskatalog.\n"
-"Om ändringarna skall läggas in i föregående incheckning, kör:\n"
-"\n"
-"  git commit --amend %s\n"
-"\n"
-"Om de skall checkas in i en egen incheckning, kör:\n"
-"\n"
-"  git commit %s\n"
-"\n"
-"Oavsett vilket, när du är färdig fortsätter du med:\n"
-"\n"
-"  git rebase --continue\n"
+msgid "unable to create lazy_dir thread: %s"
+msgstr "misslyckades skapa lazy_dir-tråd: %s"
 
-#: sequencer.c:818
-msgid "writing root commit"
-msgstr "skriver rotincheckning"
-
-#: sequencer.c:1043
-msgid "'prepare-commit-msg' hook failed"
-msgstr "kroken \"prepare-commit-msg\" misslyckades"
+#: name-hash.c:559
+#, c-format
+msgid "unable to create lazy_name thread: %s"
+msgstr "misslyckades skapa lazy_name-tråd: %s"
 
-#: sequencer.c:1050
-msgid ""
-"Your name and email address were configured automatically based\n"
-"on your username and hostname. Please check that they are accurate.\n"
-"You can suppress this message by setting them explicitly. Run the\n"
-"following command and follow the instructions in your editor to edit\n"
-"your configuration file:\n"
-"\n"
-"    git config --global --edit\n"
-"\n"
-"After doing this, you may fix the identity used for this commit with:\n"
-"\n"
-"    git commit --amend --reset-author\n"
-msgstr ""
-"Ditt namn och e-postadress konfigurerades automatiskt baserat på\n"
-"ditt användar-id och värdnamn. Kontrollera att de är riktiga. Du\n"
-"kan förhindra det här meddelandet genom att ställa dem explicit.\n"
-"Kör följande kommandon och följ instruktionerna i textredigeraren\n"
-"för att redigera din konfigurationsfil:\n"
-"\n"
-"    git config --global --edit\n"
-"\n"
-"När du gjort det kan du rätta identiteten som användes för den här\n"
-"incheckningen med:\n"
-"\n"
-"    git commit --amend --reset-author\n"
+#: name-hash.c:565
+#, c-format
+msgid "unable to join lazy_name thread: %s"
+msgstr "misslyckades utföra join på lazy_name-tråd: %s"
 
-#: sequencer.c:1063
+#: notes-merge.c:277
+#, c-format
 msgid ""
-"Your name and email address were configured automatically based\n"
-"on your username and hostname. Please check that they are accurate.\n"
-"You can suppress this message by setting them explicitly:\n"
-"\n"
-"    git config --global user.name \"Your Name\"\n"
-"    git config --global user.email you@example.com\n"
-"\n"
-"After doing this, you may fix the identity used for this commit with:\n"
-"\n"
-"    git commit --amend --reset-author\n"
+"You have not concluded your previous notes merge (%s exists).\n"
+"Please, use 'git notes merge --commit' or 'git notes merge --abort' to "
+"commit/abort the previous merge before you start a new notes merge."
 msgstr ""
-"Ditt namn och e-postadress konfigurerades automatiskt baserat på\n"
-"ditt användar-id och värdnamn. Kontrollera att de är riktiga. Du\n"
-"kan förhindra det här meddelandet genom att ställa dem explicit:\n"
-"\n"
-"    git config --global user.name \"Ditt namn\"\n"
-"    git config --global user.email du@example.com\n"
-"\n"
-"När du gjort det kan du rätta identiteten som användes för den här\n"
-"incheckningen med:\n"
-"\n"
-"    git commit --amend --reset-author\n"
-
-#: sequencer.c:1103
-msgid "couldn't look up newly created commit"
-msgstr "kunde inte slå upp en precis skapad incheckning"
-
-#: sequencer.c:1105
-msgid "could not parse newly created commit"
-msgstr "kunde inte tolka en precis skapad incheckning"
-
-#: sequencer.c:1151
-msgid "unable to resolve HEAD after creating commit"
-msgstr "kunde inte bestämma HEAD efter att ha skapat incheckning"
-
-#: sequencer.c:1153
-msgid "detached HEAD"
-msgstr "frånkopplad HEAD"
-
-#: sequencer.c:1157
-msgid " (root-commit)"
-msgstr " (rotincheckning)"
-
-#: sequencer.c:1178
-msgid "could not parse HEAD"
-msgstr "kunde inte tolka HEAD"
+"Du har inte avslutat föregående antecknings-sammanslagning (%s finns).\n"
+"Använd \"git notes merge --commit\" eller \"git notes merge --abort\" för "
+"att checka in eller avbryta föregående sammanslagning innan du påbörjar en "
+"ny antecknings-sammanslagning."
 
-#: sequencer.c:1180
+#: notes-merge.c:284
 #, c-format
-msgid "HEAD %s is not a commit!"
-msgstr "HEAD %s är inte en incheckning!"
-
-#: sequencer.c:1184 builtin/commit.c:1528
-msgid "could not parse HEAD commit"
-msgstr "kunde inte tolka HEAD:s incheckning"
-
-#: sequencer.c:1235 sequencer.c:1832
-msgid "unable to parse commit author"
-msgstr "kunde inte tolka incheckningens författare"
+msgid "You have not concluded your notes merge (%s exists)."
+msgstr "Du har inte avslutat antecknings-sammanslagningen (%s finns)."
 
-#: sequencer.c:1245 builtin/am.c:1630 builtin/merge.c:645
-msgid "git write-tree failed to write a tree"
-msgstr "git write-tree misslyckades skriva ett träd"
+#: notes-utils.c:46
+msgid "Cannot commit uninitialized/unreferenced notes tree"
+msgstr "Kan inte checka in oinitierat/orefererat anteckningsträd"
 
-#: sequencer.c:1262 sequencer.c:1317
+#: notes-utils.c:105
 #, c-format
-msgid "unable to read commit message from '%s'"
-msgstr "kunde inte läsa incheckningsmeddelande från \"%s\""
-
-#: sequencer.c:1284 builtin/am.c:1650 builtin/commit.c:1631 builtin/merge.c:825
-#: builtin/merge.c:850
-msgid "failed to write commit object"
-msgstr "kunde inte skriva incheckningsobjekt"
+msgid "Bad notes.rewriteMode value: '%s'"
+msgstr "Felaktigt värde för notes.rewriteMode: '%s'"
 
-#: sequencer.c:1344
+#: notes-utils.c:115
 #, c-format
-msgid "could not parse commit %s"
-msgstr "kunde inte tolka incheckningen %s"
+msgid "Refusing to rewrite notes in %s (outside of refs/notes/)"
+msgstr "Vägrar skriva över anteckningar i %s (utanför refs/notes/)"
 
-#: sequencer.c:1349
+#. TRANSLATORS: The first %s is the name of
+#. the environment variable, the second %s is
+#. its value.
+#.
+#: notes-utils.c:145
 #, c-format
-msgid "could not parse parent commit %s"
-msgstr "kunde inte tolka föräldraincheckningen %s"
+msgid "Bad %s value: '%s'"
+msgstr "Felaktigt värde på %s: \"%s\""
 
-#: sequencer.c:1500 sequencer.c:1525
+#: object.c:53
 #, c-format
-msgid "This is a combination of %d commits."
-msgstr "Det här är en kombination av %d incheckningar."
+msgid "invalid object type \"%s\""
+msgstr "ogiltig objekttyp \"%s\""
 
-#: sequencer.c:1510 sequencer.c:4355
-msgid "need a HEAD to fixup"
-msgstr "behöver en HEAD-incheckning att rätta"
+#: object.c:173
+#, c-format
+msgid "object %s is a %s, not a %s"
+msgstr "objektet %s är en %s, inte en %s"
 
-#: sequencer.c:1512 sequencer.c:2729
-msgid "could not read HEAD"
-msgstr "kunde inte läsa HEAD"
+#: object.c:233
+#, c-format
+msgid "object %s has unknown type id %d"
+msgstr "objektet %s har okänd typ-id %d"
 
-#: sequencer.c:1514
-msgid "could not read HEAD's commit message"
-msgstr "kunde inte läsa HEAD:s incheckningsmeddelande"
+#: object.c:246
+#, c-format
+msgid "unable to parse object: %s"
+msgstr "kunde inte tolka objektet: %s"
 
-#: sequencer.c:1520
+#: object.c:266 object.c:277
 #, c-format
-msgid "cannot write '%s'"
-msgstr "kan inte skriva \"%s\""
+msgid "hash mismatch %s"
+msgstr "hashvärde stämmer inte överens %s"
 
-#: sequencer.c:1527 git-rebase--interactive.sh:457
-msgid "This is the 1st commit message:"
-msgstr "Det här är 1:a incheckningsmeddelandet:"
+#: packfile.c:641
+msgid "offset before end of packfile (broken .idx?)"
+msgstr "offset före slutet av packfilen (trasig .idx?)"
 
-#: sequencer.c:1535
+#: packfile.c:1888
 #, c-format
-msgid "could not read commit message of %s"
-msgstr "kunde inte läsa incheckningsmeddelande för %s"
+msgid "offset before start of pack index for %s (corrupt index?)"
+msgstr "offset före slutet av packindex för %s (trasigt index?)"
 
-#: sequencer.c:1542
+#: packfile.c:1892
 #, c-format
-msgid "This is the commit message #%d:"
-msgstr "Det här är incheckningsmeddelande %d:"
+msgid "offset beyond end of pack index for %s (truncated index?)"
+msgstr "offset borton slutet av packindex för %s (trunkerat index?)"
 
-#: sequencer.c:1548
+#: parse-options.c:38
 #, c-format
-msgid "The commit message #%d will be skipped:"
-msgstr "Incheckningsmeddelande %d kommer hoppas över:"
+msgid "%s requires a value"
+msgstr "%s behöver ett värde"
 
-#: sequencer.c:1553
+#: parse-options.c:73
 #, c-format
-msgid "unknown command: %d"
-msgstr "okänt kommando: %d"
-
-#: sequencer.c:1631
-msgid "your index file is unmerged."
-msgstr "din indexfil har inte slagits ihop."
+msgid "%s is incompatible with %s"
+msgstr "%s är inkompatibel med %s"
 
-#: sequencer.c:1638
-msgid "cannot fixup root commit"
-msgstr "kan inte göra \"fixup\" på rotincheckning"
+#: parse-options.c:78
+#, c-format
+msgid "%s : incompatible with something else"
+msgstr "%s: inkompatibelt med något annat"
 
-#: sequencer.c:1657
+#: parse-options.c:92 parse-options.c:96 parse-options.c:319
 #, c-format
-msgid "commit %s is a merge but no -m option was given."
-msgstr "incheckning %s är en sammanslagning, men flaggan -m angavs inte."
+msgid "%s takes no value"
+msgstr "%s tar inget värde"
 
-#: sequencer.c:1665
+#: parse-options.c:94
 #, c-format
-msgid "commit %s does not have parent %d"
-msgstr "incheckning %s har inte förälder %d"
+msgid "%s isn't available"
+msgstr "%s är inte tillgängligt"
 
-#: sequencer.c:1669
+#: parse-options.c:219
 #, c-format
-msgid "mainline was specified but commit %s is not a merge."
-msgstr "huvudlinje angavs, men incheckningen %s är inte en sammanslagning."
+msgid "%s expects a non-negative integer value with an optional k/m/g suffix"
+msgstr "%s förväntar ett icke-negativt heltalsvärde, med valfritt k/m/g-suffix"
 
-#: sequencer.c:1675
+#: parse-options.c:389
 #, c-format
-msgid "cannot get commit message for %s"
-msgstr "kan inte hämta incheckningsmeddelande för %s"
+msgid "ambiguous option: %s (could be --%s%s or --%s%s)"
+msgstr "tvetydig flagga: %s (kan vara --%s%s eller --%s%s)"
 
-#. TRANSLATORS: The first %s will be a "todo" command like
-#. "revert" or "pick", the second %s a SHA1.
-#: sequencer.c:1694
+#: parse-options.c:423 parse-options.c:431
 #, c-format
-msgid "%s: cannot parse parent commit %s"
-msgstr "%s: kan inte tolka föräldraincheckningen %s"
+msgid "did you mean `--%s` (with two dashes ?)"
+msgstr "menade du \"--%s\" (med två bindestreck?)"
 
-#: sequencer.c:1759
+#: parse-options.c:860
 #, c-format
-msgid "could not rename '%s' to '%s'"
-msgstr "kunde inte byta namn på \"%s\" till \"%s\""
+msgid "unknown option `%s'"
+msgstr "okänd flagga \"%s\""
 
-#: sequencer.c:1813
+#: parse-options.c:862
 #, c-format
-msgid "could not revert %s... %s"
-msgstr "kunde inte ångra %s... %s"
+msgid "unknown switch `%c'"
+msgstr "okänd flagga \"%c\""
 
-#: sequencer.c:1814
+#: parse-options.c:864
 #, c-format
-msgid "could not apply %s... %s"
-msgstr "kunde inte tillämpa %s... %s"
+msgid "unknown non-ascii option in string: `%s'"
+msgstr "okänd icke-ascii-flagga i strängen: \"%s\""
 
-#: sequencer.c:1864
-msgid "empty commit set passed"
-msgstr "den angivna uppsättningen incheckningar är tom"
+#: parse-options.c:888
+msgid "..."
+msgstr "..."
 
-#: sequencer.c:1874
+#: parse-options.c:907
 #, c-format
-msgid "git %s: failed to read the index"
-msgstr "git %s: misslyckades läsa indexet"
+msgid "usage: %s"
+msgstr "användning: %s"
 
-#: sequencer.c:1881
+#. TRANSLATORS: the colon here should align with the
+#. one in "usage: %s" translation.
+#.
+#: parse-options.c:913
 #, c-format
-msgid "git %s: failed to refresh the index"
-msgstr "git %s: misslyckades uppdatera indexet"
+msgid "   or: %s"
+msgstr "     eller: %s"
 
-#: sequencer.c:1961
+#: parse-options.c:916
 #, c-format
-msgid "%s does not accept arguments: '%s'"
-msgstr "%s tar inte argument: \"%s\""
+msgid "    %s"
+msgstr "    %s"
+
+#: parse-options.c:955
+msgid "-NUM"
+msgstr "-TAL"
 
-#: sequencer.c:1970
+#: parse-options.c:969
 #, c-format
-msgid "missing arguments for %s"
-msgstr "argument saknas för %s"
+msgid "alias of --%s"
+msgstr "alias för --%s"
 
-#: sequencer.c:2029
+#: parse-options-cb.c:20 parse-options-cb.c:24
 #, c-format
-msgid "invalid line %d: %.*s"
-msgstr "ogiltig rad %d: %.*s"
+msgid "option `%s' expects a numerical value"
+msgstr "flaggan \"%s\" antar ett numeriskt värde"
 
-#: sequencer.c:2037
+#: parse-options-cb.c:41
 #, c-format
-msgid "cannot '%s' without a previous commit"
-msgstr "kan inte utföra \"%s\" utan en föregående incheckning"
+msgid "malformed expiration date '%s'"
+msgstr "trasigt utlöpsdatum: \"%s\""
 
-#: sequencer.c:2085 sequencer.c:4138 sequencer.c:4173
+#: parse-options-cb.c:54
 #, c-format
-msgid "could not read '%s'."
-msgstr "kunde inte läsa \"%s\"."
+msgid "option `%s' expects \"always\", \"auto\", or \"never\""
+msgstr ""
+"flaggan \"%s\" antar \"always\" (alltid), \"auto\" eller \"never\" (aldrig)"
 
-#: sequencer.c:2108
-msgid "please fix this using 'git rebase --edit-todo'."
-msgstr "rätta det med \"git rebase --edit-todo\"."
+#: parse-options-cb.c:130 parse-options-cb.c:147
+#, c-format
+msgid "malformed object name '%s'"
+msgstr "felformat objektnamn \"%s\""
 
-#: sequencer.c:2110
+#: path.c:915
 #, c-format
-msgid "unusable instruction sheet: '%s'"
-msgstr "oanvändbart manus: ”%s”"
+msgid "Could not make %s writable by group"
+msgstr "Kunde inte göra %s skrivbar för gruppen"
 
-#: sequencer.c:2115
-msgid "no commits parsed."
-msgstr "inga incheckningar lästes."
+#: pathspec.c:130
+msgid "Escape character '\\' not allowed as last character in attr value"
+msgstr "Specialtecknet \"\\\" tillåts inte som sista tecken i attributvärde"
 
-#: sequencer.c:2126
-msgid "cannot cherry-pick during a revert."
-msgstr "kan inte utföra \"cherry-pick\" under en \"revert\"."
+#: pathspec.c:148
+msgid "Only one 'attr:' specification is allowed."
+msgstr "Endast en \"attr:\"-angivelse tillåten."
 
-#: sequencer.c:2128
-msgid "cannot revert during a cherry-pick."
-msgstr "kan inte utföra \"revert\" under en \"cherry-pick\"."
+#: pathspec.c:151
+msgid "attr spec must not be empty"
+msgstr "attr-angivelse kan inte vara tom"
 
-#: sequencer.c:2195
+#: pathspec.c:194
 #, c-format
-msgid "invalid key: %s"
-msgstr "felaktig nyckel: %s"
+msgid "invalid attribute name %s"
+msgstr "ogiltigt attributnamn %s"
 
-#: sequencer.c:2198
-#, c-format
-msgid "invalid value for %s: %s"
-msgstr "felaktigt värde för %s: %s"
+#: pathspec.c:259
+msgid "global 'glob' and 'noglob' pathspec settings are incompatible"
+msgstr ""
+"de globala sökvägsinställningarna \"glob\" och \"noglob\" är inkompatibla"
 
-#: sequencer.c:2269
-msgid "unusable squash-onto"
-msgstr "oanvändbar squash-onto"
+#: pathspec.c:266
+msgid ""
+"global 'literal' pathspec setting is incompatible with all other global "
+"pathspec settings"
+msgstr ""
+"den globala sökvägsinställningen \"literal\" är inkompatibel med alla andra "
+"globala sökvägsinställningar"
 
-#: sequencer.c:2285
-#, c-format
-msgid "malformed options sheet: '%s'"
-msgstr "trasigt manus: ”%s”"
+#: pathspec.c:306
+msgid "invalid parameter for pathspec magic 'prefix'"
+msgstr "ogiltig parameter för sökvägsuttrycket för \"prefix\""
 
-#: sequencer.c:2323
-msgid "a cherry-pick or revert is already in progress"
-msgstr "en \"cherry-pick\" eller \"revert\" pågår redan"
+#: pathspec.c:327
+#, c-format
+msgid "Invalid pathspec magic '%.*s' in '%s'"
+msgstr "Felaktigt sökvägsuttryck \"%.*s\" i \"%s\""
 
-#: sequencer.c:2324
-msgid "try \"git cherry-pick (--continue | --quit | --abort)\""
-msgstr "testa \"git cherry-pick (--continue | --quit | --abort)\""
+#: pathspec.c:332
+#, c-format
+msgid "Missing ')' at the end of pathspec magic in '%s'"
+msgstr "\")\" saknas i slutet av sökvägsuttrycket för \"%s\""
 
-#: sequencer.c:2327
+#: pathspec.c:370
 #, c-format
-msgid "could not create sequencer directory '%s'"
-msgstr "kunde inte skapa \"sequencer\"-katalogen \"%s\""
+msgid "Unimplemented pathspec magic '%c' in '%s'"
+msgstr "Ej implementerat sökvägsuttryckmagi \"%c\" i \"%s\""
 
-#: sequencer.c:2341
-msgid "could not lock HEAD"
-msgstr "kunde inte låsa HEAD"
+#: pathspec.c:429
+#, c-format
+msgid "%s: 'literal' and 'glob' are incompatible"
+msgstr "%s: \"literal\" och \"glob\" är inkompatibla"
 
-#: sequencer.c:2396 sequencer.c:3403
-msgid "no cherry-pick or revert in progress"
-msgstr "ingen \"cherry-pick\" eller \"revert\" pågår"
+#: pathspec.c:442
+#, c-format
+msgid "%s: '%s' is outside repository"
+msgstr "%s: \"%s\" är utanför arkivet"
 
-#: sequencer.c:2398
-msgid "cannot resolve HEAD"
-msgstr "kan inte bestämma HEAD"
+#: pathspec.c:516
+#, c-format
+msgid "'%s' (mnemonic: '%c')"
+msgstr "\"%s\" (minnesstöd: \"%c\")"
 
-#: sequencer.c:2400 sequencer.c:2435
-msgid "cannot abort from a branch yet to be born"
-msgstr "kan inte avbryta från en gren som ännu inte är född"
+#: pathspec.c:526
+#, c-format
+msgid "%s: pathspec magic not supported by this command: %s"
+msgstr "%s: sökvägsuttrycket hanteras inte av det här kommandot: %s"
 
-#: sequencer.c:2421 builtin/grep.c:720
+#: pathspec.c:593
 #, c-format
-msgid "cannot open '%s'"
-msgstr "kan inte öppna \"%s\""
+msgid "pathspec '%s' is beyond a symbolic link"
+msgstr "sökvägsangivelsen \"%s\" är på andra sidan av en symbolisk länk"
 
-#: sequencer.c:2423
+#: pathspec.c:638
 #, c-format
-msgid "cannot read '%s': %s"
-msgstr "kan inte läsa \"%s\": %s"
+msgid "line is badly quoted: %s"
+msgstr "linjen er felaktigt citerad: %s"
 
-#: sequencer.c:2424
-msgid "unexpected end of file"
-msgstr "oväntat filslut"
+#: pkt-line.c:92
+msgid "unable to write flush packet"
+msgstr "kan inte skriva flush-paket"
 
-#: sequencer.c:2430
-#, c-format
-msgid "stored pre-cherry-pick HEAD file '%s' is corrupt"
-msgstr "sparad HEAD-fil från före \"cherry-pick\", \"%s\", är trasig"
+#: pkt-line.c:99
+msgid "unable to write delim packet"
+msgstr "kan inte skriva delim-paket"
 
-#: sequencer.c:2441
-msgid "You seem to have moved HEAD. Not rewinding, check your HEAD!"
-msgstr ""
-"Du verkar ha flyttat HEAD.\n"
-"Spolar inte tillbaka, kontrollera HEAD!"
+#: pkt-line.c:106
+msgid "flush packet write failed"
+msgstr "fel vid skrivning av \"flush\"-paket"
+
+#: pkt-line.c:146 pkt-line.c:232
+msgid "protocol error: impossibly long line"
+msgstr "protokollfel: omöjligt lång rad"
 
-#: sequencer.c:2545 sequencer.c:3321
+#: pkt-line.c:162 pkt-line.c:164
+msgid "packet write with format failed"
+msgstr "paketskrivning med format misslyckades"
+
+#: pkt-line.c:196
+msgid "packet write failed - data exceeds max packet size"
+msgstr "paketskrivning misslyckades - data överskrider maximal paketstorlek"
+
+#: pkt-line.c:203 pkt-line.c:210
+msgid "packet write failed"
+msgstr "paketskrivning misslyckades"
+
+#: pkt-line.c:295
+msgid "read error"
+msgstr "läsfel"
+
+#: pkt-line.c:303
+msgid "the remote end hung up unexpectedly"
+msgstr "fjärren lade på oväntat"
+
+#: pkt-line.c:331
 #, c-format
-msgid "could not update %s"
-msgstr "kunde inte uppdatera %s"
+msgid "protocol error: bad line length character: %.4s"
+msgstr "protokollfel: felaktig radlängdstecken: %.4s"
 
-#: sequencer.c:2583 sequencer.c:3301
-msgid "cannot read HEAD"
-msgstr "kan inte läsa HEAD"
+#: pkt-line.c:341 pkt-line.c:346
+#, c-format
+msgid "protocol error: bad line length %d"
+msgstr "protokollfel: felaktig radlängd: %d"
 
-#: sequencer.c:2618 sequencer.c:2622 builtin/difftool.c:639
+#: pkt-line.c:362
 #, c-format
-msgid "could not copy '%s' to '%s'"
-msgstr "kunde inte kopiera in \"%s\" till \"%s\""
+msgid "remote error: %s"
+msgstr "fjärrfel: %s"
 
-#: sequencer.c:2641
-msgid "could not read index"
-msgstr "kunde inte läsa indexet"
+#: preload-index.c:119
+msgid "Refreshing index"
+msgstr "Uppdaterar indexet"
 
-#: sequencer.c:2646
+#: preload-index.c:138
 #, c-format
-msgid ""
-"execution failed: %s\n"
-"%sYou can fix the problem, and then run\n"
-"\n"
-"  git rebase --continue\n"
-"\n"
-msgstr ""
-"körningen misslyckades: %s\n"
-"%sDu kan rätta problemet och sedan köra\n"
-"\n"
-"\tgit rebase --continue\n"
-"\n"
+msgid "unable to create threaded lstat: %s"
+msgstr "kunde inte skapa trådad lstat: %s"
 
-#: sequencer.c:2652
-msgid "and made changes to the index and/or the working tree\n"
-msgstr "och gjorde ändringar till indexet och/eller arbetskatalogen\n"
+#: pretty.c:981
+msgid "unable to parse --pretty format"
+msgstr "kunde inte tolka format för --pretty"
+
+#: promisor-remote.c:23
+msgid "Remote with no URL"
+msgstr "Fjärr utan URL"
 
-#: sequencer.c:2658
+#: promisor-remote.c:58
 #, c-format
-msgid ""
-"execution succeeded: %s\n"
-"but left changes to the index and/or the working tree\n"
-"Commit or stash your changes, and then run\n"
-"\n"
-"  git rebase --continue\n"
-"\n"
-msgstr ""
-"körningen lyckades: %s\n"
-"men lämnade kvar ändringar i indexet och/eller arbetskatalogen\n"
-"Checka in eller utför \"stash\" på ändringarna och kör sedan\n"
-"\n"
-"\tgit rebase --continue\n"
-"\n"
+msgid "promisor remote name cannot begin with '/': %s"
+msgstr "kontraktsfjärr kan inte börja med \"/\": %s"
 
-#: sequencer.c:2771
-msgid "writing fake root commit"
-msgstr "skriver fejkad rotincheckning"
+#: range-diff.c:75
+msgid "could not start `log`"
+msgstr "kunde inte starta \"log\""
 
-#: sequencer.c:2776
-msgid "writing squash-onto"
-msgstr "skriver squash-onto"
+#: range-diff.c:77
+msgid "could not read `log` output"
+msgstr "kunde inte läsa utdata från \"log\""
 
-#: sequencer.c:2811
+#: range-diff.c:96 sequencer.c:5163
 #, c-format
-msgid "failed to find tree of %s"
-msgstr "kunde inte hitta trädet för %s."
+msgid "could not parse commit '%s'"
+msgstr "kunde inte tolka incheckningen \"%s\""
 
-#: sequencer.c:2829
-msgid "could not write index"
-msgstr "kunde inte skriva indexet"
+#: range-diff.c:122
+#, c-format
+msgid "could not parse git header '%.*s'"
+msgstr "kunde inte tolka git-huvudet \"%.*s\""
 
-#: sequencer.c:2861
-msgid "cannot merge without a current revision"
-msgstr "kan inte slå ihop utan en aktuell incheckning"
+#: range-diff.c:285
+msgid "failed to generate diff"
+msgstr "misslyckades skapa diff"
 
-#: sequencer.c:2884
+#: range-diff.c:518 range-diff.c:520
 #, c-format
-msgid "could not resolve '%s'"
-msgstr "kunde inte upplösa \"%s\""
+msgid "could not parse log for '%s'"
+msgstr "kunde inte tolka loggen för \"%s\""
 
-#: sequencer.c:2906
+#: read-cache.c:680
 #, c-format
-msgid "could not get commit message of '%s'"
-msgstr "kunde inte läsa incheckningsmeddelande för \"%s\""
+msgid "will not add file alias '%s' ('%s' already exists in index)"
+msgstr "lägger inte till filalias \"%s\" (\"%s\" finns redan i indexet)"
+
+#: read-cache.c:696
+msgid "cannot create an empty blob in the object database"
+msgstr "kan inte skapa tom blob i objektdatabasen"
 
-#: sequencer.c:2916 sequencer.c:2941
+#: read-cache.c:718
 #, c-format
-msgid "could not write '%s'"
-msgstr "kunde inte skriva \"%s\""
+msgid "%s: can only add regular files, symbolic links or git-directories"
+msgstr ""
+"%s: kan bara lägga till vanliga filer, symboliska länkar och git-kataloger"
 
-#: sequencer.c:3005
+#: read-cache.c:723
 #, c-format
-msgid "could not even attempt to merge '%.*s'"
-msgstr "kunde inte ens försöka slå ihop \"%.*s\""
+msgid "'%s' does not have a commit checked out"
+msgstr "\"%s\" har inte någon utcheckad incheckning"
 
-#: sequencer.c:3021
-msgid "merge: Unable to write new index file"
-msgstr "sammanslagning: Kunde inte skriva ny indexfil"
+#: read-cache.c:775
+#, c-format
+msgid "unable to index file '%s'"
+msgstr "kan inte indexera filen \"%s\""
 
-#: sequencer.c:3088
+#: read-cache.c:794
 #, c-format
-msgid "Applied autostash.\n"
-msgstr "Tillämpade autostash.\n"
+msgid "unable to add '%s' to index"
+msgstr "kan inte lägga till \"%s\" till indexet"
 
-#: sequencer.c:3100
+#: read-cache.c:805
 #, c-format
-msgid "cannot store %s"
-msgstr "kan inte spara %s"
+msgid "unable to stat '%s'"
+msgstr "kan inte ta status på \"%s\""
+
+#: read-cache.c:1325
+#, c-format
+msgid "'%s' appears as both a file and as a directory"
+msgstr "\"%s\" finns både som en fil och en katalog"
+
+#: read-cache.c:1531
+msgid "Refresh index"
+msgstr "Uppdatera indexet"
 
-#: sequencer.c:3103 git-rebase.sh:188
+#: read-cache.c:1646
 #, c-format
 msgid ""
-"Applying autostash resulted in conflicts.\n"
-"Your changes are safe in the stash.\n"
-"You can run \"git stash pop\" or \"git stash drop\" at any time.\n"
+"index.version set, but the value is invalid.\n"
+"Using version %i"
 msgstr ""
-"Tillämpning av autostash gav konflikter.\n"
-"Dina ändringar är säkra i stashen.\n"
-"Du kan när som helst använda \"git stash pop\" eller \"git stash drop\".\n"
+"index.version satt, men värdet är ogiltigt.\n"
+"Använder version %i"
 
-#: sequencer.c:3134
+#: read-cache.c:1656
 #, c-format
 msgid ""
-"Could not execute the todo command\n"
-"\n"
-"    %.*s\n"
-"It has been rescheduled; To edit the command before continuing, please\n"
-"edit the todo list first:\n"
-"\n"
-"    git rebase --edit-todo\n"
-"    git rebase --continue\n"
+"GIT_INDEX_VERSION set, but the value is invalid.\n"
+"Using version %i"
 msgstr ""
-"Kunde inte köra todo-kommandot\n"
-"\n"
-"    %.*s\n"
-"Det har lagts tillbaka i kön; För att redigera kommandot innan du\n"
-"fortsätter, redigera först attgöra-listan:\n"
-"\n"
-"    git rebase --edit-todo\n"
-"    git rebase --continue\n"
+"GIT_INDEX_VERSION satt, men värdet är ogiltigt.\n"
+"Använder version %i"
 
-#: sequencer.c:3202
+#: read-cache.c:1712
 #, c-format
-msgid "Stopped at %s...  %.*s\n"
-msgstr "Stoppade på %s... %.*s\n"
+msgid "bad signature 0x%08x"
+msgstr "felaktig signatur 0x%08x"
 
-#: sequencer.c:3264
+#: read-cache.c:1715
 #, c-format
-msgid "unknown command %d"
-msgstr "okänt kommando %d"
+msgid "bad index version %d"
+msgstr "felaktig indexversion %d"
 
-#: sequencer.c:3309
-msgid "could not read orig-head"
-msgstr "kunde inte läsa orig-head"
+#: read-cache.c:1724
+msgid "bad index file sha1 signature"
+msgstr "felaktig sha1-signatur för indexfil"
 
-#: sequencer.c:3314 sequencer.c:4352
-msgid "could not read 'onto'"
-msgstr "kunde inte läsa \"onto\""
+#: read-cache.c:1754
+#, c-format
+msgid "index uses %.4s extension, which we do not understand"
+msgstr "index använder filtillägget %.4s, vilket vi inte förstår"
 
-#: sequencer.c:3328
+#: read-cache.c:1756
 #, c-format
-msgid "could not update HEAD to %s"
-msgstr "kunde inte uppdatera HEAD till %s"
+msgid "ignoring %.4s extension"
+msgstr "ignorerar filtillägget %.4s"
 
-#: sequencer.c:3414
-msgid "cannot rebase: You have unstaged changes."
-msgstr "kan inte ombasera: Du har oköade ändringar."
+#: read-cache.c:1793
+#, c-format
+msgid "unknown index entry format 0x%08x"
+msgstr "okänt format 0x%08x på indexpost"
 
-#: sequencer.c:3423
-msgid "cannot amend non-existing commit"
-msgstr "kan inte lägga till incheckning som inte finns"
+#: read-cache.c:1809
+#, c-format
+msgid "malformed name field in the index, near path '%s'"
+msgstr "felformat namnfält i indexet, nära sökvägen \"%s\""
+
+#: read-cache.c:1866
+msgid "unordered stage entries in index"
+msgstr "osorterade köposter i index"
 
-#: sequencer.c:3425
+#: read-cache.c:1869
 #, c-format
-msgid "invalid file: '%s'"
-msgstr "ogiltig fil: \"%s\""
+msgid "multiple stage entries for merged file '%s'"
+msgstr "flera köposter för den sammanslagna filen \"%s\""
 
-#: sequencer.c:3427
+#: read-cache.c:1872
 #, c-format
-msgid "invalid contents: '%s'"
-msgstr "ogiltigt innehåll: \"%s\""
+msgid "unordered stage entries for '%s'"
+msgstr "osorterade köposter för \"%s\""
 
-#: sequencer.c:3430
-msgid ""
-"\n"
-"You have uncommitted changes in your working tree. Please, commit them\n"
-"first and then run 'git rebase --continue' again."
-msgstr ""
-"\n"
-"Du har ändringar i arbetskatalogen som inte checkats in. Checka in dem\n"
-"först och kör sedan \"git rebase --continute\" igen."
+#: read-cache.c:1978 read-cache.c:2266 rerere.c:565 rerere.c:599 rerere.c:1111
+#: builtin/add.c:499 builtin/check-ignore.c:178 builtin/checkout.c:470
+#: builtin/checkout.c:654 builtin/clean.c:967 builtin/commit.c:367
+#: builtin/diff-tree.c:120 builtin/grep.c:499 builtin/mv.c:145
+#: builtin/reset.c:246 builtin/rm.c:271 builtin/submodule--helper.c:332
+msgid "index file corrupt"
+msgstr "indexfilen trasig"
 
-#: sequencer.c:3455 sequencer.c:3493
+#: read-cache.c:2119
 #, c-format
-msgid "could not write file: '%s'"
-msgstr "kunde inte skriva fil: \"%s\""
+msgid "unable to create load_cache_entries thread: %s"
+msgstr "kunde inte läsa in cache_entries-tråden: %s"
 
-#: sequencer.c:3508
-msgid "could not remove CHERRY_PICK_HEAD"
-msgstr "kunde inte ta bort CHERRY_PICK_HEAD"
+#: read-cache.c:2132
+#, c-format
+msgid "unable to join load_cache_entries thread: %s"
+msgstr "kunde inte utföra join på cache_entries-tråden: %s"
 
-#: sequencer.c:3515
-msgid "could not commit staged changes."
-msgstr "kunde inte checka in köade ändringar."
+#: read-cache.c:2165
+#, c-format
+msgid "%s: index file open failed"
+msgstr "%s: öppning av indexfilen misslyckades"
 
-#: sequencer.c:3612
+#: read-cache.c:2169
 #, c-format
-msgid "%s: can't cherry-pick a %s"
-msgstr "%s: kan inte göra \"cherry-pick\" på typen ”%s”"
+msgid "%s: cannot stat the open index"
+msgstr "%s: kan inte ta startus på det öppna indexet"
 
-#: sequencer.c:3616
+#: read-cache.c:2173
 #, c-format
-msgid "%s: bad revision"
-msgstr "%s: felaktig revision"
+msgid "%s: index file smaller than expected"
+msgstr "%s: indexfilen mindre än förväntat"
 
-#: sequencer.c:3649
-msgid "can't revert as initial commit"
-msgstr "kan inte ångra som första incheckning"
+#: read-cache.c:2177
+#, c-format
+msgid "%s: unable to map index file"
+msgstr "%s: kan inte koppla indexfilen"
 
-#: sequencer.c:4098
-msgid "make_script: unhandled options"
-msgstr "make_script: flaggor som inte stöds"
+#: read-cache.c:2219
+#, c-format
+msgid "unable to create load_index_extensions thread: %s"
+msgstr "kunde inte skapa load_index_extensions-tråden: %s"
 
-#: sequencer.c:4101
-msgid "make_script: error preparing revisions"
-msgstr "make_script: fel när revisioner skulle förberedas"
+#: read-cache.c:2246
+#, c-format
+msgid "unable to join load_index_extensions thread: %s"
+msgstr "kunde inte utföra join på load_index_extensions-tråden: %s"
 
-#: sequencer.c:4142 sequencer.c:4177
+#: read-cache.c:2278
 #, c-format
-msgid "unusable todo list: '%s'"
-msgstr "oanvändbar todo-lista: %s"
+msgid "could not freshen shared index '%s'"
+msgstr "kunde inte uppdatera delat index \"%s\""
 
-#: sequencer.c:4236
+#: read-cache.c:2325
 #, c-format
-msgid ""
-"unrecognized setting %s for option rebase.missingCommitsCheck. Ignoring."
-msgstr ""
-"okänd inställning %s för flaggan rebase.missingCommitsCheck. Ignorerar."
+msgid "broken index, expect %s in %s, got %s"
+msgstr "trasigt index, förväntade %s i %s, fick %s"
 
-#: sequencer.c:4302
+#: read-cache.c:3021 strbuf.c:1145 wrapper.c:622 builtin/merge.c:1119
 #, c-format
-msgid ""
-"Warning: some commits may have been dropped accidentally.\n"
-"Dropped commits (newer to older):\n"
-msgstr ""
-"Varning: vissa incheckningar kan av misstag ha tappats.\n"
-"Tappade incheckningar (nyaste först):\n"
+msgid "could not close '%s'"
+msgstr "kunde inte stänga \"%s\""
 
-#: sequencer.c:4309
+#: read-cache.c:3124 sequencer.c:2429 sequencer.c:4069
 #, c-format
-msgid ""
-"To avoid this message, use \"drop\" to explicitly remove a commit.\n"
-"\n"
-"Use 'git config rebase.missingCommitsCheck' to change the level of "
-"warnings.\n"
-"The possible behaviours are: ignore, warn, error.\n"
+msgid "could not stat '%s'"
+msgstr "kunde inte ta status på \"%s\""
+
+#: read-cache.c:3137
+#, c-format
+msgid "unable to open git dir: %s"
+msgstr "kunde inte öppna git-katalog: %s"
+
+#: read-cache.c:3149
+#, c-format
+msgid "unable to unlink: %s"
+msgstr "misslyckades ta bort länken: %s"
+
+#: read-cache.c:3174
+#, c-format
+msgid "cannot fix permission bits on '%s'"
+msgstr "kan inte rätta behörighetsbitar på \"%s\""
+
+#: read-cache.c:3323
+#, c-format
+msgid "%s: cannot drop to stage #0"
+msgstr "%s: kan inte återgå till kö 0"
+
+#: rebase-interactive.c:26
+#, c-format
+msgid ""
+"unrecognized setting %s for option rebase.missingCommitsCheck. Ignoring."
+msgstr ""
+"okänd inställning %s för flaggan rebase.missingCommitsCheck. Ignorerar."
+
+#: rebase-interactive.c:35
+msgid ""
+"\n"
+"Commands:\n"
+"p, pick <commit> = use commit\n"
+"r, reword <commit> = use commit, but edit the commit message\n"
+"e, edit <commit> = use commit, but stop for amending\n"
+"s, squash <commit> = use commit, but meld into previous commit\n"
+"f, fixup <commit> = like \"squash\", but discard this commit's log message\n"
+"x, exec <command> = run command (the rest of the line) using shell\n"
+"b, break = stop here (continue rebase later with 'git rebase --continue')\n"
+"d, drop <commit> = remove commit\n"
+"l, label <label> = label current HEAD with a name\n"
+"t, reset <label> = reset HEAD to a label\n"
+"m, merge [-C <commit> | -c <commit>] <label> [# <oneline>]\n"
+".       create a merge commit using the original merge commit's\n"
+".       message (or the oneline, if no original merge commit was\n"
+".       specified). Use -c <commit> to reword the commit message.\n"
 "\n"
+"These lines can be re-ordered; they are executed from top to bottom.\n"
 msgstr ""
-"För att undvika det här meddelandet kan du använda \"drop\" för att "
-"explicit\n"
-"kasta en incheckning.\n"
 "\n"
-"Använd \"git config rebase.missingCommitsCheck\" för att ändra "
-"varningsnivån.\n"
-"Möjliga bettenden är: \"ignore\" (ignorera), \"warn\" (varna), \"error"
-"\" (fel).\n"
+"Kommandon:\n"
+"p, pick <incheckning> = använd incheckning\n"
+"r, reword <incheckning> = använd incheckning, men redigera "
+"incheckningsmeddelandet\n"
+"e, edit <incheckning> = använd incheckning, men stanna för tillägg\n"
+"s, squash <incheckning> = använd incheckning, men infoga i föregående "
+"incheckning\n"
+"f, fixup <incheckning> = som \"squash\", men förkasta "
+"incheckningsmeddelandet\n"
+"x, exec <kommando> = kör kommando (resten av raden) i skalet\n"
+"b, break = stoppa här (fortsätt ombaseringen senare med \"git rebase --"
+"continue\")\n"
+"d, drop <incheckning> = ta bort incheckning\n"
+"l, label <etikett> = ge aktuellt HEAD ett namn\n"
+"t, reset <etikett> = återställ HEAD till en etikett\n"
+"m, merge [-C <incheckning> | -c <incheckning>] <etikett> [# <enrads>]\n"
+".       skapa en sammanslagning med ursprungligt meddelande (eller\n"
+".       enrads, om inget incheckningsmeddelande angavs). Använd\n"
+".       -v <incheckning> för att skriva om meddelandet.\n"
 "\n"
+"Du kan byta ordning på raderna; de utförs uppifrån och ned.\n"
 
-#: sequencer.c:4321
+#: rebase-interactive.c:56
 #, c-format
+msgid "Rebase %s onto %s (%d command)"
+msgid_plural "Rebase %s onto %s (%d commands)"
+msgstr[0] "Ombasera %s på %s (%d kommando)"
+msgstr[1] "Ombasera %s på %s (%d kommandon)"
+
+#: rebase-interactive.c:65 git-rebase--preserve-merges.sh:228
 msgid ""
-"You can fix this with 'git rebase --edit-todo' and then run 'git rebase --"
-"continue'.\n"
-"Or you can abort the rebase with 'git rebase --abort'.\n"
+"\n"
+"Do not remove any line. Use 'drop' explicitly to remove a commit.\n"
 msgstr ""
-"Du kan rätta detta med \"git rebase --edit-todo\" följt av \"git rebase --"
-"continue\".\n"
-"Avbryt ombaseringen med \"git rebase --abort\".\n"
+"\n"
+"Ta inte bort rader. Använd \"drop\" för att specifikt förkasta en "
+"incheckning.\n"
 
-#: sequencer.c:4375
-#, c-format
-msgid "could not parse commit '%s'"
-msgstr "kunde inte tolka incheckningen\" %s\""
+#: rebase-interactive.c:68 git-rebase--preserve-merges.sh:232
+msgid ""
+"\n"
+"If you remove a line here THAT COMMIT WILL BE LOST.\n"
+msgstr ""
+"\n"
+"Om du tar bort en rad KOMMER DEN INCHECKNINGEN ATT FÖRLORAS.\n"
 
-#: sequencer.c:4490
-msgid "the script was already rearranged."
-msgstr "skriptet har redan omordnats."
+#: rebase-interactive.c:74 git-rebase--preserve-merges.sh:871
+msgid ""
+"\n"
+"You are editing the todo file of an ongoing interactive rebase.\n"
+"To continue rebase after editing, run:\n"
+"    git rebase --continue\n"
+"\n"
+msgstr ""
+"\n"
+"Du redigerar \"todo\"-filen för en pågående interaktiv ombasering.\n"
+"För att forsätta ombasera efter redigeringen, kör:\n"
+"    git rebase --continue\n"
+"\n"
+
+#: rebase-interactive.c:79 git-rebase--preserve-merges.sh:948
+msgid ""
+"\n"
+"However, if you remove everything, the rebase will be aborted.\n"
+"\n"
+msgstr ""
+"\n"
+"Ombaseringen kommer dock att avbrytas om du tar bort allting.\n"
+"\n"
+
+#: rebase-interactive.c:85 git-rebase--preserve-merges.sh:955
+msgid "Note that empty commits are commented out"
+msgstr "Observera att tomma incheckningar är utkommenterade"
 
-#: setup.c:123
+#: rebase-interactive.c:105 rerere.c:485 rerere.c:692 sequencer.c:3536
+#: sequencer.c:3562 sequencer.c:5263 builtin/fsck.c:346 builtin/rebase.c:254
 #, c-format
-msgid "'%s' is outside repository"
-msgstr "\"%s\" är utanför arkivet"
+msgid "could not write '%s'"
+msgstr "kunde inte skriva \"%s\""
 
-#: setup.c:172
+#: rebase-interactive.c:108
 #, c-format
-msgid ""
-"%s: no such path in the working tree.\n"
-"Use 'git <command> -- <path>...' to specify paths that do not exist locally."
-msgstr ""
-"%s: sökvägen finns inte i arbetskatalogen.\n"
-"Använd \"git <kommando> -- <sökväg>..\" för att ange sökvägar som inte finns "
-"lokalt."
+msgid "could not copy '%s' to '%s'."
+msgstr "kunde inte kopiera \"%s\" till \"%s\"."
 
-#: setup.c:185
+#: rebase-interactive.c:173
 #, c-format
 msgid ""
-"ambiguous argument '%s': unknown revision or path not in the working tree.\n"
-"Use '--' to separate paths from revisions, like this:\n"
-"'git <command> [<revision>...] -- [<file>...]'"
+"Warning: some commits may have been dropped accidentally.\n"
+"Dropped commits (newer to older):\n"
 msgstr ""
-"tvetydigt argument \"%s\": okänd revision eller sökväg inte i "
-"arbetskatalogen.\n"
-"Använd \"--\" för att skilja sökvägar från revisioner, så här:\n"
-"\"git <kommando> [<revision>...] -- [<fil>...]\""
-
-#: setup.c:234
-#, c-format
-msgid "option '%s' must come before non-option arguments"
-msgstr "flaggan \"%s\" måste anges före argument som inte är flaggor"
+"Varning: vissa incheckningar kan av misstag ha tappats.\n"
+"Tappade incheckningar (nyaste först):\n"
 
-#: setup.c:253
+#: rebase-interactive.c:180
 #, c-format
 msgid ""
-"ambiguous argument '%s': both revision and filename\n"
-"Use '--' to separate paths from revisions, like this:\n"
-"'git <command> [<revision>...] -- [<file>...]'"
+"To avoid this message, use \"drop\" to explicitly remove a commit.\n"
+"\n"
+"Use 'git config rebase.missingCommitsCheck' to change the level of "
+"warnings.\n"
+"The possible behaviours are: ignore, warn, error.\n"
+"\n"
 msgstr ""
-"tvetydigt argument \"%s\": både revision och filnamn\n"
-"Använd \"--\" för att skilja sökvägar från revisioner, så här:\n"
-"\"git <kommando> [<revision>...] -- [<fil>...]\""
+"För att undvika det här meddelandet kan du använda \"drop\" för att "
+"explicit\n"
+"kasta en incheckning.\n"
+"\n"
+"Använd \"git config rebase.missingCommitsCheck\" för att ändra "
+"varningsnivån.\n"
+"Möjliga bettenden är: \"ignore\" (ignorera), \"warn\" (varna), \"error"
+"\" (fel).\n"
+"\n"
 
-#: setup.c:389
-msgid "unable to set up work tree using invalid config"
-msgstr "kan inte skapa arbetskatalog med felaktig konfiguration"
+#: refs.c:262
+#, c-format
+msgid "%s does not point to a valid object!"
+msgstr "\"%s\" pekar inte på ett giltigt objekt!"
 
-#: setup.c:393
-msgid "this operation must be run in a work tree"
-msgstr "funktionen måste köras i en arbetskatalog"
+#: refs.c:667
+#, c-format
+msgid "ignoring dangling symref %s"
+msgstr "ignorerar dinglande symbolisk referens %s"
 
-#: setup.c:503
+#: refs.c:669 ref-filter.c:2098
 #, c-format
-msgid "Expected git repo version <= %d, found %d"
-msgstr "Förväntade git-arkivversion <= %d, hittade %d"
+msgid "ignoring broken ref %s"
+msgstr "ignorerar trasig referens %s"
 
-#: setup.c:511
-msgid "unknown repository extensions found:"
-msgstr "okända arkivutökningar hittades:"
+#: refs.c:804
+#, c-format
+msgid "could not open '%s' for writing: %s"
+msgstr "kunde inte öppna \"%s\" för skrivning: %s"
 
-#: setup.c:530
+#: refs.c:814 refs.c:865
 #, c-format
-msgid "error opening '%s'"
-msgstr "fel vid öppning av \"%s\""
+msgid "could not read ref '%s'"
+msgstr "Kunde inte läsa referensen \"%s\""
 
-#: setup.c:532
+#: refs.c:820
 #, c-format
-msgid "too large to be a .git file: '%s'"
-msgstr "för stor för att vara en .git-fil: \"%s\""
+msgid "ref '%s' already exists"
+msgstr "referensen \"%s\" finns redan"
 
-#: setup.c:534
+#: refs.c:825
 #, c-format
-msgid "error reading %s"
-msgstr "fel vid läsning av %s"
+msgid "unexpected object ID when writing '%s'"
+msgstr "oväntat objekt-id vid skrivning \"%s\""
 
-#: setup.c:536
+#: refs.c:833 sequencer.c:405 sequencer.c:2793 sequencer.c:2997
+#: sequencer.c:3011 sequencer.c:3269 sequencer.c:5179 strbuf.c:1142
+#: wrapper.c:620
 #, c-format
-msgid "invalid gitfile format: %s"
-msgstr "ogiltigt gitfilformat: %s"
+msgid "could not write to '%s'"
+msgstr "kunde inte skriva till \"%s\""
 
-#: setup.c:538
+#: refs.c:860 strbuf.c:1140 wrapper.c:188 wrapper.c:358 builtin/am.c:714
+#: builtin/rebase.c:1031
 #, c-format
-msgid "no path in gitfile: %s"
-msgstr "ingen sökväg i gitfil: %s"
+msgid "could not open '%s' for writing"
+msgstr "kunde inte öppna \"%s\" för skrivning"
 
-#: setup.c:540
+#: refs.c:867
 #, c-format
-msgid "not a git repository: %s"
-msgstr "inte ett git-arkiv: %s"
+msgid "unexpected object ID when deleting '%s'"
+msgstr "oväntat objekt-id vid borttagning \"%s\""
 
-#: setup.c:639
+#: refs.c:998
 #, c-format
-msgid "'$%s' too big"
-msgstr "\"$%s\" för stor"
+msgid "log for ref %s has gap after %s"
+msgstr "loggen för referensen %s har lucka efter %s"
 
-#: setup.c:653
+#: refs.c:1004
 #, c-format
-msgid "not a git repository: '%s'"
-msgstr "inte ett git-arkiv: \"%s\""
+msgid "log for ref %s unexpectedly ended on %s"
+msgstr "loggen för referensen %s slutade oväntat på %s"
 
-#: setup.c:682 setup.c:684 setup.c:715
+#: refs.c:1063
 #, c-format
-msgid "cannot chdir to '%s'"
-msgstr "kan inte byta katalog (chdir) till \"%s\""
+msgid "log for %s is empty"
+msgstr "loggen för %s är tom"
 
-#: setup.c:687 setup.c:743 setup.c:753 setup.c:792 setup.c:800 setup.c:815
-msgid "cannot come back to cwd"
-msgstr "kan inte gå tillbaka till arbetskatalogen (cwd)"
+#: refs.c:1155
+#, c-format
+msgid "refusing to update ref with bad name '%s'"
+msgstr "vägrar uppdatera referens med trasigt namn \"%s\""
 
-#: setup.c:813
+#: refs.c:1231
 #, c-format
-msgid "not a git repository (or any of the parent directories): %s"
-msgstr "inte ett git-arkiv (eller någon av föräldrakatalogerna): %s"
+msgid "update_ref failed for ref '%s': %s"
+msgstr "update_ref misslyckades för referensen \"%s\": %s"
 
-#: setup.c:824
+#: refs.c:2023
 #, c-format
-msgid "failed to stat '%*s%s%s'"
-msgstr "misslyckades ta status på \"%*ss%s%s\""
+msgid "multiple updates for ref '%s' not allowed"
+msgstr "flera uppdateringar för referensen \"%s\" tillåts inte"
 
-#: setup.c:1054
-msgid "Unable to read current working directory"
-msgstr "Kan inte läsa aktuell arbetskatalog"
+#: refs.c:2055
+msgid "ref updates forbidden inside quarantine environment"
+msgstr "referensuppdateringar förbjudna i karantänmiljö"
 
-#: setup.c:1066 setup.c:1072
+#: refs.c:2151 refs.c:2181
 #, c-format
-msgid "cannot change to '%s'"
-msgstr "kan inte byta till \"%s\""
+msgid "'%s' exists; cannot create '%s'"
+msgstr "\"%s\" finns; kan inte skapa \"%s\""
 
-#: setup.c:1085
+#: refs.c:2157 refs.c:2192
 #, c-format
-msgid ""
-"not a git repository (or any parent up to mount point %s)\n"
-"Stopping at filesystem boundary (GIT_DISCOVERY_ACROSS_FILESYSTEM not set)."
-msgstr ""
-"inte ett git-arkiv (eller någon av föräldrakatalogerna upp till "
-"monteringspunkten %s)\n"
-"Stoppar vid filsystemsgräns (GIT_DISCOVERY_ACROSS_FILESYSTEM är inte satt)."
+msgid "cannot process '%s' and '%s' at the same time"
+msgstr "kan inte hantera \"%s\" och \"%s\" samtidigt"
 
-#: setup.c:1168
+#: refs/files-backend.c:1234
 #, c-format
-msgid ""
-"problem with core.sharedRepository filemode value (0%.3o).\n"
-"The owner of files must always have read and write permissions."
-msgstr ""
-"problem med filläges-värdet i core.sharedRepository (0%.3o).\n"
-"Ägaren av filerna måste alltid ha läs- och skrivbehörighet."
+msgid "could not remove reference %s"
+msgstr "kunde inte ta bort referensen %s"
 
-#: setup.c:1211
-msgid "open /dev/null or dup failed"
-msgstr "misslyckades öppna /dev/null eller \"dup\""
+#: refs/files-backend.c:1248 refs/packed-backend.c:1541
+#: refs/packed-backend.c:1551
+#, c-format
+msgid "could not delete reference %s: %s"
+msgstr "kunde inte ta bort referensen %s: %s"
 
-#: setup.c:1226
-msgid "fork failed"
-msgstr "\"fork\" misslyckades"
+#: refs/files-backend.c:1251 refs/packed-backend.c:1554
+#, c-format
+msgid "could not delete references: %s"
+msgstr "kunde inte ta bort referenser: %s"
 
-#: setup.c:1231
-msgid "setsid failed"
-msgstr "\"setsid\" misslyckades"
+#: refspec.c:137
+#, c-format
+msgid "invalid refspec '%s'"
+msgstr "felaktig referensspecifikation: \"%s\""
 
-#: sha1-file.c:625
+#: ref-filter.c:42 wt-status.c:1938
+msgid "gone"
+msgstr "försvunnen"
+
+#: ref-filter.c:43
 #, c-format
-msgid "path '%s' does not exist"
-msgstr "sökvägen \"%s\" finns inte"
+msgid "ahead %d"
+msgstr "före %d"
 
-#: sha1-file.c:651
+#: ref-filter.c:44
 #, c-format
-msgid "reference repository '%s' as a linked checkout is not supported yet."
-msgstr "referensarkivet \"%s\" som en länkad utcheckning stöds inte ännu."
+msgid "behind %d"
+msgstr "bakom %d"
 
-#: sha1-file.c:657
+#: ref-filter.c:45
 #, c-format
-msgid "reference repository '%s' is not a local repository."
-msgstr "referensarkivet \"%s\" är inte ett lokalt arkiv."
+msgid "ahead %d, behind %d"
+msgstr "före %d, bakom %d"
 
-#: sha1-file.c:663
+#: ref-filter.c:165
 #, c-format
-msgid "reference repository '%s' is shallow"
-msgstr "referensarkivet \"%s\" är grunt"
+msgid "expected format: %%(color:<color>)"
+msgstr "förväntat format: %%(color:<color>)"
 
-#: sha1-file.c:671
+#: ref-filter.c:167
 #, c-format
-msgid "reference repository '%s' is grafted"
-msgstr "referensarkivet \"%s\" är ympat"
+msgid "unrecognized color: %%(color:%s)"
+msgstr "okänd färg: %%(color:%s)"
 
-#: sha1-name.c:442
+#: ref-filter.c:189
 #, c-format
-msgid "short SHA1 %s is ambiguous"
-msgstr "kort SHA1 %s är tvetydig"
+msgid "Integer value expected refname:lstrip=%s"
+msgstr "Heltalsvärde förväntades refname:lstrip=%s"
 
-#: sha1-name.c:453
-msgid "The candidates are:"
-msgstr "Kandidaterna är:"
+#: ref-filter.c:193
+#, c-format
+msgid "Integer value expected refname:rstrip=%s"
+msgstr "Heltalsvärde förväntades refname:rstrip=%s"
 
-#: sha1-name.c:695
-msgid ""
-"Git normally never creates a ref that ends with 40 hex characters\n"
-"because it will be ignored when you just specify 40-hex. These refs\n"
-"may be created by mistake. For example,\n"
-"\n"
-"  git checkout -b $br $(git rev-parse ...)\n"
-"\n"
-"where \"$br\" is somehow empty and a 40-hex ref is created. Please\n"
-"examine these refs and maybe delete them. Turn this message off by\n"
-"running \"git config advice.objectNameWarning false\""
-msgstr ""
-"Git skapar normalt aldrig referenser som slutar med 40 hexadecimala\n"
-"tecken, då detta ignoreras när du anger 40-hex enbart. Dessa\n"
-"referenser kan skapas av misstag. Till exempel, för\n"
-"\n"
-"  git checkout -b $br $(git rev-parse ...)\n"
-"\n"
-"där \"$br\" på något sätt blivit tomt och en 40-hex-referens skapats.\n"
-"Undersök referenserna och ta kanske bort dem. Stäng av meddelandet\n"
-"genom att köra \"git config advice.objectNameWarning false\""
+#: ref-filter.c:195
+#, c-format
+msgid "unrecognized %%(%s) argument: %s"
+msgstr "okänt %%(%s)-argument: %s"
 
-#: submodule.c:97 submodule.c:131
-msgid "Cannot change unmerged .gitmodules, resolve merge conflicts first"
-msgstr ""
-"Kan inte ändra .gitmodules-fil som inte slagits ihop, lös "
-"sammanslagningskonflikter först"
+#: ref-filter.c:250
+#, c-format
+msgid "%%(objecttype) does not take arguments"
+msgstr "%%(objecttype) tar inte argument"
 
-#: submodule.c:101 submodule.c:135
+#: ref-filter.c:272
 #, c-format
-msgid "Could not find section in .gitmodules where path=%s"
-msgstr "Hittade inte någon sektion i .gitmodules där sökväg=%s"
+msgid "unrecognized %%(objectsize) argument: %s"
+msgstr "okänt %%(objectsize)-argument: %s"
 
-#: submodule.c:109
+#: ref-filter.c:280
 #, c-format
-msgid "Could not update .gitmodules entry %s"
-msgstr "Kunde inte uppdatera .gitmodules-posten %s"
+msgid "%%(deltabase) does not take arguments"
+msgstr "%%(deltabase) tar inte argument"
 
-#: submodule.c:142
+#: ref-filter.c:292
 #, c-format
-msgid "Could not remove .gitmodules entry for %s"
-msgstr "Kunde inte ta bort .gitmodules-posten för %s"
+msgid "%%(body) does not take arguments"
+msgstr "%%(body) tar inte argument"
 
-#: submodule.c:153
-msgid "staging updated .gitmodules failed"
-msgstr "misslyckades köa uppdaterad .gitmodules"
+#: ref-filter.c:301
+#, c-format
+msgid "%%(subject) does not take arguments"
+msgstr "%%(subject) tar inte argument"
 
-#: submodule.c:315
+#: ref-filter.c:323
 #, c-format
-msgid "in unpopulated submodule '%s'"
-msgstr "i ej utcheckad undermodul \"%s\""
+msgid "unknown %%(trailers) argument: %s"
+msgstr "okänt %%(trailers)-argument: %s"
 
-#: submodule.c:346
+#: ref-filter.c:352
 #, c-format
-msgid "Pathspec '%s' is in submodule '%.*s'"
-msgstr "Sökvägsangivelsen \"%s\" är i undermodulen \"%.*s\""
+msgid "positive value expected contents:lines=%s"
+msgstr "positivt värde förväntat contents:lines=%s"
 
-#: submodule.c:837
+#: ref-filter.c:354
 #, c-format
-msgid "submodule entry '%s' (%s) is a %s, not a commit"
-msgstr "undermodulposten \"%s\" (%s) är en %s, inte en incheckning"
+msgid "unrecognized %%(contents) argument: %s"
+msgstr "okänt %%(contents)-argument: %s"
 
-#: submodule.c:1069 builtin/branch.c:651 builtin/submodule--helper.c:1743
-msgid "Failed to resolve HEAD as a valid ref."
-msgstr "Misslyckades slå upp HEAD som giltig referens."
+#: ref-filter.c:369
+#, c-format
+msgid "positive value expected objectname:short=%s"
+msgstr "positivt värde förväntat objectname:short=%s"
 
-#: submodule.c:1375
+#: ref-filter.c:373
 #, c-format
-msgid "'%s' not recognized as a git repository"
-msgstr "\"%s\" känns inte igen som ett git-arkiv"
+msgid "unrecognized %%(objectname) argument: %s"
+msgstr "okänt %%(objectname)-argument: %s"
 
-#: submodule.c:1513
+#: ref-filter.c:403
 #, c-format
-msgid "could not start 'git status' in submodule '%s'"
-msgstr "kunde inte starta \"git status\" i undermodulen \"%s\""
+msgid "expected format: %%(align:<width>,<position>)"
+msgstr "förväntat format: %%(align:<bredd>,<position>)"
 
-#: submodule.c:1526
+#: ref-filter.c:415
 #, c-format
-msgid "could not run 'git status' in submodule '%s'"
-msgstr "kunde inte köra \"git status\" i undermodulen \"%s\""
+msgid "unrecognized position:%s"
+msgstr "okänd position:%s"
 
-#: submodule.c:1619
+#: ref-filter.c:422
 #, c-format
-msgid "submodule '%s' has dirty index"
-msgstr "undermodulen \"%s\" har ett smutsigt index"
+msgid "unrecognized width:%s"
+msgstr "okänd bredd:%s"
 
-#: submodule.c:1718
+#: ref-filter.c:431
 #, c-format
-msgid ""
-"relocate_gitdir for submodule '%s' with more than one worktree not supported"
-msgstr ""
-"relocate_gitdir för undermodulen \"%s\", som har mer än en arbetskatalog, "
-"stöds ej"
+msgid "unrecognized %%(align) argument: %s"
+msgstr "okänt %%(align)-argument: %s"
 
-#: submodule.c:1730 submodule.c:1786
+#: ref-filter.c:439
 #, c-format
-msgid "could not lookup name for submodule '%s'"
-msgstr "kunde inte slå upp namnet för undermodulen \"%s\""
+msgid "positive width expected with the %%(align) atom"
+msgstr "positiv bredd förväntad med atomen %%(align)"
 
-#: submodule.c:1734 builtin/submodule--helper.c:1261
-#: builtin/submodule--helper.c:1271
+#: ref-filter.c:457
 #, c-format
-msgid "could not create directory '%s'"
-msgstr "kunde inte skapa katalogen \"%s\""
+msgid "unrecognized %%(if) argument: %s"
+msgstr "okänt %%(if)-argument: %s"
 
-#: submodule.c:1737
+#: ref-filter.c:559
+#, c-format
+msgid "malformed field name: %.*s"
+msgstr "felformat fältnamn: %.*s"
+
+#: ref-filter.c:586
+#, c-format
+msgid "unknown field name: %.*s"
+msgstr "okänt fältnamn: %.*s"
+
+#: ref-filter.c:590
 #, c-format
 msgid ""
-"Migrating git directory of '%s%s' from\n"
-"'%s' to\n"
-"'%s'\n"
+"not a git repository, but the field '%.*s' requires access to object data"
 msgstr ""
-"Migrerar git-katalogen för \"%s%s\" från\n"
-"\"%s\" till\n"
-"\"%s\"\n"
+"inte ett git-arkiv, men fältet \"%.*s\" kräver tillgång till objektdata"
 
-#: submodule.c:1821
+#: ref-filter.c:714
 #, c-format
-msgid "could not recurse into submodule '%s'"
-msgstr "kunde inte rekursera in i undermodulen \"%s\""
+msgid "format: %%(if) atom used without a %%(then) atom"
+msgstr "format: atomen %%(if) använd utan en %%(then)-atom"
 
-#: submodule.c:1865
-msgid "could not start ls-files in .."
-msgstr "kunde inte starta ls-files i .."
+#: ref-filter.c:777
+#, c-format
+msgid "format: %%(then) atom used without an %%(if) atom"
+msgstr "format: atomen %%(then) använd utan en %%(if)-atom"
 
-#: submodule.c:1904
+#: ref-filter.c:779
 #, c-format
-msgid "ls-tree returned unexpected return code %d"
-msgstr "ls-tree returnerade en oväntad returkod %d"
+msgid "format: %%(then) atom used more than once"
+msgstr "format: atomen %%(then) använd mer än en gång"
 
-#: submodule-config.c:230
+#: ref-filter.c:781
 #, c-format
-msgid "ignoring suspicious submodule name: %s"
-msgstr "ignorerar misstänkt undermodulnamn: %s"
+msgid "format: %%(then) atom used after %%(else)"
+msgstr "format: atomen %%(then) använd efter %%(else)"
 
-#: submodule-config.c:294
-msgid "negative values not allowed for submodule.fetchjobs"
-msgstr "negativa värden är inte tillåtna för submodule.fetchjobs"
+#: ref-filter.c:809
+#, c-format
+msgid "format: %%(else) atom used without an %%(if) atom"
+msgstr "format: atomen %%(else) använd utan en %%(if)-atom"
 
-#: submodule-config.c:467
+#: ref-filter.c:811
 #, c-format
-msgid "invalid value for %s"
-msgstr "ogiltigt värde för %s"
+msgid "format: %%(else) atom used without a %%(then) atom"
+msgstr "format: atomen %%(else) använd utan en %%(then)-atom"
 
-#: trailer.c:238
+#: ref-filter.c:813
 #, c-format
-msgid "running trailer command '%s' failed"
-msgstr "misslyckades utföra \"trailer\"-kommandot \"%s\""
+msgid "format: %%(else) atom used more than once"
+msgstr "format: atomen %%(else) använd mer än en gång"
 
-#: trailer.c:485 trailer.c:490 trailer.c:495 trailer.c:549 trailer.c:553
-#: trailer.c:557
+#: ref-filter.c:828
 #, c-format
-msgid "unknown value '%s' for key '%s'"
-msgstr "okänt värde \"%s\" för nyckeln \"%s\""
+msgid "format: %%(end) atom used without corresponding atom"
+msgstr "format: atomen %%(end) använd utan motsvarande atom"
 
-#: trailer.c:539 trailer.c:544 builtin/remote.c:293
+#: ref-filter.c:885
 #, c-format
-msgid "more than one %s"
-msgstr "mer än en %s"
+msgid "malformed format string %s"
+msgstr "felformad formatsträng %s"
 
-#: trailer.c:730
+#: ref-filter.c:1488
 #, c-format
-msgid "empty trailer token in trailer '%.*s'"
-msgstr "tom släpradssymbol i släpraden \"%.*s\""
+msgid "no branch, rebasing %s"
+msgstr "ingen gren, ombaserar %s"
 
-#: trailer.c:750
+#: ref-filter.c:1491
 #, c-format
-msgid "could not read input file '%s'"
-msgstr "kunde inte läsa indatafilen \"%s\""
+msgid "no branch, rebasing detached HEAD %s"
+msgstr "ingen gren, ombaserar frånkopplat HEAD %s"
 
-#: trailer.c:753
-msgid "could not read from stdin"
-msgstr "kunde inte läsa från standard in"
+#: ref-filter.c:1494
+#, c-format
+msgid "no branch, bisect started on %s"
+msgstr "ingen gren, \"bisect\" startad på %s"
 
-#: trailer.c:1008 builtin/am.c:46
+#: ref-filter.c:1504
+msgid "no branch"
+msgstr "ingen gren"
+
+#: ref-filter.c:1540 ref-filter.c:1749
 #, c-format
-msgid "could not stat %s"
-msgstr "kunde inte ta status på %s"
+msgid "missing object %s for %s"
+msgstr "objektet %s saknas för %s"
 
-#: trailer.c:1010
+#: ref-filter.c:1550
 #, c-format
-msgid "file %s is not a regular file"
-msgstr "filen %s är inte en normal fil"
+msgid "parse_object_buffer failed on %s for %s"
+msgstr "parse_object_buffer misslyckades på %s för %s"
 
-#: trailer.c:1012
+#: ref-filter.c:2004
 #, c-format
-msgid "file %s is not writable by user"
-msgstr "filen %s är inte skrivbar av användaren"
+msgid "malformed object at '%s'"
+msgstr "felformat objekt vid \"%s\""
 
-#: trailer.c:1024
-msgid "could not open temporary file"
-msgstr "kunde inte öppna temporär fil"
+#: ref-filter.c:2093
+#, c-format
+msgid "ignoring ref with broken name %s"
+msgstr "ignorerar referens med trasigt namn %s"
 
-#: trailer.c:1064
+#: ref-filter.c:2389
 #, c-format
-msgid "could not rename temporary file to %s"
-msgstr "kunde inte byta namn på temporär fil till %s"
+msgid "format: %%(end) atom missing"
+msgstr "format: atomen %%(end) saknas"
 
-#: transport.c:116
+#: ref-filter.c:2489
 #, c-format
-msgid "Would set upstream of '%s' to '%s' of '%s'\n"
-msgstr "Skulle sätta uppströms för \"%s\" till \"%s\" från \"%s\"\n"
+msgid "option `%s' is incompatible with --merged"
+msgstr "flaggan \"%s\" är inkompatibel med --merged"
 
-#: transport.c:208
+#: ref-filter.c:2492
 #, c-format
-msgid "transport: invalid depth option '%s'"
-msgstr "transport: ogiltig flagga för depth: ”%s”"
+msgid "option `%s' is incompatible with --no-merged"
+msgstr "flaggan \"%s\" är inkompatibel med --no-merged"
 
-#: transport.c:584
-msgid "could not parse transport.color.* config"
-msgstr "kunde inte tolka inställningen för transport.color.*"
+#: ref-filter.c:2502
+#, c-format
+msgid "malformed object name %s"
+msgstr "felformat objektnamn %s"
 
-#: transport.c:996
+#: ref-filter.c:2507
 #, c-format
-msgid ""
-"The following submodule paths contain changes that can\n"
-"not be found on any remote:\n"
-msgstr ""
-"Följande undermodulsökvägar innehåller ändringar som\n"
-"inte kan hittas av fjärrarna:\n"
+msgid "option `%s' must point to a commit"
+msgstr "flaggan \"%s\" måste peka på en incheckning"
 
-#: transport.c:1000
+#: remote.c:366
 #, c-format
-msgid ""
-"\n"
-"Please try\n"
-"\n"
-"\tgit push --recurse-submodules=on-demand\n"
-"\n"
-"or cd to the path and use\n"
-"\n"
-"\tgit push\n"
-"\n"
-"to push them to a remote.\n"
-"\n"
-msgstr ""
-"\n"
-"Testa\n"
-"\n"
-"\tgit push --recurse-submodules=on-demand\n"
-"\n"
-"eller cd till sökvägen och använd\n"
-"\n"
-"\tgit push\n"
-"\n"
-"för att sända dem till fjärren.\n"
-"\n"
+msgid "config remote shorthand cannot begin with '/': %s"
+msgstr "konfigurerad kortform för fjärr kan inte börja med \"/\": %s"
 
-#: transport.c:1008
-msgid "Aborting."
-msgstr "Avbryter."
+#: remote.c:413
+msgid "more than one receivepack given, using the first"
+msgstr "mer än en receivepack angavs, använder den första"
 
-#: transport-helper.c:1087
-#, c-format
-msgid "Could not read ref %s"
-msgstr "Kunde inte läsa referensen %s"
+#: remote.c:421
+msgid "more than one uploadpack given, using the first"
+msgstr "mer än en uploadpack angavs, använder den första"
 
-#: tree-walk.c:31
-msgid "too-short tree object"
-msgstr "trädobjekt för kort"
+#: remote.c:611
+#, c-format
+msgid "Cannot fetch both %s and %s to %s"
+msgstr "Kan inte hämta både %s och %s till %s"
 
-#: tree-walk.c:37
-msgid "malformed mode in tree entry"
-msgstr "felformat läge i trädpost"
+#: remote.c:615
+#, c-format
+msgid "%s usually tracks %s, not %s"
+msgstr "%s spårar vanligtvis %s, inte %s"
 
-#: tree-walk.c:41
-msgid "empty filename in tree entry"
-msgstr "tomt filnamn i trädpost"
+#: remote.c:619
+#, c-format
+msgid "%s tracks both %s and %s"
+msgstr "%s spårar både %s och %s"
 
-#: tree-walk.c:113
-msgid "too-short tree file"
-msgstr "trädfil för kort"
+#: remote.c:687
+#, c-format
+msgid "key '%s' of pattern had no '*'"
+msgstr "nyckeln \"%s\" i mönstret innehåller ingen \"*\""
 
-#: unpack-trees.c:111
+#: remote.c:697
 #, c-format
-msgid ""
-"Your local changes to the following files would be overwritten by checkout:\n"
-"%%sPlease commit your changes or stash them before you switch branches."
-msgstr ""
-"Dina lokala ändringar av följande filer skulle skrivas över av utcheckning:\n"
-"%%sChecka in dina ändringar eller använd \"stash\" innan du byter gren."
+msgid "value '%s' of pattern has no '*'"
+msgstr "värdet \"%s\" i mönstret innehåller ingen \"*\""
 
-#: unpack-trees.c:113
+#: remote.c:1003
 #, c-format
-msgid ""
-"Your local changes to the following files would be overwritten by checkout:\n"
-"%%s"
-msgstr ""
-"Dina lokala ändringar av följande filer skulle skrivas över av utcheckning:\n"
-"%%s"
+msgid "src refspec %s does not match any"
+msgstr "käll-referensspecifikationen %s motsvarar ingen"
 
-#: unpack-trees.c:116
+#: remote.c:1008
 #, c-format
-msgid ""
-"Your local changes to the following files would be overwritten by merge:\n"
-"%%sPlease commit your changes or stash them before you merge."
-msgstr ""
-"Dina lokala ändringar av följande filer skulle skrivas över av "
-"sammanslagning:\n"
-"%%sChecka in dina ändringar eller använd \"stash\" innan du byter gren."
+msgid "src refspec %s matches more than one"
+msgstr "käll-referensspecifikationen %s motsvarar mer än en"
 
-#: unpack-trees.c:118
+#. TRANSLATORS: "matches '%s'%" is the <dst> part of "git push
+#. <remote> <src>:<dst>" push, and "being pushed ('%s')" is
+#. the <src>.
+#.
+#: remote.c:1023
 #, c-format
 msgid ""
-"Your local changes to the following files would be overwritten by merge:\n"
-"%%s"
+"The destination you provided is not a full refname (i.e.,\n"
+"starting with \"refs/\"). We tried to guess what you meant by:\n"
+"\n"
+"- Looking for a ref that matches '%s' on the remote side.\n"
+"- Checking if the <src> being pushed ('%s')\n"
+"  is a ref in \"refs/{heads,tags}/\". If so we add a corresponding\n"
+"  refs/{heads,tags}/ prefix on the remote side.\n"
+"\n"
+"Neither worked, so we gave up. You must fully qualify the ref."
 msgstr ""
-"Dina lokala ändringar av följande filer skulle skrivas över av "
-"sammanslagning:\n"
-"%%s"
+"Målet du angav är inte ett komplett referensamn (dvs.,\n"
+"startar med \"refs/\"). Vi försökte gissa vad du menade genom att:\n"
+"\n"
+"- Se efter en referens som motsvarar \"%s\" på fjärrsidan.\n"
+"- Se om <källan> som sänds (\"%s\")\n"
+"  är en referens i \"refs/{heads,tags}/\". Om så lägger vi till\n"
+"  motsvarande refs/{heads,tags}/-prefix på fjärrsidan.\n"
+"\n"
+"Inget av dem fungerade, så vi gav upp. Ange fullständig referens."
 
-#: unpack-trees.c:121
+#: remote.c:1043
 #, c-format
 msgid ""
-"Your local changes to the following files would be overwritten by %s:\n"
-"%%sPlease commit your changes or stash them before you %s."
+"The <src> part of the refspec is a commit object.\n"
+"Did you mean to create a new branch by pushing to\n"
+"'%s:refs/heads/%s'?"
 msgstr ""
-"Dina lokala ändringar av följande filer skulle skrivas över av \"%s\":\n"
-"%%sChecka in dina ändringar eller använd \"stash\" innan du \"%s\"."
+"<Källa>-delen av ref.spec-en är ett incheckningsobjekt.\n"
+"Var det meningen att skapa en ny gren genom att sända\n"
+"till \"%s:refs/heads/%s\"?"
 
-#: unpack-trees.c:123
+#: remote.c:1048
 #, c-format
 msgid ""
-"Your local changes to the following files would be overwritten by %s:\n"
-"%%s"
+"The <src> part of the refspec is a tag object.\n"
+"Did you mean to create a new tag by pushing to\n"
+"'%s:refs/tags/%s'?"
 msgstr ""
-"Dina lokala ändringar av följande filer skulle skrivas över av \"%s\":\n"
-"%%s"
+"<Källa>-delen av ref.spec-en är ett taggobjekt.\n"
+"Var det meningen att skapa en ny tagg genom att sända\n"
+"till \"%s:refs/tags/%s\"?"
 
-#: unpack-trees.c:128
+#: remote.c:1053
 #, c-format
 msgid ""
-"Updating the following directories would lose untracked files in them:\n"
-"%s"
+"The <src> part of the refspec is a tree object.\n"
+"Did you mean to tag a new tree by pushing to\n"
+"'%s:refs/tags/%s'?"
 msgstr ""
-"Uppdatering av följande kataloger gör att ospårade filer går förlorade i "
-"dem:\n"
-"%s"
+"<Källa>-delen av ref.spec-en är ett trädobjekt.\n"
+"Var det meningen att tagga ett nytt träd genom att sända\n"
+"till \"%s:refs/tags/%s\"?"
 
-#: unpack-trees.c:132
+#: remote.c:1058
 #, c-format
 msgid ""
-"The following untracked working tree files would be removed by checkout:\n"
-"%%sPlease move or remove them before you switch branches."
+"The <src> part of the refspec is a blob object.\n"
+"Did you mean to tag a new blob by pushing to\n"
+"'%s:refs/tags/%s'?"
 msgstr ""
-"Följande ospårade filer i arbetskatalogen skulle tas bort av utcheckningen:\n"
-"%%sFlytta eller ta bort dem innan du byter gren."
+"<Källa>-delen av ref.spec-en är ett blobobjekt.\n"
+"Var det meningen att tagga en ny blob genom att sända\n"
+"till \"%s:refs/tags/%s\"?"
 
-#: unpack-trees.c:134
+#: remote.c:1094
 #, c-format
-msgid ""
-"The following untracked working tree files would be removed by checkout:\n"
-"%%s"
-msgstr ""
-"Följande ospårade filer i arbetskatalogen skulle tas bort av utcheckningen:\n"
-"%%s"
+msgid "%s cannot be resolved to branch"
+msgstr "%s kan inte slås upp till en gren"
 
-#: unpack-trees.c:137
+#: remote.c:1105
 #, c-format
-msgid ""
-"The following untracked working tree files would be removed by merge:\n"
-"%%sPlease move or remove them before you merge."
-msgstr ""
-"Följande ospårade filer i arbetskatalogen skulle tas bort av "
-"sammanslagningen:\n"
-"%%sFlytta eller ta bort dem innan du slår samman."
+msgid "unable to delete '%s': remote ref does not exist"
+msgstr "kan inte ta bort \"%s\": fjärreferensen finns inte"
 
-#: unpack-trees.c:139
+#: remote.c:1117
 #, c-format
-msgid ""
-"The following untracked working tree files would be removed by merge:\n"
-"%%s"
-msgstr ""
-"Följande ospårade filer i arbetskatalogen skulle tas bort av "
-"sammanslagningen:\n"
-"%%s"
+msgid "dst refspec %s matches more than one"
+msgstr "fjärr-referensspecifikationen \"%s\" motsvarar mer än en"
 
-#: unpack-trees.c:142
+#: remote.c:1124
 #, c-format
-msgid ""
-"The following untracked working tree files would be removed by %s:\n"
-"%%sPlease move or remove them before you %s."
-msgstr ""
-"Följande ospårade filer i arbetskatalogen skulle tas bort av \"%s\":\n"
-"%%sFlytta eller ta bort dem innan du \"%s\"."
+msgid "dst ref %s receives from more than one src"
+msgstr "fjärr-referensen \"%s\" hämtar från mer än en källa"
 
-#: unpack-trees.c:144
+#: remote.c:1627 remote.c:1728
+msgid "HEAD does not point to a branch"
+msgstr "HEAD pekar inte på en gren"
+
+#: remote.c:1636
 #, c-format
-msgid ""
-"The following untracked working tree files would be removed by %s:\n"
-"%%s"
-msgstr ""
-"Följande ospårade filer i arbetskatalogen skulle tas bort av \"%s\":\n"
-"%%s"
+msgid "no such branch: '%s'"
+msgstr "okänd gren: \"%s\""
 
-#: unpack-trees.c:150
+#: remote.c:1639
 #, c-format
-msgid ""
-"The following untracked working tree files would be overwritten by "
-"checkout:\n"
-"%%sPlease move or remove them before you switch branches."
-msgstr ""
-"Följande ospårade filer i arbetskatalogen skulle skrivas över av "
-"utcheckningen:\n"
-"%%sFlytta eller ta bort dem innan du byter gren."
+msgid "no upstream configured for branch '%s'"
+msgstr "ingen standarduppström angiven för grenen \"%s\""
 
-#: unpack-trees.c:152
+#: remote.c:1645
 #, c-format
-msgid ""
-"The following untracked working tree files would be overwritten by "
-"checkout:\n"
-"%%s"
-msgstr ""
-"Följande ospårade filer i arbetskatalogen skulle skrivas över av "
-"utcheckningen:\n"
-"%%s"
+msgid "upstream branch '%s' not stored as a remote-tracking branch"
+msgstr "uppströmsgrenen \"%s\" är inte lagrad som en fjärrspårande gren"
 
-#: unpack-trees.c:155
+#: remote.c:1660
 #, c-format
-msgid ""
-"The following untracked working tree files would be overwritten by merge:\n"
-"%%sPlease move or remove them before you merge."
-msgstr ""
-"Följande ospårade filer i arbetskatalogen skulle skrivas över av "
-"sammanslagningen:\n"
-"%%sFlytta eller ta bort dem innan du byter gren."
+msgid "push destination '%s' on remote '%s' has no local tracking branch"
+msgstr "push-målet \"%s\" på fjärren \"%s\" har ingen lokalt spårande gren"
 
-#: unpack-trees.c:157
+#: remote.c:1672
 #, c-format
-msgid ""
-"The following untracked working tree files would be overwritten by merge:\n"
-"%%s"
-msgstr ""
-"Följande ospårade filer i arbetskatalogen skulle skrivas över av "
-"sammanslagningen:\n"
-"%%s"
+msgid "branch '%s' has no remote for pushing"
+msgstr "grenen \"%s\" har ingen fjärr för \"push\""
 
-#: unpack-trees.c:160
+#: remote.c:1682
 #, c-format
-msgid ""
-"The following untracked working tree files would be overwritten by %s:\n"
-"%%sPlease move or remove them before you %s."
-msgstr ""
-"Följande ospårade filer i arbetskatalogen skulle skrivas över av \"%s\":\n"
-"%%sFlytta eller ta bort dem innan du \"%s\"."
+msgid "push refspecs for '%s' do not include '%s'"
+msgstr "\"push\"-referensspecifikation för \"%s\" innehåller inte \"%s\""
+
+#: remote.c:1695
+msgid "push has no destination (push.default is 'nothing')"
+msgstr "\"push\" har inget mål (push.default är \"ingenting\")"
 
-#: unpack-trees.c:162
+#: remote.c:1717
+msgid "cannot resolve 'simple' push to a single destination"
+msgstr "\"enkel push\" motsvarar flera olika mål"
+
+#: remote.c:1843
 #, c-format
-msgid ""
-"The following untracked working tree files would be overwritten by %s:\n"
-"%%s"
-msgstr ""
-"Följande ospårade filer i arbetskatalogen skulle skrivas över av \"%s\":\n"
-"%%s"
+msgid "couldn't find remote ref %s"
+msgstr "Kunde inte hitta fjärr-referensen %s"
 
-#: unpack-trees.c:170
+#: remote.c:1856
 #, c-format
-msgid "Entry '%s' overlaps with '%s'.  Cannot bind."
-msgstr "Posten \"%s\" överlappar \"%s\". Kan inte binda."
+msgid "* Ignoring funny ref '%s' locally"
+msgstr "* Ignorerar märklig referens \"%s\" lokalt"
 
-#: unpack-trees.c:173
+#: remote.c:2019
 #, c-format
-msgid ""
-"Cannot update sparse checkout: the following entries are not up to date:\n"
-"%s"
-msgstr ""
-"Kan inte uppdatera gles utcheckning: följande poster är inte à jour:\n"
-"%s"
+msgid "Your branch is based on '%s', but the upstream is gone.\n"
+msgstr "Din gren är baserad på \"%s\", men den har försvunnit uppströms.\n"
+
+#: remote.c:2023
+msgid "  (use \"git branch --unset-upstream\" to fixup)\n"
+msgstr "  (använd \"git branch --unset-upstream\" för att rätta)\n"
 
-#: unpack-trees.c:175
+#: remote.c:2026
 #, c-format
-msgid ""
-"The following working tree files would be overwritten by sparse checkout "
-"update:\n"
-"%s"
-msgstr ""
-"Följande filer i arbetskatalogen skulle skrivas över av uppdatering av gles "
-"utcheckning:\n"
-"%s"
+msgid "Your branch is up to date with '%s'.\n"
+msgstr "Din gren är à jour med \"%s\".\n"
 
-#: unpack-trees.c:177
+#: remote.c:2030
 #, c-format
-msgid ""
-"The following working tree files would be removed by sparse checkout "
-"update:\n"
-"%s"
-msgstr ""
-"Följande filer i arbetskatalogen skulle tas bort av uppdatering av gles "
-"utcheckning:\n"
-"%s"
+msgid "Your branch and '%s' refer to different commits.\n"
+msgstr "Din gren och \"%s\" pekar på olika incheckningar.\n"
 
-#: unpack-trees.c:179
+#: remote.c:2033
 #, c-format
-msgid ""
-"Cannot update submodule:\n"
-"%s"
-msgstr ""
-"Kan inte uppdatera undermodul:\n"
-"%s"
+msgid "  (use \"%s\" for details)\n"
+msgstr "  (använd \"%s\" för detaljer)\n"
 
-#: unpack-trees.c:262
+#: remote.c:2037
 #, c-format
-msgid "Aborting\n"
-msgstr "Avbryter\n"
+msgid "Your branch is ahead of '%s' by %d commit.\n"
+msgid_plural "Your branch is ahead of '%s' by %d commits.\n"
+msgstr[0] "Din gren ligger före \"%s\" med %d incheckning.\n"
+msgstr[1] "Din gren ligger före \"%s\" med %d incheckningar.\n"
 
-#: unpack-trees.c:344
-msgid "Checking out files"
-msgstr "Checkar ut filer"
+#: remote.c:2043
+msgid "  (use \"git push\" to publish your local commits)\n"
+msgstr "  (använd \"git push\" för att publicera dina lokala incheckningar)\n"
 
-#: urlmatch.c:163
-msgid "invalid URL scheme name or missing '://' suffix"
-msgstr "ogiltig URL-schemanamn eller saknat \"://\"-suffix"
+#: remote.c:2046
+#, c-format
+msgid "Your branch is behind '%s' by %d commit, and can be fast-forwarded.\n"
+msgid_plural ""
+"Your branch is behind '%s' by %d commits, and can be fast-forwarded.\n"
+msgstr[0] ""
+"Din gren ligger efter \"%s\" med %d incheckning, och kan snabbspolas.\n"
+msgstr[1] ""
+"Din gren ligger efter \"%s\" med %d incheckningar, och kan snabbspolas.\n"
 
-#: urlmatch.c:187 urlmatch.c:346 urlmatch.c:405
+#: remote.c:2054
+msgid "  (use \"git pull\" to update your local branch)\n"
+msgstr "  (använd \"git pull\" för att uppdatera din lokala gren)\n"
+
+#: remote.c:2057
 #, c-format
-msgid "invalid %XX escape sequence"
-msgstr "ogiltig %XX-teckensekvens"
+msgid ""
+"Your branch and '%s' have diverged,\n"
+"and have %d and %d different commit each, respectively.\n"
+msgid_plural ""
+"Your branch and '%s' have diverged,\n"
+"and have %d and %d different commits each, respectively.\n"
+msgstr[0] ""
+"Din gren och \"%s\" har divergerat,\n"
+"och har %d respektive %d olika incheckning.\n"
+msgstr[1] ""
+"Din gren och \"%s\" har divergerat,\n"
+"och har %d respektive %d olika incheckningar.\n"
 
-#: urlmatch.c:215
-msgid "missing host and scheme is not 'file:'"
-msgstr "värd saknas och schemat är inte \"file:\""
+#: remote.c:2067
+msgid "  (use \"git pull\" to merge the remote branch into yours)\n"
+msgstr "  (använd \"git pull\" för att slå ihop fjärrgrenen med din egen)\n"
 
-#: urlmatch.c:232
-msgid "a 'file:' URL may not have a port number"
-msgstr "en \"file:\"-URL kan inte innehålla portnummer"
+#: remote.c:2250
+#, c-format
+msgid "cannot parse expected object name '%s'"
+msgstr "kan inte tolka förväntat objektnamn \"%s\""
 
-#: urlmatch.c:247
-msgid "invalid characters in host name"
-msgstr "ogiltiga tecken i värdnamnet"
+#: replace-object.c:21
+#, c-format
+msgid "bad replace ref name: %s"
+msgstr "felaktig ersättningsreferensnamn: %s"
 
-#: urlmatch.c:292 urlmatch.c:303
-msgid "invalid port number"
-msgstr "felaktigt portnummer"
+#: replace-object.c:30
+#, c-format
+msgid "duplicate replace ref: %s"
+msgstr "duplicerat ersättningsreferensnamn: %s"
 
-#: urlmatch.c:371
-msgid "invalid '..' path segment"
-msgstr "felaktigt \"..\"-sökvägssegment"
+#: replace-object.c:73
+#, c-format
+msgid "replace depth too high for object %s"
+msgstr "ersättningsdjupet för högt för objektet %s"
 
-#: worktree.c:245 builtin/am.c:2147
+#: rerere.c:217 rerere.c:226 rerere.c:229
+msgid "corrupt MERGE_RR"
+msgstr "trasig MERGE_RR"
+
+#: rerere.c:264 rerere.c:269
+msgid "unable to write rerere record"
+msgstr "kunde inte skriva rerere-post"
+
+#: rerere.c:495
 #, c-format
-msgid "failed to read '%s'"
-msgstr "misslyckades läsa \"%s\""
+msgid "there were errors while writing '%s' (%s)"
+msgstr "fel vid skrivning av \"%s\" (%s)"
 
-#: worktree.c:291
+#: rerere.c:498
 #, c-format
-msgid "'%s' at main working tree is not the repository directory"
-msgstr "\"%s\" i huvudarbetskatalogen är inte arkivkatalogen"
+msgid "failed to flush '%s'"
+msgstr "misslyckades spola \"%s\""
 
-#: worktree.c:302
+#: rerere.c:503 rerere.c:1039
 #, c-format
-msgid "'%s' file does not contain absolute path to the working tree location"
-msgstr "filen \"%s\" innehåller inte absolut sökväg till arbetskatalogen"
+msgid "could not parse conflict hunks in '%s'"
+msgstr "kunde inte tolka konflikt-stycket i \"%s\""
 
-#: worktree.c:314
+#: rerere.c:684
 #, c-format
-msgid "'%s' does not exist"
-msgstr "\"%s\" finns inte"
+msgid "failed utime() on '%s'"
+msgstr "\"utime()\" misslyckades på \"%s\""
 
-#: worktree.c:320
+#: rerere.c:694
 #, c-format
-msgid "'%s' is not a .git file, error code %d"
-msgstr "\"%s\" är inte en .git-fil, felkod %d"
+msgid "writing '%s' failed"
+msgstr "misslyckades skriva \"%s\""
 
-#: worktree.c:328
+#: rerere.c:714
 #, c-format
-msgid "'%s' does not point back to '%s'"
-msgstr "\"%s\" pekar inte tillbaka till \"%s\""
+msgid "Staged '%s' using previous resolution."
+msgstr "Köade \"%s\" med sparad lösning."
 
-#: wrapper.c:223 wrapper.c:393
+#: rerere.c:753
 #, c-format
-msgid "could not open '%s' for reading and writing"
-msgstr "kunde inte öppna \"%s\" för läsning och skrivning"
+msgid "Recorded resolution for '%s'."
+msgstr "Sparade lösning för \"%s\"."
 
-#: wrapper.c:227 wrapper.c:397 builtin/am.c:320 builtin/am.c:770
-#: builtin/am.c:862 builtin/merge.c:1043
+#: rerere.c:788
 #, c-format
-msgid "could not open '%s' for reading"
-msgstr "kunde inte öppna \"%s\" för läsning"
+msgid "Resolved '%s' using previous resolution."
+msgstr "Löste \"%s\" med tidigare lösning."
 
-#: wrapper.c:424 wrapper.c:624
+#: rerere.c:803
 #, c-format
-msgid "unable to access '%s'"
-msgstr "kan inte komma åt \"%s\""
+msgid "cannot unlink stray '%s'"
+msgstr "kan inte ta bort lös länk \"%s\""
 
-#: wrapper.c:632
-msgid "unable to get current working directory"
-msgstr "kan inte hämta aktuell arbetskatalog"
+#: rerere.c:807
+#, c-format
+msgid "Recorded preimage for '%s'"
+msgstr "Sparade förhandsbild för \"%s\""
 
-#: wt-status.c:154
-msgid "Unmerged paths:"
-msgstr "Ej sammanslagna sökvägar:"
+#: rerere.c:881 submodule.c:2067 builtin/log.c:1871
+#: builtin/submodule--helper.c:1436 builtin/submodule--helper.c:1448
+#, c-format
+msgid "could not create directory '%s'"
+msgstr "kunde inte skapa katalogen \"%s\""
 
-#: wt-status.c:181 wt-status.c:208
+#: rerere.c:1057
 #, c-format
-msgid "  (use \"git reset %s <file>...\" to unstage)"
-msgstr "  (använd \"git reset %s <fil>...\" för att ta bort från kö)"
+msgid "failed to update conflicted state in '%s'"
+msgstr "misslyckades uppdatera tillstånd för sammanslagningsproblem i \"%s\""
 
-#: wt-status.c:183 wt-status.c:210
-msgid "  (use \"git rm --cached <file>...\" to unstage)"
-msgstr "  (använd \"git rm --cached <fil>...\" för att ta bort från kö)"
+#: rerere.c:1068 rerere.c:1075
+#, c-format
+msgid "no remembered resolution for '%s'"
+msgstr "inget sparat sammanslagningsresultat för \"%s\""
 
-#: wt-status.c:187
-msgid "  (use \"git add <file>...\" to mark resolution)"
-msgstr "  (använd \"git add <fil>...\" för att ange lösning)"
+#: rerere.c:1077
+#, c-format
+msgid "cannot unlink '%s'"
+msgstr "kan inte ta bort länken \"%s\""
 
-#: wt-status.c:189 wt-status.c:193
-msgid "  (use \"git add/rm <file>...\" as appropriate to mark resolution)"
-msgstr "  (använd \"git add/rm <fil>...\" som lämpligt för att ange lösning)"
+#: rerere.c:1087
+#, c-format
+msgid "Updated preimage for '%s'"
+msgstr "Uppdaterade förhandsbild för \"%s\""
 
-#: wt-status.c:191
-msgid "  (use \"git rm <file>...\" to mark resolution)"
-msgstr "  (använd \"git rm <fil>...\" för att ange lösning)"
+#: rerere.c:1096
+#, c-format
+msgid "Forgot resolution for '%s'\n"
+msgstr "Glömde lösning för \"%s\"\n"
 
-#: wt-status.c:202 wt-status.c:1015
-msgid "Changes to be committed:"
-msgstr "Ändringar att checka in:"
+#: rerere.c:1199
+msgid "unable to open rr-cache directory"
+msgstr "kan inte uppdatera katalogen rr-cache"
 
-#: wt-status.c:220 wt-status.c:1024
-msgid "Changes not staged for commit:"
-msgstr "Ändringar ej i incheckningskön:"
+#: revision.c:2497
+msgid "your current branch appears to be broken"
+msgstr "din nuvarande gren verkar vara trasig"
 
-#: wt-status.c:224
-msgid "  (use \"git add <file>...\" to update what will be committed)"
-msgstr ""
-"  (använd \"git add <fil>...\" för att uppdatera vad som skall checkas in)"
+#: revision.c:2500
+#, c-format
+msgid "your current branch '%s' does not have any commits yet"
+msgstr "din nuvarande gren \"%s\" innehåller ännu inte några incheckningar"
 
-#: wt-status.c:226
-msgid "  (use \"git add/rm <file>...\" to update what will be committed)"
-msgstr ""
-"  (använd \"git add/rm <fil>...\" för att uppdatera vad som skall checkas in)"
+#: revision.c:2708
+msgid "--first-parent is incompatible with --bisect"
+msgstr "--first-parent är inkompatibelt med --bisect"
 
-#: wt-status.c:227
-msgid ""
-"  (use \"git checkout -- <file>...\" to discard changes in working directory)"
-msgstr ""
-"  (använd \"git checkout -- <fil>...\" för att förkasta ändringar i "
-"arbetskatalogen)"
+#: revision.c:2712
+msgid "-L does not yet support diff formats besides -p and -s"
+msgstr "-L stöder ännu inte andra diff-format än -p och -s"
 
-#: wt-status.c:229
-msgid "  (commit or discard the untracked or modified content in submodules)"
-msgstr ""
-"  (checka in eller förkasta ospårat eller ändrat innehåll i undermoduler)"
+#: run-command.c:762
+msgid "open /dev/null failed"
+msgstr "misslyckades öppna /dev/null"
 
-#: wt-status.c:241
+#: run-command.c:1268
 #, c-format
-msgid "  (use \"git %s <file>...\" to include in what will be committed)"
-msgstr ""
-"  (använd \"git %s <fil>...\" för att ta med i det som skall checkas in)"
-
-#: wt-status.c:256
-msgid "both deleted:"
-msgstr "borttaget av bägge:"
-
-#: wt-status.c:258
-msgid "added by us:"
-msgstr "tillagt av oss:"
-
-#: wt-status.c:260
-msgid "deleted by them:"
-msgstr "borttaget av dem:"
+msgid "cannot create async thread: %s"
+msgstr "kan inte skapa asynkron tråd: %s"
 
-#: wt-status.c:262
-msgid "added by them:"
-msgstr "tillagt av dem:"
+#: run-command.c:1332
+#, c-format
+msgid ""
+"The '%s' hook was ignored because it's not set as executable.\n"
+"You can disable this warning with `git config advice.ignoredHook false`."
+msgstr ""
+"Kroken \"%s\" ignorerades eftersom den inte är markerad som körbar.\n"
+"Du kan inaktivera varningen med \"git config advice.ignoredHook false\"."
 
-#: wt-status.c:264
-msgid "deleted by us:"
-msgstr "borttaget av oss:"
+#: send-pack.c:144
+msgid "unexpected flush packet while reading remote unpack status"
+msgstr "oväntat flush-paket vid läsning av fjärruppackningsstatus"
 
-#: wt-status.c:266
-msgid "both added:"
-msgstr "tillagt av bägge:"
+#: send-pack.c:146
+#, c-format
+msgid "unable to parse remote unpack status: %s"
+msgstr "kunde inte tolka fjärruppackningsstatus: %s"
 
-#: wt-status.c:268
-msgid "both modified:"
-msgstr "ändrat av bägge:"
+#: send-pack.c:148
+#, c-format
+msgid "remote unpack failed: %s"
+msgstr "fjärruppackning misslyckades: %s"
 
-#: wt-status.c:278
-msgid "new file:"
-msgstr "ny fil:"
+#: send-pack.c:309
+msgid "failed to sign the push certificate"
+msgstr "misslyckades underteckna push-certifikatet"
 
-#: wt-status.c:280
-msgid "copied:"
-msgstr "kopierad:"
+#: send-pack.c:423
+msgid "the receiving end does not support --signed push"
+msgstr "mottagarsidan stöder inte push med --signed"
 
-#: wt-status.c:282
-msgid "deleted:"
-msgstr "borttagen:"
+#: send-pack.c:425
+msgid ""
+"not sending a push certificate since the receiving end does not support --"
+"signed push"
+msgstr ""
+"sänder inte push-certifikat eftersom mottagarsidan inte stlder push med --"
+"signed"
 
-#: wt-status.c:284
-msgid "modified:"
-msgstr "ändrad:"
+#: send-pack.c:437
+msgid "the receiving end does not support --atomic push"
+msgstr "mottagarsidan stöder inte push med --atomic"
 
-#: wt-status.c:286
-msgid "renamed:"
-msgstr "namnbytt:"
+#: send-pack.c:442
+msgid "the receiving end does not support push options"
+msgstr "mottagarsidan stöder inte push-flaggor"
 
-#: wt-status.c:288
-msgid "typechange:"
-msgstr "typbyte:"
+#: sequencer.c:189
+#, c-format
+msgid "invalid commit message cleanup mode '%s'"
+msgstr "felaktigt incheckningsmeddelandestädningsläge \"%s\""
 
-#: wt-status.c:290
-msgid "unknown:"
-msgstr "okänd:"
+#: sequencer.c:294
+#, c-format
+msgid "could not delete '%s'"
+msgstr "kunde inte ta bort \"%s\""
 
-#: wt-status.c:292
-msgid "unmerged:"
-msgstr "osammanslagen:"
+#: sequencer.c:313 builtin/rebase.c:781 builtin/rebase.c:1706 builtin/rm.c:369
+#, c-format
+msgid "could not remove '%s'"
+msgstr "kunde inte ta bort \"%s\""
 
-#: wt-status.c:372
-msgid "new commits, "
-msgstr "nya incheckningar, "
+#: sequencer.c:323
+msgid "revert"
+msgstr "revert"
 
-#: wt-status.c:374
-msgid "modified content, "
-msgstr "ändrat innehåll, "
+#: sequencer.c:325
+msgid "cherry-pick"
+msgstr "cherry-pick"
 
-#: wt-status.c:376
-msgid "untracked content, "
-msgstr "ospårat innehåll, "
+#: sequencer.c:327
+msgid "rebase -i"
+msgstr "rebase -i"
 
-#: wt-status.c:853
+#: sequencer.c:329
 #, c-format
-msgid "Your stash currently has %d entry"
-msgid_plural "Your stash currently has %d entries"
-msgstr[0] "Stashen innehåller just nu %d post"
-msgstr[1] "Stashen innehåller just nu %d poster"
-
-#: wt-status.c:885
-msgid "Submodules changed but not updated:"
-msgstr "Undermoduler ändrade men inte uppdaterade:"
+msgid "unknown action: %d"
+msgstr "okänd funktion: %d"
 
-#: wt-status.c:887
-msgid "Submodule changes to be committed:"
-msgstr "Undermodulers ändringar att checka in:"
+#: sequencer.c:387
+msgid ""
+"after resolving the conflicts, mark the corrected paths\n"
+"with 'git add <paths>' or 'git rm <paths>'"
+msgstr ""
+"efter att ha löst konflikterna, markera de rättade sökvägarna\n"
+"med \"git add <sökvägar>\" eller \"git rm <sökvägar>\""
 
-#: wt-status.c:969
+#: sequencer.c:390
 msgid ""
-"Do not modify or remove the line above.\n"
-"Everything below it will be ignored."
+"after resolving the conflicts, mark the corrected paths\n"
+"with 'git add <paths>' or 'git rm <paths>'\n"
+"and commit the result with 'git commit'"
 msgstr ""
-"Raden ovan får inte ändras eller tas bort.\n"
-"Allt under den kommer tas bort."
+"efter att ha löst konflikterna, markera de rättade sökvägarna\n"
+"med \"git add <sökvägar>\" eller \"git rm <sökvägar>\"\n"
+"och checka in resultatet med \"git commit\""
 
-#: wt-status.c:1084
-msgid "You have unmerged paths."
-msgstr "Du har ej sammanslagna sökvägar."
+#: sequencer.c:403 sequencer.c:2993
+#, c-format
+msgid "could not lock '%s'"
+msgstr "kunde inte låsa \"%s\""
 
-#: wt-status.c:1087
-msgid "  (fix conflicts and run \"git commit\")"
-msgstr "  (rätta konflikter och kör \"git commit\")"
+#: sequencer.c:410
+#, c-format
+msgid "could not write eol to '%s'"
+msgstr "kunde inte skriva radslut till \"%s\""
 
-#: wt-status.c:1089
-msgid "  (use \"git merge --abort\" to abort the merge)"
-msgstr "  (använd \"git merge --abort\" för att avbryta sammanslagningen)"
+#: sequencer.c:415 sequencer.c:2798 sequencer.c:2999 sequencer.c:3013
+#: sequencer.c:3277
+#, c-format
+msgid "failed to finalize '%s'"
+msgstr "misslyckades färdigställa \"%s\""
 
-#: wt-status.c:1094
-msgid "All conflicts fixed but you are still merging."
-msgstr "Alla konflikter har rättats men du är fortfarande i en sammanslagning."
+#: sequencer.c:438 sequencer.c:1707 sequencer.c:2818 sequencer.c:3259
+#: sequencer.c:3368 builtin/am.c:244 builtin/commit.c:783 builtin/merge.c:1117
+#: builtin/rebase.c:589
+#, c-format
+msgid "could not read '%s'"
+msgstr "kunde inte läsa \"%s\""
 
-#: wt-status.c:1097
-msgid "  (use \"git commit\" to conclude merge)"
-msgstr "  (använd \"git commit\" för att slutföra sammanslagningen)"
+#: sequencer.c:464
+#, c-format
+msgid "your local changes would be overwritten by %s."
+msgstr "dina lokala ändringar skulle skrivas över av %s."
 
-#: wt-status.c:1107
-msgid "You are in the middle of an am session."
-msgstr "Du är i mitten av en körning av \"git am\"."
+#: sequencer.c:468
+msgid "commit your changes or stash them to proceed."
+msgstr "checka in dina ändringar eller använd \"stash\" för att fortsätta."
 
-#: wt-status.c:1110
-msgid "The current patch is empty."
-msgstr "Aktuell patch är tom."
+#: sequencer.c:500
+#, c-format
+msgid "%s: fast-forward"
+msgstr "%s: snabbspola"
 
-#: wt-status.c:1114
-msgid "  (fix conflicts and then run \"git am --continue\")"
-msgstr "  (rätta konflikter och kör sedan \"git am --continue\")"
+#: sequencer.c:539 builtin/tag.c:565
+#, c-format
+msgid "Invalid cleanup mode %s"
+msgstr "Felaktigt städningsläge %s"
 
-#: wt-status.c:1116
-msgid "  (use \"git am --skip\" to skip this patch)"
-msgstr "  (använd \"git am --skip\" för att hoppa över patchen)"
+#. TRANSLATORS: %s will be "revert", "cherry-pick" or
+#. "rebase -i".
+#.
+#: sequencer.c:633
+#, c-format
+msgid "%s: Unable to write new index file"
+msgstr "%s: Kunde inte skriva ny indexfil"
 
-#: wt-status.c:1118
-msgid "  (use \"git am --abort\" to restore the original branch)"
-msgstr "  (använd \"git am --abort\" för att återställa ursprungsgrenen)"
+#: sequencer.c:650
+msgid "unable to update cache tree"
+msgstr "kan inte uppdatera cacheträd"
 
-#: wt-status.c:1250
-msgid "git-rebase-todo is missing."
-msgstr "git-rebase-todo saknas."
+#: sequencer.c:664
+msgid "could not resolve HEAD commit"
+msgstr "kunde inte bestämma HEAD:s incheckning"
 
-#: wt-status.c:1252
-msgid "No commands done."
-msgstr "Inga kommandon utförda."
+#: sequencer.c:744
+#, c-format
+msgid "no key present in '%.*s'"
+msgstr "ingen nyckel i  \"%.*s\""
 
-#: wt-status.c:1255
+#: sequencer.c:755
 #, c-format
-msgid "Last command done (%d command done):"
-msgid_plural "Last commands done (%d commands done):"
-msgstr[0] "Sista kommandot utfört (%d kommando utfört):"
-msgstr[1] "Sista kommandot utfört (%d kommandon utfört):"
+msgid "unable to dequote value of '%s'"
+msgstr "kan inte ta bort citering av värdet \"%s\""
 
-#: wt-status.c:1266
+#: sequencer.c:792 wrapper.c:190 wrapper.c:360 builtin/am.c:705
+#: builtin/am.c:797 builtin/merge.c:1114 builtin/rebase.c:1074
 #, c-format
-msgid "  (see more in file %s)"
-msgstr "  (se fler i filen %s)"
+msgid "could not open '%s' for reading"
+msgstr "kunde inte öppna \"%s\" för läsning"
 
-#: wt-status.c:1271
-msgid "No commands remaining."
-msgstr "Inga kommandon återstår."
+#: sequencer.c:802
+msgid "'GIT_AUTHOR_NAME' already given"
+msgstr "\"GIT_AUTHOR_NAME\" har redan angivits"
 
-#: wt-status.c:1274
-#, c-format
-msgid "Next command to do (%d remaining command):"
-msgid_plural "Next commands to do (%d remaining commands):"
-msgstr[0] "Nästa kommando att utföra (%d kommando återstår):"
-msgstr[1] "Följande kommandon att utföra (%d kommandon återstår):"
+#: sequencer.c:807
+msgid "'GIT_AUTHOR_EMAIL' already given"
+msgstr "\"GIT_AUTHOR_EMAIL\" har redan angivits"
 
-#: wt-status.c:1282
-msgid "  (use \"git rebase --edit-todo\" to view and edit)"
-msgstr "  (använd \"git rebase --edit-todo\" för att visa och redigera)"
+#: sequencer.c:812
+msgid "'GIT_AUTHOR_DATE' already given"
+msgstr "\"GIT_AUTHOR_DATE\" har redan angivits"
 
-#: wt-status.c:1295
+#: sequencer.c:816
 #, c-format
-msgid "You are currently rebasing branch '%s' on '%s'."
-msgstr "Du håller på att ombasera grenen \"%s\" ovanpå \"%s\"."
-
-#: wt-status.c:1300
-msgid "You are currently rebasing."
-msgstr "Du håller på med en ombasering."
+msgid "unknown variable '%s'"
+msgstr "okänd variabel \"%s\""
 
-#: wt-status.c:1314
-msgid "  (fix conflicts and then run \"git rebase --continue\")"
-msgstr "  (rätta konflikter och kör sedan \"git rebase --continue\")"
+#: sequencer.c:821
+msgid "missing 'GIT_AUTHOR_NAME'"
+msgstr "\"GIT_AUTHOR_NAME\" saknas"
 
-#: wt-status.c:1316
-msgid "  (use \"git rebase --skip\" to skip this patch)"
-msgstr "  (använd \"git rebase --skip\" för att hoppa över patchen)"
+#: sequencer.c:823
+msgid "missing 'GIT_AUTHOR_EMAIL'"
+msgstr "\"GIT_AUTHOR_EMAIL\" saknas"
 
-#: wt-status.c:1318
-msgid "  (use \"git rebase --abort\" to check out the original branch)"
-msgstr "  (använd \"git rebase --abort\" för att checka ut ursprungsgrenen)"
+#: sequencer.c:825
+msgid "missing 'GIT_AUTHOR_DATE'"
+msgstr "\"GIT_AUTHOR_DATE\" saknas"
 
-#: wt-status.c:1324
-msgid "  (all conflicts fixed: run \"git rebase --continue\")"
-msgstr "  (alla konflikter rättade: kör \"git rebase --continue\")"
+#: sequencer.c:902 sequencer.c:1427
+msgid "malformed ident line"
+msgstr "felaktig ident-rad"
 
-#: wt-status.c:1328
+#: sequencer.c:925
 #, c-format
 msgid ""
-"You are currently splitting a commit while rebasing branch '%s' on '%s'."
-msgstr ""
-"Du håller på att dela upp en incheckning medan du ombaserar grenen \"%s\" "
-"ovanpå \"%s\"."
-
-#: wt-status.c:1333
-msgid "You are currently splitting a commit during a rebase."
-msgstr "Du håller på att dela upp en incheckning i en ombasering."
-
-#: wt-status.c:1336
-msgid "  (Once your working directory is clean, run \"git rebase --continue\")"
-msgstr "  (Så fort din arbetskatalog är ren, kör \"git rebase --continue\")"
-
-#: wt-status.c:1340
-#, c-format
-msgid "You are currently editing a commit while rebasing branch '%s' on '%s'."
+"you have staged changes in your working tree\n"
+"If these changes are meant to be squashed into the previous commit, run:\n"
+"\n"
+"  git commit --amend %s\n"
+"\n"
+"If they are meant to go into a new commit, run:\n"
+"\n"
+"  git commit %s\n"
+"\n"
+"In both cases, once you're done, continue with:\n"
+"\n"
+"  git rebase --continue\n"
 msgstr ""
-"Du håller på att redigera en incheckning medan du ombaserar grenen \"%s\" "
-"ovanpå \"%s\"."
+"du har köade ändringar i din arbetskatalog.\n"
+"Om ändringarna skall läggas in i föregående incheckning, kör:\n"
+"\n"
+"  git commit --amend %s\n"
+"\n"
+"Om de skall checkas in i en egen incheckning, kör:\n"
+"\n"
+"  git commit %s\n"
+"\n"
+"Oavsett vilket, när du är färdig fortsätter du med:\n"
+"\n"
+"  git rebase --continue\n"
 
-#: wt-status.c:1345
-msgid "You are currently editing a commit during a rebase."
-msgstr "Du håller på att redigera en incheckning under en ombasering."
+#: sequencer.c:1218
+msgid "'prepare-commit-msg' hook failed"
+msgstr "kroken \"prepare-commit-msg\" misslyckades"
 
-#: wt-status.c:1348
-msgid "  (use \"git commit --amend\" to amend the current commit)"
+#: sequencer.c:1224
+msgid ""
+"Your name and email address were configured automatically based\n"
+"on your username and hostname. Please check that they are accurate.\n"
+"You can suppress this message by setting them explicitly. Run the\n"
+"following command and follow the instructions in your editor to edit\n"
+"your configuration file:\n"
+"\n"
+"    git config --global --edit\n"
+"\n"
+"After doing this, you may fix the identity used for this commit with:\n"
+"\n"
+"    git commit --amend --reset-author\n"
 msgstr ""
-"  (använd \"git commit --amend\" för att lägga till på aktuell incheckning)"
+"Ditt namn och e-postadress konfigurerades automatiskt baserat på\n"
+"ditt användar-id och värdnamn. Kontrollera att de är riktiga. Du\n"
+"kan förhindra det här meddelandet genom att ställa dem explicit.\n"
+"Kör följande kommandon och följ instruktionerna i textredigeraren\n"
+"för att redigera din konfigurationsfil:\n"
+"\n"
+"    git config --global --edit\n"
+"\n"
+"När du gjort det kan du rätta identiteten som användes för den här\n"
+"incheckningen med:\n"
+"\n"
+"    git commit --amend --reset-author\n"
 
-#: wt-status.c:1350
+#: sequencer.c:1237
 msgid ""
-"  (use \"git rebase --continue\" once you are satisfied with your changes)"
-msgstr "  (använd \"git rebase --continue\" när du är nöjd med dina ändringar)"
+"Your name and email address were configured automatically based\n"
+"on your username and hostname. Please check that they are accurate.\n"
+"You can suppress this message by setting them explicitly:\n"
+"\n"
+"    git config --global user.name \"Your Name\"\n"
+"    git config --global user.email you@example.com\n"
+"\n"
+"After doing this, you may fix the identity used for this commit with:\n"
+"\n"
+"    git commit --amend --reset-author\n"
+msgstr ""
+"Ditt namn och e-postadress konfigurerades automatiskt baserat på\n"
+"ditt användar-id och värdnamn. Kontrollera att de är riktiga. Du\n"
+"kan förhindra det här meddelandet genom att ställa dem explicit:\n"
+"\n"
+"    git config --global user.name \"Ditt namn\"\n"
+"    git config --global user.email du@example.com\n"
+"\n"
+"När du gjort det kan du rätta identiteten som användes för den här\n"
+"incheckningen med:\n"
+"\n"
+"    git commit --amend --reset-author\n"
 
-#: wt-status.c:1360
-#, c-format
-msgid "You are currently cherry-picking commit %s."
-msgstr "Du håller på med en \"cherry-pick\" av incheckningen %s."
+#: sequencer.c:1279
+msgid "couldn't look up newly created commit"
+msgstr "kunde inte slå upp en precis skapad incheckning"
 
-#: wt-status.c:1365
-msgid "  (fix conflicts and run \"git cherry-pick --continue\")"
-msgstr "  (rätta konflikter och kör sedan \"git cherry-pick --continue\")"
+#: sequencer.c:1281
+msgid "could not parse newly created commit"
+msgstr "kunde inte tolka en precis skapad incheckning"
 
-#: wt-status.c:1368
-msgid "  (all conflicts fixed: run \"git cherry-pick --continue\")"
-msgstr "  (alla konflikter rättade: kör \"git cherry-pick --continue\")"
+#: sequencer.c:1327
+msgid "unable to resolve HEAD after creating commit"
+msgstr "kunde inte bestämma HEAD efter att ha skapat incheckning"
 
-#: wt-status.c:1370
-msgid "  (use \"git cherry-pick --abort\" to cancel the cherry-pick operation)"
-msgstr ""
-"  (använd \"git cherry-pick --abort\" för att avbryta \"cherry-pick\"-"
-"operationen)"
+#: sequencer.c:1329
+msgid "detached HEAD"
+msgstr "frånkopplad HEAD"
+
+#: sequencer.c:1333
+msgid " (root-commit)"
+msgstr " (rotincheckning)"
+
+#: sequencer.c:1354
+msgid "could not parse HEAD"
+msgstr "kunde inte tolka HEAD"
 
-#: wt-status.c:1379
+#: sequencer.c:1356
 #, c-format
-msgid "You are currently reverting commit %s."
-msgstr "Du håller på med att ångra incheckningen %s."
+msgid "HEAD %s is not a commit!"
+msgstr "HEAD %s är inte en incheckning!"
 
-#: wt-status.c:1384
-msgid "  (fix conflicts and run \"git revert --continue\")"
-msgstr "  (rätta konflikter och kör sedan \"git revert --continue\")"
+#: sequencer.c:1360 sequencer.c:1458 builtin/commit.c:1569
+msgid "could not parse HEAD commit"
+msgstr "kunde inte tolka HEAD:s incheckning"
 
-#: wt-status.c:1387
-msgid "  (all conflicts fixed: run \"git revert --continue\")"
-msgstr "  (alla konflikter rättade: kör \"git revert --continue\")"
+#: sequencer.c:1411 sequencer.c:2055
+msgid "unable to parse commit author"
+msgstr "kunde inte tolka incheckningens författare"
 
-#: wt-status.c:1389
-msgid "  (use \"git revert --abort\" to cancel the revert operation)"
-msgstr "  (använd \"git revert --abort\" för att avbryta ångrandet)"
+#: sequencer.c:1431
+msgid "corrupted author without date information"
+msgstr "trasig författare utan datuminformation"
 
-#: wt-status.c:1400
-#, c-format
-msgid "You are currently bisecting, started from branch '%s'."
-msgstr "Du håller på med en \"bisect\", startad från grenen \"%s\"."
+#: sequencer.c:1447 builtin/am.c:1561 builtin/merge.c:684
+msgid "git write-tree failed to write a tree"
+msgstr "git write-tree misslyckades skriva ett träd"
 
-#: wt-status.c:1404
-msgid "You are currently bisecting."
-msgstr "Du håller på med en \"bisect\"."
+#: sequencer.c:1480 sequencer.c:1550
+#, c-format
+msgid "unable to read commit message from '%s'"
+msgstr "kunde inte läsa incheckningsmeddelande från \"%s\""
 
-#: wt-status.c:1407
-msgid "  (use \"git bisect reset\" to get back to the original branch)"
-msgstr ""
-"  (använd \"git bisect reset\" för att komma tillbaka till ursprungsgrenen)"
+#: sequencer.c:1516 builtin/am.c:1583 builtin/commit.c:1668 builtin/merge.c:883
+#: builtin/merge.c:908
+msgid "failed to write commit object"
+msgstr "kunde inte skriva incheckningsobjekt"
 
-#: wt-status.c:1604
-msgid "On branch "
-msgstr "På grenen "
+#: sequencer.c:1577
+#, c-format
+msgid "could not parse commit %s"
+msgstr "kunde inte tolka incheckningen %s"
 
-#: wt-status.c:1610
-msgid "interactive rebase in progress; onto "
-msgstr "interaktiv ombasering pågår; ovanpå "
+#: sequencer.c:1582
+#, c-format
+msgid "could not parse parent commit %s"
+msgstr "kunde inte tolka föräldraincheckningen %s"
 
-#: wt-status.c:1612
-msgid "rebase in progress; onto "
-msgstr "ombasering pågår; ovanpå "
+#: sequencer.c:1656 sequencer.c:1767
+#, c-format
+msgid "unknown command: %d"
+msgstr "okänt kommando: %d"
 
-#: wt-status.c:1617
-msgid "HEAD detached at "
-msgstr "HEAD frånkopplad vid "
+#: sequencer.c:1714 sequencer.c:1739
+#, c-format
+msgid "This is a combination of %d commits."
+msgstr "Det här är en kombination av %d incheckningar."
 
-#: wt-status.c:1619
-msgid "HEAD detached from "
-msgstr "HEAD frånkopplad från "
+#: sequencer.c:1724
+msgid "need a HEAD to fixup"
+msgstr "behöver en HEAD-incheckning att rätta"
 
-#: wt-status.c:1622
-msgid "Not currently on any branch."
-msgstr "Inte på någon gren för närvarande."
+#: sequencer.c:1726 sequencer.c:3304
+msgid "could not read HEAD"
+msgstr "kunde inte läsa HEAD"
 
-#: wt-status.c:1642
-msgid "Initial commit"
-msgstr "Första incheckning"
+#: sequencer.c:1728
+msgid "could not read HEAD's commit message"
+msgstr "kunde inte läsa HEAD:s incheckningsmeddelande"
 
-#: wt-status.c:1643
-msgid "No commits yet"
-msgstr "Inga incheckningar ännu"
+#: sequencer.c:1734
+#, c-format
+msgid "cannot write '%s'"
+msgstr "kan inte skriva \"%s\""
 
-#: wt-status.c:1657
-msgid "Untracked files"
-msgstr "Ospårade filer"
+#: sequencer.c:1741 git-rebase--preserve-merges.sh:496
+msgid "This is the 1st commit message:"
+msgstr "Det här är 1:a incheckningsmeddelandet:"
 
-#: wt-status.c:1659
-msgid "Ignored files"
-msgstr "Ignorerade filer"
+#: sequencer.c:1749
+#, c-format
+msgid "could not read commit message of %s"
+msgstr "kunde inte läsa incheckningsmeddelande för %s"
 
-#: wt-status.c:1663
+#: sequencer.c:1756
 #, c-format
-msgid ""
-"It took %.2f seconds to enumerate untracked files. 'status -uno'\n"
-"may speed it up, but you have to be careful not to forget to add\n"
-"new files yourself (see 'git help status')."
-msgstr ""
-"Det tog %.2f sekunder att räkna upp ospårade filer. \"status -uno\"\n"
-"kan gå snabbare, men du måste vara försiktig så du inte glömmer\n"
-"lägga till nya filer själv (se \"git help status\")."
+msgid "This is the commit message #%d:"
+msgstr "Det här är incheckningsmeddelande %d:"
 
-# %s är nästa sträng eller tom.
-#: wt-status.c:1669
+#: sequencer.c:1762
 #, c-format
-msgid "Untracked files not listed%s"
-msgstr "Ospårade filer visas ej%s"
+msgid "The commit message #%d will be skipped:"
+msgstr "Incheckningsmeddelande %d kommer hoppas över:"
 
-#: wt-status.c:1671
-msgid " (use -u option to show untracked files)"
-msgstr " (använd flaggan -u för att visa ospårade filer)"
+#: sequencer.c:1850
+msgid "your index file is unmerged."
+msgstr "din indexfil har inte slagits ihop."
 
-#: wt-status.c:1677
-msgid "No changes"
-msgstr "Inga ändringar"
+#: sequencer.c:1857
+msgid "cannot fixup root commit"
+msgstr "kan inte göra \"fixup\" på rotincheckning"
 
-#: wt-status.c:1682
+#: sequencer.c:1876
 #, c-format
-msgid "no changes added to commit (use \"git add\" and/or \"git commit -a\")\n"
-msgstr ""
-"inga ändringar att checka in (använd \"git add\" och/eller \"git commit -a"
-"\")\n"
+msgid "commit %s is a merge but no -m option was given."
+msgstr "incheckning %s är en sammanslagning, men flaggan -m angavs inte."
 
-#: wt-status.c:1685
+#: sequencer.c:1884 sequencer.c:1892
 #, c-format
-msgid "no changes added to commit\n"
-msgstr "inga ändringar att checka in\n"
+msgid "commit %s does not have parent %d"
+msgstr "incheckning %s har inte förälder %d"
 
-#: wt-status.c:1688
+#: sequencer.c:1898
 #, c-format
-msgid ""
-"nothing added to commit but untracked files present (use \"git add\" to "
-"track)\n"
-msgstr ""
-"inget köat för incheckning, men ospårade filer finns (spåra med \"git add"
-"\")\n"
+msgid "cannot get commit message for %s"
+msgstr "kan inte hämta incheckningsmeddelande för %s"
 
-#: wt-status.c:1691
+#. TRANSLATORS: The first %s will be a "todo" command like
+#. "revert" or "pick", the second %s a SHA1.
+#: sequencer.c:1917
 #, c-format
-msgid "nothing added to commit but untracked files present\n"
-msgstr "inget köat för incheckning, men ospårade filer finns\n"
+msgid "%s: cannot parse parent commit %s"
+msgstr "%s: kan inte tolka föräldraincheckningen %s"
 
-#: wt-status.c:1694
+#: sequencer.c:1982
 #, c-format
-msgid "nothing to commit (create/copy files and use \"git add\" to track)\n"
-msgstr "inget att checka in (skapa/kopiera filer och spåra med \"git add\")\n"
+msgid "could not rename '%s' to '%s'"
+msgstr "kunde inte byta namn på \"%s\" till \"%s\""
 
-#: wt-status.c:1697 wt-status.c:1702
+#: sequencer.c:2037
 #, c-format
-msgid "nothing to commit\n"
-msgstr "inget att checka in\n"
+msgid "could not revert %s... %s"
+msgstr "kunde inte ångra %s... %s"
 
-#: wt-status.c:1700
+#: sequencer.c:2038
 #, c-format
-msgid "nothing to commit (use -u to show untracked files)\n"
-msgstr "inget att checka in (använd -u för att visa ospårade filer)\n"
+msgid "could not apply %s... %s"
+msgstr "kunde inte tillämpa %s... %s"
 
-#: wt-status.c:1704
+#: sequencer.c:2105
 #, c-format
-msgid "nothing to commit, working tree clean\n"
-msgstr "inget att checka in, arbetskatalogen ren\n"
+msgid "git %s: failed to read the index"
+msgstr "git %s: misslyckades läsa indexet"
 
-#: wt-status.c:1817
-msgid "No commits yet on "
-msgstr "Inga incheckningar ännu på "
+#: sequencer.c:2112
+#, c-format
+msgid "git %s: failed to refresh the index"
+msgstr "git %s: misslyckades uppdatera indexet"
 
-#: wt-status.c:1821
-msgid "HEAD (no branch)"
-msgstr "HEAD (ingen gren)"
-
-#: wt-status.c:1852
-msgid "different"
-msgstr "olika"
-
-#: wt-status.c:1854 wt-status.c:1862
-msgid "behind "
-msgstr "efter "
+#: sequencer.c:2189
+#, c-format
+msgid "%s does not accept arguments: '%s'"
+msgstr "%s tar inte argument: \"%s\""
 
-#: wt-status.c:1857 wt-status.c:1860
-msgid "ahead "
-msgstr "före "
+#: sequencer.c:2198
+#, c-format
+msgid "missing arguments for %s"
+msgstr "argument saknas för %s"
 
-#. TRANSLATORS: the action is e.g. "pull with rebase"
-#: wt-status.c:2366
+#: sequencer.c:2235
 #, c-format
-msgid "cannot %s: You have unstaged changes."
-msgstr "kan inte %s: Du har oköade ändringar."
+msgid "could not parse '%.*s'"
+msgstr "kunde inte tolka \"%.*s\""
 
-#: wt-status.c:2372
-msgid "additionally, your index contains uncommitted changes."
-msgstr "dessutom innehåller dit index ändringar som inte har checkats in."
+#: sequencer.c:2289
+#, c-format
+msgid "invalid line %d: %.*s"
+msgstr "ogiltig rad %d: %.*s"
 
-#: wt-status.c:2374
+#: sequencer.c:2300
 #, c-format
-msgid "cannot %s: Your index contains uncommitted changes."
-msgstr "kan inte %s: Ditt index innehåller ändringar som inte checkats in."
+msgid "cannot '%s' without a previous commit"
+msgstr "kan inte utföra \"%s\" utan en föregående incheckning"
 
-#: compat/precompose_utf8.c:58 builtin/clone.c:442
+#: sequencer.c:2348 builtin/rebase.c:172 builtin/rebase.c:197
+#: builtin/rebase.c:223 builtin/rebase.c:248
 #, c-format
-msgid "failed to unlink '%s'"
-msgstr "misslyckades ta bort länken \"%s\""
+msgid "could not read '%s'."
+msgstr "kunde inte läsa \"%s\"."
 
-#: builtin/add.c:24
-msgid "git add [<options>] [--] <pathspec>..."
-msgstr "git add [<flaggor>] [--] <sökväg>..."
+#: sequencer.c:2384
+msgid "cancelling a cherry picking in progress"
+msgstr "avbryter pågående \"cherry-pick\""
+
+#: sequencer.c:2391
+msgid "cancelling a revert in progress"
+msgstr "avbryter pågående \"revert\""
+
+#: sequencer.c:2435
+msgid "please fix this using 'git rebase --edit-todo'."
+msgstr "rätta det med \"git rebase --edit-todo\"."
 
-#: builtin/add.c:83
+#: sequencer.c:2437
 #, c-format
-msgid "unexpected diff status %c"
-msgstr "diff-status %c förväntades inte"
+msgid "unusable instruction sheet: '%s'"
+msgstr "oanvändbart manus: \"%s\""
 
-#: builtin/add.c:88 builtin/commit.c:266
-msgid "updating files failed"
-msgstr "misslyckades uppdatera filer"
+#: sequencer.c:2442
+msgid "no commits parsed."
+msgstr "inga incheckningar lästes."
 
-#: builtin/add.c:98
-#, c-format
-msgid "remove '%s'\n"
-msgstr "ta bort \"%s\"\n"
+#: sequencer.c:2453
+msgid "cannot cherry-pick during a revert."
+msgstr "kan inte utföra \"cherry-pick\" under en \"revert\"."
 
-#: builtin/add.c:173
-msgid "Unstaged changes after refreshing the index:"
-msgstr "Oköade ändringar efter att ha uppdaterat indexet:"
+#: sequencer.c:2455
+msgid "cannot revert during a cherry-pick."
+msgstr "kan inte utföra \"revert\" under en \"cherry-pick\"."
 
-#: builtin/add.c:233 builtin/rev-parse.c:892
-msgid "Could not read the index"
-msgstr "Kunde inte läsa indexet"
+#: sequencer.c:2533
+#, c-format
+msgid "invalid value for %s: %s"
+msgstr "felaktigt värde för %s: %s"
+
+#: sequencer.c:2630
+msgid "unusable squash-onto"
+msgstr "oanvändbar squash-onto"
 
-#: builtin/add.c:244
+#: sequencer.c:2646
 #, c-format
-msgid "Could not open '%s' for writing."
-msgstr "Kunde inte öppna \"%s\" för skrivning."
+msgid "malformed options sheet: '%s'"
+msgstr "trasigt manus: \"%s\""
 
-#: builtin/add.c:248
-msgid "Could not write patch"
-msgstr "Kunde inte skriva patch"
+#: sequencer.c:2736 sequencer.c:4463
+msgid "empty commit set passed"
+msgstr "den angivna uppsättningen incheckningar är tom"
 
-#: builtin/add.c:251
-msgid "editing patch failed"
-msgstr "redigering av patch misslyckades"
+#: sequencer.c:2752
+msgid "revert is already in progress"
+msgstr "en \"revert\" pågår redan"
 
-#: builtin/add.c:254
+#: sequencer.c:2754
 #, c-format
-msgid "Could not stat '%s'"
-msgstr "Kunde inte ta status på \"%s\""
+msgid "try \"git revert (--continue | %s--abort | --quit)\""
+msgstr "testa \"git revert (--continue | %s--abort | --quit)\""
 
-#: builtin/add.c:256
-msgid "Empty patch. Aborted."
-msgstr "Tom patch. Avbryter."
+#: sequencer.c:2757
+msgid "cherry-pick is already in progress"
+msgstr "en \"cherry-pick\" pågår redan"
 
-#: builtin/add.c:261
+#: sequencer.c:2759
 #, c-format
-msgid "Could not apply '%s'"
-msgstr "Kunde inte tillämpa \"%s\""
+msgid "try \"git cherry-pick (--continue | %s--abort | --quit)\""
+msgstr "testa \"git cherry-pick (--continue | %s--abort | --quit)\""
 
-#: builtin/add.c:269
-msgid "The following paths are ignored by one of your .gitignore files:\n"
-msgstr "Följande sökvägar ignoreras av en av dina .gitignore-filer:\n"
+#: sequencer.c:2773
+#, c-format
+msgid "could not create sequencer directory '%s'"
+msgstr "kunde inte skapa \"sequencer\"-katalogen \"%s\""
 
-#: builtin/add.c:289 builtin/clean.c:911 builtin/fetch.c:145 builtin/mv.c:123
-#: builtin/prune-packed.c:55 builtin/pull.c:212 builtin/push.c:557
-#: builtin/remote.c:1342 builtin/rm.c:240 builtin/send-pack.c:165
-msgid "dry run"
-msgstr "testkörning"
+#: sequencer.c:2788
+msgid "could not lock HEAD"
+msgstr "kunde inte låsa HEAD"
 
-#: builtin/add.c:292
-msgid "interactive picking"
-msgstr "plocka interaktivt"
+#: sequencer.c:2848 sequencer.c:4209
+msgid "no cherry-pick or revert in progress"
+msgstr "ingen \"cherry-pick\" eller \"revert\" pågår"
 
-#: builtin/add.c:293 builtin/checkout.c:1135 builtin/reset.c:302
-msgid "select hunks interactively"
-msgstr "välj stycken interaktivt"
+#: sequencer.c:2850 sequencer.c:2861
+msgid "cannot resolve HEAD"
+msgstr "kan inte bestämma HEAD"
 
-#: builtin/add.c:294
-msgid "edit current diff and apply"
-msgstr "redigera aktuell diff och applicera"
+#: sequencer.c:2852 sequencer.c:2896
+msgid "cannot abort from a branch yet to be born"
+msgstr "kan inte avbryta från en gren som ännu inte är född"
 
-#: builtin/add.c:295
-msgid "allow adding otherwise ignored files"
-msgstr "tillåt lägga till annars ignorerade filer"
+#: sequencer.c:2882 builtin/grep.c:736
+#, c-format
+msgid "cannot open '%s'"
+msgstr "kan inte öppna \"%s\""
 
-#: builtin/add.c:296
-msgid "update tracked files"
-msgstr "uppdatera spårade filer"
+#: sequencer.c:2884
+#, c-format
+msgid "cannot read '%s': %s"
+msgstr "kan inte läsa \"%s\": %s"
 
-#: builtin/add.c:297
-msgid "renormalize EOL of tracked files (implies -u)"
-msgstr "åternormalisera radslut i spårade filer (implicerar -u)"
+#: sequencer.c:2885
+msgid "unexpected end of file"
+msgstr "oväntat filslut"
 
-#: builtin/add.c:298
-msgid "record only the fact that the path will be added later"
-msgstr "registrera endast att sökvägen kommer läggas till senare"
+#: sequencer.c:2891
+#, c-format
+msgid "stored pre-cherry-pick HEAD file '%s' is corrupt"
+msgstr "sparad HEAD-fil från före \"cherry-pick\", \"%s\", är trasig"
 
-#: builtin/add.c:299
-msgid "add changes from all tracked and untracked files"
-msgstr "lägg till ändringar från alla spårade och ospårade filer"
+#: sequencer.c:2902
+msgid "You seem to have moved HEAD. Not rewinding, check your HEAD!"
+msgstr ""
+"Du verkar ha flyttat HEAD.\n"
+"Spolar inte tillbaka, kontrollera HEAD!"
 
-#: builtin/add.c:302
-msgid "ignore paths removed in the working tree (same as --no-all)"
-msgstr "ignorera sökvägar borttagna i arbetskatalogen (samma som --no-all)"
+#: sequencer.c:2943
+msgid "no revert in progress"
+msgstr "ingen \"revers\" pågår"
 
-#: builtin/add.c:304
-msgid "don't add, only refresh the index"
-msgstr "lägg inte till, uppdatera endast indexet"
+#: sequencer.c:2951
+msgid "no cherry-pick in progress"
+msgstr "ingen \"cherry-pick\" pågår"
 
-#: builtin/add.c:305
-msgid "just skip files which cannot be added because of errors"
-msgstr "hoppa bara över filer som inte kan läggas till på grund av fel"
+#: sequencer.c:2961
+msgid "failed to skip the commit"
+msgstr "kunde inte hoppa över incheckningen"
 
-#: builtin/add.c:306
-msgid "check if - even missing - files are ignored in dry run"
-msgstr "se om - även saknade - filer ignoreras i testkörning"
+#: sequencer.c:2968
+msgid "there is nothing to skip"
+msgstr "ingenting att hoppa över"
 
-#: builtin/add.c:307 builtin/update-index.c:974
-msgid "(+/-)x"
-msgstr "(+/-)x"
+#: sequencer.c:2971
+#, c-format
+msgid ""
+"have you committed already?\n"
+"try \"git %s --continue\""
+msgstr ""
+"har du redan checkat in?\n"
+"testa \"git %s --continue\""
 
-#: builtin/add.c:307 builtin/update-index.c:975
-msgid "override the executable bit of the listed files"
-msgstr "överstyr exekveringsbiten för angivna filer"
+#: sequencer.c:3095 sequencer.c:4121
+#, c-format
+msgid "could not update %s"
+msgstr "kunde inte uppdatera %s"
 
-#: builtin/add.c:309
-msgid "warn when adding an embedded repository"
-msgstr "varna när ett inbyggt arkiv läggs till"
+#: sequencer.c:3134 sequencer.c:4101
+msgid "cannot read HEAD"
+msgstr "kan inte läsa HEAD"
 
-#: builtin/add.c:324
+#: sequencer.c:3151
+#, c-format
+msgid "unable to copy '%s' to '%s'"
+msgstr "kan inte kopiera in \"%s\" till \"%s\""
+
+#: sequencer.c:3159
 #, c-format
 msgid ""
-"You've added another git repository inside your current repository.\n"
-"Clones of the outer repository will not contain the contents of\n"
-"the embedded repository and will not know how to obtain it.\n"
-"If you meant to add a submodule, use:\n"
-"\n"
-"\tgit submodule add <url> %s\n"
+"You can amend the commit now, with\n"
 "\n"
-"If you added this path by mistake, you can remove it from the\n"
-"index with:\n"
+"  git commit --amend %s\n"
 "\n"
-"\tgit rm --cached %s\n"
+"Once you are satisfied with your changes, run\n"
 "\n"
-"See \"git help submodule\" for more information."
+"  git rebase --continue\n"
 msgstr ""
-"Du har lagt till ett annat git-arkiv inuti aktuellt arkiv.\n"
-"Kloner av det yttre arkivet kommer inte innehålla innehållet från\n"
-"det inbäddade arkivet eller veta hur man får tag på det.\n"
-"Om du tänkte lägga till en undermodul, skrev:\n"
-"\n"
-"\tgit submodule add <url> %s\n"
+"Du kan utöka incheckningen nu, med\n"
 "\n"
-"Om du lade till sökvägen av misstag tar du bort den från indexet\n"
-"med:\n"
+"\tgit commit --amend %s\n"
 "\n"
-"\tgit rm --cached %s\n"
+"När du är nöjd med dina ändringar kör du\n"
 "\n"
-"Se ”git help submodule” för ytterligare information."
+"\tgit rebase --continue\n"
 
-#: builtin/add.c:352
+#: sequencer.c:3169
 #, c-format
-msgid "adding embedded git repository: %s"
-msgstr "lägger till inbäddat git-arkiv: %s"
+msgid "Could not apply %s... %.*s"
+msgstr "Kunde inte tillämpa %s... %.*s"
 
-#: builtin/add.c:370
+#: sequencer.c:3176
 #, c-format
-msgid "Use -f if you really want to add them.\n"
-msgstr "Använd -f om du verkligen vill lägga till dem.\n"
+msgid "Could not merge %.*s"
+msgstr "Kunde inte slå ihop %.*s"
 
-#: builtin/add.c:378
-msgid "adding files failed"
-msgstr "misslyckades lägga till filer"
+#: sequencer.c:3190 sequencer.c:3194 builtin/difftool.c:641
+#, c-format
+msgid "could not copy '%s' to '%s'"
+msgstr "kunde inte kopiera in \"%s\" till \"%s\""
 
-#: builtin/add.c:416
-msgid "-A and -u are mutually incompatible"
-msgstr "-A och -u är ömsesidigt inkompatibla"
+#: sequencer.c:3221
+#, c-format
+msgid ""
+"execution failed: %s\n"
+"%sYou can fix the problem, and then run\n"
+"\n"
+"  git rebase --continue\n"
+"\n"
+msgstr ""
+"körningen misslyckades: %s\n"
+"%sDu kan rätta problemet och sedan köra\n"
+"\n"
+"\tgit rebase --continue\n"
+"\n"
 
-#: builtin/add.c:423
-msgid "Option --ignore-missing can only be used together with --dry-run"
-msgstr "Flaggan --ignore-missing kan endast användas tillsammans med --dry-run"
+#: sequencer.c:3227
+msgid "and made changes to the index and/or the working tree\n"
+msgstr "och gjorde ändringar till indexet och/eller arbetskatalogen\n"
 
-#: builtin/add.c:427
+#: sequencer.c:3233
 #, c-format
-msgid "--chmod param '%s' must be either -x or +x"
-msgstr "--chmod-parametern \"%s\" måste antingen vara -x eller +x"
+msgid ""
+"execution succeeded: %s\n"
+"but left changes to the index and/or the working tree\n"
+"Commit or stash your changes, and then run\n"
+"\n"
+"  git rebase --continue\n"
+"\n"
+msgstr ""
+"körningen lyckades: %s\n"
+"men lämnade kvar ändringar i indexet och/eller arbetskatalogen\n"
+"Checka in eller utför \"stash\" på ändringarna och kör sedan\n"
+"\n"
+"\tgit rebase --continue\n"
+"\n"
 
-#: builtin/add.c:442
+#: sequencer.c:3294
 #, c-format
-msgid "Nothing specified, nothing added.\n"
-msgstr "Inget angivet, inget tillagt.\n"
+msgid "illegal label name: '%.*s'"
+msgstr "ogiltigt etikettnamn: \"%.*s\""
 
-#: builtin/add.c:443
-#, c-format
-msgid "Maybe you wanted to say 'git add .'?\n"
-msgstr "Kanske menade du att skriva \"git add .\"?\n"
+#: sequencer.c:3348
+msgid "writing fake root commit"
+msgstr "skriver fejkad rotincheckning"
 
-#: builtin/add.c:448 builtin/check-ignore.c:177 builtin/checkout.c:280
-#: builtin/checkout.c:483 builtin/clean.c:958 builtin/commit.c:325
-#: builtin/diff-tree.c:114 builtin/mv.c:144 builtin/reset.c:241
-#: builtin/rm.c:270 builtin/submodule--helper.c:328
-msgid "index file corrupt"
-msgstr "indexfilen trasig"
+#: sequencer.c:3353
+msgid "writing squash-onto"
+msgstr "skriver squash-onto"
 
-#: builtin/am.c:414
-msgid "could not parse author script"
-msgstr "kunde inte tolka författarskript"
+#: sequencer.c:3391 builtin/rebase.c:876 builtin/rebase.c:882
+#, c-format
+msgid "failed to find tree of %s"
+msgstr "kunde inte hitta trädet för %s."
 
-#: builtin/am.c:498
+#: sequencer.c:3436
 #, c-format
-msgid "'%s' was deleted by the applypatch-msg hook"
-msgstr "\"%s\" togs bort av kroken applypatch-msg"
+msgid "could not resolve '%s'"
+msgstr "kunde inte upplösa \"%s\""
 
-#: builtin/am.c:539
+#: sequencer.c:3467
+msgid "cannot merge without a current revision"
+msgstr "kan inte slå ihop utan en aktuell incheckning"
+
+#: sequencer.c:3489
 #, c-format
-msgid "Malformed input line: '%s'."
-msgstr "Felaktig indatarad: \"%s\"."
+msgid "unable to parse '%.*s'"
+msgstr "kan inte tolka \"%.*s\""
 
-#: builtin/am.c:576
+#: sequencer.c:3498
 #, c-format
-msgid "Failed to copy notes from '%s' to '%s'"
-msgstr "Misslyckades kopiera anteckningar från \"%s\" till \"%s\""
+msgid "nothing to merge: '%.*s'"
+msgstr "inget att slå samman: \"%.*s\""
 
-#: builtin/am.c:602
-msgid "fseek failed"
-msgstr "\"fseek\" misslyckades"
+#: sequencer.c:3510
+msgid "octopus merge cannot be executed on top of a [new root]"
+msgstr "\"octopus\"-sammanslagning kan inte köras ovanpå en [ny rot]"
 
-#: builtin/am.c:790
+#: sequencer.c:3526
 #, c-format
-msgid "could not parse patch '%s'"
-msgstr "kunde inte tolka patchen \"%s\""
+msgid "could not get commit message of '%s'"
+msgstr "kunde inte läsa incheckningsmeddelande för \"%s\""
 
-#: builtin/am.c:855
-msgid "Only one StGIT patch series can be applied at once"
-msgstr "Endast en StGIT-patchserie kan tillämpas åt gången"
+#: sequencer.c:3688
+#, c-format
+msgid "could not even attempt to merge '%.*s'"
+msgstr "kunde inte ens försöka slå ihop \"%.*s\""
 
-#: builtin/am.c:903
-msgid "invalid timestamp"
-msgstr "ogiltig tidsstämpel"
+#: sequencer.c:3704
+msgid "merge: Unable to write new index file"
+msgstr "sammanslagning: Kunde inte skriva ny indexfil"
 
-#: builtin/am.c:908 builtin/am.c:920
-msgid "invalid Date line"
-msgstr "ogiltig \"Date\"-rad"
+#: sequencer.c:3773 builtin/rebase.c:733
+#, c-format
+msgid "Applied autostash.\n"
+msgstr "Tillämpade autostash.\n"
 
-#: builtin/am.c:915
-msgid "invalid timezone offset"
-msgstr "ogiltig tidszons-offset"
+#: sequencer.c:3785
+#, c-format
+msgid "cannot store %s"
+msgstr "kan inte spara %s"
 
-#: builtin/am.c:1008
-msgid "Patch format detection failed."
-msgstr "Misslyckades detektera patchformat."
+#: sequencer.c:3788 builtin/rebase.c:749 git-rebase--preserve-merges.sh:113
+#, c-format
+msgid ""
+"Applying autostash resulted in conflicts.\n"
+"Your changes are safe in the stash.\n"
+"You can run \"git stash pop\" or \"git stash drop\" at any time.\n"
+msgstr ""
+"Tillämpning av autostash gav konflikter.\n"
+"Dina ändringar är säkra i stashen.\n"
+"Du kan när som helst använda \"git stash pop\" eller \"git stash drop\".\n"
 
-#: builtin/am.c:1013 builtin/clone.c:407
+#: sequencer.c:3849
 #, c-format
-msgid "failed to create directory '%s'"
-msgstr "misslyckades skapa katalogen \"%s\""
+msgid "could not checkout %s"
+msgstr "kunde inte checka ut %s"
 
-#: builtin/am.c:1018
-msgid "Failed to split patches."
-msgstr "Misslyckades dela patchar."
+#: sequencer.c:3863
+#, c-format
+msgid "%s: not a valid OID"
+msgstr "%s: inte ett giltigt OID"
 
-#: builtin/am.c:1148 builtin/commit.c:351
-msgid "unable to write index file"
-msgstr "kan inte skriva indexfil"
+#: sequencer.c:3868 git-rebase--preserve-merges.sh:779
+msgid "could not detach HEAD"
+msgstr "kunde inte koppla från HEAD"
 
-#: builtin/am.c:1162
+#: sequencer.c:3883
 #, c-format
-msgid "When you have resolved this problem, run \"%s --continue\"."
-msgstr "När du har löst problemet, kör \"%s --continue\"."
+msgid "Stopped at HEAD\n"
+msgstr "Stoppade på HEAD\n"
 
-#: builtin/am.c:1163
+#: sequencer.c:3885
 #, c-format
-msgid "If you prefer to skip this patch, run \"%s --skip\" instead."
-msgstr "Om du hellre vill hoppa över patchen, kör \"%s --skip\" i stället."
+msgid "Stopped at %s\n"
+msgstr "Stoppade på %s\n"
 
-#: builtin/am.c:1164
+#: sequencer.c:3893
 #, c-format
-msgid "To restore the original branch and stop patching, run \"%s --abort\"."
+msgid ""
+"Could not execute the todo command\n"
+"\n"
+"    %.*s\n"
+"It has been rescheduled; To edit the command before continuing, please\n"
+"edit the todo list first:\n"
+"\n"
+"    git rebase --edit-todo\n"
+"    git rebase --continue\n"
 msgstr ""
-"För att återgå till ursprunglig gren och sluta patcha, kör \"%s --abort\"."
-
-#: builtin/am.c:1271
-msgid "Patch is empty."
-msgstr "Patchen är tom."
+"Kunde inte köra todo-kommandot\n"
+"\n"
+"    %.*s\n"
+"Det har lagts tillbaka i kön; För att redigera kommandot innan du\n"
+"fortsätter, redigera först attgöra-listan:\n"
+"\n"
+"    git rebase --edit-todo\n"
+"    git rebase --continue\n"
 
-#: builtin/am.c:1337
+#: sequencer.c:3979
 #, c-format
-msgid "invalid ident line: %.*s"
-msgstr "ogiltig ident-rad: %.*s"
+msgid "Stopped at %s...  %.*s\n"
+msgstr "Stoppade på %s... %.*s\n"
 
-#: builtin/am.c:1359
+#: sequencer.c:4050
 #, c-format
-msgid "unable to parse commit %s"
-msgstr "kunde inte tolka incheckningen %s"
+msgid "unknown command %d"
+msgstr "okänt kommando %d"
 
-#: builtin/am.c:1554
-msgid "Repository lacks necessary blobs to fall back on 3-way merge."
-msgstr ""
-"Arkivet saknar objekt som behövs för att falla tillbaka på 3-"
-"vägssammanslagning."
+#: sequencer.c:4109
+msgid "could not read orig-head"
+msgstr "kunde inte läsa orig-head"
 
-#: builtin/am.c:1556
-msgid "Using index info to reconstruct a base tree..."
-msgstr "Använder indexinfo för att återskapa ett basträd..."
+#: sequencer.c:4114
+msgid "could not read 'onto'"
+msgstr "kunde inte läsa \"onto\""
 
-#: builtin/am.c:1575
-msgid ""
-"Did you hand edit your patch?\n"
-"It does not apply to blobs recorded in its index."
-msgstr ""
-"Har du handredigerat din patch?\n"
-"Den kan inte tillämpas på blobbar som antecknats i dess index."
+#: sequencer.c:4128
+#, c-format
+msgid "could not update HEAD to %s"
+msgstr "kunde inte uppdatera HEAD till %s"
 
-#: builtin/am.c:1581
-msgid "Falling back to patching base and 3-way merge..."
-msgstr ""
-"Faller tillbaka på att patcha grundversionen och trevägssammanslagning..."
+#: sequencer.c:4221
+msgid "cannot rebase: You have unstaged changes."
+msgstr "kan inte ombasera: Du har oköade ändringar."
 
-#: builtin/am.c:1606
-msgid "Failed to merge in the changes."
-msgstr "Misslyckades slå ihop ändringarna."
+#: sequencer.c:4230
+msgid "cannot amend non-existing commit"
+msgstr "kan inte lägga till incheckning som inte finns"
 
-#: builtin/am.c:1637
-msgid "applying to an empty history"
-msgstr "tillämpar på en tom historik"
+#: sequencer.c:4232
+#, c-format
+msgid "invalid file: '%s'"
+msgstr "ogiltig fil: \"%s\""
 
-#: builtin/am.c:1683 builtin/am.c:1687
+#: sequencer.c:4234
 #, c-format
-msgid "cannot resume: %s does not exist."
-msgstr "kan inte återuppta: %s finns inte."
+msgid "invalid contents: '%s'"
+msgstr "ogiltigt innehåll: \"%s\""
 
-#: builtin/am.c:1703
-msgid "cannot be interactive without stdin connected to a terminal."
+#: sequencer.c:4237
+msgid ""
+"\n"
+"You have uncommitted changes in your working tree. Please, commit them\n"
+"first and then run 'git rebase --continue' again."
 msgstr ""
-"kan inte vara interaktiv om standard in inte är ansluten till en terminal."
+"\n"
+"Du har ändringar i arbetskatalogen som inte checkats in. Checka in dem\n"
+"först och kör sedan \"git rebase --continue\" igen."
 
-#: builtin/am.c:1708
-msgid "Commit Body is:"
-msgstr "Incheckningskroppen är:"
+#: sequencer.c:4273 sequencer.c:4312
+#, c-format
+msgid "could not write file: '%s'"
+msgstr "kunde inte skriva fil: \"%s\""
 
-#. TRANSLATORS: Make sure to include [y], [n], [e], [v] and [a]
-#. in your translation. The program will only accept English
-#. input at this point.
-#.
-#: builtin/am.c:1718
-msgid "Apply? [y]es/[n]o/[e]dit/[v]iew patch/[a]ccept all: "
-msgstr "Tillämpa? Y=ja/N=nej/E=redigera/V=visa patch/A=godta alla: "
+#: sequencer.c:4327
+msgid "could not remove CHERRY_PICK_HEAD"
+msgstr "kunde inte ta bort CHERRY_PICK_HEAD"
+
+#: sequencer.c:4334
+msgid "could not commit staged changes."
+msgstr "kunde inte checka in köade ändringar."
 
-#: builtin/am.c:1768
+#: sequencer.c:4440
 #, c-format
-msgid "Dirty index: cannot apply patches (dirty: %s)"
-msgstr "Smutsigt index: kan inte tillämpa patchar (smutsiga: %s)"
+msgid "%s: can't cherry-pick a %s"
+msgstr "%s: kan inte göra \"cherry-pick\" på typen \"%s\""
 
-#: builtin/am.c:1808 builtin/am.c:1879
+#: sequencer.c:4444
 #, c-format
-msgid "Applying: %.*s"
-msgstr "Tillämpar: %.*s"
+msgid "%s: bad revision"
+msgstr "%s: felaktig revision"
 
-#: builtin/am.c:1824
-msgid "No changes -- Patch already applied."
-msgstr "Inga ändringar -- Patchen har redan tillämpats."
+#: sequencer.c:4479
+msgid "can't revert as initial commit"
+msgstr "kan inte ångra som första incheckning"
 
-#: builtin/am.c:1832
-#, c-format
-msgid "Patch failed at %s %.*s"
-msgstr "Patch misslyckades på %s %.*s"
+#: sequencer.c:4952
+msgid "make_script: unhandled options"
+msgstr "make_script: flaggor som inte stöds"
 
-#: builtin/am.c:1838
-msgid "Use 'git am --show-current-patch' to see the failed patch"
-msgstr ""
-"Använd \"git am --show-current-patch\" för att se patchen som misslyckades"
+#: sequencer.c:4955
+msgid "make_script: error preparing revisions"
+msgstr "make_script: fel när revisioner skulle förberedas"
 
-#: builtin/am.c:1882
+#: sequencer.c:5113
 msgid ""
-"No changes - did you forget to use 'git add'?\n"
-"If there is nothing left to stage, chances are that something else\n"
-"already introduced the same changes; you might want to skip this patch."
+"You can fix this with 'git rebase --edit-todo' and then run 'git rebase --"
+"continue'.\n"
+"Or you can abort the rebase with 'git rebase --abort'.\n"
 msgstr ""
-"Inga ändringar - glömde du använda \"git add\"?\n"
-"Om det inte är något kvar att köa kan det hända att något annat redan\n"
-"introducerat samma ändringar; kanske du bör hoppa över patchen."
+"Du kan rätta detta med \"git rebase --edit-todo\" följt av \"git rebase --"
+"continue\".\n"
+"Avbryt ombaseringen med \"git rebase --abort\".\n"
 
-#: builtin/am.c:1889
-msgid ""
-"You still have unmerged paths in your index.\n"
-"You should 'git add' each file with resolved conflicts to mark them as "
-"such.\n"
-"You might run `git rm` on a file to accept \"deleted by them\" for it."
-msgstr ""
-"Du har fortfarande ej sammanslagna sökvägar i indexet.\n"
-"Du bör köra ”git add” på filer med lösta konflikter för att ange dem som "
-"lösta.\n"
-"Du kan köra ”git rm” för att godta ”borttagen av dem” för den."
+#: sequencer.c:5226 sequencer.c:5243
+msgid "nothing to do"
+msgstr "inget att göra"
+
+#: sequencer.c:5257
+msgid "could not skip unnecessary pick commands"
+msgstr "kunde inte hoppa över onödiga \"pick\"-kommandon"
+
+#: sequencer.c:5351
+msgid "the script was already rearranged."
+msgstr "skriptet har redan omordnats."
 
-#: builtin/am.c:1996 builtin/am.c:2000 builtin/am.c:2012 builtin/reset.c:324
-#: builtin/reset.c:332
+#: setup.c:124
 #, c-format
-msgid "Could not parse object '%s'."
-msgstr "Kan inte tolka objektet ”%s”."
+msgid "'%s' is outside repository"
+msgstr "\"%s\" är utanför arkivet"
 
-#: builtin/am.c:2048
-msgid "failed to clean index"
-msgstr "misslyckades städa upp indexet"
+#: setup.c:174
+#, c-format
+msgid ""
+"%s: no such path in the working tree.\n"
+"Use 'git <command> -- <path>...' to specify paths that do not exist locally."
+msgstr ""
+"%s: sökvägen finns inte i arbetskatalogen.\n"
+"Använd \"git <kommando> -- <sökväg>..\" för att ange sökvägar som inte finns "
+"lokalt."
 
-#: builtin/am.c:2083
+#: setup.c:187
+#, c-format
 msgid ""
-"You seem to have moved HEAD since the last 'am' failure.\n"
-"Not rewinding to ORIG_HEAD"
+"ambiguous argument '%s': unknown revision or path not in the working tree.\n"
+"Use '--' to separate paths from revisions, like this:\n"
+"'git <command> [<revision>...] -- [<file>...]'"
 msgstr ""
-"Du verkar ha flyttat HEAD sedan \"am\" sist misslyckades.\n"
-"Återställer inte till ORIG_HEAD"
+"tvetydigt argument \"%s\": okänd revision eller sökväg inte i "
+"arbetskatalogen.\n"
+"Använd \"--\" för att skilja sökvägar från revisioner, så här:\n"
+"\"git <kommando> [<revision>...] -- [<fil>...]\""
 
-#: builtin/am.c:2174
+#: setup.c:236
 #, c-format
-msgid "Invalid value for --patch-format: %s"
-msgstr "Felaktigt värde för --patch-format: %s"
+msgid "option '%s' must come before non-option arguments"
+msgstr "flaggan \"%s\" måste anges före argument som inte är flaggor"
 
-#: builtin/am.c:2210
-msgid "git am [<options>] [(<mbox> | <Maildir>)...]"
-msgstr "git am [<flaggor>] [(<mbox> | <Maildir>)...]"
+#: setup.c:255
+#, c-format
+msgid ""
+"ambiguous argument '%s': both revision and filename\n"
+"Use '--' to separate paths from revisions, like this:\n"
+"'git <command> [<revision>...] -- [<file>...]'"
+msgstr ""
+"tvetydigt argument \"%s\": både revision och filnamn\n"
+"Använd \"--\" för att skilja sökvägar från revisioner, så här:\n"
+"\"git <kommando> [<revision>...] -- [<fil>...]\""
 
-#: builtin/am.c:2211
-msgid "git am [<options>] (--continue | --skip | --abort)"
-msgstr "git am [<flaggor>] (--continue | --skip | --abort)"
+#: setup.c:391
+msgid "unable to set up work tree using invalid config"
+msgstr "kan inte skapa arbetskatalog med felaktig konfiguration"
 
-#: builtin/am.c:2217
-msgid "run interactively"
-msgstr "kör interaktivt"
+#: setup.c:395
+msgid "this operation must be run in a work tree"
+msgstr "funktionen måste köras i en arbetskatalog"
 
-#: builtin/am.c:2219
-msgid "historical option -- no-op"
-msgstr "historisk flagga -- no-op"
+#: setup.c:541
+#, c-format
+msgid "Expected git repo version <= %d, found %d"
+msgstr "Förväntade git-arkivversion <= %d, hittade %d"
 
-#: builtin/am.c:2221
-msgid "allow fall back on 3way merging if needed"
-msgstr "tillåt falla tillbaka på trevägssammanslagning om nödvändigt"
+#: setup.c:549
+msgid "unknown repository extensions found:"
+msgstr "okända arkivutökningar hittades:"
 
-#: builtin/am.c:2222 builtin/init-db.c:484 builtin/prune-packed.c:57
-#: builtin/repack.c:192
-msgid "be quiet"
-msgstr "var tyst"
+#: setup.c:568
+#, c-format
+msgid "error opening '%s'"
+msgstr "fel vid öppning av \"%s\""
 
-#: builtin/am.c:2224
-msgid "add a Signed-off-by line to the commit message"
-msgstr "lägg till \"Signed-off-by\"-rad i incheckningsmeddelandet"
+#: setup.c:570
+#, c-format
+msgid "too large to be a .git file: '%s'"
+msgstr "för stor för att vara en .git-fil: \"%s\""
 
-#: builtin/am.c:2227
-msgid "recode into utf8 (default)"
-msgstr "koda om till utf8 (standard)"
+#: setup.c:572
+#, c-format
+msgid "error reading %s"
+msgstr "fel vid läsning av %s"
 
-#: builtin/am.c:2229
-msgid "pass -k flag to git-mailinfo"
-msgstr "sänd flaggan -k till git-mailinfo"
+#: setup.c:574
+#, c-format
+msgid "invalid gitfile format: %s"
+msgstr "ogiltigt gitfilformat: %s"
 
-#: builtin/am.c:2231
-msgid "pass -b flag to git-mailinfo"
-msgstr "sänd flaggan -b till git-mailinfo"
+#: setup.c:576
+#, c-format
+msgid "no path in gitfile: %s"
+msgstr "ingen sökväg i gitfil: %s"
 
-#: builtin/am.c:2233
-msgid "pass -m flag to git-mailinfo"
-msgstr "sänd flaggan -m till git-mailinfo"
-
-#: builtin/am.c:2235
-msgid "pass --keep-cr flag to git-mailsplit for mbox format"
-msgstr "sänd flaggan --keep-cr till git-mailsplit för mbox-formatet"
-
-#: builtin/am.c:2238
-msgid "do not pass --keep-cr flag to git-mailsplit independent of am.keepcr"
-msgstr "sänd inte flaggan --keep-cr till git-mailsplit oberoende av am.keepcr"
+#: setup.c:578
+#, c-format
+msgid "not a git repository: %s"
+msgstr "inte ett git-arkiv: %s"
 
-#: builtin/am.c:2241
-msgid "strip everything before a scissors line"
-msgstr "ta bort allting före en saxlinje"
+#: setup.c:677
+#, c-format
+msgid "'$%s' too big"
+msgstr "\"$%s\" för stor"
 
-#: builtin/am.c:2243 builtin/am.c:2246 builtin/am.c:2249 builtin/am.c:2252
-#: builtin/am.c:2255 builtin/am.c:2258 builtin/am.c:2261 builtin/am.c:2264
-#: builtin/am.c:2270
-msgid "pass it through git-apply"
-msgstr "sänd det genom git-apply"
+#: setup.c:691
+#, c-format
+msgid "not a git repository: '%s'"
+msgstr "inte ett git-arkiv: \"%s\""
 
-#: builtin/am.c:2260 builtin/commit.c:1332 builtin/fmt-merge-msg.c:665
-#: builtin/fmt-merge-msg.c:668 builtin/grep.c:853 builtin/merge.c:208
-#: builtin/pull.c:150 builtin/pull.c:208 builtin/repack.c:201
-#: builtin/repack.c:205 builtin/repack.c:207 builtin/show-branch.c:631
-#: builtin/show-ref.c:169 builtin/tag.c:383 parse-options.h:144
-#: parse-options.h:146 parse-options.h:258
-msgid "n"
-msgstr "n"
+#: setup.c:720 setup.c:722 setup.c:753
+#, c-format
+msgid "cannot chdir to '%s'"
+msgstr "kan inte byta katalog (chdir) till \"%s\""
 
-#: builtin/am.c:2266 builtin/branch.c:632 builtin/for-each-ref.c:38
-#: builtin/replace.c:543 builtin/tag.c:419 builtin/verify-tag.c:39
-msgid "format"
-msgstr "format"
+#: setup.c:725 setup.c:781 setup.c:791 setup.c:830 setup.c:838
+msgid "cannot come back to cwd"
+msgstr "kan inte gå tillbaka till arbetskatalogen (cwd)"
 
-#: builtin/am.c:2267
-msgid "format the patch(es) are in"
-msgstr "format för patch(ar)"
+#: setup.c:852
+#, c-format
+msgid "failed to stat '%*s%s%s'"
+msgstr "misslyckades ta status på \"%*ss%s%s\""
 
-#: builtin/am.c:2273
-msgid "override error message when patch failure occurs"
-msgstr "överstyr felmeddelanden när patchfel uppstår"
+#: setup.c:1090
+msgid "Unable to read current working directory"
+msgstr "Kan inte läsa aktuell arbetskatalog"
 
-#: builtin/am.c:2275
-msgid "continue applying patches after resolving a conflict"
-msgstr "fortsätt applicera patchar efter att ha löst en konflikt"
+#: setup.c:1099 setup.c:1105
+#, c-format
+msgid "cannot change to '%s'"
+msgstr "kan inte byta till \"%s\""
 
-#: builtin/am.c:2278
-msgid "synonyms for --continue"
-msgstr "synonymer till --continue"
+#: setup.c:1110
+#, c-format
+msgid "not a git repository (or any of the parent directories): %s"
+msgstr "inte ett git-arkiv (eller någon av föräldrakatalogerna): %s"
 
-#: builtin/am.c:2281
-msgid "skip the current patch"
-msgstr "hoppa över den aktuella grenen"
+#: setup.c:1116
+#, c-format
+msgid ""
+"not a git repository (or any parent up to mount point %s)\n"
+"Stopping at filesystem boundary (GIT_DISCOVERY_ACROSS_FILESYSTEM not set)."
+msgstr ""
+"inte ett git-arkiv (eller någon av föräldrakatalogerna upp till "
+"monteringspunkten %s)\n"
+"Stoppar vid filsystemsgräns (GIT_DISCOVERY_ACROSS_FILESYSTEM är inte satt)."
 
-#: builtin/am.c:2284
-msgid "restore the original branch and abort the patching operation."
-msgstr "återställ originalgrenen och avbryt patchningen."
+#: setup.c:1227
+#, c-format
+msgid ""
+"problem with core.sharedRepository filemode value (0%.3o).\n"
+"The owner of files must always have read and write permissions."
+msgstr ""
+"problem med filläges-värdet i core.sharedRepository (0%.3o).\n"
+"Ägaren av filerna måste alltid ha läs- och skrivbehörighet."
 
-#: builtin/am.c:2287
-msgid "abort the patching operation but keep HEAD where it is."
-msgstr "avbryt patchningen men behåll HEAD där det är."
+#: setup.c:1271
+msgid "open /dev/null or dup failed"
+msgstr "misslyckades öppna /dev/null eller \"dup\""
 
-#: builtin/am.c:2290
-msgid "show the patch being applied."
-msgstr "visa patchen som tillämpas."
+#: setup.c:1286
+msgid "fork failed"
+msgstr "\"fork\" misslyckades"
 
-#: builtin/am.c:2294
-msgid "lie about committer date"
-msgstr "ljug om incheckningsdatum"
+#: setup.c:1291
+msgid "setsid failed"
+msgstr "\"setsid\" misslyckades"
 
-#: builtin/am.c:2296
-msgid "use current timestamp for author date"
-msgstr "använd nuvarande tidsstämpel för författardatum"
+#: sha1-file.c:452
+#, c-format
+msgid "object directory %s does not exist; check .git/objects/info/alternates"
+msgstr "objektkatalogen %s finns inte; se .git/objects/info/alternates"
 
-#: builtin/am.c:2298 builtin/commit.c:1468 builtin/merge.c:239
-#: builtin/pull.c:183 builtin/revert.c:112 builtin/tag.c:399
-msgid "key-id"
-msgstr "nyckel-id"
+#: sha1-file.c:503
+#, c-format
+msgid "unable to normalize alternate object path: %s"
+msgstr "kunde inte normalisera supplerande objektsökväg: %s"
 
-#: builtin/am.c:2299
-msgid "GPG-sign commits"
-msgstr "GPG-signera incheckningar"
+#: sha1-file.c:575
+#, c-format
+msgid "%s: ignoring alternate object stores, nesting too deep"
+msgstr "%s: ignorerar supplerande objektlager, för djup nästling"
 
-#: builtin/am.c:2302
-msgid "(internal use for git-rebase)"
-msgstr "(används internt av git-rebase)"
+#: sha1-file.c:582
+#, c-format
+msgid "unable to normalize object directory: %s"
+msgstr "kan inte normalisera objektkatalogen: %s"
 
-#: builtin/am.c:2320
-msgid ""
-"The -b/--binary option has been a no-op for long time, and\n"
-"it will be removed. Please do not use it anymore."
-msgstr ""
-"Flaggan -b/--binary har varit utan funktion länge, och\n"
-"kommer tas bort. Vi ber dig att inte använda den längre."
+#: sha1-file.c:625
+msgid "unable to fdopen alternates lockfile"
+msgstr "kan inte utföra \"fdopen\" på suppleantlåsfil"
 
-#: builtin/am.c:2327
-msgid "failed to read the index"
-msgstr "misslyckades läsa indexet"
+#: sha1-file.c:643
+msgid "unable to read alternates file"
+msgstr "kan inte läsa \"alternates\"-filen"
+
+#: sha1-file.c:650
+msgid "unable to move new alternates file into place"
+msgstr "kan inte flytta ny \"alternates\"-fil på plats"
 
-#: builtin/am.c:2342
+#: sha1-file.c:685
 #, c-format
-msgid "previous rebase directory %s still exists but mbox given."
-msgstr "tidigare rebase-katalog %s finns fortfarande, men mbox angavs."
+msgid "path '%s' does not exist"
+msgstr "sökvägen \"%s\" finns inte"
 
-#: builtin/am.c:2366
+#: sha1-file.c:711
 #, c-format
-msgid ""
-"Stray %s directory found.\n"
-"Use \"git am --abort\" to remove it."
-msgstr ""
-"Kvarbliven katalog %s hittades.\n"
-"Använd \"git am --abort\" för att ta bort den."
+msgid "reference repository '%s' as a linked checkout is not supported yet."
+msgstr "referensarkivet \"%s\" som en länkad utcheckning stöds inte ännu."
 
-#: builtin/am.c:2372
-msgid "Resolve operation not in progress, we are not resuming."
-msgstr "Lösningsoperation pågår inte, vi återupptar inte."
+#: sha1-file.c:717
+#, c-format
+msgid "reference repository '%s' is not a local repository."
+msgstr "referensarkivet \"%s\" är inte ett lokalt arkiv."
 
-#: builtin/apply.c:8
-msgid "git apply [<options>] [<patch>...]"
-msgstr "git apply [<flaggor>] [<patch>...]"
+#: sha1-file.c:723
+#, c-format
+msgid "reference repository '%s' is shallow"
+msgstr "referensarkivet \"%s\" är grunt"
 
-#: builtin/archive.c:17
+#: sha1-file.c:731
 #, c-format
-msgid "could not create archive file '%s'"
-msgstr "kunde inte skapa arkivfilen \"%s\""
+msgid "reference repository '%s' is grafted"
+msgstr "referensarkivet \"%s\" är ympat"
 
-#: builtin/archive.c:20
-msgid "could not redirect output"
-msgstr "kunde inte omdirigera utdata"
+#: sha1-file.c:791
+#, c-format
+msgid "invalid line while parsing alternate refs: %s"
+msgstr "felaktig rad vid tolkning av supplerande referenser: %s"
 
-#: builtin/archive.c:37
-msgid "git archive: Remote with no URL"
-msgstr "git archive: Fjärr utan URL"
+#: sha1-file.c:943
+#, c-format
+msgid "attempting to mmap %<PRIuMAX> over limit %<PRIuMAX>"
+msgstr "försök att utföra \"mmap\" på %<PRIuMAX> över gränsen %<PRIuMAX>"
 
-#: builtin/archive.c:58
-msgid "git archive: expected ACK/NAK, got a flush packet"
-msgstr "git archive: förväntade ACK/NAK, fick flush-paket"
+#: sha1-file.c:964
+msgid "mmap failed"
+msgstr "mmap misslyckades"
 
-#: builtin/archive.c:61
+#: sha1-file.c:1128
 #, c-format
-msgid "git archive: NACK %s"
-msgstr "git archive: NACK %s"
+msgid "object file %s is empty"
+msgstr "objektfilen %s är tom"
 
-#: builtin/archive.c:64
-msgid "git archive: protocol error"
-msgstr "git archive: protokollfel"
+#: sha1-file.c:1252 sha1-file.c:2392
+#, c-format
+msgid "corrupt loose object '%s'"
+msgstr "trasigt löst objekt \"%s\""
 
-#: builtin/archive.c:68
-msgid "git archive: expected a flush"
-msgstr "git archive: förväntade en tömning (flush)"
+#: sha1-file.c:1254 sha1-file.c:2396
+#, c-format
+msgid "garbage at end of loose object '%s'"
+msgstr "skräp i slutet av löst objekt \"%s\""
 
-#: builtin/bisect--helper.c:12
-msgid "git bisect--helper --next-all [--no-checkout]"
-msgstr "git bisect--helper --next-all [--no-checkout]"
+#: sha1-file.c:1296
+msgid "invalid object type"
+msgstr "felaktig objekttyp"
 
-#: builtin/bisect--helper.c:13
-msgid "git bisect--helper --write-terms <bad_term> <good_term>"
-msgstr "git bisect--helper --write-terms <term-för-fel> <term-för-rätt>"
+#: sha1-file.c:1380
+#, c-format
+msgid "unable to unpack %s header with --allow-unknown-type"
+msgstr "kan inte packa upp %s-huvud med --allow-unknown-type"
 
-#: builtin/bisect--helper.c:14
-msgid "git bisect--helper --bisect-clean-state"
-msgstr "git bisect--helper --bisect-clean-state"
+#: sha1-file.c:1383
+#, c-format
+msgid "unable to unpack %s header"
+msgstr "kan inte packa upp %s-huvudet"
 
-#: builtin/bisect--helper.c:46
+#: sha1-file.c:1389
 #, c-format
-msgid "'%s' is not a valid term"
-msgstr "\"%s\" är inte en giltig term"
+msgid "unable to parse %s header with --allow-unknown-type"
+msgstr "kan inte tolka %s-huvud med --allow-unknown-type"
 
-#: builtin/bisect--helper.c:50
+#: sha1-file.c:1392
 #, c-format
-msgid "can't use the builtin command '%s' as a term"
-msgstr "kan inte använda det inbyggda kommandot \"%s\" som term"
+msgid "unable to parse %s header"
+msgstr "kan inte tolka %s-huvud"
 
-#: builtin/bisect--helper.c:60
+#: sha1-file.c:1584
 #, c-format
-msgid "can't change the meaning of the term '%s'"
-msgstr "kan inte ändra betydelsen av termen \"%s\""
+msgid "failed to read object %s"
+msgstr "misslyckades läsa objektet %s"
 
-#: builtin/bisect--helper.c:71
-msgid "please use two different terms"
-msgstr "termerna måste vara olika"
+#: sha1-file.c:1588
+#, c-format
+msgid "replacement %s not found for %s"
+msgstr "ersättningen %s hittades inte för %s"
 
-#: builtin/bisect--helper.c:78
-msgid "could not open the file BISECT_TERMS"
-msgstr "kunde inte öppna filen BISECT_TERMS"
+#: sha1-file.c:1592
+#, c-format
+msgid "loose object %s (stored in %s) is corrupt"
+msgstr "löst objekt %s (lagrat i %s) är trasigt"
 
-#: builtin/bisect--helper.c:120
-msgid "perform 'git bisect next'"
-msgstr "utför 'git bisect next'"
+#: sha1-file.c:1596
+#, c-format
+msgid "packed object %s (stored in %s) is corrupt"
+msgstr "packat objekt %s (lagrat i %s) är trasigt"
 
-#: builtin/bisect--helper.c:122
-msgid "write the terms to .git/BISECT_TERMS"
-msgstr "skriv termerna i .git/BISECT_TERMS"
+#: sha1-file.c:1699
+#, c-format
+msgid "unable to write file %s"
+msgstr "kunde inte skriva filen %s"
 
-#: builtin/bisect--helper.c:124
-msgid "cleanup the bisection state"
-msgstr "städar upp bisect-tillstånd"
+#: sha1-file.c:1706
+#, c-format
+msgid "unable to set permission to '%s'"
+msgstr "kan inte sätta behörigheten till \"%s\""
 
-#: builtin/bisect--helper.c:126
-msgid "check for expected revs"
-msgstr "kontrollera för förväntade versioner"
+#: sha1-file.c:1713
+msgid "file write error"
+msgstr "fel vid skrivning av fil"
 
-#: builtin/bisect--helper.c:128
-msgid "update BISECT_HEAD instead of checking out the current commit"
-msgstr "uppdatera BISECT_HEAD istället för att checka ut aktuell incheckning"
+#: sha1-file.c:1732
+msgid "error when closing loose object file"
+msgstr "fel vid stängning av fil för löst objekt"
 
-#: builtin/bisect--helper.c:143
-msgid "--write-terms requires two arguments"
-msgstr "--write-terms kräver två argument"
+#: sha1-file.c:1797
+#, c-format
+msgid "insufficient permission for adding an object to repository database %s"
+msgstr ""
+"otillräcklig behörighet för att lägga till objekt till arkivdatabasen %s"
 
-#: builtin/bisect--helper.c:147
-msgid "--bisect-clean-state requires no arguments"
-msgstr "--bisect-clean-state tar inga argument"
+#: sha1-file.c:1799
+msgid "unable to create temporary file"
+msgstr "kan inte skapa temporär fil"
 
-#: builtin/blame.c:29
-msgid "git blame [<options>] [<rev-opts>] [<rev>] [--] <file>"
-msgstr "git blame [<flaggor>] [<rev-flaggor>] [<rev>] [--] <fil>"
+#: sha1-file.c:1823
+msgid "unable to write loose object file"
+msgstr "kunde inte skriva fil för löst objekt"
 
-#: builtin/blame.c:34
-msgid "<rev-opts> are documented in git-rev-list(1)"
-msgstr "<rev-flaggor> dokumenteras i git-rev-list(1)"
+#: sha1-file.c:1829
+#, c-format
+msgid "unable to deflate new object %s (%d)"
+msgstr "kan inte utföra \"deflate\" på nytt objekt %s (%d)"
 
-#: builtin/blame.c:404
+#: sha1-file.c:1833
 #, c-format
-msgid "expecting a color: %s"
-msgstr "förväntade en färg: %s"
+msgid "deflateEnd on object %s failed (%d)"
+msgstr "\"deflateend\" på objektet %s misslyckades (%d)"
 
-#: builtin/blame.c:411
-msgid "must end with a color"
-msgstr "måste sluta med en färg"
+#: sha1-file.c:1837
+#, c-format
+msgid "confused by unstable object source data for %s"
+msgstr "förvirrad av instabil objektkälldata för %s"
 
-#: builtin/blame.c:697
+#: sha1-file.c:1847 builtin/pack-objects.c:925
 #, c-format
-msgid "invalid color '%s' in color.blame.repeatedLines"
-msgstr "felaktig färg \"%s\" i color.blame.repeatedLines"
+msgid "failed utime() on %s"
+msgstr "\"utime()\" misslyckades på %s"
 
-#: builtin/blame.c:715
-msgid "invalid value for blame.coloring"
-msgstr "ogiltigt värde för blame.coloring"
+#: sha1-file.c:1922
+#, c-format
+msgid "cannot read object for %s"
+msgstr "kan inte läsa objekt för %s"
 
-#: builtin/blame.c:786
-msgid "Show blame entries as we find them, incrementally"
-msgstr "Visa klandringsposter när vi hittar dem, interaktivt"
+#: sha1-file.c:1962
+msgid "corrupt commit"
+msgstr "trasik incheckning"
 
-#: builtin/blame.c:787
-msgid "Show blank SHA-1 for boundary commits (Default: off)"
-msgstr "Visa blank SHA-1 för gränsincheckningar (Standard: av)"
+#: sha1-file.c:1970
+msgid "corrupt tag"
+msgstr "trasig tagg"
 
-#: builtin/blame.c:788
-msgid "Do not treat root commits as boundaries (Default: off)"
-msgstr "Behandla inte rotincheckningar som gränser (Standard: av)"
+#: sha1-file.c:2069
+#, c-format
+msgid "read error while indexing %s"
+msgstr "läsfel vid indexering av %s"
 
-#: builtin/blame.c:789
-msgid "Show work cost statistics"
-msgstr "Visa statistik över arbetskostnad"
+#: sha1-file.c:2072
+#, c-format
+msgid "short read while indexing %s"
+msgstr "för lite lästes vid indexering av %s"
 
-#: builtin/blame.c:790
-msgid "Force progress reporting"
-msgstr "Tvinga förloppsrapportering"
+#: sha1-file.c:2145 sha1-file.c:2154
+#, c-format
+msgid "%s: failed to insert into database"
+msgstr "%s: misslyckades lägga in i databasen"
 
-#: builtin/blame.c:791
-msgid "Show output score for blame entries"
-msgstr "Visa utdatapoäng för klandringsposter"
+#: sha1-file.c:2160
+#, c-format
+msgid "%s: unsupported file type"
+msgstr "%s: filtypen stöds ej"
 
-#: builtin/blame.c:792
-msgid "Show original filename (Default: auto)"
-msgstr "Visa originalfilnamn (Standard: auto)"
+#: sha1-file.c:2184
+#, c-format
+msgid "%s is not a valid object"
+msgstr "%s är inte ett giltigt objekt"
 
-#: builtin/blame.c:793
-msgid "Show original linenumber (Default: off)"
-msgstr "Visa ursprungligt radnummer (Standard: av)"
+#: sha1-file.c:2186
+#, c-format
+msgid "%s is not a valid '%s' object"
+msgstr "%s är inte ett giltigt \"%s\"-objekt"
 
-#: builtin/blame.c:794
-msgid "Show in a format designed for machine consumption"
-msgstr "Visa i ett format avsett för maskinkonsumtion"
+#: sha1-file.c:2213 builtin/index-pack.c:155
+#, c-format
+msgid "unable to open %s"
+msgstr "kan inte öppna %s"
 
-#: builtin/blame.c:795
-msgid "Show porcelain format with per-line commit information"
-msgstr "Visa porslinsformat med per-rad-incheckningsinformation"
+#: sha1-file.c:2403 sha1-file.c:2455
+#, c-format
+msgid "hash mismatch for %s (expected %s)"
+msgstr "hash stämmer inte för %s (förväntade %s)"
 
-#: builtin/blame.c:796
-msgid "Use the same output mode as git-annotate (Default: off)"
-msgstr "Använd samma utdataläge som git-annotate (Standard: av)"
+#: sha1-file.c:2427
+#, c-format
+msgid "unable to mmap %s"
+msgstr "kan inte utföra \"mmap\" för %s"
 
-#: builtin/blame.c:797
-msgid "Show raw timestamp (Default: off)"
-msgstr "Visa rå tidsstämpel (Standard: av)"
+#: sha1-file.c:2432
+#, c-format
+msgid "unable to unpack header of %s"
+msgstr "kan inte packa upp huvud för %s"
 
-#: builtin/blame.c:798
-msgid "Show long commit SHA1 (Default: off)"
-msgstr "Visa lång inchecknings-SHA1 (Standard: av)"
+#: sha1-file.c:2438
+#, c-format
+msgid "unable to parse header of %s"
+msgstr "kan inte tolka huvud för %s"
 
-#: builtin/blame.c:799
-msgid "Suppress author name and timestamp (Default: off)"
-msgstr "Undertryck författarnamn och tidsstämpel (Standard: av)"
+#: sha1-file.c:2449
+#, c-format
+msgid "unable to unpack contents of %s"
+msgstr "kan inte tolka innehåll i %s"
 
-#: builtin/blame.c:800
-msgid "Show author email instead of name (Default: off)"
-msgstr "Visa författarens e-post istället för namn (Standard: av)"
+#: sha1-name.c:487
+#, c-format
+msgid "short SHA1 %s is ambiguous"
+msgstr "kort SHA1 %s är tvetydig"
 
-#: builtin/blame.c:801
-msgid "Ignore whitespace differences"
-msgstr "Ignorera ändringar i blanksteg"
+#: sha1-name.c:498
+msgid "The candidates are:"
+msgstr "Kandidaterna är:"
 
-#: builtin/blame.c:802
-msgid "color redundant metadata from previous line differently"
-msgstr "färglägg redundant metadata från tidigare rader annorlunda"
+#: sha1-name.c:797
+msgid ""
+"Git normally never creates a ref that ends with 40 hex characters\n"
+"because it will be ignored when you just specify 40-hex. These refs\n"
+"may be created by mistake. For example,\n"
+"\n"
+"  git switch -c $br $(git rev-parse ...)\n"
+"\n"
+"where \"$br\" is somehow empty and a 40-hex ref is created. Please\n"
+"examine these refs and maybe delete them. Turn this message off by\n"
+"running \"git config advice.objectNameWarning false\""
+msgstr ""
+"Git skapar normalt aldrig referenser som slutar med 40 hexadecimala\n"
+"tecken, då detta ignoreras när du anger 40-hex enbart. Dessa\n"
+"referenser kan skapas av misstag. Till exempel, för\n"
+"\n"
+"  git switch -c $br $(git rev-parse ...)\n"
+"\n"
+"där \"$br\" på något sätt blivit tomt och en 40-hex-referens skapats.\n"
+"Undersök referenserna och ta kanske bort dem. Stäng av meddelandet\n"
+"genom att köra \"git config advice.objectNameWarning false\""
 
-#: builtin/blame.c:803
-msgid "color lines by age"
-msgstr "färglägg rader efter ålder"
+#. TRANSLATORS: IEC 80000-13:2008 gibibyte
+#: strbuf.c:822
+#, c-format
+msgid "%u.%2.2u GiB"
+msgstr "%u,%2.2u GiB"
 
-#: builtin/blame.c:810
-msgid "Use an experimental heuristic to improve diffs"
-msgstr "Använd en experimentell algoritm för att förbättra diffar"
+#. TRANSLATORS: IEC 80000-13:2008 gibibyte/second
+#: strbuf.c:824
+#, c-format
+msgid "%u.%2.2u GiB/s"
+msgstr "%u,%2.2u GiB/s"
 
-#: builtin/blame.c:812
-msgid "Spend extra cycles to find better match"
-msgstr "Slösa extra cykler med att hitta bättre träff"
+#. TRANSLATORS: IEC 80000-13:2008 mebibyte
+#: strbuf.c:832
+#, c-format
+msgid "%u.%2.2u MiB"
+msgstr "%u,%2.2u MiB"
 
-#: builtin/blame.c:813
-msgid "Use revisions from <file> instead of calling git-rev-list"
-msgstr "Använd revisioner från <fil> istället för att anropa git-rev-list"
+#. TRANSLATORS: IEC 80000-13:2008 mebibyte/second
+#: strbuf.c:834
+#, c-format
+msgid "%u.%2.2u MiB/s"
+msgstr "%u,%2.2u MiB/s"
 
-#: builtin/blame.c:814
-msgid "Use <file>'s contents as the final image"
-msgstr "Använd <fil>s innehåll som slutgiltig bild"
+#. TRANSLATORS: IEC 80000-13:2008 kibibyte
+#: strbuf.c:841
+#, c-format
+msgid "%u.%2.2u KiB"
+msgstr "%u,%2.2u KiB"
 
-#: builtin/blame.c:815 builtin/blame.c:816
-msgid "score"
-msgstr "poäng"
+#. TRANSLATORS: IEC 80000-13:2008 kibibyte/second
+#: strbuf.c:843
+#, c-format
+msgid "%u.%2.2u KiB/s"
+msgstr "%u,%2.2u KiB/s"
 
-#: builtin/blame.c:815
-msgid "Find line copies within and across files"
-msgstr "Hitta kopierade rader inuti och mellan filer"
+#. TRANSLATORS: IEC 80000-13:2008 byte
+#: strbuf.c:849
+#, c-format
+msgid "%u byte"
+msgid_plural "%u bytes"
+msgstr[0] "%u byte"
+msgstr[1] "%u bytes"
 
-#: builtin/blame.c:816
-msgid "Find line movements within and across files"
-msgstr "Hitta flyttade rader inuti och mellan filer"
+#. TRANSLATORS: IEC 80000-13:2008 byte/second
+#: strbuf.c:851
+#, c-format
+msgid "%u byte/s"
+msgid_plural "%u bytes/s"
+msgstr[0] "%u byte/s"
+msgstr[1] "%u bytes/s"
 
-#: builtin/blame.c:817
-msgid "n,m"
-msgstr "n,m"
+#: strbuf.c:1149
+#, c-format
+msgid "could not edit '%s'"
+msgstr "kunde inte redigera \"%s\""
 
-#: builtin/blame.c:817
-msgid "Process only line range n,m, counting from 1"
-msgstr "Behandla endast radintervallet n,m, med början på 1"
+#: submodule.c:114 submodule.c:143
+msgid "Cannot change unmerged .gitmodules, resolve merge conflicts first"
+msgstr ""
+"Kan inte ändra .gitmodules-fil som inte slagits ihop, lös "
+"sammanslagningskonflikter först"
 
-#: builtin/blame.c:866
-msgid "--progress can't be used with --incremental or porcelain formats"
-msgstr "--progress kan inte användas med --incremental eller porslinsformat"
+#: submodule.c:118 submodule.c:147
+#, c-format
+msgid "Could not find section in .gitmodules where path=%s"
+msgstr "Hittade inte någon sektion i .gitmodules där sökväg=%s"
 
-#. TRANSLATORS: This string is used to tell us the
-#. maximum display width for a relative timestamp in
-#. "git blame" output.  For C locale, "4 years, 11
-#. months ago", which takes 22 places, is the longest
-#. among various forms of relative timestamps, but
-#. your language may need more or fewer display
-#. columns.
-#.
-#: builtin/blame.c:917
-msgid "4 years, 11 months ago"
-msgstr "4 år, 11 månader sedan"
+#: submodule.c:154
+#, c-format
+msgid "Could not remove .gitmodules entry for %s"
+msgstr "Kunde inte ta bort .gitmodules-posten för %s"
+
+#: submodule.c:165
+msgid "staging updated .gitmodules failed"
+msgstr "misslyckades köa uppdaterad .gitmodules"
 
-#: builtin/blame.c:1003
+#: submodule.c:327
 #, c-format
-msgid "file %s has only %lu line"
-msgid_plural "file %s has only %lu lines"
-msgstr[0] "filen %s har bara %lu rad"
-msgstr[1] "filen %s har bara %lu rader"
+msgid "in unpopulated submodule '%s'"
+msgstr "i ej utcheckad undermodul \"%s\""
 
-#: builtin/blame.c:1049
-msgid "Blaming lines"
-msgstr "Klandra rader"
+#: submodule.c:358
+#, c-format
+msgid "Pathspec '%s' is in submodule '%.*s'"
+msgstr "Sökvägsangivelsen \"%s\" är i undermodulen \"%.*s\""
 
-#: builtin/branch.c:27
-msgid "git branch [<options>] [-r | -a] [--merged | --no-merged]"
-msgstr "git branch [<flaggor>] [-r | -a] [--merged | --no-merged]"
+#: submodule.c:910
+#, c-format
+msgid "submodule entry '%s' (%s) is a %s, not a commit"
+msgstr "undermodulposten \"%s\" (%s) är en %s, inte en incheckning"
 
-#: builtin/branch.c:28
-msgid "git branch [<options>] [-l] [-f] <branch-name> [<start-point>]"
-msgstr "git branch [<flaggor>] [-l] [-f] <grennamn> [<startpunkt>]"
+#: submodule.c:1147 builtin/branch.c:680 builtin/submodule--helper.c:2016
+msgid "Failed to resolve HEAD as a valid ref."
+msgstr "Misslyckades slå upp HEAD som giltig referens."
 
-#: builtin/branch.c:29
-msgid "git branch [<options>] [-r] (-d | -D) <branch-name>..."
-msgstr "git branch [<flaggor>] [-r] (-d | -D) <grennamn>..."
+#: submodule.c:1481
+#, c-format
+msgid "Could not access submodule '%s'"
+msgstr "kunde inte komma åt undermodulen \"%s\""
 
-#: builtin/branch.c:30
-msgid "git branch [<options>] (-m | -M) [<old-branch>] <new-branch>"
-msgstr "git branch [<flaggor>] (-m | -M) [<gammal_gren>] <ny_gren>"
+#: submodule.c:1651
+#, c-format
+msgid "'%s' not recognized as a git repository"
+msgstr "\"%s\" känns inte igen som ett git-arkiv"
 
-#: builtin/branch.c:31
-msgid "git branch [<options>] (-c | -C) [<old-branch>] <new-branch>"
-msgstr "git branch [<flaggor>] (-c | -C) [<gammal_gren>] <ny_gren>"
+#: submodule.c:1789
+#, c-format
+msgid "could not start 'git status' in submodule '%s'"
+msgstr "kunde inte starta \"git status\" i undermodulen \"%s\""
 
-#: builtin/branch.c:32
-msgid "git branch [<options>] [-r | -a] [--points-at]"
-msgstr "git branch [<flaggor>] [-r | -a] [--points-at]"
+#: submodule.c:1802
+#, c-format
+msgid "could not run 'git status' in submodule '%s'"
+msgstr "kunde inte köra \"git status\" i undermodulen \"%s\""
 
-#: builtin/branch.c:33
-msgid "git branch [<options>] [-r | -a] [--format]"
-msgstr "git branch [<flaggor>] [-r | -a] [--format]"
+#: submodule.c:1817
+#, c-format
+msgid "Could not unset core.worktree setting in submodule '%s'"
+msgstr "Kunde inte ta bort inställningen core.worktree i undermodulen \"%s\""
 
-#: builtin/branch.c:146
+#: submodule.c:1907
 #, c-format
-msgid ""
-"deleting branch '%s' that has been merged to\n"
-"         '%s', but not yet merged to HEAD."
-msgstr ""
-"tar bort grenen \"%s\" som har slagits ihop med\n"
-"         \"%s\", men ännu inte slagits ihop med HEAD."
+msgid "submodule '%s' has dirty index"
+msgstr "undermodulen \"%s\" har ett smutsigt index"
+
+#: submodule.c:1959
+#, c-format
+msgid "Submodule '%s' could not be updated."
+msgstr "Undermoduler \"%s\" kunde inte uppdateras."
+
+#: submodule.c:2027
+#, c-format
+msgid "submodule git dir '%s' is inside git dir '%.*s'"
+msgstr "undermodul-gitkatalogen \"%s\" är inuti gitkatalogen \"%.*s\""
 
-#: builtin/branch.c:150
+#: submodule.c:2048
 #, c-format
 msgid ""
-"not deleting branch '%s' that is not yet merged to\n"
-"         '%s', even though it is merged to HEAD."
+"relocate_gitdir for submodule '%s' with more than one worktree not supported"
 msgstr ""
-"tar inte bort grenen \"%s\" som inte har slagits ihop med\n"
-"         \"%s\", trots att den har slagits ihop med HEAD."
+"relocate_gitdir för undermodulen \"%s\", som har mer än en arbetskatalog, "
+"stöds ej"
 
-#: builtin/branch.c:164
+#: submodule.c:2060 submodule.c:2119
 #, c-format
-msgid "Couldn't look up commit object for '%s'"
-msgstr "Kunde inte slå upp incheckningsobjekt för \"%s\""
+msgid "could not lookup name for submodule '%s'"
+msgstr "kunde inte slå upp namnet för undermodulen \"%s\""
+
+#: submodule.c:2064
+#, c-format
+msgid "refusing to move '%s' into an existing git dir"
+msgstr "vägrar flytta \"%s\" till en befintlig gitkatalog"
 
-#: builtin/branch.c:168
+#: submodule.c:2071
 #, c-format
 msgid ""
-"The branch '%s' is not fully merged.\n"
-"If you are sure you want to delete it, run 'git branch -D %s'."
+"Migrating git directory of '%s%s' from\n"
+"'%s' to\n"
+"'%s'\n"
 msgstr ""
-"Grenen \"%s\" har inte slagits samman i sin helhet.\n"
-"Om du är säker på att du vill ta bort den, kör \"git branch -D %s\"."
-
-#: builtin/branch.c:181
-msgid "Update of config-file failed"
-msgstr "Misslyckades uppdatera konfigurationsfil"
+"Migrerar git-katalogen för \"%s%s\" från\n"
+"\"%s\" till\n"
+"\"%s\"\n"
 
-#: builtin/branch.c:212
-msgid "cannot use -a with -d"
-msgstr "kan inte ange -a med -d"
+#: submodule.c:2154
+#, c-format
+msgid "could not recurse into submodule '%s'"
+msgstr "kunde inte rekursera in i undermodulen \"%s\""
 
-#: builtin/branch.c:218
-msgid "Couldn't look up commit object for HEAD"
-msgstr "Kunde inte slå upp incheckningsobjekt för HEAD"
+#: submodule.c:2198
+msgid "could not start ls-files in .."
+msgstr "kunde inte starta ls-files i .."
 
-#: builtin/branch.c:232
+#: submodule.c:2237
 #, c-format
-msgid "Cannot delete branch '%s' checked out at '%s'"
-msgstr "Kan inte ta bort grenen \"%s\" som är utcheckad på \"%s\""
+msgid "ls-tree returned unexpected return code %d"
+msgstr "ls-tree returnerade en oväntad returkod %d"
 
-#: builtin/branch.c:247
+#: submodule-config.c:236
 #, c-format
-msgid "remote-tracking branch '%s' not found."
-msgstr "fjärrspårande grenen \"%s\" hittades inte."
+msgid "ignoring suspicious submodule name: %s"
+msgstr "ignorerar misstänkt undermodulnamn: %s"
+
+#: submodule-config.c:303
+msgid "negative values not allowed for submodule.fetchjobs"
+msgstr "negativa värden är inte tillåtna för submodule.fetchjobs"
 
-#: builtin/branch.c:248
+#: submodule-config.c:401
 #, c-format
-msgid "branch '%s' not found."
-msgstr "grenen \"%s\" hittades inte."
+msgid "ignoring '%s' which may be interpreted as a command-line option: %s"
+msgstr "ignorerar \"%s\" som kan tolkas som en kommandoradsflagga: %s"
 
-#: builtin/branch.c:263
+#: submodule-config.c:498
 #, c-format
-msgid "Error deleting remote-tracking branch '%s'"
-msgstr "Fel vid borttagning av fjärrspårande grenen \"%s\""
+msgid "invalid value for %s"
+msgstr "ogiltigt värde för %s"
 
-#: builtin/branch.c:264
+#: submodule-config.c:769
 #, c-format
-msgid "Error deleting branch '%s'"
-msgstr "Fel vid borttagning av grenen \"%s\""
+msgid "Could not update .gitmodules entry %s"
+msgstr "Kunde inte uppdatera .gitmodules-posten %s"
 
-#: builtin/branch.c:271
+#: trailer.c:238
 #, c-format
-msgid "Deleted remote-tracking branch %s (was %s).\n"
-msgstr "Tog bort fjärrspårande grenen %s (var %s).\n"
+msgid "running trailer command '%s' failed"
+msgstr "misslyckades utföra \"trailer\"-kommandot \"%s\""
 
-#: builtin/branch.c:272
+#: trailer.c:485 trailer.c:490 trailer.c:495 trailer.c:549 trailer.c:553
+#: trailer.c:557
 #, c-format
-msgid "Deleted branch %s (was %s).\n"
-msgstr "Tog bort grenen %s (var %s).\n"
+msgid "unknown value '%s' for key '%s'"
+msgstr "okänt värde \"%s\" för nyckeln \"%s\""
 
-#: builtin/branch.c:416 builtin/tag.c:58
-msgid "unable to parse format string"
-msgstr "kan inte tolka formatsträng"
+#: trailer.c:539 trailer.c:544 builtin/remote.c:295
+#, c-format
+msgid "more than one %s"
+msgstr "mer än en %s"
 
-#: builtin/branch.c:453
+#: trailer.c:730
 #, c-format
-msgid "Branch %s is being rebased at %s"
-msgstr "Grenen %s ombaseras på %s"
+msgid "empty trailer token in trailer '%.*s'"
+msgstr "tom släpradssymbol i släpraden \"%.*s\""
 
-#: builtin/branch.c:457
+#: trailer.c:750
 #, c-format
-msgid "Branch %s is being bisected at %s"
-msgstr "Grenen %s är i en \"bisect\" på %s"
+msgid "could not read input file '%s'"
+msgstr "kunde inte läsa indatafilen \"%s\""
 
-#: builtin/branch.c:474
-msgid "cannot copy the current branch while not on any."
-msgstr "kunde inte kopiera aktuell gren när du inte befinner dig på någon."
+#: trailer.c:753
+msgid "could not read from stdin"
+msgstr "kunde inte läsa från standard in"
 
-#: builtin/branch.c:476
-msgid "cannot rename the current branch while not on any."
-msgstr ""
-"kunde inte byta namn på aktuell gren när du inte befinner dig på någon."
+#: trailer.c:1011 wrapper.c:665
+#, c-format
+msgid "could not stat %s"
+msgstr "kunde inte ta status på %s"
 
-#: builtin/branch.c:487
+#: trailer.c:1013
 #, c-format
-msgid "Invalid branch name: '%s'"
-msgstr "Felaktigt namn på gren: \"%s\""
+msgid "file %s is not a regular file"
+msgstr "filen %s är inte en normal fil"
 
-#: builtin/branch.c:514
-msgid "Branch rename failed"
-msgstr "Misslyckades byta namn på gren"
+#: trailer.c:1015
+#, c-format
+msgid "file %s is not writable by user"
+msgstr "filen %s är inte skrivbar av användaren"
 
-#: builtin/branch.c:516
-msgid "Branch copy failed"
-msgstr "Misslyckades kopiera gren"
+#: trailer.c:1027
+msgid "could not open temporary file"
+msgstr "kunde inte öppna temporär fil"
 
-#: builtin/branch.c:520
+#: trailer.c:1067
 #, c-format
-msgid "Created a copy of a misnamed branch '%s'"
-msgstr "Skapade kopia av felaktigt namngiven gren \"%s\""
+msgid "could not rename temporary file to %s"
+msgstr "kunde inte byta namn på temporär fil till %s"
 
-#: builtin/branch.c:523
+#: transport.c:116
 #, c-format
-msgid "Renamed a misnamed branch '%s' away"
-msgstr "Bytte bort namn på en felaktigt namngiven gren \"%s\""
+msgid "Would set upstream of '%s' to '%s' of '%s'\n"
+msgstr "Skulle sätta uppströms för \"%s\" till \"%s\" från \"%s\"\n"
 
-#: builtin/branch.c:529
+#: transport.c:145
 #, c-format
-msgid "Branch renamed to %s, but HEAD is not updated!"
-msgstr "Grenen namnbytt till %s, men HEAD har inte uppdaterats!"
+msgid "could not read bundle '%s'"
+msgstr "kunde inte läsa paketet (bundlen) \"%s\""
 
-#: builtin/branch.c:538
-msgid "Branch is renamed, but update of config-file failed"
-msgstr "Grenen namnbytt, men misslyckades uppdatera konfigurationsfilen"
+#: transport.c:214
+#, c-format
+msgid "transport: invalid depth option '%s'"
+msgstr "transport: ogiltig flagga för depth: \"%s\""
 
-#: builtin/branch.c:540
-msgid "Branch is copied, but update of config-file failed"
-msgstr "Grenen kopierades, men misslyckades uppdatera konfigurationsfilen"
+#: transport.c:266
+msgid "see protocol.version in 'git help config' for more details"
+msgstr "se protocol.version i \"git help config\" för mer information"
 
-#: builtin/branch.c:556
-#, c-format
-msgid ""
-"Please edit the description for the branch\n"
-"  %s\n"
-"Lines starting with '%c' will be stripped.\n"
-msgstr ""
-"Redigera beskrivningen för grenen\n"
-"  %s\n"
-"Rader som inleds med \"%c\" ignoreras.\n"
-
-#: builtin/branch.c:589
-msgid "Generic options"
-msgstr "Allmänna flaggor"
+#: transport.c:267
+msgid "server options require protocol version 2 or later"
+msgstr "serverflaggor kräver protokollversion 2 eller senare"
 
-#: builtin/branch.c:591
-msgid "show hash and subject, give twice for upstream branch"
-msgstr "visa hash och ärenderad, ange två gånger för uppströmsgren"
-
-#: builtin/branch.c:592
-msgid "suppress informational messages"
-msgstr "undertryck informationsmeddelanden"
+#: transport.c:632
+msgid "could not parse transport.color.* config"
+msgstr "kunde inte tolka inställningen för transport.color.*"
 
-#: builtin/branch.c:593
-msgid "set up tracking mode (see git-pull(1))"
-msgstr "ställ in spårningsläge (se git-pull(1))"
+#: transport.c:705
+msgid "support for protocol v2 not implemented yet"
+msgstr "stöd för protokoll v2 ännu ej implementerat"
 
-#: builtin/branch.c:595
-msgid "do not use"
-msgstr "använd ej"
+#: transport.c:831
+#, c-format
+msgid "unknown value for config '%s': %s"
+msgstr "okänt värde för inställningen \"%s\": %s"
 
-#: builtin/branch.c:597
-msgid "upstream"
-msgstr "uppströms"
+#: transport.c:897
+#, c-format
+msgid "transport '%s' not allowed"
+msgstr "transporten \"%s\" tillåts inte"
 
-#: builtin/branch.c:597
-msgid "change the upstream info"
-msgstr "ändra uppströmsinformationen"
+#: transport.c:949
+msgid "git-over-rsync is no longer supported"
+msgstr "git-over-rsync stöds inte längre"
 
-#: builtin/branch.c:598
-msgid "Unset the upstream info"
-msgstr "Ta bort uppströmsinformationen"
+#: transport.c:1044
+#, c-format
+msgid ""
+"The following submodule paths contain changes that can\n"
+"not be found on any remote:\n"
+msgstr ""
+"Följande undermodulsökvägar innehåller ändringar som\n"
+"inte kan hittas av fjärrarna:\n"
 
-#: builtin/branch.c:599
-msgid "use colored output"
-msgstr "använd färgad utdata"
+#: transport.c:1048
+#, c-format
+msgid ""
+"\n"
+"Please try\n"
+"\n"
+"\tgit push --recurse-submodules=on-demand\n"
+"\n"
+"or cd to the path and use\n"
+"\n"
+"\tgit push\n"
+"\n"
+"to push them to a remote.\n"
+"\n"
+msgstr ""
+"\n"
+"Testa\n"
+"\n"
+"\tgit push --recurse-submodules=on-demand\n"
+"\n"
+"eller cd till sökvägen och använd\n"
+"\n"
+"\tgit push\n"
+"\n"
+"för att sända dem till fjärren.\n"
+"\n"
 
-#: builtin/branch.c:600
-msgid "act on remote-tracking branches"
-msgstr "arbeta på fjärrspårande grenar"
+#: transport.c:1056
+msgid "Aborting."
+msgstr "Avbryter."
 
-#: builtin/branch.c:602 builtin/branch.c:604
-msgid "print only branches that contain the commit"
-msgstr "visa endast grenar som innehåller incheckningen"
+#: transport.c:1201
+msgid "failed to push all needed submodules"
+msgstr "kunde inte sända alla nödvändiga undermoduler"
 
-#: builtin/branch.c:603 builtin/branch.c:605
-msgid "print only branches that don't contain the commit"
-msgstr "visa endast grenar som inte innehåller incheckningen"
+#: transport.c:1345 transport-helper.c:656
+msgid "operation not supported by protocol"
+msgstr "funktionen stöds inte av protokollet"
 
-#: builtin/branch.c:608
-msgid "Specific git-branch actions:"
-msgstr "Specifika git-branch-åtgärder:"
+#: transport-helper.c:61 transport-helper.c:90
+msgid "full write to remote helper failed"
+msgstr "komplett skrivning till fjärrhjälpare misslyckades"
 
-#: builtin/branch.c:609
-msgid "list both remote-tracking and local branches"
-msgstr "visa både fjärrspårande och lokala grenar"
+#: transport-helper.c:144
+#, c-format
+msgid "unable to find remote helper for '%s'"
+msgstr "kan inte hitta fjärrhjälpare för \"%s\""
 
-#: builtin/branch.c:611
-msgid "delete fully merged branch"
-msgstr "ta bort helt sammanslagen gren"
+#: transport-helper.c:160 transport-helper.c:570
+msgid "can't dup helper output fd"
+msgstr "kunde inte duplicera utdata-filhandtag"
 
-#: builtin/branch.c:612
-msgid "delete branch (even if not merged)"
-msgstr "ta bort gren (även om inte helt sammanslagen)"
+#: transport-helper.c:211
+#, c-format
+msgid ""
+"unknown mandatory capability %s; this remote helper probably needs newer "
+"version of Git"
+msgstr ""
+"okänd krävd förmåga (capability) %s; fjärrhjälparen behöver antagligen en "
+"nyare version av Git"
 
-#: builtin/branch.c:613
-msgid "move/rename a branch and its reflog"
-msgstr "flytta/ta bort en gren och dess reflogg"
+#: transport-helper.c:217
+msgid "this remote helper should implement refspec capability"
+msgstr ""
+"fjärrhjälparen behöver implementera förmåga för referensspecifikationer "
+"(refspec)"
 
-#: builtin/branch.c:614
-msgid "move/rename a branch, even if target exists"
-msgstr "flytta/ta bort en gren, även om målet finns"
+#: transport-helper.c:284 transport-helper.c:424
+#, c-format
+msgid "%s unexpectedly said: '%s'"
+msgstr "%s sade oväntat: \"%s\""
 
-#: builtin/branch.c:615
-msgid "copy a branch and its reflog"
-msgstr "kopiera en gren och dess reflogg"
+#: transport-helper.c:413
+#, c-format
+msgid "%s also locked %s"
+msgstr "%s låste också %s"
 
-#: builtin/branch.c:616
-msgid "copy a branch, even if target exists"
-msgstr "kopiera en gren, även om målet finns"
+#: transport-helper.c:492
+msgid "couldn't run fast-import"
+msgstr "kunde inte köra fast-import"
 
-#: builtin/branch.c:617
-msgid "list branch names"
-msgstr "lista namn på grenar"
+#: transport-helper.c:515
+msgid "error while running fast-import"
+msgstr "fel när fast-import kördes"
 
-#: builtin/branch.c:618
-msgid "create the branch's reflog"
-msgstr "skapa grenens reflogg"
+#: transport-helper.c:544 transport-helper.c:1133
+#, c-format
+msgid "could not read ref %s"
+msgstr "kunde inte läsa referensen %s"
 
-#: builtin/branch.c:620
-msgid "edit the description for the branch"
-msgstr "redigera beskrivning för grenen"
+#: transport-helper.c:589
+#, c-format
+msgid "unknown response to connect: %s"
+msgstr "okänt svar på ansluntning: %s"
 
-#: builtin/branch.c:621
-msgid "force creation, move/rename, deletion"
-msgstr "tvinga skapande, flytt/namnändring, borttagande"
+#: transport-helper.c:611
+msgid "setting remote service path not supported by protocol"
+msgstr "protkollet stöder inte att sätta sökväg till fjärrtjänst"
 
-#: builtin/branch.c:622
-msgid "print only branches that are merged"
-msgstr "visa endast sammanslagna grenar"
+#: transport-helper.c:613
+msgid "invalid remote service path"
+msgstr "felaktig sökväg till fjärrtjänst"
 
-#: builtin/branch.c:623
-msgid "print only branches that are not merged"
-msgstr "visa endast ej sammanslagna grenar"
+#: transport-helper.c:659
+#, c-format
+msgid "can't connect to subservice %s"
+msgstr "kan inte ansluta till undertjänsten %s"
 
-#: builtin/branch.c:624
-msgid "list branches in columns"
-msgstr "visa grenar i spalter"
+#: transport-helper.c:735
+#, c-format
+msgid "expected ok/error, helper said '%s'"
+msgstr "förväntade ok/error, hjälpprogrammet svarade \"%s\""
 
-#: builtin/branch.c:625 builtin/for-each-ref.c:40 builtin/ls-remote.c:70
-#: builtin/tag.c:412
-msgid "key"
-msgstr "nyckel"
+#: transport-helper.c:788
+#, c-format
+msgid "helper reported unexpected status of %s"
+msgstr "hjälparen returnerade oväntad status %s"
 
-#: builtin/branch.c:626 builtin/for-each-ref.c:41 builtin/ls-remote.c:71
-#: builtin/tag.c:413
-msgid "field name to sort on"
-msgstr "fältnamn att sortera på"
+#: transport-helper.c:849
+#, c-format
+msgid "helper %s does not support dry-run"
+msgstr "hjälparen %s stöder inte dry-run"
 
-#: builtin/branch.c:628 builtin/for-each-ref.c:43 builtin/notes.c:408
-#: builtin/notes.c:411 builtin/notes.c:571 builtin/notes.c:574
-#: builtin/tag.c:415
-msgid "object"
-msgstr "objekt"
+#: transport-helper.c:852
+#, c-format
+msgid "helper %s does not support --signed"
+msgstr "hjälparen %s stöder inte --signed"
 
-#: builtin/branch.c:629
-msgid "print only branches of the object"
-msgstr "visa endast grenar för objektet"
+#: transport-helper.c:855
+#, c-format
+msgid "helper %s does not support --signed=if-asked"
+msgstr "hjälparen %s stöder inte --signed=if-asked"
 
-#: builtin/branch.c:631 builtin/for-each-ref.c:49 builtin/tag.c:422
-msgid "sorting and filtering are case insensitive"
-msgstr "sortering och filtrering skiljer gemener och VERSALER"
+#: transport-helper.c:860
+#, c-format
+msgid "helper %s does not support --atomic"
+msgstr "hjälparen %s stöder inte --atomic"
 
-#: builtin/branch.c:632 builtin/for-each-ref.c:38 builtin/tag.c:420
-#: builtin/verify-tag.c:39
-msgid "format to use for the output"
-msgstr "format att använda för utdata"
+#: transport-helper.c:866
+#, c-format
+msgid "helper %s does not support 'push-option'"
+msgstr "hjälparen %s stöder inte \"push-option\""
 
-#: builtin/branch.c:655 builtin/clone.c:737
-msgid "HEAD not found below refs/heads!"
-msgstr "HEAD hittades inte under refs/heads!"
+#: transport-helper.c:964
+msgid "remote-helper doesn't support push; refspec needed"
+msgstr "fjärrhjälparen stöder inte push; referensspecifikation krävs"
 
-#: builtin/branch.c:678
-msgid "--column and --verbose are incompatible"
-msgstr "--column och --verbose är inkompatibla"
+#: transport-helper.c:969
+#, c-format
+msgid "helper %s does not support 'force'"
+msgstr "hjälparen %s stöder inte \"force\""
 
-#: builtin/branch.c:693 builtin/branch.c:745 builtin/branch.c:754
-msgid "branch name required"
-msgstr "grennamn krävs"
+#: transport-helper.c:1016
+msgid "couldn't run fast-export"
+msgstr "kunde inte köra fast-export"
 
-#: builtin/branch.c:721
-msgid "Cannot give description to detached HEAD"
-msgstr "Kan inte beskriva frånkopplad HEAD"
+#: transport-helper.c:1021
+msgid "error while running fast-export"
+msgstr "fel vid körning av fast-export"
 
-#: builtin/branch.c:726
-msgid "cannot edit description of more than one branch"
-msgstr "kan inte redigera beskrivning för mer än en gren"
+#: transport-helper.c:1046
+#, c-format
+msgid ""
+"No refs in common and none specified; doing nothing.\n"
+"Perhaps you should specify a branch such as 'master'.\n"
+msgstr ""
+"Inga gemensamma referenser och inga angavs; gör inget.\n"
+"Du kanske borde ange en gren såsom \"master\".\n"
 
-#: builtin/branch.c:733
+#: transport-helper.c:1119
 #, c-format
-msgid "No commit on branch '%s' yet."
-msgstr "Inga incheckningar på grenen \"%s\" ännu."
+msgid "malformed response in ref list: %s"
+msgstr "felformat svar i referenslistan: %s"
 
-#: builtin/branch.c:736
+#: transport-helper.c:1271
 #, c-format
-msgid "No branch named '%s'."
-msgstr "Ingen gren vid namnet \"%s\"."
+msgid "read(%s) failed"
+msgstr "läs(%s) misslyckades"
 
-#: builtin/branch.c:751
-msgid "too many branches for a copy operation"
-msgstr "för många grenar för kopiering"
+#: transport-helper.c:1298
+#, c-format
+msgid "write(%s) failed"
+msgstr "skriv(%s) misslyckades"
 
-#: builtin/branch.c:760
-msgid "too many arguments for a rename operation"
-msgstr "för många flaggor för namnbyte"
+#: transport-helper.c:1347
+#, c-format
+msgid "%s thread failed"
+msgstr "%s-tråden misslyckades"
 
-#: builtin/branch.c:765
-msgid "too many arguments to set new upstream"
-msgstr "för många flaggor för att byta uppström"
+#: transport-helper.c:1351
+#, c-format
+msgid "%s thread failed to join: %s"
+msgstr "%s-tråden misslyckades ansluta: %s"
 
-#: builtin/branch.c:769
+#: transport-helper.c:1370 transport-helper.c:1374
 #, c-format
-msgid ""
-"could not set upstream of HEAD to %s when it does not point to any branch."
-msgstr ""
-"kunde inte sätta uppström för HEAD till %s när det inte pekar mot någon gren."
+msgid "can't start thread for copying data: %s"
+msgstr "kan inte starta tråd för kopiering av data: %s"
 
-#: builtin/branch.c:772 builtin/branch.c:794 builtin/branch.c:810
+#: transport-helper.c:1411
 #, c-format
-msgid "no such branch '%s'"
-msgstr "okänd gren \"%s\""
+msgid "%s process failed to wait"
+msgstr "processen %s misslyckades vänta"
 
-#: builtin/branch.c:776
+#: transport-helper.c:1415
 #, c-format
-msgid "branch '%s' does not exist"
-msgstr "grenen \"%s\" finns inte"
+msgid "%s process failed"
+msgstr "processen %s misslyckades"
 
-#: builtin/branch.c:788
-msgid "too many arguments to unset upstream"
-msgstr "för många flaggor för att ta bort uppström"
+#: transport-helper.c:1433 transport-helper.c:1442
+msgid "can't start thread for copying data"
+msgstr "kan inte skapa tråd för kopiering av data"
 
-#: builtin/branch.c:792
-msgid "could not unset upstream of HEAD when it does not point to any branch."
-msgstr ""
-"kunde inte ta bort uppström för HEAD när det inte pekar mot någon gren."
+#: tree-walk.c:33
+msgid "too-short tree object"
+msgstr "trädobjekt för kort"
+
+#: tree-walk.c:39
+msgid "malformed mode in tree entry"
+msgstr "felformat läge i trädpost"
+
+#: tree-walk.c:43
+msgid "empty filename in tree entry"
+msgstr "tomt filnamn i trädpost"
 
-#: builtin/branch.c:798
+#: tree-walk.c:48
 #, c-format
-msgid "Branch '%s' has no upstream information"
-msgstr "Grenen \"%s\" har ingen uppströmsinformation"
+msgid "filename in tree entry contains backslash: '%s'"
+msgstr "filnamnet i trädet innehåller omvänt snedstreck: \"%s\""
+
+#: tree-walk.c:124
+msgid "too-short tree file"
+msgstr "trädfil för kort"
 
-#: builtin/branch.c:813
-msgid "-a and -r options to 'git branch' do not make sense with a branch name"
+#: unpack-trees.c:110
+#, c-format
+msgid ""
+"Your local changes to the following files would be overwritten by checkout:\n"
+"%%sPlease commit your changes or stash them before you switch branches."
 msgstr ""
-"flaggorna -a och -r på \"git branch\" kan inte anges tillsammans med ett "
-"grennamn"
+"Dina lokala ändringar av följande filer skulle skrivas över av utcheckning:\n"
+"%%sChecka in dina ändringar eller använd \"stash\" innan du byter gren."
 
-#: builtin/branch.c:816
+#: unpack-trees.c:112
+#, c-format
 msgid ""
-"the '--set-upstream' option is no longer supported. Please use '--track' or "
-"'--set-upstream-to' instead."
+"Your local changes to the following files would be overwritten by checkout:\n"
+"%%s"
 msgstr ""
-"Flaggan --set-upstream rekommenderas ej och kommer tas bort. Använd --track "
-"eller --set-upstream-to istället."
+"Dina lokala ändringar av följande filer skulle skrivas över av utcheckning:\n"
+"%%s"
 
-#: builtin/bundle.c:45
+#: unpack-trees.c:115
 #, c-format
-msgid "%s is okay\n"
-msgstr "%s är okej\n"
+msgid ""
+"Your local changes to the following files would be overwritten by merge:\n"
+"%%sPlease commit your changes or stash them before you merge."
+msgstr ""
+"Dina lokala ändringar av följande filer skulle skrivas över av "
+"sammanslagning:\n"
+"%%sChecka in dina ändringar eller använd \"stash\" innan du byter gren."
 
-#: builtin/bundle.c:58
-msgid "Need a repository to create a bundle."
-msgstr "Behöver ett arkiv för att skapa ett paket (bundle)."
+#: unpack-trees.c:117
+#, c-format
+msgid ""
+"Your local changes to the following files would be overwritten by merge:\n"
+"%%s"
+msgstr ""
+"Dina lokala ändringar av följande filer skulle skrivas över av "
+"sammanslagning:\n"
+"%%s"
 
-#: builtin/bundle.c:62
-msgid "Need a repository to unbundle."
-msgstr "Behöver ett arkiv för att packa upp ett paket (bundle)."
+#: unpack-trees.c:120
+#, c-format
+msgid ""
+"Your local changes to the following files would be overwritten by %s:\n"
+"%%sPlease commit your changes or stash them before you %s."
+msgstr ""
+"Dina lokala ändringar av följande filer skulle skrivas över av \"%s\":\n"
+"%%sChecka in dina ändringar eller använd \"stash\" innan du \"%s\"."
 
-#: builtin/cat-file.c:525
+#: unpack-trees.c:122
+#, c-format
 msgid ""
-"git cat-file (-t [--allow-unknown-type] | -s [--allow-unknown-type] | -e | -"
-"p | <type> | --textconv | --filters) [--path=<path>] <object>"
+"Your local changes to the following files would be overwritten by %s:\n"
+"%%s"
 msgstr ""
-"git cat-file (-t [--allow-unknown-type] | -s [--allow-unknown-type] | -e | -"
-"p | <typ> | --textconv | --filters) [--path=<sökväg>] <objekt>"
+"Dina lokala ändringar av följande filer skulle skrivas över av \"%s\":\n"
+"%%s"
 
-#: builtin/cat-file.c:526
+#: unpack-trees.c:127
+#, c-format
 msgid ""
-"git cat-file (--batch | --batch-check) [--follow-symlinks] [--textconv | --"
-"filters]"
+"Updating the following directories would lose untracked files in them:\n"
+"%s"
 msgstr ""
-"git cat-file (--batch | --batch-check) [--follow-symlinks] [--textconv | --"
-"filters]"
+"Uppdatering av följande kataloger gör att ospårade filer går förlorade i "
+"dem:\n"
+"%s"
 
-#: builtin/cat-file.c:563
+#: unpack-trees.c:131
+#, c-format
+msgid ""
+"The following untracked working tree files would be removed by checkout:\n"
+"%%sPlease move or remove them before you switch branches."
+msgstr ""
+"Följande ospårade filer i arbetskatalogen skulle tas bort av utcheckningen:\n"
+"%%sFlytta eller ta bort dem innan du byter gren."
+
+#: unpack-trees.c:133
+#, c-format
+msgid ""
+"The following untracked working tree files would be removed by checkout:\n"
+"%%s"
+msgstr ""
+"Följande ospårade filer i arbetskatalogen skulle tas bort av utcheckningen:\n"
+"%%s"
+
+#: unpack-trees.c:136
+#, c-format
+msgid ""
+"The following untracked working tree files would be removed by merge:\n"
+"%%sPlease move or remove them before you merge."
+msgstr ""
+"Följande ospårade filer i arbetskatalogen skulle tas bort av "
+"sammanslagningen:\n"
+"%%sFlytta eller ta bort dem innan du slår samman."
+
+#: unpack-trees.c:138
+#, c-format
+msgid ""
+"The following untracked working tree files would be removed by merge:\n"
+"%%s"
+msgstr ""
+"Följande ospårade filer i arbetskatalogen skulle tas bort av "
+"sammanslagningen:\n"
+"%%s"
+
+#: unpack-trees.c:141
+#, c-format
+msgid ""
+"The following untracked working tree files would be removed by %s:\n"
+"%%sPlease move or remove them before you %s."
+msgstr ""
+"Följande ospårade filer i arbetskatalogen skulle tas bort av \"%s\":\n"
+"%%sFlytta eller ta bort dem innan du \"%s\"."
+
+#: unpack-trees.c:143
+#, c-format
+msgid ""
+"The following untracked working tree files would be removed by %s:\n"
+"%%s"
+msgstr ""
+"Följande ospårade filer i arbetskatalogen skulle tas bort av \"%s\":\n"
+"%%s"
+
+#: unpack-trees.c:149
+#, c-format
+msgid ""
+"The following untracked working tree files would be overwritten by "
+"checkout:\n"
+"%%sPlease move or remove them before you switch branches."
+msgstr ""
+"Följande ospårade filer i arbetskatalogen skulle skrivas över av "
+"utcheckningen:\n"
+"%%sFlytta eller ta bort dem innan du byter gren."
+
+#: unpack-trees.c:151
+#, c-format
+msgid ""
+"The following untracked working tree files would be overwritten by "
+"checkout:\n"
+"%%s"
+msgstr ""
+"Följande ospårade filer i arbetskatalogen skulle skrivas över av "
+"utcheckningen:\n"
+"%%s"
+
+#: unpack-trees.c:154
+#, c-format
+msgid ""
+"The following untracked working tree files would be overwritten by merge:\n"
+"%%sPlease move or remove them before you merge."
+msgstr ""
+"Följande ospårade filer i arbetskatalogen skulle skrivas över av "
+"sammanslagningen:\n"
+"%%sFlytta eller ta bort dem innan du byter gren."
+
+#: unpack-trees.c:156
+#, c-format
+msgid ""
+"The following untracked working tree files would be overwritten by merge:\n"
+"%%s"
+msgstr ""
+"Följande ospårade filer i arbetskatalogen skulle skrivas över av "
+"sammanslagningen:\n"
+"%%s"
+
+#: unpack-trees.c:159
+#, c-format
+msgid ""
+"The following untracked working tree files would be overwritten by %s:\n"
+"%%sPlease move or remove them before you %s."
+msgstr ""
+"Följande ospårade filer i arbetskatalogen skulle skrivas över av \"%s\":\n"
+"%%sFlytta eller ta bort dem innan du \"%s\"."
+
+#: unpack-trees.c:161
+#, c-format
+msgid ""
+"The following untracked working tree files would be overwritten by %s:\n"
+"%%s"
+msgstr ""
+"Följande ospårade filer i arbetskatalogen skulle skrivas över av \"%s\":\n"
+"%%s"
+
+#: unpack-trees.c:169
+#, c-format
+msgid "Entry '%s' overlaps with '%s'.  Cannot bind."
+msgstr "Posten \"%s\" överlappar \"%s\". Kan inte binda."
+
+#: unpack-trees.c:172
+#, c-format
+msgid ""
+"Cannot update sparse checkout: the following entries are not up to date:\n"
+"%s"
+msgstr ""
+"Kan inte uppdatera gles utcheckning: följande poster är inte à jour:\n"
+"%s"
+
+#: unpack-trees.c:174
+#, c-format
+msgid ""
+"The following working tree files would be overwritten by sparse checkout "
+"update:\n"
+"%s"
+msgstr ""
+"Följande filer i arbetskatalogen skulle skrivas över av uppdatering av gles "
+"utcheckning:\n"
+"%s"
+
+#: unpack-trees.c:176
+#, c-format
+msgid ""
+"The following working tree files would be removed by sparse checkout "
+"update:\n"
+"%s"
+msgstr ""
+"Följande filer i arbetskatalogen skulle tas bort av uppdatering av gles "
+"utcheckning:\n"
+"%s"
+
+#: unpack-trees.c:178
+#, c-format
+msgid ""
+"Cannot update submodule:\n"
+"%s"
+msgstr ""
+"Kan inte uppdatera undermodul:\n"
+"%s"
+
+#: unpack-trees.c:255
+#, c-format
+msgid "Aborting\n"
+msgstr "Avbryter\n"
+
+#: unpack-trees.c:317
+msgid "Updating files"
+msgstr "Uppdaterar filer"
+
+#: unpack-trees.c:349
+msgid ""
+"the following paths have collided (e.g. case-sensitive paths\n"
+"on a case-insensitive filesystem) and only one from the same\n"
+"colliding group is in the working tree:\n"
+msgstr ""
+"följande sökvägar har kolliderat (t.ex. skiftlägeskänsliga\n"
+"sökvägar på ett okänsligt filsystem) och endast en från samma\n"
+"kollisionsgrupp finns i arbetskatalogen:\n"
+
+#: unpack-trees.c:1441
+msgid "Updating index flags"
+msgstr "Uppdaterar indexflaggor"
+
+#: urlmatch.c:163
+msgid "invalid URL scheme name or missing '://' suffix"
+msgstr "ogiltig URL-schemanamn eller saknat \"://\"-suffix"
+
+#: urlmatch.c:187 urlmatch.c:346 urlmatch.c:405
+#, c-format
+msgid "invalid %XX escape sequence"
+msgstr "ogiltig %XX-teckensekvens"
+
+#: urlmatch.c:215
+msgid "missing host and scheme is not 'file:'"
+msgstr "värd saknas och schemat är inte \"file:\""
+
+#: urlmatch.c:232
+msgid "a 'file:' URL may not have a port number"
+msgstr "en \"file:\"-URL kan inte innehålla portnummer"
+
+#: urlmatch.c:247
+msgid "invalid characters in host name"
+msgstr "ogiltiga tecken i värdnamnet"
+
+#: urlmatch.c:292 urlmatch.c:303
+msgid "invalid port number"
+msgstr "felaktigt portnummer"
+
+#: urlmatch.c:371
+msgid "invalid '..' path segment"
+msgstr "felaktigt \"..\"-sökvägssegment"
+
+#: worktree.c:258 builtin/am.c:2084
+#, c-format
+msgid "failed to read '%s'"
+msgstr "misslyckades läsa \"%s\""
+
+#: worktree.c:304
+#, c-format
+msgid "'%s' at main working tree is not the repository directory"
+msgstr "\"%s\" i huvudarbetskatalogen är inte arkivkatalogen"
+
+#: worktree.c:315
+#, c-format
+msgid "'%s' file does not contain absolute path to the working tree location"
+msgstr "filen \"%s\" innehåller inte absolut sökväg till arbetskatalogen"
+
+#: worktree.c:327
+#, c-format
+msgid "'%s' does not exist"
+msgstr "\"%s\" finns inte"
+
+#: worktree.c:333
+#, c-format
+msgid "'%s' is not a .git file, error code %d"
+msgstr "\"%s\" är inte en .git-fil, felkod %d"
+
+#: worktree.c:341
+#, c-format
+msgid "'%s' does not point back to '%s'"
+msgstr "\"%s\" pekar inte tillbaka till \"%s\""
+
+#: wrapper.c:186 wrapper.c:356
+#, c-format
+msgid "could not open '%s' for reading and writing"
+msgstr "kunde inte öppna \"%s\" för läsning och skrivning"
+
+#: wrapper.c:387 wrapper.c:588
+#, c-format
+msgid "unable to access '%s'"
+msgstr "kan inte komma åt \"%s\""
+
+#: wrapper.c:596
+msgid "unable to get current working directory"
+msgstr "kan inte hämta aktuell arbetskatalog"
+
+#: wt-status.c:158
+msgid "Unmerged paths:"
+msgstr "Ej sammanslagna sökvägar:"
+
+#: wt-status.c:187 wt-status.c:219
+msgid "  (use \"git restore --staged <file>...\" to unstage)"
+msgstr "  (använd \"git restore --staged <fil>...\" för att ta bort från kö)"
+
+#: wt-status.c:190 wt-status.c:222
+#, c-format
+msgid "  (use \"git restore --source=%s --staged <file>...\" to unstage)"
+msgstr ""
+"  (använd \"git restore --source=%s --staged <fil>...\" för att ta bort från "
+"kö)"
+
+#: wt-status.c:193 wt-status.c:225
+msgid "  (use \"git rm --cached <file>...\" to unstage)"
+msgstr "  (använd \"git rm --cached <fil>...\" för att ta bort från kö)"
+
+#: wt-status.c:197
+msgid "  (use \"git add <file>...\" to mark resolution)"
+msgstr "  (använd \"git add <fil>...\" för att ange lösning)"
+
+#: wt-status.c:199 wt-status.c:203
+msgid "  (use \"git add/rm <file>...\" as appropriate to mark resolution)"
+msgstr "  (använd \"git add/rm <fil>...\" som lämpligt för att ange lösning)"
+
+#: wt-status.c:201
+msgid "  (use \"git rm <file>...\" to mark resolution)"
+msgstr "  (använd \"git rm <fil>...\" för att ange lösning)"
+
+#: wt-status.c:211 wt-status.c:1074
+msgid "Changes to be committed:"
+msgstr "Ändringar att checka in:"
+
+#: wt-status.c:234 wt-status.c:1083
+msgid "Changes not staged for commit:"
+msgstr "Ändringar ej i incheckningskön:"
+
+#: wt-status.c:238
+msgid "  (use \"git add <file>...\" to update what will be committed)"
+msgstr ""
+"  (använd \"git add <fil>...\" för att uppdatera vad som skall checkas in)"
+
+#: wt-status.c:240
+msgid "  (use \"git add/rm <file>...\" to update what will be committed)"
+msgstr ""
+"  (använd \"git add/rm <fil>...\" för att uppdatera vad som skall checkas in)"
+
+#: wt-status.c:241
+msgid ""
+"  (use \"git restore <file>...\" to discard changes in working directory)"
+msgstr ""
+"  (använd \"git restore <fil>...\" för att förkasta ändringar i "
+"arbetskatalogen)"
+
+#: wt-status.c:243
+msgid "  (commit or discard the untracked or modified content in submodules)"
+msgstr ""
+"  (checka in eller förkasta ospårat eller ändrat innehåll i undermoduler)"
+
+#: wt-status.c:254
+#, c-format
+msgid "  (use \"git %s <file>...\" to include in what will be committed)"
+msgstr ""
+"  (använd \"git %s <fil>...\" för att ta med i det som skall checkas in)"
+
+#: wt-status.c:268
+msgid "both deleted:"
+msgstr "borttaget av bägge:"
+
+#: wt-status.c:270
+msgid "added by us:"
+msgstr "tillagt av oss:"
+
+#: wt-status.c:272
+msgid "deleted by them:"
+msgstr "borttaget av dem:"
+
+#: wt-status.c:274
+msgid "added by them:"
+msgstr "tillagt av dem:"
+
+#: wt-status.c:276
+msgid "deleted by us:"
+msgstr "borttaget av oss:"
+
+#: wt-status.c:278
+msgid "both added:"
+msgstr "tillagt av bägge:"
+
+#: wt-status.c:280
+msgid "both modified:"
+msgstr "ändrat av bägge:"
+
+#: wt-status.c:290
+msgid "new file:"
+msgstr "ny fil:"
+
+#: wt-status.c:292
+msgid "copied:"
+msgstr "kopierad:"
+
+#: wt-status.c:294
+msgid "deleted:"
+msgstr "borttagen:"
+
+#: wt-status.c:296
+msgid "modified:"
+msgstr "ändrad:"
+
+#: wt-status.c:298
+msgid "renamed:"
+msgstr "namnbytt:"
+
+#: wt-status.c:300
+msgid "typechange:"
+msgstr "typbyte:"
+
+#: wt-status.c:302
+msgid "unknown:"
+msgstr "okänd:"
+
+#: wt-status.c:304
+msgid "unmerged:"
+msgstr "osammanslagen:"
+
+#: wt-status.c:384
+msgid "new commits, "
+msgstr "nya incheckningar, "
+
+#: wt-status.c:386
+msgid "modified content, "
+msgstr "ändrat innehåll, "
+
+#: wt-status.c:388
+msgid "untracked content, "
+msgstr "ospårat innehåll, "
+
+#: wt-status.c:906
+#, c-format
+msgid "Your stash currently has %d entry"
+msgid_plural "Your stash currently has %d entries"
+msgstr[0] "Stashen innehåller just nu %d post"
+msgstr[1] "Stashen innehåller just nu %d poster"
+
+#: wt-status.c:938
+msgid "Submodules changed but not updated:"
+msgstr "Undermoduler ändrade men inte uppdaterade:"
+
+#: wt-status.c:940
+msgid "Submodule changes to be committed:"
+msgstr "Undermodulers ändringar att checka in:"
+
+#: wt-status.c:1022
+msgid ""
+"Do not modify or remove the line above.\n"
+"Everything below it will be ignored."
+msgstr ""
+"Raden ovan får inte ändras eller tas bort.\n"
+"Allt under den kommer tas bort."
+
+#: wt-status.c:1114
+#, c-format
+msgid ""
+"\n"
+"It took %.2f seconds to compute the branch ahead/behind values.\n"
+"You can use '--no-ahead-behind' to avoid this.\n"
+msgstr ""
+"\n"
+"Det tog %.2f sekunder att räkna före/bakom-värden.\n"
+"Du kan använda \"--no-ahead-behind\" för undvika detta.\n"
+
+#: wt-status.c:1144
+msgid "You have unmerged paths."
+msgstr "Du har ej sammanslagna sökvägar."
+
+#: wt-status.c:1147
+msgid "  (fix conflicts and run \"git commit\")"
+msgstr "  (rätta konflikter och kör \"git commit\")"
+
+#: wt-status.c:1149
+msgid "  (use \"git merge --abort\" to abort the merge)"
+msgstr "  (använd \"git merge --abort\" för att avbryta sammanslagningen)"
+
+#: wt-status.c:1153
+msgid "All conflicts fixed but you are still merging."
+msgstr "Alla konflikter har rättats men du är fortfarande i en sammanslagning."
+
+#: wt-status.c:1156
+msgid "  (use \"git commit\" to conclude merge)"
+msgstr "  (använd \"git commit\" för att slutföra sammanslagningen)"
+
+#: wt-status.c:1165
+msgid "You are in the middle of an am session."
+msgstr "Du är i mitten av en körning av \"git am\"."
+
+#: wt-status.c:1168
+msgid "The current patch is empty."
+msgstr "Aktuell patch är tom."
+
+#: wt-status.c:1172
+msgid "  (fix conflicts and then run \"git am --continue\")"
+msgstr "  (rätta konflikter och kör sedan \"git am --continue\")"
+
+#: wt-status.c:1174
+msgid "  (use \"git am --skip\" to skip this patch)"
+msgstr "  (använd \"git am --skip\" för att hoppa över patchen)"
+
+#: wt-status.c:1176
+msgid "  (use \"git am --abort\" to restore the original branch)"
+msgstr "  (använd \"git am --abort\" för att återställa ursprungsgrenen)"
+
+#: wt-status.c:1309
+msgid "git-rebase-todo is missing."
+msgstr "git-rebase-todo saknas."
+
+#: wt-status.c:1311
+msgid "No commands done."
+msgstr "Inga kommandon utförda."
+
+#: wt-status.c:1314
+#, c-format
+msgid "Last command done (%d command done):"
+msgid_plural "Last commands done (%d commands done):"
+msgstr[0] "Sista kommandot utfört (%d kommando utfört):"
+msgstr[1] "Sista kommandot utfört (%d kommandon utfört):"
+
+#: wt-status.c:1325
+#, c-format
+msgid "  (see more in file %s)"
+msgstr "  (se fler i filen %s)"
+
+#: wt-status.c:1330
+msgid "No commands remaining."
+msgstr "Inga kommandon återstår."
+
+#: wt-status.c:1333
+#, c-format
+msgid "Next command to do (%d remaining command):"
+msgid_plural "Next commands to do (%d remaining commands):"
+msgstr[0] "Nästa kommando att utföra (%d kommando återstår):"
+msgstr[1] "Följande kommandon att utföra (%d kommandon återstår):"
+
+#: wt-status.c:1341
+msgid "  (use \"git rebase --edit-todo\" to view and edit)"
+msgstr "  (använd \"git rebase --edit-todo\" för att visa och redigera)"
+
+#: wt-status.c:1353
+#, c-format
+msgid "You are currently rebasing branch '%s' on '%s'."
+msgstr "Du håller på att ombasera grenen \"%s\" ovanpå \"%s\"."
+
+#: wt-status.c:1358
+msgid "You are currently rebasing."
+msgstr "Du håller på med en ombasering."
+
+#: wt-status.c:1371
+msgid "  (fix conflicts and then run \"git rebase --continue\")"
+msgstr "  (rätta konflikter och kör sedan \"git rebase --continue\")"
+
+#: wt-status.c:1373
+msgid "  (use \"git rebase --skip\" to skip this patch)"
+msgstr "  (använd \"git rebase --skip\" för att hoppa över patchen)"
+
+#: wt-status.c:1375
+msgid "  (use \"git rebase --abort\" to check out the original branch)"
+msgstr "  (använd \"git rebase --abort\" för att checka ut ursprungsgrenen)"
+
+#: wt-status.c:1382
+msgid "  (all conflicts fixed: run \"git rebase --continue\")"
+msgstr "  (alla konflikter rättade: kör \"git rebase --continue\")"
+
+#: wt-status.c:1386
+#, c-format
+msgid ""
+"You are currently splitting a commit while rebasing branch '%s' on '%s'."
+msgstr ""
+"Du håller på att dela upp en incheckning medan du ombaserar grenen \"%s\" "
+"ovanpå \"%s\"."
+
+#: wt-status.c:1391
+msgid "You are currently splitting a commit during a rebase."
+msgstr "Du håller på att dela upp en incheckning i en ombasering."
+
+#: wt-status.c:1394
+msgid "  (Once your working directory is clean, run \"git rebase --continue\")"
+msgstr "  (Så fort din arbetskatalog är ren, kör \"git rebase --continue\")"
+
+#: wt-status.c:1398
+#, c-format
+msgid "You are currently editing a commit while rebasing branch '%s' on '%s'."
+msgstr ""
+"Du håller på att redigera en incheckning medan du ombaserar grenen \"%s\" "
+"ovanpå \"%s\"."
+
+#: wt-status.c:1403
+msgid "You are currently editing a commit during a rebase."
+msgstr "Du håller på att redigera en incheckning under en ombasering."
+
+#: wt-status.c:1406
+msgid "  (use \"git commit --amend\" to amend the current commit)"
+msgstr ""
+"  (använd \"git commit --amend\" för att lägga till på aktuell incheckning)"
+
+#: wt-status.c:1408
+msgid ""
+"  (use \"git rebase --continue\" once you are satisfied with your changes)"
+msgstr "  (använd \"git rebase --continue\" när du är nöjd med dina ändringar)"
+
+#: wt-status.c:1419
+msgid "Cherry-pick currently in progress."
+msgstr "Cherry-pick pågår."
+
+#: wt-status.c:1422
+#, c-format
+msgid "You are currently cherry-picking commit %s."
+msgstr "Du håller på med en \"cherry-pick\" av incheckningen %s."
+
+#: wt-status.c:1429
+msgid "  (fix conflicts and run \"git cherry-pick --continue\")"
+msgstr "  (rätta konflikter och kör sedan \"git cherry-pick --continue\")"
+
+#: wt-status.c:1432
+msgid "  (run \"git cherry-pick --continue\" to continue)"
+msgstr "  (kör \"git cherry-pick --continue\" för att fortsätta)"
+
+#: wt-status.c:1435
+msgid "  (all conflicts fixed: run \"git cherry-pick --continue\")"
+msgstr "  (alla konflikter rättade: kör \"git cherry-pick --continue\")"
+
+#: wt-status.c:1437
+msgid "  (use \"git cherry-pick --skip\" to skip this patch)"
+msgstr "  (använd \"git cherry-pick --skip\" för att hoppa över patchen)"
+
+#: wt-status.c:1439
+msgid "  (use \"git cherry-pick --abort\" to cancel the cherry-pick operation)"
+msgstr ""
+"  (använd \"git cherry-pick --abort\" för att avbryta \"cherry-pick\"-"
+"operationen)"
+
+#: wt-status.c:1449
+msgid "Revert currently in progress."
+msgstr "Ångring pågår."
+
+#: wt-status.c:1452
+#, c-format
+msgid "You are currently reverting commit %s."
+msgstr "Du håller på med att ångra incheckningen %s."
+
+#: wt-status.c:1458
+msgid "  (fix conflicts and run \"git revert --continue\")"
+msgstr "  (rätta konflikter och kör sedan \"git revert --continue\")"
+
+#: wt-status.c:1461
+msgid "  (run \"git revert --continue\" to continue)"
+msgstr "  (kör \"git revert --continue\" för att fortsätta)"
+
+#: wt-status.c:1464
+msgid "  (all conflicts fixed: run \"git revert --continue\")"
+msgstr "  (alla konflikter rättade: kör \"git revert --continue\")"
+
+#: wt-status.c:1466
+msgid "  (use \"git revert --skip\" to skip this patch)"
+msgstr "  (använd \"git revert --skip\" för att hoppa över patchen)"
+
+#: wt-status.c:1468
+msgid "  (use \"git revert --abort\" to cancel the revert operation)"
+msgstr "  (använd \"git revert --abort\" för att avbryta ångrandet)"
+
+#: wt-status.c:1478
+#, c-format
+msgid "You are currently bisecting, started from branch '%s'."
+msgstr "Du håller på med en \"bisect\", startad från grenen \"%s\"."
+
+#: wt-status.c:1482
+msgid "You are currently bisecting."
+msgstr "Du håller på med en \"bisect\"."
+
+#: wt-status.c:1485
+msgid "  (use \"git bisect reset\" to get back to the original branch)"
+msgstr ""
+"  (använd \"git bisect reset\" för att komma tillbaka till ursprungsgrenen)"
+
+#: wt-status.c:1694
+msgid "On branch "
+msgstr "På grenen "
+
+#: wt-status.c:1701
+msgid "interactive rebase in progress; onto "
+msgstr "interaktiv ombasering pågår; ovanpå "
+
+#: wt-status.c:1703
+msgid "rebase in progress; onto "
+msgstr "ombasering pågår; ovanpå "
+
+#: wt-status.c:1713
+msgid "Not currently on any branch."
+msgstr "Inte på någon gren för närvarande."
+
+#: wt-status.c:1730
+msgid "Initial commit"
+msgstr "Första incheckning"
+
+#: wt-status.c:1731
+msgid "No commits yet"
+msgstr "Inga incheckningar ännu"
+
+#: wt-status.c:1745
+msgid "Untracked files"
+msgstr "Ospårade filer"
+
+#: wt-status.c:1747
+msgid "Ignored files"
+msgstr "Ignorerade filer"
+
+#: wt-status.c:1751
+#, c-format
+msgid ""
+"It took %.2f seconds to enumerate untracked files. 'status -uno'\n"
+"may speed it up, but you have to be careful not to forget to add\n"
+"new files yourself (see 'git help status')."
+msgstr ""
+"Det tog %.2f sekunder att räkna upp ospårade filer. \"status -uno\"\n"
+"kan gå snabbare, men du måste vara försiktig så du inte glömmer\n"
+"lägga till nya filer själv (se \"git help status\")."
+
+# %s är nästa sträng eller tom.
+#: wt-status.c:1757
+#, c-format
+msgid "Untracked files not listed%s"
+msgstr "Ospårade filer visas ej%s"
+
+#: wt-status.c:1759
+msgid " (use -u option to show untracked files)"
+msgstr " (använd flaggan -u för att visa ospårade filer)"
+
+#: wt-status.c:1765
+msgid "No changes"
+msgstr "Inga ändringar"
+
+#: wt-status.c:1770
+#, c-format
+msgid "no changes added to commit (use \"git add\" and/or \"git commit -a\")\n"
+msgstr ""
+"inga ändringar att checka in (använd \"git add\" och/eller \"git commit -a"
+"\")\n"
+
+#: wt-status.c:1773
+#, c-format
+msgid "no changes added to commit\n"
+msgstr "inga ändringar att checka in\n"
+
+#: wt-status.c:1776
+#, c-format
+msgid ""
+"nothing added to commit but untracked files present (use \"git add\" to "
+"track)\n"
+msgstr ""
+"inget köat för incheckning, men ospårade filer finns (spåra med \"git add"
+"\")\n"
+
+#: wt-status.c:1779
+#, c-format
+msgid "nothing added to commit but untracked files present\n"
+msgstr "inget köat för incheckning, men ospårade filer finns\n"
+
+#: wt-status.c:1782
+#, c-format
+msgid "nothing to commit (create/copy files and use \"git add\" to track)\n"
+msgstr "inget att checka in (skapa/kopiera filer och spåra med \"git add\")\n"
+
+#: wt-status.c:1785 wt-status.c:1790
+#, c-format
+msgid "nothing to commit\n"
+msgstr "inget att checka in\n"
+
+#: wt-status.c:1788
+#, c-format
+msgid "nothing to commit (use -u to show untracked files)\n"
+msgstr "inget att checka in (använd -u för att visa ospårade filer)\n"
+
+#: wt-status.c:1792
+#, c-format
+msgid "nothing to commit, working tree clean\n"
+msgstr "inget att checka in, arbetskatalogen ren\n"
+
+#: wt-status.c:1905
+msgid "No commits yet on "
+msgstr "Inga incheckningar ännu på "
+
+#: wt-status.c:1909
+msgid "HEAD (no branch)"
+msgstr "HEAD (ingen gren)"
+
+#: wt-status.c:1940
+msgid "different"
+msgstr "olika"
+
+#: wt-status.c:1942 wt-status.c:1950
+msgid "behind "
+msgstr "efter "
+
+#: wt-status.c:1945 wt-status.c:1948
+msgid "ahead "
+msgstr "före "
+
+#. TRANSLATORS: the action is e.g. "pull with rebase"
+#: wt-status.c:2470
+#, c-format
+msgid "cannot %s: You have unstaged changes."
+msgstr "kan inte %s: Du har oköade ändringar."
+
+#: wt-status.c:2476
+msgid "additionally, your index contains uncommitted changes."
+msgstr "dessutom innehåller dit index ändringar som inte har checkats in."
+
+#: wt-status.c:2478
+#, c-format
+msgid "cannot %s: Your index contains uncommitted changes."
+msgstr "kan inte %s: Ditt index innehåller ändringar som inte checkats in."
+
+#: compat/precompose_utf8.c:58 builtin/clone.c:455
+#, c-format
+msgid "failed to unlink '%s'"
+msgstr "misslyckades ta bort länken \"%s\""
+
+#: builtin/add.c:26
+msgid "git add [<options>] [--] <pathspec>..."
+msgstr "git add [<flaggor>] [--] <sökväg>..."
+
+#: builtin/add.c:87
+#, c-format
+msgid "unexpected diff status %c"
+msgstr "diff-status %c förväntades inte"
+
+#: builtin/add.c:92 builtin/commit.c:288
+msgid "updating files failed"
+msgstr "misslyckades uppdatera filer"
+
+#: builtin/add.c:102
+#, c-format
+msgid "remove '%s'\n"
+msgstr "ta bort \"%s\"\n"
+
+#: builtin/add.c:177
+msgid "Unstaged changes after refreshing the index:"
+msgstr "Oköade ändringar efter att ha uppdaterat indexet:"
+
+#: builtin/add.c:252 builtin/rev-parse.c:899
+msgid "Could not read the index"
+msgstr "Kunde inte läsa indexet"
+
+#: builtin/add.c:263
+#, c-format
+msgid "Could not open '%s' for writing."
+msgstr "Kunde inte öppna \"%s\" för skrivning."
+
+#: builtin/add.c:267
+msgid "Could not write patch"
+msgstr "Kunde inte skriva patch"
+
+#: builtin/add.c:270
+msgid "editing patch failed"
+msgstr "redigering av patch misslyckades"
+
+#: builtin/add.c:273
+#, c-format
+msgid "Could not stat '%s'"
+msgstr "Kunde inte ta status på \"%s\""
+
+#: builtin/add.c:275
+msgid "Empty patch. Aborted."
+msgstr "Tom patch. Avbryter."
+
+#: builtin/add.c:280
+#, c-format
+msgid "Could not apply '%s'"
+msgstr "Kunde inte tillämpa \"%s\""
+
+#: builtin/add.c:288
+msgid "The following paths are ignored by one of your .gitignore files:\n"
+msgstr "Följande sökvägar ignoreras av en av dina .gitignore-filer:\n"
+
+#: builtin/add.c:308 builtin/clean.c:910 builtin/fetch.c:163 builtin/mv.c:124
+#: builtin/prune-packed.c:56 builtin/pull.c:223 builtin/push.c:548
+#: builtin/remote.c:1344 builtin/rm.c:241 builtin/send-pack.c:165
+msgid "dry run"
+msgstr "testkörning"
+
+#: builtin/add.c:311
+msgid "interactive picking"
+msgstr "plocka interaktivt"
+
+#: builtin/add.c:312 builtin/checkout.c:1482 builtin/reset.c:307
+msgid "select hunks interactively"
+msgstr "välj stycken interaktivt"
+
+#: builtin/add.c:313
+msgid "edit current diff and apply"
+msgstr "redigera aktuell diff och applicera"
+
+#: builtin/add.c:314
+msgid "allow adding otherwise ignored files"
+msgstr "tillåt lägga till annars ignorerade filer"
+
+#: builtin/add.c:315
+msgid "update tracked files"
+msgstr "uppdatera spårade filer"
+
+#: builtin/add.c:316
+msgid "renormalize EOL of tracked files (implies -u)"
+msgstr "åternormalisera radslut i spårade filer (implicerar -u)"
+
+#: builtin/add.c:317
+msgid "record only the fact that the path will be added later"
+msgstr "registrera endast att sökvägen kommer läggas till senare"
+
+#: builtin/add.c:318
+msgid "add changes from all tracked and untracked files"
+msgstr "lägg till ändringar från alla spårade och ospårade filer"
+
+#: builtin/add.c:321
+msgid "ignore paths removed in the working tree (same as --no-all)"
+msgstr "ignorera sökvägar borttagna i arbetskatalogen (samma som --no-all)"
+
+#: builtin/add.c:323
+msgid "don't add, only refresh the index"
+msgstr "lägg inte till, uppdatera endast indexet"
+
+#: builtin/add.c:324
+msgid "just skip files which cannot be added because of errors"
+msgstr "hoppa bara över filer som inte kan läggas till på grund av fel"
+
+#: builtin/add.c:325
+msgid "check if - even missing - files are ignored in dry run"
+msgstr "se om - även saknade - filer ignoreras i testkörning"
+
+#: builtin/add.c:327 builtin/update-index.c:1004
+msgid "override the executable bit of the listed files"
+msgstr "överstyr exekveringsbiten för angivna filer"
+
+#: builtin/add.c:329
+msgid "warn when adding an embedded repository"
+msgstr "varna när ett inbyggt arkiv läggs till"
+
+#: builtin/add.c:347
+#, c-format
+msgid ""
+"You've added another git repository inside your current repository.\n"
+"Clones of the outer repository will not contain the contents of\n"
+"the embedded repository and will not know how to obtain it.\n"
+"If you meant to add a submodule, use:\n"
+"\n"
+"\tgit submodule add <url> %s\n"
+"\n"
+"If you added this path by mistake, you can remove it from the\n"
+"index with:\n"
+"\n"
+"\tgit rm --cached %s\n"
+"\n"
+"See \"git help submodule\" for more information."
+msgstr ""
+"Du har lagt till ett annat git-arkiv inuti aktuellt arkiv.\n"
+"Kloner av det yttre arkivet kommer inte innehålla innehållet från\n"
+"det inbäddade arkivet eller veta hur man får tag på det.\n"
+"Om du tänkte lägga till en undermodul, skrev:\n"
+"\n"
+"\tgit submodule add <url> %s\n"
+"\n"
+"Om du lade till sökvägen av misstag tar du bort den från indexet\n"
+"med:\n"
+"\n"
+"\tgit rm --cached %s\n"
+"\n"
+"Se \"git help submodule\" för ytterligare information."
+
+#: builtin/add.c:375
+#, c-format
+msgid "adding embedded git repository: %s"
+msgstr "lägger till inbäddat git-arkiv: %s"
+
+#: builtin/add.c:393
+#, c-format
+msgid "Use -f if you really want to add them.\n"
+msgstr "Använd -f om du verkligen vill lägga till dem.\n"
+
+#: builtin/add.c:400
+msgid "adding files failed"
+msgstr "misslyckades lägga till filer"
+
+#: builtin/add.c:428 builtin/commit.c:348
+msgid "--pathspec-from-file is incompatible with --interactive/--patch"
+msgstr "--pathspec-from-file är inkompatibelt med --interactive/--patch"
+
+#: builtin/add.c:434
+msgid "--pathspec-from-file is incompatible with --edit"
+msgstr "--pathspec-from-file är inkompatibelt med --edit"
+
+#: builtin/add.c:446
+msgid "-A and -u are mutually incompatible"
+msgstr "-A och -u är ömsesidigt inkompatibla"
+
+#: builtin/add.c:449
+msgid "Option --ignore-missing can only be used together with --dry-run"
+msgstr "Flaggan --ignore-missing kan endast användas tillsammans med --dry-run"
+
+#: builtin/add.c:453
+#, c-format
+msgid "--chmod param '%s' must be either -x or +x"
+msgstr "--chmod-parametern \"%s\" måste antingen vara -x eller +x"
+
+#: builtin/add.c:471 builtin/checkout.c:1648 builtin/commit.c:354
+#: builtin/reset.c:327
+msgid "--pathspec-from-file is incompatible with pathspec arguments"
+msgstr "--pathspec-from-file är inkompatibelt med sökvägsangivelsesparametrar"
+
+#: builtin/add.c:478 builtin/checkout.c:1660 builtin/commit.c:360
+#: builtin/reset.c:333
+msgid "--pathspec-file-nul requires --pathspec-from-file"
+msgstr "--pathspec-file-nul kräver --pathspec-from-file"
+
+#: builtin/add.c:482
+#, c-format
+msgid "Nothing specified, nothing added.\n"
+msgstr "Inget angivet, inget tillagt.\n"
+
+#: builtin/add.c:483
+#, c-format
+msgid "Maybe you wanted to say 'git add .'?\n"
+msgstr "Kanske menade du att skriva \"git add .\"?\n"
+
+#: builtin/am.c:347
+msgid "could not parse author script"
+msgstr "kunde inte tolka författarskript"
+
+#: builtin/am.c:431
+#, c-format
+msgid "'%s' was deleted by the applypatch-msg hook"
+msgstr "\"%s\" togs bort av kroken applypatch-msg"
+
+#: builtin/am.c:473
+#, c-format
+msgid "Malformed input line: '%s'."
+msgstr "Felaktig indatarad: \"%s\"."
+
+#: builtin/am.c:511
+#, c-format
+msgid "Failed to copy notes from '%s' to '%s'"
+msgstr "Misslyckades kopiera anteckningar från \"%s\" till \"%s\""
+
+#: builtin/am.c:537
+msgid "fseek failed"
+msgstr "\"fseek\" misslyckades"
+
+#: builtin/am.c:725
+#, c-format
+msgid "could not parse patch '%s'"
+msgstr "kunde inte tolka patchen \"%s\""
+
+#: builtin/am.c:790
+msgid "Only one StGIT patch series can be applied at once"
+msgstr "Endast en StGIT-patchserie kan tillämpas åt gången"
+
+#: builtin/am.c:838
+msgid "invalid timestamp"
+msgstr "ogiltig tidsstämpel"
+
+#: builtin/am.c:843 builtin/am.c:855
+msgid "invalid Date line"
+msgstr "ogiltig \"Date\"-rad"
+
+#: builtin/am.c:850
+msgid "invalid timezone offset"
+msgstr "ogiltig tidszons-offset"
+
+#: builtin/am.c:943
+msgid "Patch format detection failed."
+msgstr "Misslyckades detektera patchformat."
+
+#: builtin/am.c:948 builtin/clone.c:409
+#, c-format
+msgid "failed to create directory '%s'"
+msgstr "misslyckades skapa katalogen \"%s\""
+
+#: builtin/am.c:953
+msgid "Failed to split patches."
+msgstr "Misslyckades dela patchar."
+
+#: builtin/am.c:1084
+#, c-format
+msgid "When you have resolved this problem, run \"%s --continue\"."
+msgstr "När du har löst problemet, kör \"%s --continue\"."
+
+#: builtin/am.c:1085
+#, c-format
+msgid "If you prefer to skip this patch, run \"%s --skip\" instead."
+msgstr "Om du hellre vill hoppa över patchen, kör \"%s --skip\" i stället."
+
+#: builtin/am.c:1086
+#, c-format
+msgid "To restore the original branch and stop patching, run \"%s --abort\"."
+msgstr ""
+"För att återgå till ursprunglig gren och sluta patcha, kör \"%s --abort\"."
+
+#: builtin/am.c:1169
+msgid "Patch sent with format=flowed; space at the end of lines might be lost."
+msgstr ""
+"Patch sänd med format=flowed; blanksteg på slut av rader kan ha tappats."
+
+#: builtin/am.c:1197
+msgid "Patch is empty."
+msgstr "Patchen är tom."
+
+#: builtin/am.c:1262
+#, c-format
+msgid "missing author line in commit %s"
+msgstr "saknad \"author\"-rad i incheckningen %s"
+
+#: builtin/am.c:1265
+#, c-format
+msgid "invalid ident line: %.*s"
+msgstr "ogiltig ident-rad: %.*s"
+
+#: builtin/am.c:1484
+msgid "Repository lacks necessary blobs to fall back on 3-way merge."
+msgstr ""
+"Arkivet saknar objekt som behövs för att falla tillbaka på 3-"
+"vägssammanslagning."
+
+#: builtin/am.c:1486
+msgid "Using index info to reconstruct a base tree..."
+msgstr "Använder indexinfo för att återskapa ett basträd..."
+
+#: builtin/am.c:1505
+msgid ""
+"Did you hand edit your patch?\n"
+"It does not apply to blobs recorded in its index."
+msgstr ""
+"Har du handredigerat din patch?\n"
+"Den kan inte tillämpas på blobbar som antecknats i dess index."
+
+#: builtin/am.c:1511
+msgid "Falling back to patching base and 3-way merge..."
+msgstr ""
+"Faller tillbaka på att patcha grundversionen och trevägssammanslagning..."
+
+#: builtin/am.c:1537
+msgid "Failed to merge in the changes."
+msgstr "Misslyckades slå ihop ändringarna."
+
+#: builtin/am.c:1569
+msgid "applying to an empty history"
+msgstr "tillämpar på en tom historik"
+
+#: builtin/am.c:1616 builtin/am.c:1620
+#, c-format
+msgid "cannot resume: %s does not exist."
+msgstr "kan inte återuppta: %s finns inte."
+
+#: builtin/am.c:1638
+msgid "Commit Body is:"
+msgstr "Incheckningskroppen är:"
+
+#. TRANSLATORS: Make sure to include [y], [n], [e], [v] and [a]
+#. in your translation. The program will only accept English
+#. input at this point.
+#.
+#: builtin/am.c:1648
+#, c-format
+msgid "Apply? [y]es/[n]o/[e]dit/[v]iew patch/[a]ccept all: "
+msgstr "Tillämpa? Y=ja/N=nej/E=redigera/V=visa patch/A=godta alla: "
+
+#: builtin/am.c:1695 builtin/commit.c:394
+msgid "unable to write index file"
+msgstr "kan inte skriva indexfil"
+
+#: builtin/am.c:1699
+#, c-format
+msgid "Dirty index: cannot apply patches (dirty: %s)"
+msgstr "Smutsigt index: kan inte tillämpa patchar (smutsiga: %s)"
+
+#: builtin/am.c:1739 builtin/am.c:1807
+#, c-format
+msgid "Applying: %.*s"
+msgstr "Tillämpar: %.*s"
+
+#: builtin/am.c:1756
+msgid "No changes -- Patch already applied."
+msgstr "Inga ändringar -- Patchen har redan tillämpats."
+
+#: builtin/am.c:1762
+#, c-format
+msgid "Patch failed at %s %.*s"
+msgstr "Patch misslyckades på %s %.*s"
+
+#: builtin/am.c:1766
+msgid "Use 'git am --show-current-patch' to see the failed patch"
+msgstr ""
+"Använd \"git am --show-current-patch\" för att se patchen som misslyckades"
+
+#: builtin/am.c:1810
+msgid ""
+"No changes - did you forget to use 'git add'?\n"
+"If there is nothing left to stage, chances are that something else\n"
+"already introduced the same changes; you might want to skip this patch."
+msgstr ""
+"Inga ändringar - glömde du att använda \"git add\"?\n"
+"Om det inte är något kvar att köa kan det hända att något annat redan\n"
+"introducerat samma ändringar; kanske du bör hoppa över patchen."
+
+#: builtin/am.c:1817
+msgid ""
+"You still have unmerged paths in your index.\n"
+"You should 'git add' each file with resolved conflicts to mark them as "
+"such.\n"
+"You might run `git rm` on a file to accept \"deleted by them\" for it."
+msgstr ""
+"Du har fortfarande ej sammanslagna sökvägar i indexet.\n"
+"Du bör köra \"git add\" på filer med lösta konflikter för att ange dem som "
+"lösta.\n"
+"Du kan köra \"git rm\" för att godta \"borttagen av dem\" för den."
+
+#: builtin/am.c:1924 builtin/am.c:1928 builtin/am.c:1940 builtin/reset.c:346
+#: builtin/reset.c:354
+#, c-format
+msgid "Could not parse object '%s'."
+msgstr "Kan inte tolka objektet \"%s\"."
+
+#: builtin/am.c:1976
+msgid "failed to clean index"
+msgstr "misslyckades städa upp indexet"
+
+#: builtin/am.c:2020
+msgid ""
+"You seem to have moved HEAD since the last 'am' failure.\n"
+"Not rewinding to ORIG_HEAD"
+msgstr ""
+"Du verkar ha flyttat HEAD sedan \"am\" sist misslyckades.\n"
+"Återställer inte till ORIG_HEAD"
+
+#: builtin/am.c:2117
+#, c-format
+msgid "Invalid value for --patch-format: %s"
+msgstr "Felaktigt värde för --patch-format: %s"
+
+#: builtin/am.c:2153
+msgid "git am [<options>] [(<mbox> | <Maildir>)...]"
+msgstr "git am [<flaggor>] [(<mbox> | <Maildir>)...]"
+
+#: builtin/am.c:2154
+msgid "git am [<options>] (--continue | --skip | --abort)"
+msgstr "git am [<flaggor>] (--continue | --skip | --abort)"
+
+#: builtin/am.c:2160
+msgid "run interactively"
+msgstr "kör interaktivt"
+
+#: builtin/am.c:2162
+msgid "historical option -- no-op"
+msgstr "historisk flagga -- no-op"
+
+#: builtin/am.c:2164
+msgid "allow fall back on 3way merging if needed"
+msgstr "tillåt falla tillbaka på trevägssammanslagning om nödvändigt"
+
+#: builtin/am.c:2165 builtin/init-db.c:494 builtin/prune-packed.c:58
+#: builtin/repack.c:304 builtin/stash.c:811
+msgid "be quiet"
+msgstr "var tyst"
+
+#: builtin/am.c:2167
+msgid "add a Signed-off-by line to the commit message"
+msgstr "lägg till \"Signed-off-by\"-rad i incheckningsmeddelandet"
+
+#: builtin/am.c:2170
+msgid "recode into utf8 (default)"
+msgstr "koda om till utf8 (standard)"
+
+#: builtin/am.c:2172
+msgid "pass -k flag to git-mailinfo"
+msgstr "sänd flaggan -k till git-mailinfo"
+
+#: builtin/am.c:2174
+msgid "pass -b flag to git-mailinfo"
+msgstr "sänd flaggan -b till git-mailinfo"
+
+#: builtin/am.c:2176
+msgid "pass -m flag to git-mailinfo"
+msgstr "sänd flaggan -m till git-mailinfo"
+
+#: builtin/am.c:2178
+msgid "pass --keep-cr flag to git-mailsplit for mbox format"
+msgstr "sänd flaggan --keep-cr till git-mailsplit för mbox-formatet"
+
+#: builtin/am.c:2181
+msgid "do not pass --keep-cr flag to git-mailsplit independent of am.keepcr"
+msgstr "sänd inte flaggan --keep-cr till git-mailsplit oberoende av am.keepcr"
+
+#: builtin/am.c:2184
+msgid "strip everything before a scissors line"
+msgstr "ta bort allting före en saxlinje"
+
+#: builtin/am.c:2186 builtin/am.c:2189 builtin/am.c:2192 builtin/am.c:2195
+#: builtin/am.c:2198 builtin/am.c:2201 builtin/am.c:2204 builtin/am.c:2207
+#: builtin/am.c:2213
+msgid "pass it through git-apply"
+msgstr "sänd det genom git-apply"
+
+#: builtin/am.c:2203 builtin/commit.c:1386 builtin/fmt-merge-msg.c:673
+#: builtin/fmt-merge-msg.c:676 builtin/grep.c:883 builtin/merge.c:249
+#: builtin/pull.c:160 builtin/pull.c:219 builtin/rebase.c:1469
+#: builtin/repack.c:315 builtin/repack.c:319 builtin/repack.c:321
+#: builtin/show-branch.c:650 builtin/show-ref.c:172 builtin/tag.c:403
+#: parse-options.h:154 parse-options.h:175 parse-options.h:316
+msgid "n"
+msgstr "n"
+
+#: builtin/am.c:2209 builtin/branch.c:661 builtin/for-each-ref.c:38
+#: builtin/replace.c:555 builtin/tag.c:437 builtin/verify-tag.c:38
+msgid "format"
+msgstr "format"
+
+#: builtin/am.c:2210
+msgid "format the patch(es) are in"
+msgstr "format för patch(ar)"
+
+#: builtin/am.c:2216
+msgid "override error message when patch failure occurs"
+msgstr "överstyr felmeddelanden när patchfel uppstår"
+
+#: builtin/am.c:2218
+msgid "continue applying patches after resolving a conflict"
+msgstr "fortsätt applicera patchar efter att ha löst en konflikt"
+
+#: builtin/am.c:2221
+msgid "synonyms for --continue"
+msgstr "synonymer till --continue"
+
+#: builtin/am.c:2224
+msgid "skip the current patch"
+msgstr "hoppa över den aktuella grenen"
+
+#: builtin/am.c:2227
+msgid "restore the original branch and abort the patching operation."
+msgstr "återställ originalgrenen och avbryt patchningen."
+
+#: builtin/am.c:2230
+msgid "abort the patching operation but keep HEAD where it is."
+msgstr "avbryt patchningen men behåll HEAD där det är."
+
+#: builtin/am.c:2233
+msgid "show the patch being applied."
+msgstr "visa patchen som tillämpas."
+
+#: builtin/am.c:2237
+msgid "lie about committer date"
+msgstr "ljug om incheckningsdatum"
+
+#: builtin/am.c:2239
+msgid "use current timestamp for author date"
+msgstr "använd nuvarande tidsstämpel för författardatum"
+
+#: builtin/am.c:2241 builtin/commit-tree.c:120 builtin/commit.c:1507
+#: builtin/merge.c:286 builtin/pull.c:194 builtin/rebase.c:509
+#: builtin/rebase.c:1513 builtin/revert.c:117 builtin/tag.c:418
+msgid "key-id"
+msgstr "nyckel-id"
+
+#: builtin/am.c:2242 builtin/rebase.c:510 builtin/rebase.c:1514
+msgid "GPG-sign commits"
+msgstr "GPG-signera incheckningar"
+
+#: builtin/am.c:2245
+msgid "(internal use for git-rebase)"
+msgstr "(används internt av git-rebase)"
+
+#: builtin/am.c:2263
+msgid ""
+"The -b/--binary option has been a no-op for long time, and\n"
+"it will be removed. Please do not use it anymore."
+msgstr ""
+"Flaggan -b/--binary har varit utan funktion länge, och\n"
+"kommer tas bort. Vi ber dig att inte använda den längre."
+
+#: builtin/am.c:2270
+msgid "failed to read the index"
+msgstr "misslyckades läsa indexet"
+
+#: builtin/am.c:2285
+#, c-format
+msgid "previous rebase directory %s still exists but mbox given."
+msgstr "tidigare rebase-katalog %s finns fortfarande, men mbox angavs."
+
+#: builtin/am.c:2309
+#, c-format
+msgid ""
+"Stray %s directory found.\n"
+"Use \"git am --abort\" to remove it."
+msgstr ""
+"Kvarbliven katalog %s hittades.\n"
+"Använd \"git am --abort\" för att ta bort den."
+
+#: builtin/am.c:2315
+msgid "Resolve operation not in progress, we are not resuming."
+msgstr "Lösningsoperation pågår inte, vi återupptar inte."
+
+#: builtin/am.c:2325
+msgid "interactive mode requires patches on the command line"
+msgstr "interaktivt läge kräver patchar på kommandoraden"
+
+#: builtin/apply.c:8
+msgid "git apply [<options>] [<patch>...]"
+msgstr "git apply [<flaggor>] [<patch>...]"
+
+#: builtin/archive.c:17
+#, c-format
+msgid "could not create archive file '%s'"
+msgstr "kunde inte skapa arkivfilen \"%s\""
+
+#: builtin/archive.c:20
+msgid "could not redirect output"
+msgstr "kunde inte omdirigera utdata"
+
+#: builtin/archive.c:37
+msgid "git archive: Remote with no URL"
+msgstr "git archive: Fjärr utan URL"
+
+#: builtin/archive.c:61
+msgid "git archive: expected ACK/NAK, got a flush packet"
+msgstr "git archive: förväntade ACK/NAK, fick flush-paket"
+
+#: builtin/archive.c:64
+#, c-format
+msgid "git archive: NACK %s"
+msgstr "git archive: NACK %s"
+
+#: builtin/archive.c:65
+msgid "git archive: protocol error"
+msgstr "git archive: protokollfel"
+
+#: builtin/archive.c:69
+msgid "git archive: expected a flush"
+msgstr "git archive: förväntade en tömning (flush)"
+
+#: builtin/bisect--helper.c:22
+msgid "git bisect--helper --next-all [--no-checkout]"
+msgstr "git bisect--helper --next-all [--no-checkout]"
+
+#: builtin/bisect--helper.c:23
+msgid "git bisect--helper --write-terms <bad_term> <good_term>"
+msgstr "git bisect--helper --write-terms <term-för-fel> <term-för-rätt>"
+
+#: builtin/bisect--helper.c:24
+msgid "git bisect--helper --bisect-clean-state"
+msgstr "git bisect--helper --bisect-clean-state"
+
+#: builtin/bisect--helper.c:25
+msgid "git bisect--helper --bisect-reset [<commit>]"
+msgstr "git bisect--helper --bisect-reset [<incheckning>]"
+
+#: builtin/bisect--helper.c:26
+msgid ""
+"git bisect--helper --bisect-write [--no-log] <state> <revision> <good_term> "
+"<bad_term>"
+msgstr ""
+"git bisect--helper --bisect-write [--no-log] <tillstånd> <revision> <term-"
+"för-rätt> <term-för-fel>"
+
+#: builtin/bisect--helper.c:27
+msgid ""
+"git bisect--helper --bisect-check-and-set-terms <command> <good_term> "
+"<bad_term>"
+msgstr ""
+"git bisect--helper --bisect-check-and-set-terms <kommadno> <term-för-rätt> "
+"<term-för-fel>"
+
+#: builtin/bisect--helper.c:28
+msgid "git bisect--helper --bisect-next-check <good_term> <bad_term> [<term>]"
+msgstr ""
+"git bisect--helper --bisect-next-check <term-för-rätt> <term-för-fel> <eterm>"
+
+#: builtin/bisect--helper.c:29
+msgid ""
+"git bisect--helper --bisect-terms [--term-good | --term-old | --term-bad | --"
+"term-new]"
+msgstr ""
+"git-bisect--helper --bisect-terms [--term-good | --term-old | --term-bad | --"
+"term-new]"
+
+#: builtin/bisect--helper.c:30
+msgid ""
+"git bisect--helper --bisect-start [--term-{old,good}=<term> --term-{new,bad}"
+"=<term>][--no-checkout] [<bad> [<good>...]] [--] [<paths>...]"
+msgstr ""
+"git bisect--helper --bisect-start [--term-{old,good}=<term> --term-{new,bad}"
+"=<term>][--no-checkout] [<fel> [<rätt>...]] [--] [<sökvägar>...]"
+
+#: builtin/bisect--helper.c:86
+#, c-format
+msgid "'%s' is not a valid term"
+msgstr "\"%s\" är inte en giltig term"
+
+#: builtin/bisect--helper.c:90
+#, c-format
+msgid "can't use the builtin command '%s' as a term"
+msgstr "kan inte använda det inbyggda kommandot \"%s\" som term"
+
+#: builtin/bisect--helper.c:100
+#, c-format
+msgid "can't change the meaning of the term '%s'"
+msgstr "kan inte ändra betydelsen av termen \"%s\""
+
+#: builtin/bisect--helper.c:111
+msgid "please use two different terms"
+msgstr "termerna måste vara olika"
+
+#: builtin/bisect--helper.c:118
+msgid "could not open the file BISECT_TERMS"
+msgstr "kunde inte öppna filen BISECT_TERMS"
+
+#: builtin/bisect--helper.c:155
+#, c-format
+msgid "We are not bisecting.\n"
+msgstr "Vi utför ingen bisect för tillfället.\n"
+
+#: builtin/bisect--helper.c:163
+#, c-format
+msgid "'%s' is not a valid commit"
+msgstr "\"%s\" är inte en giltig incheckning"
+
+#: builtin/bisect--helper.c:172
+#, c-format
+msgid ""
+"could not check out original HEAD '%s'. Try 'git bisect reset <commit>'."
+msgstr ""
+"Kunde inte checka ut original-HEAD \"%s\". Försök \"git bisect reset "
+"<incheckning>\"."
+
+#: builtin/bisect--helper.c:216
+#, c-format
+msgid "Bad bisect_write argument: %s"
+msgstr "Felaktigt argument till bisect_write: %s"
+
+#: builtin/bisect--helper.c:221
+#, c-format
+msgid "couldn't get the oid of the rev '%s'"
+msgstr "kan inte läsa oid för referensen \"%s\""
+
+#: builtin/bisect--helper.c:233
+#, c-format
+msgid "couldn't open the file '%s'"
+msgstr "kunde inte öppna filen \"%s\""
+
+#: builtin/bisect--helper.c:259
+#, c-format
+msgid "Invalid command: you're currently in a %s/%s bisect"
+msgstr "Ogiltigt kommando: du utför just nu en \"bisect\" med %s/%s."
+
+#: builtin/bisect--helper.c:286
+#, c-format
+msgid ""
+"You need to give me at least one %s and %s revision.\n"
+"You can use \"git bisect %s\" and \"git bisect %s\" for that."
+msgstr ""
+"Du måste ange åtminstone en %s och en %s version.\n"
+"(Du kan använda \"git bisect %s\" och \"git bisect %s\" för detta.)"
+
+#: builtin/bisect--helper.c:290
+#, c-format
+msgid ""
+"You need to start by \"git bisect start\".\n"
+"You then need to give me at least one %s and %s revision.\n"
+"You can use \"git bisect %s\" and \"git bisect %s\" for that."
+msgstr ""
+"Du måste starta med \"git bisect start\".\n"
+"Du måste sedan ange åtminstone en %s och en %s version.\n"
+"(Du kan använda \"git bisect %s\" och \"git bisect %s\" för detta.)"
+
+#: builtin/bisect--helper.c:322
+#, c-format
+msgid "bisecting only with a %s commit"
+msgstr "utför bisect med endast en %s incheckning"
+
+#. TRANSLATORS: Make sure to include [Y] and [n] in your
+#. translation. The program will only accept English input
+#. at this point.
+#.
+#: builtin/bisect--helper.c:330
+msgid "Are you sure [Y/n]? "
+msgstr "Är du säker [Y=ja/N=nej]? "
+
+#: builtin/bisect--helper.c:377
+msgid "no terms defined"
+msgstr "inga termer angivna"
+
+#: builtin/bisect--helper.c:380
+#, c-format
+msgid ""
+"Your current terms are %s for the old state\n"
+"and %s for the new state.\n"
+msgstr ""
+"Aktuella termer är %s för det gamla tillståndet\n"
+"och %s för det nya tillståndet.\n"
+
+#: builtin/bisect--helper.c:390
+#, c-format
+msgid ""
+"invalid argument %s for 'git bisect terms'.\n"
+"Supported options are: --term-good|--term-old and --term-bad|--term-new."
+msgstr ""
+"ogiltigt argument %s för \"git bisect terms\".\n"
+"Flaggor som stöds är: --term-good|--term-old och --term-bad|--term-new."
+
+#: builtin/bisect--helper.c:476
+#, c-format
+msgid "unrecognized option: '%s'"
+msgstr "okänd flagga: %s"
+
+#: builtin/bisect--helper.c:480
+#, c-format
+msgid "'%s' does not appear to be a valid revision"
+msgstr "\"%s\" verkar inte vara en giltig revision"
+
+#: builtin/bisect--helper.c:512
+msgid "bad HEAD - I need a HEAD"
+msgstr "felaktigt HEAD - Jag behöver ett HEAD"
+
+#: builtin/bisect--helper.c:527
+#, c-format
+msgid "checking out '%s' failed. Try 'git bisect start <valid-branch>'."
+msgstr ""
+"misslyckades checka ut \"%s\". Försök \"git bisect reset <giltig_gren>\"."
+
+# cogito-relaterat
+#: builtin/bisect--helper.c:548
+msgid "won't bisect on cg-seek'ed tree"
+msgstr "kör inte \"bisect\" på träd där \"cg-seek\" använts"
+
+#: builtin/bisect--helper.c:551
+msgid "bad HEAD - strange symbolic ref"
+msgstr "felaktigt HEAD - konstig symbolisk referens"
+
+#: builtin/bisect--helper.c:575
+#, c-format
+msgid "invalid ref: '%s'"
+msgstr "ogiltig referens: \"%s\""
+
+#: builtin/bisect--helper.c:631
+msgid "perform 'git bisect next'"
+msgstr "utför 'git bisect next'"
+
+#: builtin/bisect--helper.c:633
+msgid "write the terms to .git/BISECT_TERMS"
+msgstr "skriv termerna i .git/BISECT_TERMS"
+
+#: builtin/bisect--helper.c:635
+msgid "cleanup the bisection state"
+msgstr "städar upp bisect-tillstånd"
+
+#: builtin/bisect--helper.c:637
+msgid "check for expected revs"
+msgstr "kontrollera för förväntade versioner"
+
+#: builtin/bisect--helper.c:639
+msgid "reset the bisection state"
+msgstr "återställ bisect-tillstånd"
+
+#: builtin/bisect--helper.c:641
+msgid "write out the bisection state in BISECT_LOG"
+msgstr "skriver bisect-tillståndet i BISECT_LOG"
+
+#: builtin/bisect--helper.c:643
+msgid "check and set terms in a bisection state"
+msgstr "visa och ange termer för bisect-tillstånd"
+
+#: builtin/bisect--helper.c:645
+msgid "check whether bad or good terms exist"
+msgstr "se efter om termer för rätt och fel finns"
+
+#: builtin/bisect--helper.c:647
+msgid "print out the bisect terms"
+msgstr "skriv ut termer för bisect"
+
+#: builtin/bisect--helper.c:649
+msgid "start the bisect session"
+msgstr "påbörja bisect-körningen"
+
+#: builtin/bisect--helper.c:651
+msgid "update BISECT_HEAD instead of checking out the current commit"
+msgstr "uppdatera BISECT_HEAD istället för att checka ut aktuell incheckning"
+
+#: builtin/bisect--helper.c:653
+msgid "no log for BISECT_WRITE"
+msgstr "ingen logg för BISECT_WRITE"
+
+#: builtin/bisect--helper.c:670
+msgid "--write-terms requires two arguments"
+msgstr "--write-terms kräver två argument"
+
+#: builtin/bisect--helper.c:674
+msgid "--bisect-clean-state requires no arguments"
+msgstr "--bisect-clean-state tar inga argument"
+
+#: builtin/bisect--helper.c:681
+msgid "--bisect-reset requires either no argument or a commit"
+msgstr "--bisect-reset kräver antingen inget argument eller en incheckning"
+
+#: builtin/bisect--helper.c:685
+msgid "--bisect-write requires either 4 or 5 arguments"
+msgstr "--bisect-write kräver antingen 4 eller 5 argument"
+
+#: builtin/bisect--helper.c:691
+msgid "--check-and-set-terms requires 3 arguments"
+msgstr "--check-and-set-terms kräver tre argument"
+
+#: builtin/bisect--helper.c:697
+msgid "--bisect-next-check requires 2 or 3 arguments"
+msgstr "--bisect-next-check kräver 2 eller 3 argument"
+
+#: builtin/bisect--helper.c:703
+msgid "--bisect-terms requires 0 or 1 argument"
+msgstr "--bisect-terms kräver noll eller ett argument"
+
+#: builtin/blame.c:31
+msgid "git blame [<options>] [<rev-opts>] [<rev>] [--] <file>"
+msgstr "git blame [<flaggor>] [<rev-flaggor>] [<rev>] [--] <fil>"
+
+#: builtin/blame.c:36
+msgid "<rev-opts> are documented in git-rev-list(1)"
+msgstr "<rev-flaggor> dokumenteras i git-rev-list(1)"
+
+#: builtin/blame.c:409
+#, c-format
+msgid "expecting a color: %s"
+msgstr "förväntade en färg: %s"
+
+#: builtin/blame.c:416
+msgid "must end with a color"
+msgstr "måste sluta med en färg"
+
+#: builtin/blame.c:729
+#, c-format
+msgid "invalid color '%s' in color.blame.repeatedLines"
+msgstr "felaktig färg \"%s\" i color.blame.repeatedLines"
+
+#: builtin/blame.c:747
+msgid "invalid value for blame.coloring"
+msgstr "ogiltigt värde för blame.coloring"
+
+#: builtin/blame.c:822
+#, c-format
+msgid "cannot find revision %s to ignore"
+msgstr "kan inte hitta revision %s att ignorera"
+
+#: builtin/blame.c:844
+msgid "Show blame entries as we find them, incrementally"
+msgstr "Visa klandringsposter när vi hittar dem, interaktivt"
+
+#: builtin/blame.c:845
+msgid "Show blank SHA-1 for boundary commits (Default: off)"
+msgstr "Visa blank SHA-1 för gränsincheckningar (Standard: av)"
+
+#: builtin/blame.c:846
+msgid "Do not treat root commits as boundaries (Default: off)"
+msgstr "Behandla inte rotincheckningar som gränser (Standard: av)"
+
+#: builtin/blame.c:847
+msgid "Show work cost statistics"
+msgstr "Visa statistik över arbetskostnad"
+
+#: builtin/blame.c:848
+msgid "Force progress reporting"
+msgstr "Tvinga förloppsrapportering"
+
+#: builtin/blame.c:849
+msgid "Show output score for blame entries"
+msgstr "Visa utdatapoäng för klandringsposter"
+
+#: builtin/blame.c:850
+msgid "Show original filename (Default: auto)"
+msgstr "Visa originalfilnamn (Standard: auto)"
+
+#: builtin/blame.c:851
+msgid "Show original linenumber (Default: off)"
+msgstr "Visa ursprungligt radnummer (Standard: av)"
+
+#: builtin/blame.c:852
+msgid "Show in a format designed for machine consumption"
+msgstr "Visa i ett format avsett för maskinkonsumtion"
+
+#: builtin/blame.c:853
+msgid "Show porcelain format with per-line commit information"
+msgstr "Visa porslinsformat med per-rad-incheckningsinformation"
+
+#: builtin/blame.c:854
+msgid "Use the same output mode as git-annotate (Default: off)"
+msgstr "Använd samma utdataläge som git-annotate (Standard: av)"
+
+#: builtin/blame.c:855
+msgid "Show raw timestamp (Default: off)"
+msgstr "Visa rå tidsstämpel (Standard: av)"
+
+#: builtin/blame.c:856
+msgid "Show long commit SHA1 (Default: off)"
+msgstr "Visa lång inchecknings-SHA1 (Standard: av)"
+
+#: builtin/blame.c:857
+msgid "Suppress author name and timestamp (Default: off)"
+msgstr "Undertryck författarnamn och tidsstämpel (Standard: av)"
+
+#: builtin/blame.c:858
+msgid "Show author email instead of name (Default: off)"
+msgstr "Visa författarens e-post istället för namn (Standard: av)"
+
+#: builtin/blame.c:859
+msgid "Ignore whitespace differences"
+msgstr "Ignorera ändringar i blanksteg"
+
+#: builtin/blame.c:860 builtin/log.c:1702
+msgid "rev"
+msgstr "rev"
+
+#: builtin/blame.c:860
+msgid "Ignore <rev> when blaming"
+msgstr "ignorera <rev> vid klandren"
+
+#: builtin/blame.c:861
+msgid "Ignore revisions from <file>"
+msgstr "ignorera revisioner från <fil>"
+
+#: builtin/blame.c:862
+msgid "color redundant metadata from previous line differently"
+msgstr "färglägg redundant metadata från tidigare rader annorlunda"
+
+#: builtin/blame.c:863
+msgid "color lines by age"
+msgstr "färglägg rader efter ålder"
+
+#: builtin/blame.c:864
+msgid "Spend extra cycles to find better match"
+msgstr "Slösa extra cykler med att hitta bättre träff"
+
+#: builtin/blame.c:865
+msgid "Use revisions from <file> instead of calling git-rev-list"
+msgstr "Använd revisioner från <fil> istället för att anropa git-rev-list"
+
+#: builtin/blame.c:866
+msgid "Use <file>'s contents as the final image"
+msgstr "Använd <fil>s innehåll som slutgiltig bild"
+
+#: builtin/blame.c:867 builtin/blame.c:868
+msgid "score"
+msgstr "poäng"
+
+#: builtin/blame.c:867
+msgid "Find line copies within and across files"
+msgstr "Hitta kopierade rader inuti och mellan filer"
+
+#: builtin/blame.c:868
+msgid "Find line movements within and across files"
+msgstr "Hitta flyttade rader inuti och mellan filer"
+
+#: builtin/blame.c:869
+msgid "n,m"
+msgstr "n,m"
+
+#: builtin/blame.c:869
+msgid "Process only line range n,m, counting from 1"
+msgstr "Behandla endast radintervallet n,m, med början på 1"
+
+#: builtin/blame.c:921
+msgid "--progress can't be used with --incremental or porcelain formats"
+msgstr "--progress kan inte användas med --incremental eller porslinsformat"
+
+#. TRANSLATORS: This string is used to tell us the
+#. maximum display width for a relative timestamp in
+#. "git blame" output.  For C locale, "4 years, 11
+#. months ago", which takes 22 places, is the longest
+#. among various forms of relative timestamps, but
+#. your language may need more or fewer display
+#. columns.
+#.
+#: builtin/blame.c:972
+msgid "4 years, 11 months ago"
+msgstr "4 år, 11 månader sedan"
+
+#: builtin/blame.c:1079
+#, c-format
+msgid "file %s has only %lu line"
+msgid_plural "file %s has only %lu lines"
+msgstr[0] "filen %s har bara %lu rad"
+msgstr[1] "filen %s har bara %lu rader"
+
+#: builtin/blame.c:1125
+msgid "Blaming lines"
+msgstr "Klandra rader"
+
+#: builtin/branch.c:29
+msgid "git branch [<options>] [-r | -a] [--merged | --no-merged]"
+msgstr "git branch [<flaggor>] [-r | -a] [--merged | --no-merged]"
+
+#: builtin/branch.c:30
+msgid "git branch [<options>] [-l] [-f] <branch-name> [<start-point>]"
+msgstr "git branch [<flaggor>] [-l] [-f] <grennamn> [<startpunkt>]"
+
+#: builtin/branch.c:31
+msgid "git branch [<options>] [-r] (-d | -D) <branch-name>..."
+msgstr "git branch [<flaggor>] [-r] (-d | -D) <grennamn>..."
+
+#: builtin/branch.c:32
+msgid "git branch [<options>] (-m | -M) [<old-branch>] <new-branch>"
+msgstr "git branch [<flaggor>] (-m | -M) [<gammal_gren>] <ny_gren>"
+
+#: builtin/branch.c:33
+msgid "git branch [<options>] (-c | -C) [<old-branch>] <new-branch>"
+msgstr "git branch [<flaggor>] (-c | -C) [<gammal_gren>] <ny_gren>"
+
+#: builtin/branch.c:34
+msgid "git branch [<options>] [-r | -a] [--points-at]"
+msgstr "git branch [<flaggor>] [-r | -a] [--points-at]"
+
+#: builtin/branch.c:35
+msgid "git branch [<options>] [-r | -a] [--format]"
+msgstr "git branch [<flaggor>] [-r | -a] [--format]"
+
+#: builtin/branch.c:154
+#, c-format
+msgid ""
+"deleting branch '%s' that has been merged to\n"
+"         '%s', but not yet merged to HEAD."
+msgstr ""
+"tar bort grenen \"%s\" som har slagits ihop med\n"
+"         \"%s\", men ännu inte slagits ihop med HEAD."
+
+#: builtin/branch.c:158
+#, c-format
+msgid ""
+"not deleting branch '%s' that is not yet merged to\n"
+"         '%s', even though it is merged to HEAD."
+msgstr ""
+"tar inte bort grenen \"%s\" som inte har slagits ihop med\n"
+"         \"%s\", trots att den har slagits ihop med HEAD."
+
+#: builtin/branch.c:172
+#, c-format
+msgid "Couldn't look up commit object for '%s'"
+msgstr "Kunde inte slå upp incheckningsobjekt för \"%s\""
+
+#: builtin/branch.c:176
+#, c-format
+msgid ""
+"The branch '%s' is not fully merged.\n"
+"If you are sure you want to delete it, run 'git branch -D %s'."
+msgstr ""
+"Grenen \"%s\" har inte slagits samman i sin helhet.\n"
+"Om du är säker på att du vill ta bort den, kör \"git branch -D %s\"."
+
+#: builtin/branch.c:189
+msgid "Update of config-file failed"
+msgstr "Misslyckades uppdatera konfigurationsfil"
+
+#: builtin/branch.c:220
+msgid "cannot use -a with -d"
+msgstr "kan inte ange -a med -d"
+
+#: builtin/branch.c:226
+msgid "Couldn't look up commit object for HEAD"
+msgstr "Kunde inte slå upp incheckningsobjekt för HEAD"
+
+#: builtin/branch.c:240
+#, c-format
+msgid "Cannot delete branch '%s' checked out at '%s'"
+msgstr "Kan inte ta bort grenen \"%s\" som är utcheckad på \"%s\""
+
+#: builtin/branch.c:255
+#, c-format
+msgid "remote-tracking branch '%s' not found."
+msgstr "fjärrspårande grenen \"%s\" hittades inte."
+
+#: builtin/branch.c:256
+#, c-format
+msgid "branch '%s' not found."
+msgstr "grenen \"%s\" hittades inte."
+
+#: builtin/branch.c:271
+#, c-format
+msgid "Error deleting remote-tracking branch '%s'"
+msgstr "Fel vid borttagning av fjärrspårande grenen \"%s\""
+
+#: builtin/branch.c:272
+#, c-format
+msgid "Error deleting branch '%s'"
+msgstr "Fel vid borttagning av grenen \"%s\""
+
+#: builtin/branch.c:279
+#, c-format
+msgid "Deleted remote-tracking branch %s (was %s).\n"
+msgstr "Tog bort fjärrspårande grenen %s (var %s).\n"
+
+#: builtin/branch.c:280
+#, c-format
+msgid "Deleted branch %s (was %s).\n"
+msgstr "Tog bort grenen %s (var %s).\n"
+
+#: builtin/branch.c:429 builtin/tag.c:61
+msgid "unable to parse format string"
+msgstr "kan inte tolka formatsträng"
+
+#: builtin/branch.c:460
+msgid "could not resolve HEAD"
+msgstr "kunde inte slå upp HEAD"
+
+#: builtin/branch.c:466
+#, c-format
+msgid "HEAD (%s) points outside of refs/heads/"
+msgstr "HEAD (%s) pekar utenför refs/heads/"
+
+#: builtin/branch.c:481
+#, c-format
+msgid "Branch %s is being rebased at %s"
+msgstr "Grenen %s ombaseras på %s"
+
+#: builtin/branch.c:485
+#, c-format
+msgid "Branch %s is being bisected at %s"
+msgstr "Grenen %s är i en \"bisect\" på %s"
+
+#: builtin/branch.c:502
+msgid "cannot copy the current branch while not on any."
+msgstr "kunde inte kopiera aktuell gren när du inte befinner dig på någon."
+
+#: builtin/branch.c:504
+msgid "cannot rename the current branch while not on any."
+msgstr ""
+"kunde inte byta namn på aktuell gren när du inte befinner dig på någon."
+
+#: builtin/branch.c:515
+#, c-format
+msgid "Invalid branch name: '%s'"
+msgstr "Felaktigt namn på gren: \"%s\""
+
+#: builtin/branch.c:542
+msgid "Branch rename failed"
+msgstr "Misslyckades byta namn på gren"
+
+#: builtin/branch.c:544
+msgid "Branch copy failed"
+msgstr "Misslyckades kopiera gren"
+
+#: builtin/branch.c:548
+#, c-format
+msgid "Created a copy of a misnamed branch '%s'"
+msgstr "Skapade kopia av felaktigt namngiven gren \"%s\""
+
+#: builtin/branch.c:551
+#, c-format
+msgid "Renamed a misnamed branch '%s' away"
+msgstr "Bytte bort namn på en felaktigt namngiven gren \"%s\""
+
+#: builtin/branch.c:557
+#, c-format
+msgid "Branch renamed to %s, but HEAD is not updated!"
+msgstr "Grenen namnbytt till %s, men HEAD har inte uppdaterats!"
+
+#: builtin/branch.c:566
+msgid "Branch is renamed, but update of config-file failed"
+msgstr "Grenen namnbytt, men misslyckades uppdatera konfigurationsfilen"
+
+#: builtin/branch.c:568
+msgid "Branch is copied, but update of config-file failed"
+msgstr "Grenen kopierades, men misslyckades uppdatera konfigurationsfilen"
+
+#: builtin/branch.c:584
+#, c-format
+msgid ""
+"Please edit the description for the branch\n"
+"  %s\n"
+"Lines starting with '%c' will be stripped.\n"
+msgstr ""
+"Redigera beskrivningen för grenen\n"
+"  %s\n"
+"Rader som inleds med \"%c\" ignoreras.\n"
+
+#: builtin/branch.c:618
+msgid "Generic options"
+msgstr "Allmänna flaggor"
+
+#: builtin/branch.c:620
+msgid "show hash and subject, give twice for upstream branch"
+msgstr "visa hash och ärenderad, ange två gånger för uppströmsgren"
+
+#: builtin/branch.c:621
+msgid "suppress informational messages"
+msgstr "undertryck informationsmeddelanden"
+
+#: builtin/branch.c:622
+msgid "set up tracking mode (see git-pull(1))"
+msgstr "ställ in spårningsläge (se git-pull(1))"
+
+#: builtin/branch.c:624
+msgid "do not use"
+msgstr "använd ej"
+
+#: builtin/branch.c:626 builtin/rebase.c:505
+msgid "upstream"
+msgstr "uppströms"
+
+#: builtin/branch.c:626
+msgid "change the upstream info"
+msgstr "ändra uppströmsinformationen"
+
+#: builtin/branch.c:627
+msgid "unset the upstream info"
+msgstr "ta bort uppströmsinformationen"
+
+#: builtin/branch.c:628
+msgid "use colored output"
+msgstr "använd färgad utdata"
+
+#: builtin/branch.c:629
+msgid "act on remote-tracking branches"
+msgstr "arbeta på fjärrspårande grenar"
+
+#: builtin/branch.c:631 builtin/branch.c:633
+msgid "print only branches that contain the commit"
+msgstr "visa endast grenar som innehåller incheckningen"
+
+#: builtin/branch.c:632 builtin/branch.c:634
+msgid "print only branches that don't contain the commit"
+msgstr "visa endast grenar som inte innehåller incheckningen"
+
+#: builtin/branch.c:637
+msgid "Specific git-branch actions:"
+msgstr "Specifika git-branch-åtgärder:"
+
+#: builtin/branch.c:638
+msgid "list both remote-tracking and local branches"
+msgstr "visa både fjärrspårande och lokala grenar"
+
+#: builtin/branch.c:640
+msgid "delete fully merged branch"
+msgstr "ta bort helt sammanslagen gren"
+
+#: builtin/branch.c:641
+msgid "delete branch (even if not merged)"
+msgstr "ta bort gren (även om inte helt sammanslagen)"
+
+#: builtin/branch.c:642
+msgid "move/rename a branch and its reflog"
+msgstr "flytta/ta bort en gren och dess reflogg"
+
+#: builtin/branch.c:643
+msgid "move/rename a branch, even if target exists"
+msgstr "flytta/ta bort en gren, även om målet finns"
+
+#: builtin/branch.c:644
+msgid "copy a branch and its reflog"
+msgstr "kopiera en gren och dess reflogg"
+
+#: builtin/branch.c:645
+msgid "copy a branch, even if target exists"
+msgstr "kopiera en gren, även om målet finns"
+
+#: builtin/branch.c:646
+msgid "list branch names"
+msgstr "lista namn på grenar"
+
+#: builtin/branch.c:647
+msgid "show current branch name"
+msgstr "visa namn på aktuell gren"
+
+#: builtin/branch.c:648
+msgid "create the branch's reflog"
+msgstr "skapa grenens reflogg"
+
+#: builtin/branch.c:650
+msgid "edit the description for the branch"
+msgstr "redigera beskrivning för grenen"
+
+#: builtin/branch.c:651
+msgid "force creation, move/rename, deletion"
+msgstr "tvinga skapande, flytt/namnändring, borttagande"
+
+#: builtin/branch.c:652
+msgid "print only branches that are merged"
+msgstr "visa endast sammanslagna grenar"
+
+#: builtin/branch.c:653
+msgid "print only branches that are not merged"
+msgstr "visa endast ej sammanslagna grenar"
+
+#: builtin/branch.c:654
+msgid "list branches in columns"
+msgstr "visa grenar i spalter"
+
+#: builtin/branch.c:657 builtin/for-each-ref.c:42 builtin/notes.c:415
+#: builtin/notes.c:418 builtin/notes.c:581 builtin/notes.c:584
+#: builtin/tag.c:433
+msgid "object"
+msgstr "objekt"
+
+#: builtin/branch.c:658
+msgid "print only branches of the object"
+msgstr "visa endast grenar för objektet"
+
+#: builtin/branch.c:660 builtin/for-each-ref.c:48 builtin/tag.c:440
+msgid "sorting and filtering are case insensitive"
+msgstr "sortering och filtrering skiljer gemener och VERSALER"
+
+#: builtin/branch.c:661 builtin/for-each-ref.c:38 builtin/tag.c:438
+#: builtin/verify-tag.c:38
+msgid "format to use for the output"
+msgstr "format att använda för utdata"
+
+#: builtin/branch.c:684 builtin/clone.c:784
+msgid "HEAD not found below refs/heads!"
+msgstr "HEAD hittades inte under refs/heads!"
+
+#: builtin/branch.c:708
+msgid "--column and --verbose are incompatible"
+msgstr "--column och --verbose är inkompatibla"
+
+#: builtin/branch.c:723 builtin/branch.c:777 builtin/branch.c:786
+msgid "branch name required"
+msgstr "grennamn krävs"
+
+#: builtin/branch.c:753
+msgid "Cannot give description to detached HEAD"
+msgstr "Kan inte beskriva frånkopplad HEAD"
+
+#: builtin/branch.c:758
+msgid "cannot edit description of more than one branch"
+msgstr "kan inte redigera beskrivning för mer än en gren"
+
+#: builtin/branch.c:765
+#, c-format
+msgid "No commit on branch '%s' yet."
+msgstr "Inga incheckningar på grenen \"%s\" ännu."
+
+#: builtin/branch.c:768
+#, c-format
+msgid "No branch named '%s'."
+msgstr "Ingen gren vid namnet \"%s\"."
+
+#: builtin/branch.c:783
+msgid "too many branches for a copy operation"
+msgstr "för många grenar för kopiering"
+
+#: builtin/branch.c:792
+msgid "too many arguments for a rename operation"
+msgstr "för många flaggor för namnbyte"
+
+#: builtin/branch.c:797
+msgid "too many arguments to set new upstream"
+msgstr "för många flaggor för att byta uppström"
+
+#: builtin/branch.c:801
+#, c-format
+msgid ""
+"could not set upstream of HEAD to %s when it does not point to any branch."
+msgstr ""
+"kunde inte sätta uppström för HEAD till %s när det inte pekar mot någon gren."
+
+#: builtin/branch.c:804 builtin/branch.c:827
+#, c-format
+msgid "no such branch '%s'"
+msgstr "okänd gren \"%s\""
+
+#: builtin/branch.c:808
+#, c-format
+msgid "branch '%s' does not exist"
+msgstr "grenen \"%s\" finns inte"
+
+#: builtin/branch.c:821
+msgid "too many arguments to unset upstream"
+msgstr "för många flaggor för att ta bort uppström"
+
+#: builtin/branch.c:825
+msgid "could not unset upstream of HEAD when it does not point to any branch."
+msgstr ""
+"kunde inte ta bort uppström för HEAD när det inte pekar mot någon gren."
+
+#: builtin/branch.c:831
+#, c-format
+msgid "Branch '%s' has no upstream information"
+msgstr "Grenen \"%s\" har ingen uppströmsinformation"
+
+#: builtin/branch.c:841
+msgid ""
+"The -a, and -r, options to 'git branch' do not take a branch name.\n"
+"Did you mean to use: -a|-r --list <pattern>?"
+msgstr ""
+"Flaggorna -a och -r på \"git branch\" tar inte ett namn på gren.\n"
+"Menade du att använda: -a|-r --list <mönster>?"
+
+#: builtin/branch.c:845
+msgid ""
+"the '--set-upstream' option is no longer supported. Please use '--track' or "
+"'--set-upstream-to' instead."
+msgstr ""
+"Flaggan --set-upstream rekommenderas ej och kommer tas bort. Använd --track "
+"eller --set-upstream-to istället."
+
+#: builtin/bundle.c:15 builtin/bundle.c:23
+msgid "git bundle create [<options>] <file> <git-rev-list args>"
+msgstr "git bundle create [<flaggor>] <fil> <git-rev-list-flaggor>"
+
+#: builtin/bundle.c:16 builtin/bundle.c:28
+msgid "git bundle verify [<options>] <file>"
+msgstr "git bundle verify [<flaggor>] <fil>"
+
+#: builtin/bundle.c:17 builtin/bundle.c:33
+msgid "git bundle list-heads <file> [<refname>...]"
+msgstr "git bundle list-heads <fil> [<refnamn>...]"
+
+#: builtin/bundle.c:18 builtin/bundle.c:38
+msgid "git bundle unbundle <file> [<refname>...]"
+msgstr "git bundle unbundle <fil> [<refnamn>...]"
+
+#: builtin/bundle.c:66 builtin/pack-objects.c:3228
+msgid "do not show progress meter"
+msgstr "visa inte förloppsindikator"
+
+#: builtin/bundle.c:68 builtin/pack-objects.c:3230
+msgid "show progress meter"
+msgstr "visa förloppsindikator"
+
+#: builtin/bundle.c:70 builtin/pack-objects.c:3232
+msgid "show progress meter during object writing phase"
+msgstr "visa förloppsindikator under objektskrivningsfasen"
+
+#: builtin/bundle.c:73 builtin/pack-objects.c:3235
+msgid "similar to --all-progress when progress meter is shown"
+msgstr "som --all-progress när förloppsindikatorn visas"
+
+#: builtin/bundle.c:93
+msgid "Need a repository to create a bundle."
+msgstr "Behöver ett arkiv för att skapa ett paket (bundle)."
+
+#: builtin/bundle.c:104
+msgid "do not show bundle details"
+msgstr "visa inte paketdetaljer"
+
+#: builtin/bundle.c:119
+#, c-format
+msgid "%s is okay\n"
+msgstr "%s är okej\n"
+
+#: builtin/bundle.c:160
+msgid "Need a repository to unbundle."
+msgstr "Behöver ett arkiv för att packa upp ett paket (bundle)."
+
+#: builtin/bundle.c:168 builtin/remote.c:1609
+msgid "be verbose; must be placed before a subcommand"
+msgstr "var pratsam; måste skrivas före ett underkommando"
+
+#: builtin/bundle.c:190 builtin/remote.c:1640
+#, c-format
+msgid "Unknown subcommand: %s"
+msgstr "Okänt underkommando: %s"
+
+#: builtin/cat-file.c:595
+msgid ""
+"git cat-file (-t [--allow-unknown-type] | -s [--allow-unknown-type] | -e | -"
+"p | <type> | --textconv | --filters) [--path=<path>] <object>"
+msgstr ""
+"git cat-file (-t [--allow-unknown-type] | -s [--allow-unknown-type] | -e | -"
+"p | <typ> | --textconv | --filters) [--path=<sökväg>] <objekt>"
+
+#: builtin/cat-file.c:596
+msgid ""
+"git cat-file (--batch | --batch-check) [--follow-symlinks] [--textconv | --"
+"filters]"
+msgstr ""
+"git cat-file (--batch | --batch-check) [--follow-symlinks] [--textconv | --"
+"filters]"
+
+#: builtin/cat-file.c:617
+msgid "only one batch option may be specified"
+msgstr "endast en buntflagga kan anges"
+
+#: builtin/cat-file.c:635
 msgid "<type> can be one of: blob, tree, commit, tag"
 msgstr "<typ> kan vara en av: blob, tree, commit, tag"
 
-#: builtin/cat-file.c:564
-msgid "show object type"
-msgstr "visa objekttyp"
+#: builtin/cat-file.c:636
+msgid "show object type"
+msgstr "visa objekttyp"
+
+#: builtin/cat-file.c:637
+msgid "show object size"
+msgstr "visa objektstorlek"
+
+#: builtin/cat-file.c:639
+msgid "exit with zero when there's no error"
+msgstr "avsluta med noll när det inte uppstått något fel"
+
+#: builtin/cat-file.c:640
+msgid "pretty-print object's content"
+msgstr "visa objektets innehåll snyggt"
+
+#: builtin/cat-file.c:642
+msgid "for blob objects, run textconv on object's content"
+msgstr "för blob-objekt, kör filter på objektets innehåll"
+
+#: builtin/cat-file.c:644
+msgid "for blob objects, run filters on object's content"
+msgstr "för blob-objekt, kör filger på objektets innehåll"
+
+#: builtin/cat-file.c:645 git-submodule.sh:992
+msgid "blob"
+msgstr "blob"
+
+#: builtin/cat-file.c:646
+msgid "use a specific path for --textconv/--filters"
+msgstr "använd specifik sökväg för --textconv/--filters"
+
+#: builtin/cat-file.c:648
+msgid "allow -s and -t to work with broken/corrupt objects"
+msgstr "låter -s och -t att fungera med trasiga/sönderskrivna objekt"
+
+#: builtin/cat-file.c:649
+msgid "buffer --batch output"
+msgstr "buffra utdata från --batch"
+
+#: builtin/cat-file.c:651
+msgid "show info and content of objects fed from the standard input"
+msgstr "visa information och innehåll för objekt som listas på standard in"
+
+#: builtin/cat-file.c:655
+msgid "show info about objects fed from the standard input"
+msgstr "visa information för objekt som listas på standard in"
+
+#: builtin/cat-file.c:659
+msgid "follow in-tree symlinks (used with --batch or --batch-check)"
+msgstr ""
+"följ symboliska länkar i trädet (använd med --batch eller --batch-check)"
+
+#: builtin/cat-file.c:661
+msgid "show all objects with --batch or --batch-check"
+msgstr "visa alla objekt med --batch eller --batch-check"
+
+#: builtin/cat-file.c:663
+msgid "do not order --batch-all-objects output"
+msgstr "ordna inte --batch-all-objects output"
+
+#: builtin/check-attr.c:13
+msgid "git check-attr [-a | --all | <attr>...] [--] <pathname>..."
+msgstr "git check-attr [-a | --all | <attr>...] [--] <sökväg>..."
+
+#: builtin/check-attr.c:14
+msgid "git check-attr --stdin [-z] [-a | --all | <attr>...]"
+msgstr "git check-attr --stdin [-z] [-a | --all | <attr>...]"
+
+#: builtin/check-attr.c:21
+msgid "report all attributes set on file"
+msgstr "visa alla attribut som satts på filen"
+
+#: builtin/check-attr.c:22
+msgid "use .gitattributes only from the index"
+msgstr "använd .gitattributes endast från indexet"
+
+#: builtin/check-attr.c:23 builtin/check-ignore.c:25 builtin/hash-object.c:102
+msgid "read file names from stdin"
+msgstr "läs filnamn från standard in"
+
+#: builtin/check-attr.c:25 builtin/check-ignore.c:27
+msgid "terminate input and output records by a NUL character"
+msgstr "avsluta in- och utdataposter med NUL-tecken"
+
+#: builtin/check-ignore.c:21 builtin/checkout.c:1435 builtin/gc.c:537
+#: builtin/worktree.c:506
+msgid "suppress progress reporting"
+msgstr "undertryck förloppsrapportering"
+
+#: builtin/check-ignore.c:29
+msgid "show non-matching input paths"
+msgstr "visa indatasökvägar som inte träffas"
+
+#: builtin/check-ignore.c:31
+msgid "ignore index when checking"
+msgstr "ignorera index vid kontroll"
+
+#: builtin/check-ignore.c:160
+msgid "cannot specify pathnames with --stdin"
+msgstr "kan inte ange sökvägsnamn med --stdin"
+
+#: builtin/check-ignore.c:163
+msgid "-z only makes sense with --stdin"
+msgstr "-z kan endast användas tillsammans med --stdin"
+
+#: builtin/check-ignore.c:165
+msgid "no path specified"
+msgstr "ingen sökväg angavs"
+
+#: builtin/check-ignore.c:169
+msgid "--quiet is only valid with a single pathname"
+msgstr "--quiet kan endast användas med ett enkelt sökvägsnamn"
+
+#: builtin/check-ignore.c:171
+msgid "cannot have both --quiet and --verbose"
+msgstr "kan inte använda både --quiet och --verbose"
+
+#: builtin/check-ignore.c:174
+msgid "--non-matching is only valid with --verbose"
+msgstr "--non-matching är endast giltig med --verbose"
+
+#: builtin/check-mailmap.c:9
+msgid "git check-mailmap [<options>] <contact>..."
+msgstr "git check-mailmap [<flaggor>] <kontakt>..."
+
+#: builtin/check-mailmap.c:14
+msgid "also read contacts from stdin"
+msgstr "läs även kontakter från standard in"
+
+#: builtin/check-mailmap.c:25
+#, c-format
+msgid "unable to parse contact: %s"
+msgstr "kunde inte tolka kontakt: %s"
+
+#: builtin/check-mailmap.c:48
+msgid "no contacts specified"
+msgstr "inga kontakter angavs"
+
+#: builtin/checkout-index.c:131
+msgid "git checkout-index [<options>] [--] [<file>...]"
+msgstr "git checkout-index [<flaggor>] [--] [<fil>...]"
+
+#: builtin/checkout-index.c:148
+msgid "stage should be between 1 and 3 or all"
+msgstr "etapp måste vara mellan 1 och 3 eller \"all\""
+
+#: builtin/checkout-index.c:164
+msgid "check out all files in the index"
+msgstr "checka ut alla filer i indexet"
+
+#: builtin/checkout-index.c:165
+msgid "force overwrite of existing files"
+msgstr "tvinga överskrivning av befintliga filer"
+
+#: builtin/checkout-index.c:167
+msgid "no warning for existing files and files not in index"
+msgstr "ingen varning för existerande filer och filer ej i indexet"
+
+#: builtin/checkout-index.c:169
+msgid "don't checkout new files"
+msgstr "checka inte ut nya filer"
+
+#: builtin/checkout-index.c:171
+msgid "update stat information in the index file"
+msgstr "uppdatera stat-information i indexfilen"
+
+#: builtin/checkout-index.c:175
+msgid "read list of paths from the standard input"
+msgstr "läs listan över sökvägar från standard in"
+
+#: builtin/checkout-index.c:177
+msgid "write the content to temporary files"
+msgstr "skriv innehåll till temporära filer"
+
+#: builtin/checkout-index.c:178 builtin/column.c:31
+#: builtin/submodule--helper.c:1385 builtin/submodule--helper.c:1388
+#: builtin/submodule--helper.c:1396 builtin/submodule--helper.c:1882
+#: builtin/worktree.c:679
+msgid "string"
+msgstr "sträng"
+
+#: builtin/checkout-index.c:179
+msgid "when creating files, prepend <string>"
+msgstr "när filer skapas, lägg till <sträng> först"
+
+#: builtin/checkout-index.c:181
+msgid "copy out the files from named stage"
+msgstr "kopiera ut filer från namngiven etapp"
+
+#: builtin/checkout.c:31
+msgid "git checkout [<options>] <branch>"
+msgstr "git checkout [<flaggor>] <gren>"
+
+#: builtin/checkout.c:32
+msgid "git checkout [<options>] [<branch>] -- <file>..."
+msgstr "git checkout [<flaggor>] [<gren>] -- <fil>..."
+
+#: builtin/checkout.c:37
+msgid "git switch [<options>] [<branch>]"
+msgstr "git switch [<flaggor>] [<gren>]"
+
+#: builtin/checkout.c:42
+msgid "git restore [<options>] [--source=<branch>] <file>..."
+msgstr "git restore [<flaggor>] [--source=<gren>] <fil>..."
+
+#: builtin/checkout.c:175 builtin/checkout.c:214
+#, c-format
+msgid "path '%s' does not have our version"
+msgstr "sökvägen \"%s\" har inte vår version"
+
+#: builtin/checkout.c:177 builtin/checkout.c:216
+#, c-format
+msgid "path '%s' does not have their version"
+msgstr "sökvägen \"%s\" har inte deras version"
+
+#: builtin/checkout.c:193
+#, c-format
+msgid "path '%s' does not have all necessary versions"
+msgstr "sökvägen \"%s\" innehåller inte alla nödvändiga versioner"
+
+#: builtin/checkout.c:243
+#, c-format
+msgid "path '%s' does not have necessary versions"
+msgstr "sökvägen \"%s\" innehåller inte nödvändiga versioner"
+
+#: builtin/checkout.c:261
+#, c-format
+msgid "path '%s': cannot merge"
+msgstr "sökväg \"%s\": kan inte slå ihop"
+
+#: builtin/checkout.c:277
+#, c-format
+msgid "Unable to add merge result for '%s'"
+msgstr "Kunde inte lägga till sammanslagningsresultat för \"%s\""
+
+#: builtin/checkout.c:377
+#, c-format
+msgid "Recreated %d merge conflict"
+msgid_plural "Recreated %d merge conflicts"
+msgstr[0] "Återskapade %d sammanslagningskonflikt"
+msgstr[1] "Återskapade %d sammanslagningskonflikter"
+
+#: builtin/checkout.c:382
+#, c-format
+msgid "Updated %d path from %s"
+msgid_plural "Updated %d paths from %s"
+msgstr[0] "Uppdaterade %d sökväg från %s"
+msgstr[1] "Uppdaterade %d sökvägar från %s"
+
+#: builtin/checkout.c:389
+#, c-format
+msgid "Updated %d path from the index"
+msgid_plural "Updated %d paths from the index"
+msgstr[0] "Uppdaterade %d sökväg från indexet"
+msgstr[1] "Uppdaterade %d sökvägar från indexet"
+
+#: builtin/checkout.c:412 builtin/checkout.c:415 builtin/checkout.c:418
+#: builtin/checkout.c:422
+#, c-format
+msgid "'%s' cannot be used with updating paths"
+msgstr "\"%s\" kan inte användas vid uppdatering av sökvägar"
+
+#: builtin/checkout.c:425 builtin/checkout.c:428
+#, c-format
+msgid "'%s' cannot be used with %s"
+msgstr "\"%s\" kan inte användas med %s"
+
+#: builtin/checkout.c:432
+#, c-format
+msgid "Cannot update paths and switch to branch '%s' at the same time."
+msgstr "Kan inte uppdatera sökvägar och växla till grenen \"%s\" samtidigt."
+
+#: builtin/checkout.c:436
+#, c-format
+msgid "neither '%s' or '%s' is specified"
+msgstr "varken \"%s\" eller \"%s\" har angivits"
+
+#: builtin/checkout.c:440
+#, c-format
+msgid "'%s' must be used when '%s' is not specified"
+msgstr "\"%s\" måste användas när \"%s\" inte anges"
+
+#: builtin/checkout.c:445 builtin/checkout.c:450
+#, c-format
+msgid "'%s' or '%s' cannot be used with %s"
+msgstr "\"%s\" eller \"%s\" kan inte användas med %s"
+
+#: builtin/checkout.c:509 builtin/checkout.c:516
+#, c-format
+msgid "path '%s' is unmerged"
+msgstr "sökvägen \"%s\" har inte slagits ihop"
+
+#: builtin/checkout.c:682 builtin/sparse-checkout.c:82
+msgid "you need to resolve your current index first"
+msgstr "du måste lösa ditt befintliga index först"
+
+#: builtin/checkout.c:732
+#, c-format
+msgid ""
+"cannot continue with staged changes in the following files:\n"
+"%s"
+msgstr ""
+"kan inte fortsätta med köade ändringar i följande filer:\n"
+"%s"
+
+#: builtin/checkout.c:835
+#, c-format
+msgid "Can not do reflog for '%s': %s\n"
+msgstr "Kan inte skapa referenslogg för \"%s\": %s\n"
+
+#: builtin/checkout.c:877
+msgid "HEAD is now at"
+msgstr "HEAD är nu på"
+
+#: builtin/checkout.c:881 builtin/clone.c:716
+msgid "unable to update HEAD"
+msgstr "kan inte uppdatera HEAD"
+
+#: builtin/checkout.c:885
+#, c-format
+msgid "Reset branch '%s'\n"
+msgstr "Återställ gren \"%s\"\n"
+
+#: builtin/checkout.c:888
+#, c-format
+msgid "Already on '%s'\n"
+msgstr "Redan på \"%s\"\n"
+
+#: builtin/checkout.c:892
+#, c-format
+msgid "Switched to and reset branch '%s'\n"
+msgstr "Växlade till och nollställde grenen \"%s\"\n"
+
+#: builtin/checkout.c:894 builtin/checkout.c:1291
+#, c-format
+msgid "Switched to a new branch '%s'\n"
+msgstr "Växlade till en ny gren \"%s\"\n"
+
+#: builtin/checkout.c:896
+#, c-format
+msgid "Switched to branch '%s'\n"
+msgstr "Växlade till grenen \"%s\"\n"
+
+#: builtin/checkout.c:947
+#, c-format
+msgid " ... and %d more.\n"
+msgstr " ... och %d till.\n"
+
+#: builtin/checkout.c:953
+#, c-format
+msgid ""
+"Warning: you are leaving %d commit behind, not connected to\n"
+"any of your branches:\n"
+"\n"
+"%s\n"
+msgid_plural ""
+"Warning: you are leaving %d commits behind, not connected to\n"
+"any of your branches:\n"
+"\n"
+"%s\n"
+msgstr[0] ""
+"Varning: du lämnar %d incheckning bakom dig som inte är ansluten till\n"
+"någon av dina grenar:\n"
+"\n"
+"%s\n"
+msgstr[1] ""
+"Varning: du lämnar %d incheckningar bakom dig som inte är ansluta till\n"
+"någon av dina grenar:\n"
+"\n"
+"%s\n"
+
+#: builtin/checkout.c:972
+#, c-format
+msgid ""
+"If you want to keep it by creating a new branch, this may be a good time\n"
+"to do so with:\n"
+"\n"
+" git branch <new-branch-name> %s\n"
+"\n"
+msgid_plural ""
+"If you want to keep them by creating a new branch, this may be a good time\n"
+"to do so with:\n"
+"\n"
+" git branch <new-branch-name> %s\n"
+"\n"
+msgstr[0] ""
+"Om du vill behålla den genom att skapa en ny gren är nu en bra tidpunkt\n"
+"att göra så, med:\n"
+"\n"
+" git branch <nytt_grennamn> %s\n"
+"\n"
+msgstr[1] ""
+"Om du vill behålla dem genom att skapa en ny gren är nu en bra tidpunkt\n"
+"att göra så, med:\n"
+"\n"
+" git branch <nytt_grennamn> %s\n"
+"\n"
+
+#: builtin/checkout.c:1007
+msgid "internal error in revision walk"
+msgstr "internt fel vid genomgång av revisioner (revision walk)"
+
+#: builtin/checkout.c:1011
+msgid "Previous HEAD position was"
+msgstr "Tidigare position för HEAD var"
+
+#: builtin/checkout.c:1051 builtin/checkout.c:1286
+msgid "You are on a branch yet to be born"
+msgstr "Du är på en gren som ännu inte är född"
+
+#: builtin/checkout.c:1178
+msgid "only one reference expected"
+msgstr "endast en referens förväntades"
+
+#: builtin/checkout.c:1195
+#, c-format
+msgid "only one reference expected, %d given."
+msgstr "endast en referens förväntades, %d gavs."
+
+#: builtin/checkout.c:1232
+#, c-format
+msgid ""
+"'%s' could be both a local file and a tracking branch.\n"
+"Please use -- (and optionally --no-guess) to disambiguate"
+msgstr ""
+"\"%s\" kan vara både en lokal fil och en spårande gren.\n"
+"Använd -- (och möjligen --no-guess) för att göra otvetydig"
+
+#: builtin/checkout.c:1245 builtin/worktree.c:290 builtin/worktree.c:455
+#, c-format
+msgid "invalid reference: %s"
+msgstr "felaktig referens: %s"
+
+#: builtin/checkout.c:1258 builtin/checkout.c:1622
+#, c-format
+msgid "reference is not a tree: %s"
+msgstr "referensen är inte ett träd: %s"
+
+#: builtin/checkout.c:1305
+#, c-format
+msgid "a branch is expected, got tag '%s'"
+msgstr "förväntade gren, fick taggen \"%s\""
+
+#: builtin/checkout.c:1307
+#, c-format
+msgid "a branch is expected, got remote branch '%s'"
+msgstr "förväntade gren, fick fjärrgrenen \"%s\""
+
+#: builtin/checkout.c:1308 builtin/checkout.c:1316
+#, c-format
+msgid "a branch is expected, got '%s'"
+msgstr "förväntade gren, fick \"%s\""
+
+#: builtin/checkout.c:1311
+#, c-format
+msgid "a branch is expected, got commit '%s'"
+msgstr "förväntade gren, fick incheckningen \"%s\""
+
+#: builtin/checkout.c:1327
+msgid ""
+"cannot switch branch while merging\n"
+"Consider \"git merge --quit\" or \"git worktree add\"."
+msgstr ""
+"kan inte växla gren vid sammanslagning\n"
+"Överväg \"git merge --quit\" eller \"git worktree add\"."
+
+#: builtin/checkout.c:1331
+msgid ""
+"cannot switch branch in the middle of an am session\n"
+"Consider \"git am --quit\" or \"git worktree add\"."
+msgstr ""
+"kan inte växla gren mitt i en \"am\"-körning\n"
+"Överväg \"git am --quit\" eller \"git worktree add\"."
+
+#: builtin/checkout.c:1335
+msgid ""
+"cannot switch branch while rebasing\n"
+"Consider \"git rebase --quit\" or \"git worktree add\"."
+msgstr ""
+"kan inte växla gren vid ombasering\n"
+"Överväg \"git rebase --quit\" eller \"git worktree add\"."
+
+#: builtin/checkout.c:1339
+msgid ""
+"cannot switch branch while cherry-picking\n"
+"Consider \"git cherry-pick --quit\" or \"git worktree add\"."
+msgstr ""
+"kan inte växla gren i en \"cherry-pick\"\n"
+"Överväg \"git cherry-pick --quit\" eller \"git worktree add\"."
+
+#: builtin/checkout.c:1343
+msgid ""
+"cannot switch branch while reverting\n"
+"Consider \"git revert --quit\" or \"git worktree add\"."
+msgstr ""
+"kan inte växla gren i en \"revert\"\n"
+"Överväg \"git revert --quit\" eller \"git worktree add\"."
+
+#: builtin/checkout.c:1347
+msgid "you are switching branch while bisecting"
+msgstr "då växlar grenar medan du gör en \"bisect\""
+
+#: builtin/checkout.c:1354
+msgid "paths cannot be used with switching branches"
+msgstr "sökvägar kan inte användas vid byte av gren"
+
+#: builtin/checkout.c:1357 builtin/checkout.c:1361 builtin/checkout.c:1365
+#, c-format
+msgid "'%s' cannot be used with switching branches"
+msgstr "\"%s\" kan inte användas vid byte av gren"
+
+#: builtin/checkout.c:1369 builtin/checkout.c:1372 builtin/checkout.c:1375
+#: builtin/checkout.c:1380 builtin/checkout.c:1385
+#, c-format
+msgid "'%s' cannot be used with '%s'"
+msgstr "\"%s\" kan inte användas med \"%s\""
+
+#: builtin/checkout.c:1382
+#, c-format
+msgid "'%s' cannot take <start-point>"
+msgstr "\"%s\" kan inte ta <startpunkt>"
+
+#: builtin/checkout.c:1390
+#, c-format
+msgid "Cannot switch branch to a non-commit '%s'"
+msgstr "Kan inte växla gren till icke-incheckningen \"%s\""
+
+#: builtin/checkout.c:1397
+msgid "missing branch or commit argument"
+msgstr "saknar gren- eller incheckingsargument"
+
+#: builtin/checkout.c:1439 builtin/clone.c:91 builtin/commit-graph.c:52
+#: builtin/commit-graph.c:113 builtin/fetch.c:167 builtin/merge.c:285
+#: builtin/multi-pack-index.c:27 builtin/pull.c:138 builtin/push.c:563
+#: builtin/send-pack.c:174
+msgid "force progress reporting"
+msgstr "tvinga förloppsrapportering"
+
+#: builtin/checkout.c:1440
+msgid "perform a 3-way merge with the new branch"
+msgstr "utför en 3-vägssammanslagning för den nya grenen"
+
+#: builtin/checkout.c:1441 builtin/log.c:1690 parse-options.h:322
+msgid "style"
+msgstr "stil"
+
+#: builtin/checkout.c:1442
+msgid "conflict style (merge or diff3)"
+msgstr "konfliktstil (merge eller diff3)"
+
+#: builtin/checkout.c:1454 builtin/worktree.c:503
+msgid "detach HEAD at named commit"
+msgstr "koppla från HEAD vid namngiven incheckning"
+
+#: builtin/checkout.c:1455
+msgid "set upstream info for new branch"
+msgstr "sätt uppströmsinformation för ny gren"
+
+#: builtin/checkout.c:1457
+msgid "force checkout (throw away local modifications)"
+msgstr "tvinga utcheckning (kasta bort lokala ändringar)"
+
+#: builtin/checkout.c:1459
+msgid "new-branch"
+msgstr "ny-gren"
+
+#: builtin/checkout.c:1459
+msgid "new unparented branch"
+msgstr "ny gren utan förälder"
+
+#: builtin/checkout.c:1461 builtin/merge.c:288
+msgid "update ignored files (default)"
+msgstr "uppdatera ignorerade filer (standard)"
+
+#: builtin/checkout.c:1464
+msgid "do not check if another worktree is holding the given ref"
+msgstr ""
+"kontrollera inte om en annan arbetskatalog håller den angivna referensen"
+
+#: builtin/checkout.c:1477
+msgid "checkout our version for unmerged files"
+msgstr "checka ut vår version för ej sammanslagna filer"
+
+#: builtin/checkout.c:1480
+msgid "checkout their version for unmerged files"
+msgstr "checka ut deras version för ej sammanslagna filer"
+
+#: builtin/checkout.c:1484
+msgid "do not limit pathspecs to sparse entries only"
+msgstr "begränsa inte sökvägar till endast glesa poster"
+
+#: builtin/checkout.c:1537
+msgid "-b, -B and --orphan are mutually exclusive"
+msgstr "-b, -B och --orphan är ömsesidigt uteslutande"
+
+#: builtin/checkout.c:1540
+msgid "-p and --overlay are mutually exclusive"
+msgstr "-p och --overlay är ömsesidigt uteslutande"
+
+#: builtin/checkout.c:1577
+msgid "--track needs a branch name"
+msgstr "--track behöver ett namn på en gren"
+
+#: builtin/checkout.c:1582
+msgid "missing branch name; try -b"
+msgstr "grennamn saknas; försök med -b"
+
+#: builtin/checkout.c:1615
+#, c-format
+msgid "could not resolve %s"
+msgstr "kunde inte upplösa %s"
+
+#: builtin/checkout.c:1631
+msgid "invalid path specification"
+msgstr "felaktig sökvägsangivelse"
+
+#: builtin/checkout.c:1638
+#, c-format
+msgid "'%s' is not a commit and a branch '%s' cannot be created from it"
+msgstr ""
+"\"%s\" är inte en incheckning och grenen \"%s\" kan inte skapas från den"
+
+#: builtin/checkout.c:1642
+#, c-format
+msgid "git checkout: --detach does not take a path argument '%s'"
+msgstr "git checkout: --detach tar inte en sökväg som argument \"%s\""
+
+#: builtin/checkout.c:1651
+msgid "--pathspec-from-file is incompatible with --detach"
+msgstr "--pathspec-from-file är inkompatibelt med --detach"
+
+#: builtin/checkout.c:1654 builtin/reset.c:324
+msgid "--pathspec-from-file is incompatible with --patch"
+msgstr "--pathspec-from-file är inkompatibelt med --patch"
+
+#: builtin/checkout.c:1665
+msgid ""
+"git checkout: --ours/--theirs, --force and --merge are incompatible when\n"
+"checking out of the index."
+msgstr ""
+"git checkout: --ours/--theirs, --force och --merge är inkompatibla när\n"
+"du checkar ut från indexet."
+
+#: builtin/checkout.c:1670
+msgid "you must specify path(s) to restore"
+msgstr "du måste ange katalog(er) att återställa"
+
+#: builtin/checkout.c:1689
+#, c-format
+msgid ""
+"'%s' matched more than one remote tracking branch.\n"
+"We found %d remotes with a reference that matched. So we fell back\n"
+"on trying to resolve the argument as a path, but failed there too!\n"
+"\n"
+"If you meant to check out a remote tracking branch on, e.g. 'origin',\n"
+"you can do so by fully qualifying the name with the --track option:\n"
+"\n"
+"    git checkout --track origin/<name>\n"
+"\n"
+"If you'd like to always have checkouts of an ambiguous <name> prefer\n"
+"one remote, e.g. the 'origin' remote, consider setting\n"
+"checkout.defaultRemote=origin in your config."
+msgstr ""
+"\"%s\" motsvarar mer än en spårad fjärrgren.\n"
+"Vi hittade %d fjärrar med en motsvarande referens. Så vi förösökte\n"
+"istället tolka argumentet som en sökväg, men misslyckades också där!\n"
+"\n"
+"Om du menade checka ut en spårad fjärrgren på t.ex \"origin\", kan du\n"
+"göra det genom att ange hela namnet med flaggan --track:\n"
+"\n"
+"    git checkout --track origin/<namn>\n"
+"\n"
+"Om du alltid vill att utcheckningar med tvetydiga <namn> skall\n"
+"föredra en fjärr, t.ex fjärren \"origin\" kan du ställa in\n"
+"checkout.defaultRemote=origin i din konfiguration."
+
+#: builtin/checkout.c:1714 builtin/checkout.c:1716 builtin/checkout.c:1765
+#: builtin/checkout.c:1767 builtin/clone.c:121 builtin/remote.c:169
+#: builtin/remote.c:171 builtin/worktree.c:499 builtin/worktree.c:501
+msgid "branch"
+msgstr "gren"
+
+#: builtin/checkout.c:1715
+msgid "create and checkout a new branch"
+msgstr "skapa och checka ut en ny gren"
+
+#: builtin/checkout.c:1717
+msgid "create/reset and checkout a branch"
+msgstr "skapa/nollställ och checka ut en gren"
+
+#: builtin/checkout.c:1718
+msgid "create reflog for new branch"
+msgstr "skapa reflogg för ny gren"
+
+#: builtin/checkout.c:1720
+msgid "second guess 'git checkout <no-such-branch>' (default)"
+msgstr "förutspå \"git checkout <gren-saknas>\" (förval)"
+
+#: builtin/checkout.c:1721
+msgid "use overlay mode (default)"
+msgstr "använd överläggsläge (standard)"
+
+#: builtin/checkout.c:1766
+msgid "create and switch to a new branch"
+msgstr "skapa och växla till en ny gren"
+
+#: builtin/checkout.c:1768
+msgid "create/reset and switch to a branch"
+msgstr "skapa/nollställ och växla till en gren"
+
+#: builtin/checkout.c:1770
+msgid "second guess 'git switch <no-such-branch>'"
+msgstr "förutspå \"git checkout <gren-saknas>\""
+
+#: builtin/checkout.c:1772
+msgid "throw away local modifications"
+msgstr "kasta bort lokala ändringar"
+
+#: builtin/checkout.c:1804
+msgid "which tree-ish to checkout from"
+msgstr "vilken träd-igt att checka ut från"
+
+#: builtin/checkout.c:1806
+msgid "restore the index"
+msgstr "återställ indexet"
+
+#: builtin/checkout.c:1808
+msgid "restore the working tree (default)"
+msgstr "återställ arbetskatalogen (förval)"
+
+#: builtin/checkout.c:1810
+msgid "ignore unmerged entries"
+msgstr "ignorera ej sammanslagna poster"
+
+#: builtin/checkout.c:1811
+msgid "use overlay mode"
+msgstr "använd överläggsläge"
+
+#: builtin/clean.c:28
+msgid ""
+"git clean [-d] [-f] [-i] [-n] [-q] [-e <pattern>] [-x | -X] [--] <paths>..."
+msgstr ""
+"git clean [-d] [-f] [-i] [-n] [-q] [-e <mönster>] [-x | -X] [--] "
+"<sökvägar>..."
+
+#: builtin/clean.c:32
+#, c-format
+msgid "Removing %s\n"
+msgstr "Tar bort %s\n"
+
+#: builtin/clean.c:33
+#, c-format
+msgid "Would remove %s\n"
+msgstr "Skulle ta bort %s\n"
+
+#: builtin/clean.c:34
+#, c-format
+msgid "Skipping repository %s\n"
+msgstr "Hoppar över arkivet %s\n"
+
+#: builtin/clean.c:35
+#, c-format
+msgid "Would skip repository %s\n"
+msgstr "Skulle hoppa över arkivet %s\n"
+
+#: builtin/clean.c:36
+#, c-format
+msgid "failed to remove %s"
+msgstr "misslyckades ta bort %s"
+
+#: builtin/clean.c:37
+#, c-format
+msgid "could not lstat %s\n"
+msgstr "kunde inte ta status (\"lstat\") på %s\n"
+
+#: builtin/clean.c:301 git-add--interactive.perl:595
+#, c-format
+msgid ""
+"Prompt help:\n"
+"1          - select a numbered item\n"
+"foo        - select item based on unique prefix\n"
+"           - (empty) select nothing\n"
+msgstr ""
+"Kommandohjälp:\n"
+"1          - markera en numrerad post\n"
+"foo        - markera post baserad på unikt prefix\n"
+"           - (tomt) markera ingenting\n"
+
+#: builtin/clean.c:305 git-add--interactive.perl:604
+#, c-format
+msgid ""
+"Prompt help:\n"
+"1          - select a single item\n"
+"3-5        - select a range of items\n"
+"2-3,6-9    - select multiple ranges\n"
+"foo        - select item based on unique prefix\n"
+"-...       - unselect specified items\n"
+"*          - choose all items\n"
+"           - (empty) finish selecting\n"
+msgstr ""
+"Kommandohjälp:\n"
+"1          - markera en ensam post\n"
+"3-5        - markera ett intervall med poster\n"
+"2-3,6-9    - markera flera intervall\n"
+"foo        - markera post baserad på unikt prefix\n"
+"-...       - avmarkera specifika poster\n"
+"*          - välj alla poster\n"
+"           - (tomt) avsluta markering\n"
+
+#: builtin/clean.c:521 git-add--interactive.perl:570
+#: git-add--interactive.perl:575
+#, c-format, perl-format
+msgid "Huh (%s)?\n"
+msgstr "Vadå (%s)?\n"
+
+#: builtin/clean.c:663
+#, c-format
+msgid "Input ignore patterns>> "
+msgstr "Ange ignoreringsmönster>>"
+
+#: builtin/clean.c:700
+#, c-format
+msgid "WARNING: Cannot find items matched by: %s"
+msgstr "VARNING: Hittar inte poster som motsvarar: %s"
+
+#: builtin/clean.c:721
+msgid "Select items to delete"
+msgstr "Välj poster att ta bort"
+
+#. TRANSLATORS: Make sure to keep [y/N] as is
+#: builtin/clean.c:762
+#, c-format
+msgid "Remove %s [y/N]? "
+msgstr "Ta bort %s [Y=ja / N=nej]? "
+
+#: builtin/clean.c:795
+msgid ""
+"clean               - start cleaning\n"
+"filter by pattern   - exclude items from deletion\n"
+"select by numbers   - select items to be deleted by numbers\n"
+"ask each            - confirm each deletion (like \"rm -i\")\n"
+"quit                - stop cleaning\n"
+"help                - this screen\n"
+"?                   - help for prompt selection"
+msgstr ""
+"clean               - börja städa\n"
+"filter by pattern   - uteslut poster från borttagning\n"
+"select by numbers   - markera poster som ska tas bort med siffror\n"
+"ask each            - bekräfta varje borttagning (som \"rm -i\")\n"
+"quit                - sluta städa\n"
+"help                - denna skärm\n"
+"?                   - hjälp för kommandoval"
+
+#: builtin/clean.c:831
+msgid "Would remove the following item:"
+msgid_plural "Would remove the following items:"
+msgstr[0] "Skulle ta bort följande post:"
+msgstr[1] "Skulle ta bort följande poster:"
+
+#: builtin/clean.c:847
+msgid "No more files to clean, exiting."
+msgstr "Inga fler filer att städa, avslutar."
+
+#: builtin/clean.c:909
+msgid "do not print names of files removed"
+msgstr "skriv inte ut namn på borttagna filer"
+
+#: builtin/clean.c:911
+msgid "force"
+msgstr "tvinga"
+
+#: builtin/clean.c:912
+msgid "interactive cleaning"
+msgstr "städa interaktivt"
+
+#: builtin/clean.c:914
+msgid "remove whole directories"
+msgstr "ta bort hela kataloger"
+
+#: builtin/clean.c:915 builtin/describe.c:548 builtin/describe.c:550
+#: builtin/grep.c:901 builtin/log.c:177 builtin/log.c:179
+#: builtin/ls-files.c:557 builtin/name-rev.c:464 builtin/name-rev.c:466
+#: builtin/show-ref.c:179
+msgid "pattern"
+msgstr "mönster"
+
+#: builtin/clean.c:916
+msgid "add <pattern> to ignore rules"
+msgstr "lägg till <mönster> till ignoreringsregler"
+
+#: builtin/clean.c:917
+msgid "remove ignored files, too"
+msgstr "ta även bort ignorerade filer"
+
+#: builtin/clean.c:919
+msgid "remove only ignored files"
+msgstr "ta endast bort ignorerade filer"
+
+#: builtin/clean.c:937
+msgid "-x and -X cannot be used together"
+msgstr "-x och -X kan inte användas samtidigt"
+
+#: builtin/clean.c:941
+msgid ""
+"clean.requireForce set to true and neither -i, -n, nor -f given; refusing to "
+"clean"
+msgstr ""
+"clean.requireForce satt till true, men varken -i, -n eller -f angavs; vägrar "
+"städa"
+
+#: builtin/clean.c:944
+msgid ""
+"clean.requireForce defaults to true and neither -i, -n, nor -f given; "
+"refusing to clean"
+msgstr ""
+"clean.requireForce har standardvärdet true och varken -i, -n eller -f "
+"angavs; vägrar städa"
+
+#: builtin/clone.c:45
+msgid "git clone [<options>] [--] <repo> [<dir>]"
+msgstr "git clone [<flaggor>] [--] <arkiv> [<kat>]"
+
+#: builtin/clone.c:93
+msgid "don't create a checkout"
+msgstr "skapa inte någon utcheckning"
+
+#: builtin/clone.c:94 builtin/clone.c:96 builtin/init-db.c:489
+msgid "create a bare repository"
+msgstr "skapa ett naket (\"bare\") arkiv"
+
+#: builtin/clone.c:98
+msgid "create a mirror repository (implies bare)"
+msgstr "skapa ett spegelarkiv (implicerar \"bare\")"
+
+#: builtin/clone.c:100
+msgid "to clone from a local repository"
+msgstr "för att klona från ett lokalt arkiv"
+
+#: builtin/clone.c:102
+msgid "don't use local hardlinks, always copy"
+msgstr "skapa inte lokala hårda länkar, kopiera alltid"
+
+#: builtin/clone.c:104
+msgid "setup as shared repository"
+msgstr "skapa som ett delat arkiv"
+
+#: builtin/clone.c:107
+msgid "pathspec"
+msgstr "sökvägsangivelse"
+
+#: builtin/clone.c:107
+msgid "initialize submodules in the clone"
+msgstr "initiera undermoduler i klonen"
+
+#: builtin/clone.c:110
+msgid "number of submodules cloned in parallel"
+msgstr "antal undermoduler som klonas parallellt"
+
+#: builtin/clone.c:111 builtin/init-db.c:486
+msgid "template-directory"
+msgstr "mallkatalog"
+
+#: builtin/clone.c:112 builtin/init-db.c:487
+msgid "directory from which templates will be used"
+msgstr "katalog att använda mallar från"
+
+#: builtin/clone.c:114 builtin/clone.c:116 builtin/submodule--helper.c:1392
+#: builtin/submodule--helper.c:1885
+msgid "reference repository"
+msgstr "referensarkiv"
+
+#: builtin/clone.c:118 builtin/submodule--helper.c:1394
+#: builtin/submodule--helper.c:1887
+msgid "use --reference only while cloning"
+msgstr "använd --reference endast under kloningen"
+
+#: builtin/clone.c:119 builtin/column.c:27 builtin/merge-file.c:46
+#: builtin/pack-objects.c:3294 builtin/repack.c:327
+msgid "name"
+msgstr "namn"
+
+#: builtin/clone.c:120
+msgid "use <name> instead of 'origin' to track upstream"
+msgstr "använd <namn> istället för \"origin\" för att spåra uppströms"
+
+#: builtin/clone.c:122
+msgid "checkout <branch> instead of the remote's HEAD"
+msgstr "checka ut <gren> istället för fjärrens HEAD"
+
+#: builtin/clone.c:124
+msgid "path to git-upload-pack on the remote"
+msgstr "sökväg till git-upload-pack på fjärren"
+
+#: builtin/clone.c:125 builtin/fetch.c:168 builtin/grep.c:840
+#: builtin/pull.c:227
+msgid "depth"
+msgstr "djup"
+
+#: builtin/clone.c:126
+msgid "create a shallow clone of that depth"
+msgstr "skapa en grund klon på detta djup"
+
+#: builtin/clone.c:127 builtin/fetch.c:170 builtin/pack-objects.c:3283
+msgid "time"
+msgstr "tid"
+
+#: builtin/clone.c:128
+msgid "create a shallow clone since a specific time"
+msgstr "skapa en grund klon från en angiven tidpunkt"
+
+#: builtin/clone.c:129 builtin/fetch.c:172 builtin/fetch.c:195
+#: builtin/rebase.c:1445
+msgid "revision"
+msgstr "revision"
+
+#: builtin/clone.c:130 builtin/fetch.c:173
+msgid "deepen history of shallow clone, excluding rev"
+msgstr "fördjupa historik för grund klon, exkludera revisionen"
+
+#: builtin/clone.c:132
+msgid "clone only one branch, HEAD or --branch"
+msgstr "klona endast en gren, HEAD eller --branch"
+
+#: builtin/clone.c:134
+msgid "don't clone any tags, and make later fetches not to follow them"
+msgstr "klona inga taggar och gör att senare hämtningar inte följer dem"
+
+#: builtin/clone.c:136
+msgid "any cloned submodules will be shallow"
+msgstr "klonade undermoduler kommer vara grunda"
+
+#: builtin/clone.c:137 builtin/init-db.c:495
+msgid "gitdir"
+msgstr "gitkat"
+
+#: builtin/clone.c:138 builtin/init-db.c:496
+msgid "separate git dir from working tree"
+msgstr "separera gitkatalogen från arbetskatalogen"
+
+#: builtin/clone.c:139
+msgid "key=value"
+msgstr "nyckel=värde"
+
+#: builtin/clone.c:140
+msgid "set config inside the new repository"
+msgstr "ställ in konfiguration i det nya arkivet"
+
+#: builtin/clone.c:142 builtin/fetch.c:190 builtin/ls-remote.c:76
+#: builtin/push.c:573 builtin/send-pack.c:172
+msgid "server-specific"
+msgstr "serverspecifik"
+
+#: builtin/clone.c:142 builtin/fetch.c:190 builtin/ls-remote.c:76
+#: builtin/push.c:573 builtin/send-pack.c:173
+msgid "option to transmit"
+msgstr ""
+"inget att checka in\n"
+"flagga att sända"
+
+#: builtin/clone.c:143 builtin/fetch.c:191 builtin/pull.c:240
+#: builtin/push.c:574
+msgid "use IPv4 addresses only"
+msgstr "använd endast IPv4-adresser"
+
+#: builtin/clone.c:145 builtin/fetch.c:193 builtin/pull.c:243
+#: builtin/push.c:576
+msgid "use IPv6 addresses only"
+msgstr "använd endast IPv6-adresser"
+
+#: builtin/clone.c:149
+msgid "any cloned submodules will use their remote-tracking branch"
+msgstr "klonade undermoduler kommer använda sin fjärrspårningsgren"
+
+#: builtin/clone.c:151
+msgid "initialize sparse-checkout file to include only files at root"
+msgstr "initiera sparse-checkout-filen till att bara inkludera filer i roten"
+
+#: builtin/clone.c:287
+msgid ""
+"No directory name could be guessed.\n"
+"Please specify a directory on the command line"
+msgstr ""
+"Kunde inte gissa katalognamn.\n"
+"Ange en katalog på kommandoraden"
+
+#: builtin/clone.c:340
+#, c-format
+msgid "info: Could not add alternate for '%s': %s\n"
+msgstr "info: Kan inte skapa suppleant för \"%s\": %s\n"
+
+#: builtin/clone.c:413
+#, c-format
+msgid "%s exists and is not a directory"
+msgstr "%s finns och är ingen katalog"
+
+#: builtin/clone.c:430
+#, c-format
+msgid "failed to start iterator over '%s'"
+msgstr "misslyckades starta iterator över \"%s\""
+
+#: builtin/clone.c:460
+#, c-format
+msgid "failed to create link '%s'"
+msgstr "misslyckades skapa länken \"%s\""
+
+#: builtin/clone.c:464
+#, c-format
+msgid "failed to copy file to '%s'"
+msgstr "misslyckades kopiera filen till \"%s\""
+
+#: builtin/clone.c:469
+#, c-format
+msgid "failed to iterate over '%s'"
+msgstr "misslyckades iterera över \"%s\""
+
+#: builtin/clone.c:494
+#, c-format
+msgid "done.\n"
+msgstr "klart.\n"
+
+#: builtin/clone.c:508
+msgid ""
+"Clone succeeded, but checkout failed.\n"
+"You can inspect what was checked out with 'git status'\n"
+"and retry with 'git restore --source=HEAD :/'\n"
+msgstr ""
+"Klonen lyckades, men utcheckningen misslyckades.\n"
+"Du kan inspektera det som checkades ut med \"git status\"\n"
+"och försöka med \"git restore -source=HEAD :/\"\n"
+
+#: builtin/clone.c:585
+#, c-format
+msgid "Could not find remote branch %s to clone."
+msgstr "Kunde inte hitta fjärrgrenen %s för att klona."
+
+#: builtin/clone.c:704
+#, c-format
+msgid "unable to update %s"
+msgstr "kan inte uppdatera %s"
+
+#: builtin/clone.c:752
+msgid "failed to initialize sparse-checkout"
+msgstr "misslyckades initiera sparse-checkout"
+
+#: builtin/clone.c:775
+msgid "remote HEAD refers to nonexistent ref, unable to checkout.\n"
+msgstr ""
+"HEAD hos fjärren pekar på en obefintlig referens, kan inte checka ut.\n"
+
+#: builtin/clone.c:806
+msgid "unable to checkout working tree"
+msgstr "kunde inte checka ut arbetskatalogen"
+
+#: builtin/clone.c:856
+msgid "unable to write parameters to config file"
+msgstr "kunde inte skriva parametrar till konfigurationsfilen"
+
+#: builtin/clone.c:919
+msgid "cannot repack to clean up"
+msgstr "kan inte packa om för att städa upp"
+
+#: builtin/clone.c:921
+msgid "cannot unlink temporary alternates file"
+msgstr "kunde inte ta bort temporär \"alternates\"-fil"
+
+#: builtin/clone.c:959 builtin/receive-pack.c:1948
+msgid "Too many arguments."
+msgstr "För många argument."
+
+#: builtin/clone.c:963
+msgid "You must specify a repository to clone."
+msgstr "Du måste ange ett arkiv att klona."
+
+#: builtin/clone.c:976
+#, c-format
+msgid "--bare and --origin %s options are incompatible."
+msgstr "flaggorna --bare och --origin %s är inkompatibla."
+
+#: builtin/clone.c:979
+msgid "--bare and --separate-git-dir are incompatible."
+msgstr "flaggorna --bare och --separate-git-dir är inkompatibla."
+
+#: builtin/clone.c:992
+#, c-format
+msgid "repository '%s' does not exist"
+msgstr "arkivet \"%s\" finns inte"
+
+#: builtin/clone.c:998 builtin/fetch.c:1787
+#, c-format
+msgid "depth %s is not a positive number"
+msgstr "djupet %s är inte ett positivt tal"
+
+#: builtin/clone.c:1008
+#, c-format
+msgid "destination path '%s' already exists and is not an empty directory."
+msgstr "destinationssökvägen \"%s\" finns redan och är inte en tom katalog."
+
+#: builtin/clone.c:1018
+#, c-format
+msgid "working tree '%s' already exists."
+msgstr "arbetsträdet \"%s\" finns redan."
+
+#: builtin/clone.c:1033 builtin/clone.c:1054 builtin/difftool.c:271
+#: builtin/log.c:1866 builtin/worktree.c:302 builtin/worktree.c:334
+#, c-format
+msgid "could not create leading directories of '%s'"
+msgstr "kunde inte skapa inledande kataloger för \"%s\""
+
+#: builtin/clone.c:1038
+#, c-format
+msgid "could not create work tree dir '%s'"
+msgstr "kunde inte skapa arbetskatalogen \"%s\""
+
+#: builtin/clone.c:1058
+#, c-format
+msgid "Cloning into bare repository '%s'...\n"
+msgstr "Klonar till ett naket arkiv \"%s\"...\n"
+
+#: builtin/clone.c:1060
+#, c-format
+msgid "Cloning into '%s'...\n"
+msgstr "Klonar till \"%s\"...\n"
+
+#: builtin/clone.c:1084
+msgid ""
+"clone --recursive is not compatible with both --reference and --reference-if-"
+"able"
+msgstr ""
+"clone --recursive är inte kompatibel med --reference och --reference-if-able"
+
+#: builtin/clone.c:1148
+msgid "--depth is ignored in local clones; use file:// instead."
+msgstr "--depth ignoreras i lokala kloningar; använd file:// istället."
+
+#: builtin/clone.c:1150
+msgid "--shallow-since is ignored in local clones; use file:// instead."
+msgstr "--shallow-since ignoreras i lokala kloningar; använd file:// istället."
+
+#: builtin/clone.c:1152
+msgid "--shallow-exclude is ignored in local clones; use file:// instead."
+msgstr ""
+"--shallow-exclude ignoreras i lokala kloningar; använd file:// istället."
+
+#: builtin/clone.c:1154
+msgid "--filter is ignored in local clones; use file:// instead."
+msgstr "--filter ignoreras i lokala kloningar; använd file:// istället."
+
+#: builtin/clone.c:1157
+msgid "source repository is shallow, ignoring --local"
+msgstr "källarkivet är grunt, ignorerar --local"
+
+#: builtin/clone.c:1162
+msgid "--local is ignored"
+msgstr "--local ignoreras"
+
+#: builtin/clone.c:1237 builtin/clone.c:1245
+#, c-format
+msgid "Remote branch %s not found in upstream %s"
+msgstr "Fjärrgrenen %s hittades inte i uppströmsarkivet %s"
+
+#: builtin/clone.c:1248
+msgid "You appear to have cloned an empty repository."
+msgstr "Du verkar ha klonat ett tomt arkiv."
+
+#: builtin/column.c:10
+msgid "git column [<options>]"
+msgstr "git column [<flaggor>]"
+
+#: builtin/column.c:27
+msgid "lookup config vars"
+msgstr "slå upp konfigurationsvariabler"
+
+#: builtin/column.c:28 builtin/column.c:29
+msgid "layout to use"
+msgstr "utseende att använda"
+
+#: builtin/column.c:30
+msgid "Maximum width"
+msgstr "Maximal bredd"
+
+#: builtin/column.c:31
+msgid "Padding space on left border"
+msgstr "Spaltfyllnad i vänsterkanten"
+
+#: builtin/column.c:32
+msgid "Padding space on right border"
+msgstr "Spaltfyllnad i högerkanten"
+
+#: builtin/column.c:33
+msgid "Padding space between columns"
+msgstr "Spaltfyllnad mellan spalter"
 
-#: builtin/cat-file.c:565
-msgid "show object size"
-msgstr "visa objektstorlek"
+#: builtin/column.c:51
+msgid "--command must be the first argument"
+msgstr "--command måste vara första argument"
 
-#: builtin/cat-file.c:567
-msgid "exit with zero when there's no error"
-msgstr "avsluta med noll när det inte uppstått något fel"
+#: builtin/commit-tree.c:18
+msgid ""
+"git commit-tree [(-p <parent>)...] [-S[<keyid>]] [(-m <message>)...] [(-F "
+"<file>)...] <tree>"
+msgstr ""
+"git commit-tree [(-p <föräldrer>)...] [-S[<nyckelid>]] [(-m "
+"<meddelande>)...] [(-F <fil>)...] <träd>"
 
-#: builtin/cat-file.c:568
-msgid "pretty-print object's content"
-msgstr "visa objektets innehåll snyggt"
+#: builtin/commit-tree.c:31
+#, c-format
+msgid "duplicate parent %s ignored"
+msgstr "duplicerad förälder %s ignorerades"
 
-#: builtin/cat-file.c:570
-msgid "for blob objects, run textconv on object's content"
-msgstr "för blob-objekt, kör filter på objektets innehåll"
+#: builtin/commit-tree.c:56 builtin/commit-tree.c:136 builtin/log.c:526
+#, c-format
+msgid "not a valid object name %s"
+msgstr "objektnamnet är inte giltigt: %s"
 
-#: builtin/cat-file.c:572
-msgid "for blob objects, run filters on object's content"
-msgstr "för blob-objekt, kör filger på objektets innehåll"
+#: builtin/commit-tree.c:93
+#, c-format
+msgid "git commit-tree: failed to open '%s'"
+msgstr "git commit-tree: misslyckades öppna \"%s\""
 
-#: builtin/cat-file.c:573 git-submodule.sh:894
-msgid "blob"
-msgstr "blob"
+#: builtin/commit-tree.c:96
+#, c-format
+msgid "git commit-tree: failed to read '%s'"
+msgstr "git commit-tree: misslyckades läsa \"%s\""
 
-#: builtin/cat-file.c:574
-msgid "use a specific path for --textconv/--filters"
-msgstr "använd specifik sökväg för --textconv/--filters"
+#: builtin/commit-tree.c:98
+#, c-format
+msgid "git commit-tree: failed to close '%s'"
+msgstr "git commit-tree: misslyckades stänga \"%s\""
 
-#: builtin/cat-file.c:576
-msgid "allow -s and -t to work with broken/corrupt objects"
-msgstr "låter -s och -t att fungera med trasiga/sönderskrivna objekt"
+#: builtin/commit-tree.c:111
+msgid "parent"
+msgstr "förälder"
 
-#: builtin/cat-file.c:577
-msgid "buffer --batch output"
-msgstr "buffra utdata från --batch"
+#: builtin/commit-tree.c:112
+msgid "id of a parent commit object"
+msgstr "id på ett förälderincheckningsobjekt"
 
-#: builtin/cat-file.c:579
-msgid "show info and content of objects fed from the standard input"
-msgstr "visa information och innehåll för objekt som listas på standard in"
+#: builtin/commit-tree.c:114 builtin/commit.c:1496 builtin/merge.c:270
+#: builtin/notes.c:409 builtin/notes.c:575 builtin/stash.c:1469
+#: builtin/tag.c:412
+msgid "message"
+msgstr "meddelande"
 
-#: builtin/cat-file.c:582
-msgid "show info about objects fed from the standard input"
-msgstr "visa information för objekt som listas på standard in"
+#: builtin/commit-tree.c:115 builtin/commit.c:1496
+msgid "commit message"
+msgstr "incheckningsmeddelande"
 
-#: builtin/cat-file.c:585
-msgid "follow in-tree symlinks (used with --batch or --batch-check)"
-msgstr ""
-"följ symboliska länkar i trädet (använd med --batch eller --batch-check)"
+#: builtin/commit-tree.c:118
+msgid "read commit log message from file"
+msgstr "läs incheckningsloggmeddelande från fil"
 
-#: builtin/cat-file.c:587
-msgid "show all objects with --batch or --batch-check"
-msgstr "visa alla objekt med --batch eller --batch-check"
+#: builtin/commit-tree.c:121 builtin/commit.c:1508 builtin/merge.c:287
+#: builtin/pull.c:195 builtin/revert.c:118
+msgid "GPG sign commit"
+msgstr "GPG-signera incheckning"
 
-#: builtin/check-attr.c:12
-msgid "git check-attr [-a | --all | <attr>...] [--] <pathname>..."
-msgstr "git check-attr [-a | --all | <attr>...] [--] <sökväg>..."
+#: builtin/commit-tree.c:133
+msgid "must give exactly one tree"
+msgstr "måste ange exakt ett träd"
+
+#: builtin/commit-tree.c:140
+msgid "git commit-tree: failed to read"
+msgstr "git commit-tree: misslyckades läsa"
 
-#: builtin/check-attr.c:13
-msgid "git check-attr --stdin [-z] [-a | --all | <attr>...]"
-msgstr "git check-attr --stdin [-z] [-a | --all | <attr>...]"
+#: builtin/commit.c:41
+msgid "git commit [<options>] [--] <pathspec>..."
+msgstr "git commit [<flaggor>] [--] <sökväg>..."
 
-#: builtin/check-attr.c:20
-msgid "report all attributes set on file"
-msgstr "visa alla attribut som satts på filen"
+#: builtin/commit.c:46
+msgid "git status [<options>] [--] <pathspec>..."
+msgstr "git status [<flaggor>] [--] <sökväg>..."
 
-#: builtin/check-attr.c:21
-msgid "use .gitattributes only from the index"
-msgstr "använd .gitattributes endast från indexet"
+#: builtin/commit.c:51
+msgid ""
+"You asked to amend the most recent commit, but doing so would make\n"
+"it empty. You can repeat your command with --allow-empty, or you can\n"
+"remove the commit entirely with \"git reset HEAD^\".\n"
+msgstr ""
+"Du bad om att utöka den senaste incheckningen, men om du gör det\n"
+"blir den tom. Du kan köra kommandot på nytt med --allow-empty, eller\n"
+"så kan du ta bort incheckningen helt med \"git reset HEAD^\".\n"
 
-#: builtin/check-attr.c:22 builtin/check-ignore.c:24 builtin/hash-object.c:100
-msgid "read file names from stdin"
-msgstr "läs filnamn från standard in"
+#: builtin/commit.c:56
+msgid ""
+"The previous cherry-pick is now empty, possibly due to conflict resolution.\n"
+"If you wish to commit it anyway, use:\n"
+"\n"
+"    git commit --allow-empty\n"
+"\n"
+msgstr ""
+"Den tidigare \"cherry-pick\":en är nu tom, kanske på grund av en löst\n"
+"konflikt. Om du vill checka in den ändå använder du:\n"
+"\n"
+"    git commit --allow-empty\n"
+"\n"
 
-#: builtin/check-attr.c:24 builtin/check-ignore.c:26
-msgid "terminate input and output records by a NUL character"
-msgstr "avsluta in- och utdataposter med NUL-tecken"
+#: builtin/commit.c:63
+msgid "Otherwise, please use 'git cherry-pick --skip'\n"
+msgstr "Använd annars \"git cherry-pick --skip\"\n"
 
-#: builtin/check-ignore.c:20 builtin/checkout.c:1113 builtin/gc.c:500
-msgid "suppress progress reporting"
-msgstr "undertryck förloppsrapportering"
+#: builtin/commit.c:66
+msgid ""
+"and then use:\n"
+"\n"
+"    git cherry-pick --continue\n"
+"\n"
+"to resume cherry-picking the remaining commits.\n"
+"If you wish to skip this commit, use:\n"
+"\n"
+"    git cherry-pick --skip\n"
+"\n"
+msgstr ""
+"och sedan:\n"
+"\n"
+"    git cherry-pick --continue\n"
+"\n"
+"för att fortsätta \"cherry-pick\" med resterande incheckningar.\n"
+"Om du vill hoppa över den här incheckningen, använd:\n"
+"\n"
+"    git cherry-pick --skip\n"
+"\n"
 
-#: builtin/check-ignore.c:28
-msgid "show non-matching input paths"
-msgstr "visa indatasökvägar som inte träffas"
+#: builtin/commit.c:315
+msgid "failed to unpack HEAD tree object"
+msgstr "misslyckades packa upp HEAD:s trädobjekt"
 
-#: builtin/check-ignore.c:30
-msgid "ignore index when checking"
-msgstr "ignorera index vid kontroll"
+#: builtin/commit.c:351
+msgid "--pathspec-from-file with -a does not make sense"
+msgstr "--pathspec-from-file med -a ger ingen mening"
 
-#: builtin/check-ignore.c:159
-msgid "cannot specify pathnames with --stdin"
-msgstr "kan inte ange sökvägsnamn med --stdin"
+#: builtin/commit.c:364
+msgid "No paths with --include/--only does not make sense."
+msgstr "Du måste ange sökvägar tillsammans med --include/--only."
 
-#: builtin/check-ignore.c:162
-msgid "-z only makes sense with --stdin"
-msgstr "-z kan endast användas tillsammans med --stdin"
+#: builtin/commit.c:376
+msgid "unable to create temporary index"
+msgstr "kunde inte skapa temporär indexfil"
 
-#: builtin/check-ignore.c:164
-msgid "no path specified"
-msgstr "ingen sökväg angavs"
+#: builtin/commit.c:382
+msgid "interactive add failed"
+msgstr "interaktiv tilläggning misslyckades"
 
-#: builtin/check-ignore.c:168
-msgid "--quiet is only valid with a single pathname"
-msgstr "--quiet kan endast användas med ett enkelt sökvägsnamn"
+#: builtin/commit.c:396
+msgid "unable to update temporary index"
+msgstr "kan inte uppdatera temporärt index"
 
-#: builtin/check-ignore.c:170
-msgid "cannot have both --quiet and --verbose"
-msgstr "kan inte använda både --quiet och --verbose"
+#: builtin/commit.c:398
+msgid "Failed to update main cache tree"
+msgstr "Misslyckades uppdatera huvud-cacheträdet"
 
-#: builtin/check-ignore.c:173
-msgid "--non-matching is only valid with --verbose"
-msgstr "--non-matching är endast giltig med --verbose"
+#: builtin/commit.c:423 builtin/commit.c:446 builtin/commit.c:492
+msgid "unable to write new_index file"
+msgstr "kunde inte skriva filen new_index"
 
-#: builtin/check-mailmap.c:9
-msgid "git check-mailmap [<options>] <contact>..."
-msgstr "git check-mailmap [<flaggor>] <kontakt>..."
+#: builtin/commit.c:475
+msgid "cannot do a partial commit during a merge."
+msgstr "kan inte utföra en delvis incheckning under en sammanslagning."
 
-#: builtin/check-mailmap.c:14
-msgid "also read contacts from stdin"
-msgstr "läs även kontakter från standard in"
+#: builtin/commit.c:477
+msgid "cannot do a partial commit during a cherry-pick."
+msgstr "kan inte utföra en delvis incheckning under en cherry-pick."
 
-#: builtin/check-mailmap.c:25
-#, c-format
-msgid "unable to parse contact: %s"
-msgstr "kunde inte tolka kontakt: %s"
+#: builtin/commit.c:485
+msgid "cannot read the index"
+msgstr "kan inte läsa indexet"
 
-#: builtin/check-mailmap.c:48
-msgid "no contacts specified"
-msgstr "inga kontakter angavs"
+#: builtin/commit.c:504
+msgid "unable to write temporary index file"
+msgstr "kunde inte skriva temporär indexfil"
 
-#: builtin/checkout-index.c:128
-msgid "git checkout-index [<options>] [--] [<file>...]"
-msgstr "git checkout-index [<flaggor>] [--] [<fil>...]"
+#: builtin/commit.c:602
+#, c-format
+msgid "commit '%s' lacks author header"
+msgstr "incheckningen \"%s\" saknar författarhuvud"
 
-#: builtin/checkout-index.c:143
-msgid "stage should be between 1 and 3 or all"
-msgstr "etapp måste vara mellan 1 och 3 eller \"all\""
+#: builtin/commit.c:604
+#, c-format
+msgid "commit '%s' has malformed author line"
+msgstr "incheckningen \"%s\" har felformaterat författarhuvud"
 
-#: builtin/checkout-index.c:159
-msgid "check out all files in the index"
-msgstr "checka ut alla filer i indexet"
+#: builtin/commit.c:623
+msgid "malformed --author parameter"
+msgstr "felformad \"--author\"-flagga"
 
-#: builtin/checkout-index.c:160
-msgid "force overwrite of existing files"
-msgstr "tvinga överskrivning av befintliga filer"
+#: builtin/commit.c:676
+msgid ""
+"unable to select a comment character that is not used\n"
+"in the current commit message"
+msgstr ""
+"kunde inte välja ett kommentarstecken som inte använts\n"
+"i det befintliga incheckningsmeddelandet"
 
-#: builtin/checkout-index.c:162
-msgid "no warning for existing files and files not in index"
-msgstr "ingen varning för existerande filer och filer ej i indexet"
+#: builtin/commit.c:714 builtin/commit.c:747 builtin/commit.c:1092
+#, c-format
+msgid "could not lookup commit %s"
+msgstr "kunde inte slå upp incheckningen %s"
 
-#: builtin/checkout-index.c:164
-msgid "don't checkout new files"
-msgstr "checka inte ut nya filer"
+#: builtin/commit.c:726 builtin/shortlog.c:319
+#, c-format
+msgid "(reading log message from standard input)\n"
+msgstr "(läser loggmeddelande från standard in)\n"
 
-#: builtin/checkout-index.c:166
-msgid "update stat information in the index file"
-msgstr "uppdatera stat-information i indexfilen"
+#: builtin/commit.c:728
+msgid "could not read log from standard input"
+msgstr "kunde inte läsa logg från standard in"
 
-#: builtin/checkout-index.c:170
-msgid "read list of paths from the standard input"
-msgstr "läs listan över sökvägar från standard in"
+#: builtin/commit.c:732
+#, c-format
+msgid "could not read log file '%s'"
+msgstr "kunde inte läsa loggfilen \"%s\""
 
-#: builtin/checkout-index.c:172
-msgid "write the content to temporary files"
-msgstr "skriv innehåll till temporära filer"
+#: builtin/commit.c:763 builtin/commit.c:779
+msgid "could not read SQUASH_MSG"
+msgstr "kunde inte läsa SQUASH_MSG"
 
-#: builtin/checkout-index.c:173 builtin/column.c:31
-#: builtin/submodule--helper.c:1216 builtin/submodule--helper.c:1219
-#: builtin/submodule--helper.c:1227 builtin/submodule--helper.c:1591
-#: builtin/worktree.c:610
-msgid "string"
-msgstr "sträng"
+#: builtin/commit.c:770
+msgid "could not read MERGE_MSG"
+msgstr "kunde inte läsa MERGE_MSG"
 
-#: builtin/checkout-index.c:174
-msgid "when creating files, prepend <string>"
-msgstr "när filer skapas, lägg till <sträng> först"
+#: builtin/commit.c:830
+msgid "could not write commit template"
+msgstr "kunde inte skriva incheckningsmall"
 
-#: builtin/checkout-index.c:176
-msgid "copy out the files from named stage"
-msgstr "kopiera ut filer från namngiven etapp"
+#: builtin/commit.c:849
+#, c-format
+msgid ""
+"\n"
+"It looks like you may be committing a merge.\n"
+"If this is not correct, please remove the file\n"
+"\t%s\n"
+"and try again.\n"
+msgstr ""
+"\n"
+"Det verkar som du checkar in en sammanslagning.\n"
+"Om det inte stämmer tar du bort filen\n"
+"\t%s\n"
+"och försöker igen.\n"
 
-#: builtin/checkout.c:27
-msgid "git checkout [<options>] <branch>"
-msgstr "git checkout [<flaggor>] <gren>"
+#: builtin/commit.c:854
+#, c-format
+msgid ""
+"\n"
+"It looks like you may be committing a cherry-pick.\n"
+"If this is not correct, please remove the file\n"
+"\t%s\n"
+"and try again.\n"
+msgstr ""
+"\n"
+"Det verkar som du checkar in en cherry-pick.\n"
+"Om det inte stämmer tar du bort filen\n"
+"\t%s\n"
+"och försöker igen.\n"
 
-#: builtin/checkout.c:28
-msgid "git checkout [<options>] [<branch>] -- <file>..."
-msgstr "git checkout [<flaggor>] [<gren>] -- <fil>..."
+#: builtin/commit.c:867
+#, c-format
+msgid ""
+"Please enter the commit message for your changes. Lines starting\n"
+"with '%c' will be ignored, and an empty message aborts the commit.\n"
+msgstr ""
+"Ange incheckningsmeddelandet för dina ändringar. Rader som inleds\n"
+"med \"%c\" kommer ignoreras, och ett tomt meddelande avbryter "
+"incheckningen.\n"
+
+#: builtin/commit.c:875
+#, c-format
+msgid ""
+"Please enter the commit message for your changes. Lines starting\n"
+"with '%c' will be kept; you may remove them yourself if you want to.\n"
+"An empty message aborts the commit.\n"
+msgstr ""
+"Ange incheckningsmeddelandet för dina ändringar. Rader som inleds\n"
+"med \"%c\" kommer behållas; du kan själv ta bort dem om du vill.\n"
+"Ett tomt meddelande avbryter incheckningen.\n"
 
-#: builtin/checkout.c:136 builtin/checkout.c:169
+#: builtin/commit.c:892
 #, c-format
-msgid "path '%s' does not have our version"
-msgstr "sökvägen \"%s\" har inte vår version"
+msgid "%sAuthor:    %.*s <%.*s>"
+msgstr "%sFörfattare: %.*s <%.*s>"
 
-#: builtin/checkout.c:138 builtin/checkout.c:171
+#: builtin/commit.c:900
 #, c-format
-msgid "path '%s' does not have their version"
-msgstr "sökvägen \"%s\" har inte deras version"
+msgid "%sDate:      %s"
+msgstr "%sDatum:      %s"
 
-#: builtin/checkout.c:154
+#: builtin/commit.c:907
 #, c-format
-msgid "path '%s' does not have all necessary versions"
-msgstr "sökvägen \"%s\" innehåller inte alla nödvändiga versioner"
+msgid "%sCommitter: %.*s <%.*s>"
+msgstr "%sIncheckare: %.*s <%.*s>"
 
-#: builtin/checkout.c:198
-#, c-format
-msgid "path '%s' does not have necessary versions"
-msgstr "sökvägen \"%s\" innehåller inte nödvändiga versioner"
+#: builtin/commit.c:925
+msgid "Cannot read index"
+msgstr "Kan inte läsa indexet"
 
-#: builtin/checkout.c:215
-#, c-format
-msgid "path '%s': cannot merge"
-msgstr "sökväg \"%s\": kan inte slå ihop"
+#: builtin/commit.c:992
+msgid "Error building trees"
+msgstr "Fel vid byggande av träd"
 
-#: builtin/checkout.c:231
+#: builtin/commit.c:1006 builtin/tag.c:275
 #, c-format
-msgid "Unable to add merge result for '%s'"
-msgstr "Kunde inte lägga till sammanslagningsresultat för \"%s\""
+msgid "Please supply the message using either -m or -F option.\n"
+msgstr "Ange meddelandet en av flaggorna -m eller -F.\n"
 
-#: builtin/checkout.c:253 builtin/checkout.c:256 builtin/checkout.c:259
-#: builtin/checkout.c:262
+#: builtin/commit.c:1050
 #, c-format
-msgid "'%s' cannot be used with updating paths"
-msgstr "\"%s\" kan inte användas vid uppdatering av sökvägar"
+msgid "--author '%s' is not 'Name <email>' and matches no existing author"
+msgstr ""
+"--author '%s' är inte 'Namn <epost>' och matchar ingen befintlig författare"
 
-#: builtin/checkout.c:265 builtin/checkout.c:268
+#: builtin/commit.c:1064
 #, c-format
-msgid "'%s' cannot be used with %s"
-msgstr "\"%s\" kan inte användas med %s"
+msgid "Invalid ignored mode '%s'"
+msgstr "Ogiltigt ignorerat läge \"%s\""
 
-#: builtin/checkout.c:271
+#: builtin/commit.c:1082 builtin/commit.c:1322
 #, c-format
-msgid "Cannot update paths and switch to branch '%s' at the same time."
-msgstr "Kan inte uppdatera sökvägar och växla till grenen \"%s\" samtidigt."
+msgid "Invalid untracked files mode '%s'"
+msgstr "Ogiltigt läge för ospårade filer: \"%s\""
 
-#: builtin/checkout.c:340 builtin/checkout.c:347
-#, c-format
-msgid "path '%s' is unmerged"
-msgstr "sökvägen \"%s\" har inte slagits ihop"
+#: builtin/commit.c:1122
+msgid "--long and -z are incompatible"
+msgstr "--long och -z är inkompatibla"
 
-#: builtin/checkout.c:506
-msgid "you need to resolve your current index first"
-msgstr "du måste lösa ditt befintliga index först"
+#: builtin/commit.c:1166
+msgid "Using both --reset-author and --author does not make sense"
+msgstr "Kan inte använda både --reset-author och --author"
 
-#: builtin/checkout.c:643
-#, c-format
-msgid "Can not do reflog for '%s': %s\n"
-msgstr "Kan inte skapa referenslogg för \"%s\": %s\n"
+#: builtin/commit.c:1175
+msgid "You have nothing to amend."
+msgstr "Du har inget att utöka."
 
-#: builtin/checkout.c:684
-msgid "HEAD is now at"
-msgstr "HEAD är nu på"
+#: builtin/commit.c:1178
+msgid "You are in the middle of a merge -- cannot amend."
+msgstr "Du är i mitten av en sammanslagning -- kan inte utöka."
 
-#: builtin/checkout.c:688 builtin/clone.c:691
-msgid "unable to update HEAD"
-msgstr "kan inte uppdatera HEAD"
+#: builtin/commit.c:1180
+msgid "You are in the middle of a cherry-pick -- cannot amend."
+msgstr "Du är i mitten av en cherry-pick -- kan inte utöka."
 
-#: builtin/checkout.c:692
-#, c-format
-msgid "Reset branch '%s'\n"
-msgstr "Återställ gren \"%s\"\n"
+#: builtin/commit.c:1183
+msgid "Options --squash and --fixup cannot be used together"
+msgstr "Flaggorna --squash och --fixup kan inte användas samtidigt"
 
-#: builtin/checkout.c:695
-#, c-format
-msgid "Already on '%s'\n"
-msgstr "Redan på \"%s\"\n"
+#: builtin/commit.c:1193
+msgid "Only one of -c/-C/-F/--fixup can be used."
+msgstr "Endast en av -c/-C/-F/--fixup kan användas."
 
-#: builtin/checkout.c:699
-#, c-format
-msgid "Switched to and reset branch '%s'\n"
-msgstr "Växlade till och nollställde grenen \"%s\"\n"
+#: builtin/commit.c:1195
+msgid "Option -m cannot be combined with -c/-C/-F."
+msgstr "Flaggan -m kan inte kombineras med -c/-C/-F."
 
-#: builtin/checkout.c:701 builtin/checkout.c:1046
-#, c-format
-msgid "Switched to a new branch '%s'\n"
-msgstr "Växlade till en ny gren \"%s\"\n"
+#: builtin/commit.c:1203
+msgid "--reset-author can be used only with -C, -c or --amend."
+msgstr "--reset-author kan endast användas med -C, -c eller --amend."
 
-#: builtin/checkout.c:703
-#, c-format
-msgid "Switched to branch '%s'\n"
-msgstr "Växlade till grenen \"%s\"\n"
+#: builtin/commit.c:1220
+msgid "Only one of --include/--only/--all/--interactive/--patch can be used."
+msgstr ""
+"Endast en av --include/--only/--all/--interactive/--patch kan användas."
 
-#: builtin/checkout.c:754
+#: builtin/commit.c:1226
 #, c-format
-msgid " ... and %d more.\n"
-msgstr " ... och %d till.\n"
+msgid "paths '%s ...' with -a does not make sense"
+msgstr "sökvägarna \"%s ...\" med -a ger ingen mening"
 
-#: builtin/checkout.c:760
-#, c-format
+#: builtin/commit.c:1357 builtin/commit.c:1519
+msgid "show status concisely"
+msgstr "visa koncis status"
+
+#: builtin/commit.c:1359 builtin/commit.c:1521
+msgid "show branch information"
+msgstr "visa information om gren"
+
+#: builtin/commit.c:1361
+msgid "show stash information"
+msgstr "visa information om stash"
+
+#: builtin/commit.c:1363 builtin/commit.c:1523
+msgid "compute full ahead/behind values"
+msgstr "beräkna fullständiga före-/efter-värden"
+
+#: builtin/commit.c:1365
+msgid "version"
+msgstr "version"
+
+#: builtin/commit.c:1365 builtin/commit.c:1525 builtin/push.c:549
+#: builtin/worktree.c:650
+msgid "machine-readable output"
+msgstr "maskinläsbar utdata"
+
+#: builtin/commit.c:1368 builtin/commit.c:1527
+msgid "show status in long format (default)"
+msgstr "visa status i långt format (standard)"
+
+#: builtin/commit.c:1371 builtin/commit.c:1530
+msgid "terminate entries with NUL"
+msgstr "terminera poster med NUL"
+
+#: builtin/commit.c:1373 builtin/commit.c:1377 builtin/commit.c:1533
+#: builtin/fast-export.c:1153 builtin/fast-export.c:1156
+#: builtin/fast-export.c:1159 builtin/rebase.c:1525 parse-options.h:336
+msgid "mode"
+msgstr "läge"
+
+#: builtin/commit.c:1374 builtin/commit.c:1533
+msgid "show untracked files, optional modes: all, normal, no. (Default: all)"
+msgstr "visa ospårade filer, valfria lägen: all, normal, no. (Standard: all)"
+
+#: builtin/commit.c:1378
 msgid ""
-"Warning: you are leaving %d commit behind, not connected to\n"
-"any of your branches:\n"
-"\n"
-"%s\n"
-msgid_plural ""
-"Warning: you are leaving %d commits behind, not connected to\n"
-"any of your branches:\n"
-"\n"
-"%s\n"
-msgstr[0] ""
-"Varning: du lämnar %d incheckning bakom dig som inte är ansluten till\n"
-"någon av dina grenar:\n"
-"\n"
-"%s\n"
-msgstr[1] ""
-"Varning: du lämnar %d incheckningar bakom dig som inte är ansluta till\n"
-"någon av dina grenar:\n"
-"\n"
-"%s\n"
+"show ignored files, optional modes: traditional, matching, no. (Default: "
+"traditional)"
+msgstr ""
+"visa ignorerade filer, valfria lägen: traditional, matching, no (Standard: "
+"traditional)"
 
-#: builtin/checkout.c:779
-#, c-format
+#: builtin/commit.c:1380 parse-options.h:192
+msgid "when"
+msgstr "när"
+
+#: builtin/commit.c:1381
 msgid ""
-"If you want to keep it by creating a new branch, this may be a good time\n"
-"to do so with:\n"
-"\n"
-" git branch <new-branch-name> %s\n"
-"\n"
-msgid_plural ""
-"If you want to keep them by creating a new branch, this may be a good time\n"
-"to do so with:\n"
-"\n"
-" git branch <new-branch-name> %s\n"
-"\n"
-msgstr[0] ""
-"Om du vill behålla den genom att skapa en ny gren är nu en bra tidpunkt\n"
-"att göra så, med:\n"
-"\n"
-" git branch <nytt_grennamn> %s\n"
-"\n"
-msgstr[1] ""
-"Om du vill behålla dem genom att skapa en ny gren är nu en bra tidpunkt\n"
-"att göra så, med:\n"
-"\n"
-" git branch <nytt_grennamn> %s\n"
-"\n"
+"ignore changes to submodules, optional when: all, dirty, untracked. "
+"(Default: all)"
+msgstr ""
+"ignorera ändringar i undermoduler, valfritt när: all, dirty, untracked. "
+"(Default: all)"
 
-#: builtin/checkout.c:811
-msgid "internal error in revision walk"
-msgstr "internt fel vid genomgång av revisioner (revision walk)"
+#: builtin/commit.c:1383
+msgid "list untracked files in columns"
+msgstr "visa ospårade filer i spalter"
 
-#: builtin/checkout.c:815
-msgid "Previous HEAD position was"
-msgstr "Tidigare position för HEAD var"
+#: builtin/commit.c:1384
+msgid "do not detect renames"
+msgstr "detektera inte namnändringar"
 
-#: builtin/checkout.c:843 builtin/checkout.c:1041
-msgid "You are on a branch yet to be born"
-msgstr "Du är på en gren som ännu inte är född"
+#: builtin/commit.c:1386
+msgid "detect renames, optionally set similarity index"
+msgstr "detektera namnändringar, möjligen sätt likhetsindex"
 
-#: builtin/checkout.c:947
-#, c-format
-msgid "only one reference expected, %d given."
-msgstr "endast en referens förväntades, %d gavs."
+#: builtin/commit.c:1406
+msgid "Unsupported combination of ignored and untracked-files arguments"
+msgstr "Kombinationen av argument för ignorerade och ospårade filer stöds ej"
 
-#: builtin/checkout.c:987 builtin/worktree.c:240 builtin/worktree.c:389
-#, c-format
-msgid "invalid reference: %s"
-msgstr "felaktig referens: %s"
+#: builtin/commit.c:1489
+msgid "suppress summary after successful commit"
+msgstr "undertryck sammanfattning efter framgångsrik incheckning"
 
-#: builtin/checkout.c:1016
-#, c-format
-msgid "reference is not a tree: %s"
-msgstr "referensen är inte ett träd: %s"
+#: builtin/commit.c:1490
+msgid "show diff in commit message template"
+msgstr "visa diff i mallen för incheckningsmeddelandet"
 
-#: builtin/checkout.c:1055
-msgid "paths cannot be used with switching branches"
-msgstr "sökvägar kan inte användas vid byte av gren"
+#: builtin/commit.c:1492
+msgid "Commit message options"
+msgstr "Alternativ för incheckningsmeddelande"
 
-#: builtin/checkout.c:1058 builtin/checkout.c:1062
-#, c-format
-msgid "'%s' cannot be used with switching branches"
-msgstr "\"%s\" kan inte användas vid byte av gren"
+#: builtin/commit.c:1493 builtin/merge.c:274 builtin/tag.c:414
+msgid "read message from file"
+msgstr "läs meddelande från fil"
 
-#: builtin/checkout.c:1066 builtin/checkout.c:1069 builtin/checkout.c:1074
-#: builtin/checkout.c:1077
-#, c-format
-msgid "'%s' cannot be used with '%s'"
-msgstr "\"%s\" kan inte användas med \"%s\""
+#: builtin/commit.c:1494
+msgid "author"
+msgstr "författare"
 
-#: builtin/checkout.c:1082
-#, c-format
-msgid "Cannot switch branch to a non-commit '%s'"
-msgstr "Kan inte växla gren till icke-incheckningen \"%s\""
+#: builtin/commit.c:1494
+msgid "override author for commit"
+msgstr "överstyr författare för incheckningen"
 
-#: builtin/checkout.c:1114 builtin/checkout.c:1116 builtin/clone.c:118
-#: builtin/remote.c:167 builtin/remote.c:169 builtin/worktree.c:433
-#: builtin/worktree.c:435
-msgid "branch"
-msgstr "gren"
+#: builtin/commit.c:1495 builtin/gc.c:538
+msgid "date"
+msgstr "datum"
 
-#: builtin/checkout.c:1115
-msgid "create and checkout a new branch"
-msgstr "skapa och checka ut en ny gren"
+#: builtin/commit.c:1495
+msgid "override date for commit"
+msgstr "överstyr datum för incheckningen"
 
-#: builtin/checkout.c:1117
-msgid "create/reset and checkout a branch"
-msgstr "skapa/nollställ och checka ut en gren"
+#: builtin/commit.c:1497 builtin/commit.c:1498 builtin/commit.c:1499
+#: builtin/commit.c:1500 parse-options.h:328 ref-filter.h:92
+msgid "commit"
+msgstr "incheckning"
+
+#: builtin/commit.c:1497
+msgid "reuse and edit message from specified commit"
+msgstr "återanvänd och redigera meddelande från angiven incheckning"
+
+#: builtin/commit.c:1498
+msgid "reuse message from specified commit"
+msgstr "återanvänd meddelande från angiven incheckning"
+
+#: builtin/commit.c:1499
+msgid "use autosquash formatted message to fixup specified commit"
+msgstr ""
+"använd autosquash-formaterat meddelande för att fixa angiven incheckning"
+
+#: builtin/commit.c:1500
+msgid "use autosquash formatted message to squash specified commit"
+msgstr ""
+"använd autosquash-formaterat meddelande för att slå ihop med angiven "
+"incheckning"
 
-#: builtin/checkout.c:1118
-msgid "create reflog for new branch"
-msgstr "skapa reflogg för ny gren"
+#: builtin/commit.c:1501
+msgid "the commit is authored by me now (used with -C/-c/--amend)"
+msgstr "jag är nu författare av incheckningen (används med -C/-c/--amend)"
 
-#: builtin/checkout.c:1119 builtin/worktree.c:437
-msgid "detach HEAD at named commit"
-msgstr "koppla från HEAD vid namngiven incheckning"
+#: builtin/commit.c:1502 builtin/log.c:1634 builtin/merge.c:289
+#: builtin/pull.c:164 builtin/revert.c:110
+msgid "add Signed-off-by:"
+msgstr "lägg till Signed-off-by:"
 
-#: builtin/checkout.c:1120
-msgid "set upstream info for new branch"
-msgstr "sätt uppströmsinformation för ny gren"
+#: builtin/commit.c:1503
+msgid "use specified template file"
+msgstr "använd angiven mallfil"
 
-#: builtin/checkout.c:1122
-msgid "new-branch"
-msgstr "ny-gren"
+#: builtin/commit.c:1504
+msgid "force edit of commit"
+msgstr "tvinga redigering av incheckning"
 
-#: builtin/checkout.c:1122
-msgid "new unparented branch"
-msgstr "ny gren utan förälder"
+#: builtin/commit.c:1506
+msgid "include status in commit message template"
+msgstr "inkludera status i mallen för incheckningsmeddelandet"
 
-#: builtin/checkout.c:1123
-msgid "checkout our version for unmerged files"
-msgstr "checka ut vår version för ej sammanslagna filer"
+#: builtin/commit.c:1511
+msgid "Commit contents options"
+msgstr "Alternativ för incheckningens innehåll"
 
-#: builtin/checkout.c:1125
-msgid "checkout their version for unmerged files"
-msgstr "checka ut deras version för ej sammanslagna filer"
+#: builtin/commit.c:1512
+msgid "commit all changed files"
+msgstr "checka in alla ändrade filer"
 
-#: builtin/checkout.c:1127
-msgid "force checkout (throw away local modifications)"
-msgstr "tvinga utcheckning (kasta bort lokala ändringar)"
+#: builtin/commit.c:1513
+msgid "add specified files to index for commit"
+msgstr "lägg till angivna filer till indexet för incheckning"
 
-#: builtin/checkout.c:1129
-msgid "perform a 3-way merge with the new branch"
-msgstr "utför en 3-vägssammanslagning för den nya grenen"
+#: builtin/commit.c:1514
+msgid "interactively add files"
+msgstr "lägg till filer interaktivt"
 
-#: builtin/checkout.c:1131 builtin/merge.c:241
-msgid "update ignored files (default)"
-msgstr "uppdatera ignorerade filer (standard)"
+#: builtin/commit.c:1515
+msgid "interactively add changes"
+msgstr "lägg till ändringar interaktivt"
 
-#: builtin/checkout.c:1133 builtin/log.c:1499 parse-options.h:264
-msgid "style"
-msgstr "stil"
+#: builtin/commit.c:1516
+msgid "commit only specified files"
+msgstr "checka endast in angivna filer"
 
-#: builtin/checkout.c:1134
-msgid "conflict style (merge or diff3)"
-msgstr "konfliktstil (merge eller diff3)"
+#: builtin/commit.c:1517
+msgid "bypass pre-commit and commit-msg hooks"
+msgstr "förbigå pre-commit- och commit-msg-krokar"
 
-#: builtin/checkout.c:1137
-msgid "do not limit pathspecs to sparse entries only"
-msgstr "begränsa inte sökvägar till endast glesa poster"
+#: builtin/commit.c:1518
+msgid "show what would be committed"
+msgstr "visa vad som skulle checkas in"
 
-#: builtin/checkout.c:1139
-msgid "second guess 'git checkout <no-such-branch>'"
-msgstr "förutspå \"git checkout <gren-saknas>\""
+#: builtin/commit.c:1531
+msgid "amend previous commit"
+msgstr "lägg till föregående incheckning"
 
-#: builtin/checkout.c:1141
-msgid "do not check if another worktree is holding the given ref"
-msgstr ""
-"kontrollera inte om en annan arbetskatalog håller den angivna referensen"
+#: builtin/commit.c:1532
+msgid "bypass post-rewrite hook"
+msgstr "förbigå post-rewrite-krok"
 
-#: builtin/checkout.c:1145 builtin/clone.c:85 builtin/fetch.c:149
-#: builtin/merge.c:238 builtin/pull.c:128 builtin/push.c:572
-#: builtin/send-pack.c:174
-msgid "force progress reporting"
-msgstr "tvinga förloppsrapportering"
+#: builtin/commit.c:1539
+msgid "ok to record an empty change"
+msgstr "ok att registrera en tom ändring"
 
-#: builtin/checkout.c:1175
-msgid "-b, -B and --orphan are mutually exclusive"
-msgstr "-b, -B och --orphan är ömsesidigt uteslutande"
+#: builtin/commit.c:1541
+msgid "ok to record a change with an empty message"
+msgstr "ok att registrera en ändring med tomt meddelande"
 
-#: builtin/checkout.c:1192
-msgid "--track needs a branch name"
-msgstr "--track behöver ett namn på en gren"
+#: builtin/commit.c:1614
+#, c-format
+msgid "Corrupt MERGE_HEAD file (%s)"
+msgstr "Trasig MERGE_HEAD-fil (%s)"
 
-#: builtin/checkout.c:1197
-msgid "Missing branch name; try -b"
-msgstr "Grennamn saknas; försök med -b"
+#: builtin/commit.c:1621
+msgid "could not read MERGE_MODE"
+msgstr "kunde inte läsa MERGE_MODE"
 
-#: builtin/checkout.c:1233
-msgid "invalid path specification"
-msgstr "felaktig sökvägsangivelse"
+#: builtin/commit.c:1640
+#, c-format
+msgid "could not read commit message: %s"
+msgstr "kunde inte läsa incheckningsmeddelande: %s"
 
-#: builtin/checkout.c:1240
+#: builtin/commit.c:1647
 #, c-format
-msgid "'%s' is not a commit and a branch '%s' cannot be created from it"
-msgstr "”%s” är inte en incheckning och grenen ”%s” kan inte skapas från den"
+msgid "Aborting commit due to empty commit message.\n"
+msgstr "Avbryter på grund av tomt incheckningsmeddelande.\n"
 
-#: builtin/checkout.c:1244
+#: builtin/commit.c:1652
 #, c-format
-msgid "git checkout: --detach does not take a path argument '%s'"
-msgstr "git checkout: --detach tar inte en sökväg som argument \"%s\""
+msgid "Aborting commit; you did not edit the message.\n"
+msgstr "Avbryter incheckning; meddelandet inte redigerat.\n"
 
-#: builtin/checkout.c:1248
+#: builtin/commit.c:1686
 msgid ""
-"git checkout: --ours/--theirs, --force and --merge are incompatible when\n"
-"checking out of the index."
+"repository has been updated, but unable to write\n"
+"new_index file. Check that disk is not full and quota is\n"
+"not exceeded, and then \"git restore --staged :/\" to recover."
 msgstr ""
-"git checkout: --ours/--theirs, --force och --merge är inkompatibla när\n"
-"du checkar ut från indexet."
+"arkivet har uppdaterats, men kunde inte skriva filen\n"
+"new_index. Kontrollera att disken inte är full och\n"
+"att kvoten inte har överskridits, och kör sedan\n"
+"\"git restore --staged :/\" för att återställa."
 
-#: builtin/clean.c:26
+#: builtin/commit-graph.c:11 builtin/commit-graph.c:17
 msgid ""
-"git clean [-d] [-f] [-i] [-n] [-q] [-e <pattern>] [-x | -X] [--] <paths>..."
+"git commit-graph verify [--object-dir <objdir>] [--shallow] [--[no-]progress]"
 msgstr ""
-"git clean [-d] [-f] [-i] [-n] [-q] [-e <mönster>] [-x | -X] [--] "
-"<sökvägar>..."
+"git commit-graph verify [--object-dir <objkat>] [--shallow] [--[no-]progress]"
 
-#: builtin/clean.c:30
-#, c-format
-msgid "Removing %s\n"
-msgstr "Tar bort %s\n"
+#: builtin/commit-graph.c:12 builtin/commit-graph.c:22
+msgid ""
+"git commit-graph write [--object-dir <objdir>] [--append|--split] [--"
+"reachable|--stdin-packs|--stdin-commits] [--[no-]progress] <split options>"
+msgstr ""
+"git commit-graph write [--object-dir <objkat>] [--append|--split] [--"
+"reachable|--stdin-packs|--stdin-commits] [--[no-]progress] <delnings-flaggor>"
 
-#: builtin/clean.c:31
-#, c-format
-msgid "Would remove %s\n"
-msgstr "Skulle ta bort %s\n"
+#: builtin/commit-graph.c:48 builtin/commit-graph.c:103
+#: builtin/commit-graph.c:187 builtin/fetch.c:179 builtin/log.c:1657
+msgid "dir"
+msgstr "kat"
 
-#: builtin/clean.c:32
-#, c-format
-msgid "Skipping repository %s\n"
-msgstr "Hoppar över arkivet %s\n"
+#: builtin/commit-graph.c:49 builtin/commit-graph.c:104
+#: builtin/commit-graph.c:188
+msgid "The object directory to store the graph"
+msgstr "Objektkatalogen där grafen skall lagras"
 
-#: builtin/clean.c:33
-#, c-format
-msgid "Would skip repository %s\n"
-msgstr "Skulle hoppa över arkivet %s\n"
+#: builtin/commit-graph.c:51
+msgid "if the commit-graph is split, only verify the tip file"
+msgstr "om inchecknignsgrafen är delad, kontrollera bara spetsfilen"
+
+#: builtin/commit-graph.c:73 t/helper/test-read-graph.c:23
+#, c-format
+msgid "Could not open commit-graph '%s'"
+msgstr "Kunde inte öppna incheckningsgrafen \"%s\""
+
+#: builtin/commit-graph.c:106
+msgid "start walk at all refs"
+msgstr "starta traversering vid alla referenser"
 
-#: builtin/clean.c:34
-#, c-format
-msgid "failed to remove %s"
-msgstr "misslyckades ta bort %s"
+#: builtin/commit-graph.c:108
+msgid "scan pack-indexes listed by stdin for commits"
+msgstr "sök paketindex listade på standard in efter incheckningar"
 
-#: builtin/clean.c:302 git-add--interactive.perl:579
-#, c-format
-msgid ""
-"Prompt help:\n"
-"1          - select a numbered item\n"
-"foo        - select item based on unique prefix\n"
-"           - (empty) select nothing\n"
-msgstr ""
-"Kommandohjälp:\n"
-"1          - markera en numrerad post\n"
-"foo        - markera post baserad på unikt prefix\n"
-"           - (tomt) markera ingenting\n"
+#: builtin/commit-graph.c:110
+msgid "start walk at commits listed by stdin"
+msgstr "börja gå genom incheckningar listade på standard in"
 
-#: builtin/clean.c:306 git-add--interactive.perl:588
-#, c-format
-msgid ""
-"Prompt help:\n"
-"1          - select a single item\n"
-"3-5        - select a range of items\n"
-"2-3,6-9    - select multiple ranges\n"
-"foo        - select item based on unique prefix\n"
-"-...       - unselect specified items\n"
-"*          - choose all items\n"
-"           - (empty) finish selecting\n"
+#: builtin/commit-graph.c:112
+msgid "include all commits already in the commit-graph file"
+msgstr "ta med alla incheckningar redan i filen commit-graph"
+
+#: builtin/commit-graph.c:115
+msgid "allow writing an incremental commit-graph file"
+msgstr "tillåt skriva en inkrementell incheckningsgraffil"
+
+#: builtin/commit-graph.c:117 builtin/commit-graph.c:121
+msgid "maximum number of commits in a non-base split commit-graph"
 msgstr ""
-"Kommandohjälp:\n"
-"1          - markera en ensam post\n"
-"3-5        - markera ett intervall med poster\n"
-"2-3,6-9    - markera flera intervall\n"
-"foo        - markera post baserad på unikt prefix\n"
-"-...       - avmarkera specifika poster\n"
-"*          - välj alla poster\n"
-"           - (tomt) avsluta markering\n"
+"maximalt antal incheckningar i en delad incheckingsgraf som inte är bad"
 
-#: builtin/clean.c:522 git-add--interactive.perl:554
-#: git-add--interactive.perl:559
-#, c-format, perl-format
-msgid "Huh (%s)?\n"
-msgstr "Vadå (%s)?\n"
+#: builtin/commit-graph.c:119
+msgid "maximum ratio between two levels of a split commit-graph"
+msgstr "maximalt förhållande mellan två nivåer av en delad incheckningsgraf"
 
-#: builtin/clean.c:664
-#, c-format
-msgid "Input ignore patterns>> "
-msgstr "Ange ignoreringsmönster>>"
+#: builtin/commit-graph.c:137
+msgid "use at most one of --reachable, --stdin-commits, or --stdin-packs"
+msgstr "använd som mest en av --reachable, --stdin-commit och --stdin-packs"
+
+#: builtin/config.c:11
+msgid "git config [<options>]"
+msgstr "git config [<flaggor>]"
 
-#: builtin/clean.c:701
+#: builtin/config.c:103 builtin/env--helper.c:23
 #, c-format
-msgid "WARNING: Cannot find items matched by: %s"
-msgstr "VARNING: Hittar inte poster som motsvarar: %s"
+msgid "unrecognized --type argument, %s"
+msgstr "okänt argument för --type, %s"
 
-#: builtin/clean.c:722
-msgid "Select items to delete"
-msgstr "Välj poster att ta bort"
+#: builtin/config.c:115
+msgid "only one type at a time"
+msgstr "endast en typ åt gången"
 
-#. TRANSLATORS: Make sure to keep [y/N] as is
-#: builtin/clean.c:763
-#, c-format
-msgid "Remove %s [y/N]? "
-msgstr "Ta bort %s [Y=ja / N=nej]? "
+#: builtin/config.c:124
+msgid "Config file location"
+msgstr "Konfigurationsfilens plats"
 
-#: builtin/clean.c:788 git-add--interactive.perl:1717
-#, c-format
-msgid "Bye.\n"
-msgstr "Hej då.\n"
+#: builtin/config.c:125
+msgid "use global config file"
+msgstr "använd global konfigurationsfil"
 
-#: builtin/clean.c:796
-msgid ""
-"clean               - start cleaning\n"
-"filter by pattern   - exclude items from deletion\n"
-"select by numbers   - select items to be deleted by numbers\n"
-"ask each            - confirm each deletion (like \"rm -i\")\n"
-"quit                - stop cleaning\n"
-"help                - this screen\n"
-"?                   - help for prompt selection"
-msgstr ""
-"clean               - börja städa\n"
-"filter by pattern   - uteslut poster från borttagning\n"
-"select by numbers   - markera poster som ska tas bort med siffror\n"
-"ask each            - bekräfta varje borttagning (som \"rm -i\")\n"
-"quit                - sluta städa\n"
-"help                - denna skärm\n"
-"?                   - hjälp för kommandoval"
+#: builtin/config.c:126
+msgid "use system config file"
+msgstr "använd systemets konfigurationsfil"
 
-#: builtin/clean.c:823 git-add--interactive.perl:1793
-msgid "*** Commands ***"
-msgstr "*** Kommandon ***"
+#: builtin/config.c:127
+msgid "use repository config file"
+msgstr "använd arkivets konfigurationsfil"
 
-#: builtin/clean.c:824 git-add--interactive.perl:1790
-msgid "What now"
-msgstr "Vad nu"
+#: builtin/config.c:128
+msgid "use per-worktree config file"
+msgstr "använd arbetskatalogens konfigurationsfil"
 
-#: builtin/clean.c:832
-msgid "Would remove the following item:"
-msgid_plural "Would remove the following items:"
-msgstr[0] "Skulle ta bort följande post:"
-msgstr[1] "Skulle ta bort följande poster:"
+#: builtin/config.c:129
+msgid "use given config file"
+msgstr "använd angiven konfigurationsfil"
 
-#: builtin/clean.c:848
-msgid "No more files to clean, exiting."
-msgstr "Inga fler filer att städa, avslutar."
+#: builtin/config.c:130
+msgid "blob-id"
+msgstr "blob-id"
 
-#: builtin/clean.c:910
-msgid "do not print names of files removed"
-msgstr "skriv inte ut namn på borttagna filer"
+#: builtin/config.c:130
+msgid "read config from given blob object"
+msgstr "läs konfiguration från givet blob-objekt"
 
-#: builtin/clean.c:912
-msgid "force"
-msgstr "tvinga"
+#: builtin/config.c:131
+msgid "Action"
+msgstr "Åtgärd"
 
-#: builtin/clean.c:913
-msgid "interactive cleaning"
-msgstr "städa interaktivt"
+#: builtin/config.c:132
+msgid "get value: name [value-regex]"
+msgstr "hämta värde: namn [värde-reguttr]"
 
-#: builtin/clean.c:915
-msgid "remove whole directories"
-msgstr "ta bort hela kataloger"
+#: builtin/config.c:133
+msgid "get all values: key [value-regex]"
+msgstr "hämta alla värden: nyckel [värde-reguttr]"
+
+#: builtin/config.c:134
+msgid "get values for regexp: name-regex [value-regex]"
+msgstr "hämta värden för reguttr: namn-reguttr [värde-reguttr]"
+
+#: builtin/config.c:135
+msgid "get value specific for the URL: section[.var] URL"
+msgstr "hämta värde specifikt URL:en: sektion[.var] URL"
 
-#: builtin/clean.c:916 builtin/describe.c:533 builtin/describe.c:535
-#: builtin/grep.c:871 builtin/log.c:157 builtin/log.c:159
-#: builtin/ls-files.c:548 builtin/name-rev.c:397 builtin/name-rev.c:399
-#: builtin/show-ref.c:176
-msgid "pattern"
-msgstr "mönster"
+#: builtin/config.c:136
+msgid "replace all matching variables: name value [value_regex]"
+msgstr "ersätt alla motsvarande variabler: namn värde [värde-reguttr]"
 
-#: builtin/clean.c:917
-msgid "add <pattern> to ignore rules"
-msgstr "lägg till <mönster> till ignoreringsregler"
+#: builtin/config.c:137
+msgid "add a new variable: name value"
+msgstr "lägg till en ny variabel: namn värde"
 
-#: builtin/clean.c:918
-msgid "remove ignored files, too"
-msgstr "ta även bort ignorerade filer"
+#: builtin/config.c:138
+msgid "remove a variable: name [value-regex]"
+msgstr "ta bort en variabel: namn [värde-reguttr]"
 
-#: builtin/clean.c:920
-msgid "remove only ignored files"
-msgstr "ta endast bort ignorerade filer"
+#: builtin/config.c:139
+msgid "remove all matches: name [value-regex]"
+msgstr "ta bort alla träffar: namn [värde-reguttr]"
 
-#: builtin/clean.c:938
-msgid "-x and -X cannot be used together"
-msgstr "-x och -X kan inte användas samtidigt"
+#: builtin/config.c:140
+msgid "rename section: old-name new-name"
+msgstr "byt namn på sektion: gammalt-namn nytt-namn"
 
-#: builtin/clean.c:942
-msgid ""
-"clean.requireForce set to true and neither -i, -n, nor -f given; refusing to "
-"clean"
-msgstr ""
-"clean.requireForce satt till true, men varken -i, -n eller -f angavs; vägrar "
-"städa"
+#: builtin/config.c:141
+msgid "remove a section: name"
+msgstr "ta bort en sektion: namn"
 
-#: builtin/clean.c:945
-msgid ""
-"clean.requireForce defaults to true and neither -i, -n, nor -f given; "
-"refusing to clean"
-msgstr ""
-"clean.requireForce har standardvärdet true och varken -i, -n eller -f "
-"angavs; vägrar städa"
+#: builtin/config.c:142
+msgid "list all"
+msgstr "visa alla"
 
-#: builtin/clone.c:42
-msgid "git clone [<options>] [--] <repo> [<dir>]"
-msgstr "git clone [<flaggor>] [--] <arkiv> [<kat>]"
+#: builtin/config.c:143
+msgid "open an editor"
+msgstr "öppna textredigeringsprogram"
 
-#: builtin/clone.c:87
-msgid "don't create a checkout"
-msgstr "skapa inte någon utcheckning"
+#: builtin/config.c:144
+msgid "find the color configured: slot [default]"
+msgstr "hitta den inställda färgen: slot [default]"
 
-#: builtin/clone.c:88 builtin/clone.c:90 builtin/init-db.c:479
-msgid "create a bare repository"
-msgstr "skapa ett naket (\"bare\") arkiv"
+#: builtin/config.c:145
+msgid "find the color setting: slot [stdout-is-tty]"
+msgstr "hitta färginställningen: slot [stdout-is-tty]"
 
-#: builtin/clone.c:92
-msgid "create a mirror repository (implies bare)"
-msgstr "skapa ett spegelarkiv (implicerar \"bare\")"
+#: builtin/config.c:146
+msgid "Type"
+msgstr "Typ"
 
-#: builtin/clone.c:94
-msgid "to clone from a local repository"
-msgstr "för att klona från ett lokalt arkiv"
+#: builtin/config.c:147 builtin/env--helper.c:38
+msgid "value is given this type"
+msgstr "värdet har givits denna typ"
 
-#: builtin/clone.c:96
-msgid "don't use local hardlinks, always copy"
-msgstr "skapa inte lokala hårda länkar, kopiera alltid"
+#: builtin/config.c:148
+msgid "value is \"true\" or \"false\""
+msgstr "värdet är \"true\" eller \"false\""
 
-#: builtin/clone.c:98
-msgid "setup as shared repository"
-msgstr "skapa som ett delat arkiv"
+#: builtin/config.c:149
+msgid "value is decimal number"
+msgstr "värdet är ett decimalt tal"
 
-#: builtin/clone.c:100 builtin/clone.c:104
-msgid "pathspec"
-msgstr "sökvägsangivelse"
+#: builtin/config.c:150
+msgid "value is --bool or --int"
+msgstr "värdet är --bool eller --int"
 
-#: builtin/clone.c:100 builtin/clone.c:104
-msgid "initialize submodules in the clone"
-msgstr "initiera undermoduler i klonen"
+#: builtin/config.c:151
+msgid "value is a path (file or directory name)"
+msgstr "värdet är en sökväg (fil- eller katalognamn)"
 
-#: builtin/clone.c:107
-msgid "number of submodules cloned in parallel"
-msgstr "antal undermoduler som klonas parallellt"
+#: builtin/config.c:152
+msgid "value is an expiry date"
+msgstr "värdet är ett utgångsdatum"
 
-#: builtin/clone.c:108 builtin/init-db.c:476
-msgid "template-directory"
-msgstr "mallkatalog"
+#: builtin/config.c:153
+msgid "Other"
+msgstr "Andra"
 
-#: builtin/clone.c:109 builtin/init-db.c:477
-msgid "directory from which templates will be used"
-msgstr "katalog att använda mallar från"
+#: builtin/config.c:154
+msgid "terminate values with NUL byte"
+msgstr "terminera värden med NUL-byte"
 
-#: builtin/clone.c:111 builtin/clone.c:113 builtin/submodule--helper.c:1223
-#: builtin/submodule--helper.c:1594
-msgid "reference repository"
-msgstr "referensarkiv"
+#: builtin/config.c:155
+msgid "show variable names only"
+msgstr "visa endast variabelnamn"
 
-#: builtin/clone.c:115 builtin/submodule--helper.c:1225
-#: builtin/submodule--helper.c:1596
-msgid "use --reference only while cloning"
-msgstr "använd --reference endast under kloningen"
+#: builtin/config.c:156
+msgid "respect include directives on lookup"
+msgstr "respektera inkluderingsdirektiv vid uppslag"
 
-#: builtin/clone.c:116 builtin/column.c:27 builtin/merge-file.c:44
-#: builtin/pack-objects.c:3166 builtin/repack.c:213
-msgid "name"
-msgstr "namn"
+#: builtin/config.c:157
+msgid "show origin of config (file, standard input, blob, command line)"
+msgstr "visa konfigurationskälla (fil, standard in, blob, kommandorad)"
 
-#: builtin/clone.c:117
-msgid "use <name> instead of 'origin' to track upstream"
-msgstr "använd <namn> istället för \"origin\" för att spåra uppströms"
+#: builtin/config.c:158 builtin/env--helper.c:40
+msgid "value"
+msgstr "värde"
 
-#: builtin/clone.c:119
-msgid "checkout <branch> instead of the remote's HEAD"
-msgstr "checka ut <gren> istället för fjärrens HEAD"
+#: builtin/config.c:158
+msgid "with --get, use default value when missing entry"
+msgstr "med --get, använd standardvärde vid saknad post"
 
-#: builtin/clone.c:121
-msgid "path to git-upload-pack on the remote"
-msgstr "sökväg till git-upload-pack på fjärren"
+#: builtin/config.c:172
+#, c-format
+msgid "wrong number of arguments, should be %d"
+msgstr "fel antal argument, skulle vara %d"
 
-#: builtin/clone.c:122 builtin/fetch.c:150 builtin/grep.c:813
-#: builtin/pull.c:216
-msgid "depth"
-msgstr "djup"
+#: builtin/config.c:174
+#, c-format
+msgid "wrong number of arguments, should be from %d to %d"
+msgstr "fel antal argument, skulle vara från %d till %d"
 
-#: builtin/clone.c:123
-msgid "create a shallow clone of that depth"
-msgstr "skapa en grund klon på detta djup"
+#: builtin/config.c:308
+#, c-format
+msgid "invalid key pattern: %s"
+msgstr "felaktigt nyckelmönster: %s"
 
-#: builtin/clone.c:124 builtin/fetch.c:152 builtin/pack-objects.c:3157
-#: parse-options.h:154
-msgid "time"
-msgstr "tid"
+#: builtin/config.c:344
+#, c-format
+msgid "failed to format default config value: %s"
+msgstr "misslyckades formatera standardkonfigurationsvärde: %s"
 
-#: builtin/clone.c:125
-msgid "create a shallow clone since a specific time"
-msgstr "skapa en grund klon från en angiven tidpunkt"
+#: builtin/config.c:401
+#, c-format
+msgid "cannot parse color '%s'"
+msgstr "kan inte tolka färgen \"%s\""
 
-#: builtin/clone.c:126 builtin/fetch.c:154
-msgid "revision"
-msgstr "revision"
+#: builtin/config.c:443
+msgid "unable to parse default color value"
+msgstr "kan inte tolka standardfärgvärde"
 
-#: builtin/clone.c:127 builtin/fetch.c:155
-msgid "deepen history of shallow clone, excluding rev"
-msgstr "fördjupa historik för grund klon, exkludera revisionen"
+#: builtin/config.c:496 builtin/config.c:742
+msgid "not in a git directory"
+msgstr "inte i en git-katalog"
+
+#: builtin/config.c:499
+msgid "writing to stdin is not supported"
+msgstr "skriva till standard in stöds inte"
+
+#: builtin/config.c:502
+msgid "writing config blobs is not supported"
+msgstr "skriva konfigurations-blobbar stöds inte"
 
-#: builtin/clone.c:129
-msgid "clone only one branch, HEAD or --branch"
-msgstr "klona endast en gren, HEAD eller --branch"
+#: builtin/config.c:587
+#, c-format
+msgid ""
+"# This is Git's per-user configuration file.\n"
+"[user]\n"
+"# Please adapt and uncomment the following lines:\n"
+"#\tname = %s\n"
+"#\temail = %s\n"
+msgstr ""
+"# Detta är Gits användarspecifika konfigurationsfil\n"
+"[user]\n"
+"# Justera och ta bort kommenteringsmärket från följande rader:\n"
+"#\tname = %s\n"
+"#\temail = %s\n"
 
-#: builtin/clone.c:131
-msgid "don't clone any tags, and make later fetches not to follow them"
-msgstr "klona inga taggar och gör att senare hämtningar inte följer dem"
+#: builtin/config.c:611
+msgid "only one config file at a time"
+msgstr "endast en konfigurationsfil åt gången"
 
-#: builtin/clone.c:133
-msgid "any cloned submodules will be shallow"
-msgstr "klonade undermoduler kommer vara grunda"
+#: builtin/config.c:616
+msgid "--local can only be used inside a git repository"
+msgstr "--local kan bara användas inuti ett git-arkiv"
 
-#: builtin/clone.c:134 builtin/init-db.c:485
-msgid "gitdir"
-msgstr "gitkat"
+#: builtin/config.c:619
+msgid "--blob can only be used inside a git repository"
+msgstr "--blob kan bara användas inuti ett git-arkiv"
 
-#: builtin/clone.c:135 builtin/init-db.c:486
-msgid "separate git dir from working tree"
-msgstr "separera gitkatalogen från arbetskatalogen"
+#: builtin/config.c:638
+msgid "$HOME not set"
+msgstr "$HOME inte satt"
 
-#: builtin/clone.c:136
-msgid "key=value"
-msgstr "nyckel=värde"
+#: builtin/config.c:658
+msgid ""
+"--worktree cannot be used with multiple working trees unless the config\n"
+"extension worktreeConfig is enabled. Please read \"CONFIGURATION FILE\"\n"
+"section in \"git help worktree\" for details"
+msgstr ""
+"--worktree kan inte användas med flera arbetskataloger om inte\n"
+"konfigurationsutöknignen worktreeConfig har aktiverats. Läsa stycket\n"
+"\"KONFIGURATIONSFIL\" i \"git help worktree\" för detaljer"
 
-#: builtin/clone.c:137
-msgid "set config inside the new repository"
-msgstr "ställ in konfiguration i det nya arkivet"
+#: builtin/config.c:688
+msgid "--get-color and variable type are incoherent"
+msgstr "--get-color och variabeltyp stämmer inte överens"
 
-#: builtin/clone.c:138 builtin/fetch.c:173 builtin/pull.c:229
-#: builtin/push.c:583
-msgid "use IPv4 addresses only"
-msgstr "använd endast IPv4-adresser"
+#: builtin/config.c:693
+msgid "only one action at a time"
+msgstr "endast en åtgärd åt gången"
 
-#: builtin/clone.c:140 builtin/fetch.c:175 builtin/pull.c:232
-#: builtin/push.c:585
-msgid "use IPv6 addresses only"
-msgstr "använd endast IPv6-adresser"
+#: builtin/config.c:706
+msgid "--name-only is only applicable to --list or --get-regexp"
+msgstr "--name-only gäller bara för --list eller --get-regexp"
 
-#: builtin/clone.c:278
+#: builtin/config.c:712
 msgid ""
-"No directory name could be guessed.\n"
-"Please specify a directory on the command line"
+"--show-origin is only applicable to --get, --get-all, --get-regexp, and --"
+"list"
 msgstr ""
-"Kunde inte gissa katalognamn.\n"
-"Ange en katalog på kommandoraden"
+"--show-origin gäller bara för --get, --get-all, --get-regexp och --list"
 
-#: builtin/clone.c:331
-#, c-format
-msgid "info: Could not add alternate for '%s': %s\n"
-msgstr "info: Kan inte skapa alternativ för \"%s\": %s\n"
+#: builtin/config.c:718
+msgid "--default is only applicable to --get"
+msgstr "--default gäller bara för --get"
 
-#: builtin/clone.c:403
+#: builtin/config.c:731
 #, c-format
-msgid "failed to open '%s'"
-msgstr "misslyckades öppna \"%s\""
+msgid "unable to read config file '%s'"
+msgstr "kan inte konfigurationsfil \"%s\""
 
-#: builtin/clone.c:411
-#, c-format
-msgid "%s exists and is not a directory"
-msgstr "%s finns och är ingen katalog"
+#: builtin/config.c:734
+msgid "error processing config file(s)"
+msgstr "fel vid hantering av konfigurationsfil(er)"
 
-#: builtin/clone.c:425
-#, c-format
-msgid "failed to stat %s\n"
-msgstr "misslyckades ta status på %s\n"
+#: builtin/config.c:744
+msgid "editing stdin is not supported"
+msgstr "redigering av standard in stöds ej"
 
-#: builtin/clone.c:447
-#, c-format
-msgid "failed to create link '%s'"
-msgstr "misslyckades skapa länken \"%s\""
+#: builtin/config.c:746
+msgid "editing blobs is not supported"
+msgstr "redigering av blobbar stöds ej"
 
-#: builtin/clone.c:451
+#: builtin/config.c:760
 #, c-format
-msgid "failed to copy file to '%s'"
-msgstr "misslyckades kopiera filen till \"%s\""
+msgid "cannot create configuration file %s"
+msgstr "kan inte skapa konfigurationsfilen \"%s\""
 
-#: builtin/clone.c:477
+#: builtin/config.c:773
 #, c-format
-msgid "done.\n"
-msgstr "klart.\n"
-
-#: builtin/clone.c:491
 msgid ""
-"Clone succeeded, but checkout failed.\n"
-"You can inspect what was checked out with 'git status'\n"
-"and retry the checkout with 'git checkout -f HEAD'\n"
+"cannot overwrite multiple values with a single value\n"
+"       Use a regexp, --add or --replace-all to change %s."
 msgstr ""
-"Klonen lyckades, men utcheckningen misslyckades.\n"
-"Du kan inspektera det som checkades ut med \"git status\"\n"
-"och försöka checka ut igen med \"git checkout -f HEAD\"\n"
-
-#: builtin/clone.c:568
-#, c-format
-msgid "Could not find remote branch %s to clone."
-msgstr "Kunde inte hitta fjärrgrenen %s för att klona."
-
-#: builtin/clone.c:663
-msgid "remote did not send all necessary objects"
-msgstr "fjärren sände inte alla nödvändiga objekt"
+"kan inte skriva över flera värden med ett ensamt värde\n"
+"       Använd en regexp, --add eller --replace-all för att ändra %s."
 
-#: builtin/clone.c:679
+#: builtin/config.c:847 builtin/config.c:858
 #, c-format
-msgid "unable to update %s"
-msgstr "kan inte uppdatera %s"
-
-#: builtin/clone.c:728
-msgid "remote HEAD refers to nonexistent ref, unable to checkout.\n"
-msgstr ""
-"HEAD hos fjärren pekar på en obefintlig referens, kan inte checka ut.\n"
+msgid "no such section: %s"
+msgstr "ingen sådan sektion: %s"
 
-#: builtin/clone.c:758
-msgid "unable to checkout working tree"
-msgstr "kunde inte checka ut arbetskatalogen"
-
-#: builtin/clone.c:803
-msgid "unable to write parameters to config file"
-msgstr "kunde inte skriva parametrar till konfigurationsfilen"
+#: builtin/count-objects.c:90
+msgid "git count-objects [-v] [-H | --human-readable]"
+msgstr "git count-objects [-v] [-H | --human-readable]"
 
-#: builtin/clone.c:866
-msgid "cannot repack to clean up"
-msgstr "kan inte packa om för att städa upp"
+#: builtin/count-objects.c:100
+msgid "print sizes in human readable format"
+msgstr "skriv storlekar i människoläsbart format"
 
-#: builtin/clone.c:868
-msgid "cannot unlink temporary alternates file"
-msgstr "kunde inte ta bort temporär \"alternates\"-fil"
+#: builtin/describe.c:26
+msgid "git describe [<options>] [<commit-ish>...]"
+msgstr "git describe [<flaggor>] [<incheckning-igt>...]"
 
-#: builtin/clone.c:907 builtin/receive-pack.c:1947
-msgid "Too many arguments."
-msgstr "För många argument."
+#: builtin/describe.c:27
+msgid "git describe [<options>] --dirty"
+msgstr "git describe [<flaggor>] --dirty"
 
-#: builtin/clone.c:911
-msgid "You must specify a repository to clone."
-msgstr "Du måste ange ett arkiv att klona."
+#: builtin/describe.c:62
+msgid "head"
+msgstr "huvud"
 
-#: builtin/clone.c:924
-#, c-format
-msgid "--bare and --origin %s options are incompatible."
-msgstr "flaggorna --bare och --origin %s är inkompatibla."
+#: builtin/describe.c:62
+msgid "lightweight"
+msgstr "lättviktig"
 
-#: builtin/clone.c:927
-msgid "--bare and --separate-git-dir are incompatible."
-msgstr "flaggorna --bare och --separate-git-dir är inkompatibla."
+#: builtin/describe.c:62
+msgid "annotated"
+msgstr "annoterad"
 
-#: builtin/clone.c:940
+#: builtin/describe.c:275
 #, c-format
-msgid "repository '%s' does not exist"
-msgstr "arkivet \"%s\" finns inte"
+msgid "annotated tag %s not available"
+msgstr "den annoterade taggen %s inte tillgänglig"
 
-#: builtin/clone.c:946 builtin/fetch.c:1460
+#: builtin/describe.c:279
 #, c-format
-msgid "depth %s is not a positive number"
-msgstr "djupet %s är inte ett positivt tal"
+msgid "annotated tag %s has no embedded name"
+msgstr "den annoterade taggen %s har inget inbäddat namn"
 
-#: builtin/clone.c:956
+#: builtin/describe.c:281
 #, c-format
-msgid "destination path '%s' already exists and is not an empty directory."
-msgstr "destinationssökvägen \"%s\" finns redan och är inte en tom katalog."
+msgid "tag '%s' is really '%s' here"
+msgstr "taggen \"%s\" är i verkligheten \"%s\" här"
 
-#: builtin/clone.c:966
+#: builtin/describe.c:325
 #, c-format
-msgid "working tree '%s' already exists."
-msgstr "arbetsträdet \"%s\" finns redan."
+msgid "no tag exactly matches '%s'"
+msgstr "ingen tagg motsvarar \"%s\" exakt"
 
-#: builtin/clone.c:981 builtin/clone.c:1002 builtin/difftool.c:270
-#: builtin/worktree.c:246 builtin/worktree.c:276
+#: builtin/describe.c:327
 #, c-format
-msgid "could not create leading directories of '%s'"
-msgstr "kunde inte skapa inledande kataloger för \"%s\""
+msgid "No exact match on refs or tags, searching to describe\n"
+msgstr ""
+"Ingen exakt träff mot referenser eller taggar, söker för att beskriva\n"
 
-#: builtin/clone.c:986
+#: builtin/describe.c:381
 #, c-format
-msgid "could not create work tree dir '%s'"
-msgstr "kunde inte skapa arbetskatalogen \"%s\""
+msgid "finished search at %s\n"
+msgstr "avslutade sökning på %s\n"
 
-#: builtin/clone.c:1006
+#: builtin/describe.c:407
 #, c-format
-msgid "Cloning into bare repository '%s'...\n"
-msgstr "Klonar till ett naket arkiv \"%s\"...\n"
+msgid ""
+"No annotated tags can describe '%s'.\n"
+"However, there were unannotated tags: try --tags."
+msgstr ""
+"Inga annoterade taggar kan beskriva \"%s\".\n"
+"Det finns dock oannoterade taggar: testa --tags."
 
-#: builtin/clone.c:1008
+#: builtin/describe.c:411
 #, c-format
-msgid "Cloning into '%s'...\n"
-msgstr "Klonar till \"%s\"...\n"
-
-#: builtin/clone.c:1032
 msgid ""
-"clone --recursive is not compatible with both --reference and --reference-if-"
-"able"
+"No tags can describe '%s'.\n"
+"Try --always, or create some tags."
 msgstr ""
-"clone --recursive är inte kompatibel med --reference och --reference-if-able"
-
-#: builtin/clone.c:1093
-msgid "--depth is ignored in local clones; use file:// instead."
-msgstr "--depth ignoreras i lokala kloningar; använd file:// istället."
+"Inga taggar kan beskriva \"%s\".\n"
+"Testa --always, eller skapa några taggar."
 
-#: builtin/clone.c:1095
-msgid "--shallow-since is ignored in local clones; use file:// instead."
-msgstr "--shallow-since ignoreras i lokala kloningar; använd file:// istället."
+#: builtin/describe.c:441
+#, c-format
+msgid "traversed %lu commits\n"
+msgstr "traverserade %lu incheckningar\n"
 
-#: builtin/clone.c:1097
-msgid "--shallow-exclude is ignored in local clones; use file:// instead."
+#: builtin/describe.c:444
+#, c-format
+msgid ""
+"more than %i tags found; listed %i most recent\n"
+"gave up search at %s\n"
 msgstr ""
-"--shallow-exclude ignoreras i lokala kloningar; använd file:// istället."
-
-#: builtin/clone.c:1099
-msgid "--filter is ignored in local clones; use file:// instead."
-msgstr "--filter ignoreras i lokala kloningar; använd file:// istället."
+"mer än %i taggar hittades; listar de %i senaste\n"
+"gav upp sökningen vid %s\n"
 
-#: builtin/clone.c:1102
-msgid "source repository is shallow, ignoring --local"
-msgstr "källarkivet är grunt, ignorerar --local"
+#: builtin/describe.c:512
+#, c-format
+msgid "describe %s\n"
+msgstr "beskriva %s\n"
 
-#: builtin/clone.c:1107
-msgid "--local is ignored"
-msgstr "--local ignoreras"
+#: builtin/describe.c:515
+#, c-format
+msgid "Not a valid object name %s"
+msgstr "Objektnamnet är inte giltigt: %s"
 
-#: builtin/clone.c:1169 builtin/clone.c:1177
+#: builtin/describe.c:523
 #, c-format
-msgid "Remote branch %s not found in upstream %s"
-msgstr "Fjärrgrenen %s hittades inte i uppströmsarkivet %s"
+msgid "%s is neither a commit nor blob"
+msgstr "%s är varken incheckning eller blob"
 
-#: builtin/clone.c:1180
-msgid "You appear to have cloned an empty repository."
-msgstr "Du verkar ha klonat ett tomt arkiv."
+#: builtin/describe.c:537
+msgid "find the tag that comes after the commit"
+msgstr "hitta taggen som kommer efter incheckningen"
 
-#: builtin/column.c:10
-msgid "git column [<options>]"
-msgstr "git column [<flaggor>]"
+#: builtin/describe.c:538
+msgid "debug search strategy on stderr"
+msgstr "felsök sökstrategin på standard fel"
 
-#: builtin/column.c:27
-msgid "lookup config vars"
-msgstr "slå upp konfigurationsvariabler"
+#: builtin/describe.c:539
+msgid "use any ref"
+msgstr "använd alla referenser"
 
-#: builtin/column.c:28 builtin/column.c:29
-msgid "layout to use"
-msgstr "utseende att använda"
+#: builtin/describe.c:540
+msgid "use any tag, even unannotated"
+msgstr "använd alla taggar, även oannoterade"
 
-#: builtin/column.c:30
-msgid "Maximum width"
-msgstr "Maximal bredd"
+#: builtin/describe.c:541
+msgid "always use long format"
+msgstr "använd alltid långt format"
 
-#: builtin/column.c:31
-msgid "Padding space on left border"
-msgstr "Spaltfyllnad i vänsterkanten"
+#: builtin/describe.c:542
+msgid "only follow first parent"
+msgstr "följ endast första föräldern"
 
-#: builtin/column.c:32
-msgid "Padding space on right border"
-msgstr "Spaltfyllnad i högerkanten"
+#: builtin/describe.c:545
+msgid "only output exact matches"
+msgstr "skriv endast ut exakta träffar"
 
-#: builtin/column.c:33
-msgid "Padding space between columns"
-msgstr "Spaltfyllnad mellan spalter"
+#: builtin/describe.c:547
+msgid "consider <n> most recent tags (default: 10)"
+msgstr "överväg de <n> nyaste taggarna (standard: 10)"
 
-#: builtin/column.c:51
-msgid "--command must be the first argument"
-msgstr "--command måste vara första argument"
+#: builtin/describe.c:549
+msgid "only consider tags matching <pattern>"
+msgstr "överväg endast taggar som motsvarar <mönster>"
 
-#: builtin/commit.c:37
-msgid "git commit [<options>] [--] <pathspec>..."
-msgstr "git commit [<flaggor>] [--] <sökväg>..."
+#: builtin/describe.c:551
+msgid "do not consider tags matching <pattern>"
+msgstr "överväg inte taggar som motsvarar <mönster>"
 
-#: builtin/commit.c:42
-msgid "git status [<options>] [--] <pathspec>..."
-msgstr "git status [<flaggor>] [--] <sökväg>..."
+#: builtin/describe.c:553 builtin/name-rev.c:473
+msgid "show abbreviated commit object as fallback"
+msgstr "visa förkortade incheckningsobjekt som standard"
 
-#: builtin/commit.c:47
-msgid ""
-"You asked to amend the most recent commit, but doing so would make\n"
-"it empty. You can repeat your command with --allow-empty, or you can\n"
-"remove the commit entirely with \"git reset HEAD^\".\n"
-msgstr ""
-"Du bad om att utöka den senaste incheckningen, men om du gör det\n"
-"blir den tom. Du kan köra kommandot på nytt med --allow-empty, eller\n"
-"så kan du ta bort incheckningen helt med \"git reset HEAD^\".\n"
+#: builtin/describe.c:554 builtin/describe.c:557
+msgid "mark"
+msgstr "märke"
 
-#: builtin/commit.c:52
-msgid ""
-"The previous cherry-pick is now empty, possibly due to conflict resolution.\n"
-"If you wish to commit it anyway, use:\n"
-"\n"
-"    git commit --allow-empty\n"
-"\n"
-msgstr ""
-"Den tidigare \"cherry-pick\":en är nu tom, kanske på grund av en löst\n"
-"konflikt. Om du vill checka in den ändå använder du:\n"
-"\n"
-"    git commit --allow-empty\n"
-"\n"
+#: builtin/describe.c:555
+msgid "append <mark> on dirty working tree (default: \"-dirty\")"
+msgstr "lägg till <märke> på lortigt arbetsträd (standard: \"-dirty\")"
 
-#: builtin/commit.c:59
-msgid "Otherwise, please use 'git reset'\n"
-msgstr "Använd annars \"git reset\"\n"
+#: builtin/describe.c:558
+msgid "append <mark> on broken working tree (default: \"-broken\")"
+msgstr "lägg till <märke> på trasigt arbetsträd (standard: \"-broken\")"
 
-#: builtin/commit.c:62
-msgid ""
-"If you wish to skip this commit, use:\n"
-"\n"
-"    git reset\n"
-"\n"
-"Then \"git cherry-pick --continue\" will resume cherry-picking\n"
-"the remaining commits.\n"
-msgstr ""
-"Om du vill hoppa över incheckningen, använd:\n"
-"\n"
-"    git reset\n"
-"\n"
-"\"git cherry-pick --continue\" kommer därefter att återuppta\n"
-"cherry-pick för återstående incheckningar.\n"
+#: builtin/describe.c:576
+msgid "--long is incompatible with --abbrev=0"
+msgstr "--long är inkompatibel med --abbrev=0"
 
-#: builtin/commit.c:293
-msgid "failed to unpack HEAD tree object"
-msgstr "misslyckades packa upp HEAD:s trädobjekt"
+#: builtin/describe.c:605
+msgid "No names found, cannot describe anything."
+msgstr "Inga namn hittades, kan inte beskriva något."
 
-#: builtin/commit.c:334
-msgid "unable to create temporary index"
-msgstr "kunde inte skapa temporär indexfil"
+#: builtin/describe.c:656
+msgid "--dirty is incompatible with commit-ishes"
+msgstr "--dirty är inkompatibelt med \"commit-ish\"-värden"
 
-#: builtin/commit.c:340
-msgid "interactive add failed"
-msgstr "interaktiv tilläggning misslyckades"
+#: builtin/describe.c:658
+msgid "--broken is incompatible with commit-ishes"
+msgstr "--broken är inkompatibelt med \"commit-ish\"-värden"
 
-#: builtin/commit.c:353
-msgid "unable to update temporary index"
-msgstr "kan inte uppdatera temporärt index"
+#: builtin/diff.c:84
+#, c-format
+msgid "'%s': not a regular file or symlink"
+msgstr "\"%s\": inte en normal fil eller symbolisk länk"
 
-#: builtin/commit.c:355
-msgid "Failed to update main cache tree"
-msgstr "Misslyckades uppdatera huvud-cacheträdet"
+#: builtin/diff.c:235
+#, c-format
+msgid "invalid option: %s"
+msgstr "ogiltig flagga: %s"
 
-#: builtin/commit.c:380 builtin/commit.c:403 builtin/commit.c:449
-msgid "unable to write new_index file"
-msgstr "kunde inte skriva filen new_index"
+#: builtin/diff.c:350
+msgid "Not a git repository"
+msgstr "Inte ett git-arkiv"
 
-#: builtin/commit.c:432
-msgid "cannot do a partial commit during a merge."
-msgstr "kan inte utföra en delvis incheckning under en sammanslagning."
+#: builtin/diff.c:394
+#, c-format
+msgid "invalid object '%s' given."
+msgstr "objektet \"%s\" som angavs är felaktigt."
 
-#: builtin/commit.c:434
-msgid "cannot do a partial commit during a cherry-pick."
-msgstr "kan inte utföra en delvis incheckning under en cherry-pick."
+#: builtin/diff.c:403
+#, c-format
+msgid "more than two blobs given: '%s'"
+msgstr "mer än två blobbar angavs: \"%s\""
 
-#: builtin/commit.c:442
-msgid "cannot read the index"
-msgstr "kan inte läsa indexet"
+#: builtin/diff.c:408
+#, c-format
+msgid "unhandled object '%s' given."
+msgstr "ej hanterat objekt \"%s\" angavs."
 
-#: builtin/commit.c:461
-msgid "unable to write temporary index file"
-msgstr "kunde inte skriva temporär indexfil"
+#: builtin/difftool.c:30
+msgid "git difftool [<options>] [<commit> [<commit>]] [--] [<path>...]"
+msgstr ""
+"git difftool [<flaggor>] [<incheckning> [<incheckning>]] [--] [<sökväg>...]"
 
-#: builtin/commit.c:558
+#: builtin/difftool.c:260
 #, c-format
-msgid "commit '%s' lacks author header"
-msgstr "incheckningen \"%s\" saknar författarhuvud"
+msgid "failed: %d"
+msgstr "misslyckades: %d"
 
-#: builtin/commit.c:560
+#: builtin/difftool.c:302
 #, c-format
-msgid "commit '%s' has malformed author line"
-msgstr "incheckningen \"%s\" har felformaterat författarhuvud"
+msgid "could not read symlink %s"
+msgstr "kunde inte läsa symboliska länken %s"
 
-#: builtin/commit.c:579
-msgid "malformed --author parameter"
-msgstr "felformad \"--author\"-flagga"
+#: builtin/difftool.c:304
+#, c-format
+msgid "could not read symlink file %s"
+msgstr "kunde inte läsa symbolisk länk-fil %s"
+
+#: builtin/difftool.c:312
+#, c-format
+msgid "could not read object %s for symlink %s"
+msgstr "kunde inte läsa objektet %s för symboliska länken %s"
 
-#: builtin/commit.c:631
+#: builtin/difftool.c:413
 msgid ""
-"unable to select a comment character that is not used\n"
-"in the current commit message"
+"combined diff formats('-c' and '--cc') are not supported in\n"
+"directory diff mode('-d' and '--dir-diff')."
 msgstr ""
-"kunde inte välja ett kommentarstecken som inte använts\n"
-"i det befintliga incheckningsmeddelandet"
+"kombinerade diff-format (\"-c\" och \"--cc\") stöds inte i\n"
+"katalogdiffläge (\"-d\" och \"--dir-diff\")."
+
+#: builtin/difftool.c:634
+#, c-format
+msgid "both files modified: '%s' and '%s'."
+msgstr "bägge filerna ändrade: \"%s\" och \"%s\"."
+
+#: builtin/difftool.c:636
+msgid "working tree file has been left."
+msgstr "filen i arbetskatalogen lämnades kvar."
 
-#: builtin/commit.c:668 builtin/commit.c:701 builtin/commit.c:1029
+#: builtin/difftool.c:647
 #, c-format
-msgid "could not lookup commit %s"
-msgstr "kunde inte slå upp incheckningen %s"
+msgid "temporary files exist in '%s'."
+msgstr "temporära filer finns i \"%s\"."
 
-#: builtin/commit.c:680 builtin/shortlog.c:316
-#, c-format
-msgid "(reading log message from standard input)\n"
-msgstr "(läser loggmeddelande från standard in)\n"
+#: builtin/difftool.c:648
+msgid "you may want to cleanup or recover these."
+msgstr "du kanske vill städa eller rädda dem."
 
-#: builtin/commit.c:682
-msgid "could not read log from standard input"
-msgstr "kunde inte läsa logg från standard in"
+#: builtin/difftool.c:697
+msgid "use `diff.guitool` instead of `diff.tool`"
+msgstr "använd \"diff.guitool\" istället för \"diff.tool\""
 
-#: builtin/commit.c:686
-#, c-format
-msgid "could not read log file '%s'"
-msgstr "kunde inte läsa loggfilen \"%s\""
+#: builtin/difftool.c:699
+msgid "perform a full-directory diff"
+msgstr "utför diff för hela katalogen"
 
-#: builtin/commit.c:715 builtin/commit.c:723
-msgid "could not read SQUASH_MSG"
-msgstr "kunde inte läsa SQUASH_MSG"
+#: builtin/difftool.c:701
+msgid "do not prompt before launching a diff tool"
+msgstr "fråga inte vid start av diff-verktyg"
 
-#: builtin/commit.c:720
-msgid "could not read MERGE_MSG"
-msgstr "kunde inte läsa MERGE_MSG"
+#: builtin/difftool.c:706
+msgid "use symlinks in dir-diff mode"
+msgstr "använd symboliska länkar i katalogdiffläge"
 
-#: builtin/commit.c:774
-msgid "could not write commit template"
-msgstr "kunde inte skriva incheckningsmall"
+#: builtin/difftool.c:707
+msgid "tool"
+msgstr "verktyg"
 
-#: builtin/commit.c:792
-#, c-format
-msgid ""
-"\n"
-"It looks like you may be committing a merge.\n"
-"If this is not correct, please remove the file\n"
-"\t%s\n"
-"and try again.\n"
-msgstr ""
-"\n"
-"Det verkar som du checkar in en sammanslagning.\n"
-"Om det inte stämmer tar du bort filen\n"
-"\t%s\n"
-"och försöker igen.\n"
+#: builtin/difftool.c:708
+msgid "use the specified diff tool"
+msgstr "använd angivet diff-verktyg"
 
-#: builtin/commit.c:797
-#, c-format
-msgid ""
-"\n"
-"It looks like you may be committing a cherry-pick.\n"
-"If this is not correct, please remove the file\n"
-"\t%s\n"
-"and try again.\n"
-msgstr ""
-"\n"
-"Det verkar som du checkar in en cherry-pick.\n"
-"Om det inte stämmer tar du bort filen\n"
-"\t%s\n"
-"och försöker igen.\n"
+#: builtin/difftool.c:710
+msgid "print a list of diff tools that may be used with `--tool`"
+msgstr "visa en lista över diff-verktyg som kan användas med \"--tool\""
 
-#: builtin/commit.c:810
-#, c-format
+#: builtin/difftool.c:713
 msgid ""
-"Please enter the commit message for your changes. Lines starting\n"
-"with '%c' will be ignored, and an empty message aborts the commit.\n"
+"make 'git-difftool' exit when an invoked diff tool returns a non - zero exit "
+"code"
 msgstr ""
-"Ange incheckningsmeddelandet för dina ändringar. Rader som inleds\n"
-"med \"%c\" kommer ignoreras, och ett tomt meddelande avbryter "
-"incheckningen.\n"
+"låt \"git-difftool\" avbryta när ett anropat diff-verktyg ger returvärde "
+"skilt från noll"
 
-#: builtin/commit.c:818
-#, c-format
-msgid ""
-"Please enter the commit message for your changes. Lines starting\n"
-"with '%c' will be kept; you may remove them yourself if you want to.\n"
-"An empty message aborts the commit.\n"
-msgstr ""
-"Ange incheckningsmeddelandet för dina ändringar. Rader som inleds\n"
-"med \"%c\" kommer behållas; du kan själv ta bort dem om du vill.\n"
-"Ett tomt meddelande avbryter incheckningen.\n"
+#: builtin/difftool.c:716
+msgid "specify a custom command for viewing diffs"
+msgstr "ange eget kommando för att visa diffar"
 
-#: builtin/commit.c:835
-#, c-format
-msgid "%sAuthor:    %.*s <%.*s>"
-msgstr "%sFörfattare: %.*s <%.*s>"
+#: builtin/difftool.c:717
+msgid "passed to `diff`"
+msgstr "sändes till \"diff\""
+
+#: builtin/difftool.c:732
+msgid "difftool requires worktree or --no-index"
+msgstr "difftool kräver en arbetskatalog eller --no-index"
+
+#: builtin/difftool.c:739
+msgid "--dir-diff is incompatible with --no-index"
+msgstr "--dir-diff är inkompatibelt med --no-index"
+
+#: builtin/difftool.c:742
+msgid "--gui, --tool and --extcmd are mutually exclusive"
+msgstr "--gui, --tool och --extcmd är ömsesidigt uteslutande"
 
-#: builtin/commit.c:843
-#, c-format
-msgid "%sDate:      %s"
-msgstr "%sDatum:      %s"
+#: builtin/difftool.c:750
+msgid "no <tool> given for --tool=<tool>"
+msgstr "inget <verktyg> angavs för --tool=<verktyg>"
 
-#: builtin/commit.c:850
-#, c-format
-msgid "%sCommitter: %.*s <%.*s>"
-msgstr "%sIncheckare: %.*s <%.*s>"
+#: builtin/difftool.c:757
+msgid "no <cmd> given for --extcmd=<cmd>"
+msgstr "inget <kommando> angavs för --extcmd=<kommando>"
 
-#: builtin/commit.c:867
-msgid "Cannot read index"
-msgstr "Kan inte läsa indexet"
+#: builtin/env--helper.c:6
+msgid "git env--helper --type=[bool|ulong] <options> <env-var>"
+msgstr "git env--helper --type=[bool|ulong] <flaggor> <miljövariabel>"
 
-#: builtin/commit.c:933
-msgid "Error building trees"
-msgstr "Fel vid byggande av träd"
+#: builtin/env--helper.c:37 builtin/hash-object.c:98
+msgid "type"
+msgstr "typ"
 
-#: builtin/commit.c:947 builtin/tag.c:257
-#, c-format
-msgid "Please supply the message using either -m or -F option.\n"
-msgstr "Ange meddelandet en av flaggorna -m eller -F.\n"
+#: builtin/env--helper.c:41
+msgid "default for git_env_*(...) to fall back on"
+msgstr "standard för git_env_*(...) att falla tillbaka på"
 
-#: builtin/commit.c:991
-#, c-format
-msgid "--author '%s' is not 'Name <email>' and matches no existing author"
-msgstr ""
-"--author '%s' är inte 'Namn <epost>' och matchar ingen befintlig författare"
+#: builtin/env--helper.c:43
+msgid "be quiet only use git_env_*() value as exit code"
+msgstr "var tyst, använd bara git_env_*() som resultatvärde"
 
-#: builtin/commit.c:1005
+#: builtin/env--helper.c:62
 #, c-format
-msgid "Invalid ignored mode '%s'"
-msgstr "Ogiltigt ignorerat läge \"%s\""
+msgid "option `--default' expects a boolean value with `--type=bool`, not `%s`"
+msgstr ""
+"flaggan \"--default\" förväntar ett sanningsvärde med \"--type=bool\", inte "
+"\"%s\""
 
-#: builtin/commit.c:1019 builtin/commit.c:1269
+#: builtin/env--helper.c:77
 #, c-format
-msgid "Invalid untracked files mode '%s'"
-msgstr "Ogiltigt läge för ospårade filer: \"%s\""
-
-#: builtin/commit.c:1057
-msgid "--long and -z are incompatible"
-msgstr "--long och -z är inkompatibla"
-
-#: builtin/commit.c:1090
-msgid "Using both --reset-author and --author does not make sense"
-msgstr "Kan inte använda både --reset-author och --author"
+msgid ""
+"option `--default' expects an unsigned long value with `--type=ulong`, not `"
+"%s`"
+msgstr ""
+"flaggan \"--default\" förväntar ett teckenlöst långt värde med \"--type=ulong"
+"\", inte \"%s\""
 
-#: builtin/commit.c:1099
-msgid "You have nothing to amend."
-msgstr "Du har inget att utöka."
+#: builtin/fast-export.c:29
+msgid "git fast-export [rev-list-opts]"
+msgstr "git fast-export [rev-list-flaggor]"
 
-#: builtin/commit.c:1102
-msgid "You are in the middle of a merge -- cannot amend."
-msgstr "Du är i mitten av en sammanslagning -- kan inte utöka."
+#: builtin/fast-export.c:852
+msgid "Error: Cannot export nested tags unless --mark-tags is specified."
+msgstr "Fel: Kan inte exportera nästlade taggar såvida inte --mark-tags anges."
 
-#: builtin/commit.c:1104
-msgid "You are in the middle of a cherry-pick -- cannot amend."
-msgstr "Du är i mitten av en cherry-pick -- kan inte utöka."
+#: builtin/fast-export.c:1152
+msgid "show progress after <n> objects"
+msgstr "visa förlopp efter <n> objekt"
 
-#: builtin/commit.c:1107
-msgid "Options --squash and --fixup cannot be used together"
-msgstr "Flaggorna --squash och --fixup kan inte användas samtidigt"
+#: builtin/fast-export.c:1154
+msgid "select handling of signed tags"
+msgstr "välj hantering av signerade taggar"
 
-#: builtin/commit.c:1117
-msgid "Only one of -c/-C/-F/--fixup can be used."
-msgstr "Endast en av -c/-C/-F/--fixup kan användas."
+#: builtin/fast-export.c:1157
+msgid "select handling of tags that tag filtered objects"
+msgstr "välj hantering av taggar som har taggfiltrerade objekt"
 
-#: builtin/commit.c:1119
-msgid "Option -m cannot be combined with -c/-C/-F."
-msgstr "Flaggan -m kan inte kombineras med -c/-C/-F."
+#: builtin/fast-export.c:1160
+msgid "select handling of commit messages in an alternate encoding"
+msgstr "välj hantering av incheckningsmeddelanden i alternativ teckenkodning"
 
-#: builtin/commit.c:1127
-msgid "--reset-author can be used only with -C, -c or --amend."
-msgstr "--reset-author kan endast användas med -C, -c eller --amend."
+#: builtin/fast-export.c:1163
+msgid "Dump marks to this file"
+msgstr "Dumpa märken till filen"
 
-#: builtin/commit.c:1144
-msgid "Only one of --include/--only/--all/--interactive/--patch can be used."
-msgstr ""
-"Endast en av --include/--only/--all/--interactive/--patch kan användas."
+#: builtin/fast-export.c:1165
+msgid "Import marks from this file"
+msgstr "Importera märken från filen"
 
-#: builtin/commit.c:1146
-msgid "No paths with --include/--only does not make sense."
-msgstr "Du måste ange sökvägar tillsammans med --include/--only."
+#: builtin/fast-export.c:1169
+msgid "Import marks from this file if it exists"
+msgstr "Importera märken från filen, om den finns"
 
-#: builtin/commit.c:1160 builtin/tag.c:543
-#, c-format
-msgid "Invalid cleanup mode %s"
-msgstr "Felaktigt städningsläge %s"
+#: builtin/fast-export.c:1171
+msgid "Fake a tagger when tags lack one"
+msgstr "Fejka taggare när taggen saknar en"
 
-#: builtin/commit.c:1165
-msgid "Paths with -a does not make sense."
-msgstr "Kan inte ange sökvägar med -a."
+#: builtin/fast-export.c:1173
+msgid "Output full tree for each commit"
+msgstr "Skriv ut hela trädet för varje incheckning"
 
-#: builtin/commit.c:1303 builtin/commit.c:1480
-msgid "show status concisely"
-msgstr "visa koncis status"
+#: builtin/fast-export.c:1175
+msgid "Use the done feature to terminate the stream"
+msgstr "Använd done-funktionen för att avsluta strömmen"
 
-#: builtin/commit.c:1305 builtin/commit.c:1482
-msgid "show branch information"
-msgstr "visa information om gren"
+#: builtin/fast-export.c:1176
+msgid "Skip output of blob data"
+msgstr "Hoppa över skrivning av blob-data"
 
-#: builtin/commit.c:1307
-msgid "show stash information"
-msgstr "visa information om stash"
+#: builtin/fast-export.c:1177 builtin/log.c:1705
+msgid "refspec"
+msgstr "referensspecifikation"
 
-#: builtin/commit.c:1309 builtin/commit.c:1484
-msgid "compute full ahead/behind values"
-msgstr "beräkna fullständiga före-/efter-värden"
+#: builtin/fast-export.c:1178
+msgid "Apply refspec to exported refs"
+msgstr "Applicera referensspecifikation på exporterade referenser"
 
-#: builtin/commit.c:1311
-msgid "version"
-msgstr "version"
+#: builtin/fast-export.c:1179
+msgid "anonymize output"
+msgstr "anonymisera utdata"
 
-#: builtin/commit.c:1311 builtin/commit.c:1486 builtin/push.c:558
-#: builtin/worktree.c:581
-msgid "machine-readable output"
-msgstr "maskinläsbar utdata"
+#: builtin/fast-export.c:1181
+msgid "Reference parents which are not in fast-export stream by object id"
+msgstr "Referera föräldrar som inte finns i fast-export-ström med objekt-id"
+
+#: builtin/fast-export.c:1183
+msgid "Show original object ids of blobs/commits"
+msgstr "Visa ursprungliga objekt-id för blobbar/incheckningar"
+
+#: builtin/fast-export.c:1185
+msgid "Label tags with mark ids"
+msgstr "Märk taggar med märke-id"
+
+#: builtin/fast-export.c:1220
+msgid "Cannot pass both --import-marks and --import-marks-if-exists"
+msgstr "Kan inte ange både --import-marks och --import-marks-if-exists"
 
-#: builtin/commit.c:1314 builtin/commit.c:1488
-msgid "show status in long format (default)"
-msgstr "visa status i långt format (standard)"
+#: builtin/fetch.c:34
+msgid "git fetch [<options>] [<repository> [<refspec>...]]"
+msgstr "git fetch [<flaggor>] [<arkiv> [<refspec>...]]"
 
-#: builtin/commit.c:1317 builtin/commit.c:1491
-msgid "terminate entries with NUL"
-msgstr "terminera poster med NUL"
+#: builtin/fetch.c:35
+msgid "git fetch [<options>] <group>"
+msgstr "git fetch [<flaggor>] <grupp>"
 
-#: builtin/commit.c:1319 builtin/commit.c:1323 builtin/commit.c:1494
-#: builtin/fast-export.c:1001 builtin/fast-export.c:1004 builtin/tag.c:397
-msgid "mode"
-msgstr "läge"
+#: builtin/fetch.c:36
+msgid "git fetch --multiple [<options>] [(<repository> | <group>)...]"
+msgstr "git fetch --multiple [<flaggor>] [(<arkiv> | <grupp>)...]"
 
-#: builtin/commit.c:1320 builtin/commit.c:1494
-msgid "show untracked files, optional modes: all, normal, no. (Default: all)"
-msgstr "visa ospårade filer, valfria lägen: all, normal, no. (Standard: all)"
+#: builtin/fetch.c:37
+msgid "git fetch --all [<options>]"
+msgstr "git fetch --all [<flaggor>]"
 
-#: builtin/commit.c:1324
-msgid ""
-"show ignored files, optional modes: traditional, matching, no. (Default: "
-"traditional)"
-msgstr ""
-"visa ignorerade filer, valfria lägen: traditional, matching, no (Standard: "
-"traditional)"
+#: builtin/fetch.c:116
+msgid "fetch.parallel cannot be negative"
+msgstr "fetch.parallel kan inte vara negativt"
 
-#: builtin/commit.c:1326 parse-options.h:167
-msgid "when"
-msgstr "när"
+#: builtin/fetch.c:139 builtin/pull.c:204
+msgid "fetch from all remotes"
+msgstr "hämta från alla fjärrar"
 
-#: builtin/commit.c:1327
-msgid ""
-"ignore changes to submodules, optional when: all, dirty, untracked. "
-"(Default: all)"
-msgstr ""
-"ignorera ändringar i undermoduler, valfritt när: all, dirty, untracked. "
-"(Default: all)"
+#: builtin/fetch.c:141 builtin/pull.c:248
+msgid "set upstream for git pull/fetch"
+msgstr "ställ in uppström för git pull/fetch"
 
-#: builtin/commit.c:1329
-msgid "list untracked files in columns"
-msgstr "visa ospårade filer i spalter"
+#: builtin/fetch.c:143 builtin/pull.c:207
+msgid "append to .git/FETCH_HEAD instead of overwriting"
+msgstr "lägg till i .git/FETCH_HEAD istället för att skriva över"
 
-#: builtin/commit.c:1330
-msgid "do not detect renames"
-msgstr "detektera inte namnändringar"
+#: builtin/fetch.c:145 builtin/pull.c:210
+msgid "path to upload pack on remote end"
+msgstr "sökväg till upload pack på fjärren"
 
-#: builtin/commit.c:1332
-msgid "detect renames, optionally set similarity index"
-msgstr "detektera namnändringar, möjligen sätt likhetsindex"
+#: builtin/fetch.c:146
+msgid "force overwrite of local reference"
+msgstr "tvinga överskrivning av lokal referens"
 
-#: builtin/commit.c:1352
-msgid "Unsupported combination of ignored and untracked-files arguments"
-msgstr "Kombinationen av argument för ignorerade och ospårade filer stöds ej"
+#: builtin/fetch.c:148
+msgid "fetch from multiple remotes"
+msgstr "hämta från flera fjärrar"
 
-#: builtin/commit.c:1450
-msgid "suppress summary after successful commit"
-msgstr "undertryck sammanfattning efter framgångsrik incheckning"
+#: builtin/fetch.c:150 builtin/pull.c:214
+msgid "fetch all tags and associated objects"
+msgstr "hämta alla taggar och associerade objekt"
 
-#: builtin/commit.c:1451
-msgid "show diff in commit message template"
-msgstr "visa diff i mallen för incheckningsmeddelandet"
+#: builtin/fetch.c:152
+msgid "do not fetch all tags (--no-tags)"
+msgstr "hämta inte alla taggar (--no-tags)"
 
-#: builtin/commit.c:1453
-msgid "Commit message options"
-msgstr "Alternativ för incheckningsmeddelande"
+#: builtin/fetch.c:154
+msgid "number of submodules fetched in parallel"
+msgstr "antal undermoduler som hämtas parallellt"
 
-#: builtin/commit.c:1454 builtin/tag.c:394
-msgid "read message from file"
-msgstr "läs meddelande från fil"
+#: builtin/fetch.c:156 builtin/pull.c:217
+msgid "prune remote-tracking branches no longer on remote"
+msgstr "rensa fjärrspårande grenar ej längre på fjärren"
 
-#: builtin/commit.c:1455
-msgid "author"
-msgstr "författare"
+#: builtin/fetch.c:158
+msgid "prune local tags no longer on remote and clobber changed tags"
+msgstr ""
+"rensa lokala taggar inte längre på fjärren och skriv över ändrade taggar"
 
-#: builtin/commit.c:1455
-msgid "override author for commit"
-msgstr "överstyr författare för incheckningen"
+#: builtin/fetch.c:159 builtin/fetch.c:182 builtin/pull.c:141
+msgid "on-demand"
+msgstr "on-demand"
 
-#: builtin/commit.c:1456 builtin/gc.c:501
-msgid "date"
-msgstr "datum"
+#: builtin/fetch.c:160
+msgid "control recursive fetching of submodules"
+msgstr "styr rekursiv hämtning av undermoduler"
 
-#: builtin/commit.c:1456
-msgid "override date for commit"
-msgstr "överstyr datum för incheckningen"
+#: builtin/fetch.c:164 builtin/pull.c:225
+msgid "keep downloaded pack"
+msgstr "behåll hämtade paket"
 
-#: builtin/commit.c:1457 builtin/merge.c:228 builtin/notes.c:402
-#: builtin/notes.c:565 builtin/tag.c:392
-msgid "message"
-msgstr "meddelande"
+#: builtin/fetch.c:166
+msgid "allow updating of HEAD ref"
+msgstr "tillåt uppdatering av HEAD-referens"
 
-#: builtin/commit.c:1457
-msgid "commit message"
-msgstr "incheckningsmeddelande"
+#: builtin/fetch.c:169 builtin/fetch.c:175 builtin/pull.c:228
+msgid "deepen history of shallow clone"
+msgstr "fördjupa historik för grund klon"
 
-#: builtin/commit.c:1458 builtin/commit.c:1459 builtin/commit.c:1460
-#: builtin/commit.c:1461 parse-options.h:270 ref-filter.h:92
-msgid "commit"
-msgstr "incheckning"
+#: builtin/fetch.c:171
+msgid "deepen history of shallow repository based on time"
+msgstr "fördjupa historik för grund klon baserad på tid"
 
-#: builtin/commit.c:1458
-msgid "reuse and edit message from specified commit"
-msgstr "återanvänd och redigera meddelande från angiven incheckning"
+#: builtin/fetch.c:177 builtin/pull.c:231
+msgid "convert to a complete repository"
+msgstr "konvertera till komplett arkiv"
 
-#: builtin/commit.c:1459
-msgid "reuse message from specified commit"
-msgstr "återanvänd meddelande från angiven incheckning"
+#: builtin/fetch.c:180
+msgid "prepend this to submodule path output"
+msgstr "lägg till i början av undermodulens sökvägsutdata"
 
-#: builtin/commit.c:1460
-msgid "use autosquash formatted message to fixup specified commit"
+#: builtin/fetch.c:183
+msgid ""
+"default for recursive fetching of submodules (lower priority than config "
+"files)"
 msgstr ""
-"använd autosquash-formaterat meddelande för att fixa angiven incheckning"
+"standard för rekursiv hämtning av undermoduler (lägre prioritet än "
+"konfigurationsfiler)"
 
-#: builtin/commit.c:1461
-msgid "use autosquash formatted message to squash specified commit"
-msgstr ""
-"använd autosquash-formaterat meddelande för att slå ihop med angiven "
-"incheckning"
+#: builtin/fetch.c:187 builtin/pull.c:234
+msgid "accept refs that update .git/shallow"
+msgstr "tar emot referenser som uppdaterar .git/shallow"
 
-#: builtin/commit.c:1462
-msgid "the commit is authored by me now (used with -C/-c/--amend)"
-msgstr "jag är nu författare av incheckningen (används med -C/-c/--amend)"
+#: builtin/fetch.c:188 builtin/pull.c:236
+msgid "refmap"
+msgstr "referenskarta"
 
-#: builtin/commit.c:1463 builtin/log.c:1446 builtin/merge.c:242
-#: builtin/pull.c:154 builtin/revert.c:105
-msgid "add Signed-off-by:"
-msgstr "lägg till Signed-off-by:"
+#: builtin/fetch.c:189 builtin/pull.c:237
+msgid "specify fetch refmap"
+msgstr "ange referenskarta för \"fetch\""
 
-#: builtin/commit.c:1464
-msgid "use specified template file"
-msgstr "använd angiven mallfil"
+#: builtin/fetch.c:196
+msgid "report that we have only objects reachable from this object"
+msgstr "rapportera att vi bara har objekt nåbara från detta objektet"
+
+#: builtin/fetch.c:199
+msgid "run 'gc --auto' after fetching"
+msgstr "kör \"gc --auto\" efter hämtning"
+
+#: builtin/fetch.c:201 builtin/pull.c:246
+msgid "check for forced-updates on all updated branches"
+msgstr "se efter tvingade uppdateringar i alla uppdaterade grenar"
+
+#: builtin/fetch.c:203
+msgid "write the commit-graph after fetching"
+msgstr "skriv incheckingsgrafen efter hämtning"
 
-#: builtin/commit.c:1465
-msgid "force edit of commit"
-msgstr "tvinga redigering av incheckning"
+#: builtin/fetch.c:513
+msgid "Couldn't find remote ref HEAD"
+msgstr "Kunde inte hitta fjärr-referensen HEAD"
 
-#: builtin/commit.c:1466
-msgid "default"
-msgstr "standard"
+#: builtin/fetch.c:653
+#, c-format
+msgid "configuration fetch.output contains invalid value %s"
+msgstr "konfigurationen för fetch.output innehåller ogiltigt värde %s"
 
-#: builtin/commit.c:1466 builtin/tag.c:398
-msgid "how to strip spaces and #comments from message"
-msgstr "hur blanksteg och #kommentarer skall tas bort från meddelande"
+#: builtin/fetch.c:751
+#, c-format
+msgid "object %s not found"
+msgstr "objektet %s hittades inte"
 
-#: builtin/commit.c:1467
-msgid "include status in commit message template"
-msgstr "inkludera status i mallen för incheckningsmeddelandet"
+#: builtin/fetch.c:755
+msgid "[up to date]"
+msgstr "[àjour]"
 
-#: builtin/commit.c:1469 builtin/merge.c:240 builtin/pull.c:184
-#: builtin/revert.c:113
-msgid "GPG sign commit"
-msgstr "GPG-signera incheckning"
+#: builtin/fetch.c:768 builtin/fetch.c:784 builtin/fetch.c:856
+msgid "[rejected]"
+msgstr "[refuserad]"
 
-#: builtin/commit.c:1472
-msgid "Commit contents options"
-msgstr "Alternativ för incheckningens innehåll"
+#: builtin/fetch.c:769
+msgid "can't fetch in current branch"
+msgstr "kan inte hämta i aktuell gren"
 
-#: builtin/commit.c:1473
-msgid "commit all changed files"
-msgstr "checka in alla ändrade filer"
+#: builtin/fetch.c:779
+msgid "[tag update]"
+msgstr "[uppdaterad tagg]"
 
-#: builtin/commit.c:1474
-msgid "add specified files to index for commit"
-msgstr "lägg till angivna filer till indexet för incheckning"
+#: builtin/fetch.c:780 builtin/fetch.c:817 builtin/fetch.c:839
+#: builtin/fetch.c:851
+msgid "unable to update local ref"
+msgstr "kunde inte uppdatera lokal ref"
 
-#: builtin/commit.c:1475
-msgid "interactively add files"
-msgstr "lägg till filer interaktivt"
+#: builtin/fetch.c:784
+msgid "would clobber existing tag"
+msgstr "skulle skriva över befintlig tagg"
 
-#: builtin/commit.c:1476
-msgid "interactively add changes"
-msgstr "lägg till ändringar interaktivt"
+#: builtin/fetch.c:806
+msgid "[new tag]"
+msgstr "[ny tagg]"
 
-#: builtin/commit.c:1477
-msgid "commit only specified files"
-msgstr "checka endast in angivna filer"
+#: builtin/fetch.c:809
+msgid "[new branch]"
+msgstr "[ny gren]"
 
-#: builtin/commit.c:1478
-msgid "bypass pre-commit and commit-msg hooks"
-msgstr "förbigå pre-commit- och commit-msg-krokar"
+#: builtin/fetch.c:812
+msgid "[new ref]"
+msgstr "[ny ref]"
 
-#: builtin/commit.c:1479
-msgid "show what would be committed"
-msgstr "visa vad som skulle checkas in"
+#: builtin/fetch.c:851
+msgid "forced update"
+msgstr "tvingad uppdatering"
 
-#: builtin/commit.c:1492
-msgid "amend previous commit"
-msgstr "lägg till föregående incheckning"
+#: builtin/fetch.c:856
+msgid "non-fast-forward"
+msgstr "ej snabbspolad"
 
-#: builtin/commit.c:1493
-msgid "bypass post-rewrite hook"
-msgstr "förbigå post-rewrite-krok"
+#: builtin/fetch.c:877
+msgid ""
+"Fetch normally indicates which branches had a forced update,\n"
+"but that check has been disabled. To re-enable, use '--show-forced-updates'\n"
+"flag or run 'git config fetch.showForcedUpdates true'."
+msgstr ""
+"Fetch visar normalt vilka grenar som tvångsuppdaterats, men testet har "
+"slagits\n"
+"av. För att slå på igen, använd flaggan \"--show-forced-updates\" eller kör\n"
+"\"git config fetch.showForcedUpdates true\"."
 
-#: builtin/commit.c:1498
-msgid "ok to record an empty change"
-msgstr "ok att registrera en tom ändring"
+#: builtin/fetch.c:881
+#, c-format
+msgid ""
+"It took %.2f seconds to check forced updates. You can use\n"
+"'--no-show-forced-updates' or run 'git config fetch.showForcedUpdates "
+"false'\n"
+" to avoid this check.\n"
+msgstr ""
+"Det tog %.2f sekunder att se efter tvångsuppdateringar. Du kan använda\n"
+"\"--no-show-forced-updates\" eller köra \"git config fetch."
+"showForcedUpdates\n"
+"false\" för att undvika testet.\n"
 
-#: builtin/commit.c:1500
-msgid "ok to record a change with an empty message"
-msgstr "ok att registrera en ändring med tomt meddelande"
+#: builtin/fetch.c:911
+#, c-format
+msgid "%s did not send all necessary objects\n"
+msgstr "%s sände inte alla nödvändiga objekt\n"
 
-#: builtin/commit.c:1573
+#: builtin/fetch.c:932
 #, c-format
-msgid "Corrupt MERGE_HEAD file (%s)"
-msgstr "Trasig MERGE_HEAD-fil (%s)"
+msgid "reject %s because shallow roots are not allowed to be updated"
+msgstr "avvisa %s då grunda rötter inte kan uppdateras"
 
-#: builtin/commit.c:1580
-msgid "could not read MERGE_MODE"
-msgstr "kunde inte läsa MERGE_MODE"
+#: builtin/fetch.c:1017 builtin/fetch.c:1155
+#, c-format
+msgid "From %.*s\n"
+msgstr "Från %.*s\n"
 
-#: builtin/commit.c:1599
+#: builtin/fetch.c:1028
 #, c-format
-msgid "could not read commit message: %s"
-msgstr "kunde inte läsa incheckningsmeddelande: %s"
+msgid ""
+"some local refs could not be updated; try running\n"
+" 'git remote prune %s' to remove any old, conflicting branches"
+msgstr ""
+"vissa lokala referenser kunde inte uppdateras; testa att köra\n"
+" \"git remote prune %s\" för att ta bort gamla grenar som står i konflikt"
 
-#: builtin/commit.c:1610
+#: builtin/fetch.c:1125
 #, c-format
-msgid "Aborting commit due to empty commit message.\n"
-msgstr "Avbryter på grund av tomt incheckningsmeddelande.\n"
+msgid "   (%s will become dangling)"
+msgstr "   (%s kommer bli dinglande)"
 
-#: builtin/commit.c:1615
+#: builtin/fetch.c:1126
 #, c-format
-msgid "Aborting commit; you did not edit the message.\n"
-msgstr "Avbryter incheckning; meddelandet inte redigerat.\n"
+msgid "   (%s has become dangling)"
+msgstr "   (%s har blivit dinglande)"
 
-#: builtin/commit.c:1650
-msgid ""
-"Repository has been updated, but unable to write\n"
-"new_index file. Check that disk is not full and quota is\n"
-"not exceeded, and then \"git reset HEAD\" to recover."
-msgstr ""
-"Arkivet har uppdaterats, men kunde inte skriva filen\n"
-"new_index. Kontrollera att disken inte är full och\n"
-"att kvoten inte har överskridits, och kör sedan\n"
-"\"git reset HEAD\" för att återställa."
+#: builtin/fetch.c:1158
+msgid "[deleted]"
+msgstr "[borttagen]"
 
-#: builtin/commit-graph.c:9
-msgid "git commit-graph [--object-dir <objdir>]"
-msgstr "git commit-graph [--object-dir <objkat>]"
+#: builtin/fetch.c:1159 builtin/remote.c:1035
+msgid "(none)"
+msgstr "(ingen)"
 
-#: builtin/commit-graph.c:10 builtin/commit-graph.c:16
-msgid "git commit-graph read [--object-dir <objdir>]"
-msgstr "git commit-graph read [--object-dir <objkat>]"
+#: builtin/fetch.c:1182
+#, c-format
+msgid "Refusing to fetch into current branch %s of non-bare repository"
+msgstr "Vägrar hämta till aktuell gren %s i ett icke-naket arkiv"
 
-#: builtin/commit-graph.c:11 builtin/commit-graph.c:21
-msgid ""
-"git commit-graph write [--object-dir <objdir>] [--append] [--stdin-packs|--"
-"stdin-commits]"
-msgstr ""
-"git commit-graph write [--object-dir <objkat>] [--append] [--stdin-packs|--"
-"stdin-commits]"
+#: builtin/fetch.c:1201
+#, c-format
+msgid "Option \"%s\" value \"%s\" is not valid for %s"
+msgstr "Flaggan \"%s\" och värdet \"%s\" är inte giltigt för %s"
 
-#: builtin/commit-graph.c:39 builtin/commit-graph.c:92
-#: builtin/commit-graph.c:147 builtin/fetch.c:161 builtin/log.c:1466
-msgid "dir"
-msgstr "kat"
+#: builtin/fetch.c:1204
+#, c-format
+msgid "Option \"%s\" is ignored for %s\n"
+msgstr "Flaggan \"%s\" ignoreras för %s\n"
 
-#: builtin/commit-graph.c:40 builtin/commit-graph.c:93
-#: builtin/commit-graph.c:148
-msgid "The object directory to store the graph"
-msgstr "Objektkatalogen där grafen skall lagras"
+#: builtin/fetch.c:1412
+msgid "multiple branches detected, incompatible with --set-upstream"
+msgstr "flera grenar upptäcktes, inkompatibelt med --set-upstream"
 
-#: builtin/commit-graph.c:95
-msgid "scan pack-indexes listed by stdin for commits"
-msgstr "sök paketindex listade på standard in efter incheckningar"
+#: builtin/fetch.c:1427
+msgid "not setting upstream for a remote remote-tracking branch"
+msgstr "ställer inte in uppströmsgren för en fjärrspårande gren på fjärren"
 
-#: builtin/commit-graph.c:97
-msgid "start walk at commits listed by stdin"
-msgstr "börja gå genom incheckningar listade på standard in"
+#: builtin/fetch.c:1429
+msgid "not setting upstream for a remote tag"
+msgstr "ställer inte in uppström för en fjärrtag"
 
-#: builtin/commit-graph.c:99
-msgid "include all commits already in the commit-graph file"
-msgstr "ta med alla incheckningar redan i filen commit-graph"
+#: builtin/fetch.c:1431
+msgid "unknown branch type"
+msgstr "okänd grentyp"
 
-#: builtin/commit-graph.c:108
-msgid "cannot use both --stdin-commits and --stdin-packs"
-msgstr "kan inte använda både --stdin-commit och --stdin-packs"
+#: builtin/fetch.c:1433
+msgid ""
+"no source branch found.\n"
+"you need to specify exactly one branch with the --set-upstream option."
+msgstr ""
+"hittade ingen källgren.\n"
+"du måste ange exakt en gren med flaggan --set-upstream."
 
-#: builtin/config.c:10
-msgid "git config [<options>]"
-msgstr "git config [<flaggor>]"
+#: builtin/fetch.c:1559 builtin/fetch.c:1622
+#, c-format
+msgid "Fetching %s\n"
+msgstr "Hämtar %s\n"
 
-#: builtin/config.c:101
+#: builtin/fetch.c:1569 builtin/fetch.c:1624 builtin/remote.c:100
 #, c-format
-msgid "unrecognized --type argument, %s"
-msgstr "okänt argument för --type, %s"
+msgid "Could not fetch %s"
+msgstr "Kunde inte hämta %s"
 
-#: builtin/config.c:123
-msgid "Config file location"
-msgstr "Konfigurationsfilens plats"
+#: builtin/fetch.c:1581
+#, c-format
+msgid "could not fetch '%s' (exit code: %d)\n"
+msgstr "kunde inte hämta \"%s\" (felkod: %d)\n"
 
-#: builtin/config.c:124
-msgid "use global config file"
-msgstr "använd global konfigurationsfil"
+#: builtin/fetch.c:1684
+msgid ""
+"No remote repository specified.  Please, specify either a URL or a\n"
+"remote name from which new revisions should be fetched."
+msgstr ""
+"Inget fjärrarkiv angavs. Ange antingen en URL eller namnet på ett\n"
+"fjärrarkiv som nya incheckningar skall hämtas från."
 
-#: builtin/config.c:125
-msgid "use system config file"
-msgstr "använd systemets konfigurationsfil"
+#: builtin/fetch.c:1721
+msgid "You need to specify a tag name."
+msgstr "Du måste ange namnet på en tagg."
 
-#: builtin/config.c:126
-msgid "use repository config file"
-msgstr "använd arkivets konfigurationsfil"
+#: builtin/fetch.c:1771
+msgid "Negative depth in --deepen is not supported"
+msgstr "Negativa djup stöds inte i --deepen"
 
-#: builtin/config.c:127
-msgid "use given config file"
-msgstr "använd angiven konfigurationsfil"
+#: builtin/fetch.c:1773
+msgid "--deepen and --depth are mutually exclusive"
+msgstr "--deepen och --depth är ömsesidigt uteslutande"
 
-#: builtin/config.c:128
-msgid "blob-id"
-msgstr "blob-id"
+#: builtin/fetch.c:1778
+msgid "--depth and --unshallow cannot be used together"
+msgstr "--depth och --unshallow kan inte användas samtidigt"
 
-#: builtin/config.c:128
-msgid "read config from given blob object"
-msgstr "läs konfiguration från givet blob-objekt"
+#: builtin/fetch.c:1780
+msgid "--unshallow on a complete repository does not make sense"
+msgstr "--unshallow kan inte användas på ett komplett arkiv"
 
-#: builtin/config.c:129
-msgid "Action"
-msgstr "Åtgärd"
+#: builtin/fetch.c:1796
+msgid "fetch --all does not take a repository argument"
+msgstr "fetch --all tar inte namnet på ett arkiv som argument"
 
-#: builtin/config.c:130
-msgid "get value: name [value-regex]"
-msgstr "hämta värde: namn [värde-reguttr]"
+#: builtin/fetch.c:1798
+msgid "fetch --all does not make sense with refspecs"
+msgstr "fetch --all kan inte anges med referensspecifikationer"
 
-#: builtin/config.c:131
-msgid "get all values: key [value-regex]"
-msgstr "hämta alla värden: nyckel [värde-reguttr]"
+#: builtin/fetch.c:1807
+#, c-format
+msgid "No such remote or remote group: %s"
+msgstr "Fjärren eller fjärrgruppen finns inte: %s"
 
-#: builtin/config.c:132
-msgid "get values for regexp: name-regex [value-regex]"
-msgstr "hämta värden för reguttr: namn-reguttr [värde-reguttr]"
+#: builtin/fetch.c:1814
+msgid "Fetching a group and specifying refspecs does not make sense"
+msgstr "Kan inte hämta från grupp och ange referensspecifikationer"
 
-#: builtin/config.c:133
-msgid "get value specific for the URL: section[.var] URL"
-msgstr "hämta värde specifikt URL:en: sektion[.var] URL"
+#: builtin/fetch.c:1832
+msgid ""
+"--filter can only be used with the remote configured in extensions."
+"partialclone"
+msgstr ""
+"--filter kan endast användas med fjärren konfigurerad i extensions."
+"partialclone"
 
-#: builtin/config.c:134
-msgid "replace all matching variables: name value [value_regex]"
-msgstr "ersätt alla motsvarande variabler: namn värde [värde-reguttr]"
+#: builtin/fmt-merge-msg.c:18
+msgid ""
+"git fmt-merge-msg [-m <message>] [--log[=<n>] | --no-log] [--file <file>]"
+msgstr ""
+"git fmt-merge-msg [-m <meddelande>] [--log[=<n>] | --no-log] [--file <fil>]"
 
-#: builtin/config.c:135
-msgid "add a new variable: name value"
-msgstr "lägg till en ny variabel: namn värde"
+#: builtin/fmt-merge-msg.c:674
+msgid "populate log with at most <n> entries from shortlog"
+msgstr "fyll i loggen med som mest <n> poster från shortlog"
 
-#: builtin/config.c:136
-msgid "remove a variable: name [value-regex]"
-msgstr "ta bort en variabel: namn [värde-reguttr]"
+#: builtin/fmt-merge-msg.c:677
+msgid "alias for --log (deprecated)"
+msgstr "alias för --log (avråds)"
 
-#: builtin/config.c:137
-msgid "remove all matches: name [value-regex]"
-msgstr "ta bort alla träffar: namn [värde-reguttr]"
+#: builtin/fmt-merge-msg.c:680
+msgid "text"
+msgstr "text"
 
-#: builtin/config.c:138
-msgid "rename section: old-name new-name"
-msgstr "byt namn på sektion: gammalt-namn nytt-namn"
+#: builtin/fmt-merge-msg.c:681
+msgid "use <text> as start of message"
+msgstr "inled meddelande med <text>"
 
-#: builtin/config.c:139
-msgid "remove a section: name"
-msgstr "ta bort en sektion: namn"
+#: builtin/fmt-merge-msg.c:682
+msgid "file to read from"
+msgstr "fil att läsa från"
 
-#: builtin/config.c:140
-msgid "list all"
-msgstr "visa alla"
+#: builtin/for-each-ref.c:10
+msgid "git for-each-ref [<options>] [<pattern>]"
+msgstr "git for-each-ref [<flaggor>] [<mönster>]"
 
-#: builtin/config.c:141
-msgid "open an editor"
-msgstr "öppna textredigeringsprogram"
+#: builtin/for-each-ref.c:11
+msgid "git for-each-ref [--points-at <object>]"
+msgstr "git for-each-ref [--points-at <objekt>]"
 
-#: builtin/config.c:142
-msgid "find the color configured: slot [default]"
-msgstr "hitta den inställda färgen: slot [default]"
+#: builtin/for-each-ref.c:12
+msgid "git for-each-ref [(--merged | --no-merged) [<commit>]]"
+msgstr "git for-each-ref [(--merged | --no-merged) [<incheckning>]]"
 
-#: builtin/config.c:143
-msgid "find the color setting: slot [stdout-is-tty]"
-msgstr "hitta färginställningen: slot [stdout-is-tty]"
+#: builtin/for-each-ref.c:13
+msgid "git for-each-ref [--contains [<commit>]] [--no-contains [<commit>]]"
+msgstr ""
+"git for-each-ref [--contains [<incheckning>]] [--no-contains [<incheckning>]]"
 
-#: builtin/config.c:144
-msgid "Type"
-msgstr "Typ"
+#: builtin/for-each-ref.c:28
+msgid "quote placeholders suitably for shells"
+msgstr "citera platshållare passande för skal"
 
-#: builtin/config.c:145
-msgid "value is given this type"
-msgstr "värdet har givits denna typ"
+#: builtin/for-each-ref.c:30
+msgid "quote placeholders suitably for perl"
+msgstr "citera platshållare passande för perl"
 
-#: builtin/config.c:146
-msgid "value is \"true\" or \"false\""
-msgstr "värdet är \"true\" eller \"false\""
+#: builtin/for-each-ref.c:32
+msgid "quote placeholders suitably for python"
+msgstr "citera platshållare passande för python"
 
-#: builtin/config.c:147
-msgid "value is decimal number"
-msgstr "värdet är ett decimalt tal"
+#: builtin/for-each-ref.c:34
+msgid "quote placeholders suitably for Tcl"
+msgstr "citera platshållare passande för Tcl"
 
-#: builtin/config.c:148
-msgid "value is --bool or --int"
-msgstr "värdet är --bool eller --int"
+#: builtin/for-each-ref.c:37
+msgid "show only <n> matched refs"
+msgstr "visa endast <n> träffade refs"
 
-#: builtin/config.c:149
-msgid "value is a path (file or directory name)"
-msgstr "värdet är en sökväg (fil- eller katalognamn)"
+#: builtin/for-each-ref.c:39 builtin/tag.c:439
+msgid "respect format colors"
+msgstr "använd formatfärger"
 
-#: builtin/config.c:150
-msgid "value is an expiry date"
-msgstr "värdet är ett utgångsdatum"
+#: builtin/for-each-ref.c:42
+msgid "print only refs which points at the given object"
+msgstr "visa endast referenser som pekar på objektet"
 
-#: builtin/config.c:151
-msgid "Other"
-msgstr "Andra"
+#: builtin/for-each-ref.c:44
+msgid "print only refs that are merged"
+msgstr "visa endast referenser som slagits samman"
 
-#: builtin/config.c:152
-msgid "terminate values with NUL byte"
-msgstr "terminera värden med NUL-byte"
+#: builtin/for-each-ref.c:45
+msgid "print only refs that are not merged"
+msgstr "visa endast referenser som ej slagits samman"
 
-#: builtin/config.c:153
-msgid "show variable names only"
-msgstr "visa endast variabelnamn"
+#: builtin/for-each-ref.c:46
+msgid "print only refs which contain the commit"
+msgstr "visa endast referenser som innehåller incheckningen"
 
-#: builtin/config.c:154
-msgid "respect include directives on lookup"
-msgstr "respektera inkluderingsdirektiv vid uppslag"
+#: builtin/for-each-ref.c:47
+msgid "print only refs which don't contain the commit"
+msgstr "visa endast referenser som inte innehåller incheckningen"
 
-#: builtin/config.c:155
-msgid "show origin of config (file, standard input, blob, command line)"
-msgstr "visa konfigurationskälla (fil, standard in, blob, kommandorad)"
+#: builtin/fsck.c:68 builtin/fsck.c:147 builtin/fsck.c:148
+msgid "unknown"
+msgstr "okänd"
 
-#: builtin/config.c:156
-msgid "value"
-msgstr "värde"
+#. TRANSLATORS: e.g. error in tree 01bfda: <more explanation>
+#: builtin/fsck.c:100 builtin/fsck.c:120
+#, c-format
+msgid "error in %s %s: %s"
+msgstr "fel i %s %s: %s"
 
-#: builtin/config.c:156
-msgid "with --get, use default value when missing entry"
-msgstr "med --get, använd standardvärde vid saknad post"
+#. TRANSLATORS: e.g. warning in tree 01bfda: <more explanation>
+#: builtin/fsck.c:114
+#, c-format
+msgid "warning in %s %s: %s"
+msgstr "varning i %s %s: %s"
 
-#: builtin/config.c:332
+#: builtin/fsck.c:143 builtin/fsck.c:146
 #, c-format
-msgid "failed to format default config value: %s"
-msgstr "misslyckades formatera standardkonfigurationsvärde: %s"
+msgid "broken link from %7s %s"
+msgstr "trasig länk från %7s %s"
 
-#: builtin/config.c:431
-msgid "unable to parse default color value"
-msgstr "kan inte tolka standardfärgvärde"
+#: builtin/fsck.c:155
+msgid "wrong object type in link"
+msgstr "fel objekttyp i länk"
 
-#: builtin/config.c:575
+#: builtin/fsck.c:171
 #, c-format
 msgid ""
-"# This is Git's per-user configuration file.\n"
-"[user]\n"
-"# Please adapt and uncomment the following lines:\n"
-"#\tname = %s\n"
-"#\temail = %s\n"
+"broken link from %7s %s\n"
+"              to %7s %s"
 msgstr ""
-"# Detta är Gits användarspecifika konfigurationsfil\n"
-"[user]\n"
-"# Justera och ta bort kommenteringsmärket från följande rader:\n"
-"#\tname = %s\n"
-"#\temail = %s\n"
+"trasig länk från %7s %s\n"
+"            till %7s %s"
 
-#: builtin/config.c:603
-msgid "--local can only be used inside a git repository"
-msgstr "--local kan bara användas inuti ett git-arkiv"
+#: builtin/fsck.c:282
+#, c-format
+msgid "missing %s %s"
+msgstr "saknat %s %s"
 
-#: builtin/config.c:606
-msgid "--blob can only be used inside a git repository"
-msgstr "--blob kan bara användas inuti ett git-arkiv"
+#: builtin/fsck.c:309
+#, c-format
+msgid "unreachable %s %s"
+msgstr "onåbart %s %s"
 
-#: builtin/config.c:735
+#: builtin/fsck.c:329
 #, c-format
-msgid "cannot create configuration file %s"
-msgstr "kan inte skapa konfigurationsfilen \"%s\""
+msgid "dangling %s %s"
+msgstr "hängande %s %s"
 
-#: builtin/config.c:748
+#: builtin/fsck.c:339
+msgid "could not create lost-found"
+msgstr "kunde inte skapa lost-found"
+
+#: builtin/fsck.c:350
 #, c-format
-msgid ""
-"cannot overwrite multiple values with a single value\n"
-"       Use a regexp, --add or --replace-all to change %s."
-msgstr ""
-"kan inte skriva över flera värden med ett ensamt värde\n"
-"       Använd en regexp, --add eller --replace-all för att ändra %s."
+msgid "could not finish '%s'"
+msgstr "kunde inte avsluta \"%s\""
 
-#: builtin/count-objects.c:90
-msgid "git count-objects [-v] [-H | --human-readable]"
-msgstr "git count-objects [-v] [-H | --human-readable]"
+#: builtin/fsck.c:367
+#, c-format
+msgid "Checking %s"
+msgstr "Kontrollerar %s"
 
-#: builtin/count-objects.c:100
-msgid "print sizes in human readable format"
-msgstr "skriv storlekar i människoläsbart format"
+# Vague original, not networking-related, but rather related to the actual
+# objects in the database.
+#: builtin/fsck.c:405
+#, c-format
+msgid "Checking connectivity (%d objects)"
+msgstr "Kontrollerar konnektivitet (%d objekt)"
 
-#: builtin/describe.c:22
-msgid "git describe [<options>] [<commit-ish>...]"
-msgstr "git describe [<flaggor>] [<incheckning-igt>...]"
+#: builtin/fsck.c:424
+#, c-format
+msgid "Checking %s %s"
+msgstr "Kontrollerar %s %s"
 
-#: builtin/describe.c:23
-msgid "git describe [<options>] --dirty"
-msgstr "git describe [<flaggor>] --dirty"
+#: builtin/fsck.c:429
+msgid "broken links"
+msgstr "trasiga länkar"
 
-#: builtin/describe.c:57
-msgid "head"
-msgstr "huvud"
+#: builtin/fsck.c:438
+#, c-format
+msgid "root %s"
+msgstr "roten %s"
 
-#: builtin/describe.c:57
-msgid "lightweight"
-msgstr "lättviktig"
+#: builtin/fsck.c:446
+#, c-format
+msgid "tagged %s %s (%s) in %s"
+msgstr "taggad %s %s (%s) i %s"
 
-#: builtin/describe.c:57
-msgid "annotated"
-msgstr "annoterad"
+#: builtin/fsck.c:475
+#, c-format
+msgid "%s: object corrupt or missing"
+msgstr "%s: objekt trasigt eller saknas"
 
-#: builtin/describe.c:267
+#: builtin/fsck.c:500
 #, c-format
-msgid "annotated tag %s not available"
-msgstr "den annoterade taggen %s inte tillgänglig"
+msgid "%s: invalid reflog entry %s"
+msgstr "%s: ogiltig reflog-post %s"
 
-#: builtin/describe.c:271
+#: builtin/fsck.c:514
 #, c-format
-msgid "annotated tag %s has no embedded name"
-msgstr "den annoterade taggen %s har inget inbäddat namn"
+msgid "Checking reflog %s->%s"
+msgstr "Kontrollerar reflog %s->%s"
 
-#: builtin/describe.c:273
+#: builtin/fsck.c:548
 #, c-format
-msgid "tag '%s' is really '%s' here"
-msgstr "taggen \"%s\" är i verkligheten \"%s\" här"
+msgid "%s: invalid sha1 pointer %s"
+msgstr "%s: ogiltig sha1-pekare %s"
 
-#: builtin/describe.c:317
+#: builtin/fsck.c:555
 #, c-format
-msgid "no tag exactly matches '%s'"
-msgstr "ingen tagg motsvarar \"%s\" exakt"
+msgid "%s: not a commit"
+msgstr "%s: inte en incheckning!"
+
+#: builtin/fsck.c:609
+msgid "notice: No default references"
+msgstr "obs: Inga förvalda referenser"
 
-#: builtin/describe.c:319
+#: builtin/fsck.c:624
 #, c-format
-msgid "No exact match on refs or tags, searching to describe\n"
-msgstr ""
-"Ingen exakt träff mot referenser eller taggar, söker för att beskriva\n"
+msgid "%s: object corrupt or missing: %s"
+msgstr "%s: objektet trasigt eller saknas: %s"
 
-#: builtin/describe.c:366
+#: builtin/fsck.c:637
 #, c-format
-msgid "finished search at %s\n"
-msgstr "avslutade sökning på %s\n"
+msgid "%s: object could not be parsed: %s"
+msgstr "%s: objektet kunde inte tolkas: %s"
 
-#: builtin/describe.c:392
+#: builtin/fsck.c:657
 #, c-format
-msgid ""
-"No annotated tags can describe '%s'.\n"
-"However, there were unannotated tags: try --tags."
-msgstr ""
-"Inga annoterade taggar kan beskriva \"%s\".\n"
-"Det finns dock oannoterade taggar: testa --tags."
+msgid "bad sha1 file: %s"
+msgstr "ogiltig sha1-fil: %s"
+
+#: builtin/fsck.c:672
+msgid "Checking object directory"
+msgstr "Kontrollerar objektkatalog"
+
+#: builtin/fsck.c:675
+msgid "Checking object directories"
+msgstr "Kontrollerar objektkataloger"
 
-#: builtin/describe.c:396
+#: builtin/fsck.c:690
 #, c-format
-msgid ""
-"No tags can describe '%s'.\n"
-"Try --always, or create some tags."
-msgstr ""
-"Inga taggar kan beskriva \"%s\".\n"
-"Testa --always, eller skapa några taggar."
+msgid "Checking %s link"
+msgstr "Kontrollerar %s-länk"
 
-#: builtin/describe.c:426
+#: builtin/fsck.c:695 builtin/index-pack.c:842
 #, c-format
-msgid "traversed %lu commits\n"
-msgstr "traverserade %lu incheckningar\n"
+msgid "invalid %s"
+msgstr "ogiltigt %s"
 
-#: builtin/describe.c:429
+#: builtin/fsck.c:702
 #, c-format
-msgid ""
-"more than %i tags found; listed %i most recent\n"
-"gave up search at %s\n"
-msgstr ""
-"mer än %i taggar hittades; listar de %i senaste\n"
-"gav upp sökningen vid %s\n"
+msgid "%s points to something strange (%s)"
+msgstr "%s pekar på något konstigt (%s)"
 
-#: builtin/describe.c:497
+#: builtin/fsck.c:708
 #, c-format
-msgid "describe %s\n"
-msgstr "beskriva %s\n"
+msgid "%s: detached HEAD points at nothing"
+msgstr "%s: frånkopplat HEAD pekar på ingenting"
 
-#: builtin/describe.c:500 builtin/log.c:502
+#: builtin/fsck.c:712
 #, c-format
-msgid "Not a valid object name %s"
-msgstr "Objektnamnet är inte giltigt: %s"
+msgid "notice: %s points to an unborn branch (%s)"
+msgstr "obs: %s pekar på en ofödd gren (%s)"
+
+#: builtin/fsck.c:724
+msgid "Checking cache tree"
+msgstr "Kontrollerar cacheträd"
 
-#: builtin/describe.c:508
+#: builtin/fsck.c:729
 #, c-format
-msgid "%s is neither a commit nor blob"
-msgstr "%s är varken incheckning eller blob"
+msgid "%s: invalid sha1 pointer in cache-tree"
+msgstr "%s: ogiltig sha1-pekare i cacheträd"
+
+#: builtin/fsck.c:738
+msgid "non-tree in cache-tree"
+msgstr "icke-träd i cacheträd"
+
+#: builtin/fsck.c:769
+msgid "git fsck [<options>] [<object>...]"
+msgstr "git fsck [<flaggor>] [<objekt>...]"
+
+#: builtin/fsck.c:775
+msgid "show unreachable objects"
+msgstr "visa onåbara objekt"
+
+#: builtin/fsck.c:776
+msgid "show dangling objects"
+msgstr "visa dinglande objekt"
+
+#: builtin/fsck.c:777
+msgid "report tags"
+msgstr "rapportera taggar"
+
+#: builtin/fsck.c:778
+msgid "report root nodes"
+msgstr "rapportera rotnoder"
+
+#: builtin/fsck.c:779
+msgid "make index objects head nodes"
+msgstr "gör indexojekt till huvudnoder"
+
+#: builtin/fsck.c:780
+msgid "make reflogs head nodes (default)"
+msgstr "gör refloggar till huvudnoder (standard)"
+
+#: builtin/fsck.c:781
+msgid "also consider packs and alternate objects"
+msgstr "ta även hänsyn till paket och supplerande objekt"
+
+# Vague original, not networking-related, but rather related to the actual
+# objects in the database.
+#: builtin/fsck.c:782
+msgid "check only connectivity"
+msgstr "kontrollera endast konnektivitet"
 
-#: builtin/describe.c:522
-msgid "find the tag that comes after the commit"
-msgstr "hitta taggen som kommer efter incheckningen"
+#: builtin/fsck.c:783
+msgid "enable more strict checking"
+msgstr "aktivera striktare kontroll"
 
-#: builtin/describe.c:523
-msgid "debug search strategy on stderr"
-msgstr "felsök sökstrategin på standard fel"
+#: builtin/fsck.c:785
+msgid "write dangling objects in .git/lost-found"
+msgstr "skriv dinglande objekt i .git/lost-found"
 
-#: builtin/describe.c:524
-msgid "use any ref"
-msgstr "använd alla referenser"
+#: builtin/fsck.c:786 builtin/prune.c:132
+msgid "show progress"
+msgstr "visa förlopp"
 
-#: builtin/describe.c:525
-msgid "use any tag, even unannotated"
-msgstr "använd alla taggar, även oannoterade"
+#: builtin/fsck.c:787
+msgid "show verbose names for reachable objects"
+msgstr "visa ordrika namn för nåbara objekt"
 
-#: builtin/describe.c:526
-msgid "always use long format"
-msgstr "använd alltid långt format"
+#: builtin/fsck.c:846 builtin/index-pack.c:225
+msgid "Checking objects"
+msgstr "Kontrollerar objekt"
 
-#: builtin/describe.c:527
-msgid "only follow first parent"
-msgstr "följ endast första föräldern"
+#: builtin/fsck.c:874
+#, c-format
+msgid "%s: object missing"
+msgstr "%s: objekt saknas"
 
-#: builtin/describe.c:530
-msgid "only output exact matches"
-msgstr "skriv endast ut exakta träffar"
+#: builtin/fsck.c:885
+#, c-format
+msgid "invalid parameter: expected sha1, got '%s'"
+msgstr "ogiltig parameter: förväntade sha1, fick \"%s\""
 
-#: builtin/describe.c:532
-msgid "consider <n> most recent tags (default: 10)"
-msgstr "överväg de <n> nyaste taggarna (standard: 10)"
+#: builtin/gc.c:35
+msgid "git gc [<options>]"
+msgstr "git gc [<flaggor>]"
 
-#: builtin/describe.c:534
-msgid "only consider tags matching <pattern>"
-msgstr "överväg endast taggar som motsvarar <mönster>"
+#: builtin/gc.c:90
+#, c-format
+msgid "Failed to fstat %s: %s"
+msgstr "Misslyckades ta status (fstat) på %s: %s"
 
-#: builtin/describe.c:536
-msgid "do not consider tags matching <pattern>"
-msgstr "överväg inte taggar som motsvarar <mönster>"
+#: builtin/gc.c:126
+#, c-format
+msgid "failed to parse '%s' value '%s'"
+msgstr "misslyckades tolka \"%s\" värde \"%s\""
 
-#: builtin/describe.c:538 builtin/name-rev.c:406
-msgid "show abbreviated commit object as fallback"
-msgstr "visa förkortade incheckningsobjekt som standard"
+#: builtin/gc.c:475 builtin/init-db.c:55
+#, c-format
+msgid "cannot stat '%s'"
+msgstr "kan inte ta status på \"%s\""
 
-#: builtin/describe.c:539 builtin/describe.c:542
-msgid "mark"
-msgstr "märke"
+#: builtin/gc.c:484 builtin/notes.c:240 builtin/tag.c:529
+#, c-format
+msgid "cannot read '%s'"
+msgstr "kunde inte läsa \"%s\""
 
-#: builtin/describe.c:540
-msgid "append <mark> on dirty working tree (default: \"-dirty\")"
-msgstr "lägg till <märke> på lortigt arbetsträd (standard: \"-dirty\")"
+#: builtin/gc.c:491
+#, c-format
+msgid ""
+"The last gc run reported the following. Please correct the root cause\n"
+"and remove %s.\n"
+"Automatic cleanup will not be performed until the file is removed.\n"
+"\n"
+"%s"
+msgstr ""
+"Senaste körningen av git gc rapporterade följande. Fixa grundproblemet\n"
+"och ta bort %s.\n"
+"Automatisk städning kommer inte utföras förrän filen tas bort.\n"
+"\n"
+"%s"
 
-#: builtin/describe.c:543
-msgid "append <mark> on broken working tree (default: \"-broken\")"
-msgstr "lägg till <märke> på trasigt arbetsträd (standard: \"-broken\")"
+#: builtin/gc.c:539
+msgid "prune unreferenced objects"
+msgstr "rensa ej refererade objekt"
 
-#: builtin/describe.c:561
-msgid "--long is incompatible with --abbrev=0"
-msgstr "--long är inkompatibel med --abbrev=0"
+#: builtin/gc.c:541
+msgid "be more thorough (increased runtime)"
+msgstr "var mer grundlig (ökar körtiden)"
 
-#: builtin/describe.c:590
-msgid "No names found, cannot describe anything."
-msgstr "Inga namn hittades, kan inte beskriva något."
+#: builtin/gc.c:542
+msgid "enable auto-gc mode"
+msgstr "aktivera auto-gc-läge"
 
-#: builtin/describe.c:640
-msgid "--dirty is incompatible with commit-ishes"
-msgstr "--dirty är inkompatibelt med \"commit-ish\"-värden"
+#: builtin/gc.c:545
+msgid "force running gc even if there may be another gc running"
+msgstr "tvinga gc-körning även om en annan gc kanske körs"
 
-#: builtin/describe.c:642
-msgid "--broken is incompatible with commit-ishes"
-msgstr "--broken är inkompatibelt med \"commit-ish\"-värden"
+#: builtin/gc.c:548
+msgid "repack all other packs except the largest pack"
+msgstr "packa om alla paket förutom det största paketet"
 
-#: builtin/diff.c:83
+#: builtin/gc.c:565
 #, c-format
-msgid "'%s': not a regular file or symlink"
-msgstr "\"%s\": inte en normal fil eller symbolisk länk"
+msgid "failed to parse gc.logexpiry value %s"
+msgstr "kunde inte tolka värdet %s för gc.logexpiry"
 
-#: builtin/diff.c:234
+#: builtin/gc.c:576
 #, c-format
-msgid "invalid option: %s"
-msgstr "ogiltig flagga: %s"
+msgid "failed to parse prune expiry value %s"
+msgstr "kunde inte tolka värdet %s för prune expiry"
 
-#: builtin/diff.c:356
-msgid "Not a git repository"
-msgstr "Inte ett git-arkiv"
+#: builtin/gc.c:596
+#, c-format
+msgid "Auto packing the repository in background for optimum performance.\n"
+msgstr "Packar arkivet automatiskt i bakgrunden för optimal prestanda.\n"
 
-#: builtin/diff.c:399
+#: builtin/gc.c:598
 #, c-format
-msgid "invalid object '%s' given."
-msgstr "objektet \"%s\" som angavs är felaktigt."
+msgid "Auto packing the repository for optimum performance.\n"
+msgstr "Packar arkivet automatiskt för optimal prestanda.\n"
 
-#: builtin/diff.c:408
+#: builtin/gc.c:599
 #, c-format
-msgid "more than two blobs given: '%s'"
-msgstr "mer än två blobbar angavs: \"%s\""
+msgid "See \"git help gc\" for manual housekeeping.\n"
+msgstr "Se \"git help gc\" för manuell hushållning.\n"
 
-#: builtin/diff.c:413
+#: builtin/gc.c:639
 #, c-format
-msgid "unhandled object '%s' given."
-msgstr "ej hanterat objekt \"%s\" angavs."
+msgid ""
+"gc is already running on machine '%s' pid %<PRIuMAX> (use --force if not)"
+msgstr ""
+"gc körs redan på maskinen \"%s\" pid %<PRIuMAX> (använd --force om så inte "
+"är fallet)"
 
-#: builtin/difftool.c:29
-msgid "git difftool [<options>] [<commit> [<commit>]] [--] [<path>...]"
+#: builtin/gc.c:694
+msgid ""
+"There are too many unreachable loose objects; run 'git prune' to remove them."
 msgstr ""
-"git difftool [<flaggor>] [<incheckning> [<incheckning>]] [--] [<sökväg>...]"
+"Det finns för många onåbara lösa objekt; kör \"git prune\" för att ta bort "
+"dem."
+
+#: builtin/grep.c:29
+msgid "git grep [<options>] [-e] <pattern> [<rev>...] [[--] <path>...]"
+msgstr "git grep [<flaggor>] [-e] <mönster> [<rev>...] [[--] <sökväg>...]"
 
-#: builtin/difftool.c:259
+#: builtin/grep.c:225
 #, c-format
-msgid "failed: %d"
-msgstr "misslyckades: %d"
+msgid "grep: failed to create thread: %s"
+msgstr "grep: misslyckades skapa tråd. %s"
 
-#: builtin/difftool.c:301
+#: builtin/grep.c:279
 #, c-format
-msgid "could not read symlink %s"
-msgstr "kunde inte läsa symboliska länken %s"
+msgid "invalid number of threads specified (%d) for %s"
+msgstr "felaktigt antal trådar angivet (%d) för %s"
 
-#: builtin/difftool.c:303
+#. TRANSLATORS: %s is the configuration
+#. variable for tweaking threads, currently
+#. grep.threads
+#.
+#: builtin/grep.c:287 builtin/index-pack.c:1534 builtin/index-pack.c:1727
+#: builtin/pack-objects.c:2708
 #, c-format
-msgid "could not read symlink file %s"
-msgstr "kunde inte läsa symbolisk länk-fil %s"
+msgid "no threads support, ignoring %s"
+msgstr "trådstöd saknas, ignorerar %s"
 
-#: builtin/difftool.c:311
+#: builtin/grep.c:467 builtin/grep.c:592 builtin/grep.c:635
 #, c-format
-msgid "could not read object %s for symlink %s"
-msgstr "kunde inte läsa objektet %s för symboliska länken %s"
+msgid "unable to read tree (%s)"
+msgstr "kunde inte läsa träd (%s)"
 
-#: builtin/difftool.c:412
-msgid ""
-"combined diff formats('-c' and '--cc') are not supported in\n"
-"directory diff mode('-d' and '--dir-diff')."
-msgstr ""
-"kombinerade diff-format (\"-c\" och \"--cc\") stöds inte i\n"
-"katalogdiffläge (\"-d\" och \"--dir-diff\")."
+#: builtin/grep.c:650
+#, c-format
+msgid "unable to grep from object of type %s"
+msgstr "kunde inte \"grep\" från objekt av typen %s"
 
-#: builtin/difftool.c:632
+#: builtin/grep.c:716
 #, c-format
-msgid "both files modified: '%s' and '%s'."
-msgstr "bägge filerna ändrade: \"%s\" och \"%s\"."
+msgid "switch `%c' expects a numerical value"
+msgstr "flaggan \"%c\" antar ett numeriskt värde"
 
-#: builtin/difftool.c:634
-msgid "working tree file has been left."
-msgstr "filen i arbetskatalogen lämnades kvar."
+#: builtin/grep.c:815
+msgid "search in index instead of in the work tree"
+msgstr "sök i indexet istället för i arbetskatalogen"
 
-#: builtin/difftool.c:645
-#, c-format
-msgid "temporary files exist in '%s'."
-msgstr "temporära filer finns i \"%s\"."
+#: builtin/grep.c:817
+msgid "find in contents not managed by git"
+msgstr "sök i innehåll som inte hanteras av git"
 
-#: builtin/difftool.c:646
-msgid "you may want to cleanup or recover these."
-msgstr "du kanske vill städa eller rädda dem."
+#: builtin/grep.c:819
+msgid "search in both tracked and untracked files"
+msgstr "sök i både spårade och ospårade filer"
 
-#: builtin/difftool.c:695
-msgid "use `diff.guitool` instead of `diff.tool`"
-msgstr "använd \"diff.guitool\" istället för \"diff.tool\""
+#: builtin/grep.c:821
+msgid "ignore files specified via '.gitignore'"
+msgstr "ignorera filer angivna i \".gitignore\""
 
-#: builtin/difftool.c:697
-msgid "perform a full-directory diff"
-msgstr "utför diff för hela katalogen"
+#: builtin/grep.c:823
+msgid "recursively search in each submodule"
+msgstr "sök varje undermodul rekursivt"
 
-#: builtin/difftool.c:699
-msgid "do not prompt before launching a diff tool"
-msgstr "fråga inte vid start av diff-verktyg"
+#: builtin/grep.c:826
+msgid "show non-matching lines"
+msgstr "visa rader som inte träffas"
 
-#: builtin/difftool.c:704
-msgid "use symlinks in dir-diff mode"
-msgstr "använd symboliska länkar i katalogdiffläge"
+#: builtin/grep.c:828
+msgid "case insensitive matching"
+msgstr "skiftlägesokänslig sökning"
 
-#: builtin/difftool.c:705
-msgid "<tool>"
-msgstr "<verktyg>"
+#: builtin/grep.c:830
+msgid "match patterns only at word boundaries"
+msgstr "matcha endast mönster vid ordgränser"
 
-#: builtin/difftool.c:706
-msgid "use the specified diff tool"
-msgstr "använd angivet diff-verktyg"
+#: builtin/grep.c:832
+msgid "process binary files as text"
+msgstr "hantera binärfiler som text"
 
-#: builtin/difftool.c:708
-msgid "print a list of diff tools that may be used with `--tool`"
-msgstr "visa en lista över diff-verktyg som kan användas med ”--tool”"
+#: builtin/grep.c:834
+msgid "don't match patterns in binary files"
+msgstr "träffa inte mönster i binärfiler"
 
-#: builtin/difftool.c:711
-msgid ""
-"make 'git-difftool' exit when an invoked diff tool returns a non - zero exit "
-"code"
-msgstr ""
-"låt \"git-difftool\" avbryta när ett anropat diff-verktyg ger returvärde "
-"skilt från noll"
+#: builtin/grep.c:837
+msgid "process binary files with textconv filters"
+msgstr "hantera binärfiler med textconv-filter"
 
-#: builtin/difftool.c:713
-msgid "<command>"
-msgstr "<kommando>"
+#: builtin/grep.c:839
+msgid "search in subdirectories (default)"
+msgstr "sök i underkataloger (standard)"
 
-#: builtin/difftool.c:714
-msgid "specify a custom command for viewing diffs"
-msgstr "ange eget kommando för att visa diffar"
+#: builtin/grep.c:841
+msgid "descend at most <depth> levels"
+msgstr "gå som mest ned <djup> nivåer"
 
-#: builtin/difftool.c:738
-msgid "no <tool> given for --tool=<tool>"
-msgstr "inget <verktyg> angavs för --tool=<verktyg>"
+#: builtin/grep.c:845
+msgid "use extended POSIX regular expressions"
+msgstr "använd utökade POSIX-reguljära uttryck"
 
-#: builtin/difftool.c:745
-msgid "no <cmd> given for --extcmd=<cmd>"
-msgstr "inget <kommando> angavs för --extcmd=<kommando>"
+#: builtin/grep.c:848
+msgid "use basic POSIX regular expressions (default)"
+msgstr "använd grundläggande POSIX-reguljära uttryck (standard)"
 
-#: builtin/fast-export.c:27
-msgid "git fast-export [rev-list-opts]"
-msgstr "git fast-export [rev-list-flaggor]"
+#: builtin/grep.c:851
+msgid "interpret patterns as fixed strings"
+msgstr "tolka mönster som fixerade strängar"
 
-#: builtin/fast-export.c:1000
-msgid "show progress after <n> objects"
-msgstr "visa förlopp efter <n> objekt"
+#: builtin/grep.c:854
+msgid "use Perl-compatible regular expressions"
+msgstr "använd Perlkompatibla reguljära uttryck"
 
-#: builtin/fast-export.c:1002
-msgid "select handling of signed tags"
-msgstr "välj hantering av signerade taggar"
+#: builtin/grep.c:857
+msgid "show line numbers"
+msgstr "visa radnummer"
+
+#: builtin/grep.c:858
+msgid "show column number of first match"
+msgstr "visa kolumnnummer för första träff"
+
+#: builtin/grep.c:859
+msgid "don't show filenames"
+msgstr "visa inte filnamn"
+
+#: builtin/grep.c:860
+msgid "show filenames"
+msgstr "visa filnamn"
+
+#: builtin/grep.c:862
+msgid "show filenames relative to top directory"
+msgstr "visa filnamn relativa till toppkatalogen"
+
+#: builtin/grep.c:864
+msgid "show only filenames instead of matching lines"
+msgstr "visa endast filnamn istället för träffade rader"
 
-#: builtin/fast-export.c:1005
-msgid "select handling of tags that tag filtered objects"
-msgstr "välj hantering av taggar som har taggfiltrerade objekt"
+#: builtin/grep.c:866
+msgid "synonym for --files-with-matches"
+msgstr "synonym för --files-with-matches"
 
-#: builtin/fast-export.c:1008
-msgid "Dump marks to this file"
-msgstr "Dump märken till filen"
+#: builtin/grep.c:869
+msgid "show only the names of files without match"
+msgstr "visa endast namn på filer utan träffar"
 
-#: builtin/fast-export.c:1010
-msgid "Import marks from this file"
-msgstr "Importera märken från filen"
+#: builtin/grep.c:871
+msgid "print NUL after filenames"
+msgstr "skriv NUL efter filnamn"
 
-#: builtin/fast-export.c:1012
-msgid "Fake a tagger when tags lack one"
-msgstr "Fejka taggare när taggen saknar en"
+#: builtin/grep.c:874
+msgid "show only matching parts of a line"
+msgstr "visa endast träffade delar av rader"
 
-#: builtin/fast-export.c:1014
-msgid "Output full tree for each commit"
-msgstr "Skriv ut hela trädet för varje incheckning"
+#: builtin/grep.c:876
+msgid "show the number of matches instead of matching lines"
+msgstr "visa antal träffar istället för träffade rader"
 
-#: builtin/fast-export.c:1016
-msgid "Use the done feature to terminate the stream"
-msgstr "Använd done-funktionen för att avsluta strömmen"
+#: builtin/grep.c:877
+msgid "highlight matches"
+msgstr "ljusmarkera träffar"
 
-#: builtin/fast-export.c:1017
-msgid "Skip output of blob data"
-msgstr "Hoppa över skrivning av blob-data"
+#: builtin/grep.c:879
+msgid "print empty line between matches from different files"
+msgstr "skriv tomma rader mellan träffar från olika filer"
 
-#: builtin/fast-export.c:1018
-msgid "refspec"
-msgstr "referensspecifikation"
+#: builtin/grep.c:881
+msgid "show filename only once above matches from same file"
+msgstr "visa filnamn endast en gång ovanför träffar från samma fil"
 
-#: builtin/fast-export.c:1019
-msgid "Apply refspec to exported refs"
-msgstr "Applicera referensspecifikation på exporterade referenser"
+#: builtin/grep.c:884
+msgid "show <n> context lines before and after matches"
+msgstr "visa <n> rader sammanhang före och efter träffar"
 
-#: builtin/fast-export.c:1020
-msgid "anonymize output"
-msgstr "anonymisera utdata"
+#: builtin/grep.c:887
+msgid "show <n> context lines before matches"
+msgstr "visa <n> rader sammanhang före träffar"
 
-#: builtin/fetch.c:26
-msgid "git fetch [<options>] [<repository> [<refspec>...]]"
-msgstr "git fetch [<flaggor>] [<arkiv> [<refspec>...]]"
+#: builtin/grep.c:889
+msgid "show <n> context lines after matches"
+msgstr "visa <n> rader sammanhang efter träffar"
 
-#: builtin/fetch.c:27
-msgid "git fetch [<options>] <group>"
-msgstr "git fetch [<flaggor>] <grupp>"
+#: builtin/grep.c:891
+msgid "use <n> worker threads"
+msgstr "använd <n> jobbtrådar"
 
-#: builtin/fetch.c:28
-msgid "git fetch --multiple [<options>] [(<repository> | <group>)...]"
-msgstr "git fetch --multiple [<flaggor>] [(<arkiv> | <grupp>)...]"
+#: builtin/grep.c:892
+msgid "shortcut for -C NUM"
+msgstr "genväg för -C NUM"
 
-#: builtin/fetch.c:29
-msgid "git fetch --all [<options>]"
-msgstr "git fetch --all [<flaggor>]"
+#: builtin/grep.c:895
+msgid "show a line with the function name before matches"
+msgstr "visa en rad med funktionsnamnet före träffen"
 
-#: builtin/fetch.c:123 builtin/pull.c:193
-msgid "fetch from all remotes"
-msgstr "hämta från alla fjärrar"
+#: builtin/grep.c:897
+msgid "show the surrounding function"
+msgstr "visa den omkringliggande funktionen"
 
-#: builtin/fetch.c:125 builtin/pull.c:196
-msgid "append to .git/FETCH_HEAD instead of overwriting"
-msgstr "lägg till i .git/FETCH_HEAD istället för att skriva över"
+#: builtin/grep.c:900
+msgid "read patterns from file"
+msgstr "läs mönster från fil"
 
-#: builtin/fetch.c:127 builtin/pull.c:199
-msgid "path to upload pack on remote end"
-msgstr "sökväg till upload pack på fjärren"
+#: builtin/grep.c:902
+msgid "match <pattern>"
+msgstr "träffa <mönster>"
 
-#: builtin/fetch.c:128 builtin/pull.c:201
-msgid "force overwrite of local branch"
-msgstr "tvinga överskrivning av lokal gren"
+#: builtin/grep.c:904
+msgid "combine patterns specified with -e"
+msgstr "kombinera mönster som anges med -e"
 
-#: builtin/fetch.c:130
-msgid "fetch from multiple remotes"
-msgstr "hämta från flera fjärrar"
+#: builtin/grep.c:916
+msgid "indicate hit with exit status without output"
+msgstr "ange träff med slutstatuskod utan utdata"
 
-#: builtin/fetch.c:132 builtin/pull.c:203
-msgid "fetch all tags and associated objects"
-msgstr "hämta alla taggar och associerade objekt"
+#: builtin/grep.c:918
+msgid "show only matches from files that match all patterns"
+msgstr "visa endast träffar från filer som träffar alla mönster"
 
-#: builtin/fetch.c:134
-msgid "do not fetch all tags (--no-tags)"
-msgstr "hämta inte alla taggar (--no-tags)"
+#: builtin/grep.c:920
+msgid "show parse tree for grep expression"
+msgstr "visa analysträd för grep-uttryck"
 
-#: builtin/fetch.c:136
-msgid "number of submodules fetched in parallel"
-msgstr "antal undermoduler som hämtas parallellt"
+#: builtin/grep.c:924
+msgid "pager"
+msgstr "bläddrare"
 
-#: builtin/fetch.c:138 builtin/pull.c:206
-msgid "prune remote-tracking branches no longer on remote"
-msgstr "rensa fjärrspårande grenar ej längre på fjärren"
+#: builtin/grep.c:924
+msgid "show matching files in the pager"
+msgstr "visa träffade filer i filbläddraren"
 
-#: builtin/fetch.c:140
-msgid "prune local tags no longer on remote and clobber changed tags"
-msgstr ""
-"rensa lokala taggar inte längre på fjärren och skriv över ändrade taggar"
+#: builtin/grep.c:928
+msgid "allow calling of grep(1) (ignored by this build)"
+msgstr "tillåt anropa grep(1) (ignoreras av detta bygge)"
 
-#: builtin/fetch.c:141 builtin/fetch.c:164 builtin/pull.c:131
-msgid "on-demand"
-msgstr "on-demand"
+#: builtin/grep.c:992
+msgid "no pattern given"
+msgstr "inget mönster angavs"
 
-#: builtin/fetch.c:142
-msgid "control recursive fetching of submodules"
-msgstr "styr rekursiv hämtning av undermoduler"
+#: builtin/grep.c:1028
+msgid "--no-index or --untracked cannot be used with revs"
+msgstr "--no-index och --untracked kan inte användas med revisioner"
 
-#: builtin/fetch.c:146 builtin/pull.c:214
-msgid "keep downloaded pack"
-msgstr "behåll hämtade paket"
+#: builtin/grep.c:1036
+#, c-format
+msgid "unable to resolve revision: %s"
+msgstr "kan inte slå upp revision: %s"
 
-#: builtin/fetch.c:148
-msgid "allow updating of HEAD ref"
-msgstr "tillåt uppdatering av HEAD-referens"
+#: builtin/grep.c:1067
+msgid "invalid option combination, ignoring --threads"
+msgstr "ogiltig kombination av flaggor, ignorerar --threads"
 
-#: builtin/fetch.c:151 builtin/fetch.c:157 builtin/pull.c:217
-msgid "deepen history of shallow clone"
-msgstr "fördjupa historik för grund klon"
+#: builtin/grep.c:1070 builtin/pack-objects.c:3400
+msgid "no threads support, ignoring --threads"
+msgstr "trådstöd saknas, ignorerar --threads"
 
-#: builtin/fetch.c:153
-msgid "deepen history of shallow repository based on time"
-msgstr "fördjupa historik för grund klon baserad på tid"
+#: builtin/grep.c:1073 builtin/index-pack.c:1531 builtin/pack-objects.c:2705
+#, c-format
+msgid "invalid number of threads specified (%d)"
+msgstr "felaktigt antal trådar angivet (%d)"
 
-#: builtin/fetch.c:159 builtin/pull.c:220
-msgid "convert to a complete repository"
-msgstr "konvertera till komplett arkiv"
+#: builtin/grep.c:1096
+msgid "--open-files-in-pager only works on the worktree"
+msgstr "--open-files-in-pager fungerar endast i arbetskatalogen"
 
-#: builtin/fetch.c:162
-msgid "prepend this to submodule path output"
-msgstr "lägg till i början av undermodulens sökvägsutdata"
+#: builtin/grep.c:1119
+msgid "option not supported with --recurse-submodules"
+msgstr "flaggan stöds inte med --recurse-submodules"
+
+#: builtin/grep.c:1125
+msgid "--cached or --untracked cannot be used with --no-index"
+msgstr "--cached och --untracked kan inte användas med --no-index"
+
+#: builtin/grep.c:1131
+msgid "--[no-]exclude-standard cannot be used for tracked contents"
+msgstr "--[no-]exclude-standard kan inte användas för spårat innehåll"
+
+#: builtin/grep.c:1139
+msgid "both --cached and trees are given"
+msgstr "både --cached och träd angavs"
 
-#: builtin/fetch.c:165
+#: builtin/hash-object.c:85
 msgid ""
-"default for recursive fetching of submodules (lower priority than config "
-"files)"
+"git hash-object [-t <type>] [-w] [--path=<file> | --no-filters] [--stdin] "
+"[--] <file>..."
 msgstr ""
-"standard för rekursiv hämtning av undermoduler (lägre prioritet än "
-"konfigurationsfiler)"
+"git hash-object [-t <typ>] [-w] [--path=<fil> | --no-filters] [--stdin] [--] "
+"<fil>..."
 
-#: builtin/fetch.c:169 builtin/pull.c:223
-msgid "accept refs that update .git/shallow"
-msgstr "tar emot referenser som uppdaterar .git/shallow"
+#: builtin/hash-object.c:86
+msgid "git hash-object  --stdin-paths"
+msgstr "git hash-object  --stdin-paths"
 
-#: builtin/fetch.c:170 builtin/pull.c:225
-msgid "refmap"
-msgstr "referenskarta"
+#: builtin/hash-object.c:98
+msgid "object type"
+msgstr "objekttyp"
 
-#: builtin/fetch.c:171 builtin/pull.c:226
-msgid "specify fetch refmap"
-msgstr "ange referenskarta för \"fetch\""
+#: builtin/hash-object.c:99
+msgid "write the object into the object database"
+msgstr "skriv objektet till objektdatabasen"
 
-#: builtin/fetch.c:172 builtin/ls-remote.c:77 builtin/push.c:582
-#: builtin/send-pack.c:172
-msgid "server-specific"
-msgstr "serverspecifik"
+#: builtin/hash-object.c:101
+msgid "read the object from stdin"
+msgstr "läs objektet från standard in"
 
-#: builtin/fetch.c:172 builtin/ls-remote.c:77 builtin/push.c:582
-#: builtin/send-pack.c:173
-msgid "option to transmit"
+#: builtin/hash-object.c:103
+msgid "store file as is without filters"
+msgstr "spara filen som den är utan filer"
+
+#: builtin/hash-object.c:104
+msgid ""
+"just hash any random garbage to create corrupt objects for debugging Git"
 msgstr ""
-"inget att checka in\n"
-"flagga att sända"
+"hasha slumpmässigt skräp för att skapa korrupta objekt för felsökning av Git"
 
-#: builtin/fetch.c:442
-msgid "Couldn't find remote ref HEAD"
-msgstr "Kunde inte hitta fjärr-referensen HEAD"
+#: builtin/hash-object.c:105
+msgid "process file as it were from this path"
+msgstr "hantera filen som om den kom från sökvägen"
 
-#: builtin/fetch.c:560
-#, c-format
-msgid "configuration fetch.output contains invalid value %s"
-msgstr "konfigurationen för fetch.output innehåller ogiltigt värde %s"
+#: builtin/help.c:46
+msgid "print all available commands"
+msgstr "visa alla tillgängliga kommandon"
 
-#: builtin/fetch.c:653
-#, c-format
-msgid "object %s not found"
-msgstr "objektet %s hittades inte"
+#: builtin/help.c:47
+msgid "exclude guides"
+msgstr "uteslut vägledningar"
 
-#: builtin/fetch.c:657
-msgid "[up to date]"
-msgstr "[àjour]"
+#: builtin/help.c:48
+msgid "print list of useful guides"
+msgstr "lista användbara vägledningar"
 
-#: builtin/fetch.c:670 builtin/fetch.c:750
-msgid "[rejected]"
-msgstr "[refuserad]"
+#: builtin/help.c:49
+msgid "print all configuration variable names"
+msgstr "visa namn på alla konfigurationsvariabler"
 
-#: builtin/fetch.c:671
-msgid "can't fetch in current branch"
-msgstr "kan inte hämta i aktuell gren"
+#: builtin/help.c:51
+msgid "show man page"
+msgstr "visa manualsida"
 
-#: builtin/fetch.c:680
-msgid "[tag update]"
-msgstr "[uppdaterad tagg]"
+#: builtin/help.c:52
+msgid "show manual in web browser"
+msgstr "visa manual i webbläsare"
 
-#: builtin/fetch.c:681 builtin/fetch.c:714 builtin/fetch.c:730
-#: builtin/fetch.c:745
-msgid "unable to update local ref"
-msgstr "kunde inte uppdatera lokal ref"
+#: builtin/help.c:54
+msgid "show info page"
+msgstr "visa info-sida"
 
-#: builtin/fetch.c:700
-msgid "[new tag]"
-msgstr "[ny tagg]"
+#: builtin/help.c:56
+msgid "print command description"
+msgstr "visa kommandobeskrivning"
 
-#: builtin/fetch.c:703
-msgid "[new branch]"
-msgstr "[ny gren]"
+#: builtin/help.c:61
+msgid "git help [--all] [--guides] [--man | --web | --info] [<command>]"
+msgstr "git help [--all] [--guides] [--man | --web | --info] [<kommando>]"
 
-#: builtin/fetch.c:706
-msgid "[new ref]"
-msgstr "[ny ref]"
+#: builtin/help.c:77
+#, c-format
+msgid "unrecognized help format '%s'"
+msgstr "okänt hjälpformat: \"%s\""
 
-#: builtin/fetch.c:745
-msgid "forced update"
-msgstr "tvingad uppdatering"
+#: builtin/help.c:104
+msgid "Failed to start emacsclient."
+msgstr "Misslyckades starta emacsclient."
 
-#: builtin/fetch.c:750
-msgid "non-fast-forward"
-msgstr "ej snabbspolad"
+#: builtin/help.c:117
+msgid "Failed to parse emacsclient version."
+msgstr "Kunde inte tolka emacsclient-version."
 
-#: builtin/fetch.c:795
+#: builtin/help.c:125
 #, c-format
-msgid "%s did not send all necessary objects\n"
-msgstr "%s sände inte alla nödvändiga objekt\n"
+msgid "emacsclient version '%d' too old (< 22)."
+msgstr "emacsclient version \"%d\" för gammal (< 22)."
 
-#: builtin/fetch.c:815
+#: builtin/help.c:143 builtin/help.c:165 builtin/help.c:175 builtin/help.c:183
 #, c-format
-msgid "reject %s because shallow roots are not allowed to be updated"
-msgstr "avvisa %s då grunda rötter inte kan uppdateras"
+msgid "failed to exec '%s'"
+msgstr "exec misslyckades för \"%s\""
 
-#: builtin/fetch.c:903 builtin/fetch.c:999
+#: builtin/help.c:221
 #, c-format
-msgid "From %.*s\n"
-msgstr "Från %.*s\n"
+msgid ""
+"'%s': path for unsupported man viewer.\n"
+"Please consider using 'man.<tool>.cmd' instead."
+msgstr ""
+"\"%s\": sökväg för man-visare som ej stöds.\n"
+"Använd \"man.<verktyg>.cmd\" istället."
 
-#: builtin/fetch.c:914
+#: builtin/help.c:233
 #, c-format
 msgid ""
-"some local refs could not be updated; try running\n"
-" 'git remote prune %s' to remove any old, conflicting branches"
+"'%s': cmd for supported man viewer.\n"
+"Please consider using 'man.<tool>.path' instead."
 msgstr ""
-"vissa lokala referenser kunde inte uppdateras; testa att köra\n"
-" \"git remote prune %s\" för att ta bort gamla grenar som står i konflikt"
+"\"%s\": kommando för man-visare som stöds.\n"
+"Använd \"man.<verktyg>.path\" istället."
 
-#: builtin/fetch.c:969
+#: builtin/help.c:350
 #, c-format
-msgid "   (%s will become dangling)"
-msgstr "   (%s kommer bli dinglande)"
+msgid "'%s': unknown man viewer."
+msgstr "\"%s\": okänd man-visare."
 
-#: builtin/fetch.c:970
-#, c-format
-msgid "   (%s has become dangling)"
-msgstr "   (%s har blivit dinglande)"
+#: builtin/help.c:367
+msgid "no man viewer handled the request"
+msgstr "ingen man-visare hanterade förfrågan"
 
-#: builtin/fetch.c:1002
-msgid "[deleted]"
-msgstr "[borttagen]"
+#: builtin/help.c:375
+msgid "no info viewer handled the request"
+msgstr "ingen info-visare hanterade förfrågan"
 
-#: builtin/fetch.c:1003 builtin/remote.c:1033
-msgid "(none)"
-msgstr "(ingen)"
+#: builtin/help.c:434 builtin/help.c:445 git.c:336
+#, c-format
+msgid "'%s' is aliased to '%s'"
+msgstr "\"%s\" är ett alias för \"%s\""
 
-#: builtin/fetch.c:1026
+#: builtin/help.c:448 git.c:365
 #, c-format
-msgid "Refusing to fetch into current branch %s of non-bare repository"
-msgstr "Vägrar hämta till aktuell gren %s i ett icke-naket arkiv"
+msgid "bad alias.%s string: %s"
+msgstr "felaktig alias.%s-sträng: %s"
 
-#: builtin/fetch.c:1045
+#: builtin/help.c:477 builtin/help.c:507
 #, c-format
-msgid "Option \"%s\" value \"%s\" is not valid for %s"
-msgstr "Flaggan \"%s\" och värdet \"%s\" är inte giltigt för %s"
+msgid "usage: %s%s"
+msgstr "användning: %s%s"
 
-#: builtin/fetch.c:1048
+#: builtin/help.c:491
+msgid "'git help config' for more information"
+msgstr "\"git help config\" för mer information"
+
+#: builtin/index-pack.c:185
 #, c-format
-msgid "Option \"%s\" is ignored for %s\n"
-msgstr "Flaggan \"%s\" ignoreras för %s\n"
+msgid "object type mismatch at %s"
+msgstr "objekttyp stämmer inte överens vid %s"
 
-#: builtin/fetch.c:1287
+#: builtin/index-pack.c:205
 #, c-format
-msgid "Fetching %s\n"
-msgstr "Hämtar %s\n"
+msgid "did not receive expected object %s"
+msgstr "emottog inte det förväntade objektet %s"
 
-#: builtin/fetch.c:1289 builtin/remote.c:98
+#: builtin/index-pack.c:208
 #, c-format
-msgid "Could not fetch %s"
-msgstr "Kunde inte hämta %s"
+msgid "object %s: expected type %s, found %s"
+msgstr "objektet %s: förväntad typ %s, såg %s"
 
-#: builtin/fetch.c:1335 builtin/fetch.c:1503
-msgid ""
-"--filter can only be used with the remote configured in core.partialClone"
-msgstr ""
-"--filter kan endast användas med fjärren konfigurerad i core.partialClone"
+#: builtin/index-pack.c:258
+#, c-format
+msgid "cannot fill %d byte"
+msgid_plural "cannot fill %d bytes"
+msgstr[0] "kan inte fylla %d byte"
+msgstr[1] "kan inte fylla %d byte"
 
-#: builtin/fetch.c:1358
-msgid ""
-"No remote repository specified.  Please, specify either a URL or a\n"
-"remote name from which new revisions should be fetched."
-msgstr ""
-"Inget fjärrarkiv angavs. Ange antingen en URL eller namnet på ett\n"
-"fjärrarkiv som nya incheckningar skall hämtas från."
+#: builtin/index-pack.c:268
+msgid "early EOF"
+msgstr "tidigt filslut"
 
-#: builtin/fetch.c:1395
-msgid "You need to specify a tag name."
-msgstr "Du måste ange namnet på en tagg."
+#: builtin/index-pack.c:269
+msgid "read error on input"
+msgstr "indataläsfel"
 
-#: builtin/fetch.c:1444
-msgid "Negative depth in --deepen is not supported"
-msgstr "Negativa djup stöds inte i --deepen"
+#: builtin/index-pack.c:281
+msgid "used more bytes than were available"
+msgstr "använde fler byte än tillgängligt"
 
-#: builtin/fetch.c:1446
-msgid "--deepen and --depth are mutually exclusive"
-msgstr "--deepen och --depth är ömsesidigt uteslutande"
+#: builtin/index-pack.c:288 builtin/pack-objects.c:604
+msgid "pack too large for current definition of off_t"
+msgstr "paket för stort för nuvarande definition av off_t"
 
-#: builtin/fetch.c:1451
-msgid "--depth and --unshallow cannot be used together"
-msgstr "--depth och --unshallow kan inte användas samtidigt"
+#: builtin/index-pack.c:291 builtin/unpack-objects.c:95
+msgid "pack exceeds maximum allowed size"
+msgstr "paket är större än tillåten maximal storlek"
 
-#: builtin/fetch.c:1453
-msgid "--unshallow on a complete repository does not make sense"
-msgstr "--unshallow kan inte användas på ett komplett arkiv"
+#: builtin/index-pack.c:312
+#, c-format
+msgid "cannot open packfile '%s'"
+msgstr "kan inte öppna paketfilen \"%s\""
 
-#: builtin/fetch.c:1469
-msgid "fetch --all does not take a repository argument"
-msgstr "fetch --all tar inte namnet på ett arkiv som argument"
+#: builtin/index-pack.c:326
+msgid "pack signature mismatch"
+msgstr "paketsignatur stämmer inte överens"
 
-#: builtin/fetch.c:1471
-msgid "fetch --all does not make sense with refspecs"
-msgstr "fetch --all kan inte anges med referensspecifikationer"
+#: builtin/index-pack.c:328
+#, c-format
+msgid "pack version %<PRIu32> unsupported"
+msgstr "paketversion %<PRIu32> stöds ej"
 
-#: builtin/fetch.c:1480
+#: builtin/index-pack.c:346
 #, c-format
-msgid "No such remote or remote group: %s"
-msgstr "Fjärren eller fjärrgruppen finns inte: %s"
+msgid "pack has bad object at offset %<PRIuMAX>: %s"
+msgstr "paketet har felaktigt objekt vid index %<PRIuMAX>: %s"
 
-#: builtin/fetch.c:1487
-msgid "Fetching a group and specifying refspecs does not make sense"
-msgstr "Kan inte hämta från grupp och ange referensspecifikationer"
+#: builtin/index-pack.c:466
+#, c-format
+msgid "inflate returned %d"
+msgstr "inflate returnerade %d"
 
-#: builtin/fmt-merge-msg.c:15
-msgid ""
-"git fmt-merge-msg [-m <message>] [--log[=<n>] | --no-log] [--file <file>]"
-msgstr ""
-"git fmt-merge-msg [-m <meddelande>] [--log[=<n>] | --no-log] [--file <fil>]"
+#: builtin/index-pack.c:515
+msgid "offset value overflow for delta base object"
+msgstr "indexvärdespill för deltabasobjekt"
 
-#: builtin/fmt-merge-msg.c:666
-msgid "populate log with at most <n> entries from shortlog"
-msgstr "fyll i loggen med som mest <n> poster från shortlog"
+#: builtin/index-pack.c:523
+msgid "delta base offset is out of bound"
+msgstr "deltabasindex utanför gränsen"
 
-#: builtin/fmt-merge-msg.c:669
-msgid "alias for --log (deprecated)"
-msgstr "alias för --log (avråds)"
+#: builtin/index-pack.c:531
+#, c-format
+msgid "unknown object type %d"
+msgstr "okänd objekttyp %d"
 
-#: builtin/fmt-merge-msg.c:672
-msgid "text"
-msgstr "text"
+#: builtin/index-pack.c:562
+msgid "cannot pread pack file"
+msgstr "kan inte utföra \"pread\" på paketfil"
 
-#: builtin/fmt-merge-msg.c:673
-msgid "use <text> as start of message"
-msgstr "inled meddelande med <text>"
+#: builtin/index-pack.c:564
+#, c-format
+msgid "premature end of pack file, %<PRIuMAX> byte missing"
+msgid_plural "premature end of pack file, %<PRIuMAX> bytes missing"
+msgstr[0] "för tidigt slut på paketfilen, %<PRIuMAX> byte saknas"
+msgstr[1] "för tidigt slut på paketfilen, %<PRIuMAX> byte saknas"
 
-#: builtin/fmt-merge-msg.c:674
-msgid "file to read from"
-msgstr "fil att läsa från"
+#: builtin/index-pack.c:590
+msgid "serious inflate inconsistency"
+msgstr "allvarlig inflate-inkonsekvens"
 
-#: builtin/for-each-ref.c:10
-msgid "git for-each-ref [<options>] [<pattern>]"
-msgstr "git for-each-ref [<flaggor>] [<mönster>]"
+#: builtin/index-pack.c:735 builtin/index-pack.c:741 builtin/index-pack.c:764
+#: builtin/index-pack.c:803 builtin/index-pack.c:812
+#, c-format
+msgid "SHA1 COLLISION FOUND WITH %s !"
+msgstr "SHA1-KOLLISION UPPTÄCKT VID %s !"
 
-#: builtin/for-each-ref.c:11
-msgid "git for-each-ref [--points-at <object>]"
-msgstr "git for-each-ref [--points-at <objekt>]"
+#: builtin/index-pack.c:738 builtin/pack-objects.c:157
+#: builtin/pack-objects.c:217 builtin/pack-objects.c:311
+#, c-format
+msgid "unable to read %s"
+msgstr "kunde inte läsa %s"
 
-#: builtin/for-each-ref.c:12
-msgid "git for-each-ref [(--merged | --no-merged) [<commit>]]"
-msgstr "git for-each-ref [(--merged | --no-merged) [<incheckning>]]"
+#: builtin/index-pack.c:801
+#, c-format
+msgid "cannot read existing object info %s"
+msgstr "kan inte läsa information om befintligt objekt %s"
 
-#: builtin/for-each-ref.c:13
-msgid "git for-each-ref [--contains [<commit>]] [--no-contains [<commit>]]"
-msgstr ""
-"git for-each-ref [--contains [<incheckning>]] [--no-contains [<incheckning>]]"
+#: builtin/index-pack.c:809
+#, c-format
+msgid "cannot read existing object %s"
+msgstr "kan inte läsa befintligt objekt %s"
 
-#: builtin/for-each-ref.c:28
-msgid "quote placeholders suitably for shells"
-msgstr "citera platshållare passande för skal"
+#: builtin/index-pack.c:823
+#, c-format
+msgid "invalid blob object %s"
+msgstr "ogiltigt blob-objekt %s"
 
-#: builtin/for-each-ref.c:30
-msgid "quote placeholders suitably for perl"
-msgstr "citera platshållare passande för perl"
+#: builtin/index-pack.c:826 builtin/index-pack.c:845
+msgid "fsck error in packed object"
+msgstr "fsck-fel i packat objekt"
 
-#: builtin/for-each-ref.c:32
-msgid "quote placeholders suitably for python"
-msgstr "citera platshållare passande för python"
+#: builtin/index-pack.c:847
+#, c-format
+msgid "Not all child objects of %s are reachable"
+msgstr "Inte alla barnobjekt för %s kan nås"
 
-#: builtin/for-each-ref.c:34
-msgid "quote placeholders suitably for Tcl"
-msgstr "citera platshållare passande för Tcl"
+#: builtin/index-pack.c:919 builtin/index-pack.c:950
+msgid "failed to apply delta"
+msgstr "misslyckades tillämpa delta"
 
-#: builtin/for-each-ref.c:37
-msgid "show only <n> matched refs"
-msgstr "visa endast <n> träffade refs"
+#: builtin/index-pack.c:1118
+msgid "Receiving objects"
+msgstr "Tar emot objekt"
 
-#: builtin/for-each-ref.c:39 builtin/tag.c:421
-msgid "respect format colors"
-msgstr "använd formatfärger"
+#: builtin/index-pack.c:1118
+msgid "Indexing objects"
+msgstr "Skapar index för objekt"
 
-#: builtin/for-each-ref.c:43
-msgid "print only refs which points at the given object"
-msgstr "visa endast referenser som pekar på objektet"
+#: builtin/index-pack.c:1152
+msgid "pack is corrupted (SHA1 mismatch)"
+msgstr "paketet är trasigt (SHA1 stämmer inte)"
 
-#: builtin/for-each-ref.c:45
-msgid "print only refs that are merged"
-msgstr "visa endast referenser som slagits samman"
+#: builtin/index-pack.c:1157
+msgid "cannot fstat packfile"
+msgstr "kan inte utföra \"fstat\" på paketfil"
 
-#: builtin/for-each-ref.c:46
-msgid "print only refs that are not merged"
-msgstr "visa endast referenser som ej slagits samman"
+#: builtin/index-pack.c:1160
+msgid "pack has junk at the end"
+msgstr "paket har skräp i slutet"
 
-#: builtin/for-each-ref.c:47
-msgid "print only refs which contain the commit"
-msgstr "visa endast referenser som innehåller incheckningen"
+#: builtin/index-pack.c:1172
+msgid "confusion beyond insanity in parse_pack_objects()"
+msgstr "förvirrad bortom vanvett i parse_pack_objects()"
 
-#: builtin/for-each-ref.c:48
-msgid "print only refs which don't contain the commit"
-msgstr "visa endast referenser som inte innehåller incheckningen"
+#: builtin/index-pack.c:1195
+msgid "Resolving deltas"
+msgstr "Analyserar delta"
 
-#: builtin/fsck.c:569
-msgid "Checking object directories"
-msgstr "Kontrollerar objektkataloger"
+#: builtin/index-pack.c:1205 builtin/pack-objects.c:2481
+#, c-format
+msgid "unable to create thread: %s"
+msgstr "kunde inte skapa tråd: %s"
 
-#: builtin/fsck.c:661
-msgid "git fsck [<options>] [<object>...]"
-msgstr "git fsck [<flaggor>] [<objekt>...]"
+#: builtin/index-pack.c:1246
+msgid "confusion beyond insanity"
+msgstr "förvirrad bortom vanvett"
 
-#: builtin/fsck.c:667
-msgid "show unreachable objects"
-msgstr "visa onåbara objekt"
+#: builtin/index-pack.c:1252
+#, c-format
+msgid "completed with %d local object"
+msgid_plural "completed with %d local objects"
+msgstr[0] "slutfördes med %d lokalt objekt"
+msgstr[1] "slutfördes med %d lokala objekt"
 
-#: builtin/fsck.c:668
-msgid "show dangling objects"
-msgstr "visa dinglande objekt"
+#: builtin/index-pack.c:1264
+#, c-format
+msgid "Unexpected tail checksum for %s (disk corruption?)"
+msgstr "Oväntad svanschecksumma för %s (trasig disk?)"
 
-#: builtin/fsck.c:669
-msgid "report tags"
-msgstr "rapportera taggar"
+#: builtin/index-pack.c:1268
+#, c-format
+msgid "pack has %d unresolved delta"
+msgid_plural "pack has %d unresolved deltas"
+msgstr[0] "paketet har %d oanalyserat delta"
+msgstr[1] "paketet har %d oanalyserade delta"
 
-#: builtin/fsck.c:670
-msgid "report root nodes"
-msgstr "rapportera rotnoder"
+#: builtin/index-pack.c:1292
+#, c-format
+msgid "unable to deflate appended object (%d)"
+msgstr "kunde inte utföra \"deflate\" på tillagt objekt (%d)"
 
-#: builtin/fsck.c:671
-msgid "make index objects head nodes"
-msgstr "gör indexojekt till huvudnoder"
+#: builtin/index-pack.c:1388
+#, c-format
+msgid "local object %s is corrupt"
+msgstr "lokalt objekt %s är trasigt"
 
-#: builtin/fsck.c:672
-msgid "make reflogs head nodes (default)"
-msgstr "gör refloggar till huvudnoder (standard)"
+#: builtin/index-pack.c:1402
+#, c-format
+msgid "packfile name '%s' does not end with '.pack'"
+msgstr "paketfilnamnet \"%s\" slutar inte med \".pack\""
 
-#: builtin/fsck.c:673
-msgid "also consider packs and alternate objects"
-msgstr "ta även hänsyn till paket och alternativa objekt"
+#: builtin/index-pack.c:1427
+#, c-format
+msgid "cannot write %s file '%s'"
+msgstr "kan inte ta skriva %s-fil \"%s\""
 
-# Vague original, not networking-related, but rather related to the actual
-# objects in the database.
-#: builtin/fsck.c:674
-msgid "check only connectivity"
-msgstr "kontrollera endast konnektivitet"
+#: builtin/index-pack.c:1435
+#, c-format
+msgid "cannot close written %s file '%s'"
+msgstr "kan inte stänga skriven %s-fil \"%s\""
 
-#: builtin/fsck.c:675
-msgid "enable more strict checking"
-msgstr "aktivera striktare kontroll"
+#: builtin/index-pack.c:1459
+msgid "error while closing pack file"
+msgstr "fel vid stängning av paketfil"
 
-#: builtin/fsck.c:677
-msgid "write dangling objects in .git/lost-found"
-msgstr "skriv dinglande objekt i .git/lost-found"
+#: builtin/index-pack.c:1473
+msgid "cannot store pack file"
+msgstr "kan inte spara paketfil"
 
-#: builtin/fsck.c:678 builtin/prune.c:109
-msgid "show progress"
-msgstr "visa förlopp"
+#: builtin/index-pack.c:1481
+msgid "cannot store index file"
+msgstr "kan inte spara indexfil"
 
-#: builtin/fsck.c:679
-msgid "show verbose names for reachable objects"
-msgstr "visa ordrika namn för nåbara objekt"
+#: builtin/index-pack.c:1525 builtin/pack-objects.c:2716
+#, c-format
+msgid "bad pack.indexversion=%<PRIu32>"
+msgstr "felaktig pack.indexversion=%<PRIu32>"
 
-#: builtin/fsck.c:745
-msgid "Checking objects"
-msgstr "Kontrollerar objekt"
+#: builtin/index-pack.c:1593
+#, c-format
+msgid "Cannot open existing pack file '%s'"
+msgstr "Kan inte öppna befintlig paketfil \"%s\""
 
-#: builtin/gc.c:33
-msgid "git gc [<options>]"
-msgstr "git gc [<flaggor>]"
+#: builtin/index-pack.c:1595
+#, c-format
+msgid "Cannot open existing pack idx file for '%s'"
+msgstr "Kan inte öppna befintlig paket-idx-fil för \"%s\""
 
-#: builtin/gc.c:88
+#: builtin/index-pack.c:1643
 #, c-format
-msgid "Failed to fstat %s: %s"
-msgstr "Misslyckades ta status (fstat) på %s: %s"
+msgid "non delta: %d object"
+msgid_plural "non delta: %d objects"
+msgstr[0] "icke-delta: %d objekt"
+msgstr[1] "icke-delta: %d objekt"
 
-#: builtin/gc.c:452
+#: builtin/index-pack.c:1650
 #, c-format
-msgid "Can't stat %s"
-msgstr "Kan inte ta status på %s"
+msgid "chain length = %d: %lu object"
+msgid_plural "chain length = %d: %lu objects"
+msgstr[0] "kedjelängd = %d: %lu objekt"
+msgstr[1] "kedjelängd = %d: %lu objekt"
+
+#: builtin/index-pack.c:1689
+msgid "Cannot come back to cwd"
+msgstr "Kan inte gå tillbaka till arbetskatalogen (cwd)"
 
-#: builtin/gc.c:461
+#: builtin/index-pack.c:1738 builtin/index-pack.c:1741
+#: builtin/index-pack.c:1757 builtin/index-pack.c:1761
 #, c-format
-msgid ""
-"The last gc run reported the following. Please correct the root cause\n"
-"and remove %s.\n"
-"Automatic cleanup will not be performed until the file is removed.\n"
-"\n"
-"%s"
-msgstr ""
-"Senaste körningen av git gc rapporterade följande. Fixa grundproblemet\n"
-"och ta bort %s.\n"
-"Automatisk städning kommer inte utföras förrän filen tas bort.\n"
-"\n"
-"%s"
+msgid "bad %s"
+msgstr "felaktig %s"
 
-#: builtin/gc.c:502
-msgid "prune unreferenced objects"
-msgstr "rensa ej refererade objekt"
+#: builtin/index-pack.c:1777
+msgid "--fix-thin cannot be used without --stdin"
+msgstr "--fix-thin kan inte användas med --stdin"
 
-#: builtin/gc.c:504
-msgid "be more thorough (increased runtime)"
-msgstr "var mer grundlig (ökar körtiden)"
+#: builtin/index-pack.c:1779
+msgid "--stdin requires a git repository"
+msgstr "--stdin kräver ett git-arkiv"
 
-#: builtin/gc.c:505
-msgid "enable auto-gc mode"
-msgstr "aktivera auto-gc-läge"
+#: builtin/index-pack.c:1785
+msgid "--verify with no packfile name given"
+msgstr "--verify angavs utan paketfilnamn"
 
-#: builtin/gc.c:508
-msgid "force running gc even if there may be another gc running"
-msgstr "tvinga gc-körning även om en annan gc kanske körs"
+#: builtin/index-pack.c:1833 builtin/unpack-objects.c:581
+msgid "fsck error in pack objects"
+msgstr "fsck-fel i packat objekt"
 
-#: builtin/gc.c:511
-msgid "repack all other packs except the largest pack"
-msgstr "packa om alla paket förutom det största paketet"
+#: builtin/init-db.c:61
+#, c-format
+msgid "cannot stat template '%s'"
+msgstr "kan inte ta status på mallen \"%s\""
 
-#: builtin/gc.c:528
+#: builtin/init-db.c:66
 #, c-format
-msgid "failed to parse gc.logexpiry value %s"
-msgstr "kunde inte tolka värdet %s för gc.logexpiry"
+msgid "cannot opendir '%s'"
+msgstr "kan inte öppna katalogen (opendir) \"%s\""
 
-#: builtin/gc.c:539
+#: builtin/init-db.c:78
 #, c-format
-msgid "failed to parse prune expiry value %s"
-msgstr "kunde inte tolka värdet %s för prune expiry"
+msgid "cannot readlink '%s'"
+msgstr "kan inte läsa länk (readlink) \"%s\""
 
-#: builtin/gc.c:559
+#: builtin/init-db.c:80
 #, c-format
-msgid "Auto packing the repository in background for optimum performance.\n"
-msgstr "Packar arkivet automatiskt i bakgrunden för optimal prestanda.\n"
+msgid "cannot symlink '%s' '%s'"
+msgstr "kan inte skapa symbolisk länk \"%s\" \"%s\""
 
-#: builtin/gc.c:561
+#: builtin/init-db.c:86
 #, c-format
-msgid "Auto packing the repository for optimum performance.\n"
-msgstr "Packar arkivet automatiskt för optimal prestanda.\n"
+msgid "cannot copy '%s' to '%s'"
+msgstr "kan inte kopiera \"%s\" till \"%s\""
 
-#: builtin/gc.c:562
+#: builtin/init-db.c:90
 #, c-format
-msgid "See \"git help gc\" for manual housekeeping.\n"
-msgstr "Se \"git help gc\" för manuell hushållning.\n"
+msgid "ignoring template %s"
+msgstr "ignorerar mallen %s"
 
-#: builtin/gc.c:598
+#: builtin/init-db.c:121
 #, c-format
-msgid ""
-"gc is already running on machine '%s' pid %<PRIuMAX> (use --force if not)"
-msgstr ""
-"gc körs redan på maskinen \"%s\" pid %<PRIuMAX> (använd --force om så inte "
-"är fallet)"
+msgid "templates not found in %s"
+msgstr "mallarna hittades inte i %s"
 
-#: builtin/gc.c:645
-msgid ""
-"There are too many unreachable loose objects; run 'git prune' to remove them."
-msgstr ""
-"Det finns för många onåbara lösa objekt; kör \"git prune\" för att ta bort "
-"dem."
+#: builtin/init-db.c:136
+#, c-format
+msgid "not copying templates from '%s': %s"
+msgstr "kopierade inte mallar från \"%s\": %s"
 
-#: builtin/grep.c:28
-msgid "git grep [<options>] [-e] <pattern> [<rev>...] [[--] <path>...]"
-msgstr "git grep [<flaggor>] [-e] <mönster> [<rev>...] [[--] <sökväg>...]"
+#: builtin/init-db.c:334
+#, c-format
+msgid "unable to handle file type %d"
+msgstr "kan inte hantera filtyp %d"
 
-#: builtin/grep.c:226
+#: builtin/init-db.c:337
 #, c-format
-msgid "grep: failed to create thread: %s"
-msgstr "grep: misslyckades skapa tråd. %s"
+msgid "unable to move %s to %s"
+msgstr "kan inte flytta %s till %s"
 
-#: builtin/grep.c:284
+#: builtin/init-db.c:354 builtin/init-db.c:357
 #, c-format
-msgid "invalid number of threads specified (%d) for %s"
-msgstr "felaktigt antal trådar angivet (%d) för %s"
+msgid "%s already exists"
+msgstr "%s finns redan"
 
-#. TRANSLATORS: %s is the configuration
-#. variable for tweaking threads, currently
-#. grep.threads
-#.
-#: builtin/grep.c:293 builtin/index-pack.c:1531 builtin/index-pack.c:1723
+#: builtin/init-db.c:413
 #, c-format
-msgid "no threads support, ignoring %s"
-msgstr "trådstöd saknas, ignorerar %s"
+msgid "Reinitialized existing shared Git repository in %s%s\n"
+msgstr "Ominitierade befintligt delat Git-arkiv i %s%s\n"
 
-#: builtin/grep.c:461 builtin/grep.c:582 builtin/grep.c:623
+#: builtin/init-db.c:414
 #, c-format
-msgid "unable to read tree (%s)"
-msgstr "kunde inte läsa träd (%s)"
+msgid "Reinitialized existing Git repository in %s%s\n"
+msgstr "Ominitierade befintligt Git-arkiv i %s%s\n"
 
-#: builtin/grep.c:638
+#: builtin/init-db.c:418
 #, c-format
-msgid "unable to grep from object of type %s"
-msgstr "kunde inte \"grep\" från objekt av typen %s"
+msgid "Initialized empty shared Git repository in %s%s\n"
+msgstr "Initierade tomt delat Git-arkiv i %s%s\n"
 
-#: builtin/grep.c:703
+#: builtin/init-db.c:419
 #, c-format
-msgid "switch `%c' expects a numerical value"
-msgstr "flaggan \"%c\" antar ett numeriskt värde"
+msgid "Initialized empty Git repository in %s%s\n"
+msgstr "Initierade tomt Git-arkiv i %s%s\n"
 
-#: builtin/grep.c:790
-msgid "search in index instead of in the work tree"
-msgstr "sök i indexet istället för i arbetskatalogen"
+#: builtin/init-db.c:468
+msgid ""
+"git init [-q | --quiet] [--bare] [--template=<template-directory>] [--"
+"shared[=<permissions>]] [<directory>]"
+msgstr ""
+"git init [-q | --quiet] [--bare] [--template=<mallkatalog>] [--"
+"shared[=<behörigheter>]] [<katalog>]"
 
-#: builtin/grep.c:792
-msgid "find in contents not managed by git"
-msgstr "sök i innehåll som inte hanteras av git"
+#: builtin/init-db.c:491
+msgid "permissions"
+msgstr "behörigheter"
 
-#: builtin/grep.c:794
-msgid "search in both tracked and untracked files"
-msgstr "sök i både spårade och ospårade filer"
+#: builtin/init-db.c:492
+msgid "specify that the git repository is to be shared amongst several users"
+msgstr "ange att git-arkivet skall delas bland flera användare"
 
-#: builtin/grep.c:796
-msgid "ignore files specified via '.gitignore'"
-msgstr "ignorera filer angivna i \".gitignore\""
+#: builtin/init-db.c:529 builtin/init-db.c:534
+#, c-format
+msgid "cannot mkdir %s"
+msgstr "kan inte skapa katalogen (mkdir) %s"
 
-#: builtin/grep.c:798
-msgid "recursively search in each submodule"
-msgstr "sök varje undermodul rekursivt"
+#: builtin/init-db.c:538
+#, c-format
+msgid "cannot chdir to %s"
+msgstr "kan inte byta katalog (chdir) till %s"
 
-#: builtin/grep.c:801
-msgid "show non-matching lines"
-msgstr "visa rader som inte träffas"
+#: builtin/init-db.c:559
+#, c-format
+msgid ""
+"%s (or --work-tree=<directory>) not allowed without specifying %s (or --git-"
+"dir=<directory>)"
+msgstr ""
+"%s (eller --work-tree=<katalog>) inte tillåtet utan att ange %s (eller --git-"
+"dir=<katalog>)"
 
-#: builtin/grep.c:803
-msgid "case insensitive matching"
-msgstr "skiftlägesokänslig sökning"
+#: builtin/init-db.c:587
+#, c-format
+msgid "Cannot access work tree '%s'"
+msgstr "Kan inte komma åt arbetskatalogen \"%s\""
 
-#: builtin/grep.c:805
-msgid "match patterns only at word boundaries"
-msgstr "matcha endast mönster vid ordgränser"
+#: builtin/interpret-trailers.c:16
+msgid ""
+"git interpret-trailers [--in-place] [--trim-empty] [(--trailer "
+"<token>[(=|:)<value>])...] [<file>...]"
+msgstr ""
+"git interpret-trailers [--in-place] [--trim-empty] [(--trailer "
+"<symbol>[(=|:)<värde>])...] [<fil>...]"
 
-#: builtin/grep.c:807
-msgid "process binary files as text"
-msgstr "hantera binärfiler som text"
+#: builtin/interpret-trailers.c:95
+msgid "edit files in place"
+msgstr "redigera filer på plats"
 
-#: builtin/grep.c:809
-msgid "don't match patterns in binary files"
-msgstr "träffa inte mönster i binärfiler"
+#: builtin/interpret-trailers.c:96
+msgid "trim empty trailers"
+msgstr "ta bort tomma släprader"
 
-#: builtin/grep.c:812
-msgid "process binary files with textconv filters"
-msgstr "hantera binärfiler med textconv-filter"
+#: builtin/interpret-trailers.c:99
+msgid "where to place the new trailer"
+msgstr "var nya släprader skall placeras"
 
-#: builtin/grep.c:814
-msgid "descend at most <depth> levels"
-msgstr "gå som mest ned <djup> nivåer"
+#: builtin/interpret-trailers.c:101
+msgid "action if trailer already exists"
+msgstr "att göra om släprader redan finns"
 
-#: builtin/grep.c:818
-msgid "use extended POSIX regular expressions"
-msgstr "använd utökade POSIX-reguljära uttryck"
+#: builtin/interpret-trailers.c:103
+msgid "action if trailer is missing"
+msgstr "att göra om släprader saknas"
 
-#: builtin/grep.c:821
-msgid "use basic POSIX regular expressions (default)"
-msgstr "använd grundläggande POSIX-reguljära uttryck (standard)"
+#: builtin/interpret-trailers.c:105
+msgid "output only the trailers"
+msgstr "visa endast släprader"
 
-#: builtin/grep.c:824
-msgid "interpret patterns as fixed strings"
-msgstr "tolka mönster som fixerade strängar"
+#: builtin/interpret-trailers.c:106
+msgid "do not apply config rules"
+msgstr "använd inte regler från konfigurationen"
 
-#: builtin/grep.c:827
-msgid "use Perl-compatible regular expressions"
-msgstr "använd Perlkompatibla reguljära uttryck"
+#: builtin/interpret-trailers.c:107
+msgid "join whitespace-continued values"
+msgstr "slå ihop värden avdelade med blanksteg"
 
-#: builtin/grep.c:830
-msgid "show line numbers"
-msgstr "visa radnummer"
+#: builtin/interpret-trailers.c:108
+msgid "set parsing options"
+msgstr "välj tolkningsalternativ"
 
-#: builtin/grep.c:831
-msgid "don't show filenames"
-msgstr "visa inte filnamn"
+#: builtin/interpret-trailers.c:110
+msgid "do not treat --- specially"
+msgstr "tolka inte --- speciellt"
 
-#: builtin/grep.c:832
-msgid "show filenames"
-msgstr "visa filnamn"
+#: builtin/interpret-trailers.c:111
+msgid "trailer"
+msgstr "släprad"
 
-#: builtin/grep.c:834
-msgid "show filenames relative to top directory"
-msgstr "visa filnamn relativa till toppkatalogen"
+#: builtin/interpret-trailers.c:112
+msgid "trailer(s) to add"
+msgstr "släprad(er) att lägga till"
 
-#: builtin/grep.c:836
-msgid "show only filenames instead of matching lines"
-msgstr "visa endast filnamn istället för träffade rader"
+#: builtin/interpret-trailers.c:123
+msgid "--trailer with --only-input does not make sense"
+msgstr "--trailer med --only-input ger ingen mening"
 
-#: builtin/grep.c:838
-msgid "synonym for --files-with-matches"
-msgstr "synonym för --files-with-matches"
+#: builtin/interpret-trailers.c:133
+msgid "no input file given for in-place editing"
+msgstr "ingen indatafil angiven för redigering på plats"
 
-#: builtin/grep.c:841
-msgid "show only the names of files without match"
-msgstr "visa endast namn på filer utan träffar"
+#: builtin/log.c:56
+msgid "git log [<options>] [<revision-range>] [[--] <path>...]"
+msgstr "git log [<flaggor>] [<versionsintervall>] [[--] <sökväg>...]"
 
-#: builtin/grep.c:843
-msgid "print NUL after filenames"
-msgstr "skriv NUL efter filnamn"
+#: builtin/log.c:57
+msgid "git show [<options>] <object>..."
+msgstr "git show [<flaggor>] <objekt>..."
 
-#: builtin/grep.c:846
-msgid "show the number of matches instead of matching lines"
-msgstr "visa antal träffar istället för träffade rader"
+#: builtin/log.c:110
+#, c-format
+msgid "invalid --decorate option: %s"
+msgstr "ogiltig flagga för --decorate: %s"
 
-#: builtin/grep.c:847
-msgid "highlight matches"
-msgstr "ljusmarkera träffar"
+#: builtin/log.c:174
+msgid "show source"
+msgstr "visa källkod"
 
-#: builtin/grep.c:849
-msgid "print empty line between matches from different files"
-msgstr "skriv tomma rader mellan träffar från olika filer"
+#: builtin/log.c:175
+msgid "Use mail map file"
+msgstr "Använd e-postmappningsfil"
 
-#: builtin/grep.c:851
-msgid "show filename only once above matches from same file"
-msgstr "visa filnamn endast en gång ovanför träffar från samma fil"
+#: builtin/log.c:177
+msgid "only decorate refs that match <pattern>"
+msgstr "dekorera endast referenser som motsvarar <mönster>"
 
-#: builtin/grep.c:854
-msgid "show <n> context lines before and after matches"
-msgstr "visa <n> rader sammanhang före och efter träffar"
+#: builtin/log.c:179
+msgid "do not decorate refs that match <pattern>"
+msgstr "dekorera inte referenser som motsvarar <mönster>"
 
-#: builtin/grep.c:857
-msgid "show <n> context lines before matches"
-msgstr "visa <n> rader sammanhang före träffar"
+#: builtin/log.c:180
+msgid "decorate options"
+msgstr "dekoreringsflaggor"
 
-#: builtin/grep.c:859
-msgid "show <n> context lines after matches"
-msgstr "visa <n> rader sammanhang efter träffar"
+#: builtin/log.c:183
+msgid "Process line range n,m in file, counting from 1"
+msgstr "Behandla radintervallet n,m i filen, med början på 1"
 
-#: builtin/grep.c:861
-msgid "use <n> worker threads"
-msgstr "använd <n> jobbtrådar"
+#: builtin/log.c:281
+#, c-format
+msgid "Final output: %d %s\n"
+msgstr "Slututdata: %d %s\n"
 
-#: builtin/grep.c:862
-msgid "shortcut for -C NUM"
-msgstr "genväg för -C NUM"
+#: builtin/log.c:535
+#, c-format
+msgid "git show %s: bad file"
+msgstr "git show %s: felaktig fil"
 
-#: builtin/grep.c:865
-msgid "show a line with the function name before matches"
-msgstr "visa en rad med funktionsnamnet före träffen"
+#: builtin/log.c:550 builtin/log.c:645
+#, c-format
+msgid "could not read object %s"
+msgstr "kunde inte läsa objektet %s"
 
-#: builtin/grep.c:867
-msgid "show the surrounding function"
-msgstr "visa den omkringliggande funktionen"
+#: builtin/log.c:670
+#, c-format
+msgid "unknown type: %d"
+msgstr "okänd typ: %d"
 
-#: builtin/grep.c:870
-msgid "read patterns from file"
-msgstr "läs mönster från fil"
+#: builtin/log.c:814
+#, c-format
+msgid "%s: invalid cover from description mode"
+msgstr "%s: ogiltigt omslag från beskrivningsläge"
 
-#: builtin/grep.c:872
-msgid "match <pattern>"
-msgstr "träffa <mönster>"
+#: builtin/log.c:821
+msgid "format.headers without value"
+msgstr "format.headers utan värde"
 
-#: builtin/grep.c:874
-msgid "combine patterns specified with -e"
-msgstr "kombinera mönster som anges med -e"
+#: builtin/log.c:936
+msgid "name of output directory is too long"
+msgstr "namnet på utdatakatalogen är för långt"
 
-#: builtin/grep.c:886
-msgid "indicate hit with exit status without output"
-msgstr "ange träff med slutstatuskod utan utdata"
+#: builtin/log.c:952
+#, c-format
+msgid "cannot open patch file %s"
+msgstr "kan inte öppna patchfilen %s"
 
-#: builtin/grep.c:888
-msgid "show only matches from files that match all patterns"
-msgstr "visa endast träffar från filer som träffar alla mönster"
+#: builtin/log.c:969
+msgid "need exactly one range"
+msgstr "behöver precis ett intervall"
 
-#: builtin/grep.c:890
-msgid "show parse tree for grep expression"
-msgstr "visa analysträd för grep-uttryck"
+#: builtin/log.c:979
+msgid "not a range"
+msgstr "inte ett intervall"
 
-#: builtin/grep.c:894
-msgid "pager"
-msgstr "bläddrare"
+#: builtin/log.c:1143
+msgid "cover letter needs email format"
+msgstr "omslagsbrevet behöver e-postformat"
 
-#: builtin/grep.c:894
-msgid "show matching files in the pager"
-msgstr "visa träffade filer i filbläddraren"
+#: builtin/log.c:1149
+msgid "failed to create cover-letter file"
+msgstr "misslyckades skapa fil för omslagsbrev"
 
-#: builtin/grep.c:898
-msgid "allow calling of grep(1) (ignored by this build)"
-msgstr "tillåt anropa grep(1) (ignoreras av detta bygge)"
+#: builtin/log.c:1228
+#, c-format
+msgid "insane in-reply-to: %s"
+msgstr "tokigt in-reply-to: %s"
 
-#: builtin/grep.c:962
-msgid "no pattern given."
-msgstr "inget mönster angavs."
+#: builtin/log.c:1255
+msgid "git format-patch [<options>] [<since> | <revision-range>]"
+msgstr "git format-patch [<flaggor>] [<sedan> | <revisionsintervall>]"
 
-#: builtin/grep.c:994
-msgid "--no-index or --untracked cannot be used with revs"
-msgstr "--no-index och --untracked kan inte användas med revisioner"
+#: builtin/log.c:1313
+msgid "two output directories?"
+msgstr "två utdatakataloger?"
 
-#: builtin/grep.c:1001
+#: builtin/log.c:1424 builtin/log.c:2197 builtin/log.c:2199 builtin/log.c:2211
 #, c-format
-msgid "unable to resolve revision: %s"
-msgstr "kan inte slå upp revision: %s"
+msgid "unknown commit %s"
+msgstr "okänd incheckning %s"
 
-#: builtin/grep.c:1036 builtin/index-pack.c:1527
+#: builtin/log.c:1434 builtin/replace.c:58 builtin/replace.c:207
+#: builtin/replace.c:210
 #, c-format
-msgid "invalid number of threads specified (%d)"
-msgstr "felaktigt antal trådar angivet (%d)"
-
-#: builtin/grep.c:1041
-msgid "no threads support, ignoring --threads"
-msgstr "trådstöd saknas, ignorerar --threads"
-
-#: builtin/grep.c:1065
-msgid "--open-files-in-pager only works on the worktree"
-msgstr "--open-files-in-pager fungerar endast i arbetskatalogen"
+msgid "failed to resolve '%s' as a valid ref"
+msgstr "misslyckades slå upp \"%s\" som en giltig referens"
 
-#: builtin/grep.c:1088
-msgid "option not supported with --recurse-submodules."
-msgstr "flaggan stöds inte med --recurse-submodules."
-
-#: builtin/grep.c:1094
-msgid "--cached or --untracked cannot be used with --no-index."
-msgstr "--cached och --untracked kan inte användas med --no-index."
-
-#: builtin/grep.c:1100
-msgid "--[no-]exclude-standard cannot be used for tracked contents."
-msgstr "--[no-]exclude-standard kan inte användas för spårat innehåll."
-
-#: builtin/grep.c:1108
-msgid "both --cached and trees are given."
-msgstr "både --cached och träd angavs."
+#: builtin/log.c:1439
+msgid "could not find exact merge base"
+msgstr "kunde inte hitta exakt sammanslagningsbas"
 
-#: builtin/hash-object.c:83
+#: builtin/log.c:1443
 msgid ""
-"git hash-object [-t <type>] [-w] [--path=<file> | --no-filters] [--stdin] "
-"[--] <file>..."
+"failed to get upstream, if you want to record base commit automatically,\n"
+"please use git branch --set-upstream-to to track a remote branch.\n"
+"Or you could specify base commit by --base=<base-commit-id> manually"
 msgstr ""
-"git hash-object [-t <typ>] [-w] [--path=<fil> | --no-filters] [--stdin] [--] "
-"<fil>..."
-
-#: builtin/hash-object.c:84
-msgid "git hash-object  --stdin-paths"
-msgstr "git hash-object  --stdin-paths"
+"kunde inte hämta uppström, om du vill lagra basincheckningen automatiskt,\n"
+"använd git branch --set-upstream-to för att spåra en fjärrgren.\n"
+"Eller så kan du ange basincheckning med --base=<bas-inchecknings-id> manuellt"
 
-#: builtin/hash-object.c:96
-msgid "type"
-msgstr "typ"
+#: builtin/log.c:1463
+msgid "failed to find exact merge base"
+msgstr "kunde inte hitta exakt sammanslagningsbas"
 
-#: builtin/hash-object.c:96
-msgid "object type"
-msgstr "objekttyp"
+#: builtin/log.c:1474
+msgid "base commit should be the ancestor of revision list"
+msgstr "basincheckningen bör vara förfader till revisionslistan"
 
-#: builtin/hash-object.c:97
-msgid "write the object into the object database"
-msgstr "skriv objektet till objektdatabasen"
+#: builtin/log.c:1478
+msgid "base commit shouldn't be in revision list"
+msgstr "basincheckningen bör inte vara i revisionslistan"
 
-#: builtin/hash-object.c:99
-msgid "read the object from stdin"
-msgstr "läs objektet från standard in"
+#: builtin/log.c:1531
+msgid "cannot get patch id"
+msgstr "kan inte hämta patch-id"
 
-#: builtin/hash-object.c:101
-msgid "store file as is without filters"
-msgstr "spara filen som den är utan filer"
+#: builtin/log.c:1583
+msgid "failed to infer range-diff ranges"
+msgstr "misslyckades räkna ut intervall range-diff"
 
-#: builtin/hash-object.c:102
-msgid ""
-"just hash any random garbage to create corrupt objects for debugging Git"
-msgstr ""
-"hasha slumpmässigt skräp för att skapa korrupta objekt för felsökning av Git"
+#: builtin/log.c:1629
+msgid "use [PATCH n/m] even with a single patch"
+msgstr "använd [PATCH n/m] även för en ensam patch"
 
-#: builtin/hash-object.c:103
-msgid "process file as it were from this path"
-msgstr "hantera filen som om den kom från sökvägen"
+#: builtin/log.c:1632
+msgid "use [PATCH] even with multiple patches"
+msgstr "använd [PATCH] även för flera patchar"
 
-#: builtin/help.c:45
-msgid "print all available commands"
-msgstr "visa alla tillgängliga kommandon"
+#: builtin/log.c:1636
+msgid "print patches to standard out"
+msgstr "skriv patcharna på standard ut"
 
-#: builtin/help.c:46
-msgid "exclude guides"
-msgstr "uteslut vägledningar"
+#: builtin/log.c:1638
+msgid "generate a cover letter"
+msgstr "generera ett följebrev"
 
-#: builtin/help.c:47
-msgid "print list of useful guides"
-msgstr "lista användbara vägledningar"
+#: builtin/log.c:1640
+msgid "use simple number sequence for output file names"
+msgstr "använd enkel nummersekvens för utdatafilnamn"
 
-#: builtin/help.c:48
-msgid "show man page"
-msgstr "visa manualsida"
+#: builtin/log.c:1641
+msgid "sfx"
+msgstr "sfx"
 
-#: builtin/help.c:49
-msgid "show manual in web browser"
-msgstr "visa manual i webbläsare"
+#: builtin/log.c:1642
+msgid "use <sfx> instead of '.patch'"
+msgstr "använd <sfx> istället för \".patch\""
 
-#: builtin/help.c:51
-msgid "show info page"
-msgstr "visa info-sida"
+#: builtin/log.c:1644
+msgid "start numbering patches at <n> instead of 1"
+msgstr "börja numrera patchar på <n> istället för 1"
 
-#: builtin/help.c:53
-msgid "print command description"
-msgstr "visa kommandobeskrivning"
+#: builtin/log.c:1646
+msgid "mark the series as Nth re-roll"
+msgstr "markera serien som N:te försök"
 
-#: builtin/help.c:58
-msgid "git help [--all] [--guides] [--man | --web | --info] [<command>]"
-msgstr "git help [--all] [--guides] [--man | --web | --info] [<kommando>]"
+#: builtin/log.c:1648
+msgid "Use [RFC PATCH] instead of [PATCH]"
+msgstr "Använd  [RFC PATCH] istället för [PATCH]"
 
-#: builtin/help.c:70
-#, c-format
-msgid "unrecognized help format '%s'"
-msgstr "okänt hjälpformat: ”%s”"
+#: builtin/log.c:1651
+msgid "cover-from-description-mode"
+msgstr "cover-from-description-läge"
+
+#: builtin/log.c:1652
+msgid "generate parts of a cover letter based on a branch's description"
+msgstr "skapa delar av omslagsbrevet baserat på grenbeskrivelsen"
 
-#: builtin/help.c:97
-msgid "Failed to start emacsclient."
-msgstr "Misslyckades starta emacsclient."
+#: builtin/log.c:1654
+msgid "Use [<prefix>] instead of [PATCH]"
+msgstr "Använd [<prefix>] istället för [PATCH]"
 
-#: builtin/help.c:110
-msgid "Failed to parse emacsclient version."
-msgstr "Kunde inte tolka emacsclient-version."
+#: builtin/log.c:1657
+msgid "store resulting files in <dir>"
+msgstr "spara filerna i <katalog>"
 
-#: builtin/help.c:118
-#, c-format
-msgid "emacsclient version '%d' too old (< 22)."
-msgstr "emacsclient version \"%d\" för gammal (< 22)."
+#: builtin/log.c:1660
+msgid "don't strip/add [PATCH]"
+msgstr "ta inte bort eller lägg till [PATCH]"
 
-#: builtin/help.c:136 builtin/help.c:158 builtin/help.c:168 builtin/help.c:176
-#, c-format
-msgid "failed to exec '%s'"
-msgstr "exec misslyckades för \"%s\""
+#: builtin/log.c:1663
+msgid "don't output binary diffs"
+msgstr "skriv inte binära diffar"
 
-#: builtin/help.c:214
-#, c-format
-msgid ""
-"'%s': path for unsupported man viewer.\n"
-"Please consider using 'man.<tool>.cmd' instead."
-msgstr ""
-"\"%s\": sökväg för man-visare som ej stöds.\n"
-"Använd \"man.<verktyg>.cmd\" istället."
+#: builtin/log.c:1665
+msgid "output all-zero hash in From header"
+msgstr "använd hashvärde med nollor i From-huvud"
 
-#: builtin/help.c:226
-#, c-format
-msgid ""
-"'%s': cmd for supported man viewer.\n"
-"Please consider using 'man.<tool>.path' instead."
-msgstr ""
-"\"%s\": kommando för man-visare som stöds.\n"
-"Använd \"man.<verktyg>.path\" istället."
+#: builtin/log.c:1667
+msgid "don't include a patch matching a commit upstream"
+msgstr "ta inte med patchar som motsvarar en uppströmsincheckning"
 
-#: builtin/help.c:343
-#, c-format
-msgid "'%s': unknown man viewer."
-msgstr "\"%s\": okänd man-visare."
+#: builtin/log.c:1669
+msgid "show patch format instead of default (patch + stat)"
+msgstr "visa patchformat istället för standard (patch + stat)"
 
-#: builtin/help.c:360
-msgid "no man viewer handled the request"
-msgstr "ingen man-visare hanterade förfrågan"
+#: builtin/log.c:1671
+msgid "Messaging"
+msgstr "E-post"
 
-#: builtin/help.c:368
-msgid "no info viewer handled the request"
-msgstr "ingen info-visare hanterade förfrågan"
+#: builtin/log.c:1672
+msgid "header"
+msgstr "huvud"
 
-#: builtin/help.c:415
-#, c-format
-msgid "'%s' is aliased to '%s'"
-msgstr "\"%s\" är ett alias för \"%s\""
+#: builtin/log.c:1673
+msgid "add email header"
+msgstr "lägg till e-posthuvud"
 
-#: builtin/help.c:442 builtin/help.c:459
-#, c-format
-msgid "usage: %s%s"
-msgstr "användning: %s%s"
+#: builtin/log.c:1674 builtin/log.c:1676
+msgid "email"
+msgstr "epost"
 
-#: builtin/index-pack.c:158
-#, c-format
-msgid "unable to open %s"
-msgstr "kunde inte öppna %s"
+#: builtin/log.c:1674
+msgid "add To: header"
+msgstr "lägg till mottagarhuvud (\"To:\")"
 
-#: builtin/index-pack.c:208
-#, c-format
-msgid "object type mismatch at %s"
-msgstr "objekttyp stämmer inte överens vid %s"
+#: builtin/log.c:1676
+msgid "add Cc: header"
+msgstr "lägg till kopiehuvud (\"Cc:\")"
 
-#: builtin/index-pack.c:228
-#, c-format
-msgid "did not receive expected object %s"
-msgstr "emottog inte det förväntade objektet %s"
+#: builtin/log.c:1678
+msgid "ident"
+msgstr "ident"
 
-#: builtin/index-pack.c:231
-#, c-format
-msgid "object %s: expected type %s, found %s"
-msgstr "objektet %s: förväntad typ %s, såg %s"
+#: builtin/log.c:1679
+msgid "set From address to <ident> (or committer ident if absent)"
+msgstr "sätt Från-adress till <ident> (eller incheckare om ident saknas)"
 
-#: builtin/index-pack.c:273
-#, c-format
-msgid "cannot fill %d byte"
-msgid_plural "cannot fill %d bytes"
-msgstr[0] "kan inte fylla %d byte"
-msgstr[1] "kan inte fylla %d byte"
+#: builtin/log.c:1681
+msgid "message-id"
+msgstr "meddelande-id"
 
-#: builtin/index-pack.c:283
-msgid "early EOF"
-msgstr "tidigt filslut"
+#: builtin/log.c:1682
+msgid "make first mail a reply to <message-id>"
+msgstr "gör det första brevet ett svar till <meddelande-id>"
 
-#: builtin/index-pack.c:284
-msgid "read error on input"
-msgstr "indataläsfel"
+#: builtin/log.c:1683 builtin/log.c:1686
+msgid "boundary"
+msgstr "gräns"
 
-#: builtin/index-pack.c:296
-msgid "used more bytes than were available"
-msgstr "använde fler byte än tillgängligt"
+#: builtin/log.c:1684
+msgid "attach the patch"
+msgstr "bifoga patchen"
 
-#: builtin/index-pack.c:303
-msgid "pack too large for current definition of off_t"
-msgstr "paket för stort för nuvarande definition av off_t"
+#: builtin/log.c:1687
+msgid "inline the patch"
+msgstr "gör patchen ett inline-objekt"
 
-#: builtin/index-pack.c:306 builtin/unpack-objects.c:93
-msgid "pack exceeds maximum allowed size"
-msgstr "paket är större än tillåten maximal storlek"
+#: builtin/log.c:1691
+msgid "enable message threading, styles: shallow, deep"
+msgstr "aktivera brevtrådning, typer: shallow, deep"
 
-#: builtin/index-pack.c:321
-#, c-format
-msgid "unable to create '%s'"
-msgstr "kunde inte skapa \"%s\""
+#: builtin/log.c:1693
+msgid "signature"
+msgstr "signatur"
 
-#: builtin/index-pack.c:327
-#, c-format
-msgid "cannot open packfile '%s'"
-msgstr "kan inte öppna paketfilen \"%s\""
+#: builtin/log.c:1694
+msgid "add a signature"
+msgstr "lägg till signatur"
 
-#: builtin/index-pack.c:341
-msgid "pack signature mismatch"
-msgstr "paketsignatur stämmer inte överens"
+#: builtin/log.c:1695
+msgid "base-commit"
+msgstr "basincheckning"
 
-#: builtin/index-pack.c:343
-#, c-format
-msgid "pack version %<PRIu32> unsupported"
-msgstr "paketversion %<PRIu32> stöds ej"
+#: builtin/log.c:1696
+msgid "add prerequisite tree info to the patch series"
+msgstr "lägg till förhandskrävd trädinfo i patchserien"
 
-#: builtin/index-pack.c:361
-#, c-format
-msgid "pack has bad object at offset %<PRIuMAX>: %s"
-msgstr "paketet har felaktigt objekt vid index %<PRIuMAX>: %s"
+#: builtin/log.c:1698
+msgid "add a signature from a file"
+msgstr "lägg till signatur från fil"
 
-#: builtin/index-pack.c:482
-#, c-format
-msgid "inflate returned %d"
-msgstr "inflate returnerade %d"
+#: builtin/log.c:1699
+msgid "don't print the patch filenames"
+msgstr "visa inte filnamn för patchar"
 
-#: builtin/index-pack.c:531
-msgid "offset value overflow for delta base object"
-msgstr "indexvärdespill för deltabasobjekt"
+#: builtin/log.c:1701
+msgid "show progress while generating patches"
+msgstr "visa förloppsindikator medan patchar skapas"
 
-#: builtin/index-pack.c:539
-msgid "delta base offset is out of bound"
-msgstr "deltabasindex utanför gränsen"
+#: builtin/log.c:1703
+msgid "show changes against <rev> in cover letter or single patch"
+msgstr "visa ändringar mot <rev> i omslagsbrev eller ensam patch"
+
+#: builtin/log.c:1706
+msgid "show changes against <refspec> in cover letter or single patch"
+msgstr "visa ändringar mot <refspec> i omslagsbrev eller ensam patch"
+
+#: builtin/log.c:1708
+msgid "percentage by which creation is weighted"
+msgstr "procent som skapelse vägs med"
 
-#: builtin/index-pack.c:547
+#: builtin/log.c:1792
 #, c-format
-msgid "unknown object type %d"
-msgstr "okänd objekttyp %d"
+msgid "invalid ident line: %s"
+msgstr "ogiltig ident-rad: %s"
 
-#: builtin/index-pack.c:578
-msgid "cannot pread pack file"
-msgstr "kan inte utföra \"pread\" på paketfil"
+#: builtin/log.c:1807
+msgid "-n and -k are mutually exclusive"
+msgstr "-n och -k kan inte användas samtidigt"
+
+#: builtin/log.c:1809
+msgid "--subject-prefix/--rfc and -k are mutually exclusive"
+msgstr "--subject-prefix/--rfc och -k kan inte användas samtidigt"
 
-#: builtin/index-pack.c:580
-#, c-format
-msgid "premature end of pack file, %<PRIuMAX> byte missing"
-msgid_plural "premature end of pack file, %<PRIuMAX> bytes missing"
-msgstr[0] "för tidigt slut på paketfilen, %<PRIuMAX> byte saknas"
-msgstr[1] "för tidigt slut på paketfilen, %<PRIuMAX> byte saknas"
+#: builtin/log.c:1817
+msgid "--name-only does not make sense"
+msgstr "kan inte använda --name-only"
 
-#: builtin/index-pack.c:606
-msgid "serious inflate inconsistency"
-msgstr "allvarlig inflate-inkonsekvens"
+#: builtin/log.c:1819
+msgid "--name-status does not make sense"
+msgstr "kan inte använda --name-status"
 
-#: builtin/index-pack.c:751 builtin/index-pack.c:757 builtin/index-pack.c:780
-#: builtin/index-pack.c:819 builtin/index-pack.c:828
-#, c-format
-msgid "SHA1 COLLISION FOUND WITH %s !"
-msgstr "SHA1-KOLLISION UPPTÄCKT VID %s !"
+#: builtin/log.c:1821
+msgid "--check does not make sense"
+msgstr "kan inte använda --check"
 
-#: builtin/index-pack.c:754 builtin/pack-objects.c:198
-#: builtin/pack-objects.c:292
-#, c-format
-msgid "unable to read %s"
-msgstr "kunde inte läsa %s"
+#: builtin/log.c:1854
+msgid "standard output, or directory, which one?"
+msgstr "standard ut, eller katalog, vilken skall det vara?"
 
-#: builtin/index-pack.c:817
-#, c-format
-msgid "cannot read existing object info %s"
-msgstr "kan inte läsa information om befintligt objekt %s"
+#: builtin/log.c:1958
+msgid "--interdiff requires --cover-letter or single patch"
+msgstr "--interdiff kräver --cover-letter eller ensam patch"
 
-#: builtin/index-pack.c:825
-#, c-format
-msgid "cannot read existing object %s"
-msgstr "kan inte läsa befintligt objekt %s"
+#: builtin/log.c:1962
+msgid "Interdiff:"
+msgstr "Interdiff:"
 
-#: builtin/index-pack.c:839
+#: builtin/log.c:1963
 #, c-format
-msgid "invalid blob object %s"
-msgstr "ogiltigt blob-objekt %s"
+msgid "Interdiff against v%d:"
+msgstr "Interdiff mot v%d:"
 
-#: builtin/index-pack.c:842 builtin/index-pack.c:860
-msgid "fsck error in packed object"
-msgstr "fsck-fel i packat objekt"
+#: builtin/log.c:1969
+msgid "--creation-factor requires --range-diff"
+msgstr "--creation-factor kräver --range-diff"
 
-#: builtin/index-pack.c:857
-#, c-format
-msgid "invalid %s"
-msgstr "ogiltigt %s"
+#: builtin/log.c:1973
+msgid "--range-diff requires --cover-letter or single patch"
+msgstr "--range-diff kräver --cover-letter eller ensam patch"
 
-#: builtin/index-pack.c:862
-#, c-format
-msgid "Not all child objects of %s are reachable"
-msgstr "Inte alla barnobjekt för %s kan nås"
+#: builtin/log.c:1981
+msgid "Range-diff:"
+msgstr "Intervall-diff:"
 
-#: builtin/index-pack.c:934 builtin/index-pack.c:965
-msgid "failed to apply delta"
-msgstr "misslyckades tillämpa delta"
+#: builtin/log.c:1982
+#, c-format
+msgid "Range-diff against v%d:"
+msgstr "Intervall-diff mot v%d:"
 
-#: builtin/index-pack.c:1135
-msgid "Receiving objects"
-msgstr "Tar emot objekt"
+#: builtin/log.c:1993
+#, c-format
+msgid "unable to read signature file '%s'"
+msgstr "kunde inte läsa signaturfil \"%s\""
 
-#: builtin/index-pack.c:1135
-msgid "Indexing objects"
-msgstr "Skapar index för objekt"
+#: builtin/log.c:2029
+msgid "Generating patches"
+msgstr "Skapar patchar"
 
-#: builtin/index-pack.c:1169
-msgid "pack is corrupted (SHA1 mismatch)"
-msgstr "paketet är trasigt (SHA1 stämmer inte)"
+#: builtin/log.c:2073
+msgid "failed to create output files"
+msgstr "misslyckades skapa utdatafiler"
 
-#: builtin/index-pack.c:1174
-msgid "cannot fstat packfile"
-msgstr "kan inte utföra \"fstat\" på paketfil"
+#: builtin/log.c:2132
+msgid "git cherry [-v] [<upstream> [<head> [<limit>]]]"
+msgstr "git cherry [-v] [<uppström> [<huvud> [<gräns>]]]"
 
-#: builtin/index-pack.c:1177
-msgid "pack has junk at the end"
-msgstr "paket har skräp i slutet"
+#: builtin/log.c:2186
+#, c-format
+msgid ""
+"Could not find a tracked remote branch, please specify <upstream> manually.\n"
+msgstr "Kunde inte hitta en spårad fjärrgren, ange <uppström> manuellt.\n"
 
-#: builtin/index-pack.c:1189
-msgid "confusion beyond insanity in parse_pack_objects()"
-msgstr "förvirrad bortom vanvett i parse_pack_objects()"
+#: builtin/ls-files.c:470
+msgid "git ls-files [<options>] [<file>...]"
+msgstr "git ls-files [<flaggor>] [<fil>...]"
 
-#: builtin/index-pack.c:1212
-msgid "Resolving deltas"
-msgstr "Analyserar delta"
+#: builtin/ls-files.c:526
+msgid "identify the file status with tags"
+msgstr "identifiera filstatus med taggar"
 
-#: builtin/index-pack.c:1223
-#, c-format
-msgid "unable to create thread: %s"
-msgstr "kunde inte skapa tråd: %s"
+#: builtin/ls-files.c:528
+msgid "use lowercase letters for 'assume unchanged' files"
+msgstr "använd små bokstäver för \"anta oförändrade\"-filer"
 
-#: builtin/index-pack.c:1265
-msgid "confusion beyond insanity"
-msgstr "förvirrad bortom vanvett"
+#: builtin/ls-files.c:530
+msgid "use lowercase letters for 'fsmonitor clean' files"
+msgstr "använd små bokstäver för \"fsmonitor clean\"-filer"
 
-#: builtin/index-pack.c:1271
-#, c-format
-msgid "completed with %d local object"
-msgid_plural "completed with %d local objects"
-msgstr[0] "slutfördes med %d lokalt objekt"
-msgstr[1] "slutfördes med %d lokala objekt"
+#: builtin/ls-files.c:532
+msgid "show cached files in the output (default)"
+msgstr "visa cachade filer i utdata (standard)"
 
-#: builtin/index-pack.c:1283
-#, c-format
-msgid "Unexpected tail checksum for %s (disk corruption?)"
-msgstr "Oväntad svanschecksumma för %s (trasig disk?)"
+#: builtin/ls-files.c:534
+msgid "show deleted files in the output"
+msgstr "visa borttagna filer i utdata"
 
-#: builtin/index-pack.c:1287
-#, c-format
-msgid "pack has %d unresolved delta"
-msgid_plural "pack has %d unresolved deltas"
-msgstr[0] "paketet har %d oanalyserat delta"
-msgstr[1] "paketet har %d oanalyserade delta"
+#: builtin/ls-files.c:536
+msgid "show modified files in the output"
+msgstr "visa modifierade filer i utdata"
 
-#: builtin/index-pack.c:1311
-#, c-format
-msgid "unable to deflate appended object (%d)"
-msgstr "kunde inte utföra \"deflate\" på tillagt objekt (%d)"
+#: builtin/ls-files.c:538
+msgid "show other files in the output"
+msgstr "visa andra filer i utdata"
 
-#: builtin/index-pack.c:1388
-#, c-format
-msgid "local object %s is corrupt"
-msgstr "lokalt objekt %s är trasigt"
+#: builtin/ls-files.c:540
+msgid "show ignored files in the output"
+msgstr "visa ignorerade filer i utdata"
 
-#: builtin/index-pack.c:1402
-#, c-format
-msgid "packfile name '%s' does not end with '.pack'"
-msgstr "paketfilnamnet \"%s\" slutar inte med \".pack\""
+#: builtin/ls-files.c:543
+msgid "show staged contents' object name in the output"
+msgstr "visa köat innehålls objektnamn i utdata"
 
-#: builtin/index-pack.c:1427
-#, c-format
-msgid "cannot write %s file '%s'"
-msgstr "kan inte ta skriva %s-fil \"%s\""
+#: builtin/ls-files.c:545
+msgid "show files on the filesystem that need to be removed"
+msgstr "visa filer i filsystemet som behöver tas bort"
 
-#: builtin/index-pack.c:1435
-#, c-format
-msgid "cannot close written %s file '%s'"
-msgstr "kan inte stänga skriven %s-fil \"%s\""
+#: builtin/ls-files.c:547
+msgid "show 'other' directories' names only"
+msgstr "visa endast namn för \"andra\" kataloger"
 
-#: builtin/index-pack.c:1459
-msgid "error while closing pack file"
-msgstr "fel vid stängning av paketfil"
+#: builtin/ls-files.c:549
+msgid "show line endings of files"
+msgstr "visa radslut i filer"
 
-#: builtin/index-pack.c:1473
-msgid "cannot store pack file"
-msgstr "kan inte spara paketfil"
+#: builtin/ls-files.c:551
+msgid "don't show empty directories"
+msgstr "visa inte tomma kataloger"
 
-#: builtin/index-pack.c:1481
-msgid "cannot store index file"
-msgstr "kan inte spara indexfil"
+#: builtin/ls-files.c:554
+msgid "show unmerged files in the output"
+msgstr "visa ej sammanslagna filer i utdata"
 
-#: builtin/index-pack.c:1521
-#, c-format
-msgid "bad pack.indexversion=%<PRIu32>"
-msgstr "felaktig pack.indexversion=%<PRIu32>"
+#: builtin/ls-files.c:556
+msgid "show resolve-undo information"
+msgstr "visa \"resolve-undo\"-information"
 
-#: builtin/index-pack.c:1590
-#, c-format
-msgid "Cannot open existing pack file '%s'"
-msgstr "Kan inte öppna befintlig paketfil \"%s\""
+#: builtin/ls-files.c:558
+msgid "skip files matching pattern"
+msgstr "hoppa över filer som motsvarar mönster"
 
-#: builtin/index-pack.c:1592
-#, c-format
-msgid "Cannot open existing pack idx file for '%s'"
-msgstr "Kan inte öppna befintlig paket-idx-fil för \"%s\""
+#: builtin/ls-files.c:561
+msgid "exclude patterns are read from <file>"
+msgstr "exkludera mönster som läses från <fil>"
 
-#: builtin/index-pack.c:1640
-#, c-format
-msgid "non delta: %d object"
-msgid_plural "non delta: %d objects"
-msgstr[0] "icke-delta: %d objekt"
-msgstr[1] "icke-delta: %d objekt"
+#: builtin/ls-files.c:564
+msgid "read additional per-directory exclude patterns in <file>"
+msgstr "läs ytterligare per-katalog-exkluderingsmönster från <fil>"
 
-#: builtin/index-pack.c:1647
-#, c-format
-msgid "chain length = %d: %lu object"
-msgid_plural "chain length = %d: %lu objects"
-msgstr[0] "kedjelängd = %d: %lu objekt"
-msgstr[1] "kedjelängd = %d: %lu objekt"
+#: builtin/ls-files.c:566
+msgid "add the standard git exclusions"
+msgstr "lägg till git:s standardexkluderingar"
 
-#: builtin/index-pack.c:1684
-msgid "Cannot come back to cwd"
-msgstr "Kan inte gå tillbaka till arbetskatalogen (cwd)"
+#: builtin/ls-files.c:570
+msgid "make the output relative to the project top directory"
+msgstr "gör utdata relativ till projektets toppkatalog"
 
-#: builtin/index-pack.c:1735 builtin/index-pack.c:1738
-#: builtin/index-pack.c:1754 builtin/index-pack.c:1758
-#, c-format
-msgid "bad %s"
-msgstr "felaktig %s"
+#: builtin/ls-files.c:573
+msgid "recurse through submodules"
+msgstr "rekursera ner i undermoduler"
 
-#: builtin/index-pack.c:1774
-msgid "--fix-thin cannot be used without --stdin"
-msgstr "--fix-thin kan inte användas med --stdin"
+#: builtin/ls-files.c:575
+msgid "if any <file> is not in the index, treat this as an error"
+msgstr "om en <fil> inte är indexet, betrakta det som ett fel"
 
-#: builtin/index-pack.c:1776
-msgid "--stdin requires a git repository"
-msgstr "--stdin kräver ett git-arkiv"
+#: builtin/ls-files.c:576
+msgid "tree-ish"
+msgstr "träd-igt"
 
-#: builtin/index-pack.c:1782
-msgid "--verify with no packfile name given"
-msgstr "--verify angavs utan paketfilnamn"
+#: builtin/ls-files.c:577
+msgid "pretend that paths removed since <tree-ish> are still present"
+msgstr "låtsas att sökvägar borttagna sedan <träd-igt> fortfarande finns"
 
-#: builtin/index-pack.c:1832 builtin/unpack-objects.c:578
-msgid "fsck error in pack objects"
-msgstr "fsck-fel i packat objekt"
+#: builtin/ls-files.c:579
+msgid "show debugging data"
+msgstr "visa felsökningsutdata"
 
-#: builtin/init-db.c:55
-#, c-format
-msgid "cannot stat '%s'"
-msgstr "kan inte ta status på \"%s\""
+#: builtin/ls-remote.c:9
+msgid ""
+"git ls-remote [--heads] [--tags] [--refs] [--upload-pack=<exec>]\n"
+"                     [-q | --quiet] [--exit-code] [--get-url]\n"
+"                     [--symref] [<repository> [<refs>...]]"
+msgstr ""
+"git ls-remote [--heads] [--tags] [--refs] [--upload-pack=<exec>]\n"
+"                     [-q | --quiet] [--exit-code] [--get-url]\n"
+"                     [--symref] [<arkiv> [<referenser>...]]"
 
-#: builtin/init-db.c:61
-#, c-format
-msgid "cannot stat template '%s'"
-msgstr "kan inte ta status på mallen \"%s\""
+#: builtin/ls-remote.c:59
+msgid "do not print remote URL"
+msgstr "visa inte fjärr-URL"
 
-#: builtin/init-db.c:66
-#, c-format
-msgid "cannot opendir '%s'"
-msgstr "kan inte öppna katalogen (opendir) \"%s\""
+#: builtin/ls-remote.c:60 builtin/ls-remote.c:62 builtin/rebase.c:1518
+msgid "exec"
+msgstr "exec"
 
-#: builtin/init-db.c:77
-#, c-format
-msgid "cannot readlink '%s'"
-msgstr "kan inte läsa länk (readlink) \"%s\""
+#: builtin/ls-remote.c:61 builtin/ls-remote.c:63
+msgid "path of git-upload-pack on the remote host"
+msgstr "sökväg till git-upload-pack på fjärren"
 
-#: builtin/init-db.c:79
-#, c-format
-msgid "cannot symlink '%s' '%s'"
-msgstr "kan inte skapa symbolisk länk \"%s\" \"%s\""
+#: builtin/ls-remote.c:65
+msgid "limit to tags"
+msgstr "begränsa till taggar"
 
-#: builtin/init-db.c:85
-#, c-format
-msgid "cannot copy '%s' to '%s'"
-msgstr "kan inte kopiera \"%s\" till \"%s\""
+#: builtin/ls-remote.c:66
+msgid "limit to heads"
+msgstr "begränsa till huvuden"
 
-#: builtin/init-db.c:89
-#, c-format
-msgid "ignoring template %s"
-msgstr "ignorerar mallen %s"
+#: builtin/ls-remote.c:67
+msgid "do not show peeled tags"
+msgstr "visa inte avskalade taggar"
 
-#: builtin/init-db.c:120
-#, c-format
-msgid "templates not found in %s"
-msgstr "mallarna hittades inte i %s"
+#: builtin/ls-remote.c:69
+msgid "take url.<base>.insteadOf into account"
+msgstr "ta hänsyn till url.<bas>.insteadOf"
 
-#: builtin/init-db.c:135
-#, c-format
-msgid "not copying templates from '%s': %s"
-msgstr "kopierade inte mallar från \"%s\": %s"
+#: builtin/ls-remote.c:72
+msgid "exit with exit code 2 if no matching refs are found"
+msgstr "avsluta med felkod 2 om motsvarande referenser inte hittas"
 
-#: builtin/init-db.c:328
-#, c-format
-msgid "unable to handle file type %d"
-msgstr "kan inte hantera filtyp %d"
+#: builtin/ls-remote.c:75
+msgid "show underlying ref in addition to the object pointed by it"
+msgstr "visa underliggande referens och objektet det pekar på"
 
-#: builtin/init-db.c:331
-#, c-format
-msgid "unable to move %s to %s"
-msgstr "kan inte flytta %s till %s"
+#: builtin/ls-tree.c:30
+msgid "git ls-tree [<options>] <tree-ish> [<path>...]"
+msgstr "git ls-tree [<flaggor>] <träd-igt> [<sökväg>...]"
 
-#: builtin/init-db.c:348 builtin/init-db.c:351
-#, c-format
-msgid "%s already exists"
-msgstr "%s finns redan"
+#: builtin/ls-tree.c:128
+msgid "only show trees"
+msgstr "visa endast träd"
 
-#: builtin/init-db.c:404
-#, c-format
-msgid "Reinitialized existing shared Git repository in %s%s\n"
-msgstr "Ominitierade befintligt delat Git-arkiv i %s%s\n"
+#: builtin/ls-tree.c:130
+msgid "recurse into subtrees"
+msgstr "rekursera ner i underträd"
 
-#: builtin/init-db.c:405
-#, c-format
-msgid "Reinitialized existing Git repository in %s%s\n"
-msgstr "Ominitierade befintligt Git-arkiv i %s%s\n"
+#: builtin/ls-tree.c:132
+msgid "show trees when recursing"
+msgstr "visa träd medan rekursering"
 
-#: builtin/init-db.c:409
-#, c-format
-msgid "Initialized empty shared Git repository in %s%s\n"
-msgstr "Initierade tomt delat Git-arkiv i %s%s\n"
+#: builtin/ls-tree.c:135
+msgid "terminate entries with NUL byte"
+msgstr "terminera poster med NUL-byte"
 
-#: builtin/init-db.c:410
-#, c-format
-msgid "Initialized empty Git repository in %s%s\n"
-msgstr "Initierade tomt Git-arkiv i %s%s\n"
+#: builtin/ls-tree.c:136
+msgid "include object size"
+msgstr "inkludera objektstorlek"
 
-#: builtin/init-db.c:458
-msgid ""
-"git init [-q | --quiet] [--bare] [--template=<template-directory>] [--"
-"shared[=<permissions>]] [<directory>]"
-msgstr ""
-"git init [-q | --quiet] [--bare] [--template=<mallkatalog>] [--"
-"shared[=<behörigheter>]] [<katalog>]"
+#: builtin/ls-tree.c:138 builtin/ls-tree.c:140
+msgid "list only filenames"
+msgstr "visa endast filnamn"
 
-#: builtin/init-db.c:481
-msgid "permissions"
-msgstr "behörigheter"
+#: builtin/ls-tree.c:143
+msgid "use full path names"
+msgstr "använd fullständiga sökvägsnamn"
 
-#: builtin/init-db.c:482
-msgid "specify that the git repository is to be shared amongst several users"
-msgstr "ange att git-arkivet skall delas bland flera användare"
+#: builtin/ls-tree.c:145
+msgid "list entire tree; not just current directory (implies --full-name)"
+msgstr "visa hela trädet; inte bara aktuell katalog (implicerar --full-name)"
 
-#: builtin/init-db.c:525
+#: builtin/mailsplit.c:241
 #, c-format
-msgid "cannot chdir to %s"
-msgstr "kan inte byta katalog (chdir) till %s"
+msgid "empty mbox: '%s'"
+msgstr "tom mbox: \"%s\""
 
-#: builtin/init-db.c:546
-#, c-format
-msgid ""
-"%s (or --work-tree=<directory>) not allowed without specifying %s (or --git-"
-"dir=<directory>)"
-msgstr ""
-"%s (eller --work-tree=<katalog>) inte tillåtet utan att ange %s (eller --git-"
-"dir=<katalog>)"
+#: builtin/merge.c:55
+msgid "git merge [<options>] [<commit>...]"
+msgstr "git merge [<flaggor>] [<incheckning>...]"
 
-#: builtin/init-db.c:574
-#, c-format
-msgid "Cannot access work tree '%s'"
-msgstr "Kan inte komma åt arbetskatalogen \"%s\""
+#: builtin/merge.c:56
+msgid "git merge --abort"
+msgstr "git merge --abort"
 
-#: builtin/interpret-trailers.c:15
-msgid ""
-"git interpret-trailers [--in-place] [--trim-empty] [(--trailer "
-"<token>[(=|:)<value>])...] [<file>...]"
-msgstr ""
-"git interpret-trailers [--in-place] [--trim-empty] [(--trailer "
-"<symbol>[(=|:)<värde>])...] [<fil>...]"
+#: builtin/merge.c:57
+msgid "git merge --continue"
+msgstr "git merge --continue"
 
-#: builtin/interpret-trailers.c:92
-msgid "edit files in place"
-msgstr "redigera filer på plats"
+#: builtin/merge.c:118
+msgid "switch `m' requires a value"
+msgstr "flaggan \"m\" behöver ett värde"
 
-#: builtin/interpret-trailers.c:93
-msgid "trim empty trailers"
-msgstr "ta bort tomma släprader"
+#: builtin/merge.c:141
+#, c-format
+msgid "option `%s' requires a value"
+msgstr "flaggan \"%s\" behöver ett värde"
 
-#: builtin/interpret-trailers.c:96
-msgid "where to place the new trailer"
-msgstr "var nya släprader skall placeras"
+#: builtin/merge.c:187
+#, c-format
+msgid "Could not find merge strategy '%s'.\n"
+msgstr "Kunde inte hitta sammanslagningsstrategin \"%s\".\n"
 
-#: builtin/interpret-trailers.c:98
-msgid "action if trailer already exists"
-msgstr "att göra om släprader redan finns"
+#: builtin/merge.c:188
+#, c-format
+msgid "Available strategies are:"
+msgstr "Tillgängliga strategier är:"
 
-#: builtin/interpret-trailers.c:100
-msgid "action if trailer is missing"
-msgstr "att göra om släprader saknas"
+#: builtin/merge.c:193
+#, c-format
+msgid "Available custom strategies are:"
+msgstr "Tillgängliga skräddarsydda strategier är:"
 
-#: builtin/interpret-trailers.c:102
-msgid "output only the trailers"
-msgstr "visa endast släprader"
+#: builtin/merge.c:244 builtin/pull.c:152
+msgid "do not show a diffstat at the end of the merge"
+msgstr "visa inte en diffstat när sammanslagningen är färdig"
 
-#: builtin/interpret-trailers.c:103
-msgid "do not apply config rules"
-msgstr "använd inte regler från konfigurationen"
+#: builtin/merge.c:247 builtin/pull.c:155
+msgid "show a diffstat at the end of the merge"
+msgstr "visa en diffstat när sammanslagningen är färdig"
 
-#: builtin/interpret-trailers.c:104
-msgid "join whitespace-continued values"
-msgstr "slå ihop värden avdelade med blanksteg"
+#: builtin/merge.c:248 builtin/pull.c:158
+msgid "(synonym to --stat)"
+msgstr "(synonym till --stat)"
 
-#: builtin/interpret-trailers.c:105
-msgid "set parsing options"
-msgstr "välj tolkningsalternativ"
+#: builtin/merge.c:250 builtin/pull.c:161
+msgid "add (at most <n>) entries from shortlog to merge commit message"
+msgstr ""
+"lägg till (som mest <n>) poster från shortlog till incheckningsmeddelandet"
 
-#: builtin/interpret-trailers.c:107
-msgid "trailer"
-msgstr "släprad"
+#: builtin/merge.c:253 builtin/pull.c:167
+msgid "create a single commit instead of doing a merge"
+msgstr "skapa en ensam incheckning istället för en sammanslagning"
 
-#: builtin/interpret-trailers.c:108
-msgid "trailer(s) to add"
-msgstr "släprad(er) att lägga till"
+#: builtin/merge.c:255 builtin/pull.c:170
+msgid "perform a commit if the merge succeeds (default)"
+msgstr "utför en incheckning om sammanslagningen lyckades (standard)"
 
-#: builtin/interpret-trailers.c:117
-msgid "--trailer with --only-input does not make sense"
-msgstr "--trailer med --only-input ger ingen mening"
+#: builtin/merge.c:257 builtin/pull.c:173
+msgid "edit message before committing"
+msgstr "redigera meddelande innan incheckning"
 
-#: builtin/interpret-trailers.c:127
-msgid "no input file given for in-place editing"
-msgstr "ingen indatafil angiven för redigering på plats"
+#: builtin/merge.c:259
+msgid "allow fast-forward (default)"
+msgstr "tillåt snabbspolning (standard)"
 
-#: builtin/log.c:48
-msgid "git log [<options>] [<revision-range>] [[--] <path>...]"
-msgstr "git log [<flaggor>] [<versionsintervall>] [[--] <sökväg>...]"
+#: builtin/merge.c:261 builtin/pull.c:180
+msgid "abort if fast-forward is not possible"
+msgstr "avbryt om snabbspolning inte är möjlig"
 
-#: builtin/log.c:49
-msgid "git show [<options>] <object>..."
-msgstr "git show [<flaggor>] <objekt>..."
+#: builtin/merge.c:265 builtin/pull.c:183
+msgid "verify that the named commit has a valid GPG signature"
+msgstr "bekräfta att den namngivna incheckningen har en giltig GPG-signatur"
 
-#: builtin/log.c:93
-#, c-format
-msgid "invalid --decorate option: %s"
-msgstr "ogiltig flagga för --decorate: %s"
+#: builtin/merge.c:266 builtin/notes.c:787 builtin/pull.c:187
+#: builtin/rebase.c:512 builtin/rebase.c:1531 builtin/revert.c:114
+msgid "strategy"
+msgstr "strategi"
 
-#: builtin/log.c:153
-msgid "suppress diff output"
-msgstr "undertryck diff-utdata"
+#: builtin/merge.c:267 builtin/pull.c:188
+msgid "merge strategy to use"
+msgstr "sammanslagningsstrategi att använda"
 
-#: builtin/log.c:154
-msgid "show source"
-msgstr "visa källkod"
+#: builtin/merge.c:268 builtin/pull.c:191
+msgid "option=value"
+msgstr "alternativ=värde"
 
-#: builtin/log.c:155
-msgid "Use mail map file"
-msgstr "Använd e-postmappningsfil"
+#: builtin/merge.c:269 builtin/pull.c:192
+msgid "option for selected merge strategy"
+msgstr "alternativ för vald sammanslagningsstrategi"
 
-#: builtin/log.c:157
-msgid "only decorate refs that match <pattern>"
-msgstr "dekorera endast referenser som motsvarar <mönster>"
+#: builtin/merge.c:271
+msgid "merge commit message (for a non-fast-forward merge)"
+msgstr "incheckningsmeddelande för (icke snabbspolande) sammanslagning"
 
-#: builtin/log.c:159
-msgid "do not decorate refs that match <pattern>"
-msgstr "dekorera inte referenser som motsvarar <mönster>"
+#: builtin/merge.c:278
+msgid "abort the current in-progress merge"
+msgstr "avbryt den pågående sammanslagningen"
 
-#: builtin/log.c:160
-msgid "decorate options"
-msgstr "dekoreringsflaggor"
+#: builtin/merge.c:280
+msgid "--abort but leave index and working tree alone"
+msgstr "--abort men lämna index och arbetskatalog ensamma"
 
-#: builtin/log.c:163
-msgid "Process line range n,m in file, counting from 1"
-msgstr "Behandla radintervallet n,m i filen, med början på 1"
+#: builtin/merge.c:282
+msgid "continue the current in-progress merge"
+msgstr "fortsätt den pågående sammanslagningen"
 
-#: builtin/log.c:259
-#, c-format
-msgid "Final output: %d %s\n"
-msgstr "Slututdata: %d %s\n"
+#: builtin/merge.c:284 builtin/pull.c:199
+msgid "allow merging unrelated histories"
+msgstr "tillåt sammanslagning av orelaterade historier"
 
-#: builtin/log.c:510
-#, c-format
-msgid "git show %s: bad file"
-msgstr "git show %s: felaktig fil"
+#: builtin/merge.c:290
+msgid "bypass pre-merge-commit and commit-msg hooks"
+msgstr "förbigå pre-merge-commit- och commit-msg-krokar"
 
-#: builtin/log.c:525 builtin/log.c:619
-#, c-format
-msgid "Could not read object %s"
-msgstr "Kunde inte läsa objektet %s"
+#: builtin/merge.c:307
+msgid "could not run stash."
+msgstr "kunde köra stash."
+
+#: builtin/merge.c:312
+msgid "stash failed"
+msgstr "stash misslyckades"
 
-#: builtin/log.c:643
+#: builtin/merge.c:317
 #, c-format
-msgid "Unknown type: %d"
-msgstr "Okänd typ: %d"
+msgid "not a valid object: %s"
+msgstr "inte ett giltigt objekt: %s"
 
-#: builtin/log.c:764
-msgid "format.headers without value"
-msgstr "format.headers utan värde"
+#: builtin/merge.c:339 builtin/merge.c:356
+msgid "read-tree failed"
+msgstr "read-tree misslyckades"
 
-#: builtin/log.c:865
-msgid "name of output directory is too long"
-msgstr "namnet på utdatakatalogen är för långt"
+#: builtin/merge.c:386
+msgid " (nothing to squash)"
+msgstr " (inget att platta till)"
 
-#: builtin/log.c:881
+#: builtin/merge.c:397
 #, c-format
-msgid "Cannot open patch file %s"
-msgstr "Kan inte öppna patchfilen %s"
-
-#: builtin/log.c:898
-msgid "Need exactly one range."
-msgstr "Behöver precis ett intervall."
+msgid "Squash commit -- not updating HEAD\n"
+msgstr "Tillplattningsincheckning -- uppdaterar inte HEAD\n"
 
-#: builtin/log.c:908
-msgid "Not a range."
-msgstr "Inte ett intervall."
+#: builtin/merge.c:447
+#, c-format
+msgid "No merge message -- not updating HEAD\n"
+msgstr "Inget sammanslagningsmeddelande -- uppdaterar inte HEAD\n"
 
-#: builtin/log.c:1014
-msgid "Cover letter needs email format"
-msgstr "Omslagsbrevet behöver e-postformat"
+#: builtin/merge.c:498
+#, c-format
+msgid "'%s' does not point to a commit"
+msgstr "\"%s\" verkar inte peka på en incheckning"
 
-#: builtin/log.c:1095
+#: builtin/merge.c:585
 #, c-format
-msgid "insane in-reply-to: %s"
-msgstr "tokigt in-reply-to: %s"
+msgid "Bad branch.%s.mergeoptions string: %s"
+msgstr "Felaktig branch.%s.mergeoptions-sträng: %s"
 
-#: builtin/log.c:1122
-msgid "git format-patch [<options>] [<since> | <revision-range>]"
-msgstr "git format-patch [<flaggor>] [<sedan> | <revisionsintervall>]"
+#: builtin/merge.c:705
+msgid "Not handling anything other than two heads merge."
+msgstr "Hanterar inte något annat än en sammanslagning av två huvuden."
 
-#: builtin/log.c:1172
-msgid "Two output directories?"
-msgstr "Två utdatakataloger?"
+#: builtin/merge.c:719
+#, c-format
+msgid "Unknown option for merge-recursive: -X%s"
+msgstr "Felaktig flagga för merge-recursive: -X%s"
 
-#: builtin/log.c:1279 builtin/log.c:1932 builtin/log.c:1934 builtin/log.c:1946
+#: builtin/merge.c:734
 #, c-format
-msgid "Unknown commit %s"
-msgstr "Okänd incheckning %s"
+msgid "unable to write %s"
+msgstr "kunde inte skriva %s"
 
-#: builtin/log.c:1289 builtin/notes.c:887 builtin/tag.c:523
+#: builtin/merge.c:786
 #, c-format
-msgid "Failed to resolve '%s' as a valid ref."
-msgstr "Kunde inte slå upp \"%s\" som en giltig referens."
+msgid "Could not read from '%s'"
+msgstr "Kunde inte läsa från \"%s\""
 
-#: builtin/log.c:1294
-msgid "Could not find exact merge base."
-msgstr "Kunde inte hitta exakt sammanslagningsbas."
+#: builtin/merge.c:795
+#, c-format
+msgid "Not committing merge; use 'git commit' to complete the merge.\n"
+msgstr ""
+"Checkar inte in sammanslagningen; använd \"git commit\" för att slutföra "
+"den.\n"
 
-#: builtin/log.c:1298
+#: builtin/merge.c:801
 msgid ""
-"Failed to get upstream, if you want to record base commit automatically,\n"
-"please use git branch --set-upstream-to to track a remote branch.\n"
-"Or you could specify base commit by --base=<base-commit-id> manually."
+"Please enter a commit message to explain why this merge is necessary,\n"
+"especially if it merges an updated upstream into a topic branch.\n"
+"\n"
 msgstr ""
-"Kunde inte hämta uppström, om du vill lagra basincheckningen automatiskt,\n"
-"använd git branch --set-upstream-to för att spåra en fjärrgren.\n"
-"Eller så kan du ange basincheckning med --base=<bas-inchecknings-id> "
-"manuellt."
-
-#: builtin/log.c:1318
-msgid "Failed to find exact merge base"
-msgstr "Kunde inte hitta exakt sammanslagningsbas"
-
-#: builtin/log.c:1329
-msgid "base commit should be the ancestor of revision list"
-msgstr "basincheckningen bör vara förfader till revisionslistan"
-
-#: builtin/log.c:1333
-msgid "base commit shouldn't be in revision list"
-msgstr "basincheckningen bör inte vara i revisionslistan"
+"Ange ett incheckningsmeddelande för att förklara varför sammanslagningen\n"
+"är nödvändig, speciellt om den slår in en uppdaterad uppström i en\n"
+"temagren.\n"
+"\n"
 
-#: builtin/log.c:1382
-msgid "cannot get patch id"
-msgstr "kan inte hämta patch-id"
+#: builtin/merge.c:806
+msgid "An empty message aborts the commit.\n"
+msgstr "Ett tomt meddelande avbryter incheckningen.\n"
 
-#: builtin/log.c:1441
-msgid "use [PATCH n/m] even with a single patch"
-msgstr "använd [PATCH n/m] även för en ensam patch"
+#: builtin/merge.c:809
+#, c-format
+msgid ""
+"Lines starting with '%c' will be ignored, and an empty message aborts\n"
+"the commit.\n"
+msgstr ""
+"Rader som inleds med \"%c\" kommer ignoreras, och ett tomt meddelande\n"
+"avbryter incheckningen.\n"
 
-#: builtin/log.c:1444
-msgid "use [PATCH] even with multiple patches"
-msgstr "använd [PATCH] även för flera patchar"
+#: builtin/merge.c:862
+msgid "Empty commit message."
+msgstr "Tomt incheckningsmeddelande."
 
-#: builtin/log.c:1448
-msgid "print patches to standard out"
-msgstr "skriv patcharna på standard ut"
+#: builtin/merge.c:877
+#, c-format
+msgid "Wonderful.\n"
+msgstr "Underbart.\n"
 
-#: builtin/log.c:1450
-msgid "generate a cover letter"
-msgstr "generera ett följebrev"
+#: builtin/merge.c:938
+#, c-format
+msgid "Automatic merge failed; fix conflicts and then commit the result.\n"
+msgstr ""
+"Kunde inte slå ihop automatiskt; fixa konflikter och checka in resultatet.\n"
 
-#: builtin/log.c:1452
-msgid "use simple number sequence for output file names"
-msgstr "använd enkel nummersekvens för utdatafilnamn"
+#: builtin/merge.c:977
+msgid "No current branch."
+msgstr "Inte på någon gren."
 
-#: builtin/log.c:1453
-msgid "sfx"
-msgstr "sfx"
+#: builtin/merge.c:979
+msgid "No remote for the current branch."
+msgstr "Ingen fjärr för aktuell gren."
 
-#: builtin/log.c:1454
-msgid "use <sfx> instead of '.patch'"
-msgstr "använd <sfx> istället för \".patch\""
+#: builtin/merge.c:981
+msgid "No default upstream defined for the current branch."
+msgstr "Ingen standarduppström angiven för aktuell gren."
 
-#: builtin/log.c:1456
-msgid "start numbering patches at <n> instead of 1"
-msgstr "börja numrera patchar på <n> istället för 1"
+#: builtin/merge.c:986
+#, c-format
+msgid "No remote-tracking branch for %s from %s"
+msgstr "Ingen fjärrspårande gren för %s från %s"
 
-#: builtin/log.c:1458
-msgid "mark the series as Nth re-roll"
-msgstr "markera serien som N:te försök"
+#: builtin/merge.c:1043
+#, c-format
+msgid "Bad value '%s' in environment '%s'"
+msgstr "Felaktigt värde \"%s\" i miljövariabeln \"%s\""
 
-#: builtin/log.c:1460
-msgid "Use [RFC PATCH] instead of [PATCH]"
-msgstr "Använd  [RFC PATCH] istället för [PATCH]"
+#: builtin/merge.c:1146
+#, c-format
+msgid "not something we can merge in %s: %s"
+msgstr "inte något vi kan slå ihop med %s: %s"
 
-#: builtin/log.c:1463
-msgid "Use [<prefix>] instead of [PATCH]"
-msgstr "Använd [<prefix>] istället för [PATCH]"
+#: builtin/merge.c:1180
+msgid "not something we can merge"
+msgstr "inte något vi kan slå ihop"
 
-#: builtin/log.c:1466
-msgid "store resulting files in <dir>"
-msgstr "spara filerna i <katalog>"
+#: builtin/merge.c:1283
+msgid "--abort expects no arguments"
+msgstr "--abort tar inga argument"
 
-#: builtin/log.c:1469
-msgid "don't strip/add [PATCH]"
-msgstr "ta inte bort eller lägg till [PATCH]"
+#: builtin/merge.c:1287
+msgid "There is no merge to abort (MERGE_HEAD missing)."
+msgstr "Ingen sammanslagning att avbryta (MERGE_HEAD saknas)."
 
-#: builtin/log.c:1472
-msgid "don't output binary diffs"
-msgstr "skriv inte binära diffar"
+#: builtin/merge.c:1296
+msgid "--quit expects no arguments"
+msgstr "--quit tar inga argument"
 
-#: builtin/log.c:1474
-msgid "output all-zero hash in From header"
-msgstr "använd hashvärde med nollor i From-huvud"
+#: builtin/merge.c:1309
+msgid "--continue expects no arguments"
+msgstr "--continue tar inga argument"
 
-#: builtin/log.c:1476
-msgid "don't include a patch matching a commit upstream"
-msgstr "ta inte med patchar som motsvarar en uppströmsincheckning"
+#: builtin/merge.c:1313
+msgid "There is no merge in progress (MERGE_HEAD missing)."
+msgstr "Ingen sammanslagning pågår (MERGE_HEAD saknas)."
 
-#: builtin/log.c:1478
-msgid "show patch format instead of default (patch + stat)"
-msgstr "visa patchformat istället för standard (patch + stat)"
+#: builtin/merge.c:1329
+msgid ""
+"You have not concluded your merge (MERGE_HEAD exists).\n"
+"Please, commit your changes before you merge."
+msgstr ""
+"Du har inte avslutat sammanslagningen (MERGE_HEAD finns).\n"
+"Checka in dina ändringar innan du slår ihop."
 
-#: builtin/log.c:1480
-msgid "Messaging"
-msgstr "E-post"
+#: builtin/merge.c:1336
+msgid ""
+"You have not concluded your cherry-pick (CHERRY_PICK_HEAD exists).\n"
+"Please, commit your changes before you merge."
+msgstr ""
+"Du har inte avslutat din \"cherry-pick\" (CHERRY_PICK_HEAD finns).\n"
+"Checka in dina ändringar innan du slår ihop."
 
-#: builtin/log.c:1481
-msgid "header"
-msgstr "huvud"
+#: builtin/merge.c:1339
+msgid "You have not concluded your cherry-pick (CHERRY_PICK_HEAD exists)."
+msgstr "Du har inte avslutat din \"cherry-pick\" (CHERRY_PICK_HEAD finns)."
 
-#: builtin/log.c:1482
-msgid "add email header"
-msgstr "lägg till e-posthuvud"
+#: builtin/merge.c:1353
+msgid "You cannot combine --squash with --no-ff."
+msgstr "Du kan inte kombinera --squash med --no-ff."
 
-#: builtin/log.c:1483 builtin/log.c:1485
-msgid "email"
-msgstr "epost"
+#: builtin/merge.c:1355
+msgid "You cannot combine --squash with --commit."
+msgstr "Du kan inte kombinera --squash med --commit."
 
-#: builtin/log.c:1483
-msgid "add To: header"
-msgstr "lägg till mottagarhuvud (\"To:\")"
+#: builtin/merge.c:1371
+msgid "No commit specified and merge.defaultToUpstream not set."
+msgstr "Ingen incheckning angiven och merge.defaultToUpstream är ej satt."
 
-#: builtin/log.c:1485
-msgid "add Cc: header"
-msgstr "lägg till kopiehuvud (\"Cc:\")"
+#: builtin/merge.c:1388
+msgid "Squash commit into empty head not supported yet"
+msgstr "Stöder inte en tillplattningsincheckning på ett tomt huvud ännu"
 
-#: builtin/log.c:1487
-msgid "ident"
-msgstr "ident"
+#: builtin/merge.c:1390
+msgid "Non-fast-forward commit does not make sense into an empty head"
+msgstr "Icke-snabbspolad incheckning kan inte användas med ett tomt huvud"
 
-#: builtin/log.c:1488
-msgid "set From address to <ident> (or committer ident if absent)"
-msgstr "sätt Från-adress till <ident> (eller incheckare om ident saknas)"
+#: builtin/merge.c:1395
+#, c-format
+msgid "%s - not something we can merge"
+msgstr "%s - inte något vi kan slå ihop"
 
-#: builtin/log.c:1490
-msgid "message-id"
-msgstr "meddelande-id"
+#: builtin/merge.c:1397
+msgid "Can merge only exactly one commit into empty head"
+msgstr "Kan endast slå ihop en enda incheckning i ett tomt huvud"
 
-#: builtin/log.c:1491
-msgid "make first mail a reply to <message-id>"
-msgstr "gör det första brevet ett svar till <meddelande-id>"
+#: builtin/merge.c:1476
+msgid "refusing to merge unrelated histories"
+msgstr "vägrar slå samman orelaterad historik"
 
-#: builtin/log.c:1492 builtin/log.c:1495
-msgid "boundary"
-msgstr "gräns"
+#: builtin/merge.c:1485
+msgid "Already up to date."
+msgstr "Redan à jour."
 
-#: builtin/log.c:1493
-msgid "attach the patch"
-msgstr "bifoga patchen"
+#: builtin/merge.c:1495
+#, c-format
+msgid "Updating %s..%s\n"
+msgstr "Uppdaterar %s..%s\n"
 
-#: builtin/log.c:1496
-msgid "inline the patch"
-msgstr "gör patchen ett inline-objekt"
+#: builtin/merge.c:1537
+#, c-format
+msgid "Trying really trivial in-index merge...\n"
+msgstr "Försöker riktigt enkel sammanslagning i indexet...\n"
 
-#: builtin/log.c:1500
-msgid "enable message threading, styles: shallow, deep"
-msgstr "aktivera brevtrådning, typer: shallow, deep"
+#: builtin/merge.c:1544
+#, c-format
+msgid "Nope.\n"
+msgstr "Nej.\n"
 
-#: builtin/log.c:1502
-msgid "signature"
-msgstr "signatur"
+#: builtin/merge.c:1569
+msgid "Already up to date. Yeeah!"
+msgstr "Redan à jour. Toppen!"
 
-#: builtin/log.c:1503
-msgid "add a signature"
-msgstr "lägg till signatur"
+#: builtin/merge.c:1575
+msgid "Not possible to fast-forward, aborting."
+msgstr "Kan inte snabbspola, avbryter."
 
-#: builtin/log.c:1504
-msgid "base-commit"
-msgstr "basincheckning"
+#: builtin/merge.c:1598 builtin/merge.c:1663
+#, c-format
+msgid "Rewinding the tree to pristine...\n"
+msgstr "Återspolar trädet till orört...\n"
 
-#: builtin/log.c:1505
-msgid "add prerequisite tree info to the patch series"
-msgstr "lägg till förhandskrävd trädinfo i patchserien"
+#: builtin/merge.c:1602
+#, c-format
+msgid "Trying merge strategy %s...\n"
+msgstr "Försöker sammanslagningsstrategin %s...\n"
 
-#: builtin/log.c:1507
-msgid "add a signature from a file"
-msgstr "lägg till signatur från fil"
+#: builtin/merge.c:1654
+#, c-format
+msgid "No merge strategy handled the merge.\n"
+msgstr "Ingen sammanslagningsstrategi hanterade sammanslagningen.\n"
 
-#: builtin/log.c:1508
-msgid "don't print the patch filenames"
-msgstr "visa inte filnamn för patchar"
+#: builtin/merge.c:1656
+#, c-format
+msgid "Merge with strategy %s failed.\n"
+msgstr "Sammanslagning med strategin %s misslyckades.\n"
 
-#: builtin/log.c:1510
-msgid "show progress while generating patches"
-msgstr "visa förloppsindikator medan patchar skapas"
+#: builtin/merge.c:1665
+#, c-format
+msgid "Using the %s to prepare resolving by hand.\n"
+msgstr "Använder %s för att förbereda lösning för hand.\n"
 
-#: builtin/log.c:1585
+#: builtin/merge.c:1677
 #, c-format
-msgid "invalid ident line: %s"
-msgstr "ogiltig ident-rad: %s"
+msgid "Automatic merge went well; stopped before committing as requested\n"
+msgstr ""
+"Automatisk sammanslagning lyckades; stoppar före incheckning som önskat\n"
 
-#: builtin/log.c:1600
-msgid "-n and -k are mutually exclusive."
-msgstr "-n och -k kan inte användas samtidigt."
-
-#: builtin/log.c:1602
-msgid "--subject-prefix/--rfc and -k are mutually exclusive."
-msgstr "--subject-prefix/--rfc och -k kan inte användas samtidigt."
+#: builtin/merge-base.c:32
+msgid "git merge-base [-a | --all] <commit> <commit>..."
+msgstr "git merge-base [-a | --all] <incheckning> <incheckning>..."
 
-#: builtin/log.c:1610
-msgid "--name-only does not make sense"
-msgstr "kan inte använda --name-only"
+#: builtin/merge-base.c:33
+msgid "git merge-base [-a | --all] --octopus <commit>..."
+msgstr "git merge-base [-a | --all] --octopus <incheckning>..."
 
-#: builtin/log.c:1612
-msgid "--name-status does not make sense"
-msgstr "kan inte använda --name-status"
+#: builtin/merge-base.c:34
+msgid "git merge-base --independent <commit>..."
+msgstr "git merge-base --independent <incheckning>..."
 
-#: builtin/log.c:1614
-msgid "--check does not make sense"
-msgstr "kan inte använda --check"
+#: builtin/merge-base.c:35
+msgid "git merge-base --is-ancestor <commit> <commit>"
+msgstr "git merge-base --is-ancestor <incheckning> <incheckning>"
 
-#: builtin/log.c:1646
-msgid "standard output, or directory, which one?"
-msgstr "standard ut, eller katalog, vilken skall det vara?"
+#: builtin/merge-base.c:36
+msgid "git merge-base --fork-point <ref> [<commit>]"
+msgstr "git merge-base --fork-point <ref> [<incheckning>]"
 
-#: builtin/log.c:1648
-#, c-format
-msgid "Could not create directory '%s'"
-msgstr "Kunde inte skapa katalogen \"%s\""
+#: builtin/merge-base.c:153
+msgid "output all common ancestors"
+msgstr "skriv ut alla gemensamma anfäder"
 
-#: builtin/log.c:1741
-#, c-format
-msgid "unable to read signature file '%s'"
-msgstr "kunde inte läsa signaturfil \"%s\""
+#: builtin/merge-base.c:155
+msgid "find ancestors for a single n-way merge"
+msgstr "hitta anfader för enkel n-vägssammanslagning"
 
-#: builtin/log.c:1773
-msgid "Generating patches"
-msgstr "Skapar patchar"
+#: builtin/merge-base.c:157
+msgid "list revs not reachable from others"
+msgstr "visa revisioner som inte kan nås från andra"
 
-#: builtin/log.c:1817
-msgid "Failed to create output files"
-msgstr "Misslyckades skapa utdatafiler"
+#: builtin/merge-base.c:159
+msgid "is the first one ancestor of the other?"
+msgstr "är den första anfader till den andra?"
 
-#: builtin/log.c:1867
-msgid "git cherry [-v] [<upstream> [<head> [<limit>]]]"
-msgstr "git cherry [-v] [<uppström> [<huvud> [<gräns>]]]"
+#: builtin/merge-base.c:161
+msgid "find where <commit> forked from reflog of <ref>"
+msgstr "se var <incheckning> grenades av från referensloggen från <ref>"
 
-#: builtin/log.c:1921
-#, c-format
+#: builtin/merge-file.c:9
 msgid ""
-"Could not find a tracked remote branch, please specify <upstream> manually.\n"
-msgstr "Kunde inte hitta en spårad fjärrgren, ange <uppström> manuellt.\n"
+"git merge-file [<options>] [-L <name1> [-L <orig> [-L <name2>]]] <file1> "
+"<orig-file> <file2>"
+msgstr ""
+"git merge-file [<alternativ>] [-L <namn1> [-L <orig> [-L <namn2>]]] <fil1> "
+"<origfil> <fil2>"
 
-#: builtin/ls-files.c:468
-msgid "git ls-files [<options>] [<file>...]"
-msgstr "git ls-files [<flaggor>] [<fil>...]"
+#: builtin/merge-file.c:35
+msgid "send results to standard output"
+msgstr "sänd resultat till standard ut"
 
-#: builtin/ls-files.c:517
-msgid "identify the file status with tags"
-msgstr "identifiera filstatus med taggar"
+#: builtin/merge-file.c:36
+msgid "use a diff3 based merge"
+msgstr "använd diff3-baserad sammanslagning"
 
-#: builtin/ls-files.c:519
-msgid "use lowercase letters for 'assume unchanged' files"
-msgstr "använd små bokstäver för \"anta oförändrade\"-filer"
+#: builtin/merge-file.c:37
+msgid "for conflicts, use our version"
+msgstr "för konflikter, använd vår version"
 
-#: builtin/ls-files.c:521
-msgid "use lowercase letters for 'fsmonitor clean' files"
-msgstr "använd små bokstäver för \"fsmonitor clean\"-filer"
+#: builtin/merge-file.c:39
+msgid "for conflicts, use their version"
+msgstr "för konflikter, använd deras version"
 
-#: builtin/ls-files.c:523
-msgid "show cached files in the output (default)"
-msgstr "visa cachade filer i utdata (standard)"
+#: builtin/merge-file.c:41
+msgid "for conflicts, use a union version"
+msgstr "för konflikter, använd en förenad version"
 
-#: builtin/ls-files.c:525
-msgid "show deleted files in the output"
-msgstr "visa borttagna filer i utdata"
+#: builtin/merge-file.c:44
+msgid "for conflicts, use this marker size"
+msgstr "för konflikter, använd denna markörstorlek"
 
-#: builtin/ls-files.c:527
-msgid "show modified files in the output"
-msgstr "visa modifierade filer i utdata"
+#: builtin/merge-file.c:45
+msgid "do not warn about conflicts"
+msgstr "varna inte om konflikter"
 
-#: builtin/ls-files.c:529
-msgid "show other files in the output"
-msgstr "visa andra filer i utdata"
+#: builtin/merge-file.c:47
+msgid "set labels for file1/orig-file/file2"
+msgstr "sätt etiketter för fil1/origfil/fil2"
 
-#: builtin/ls-files.c:531
-msgid "show ignored files in the output"
-msgstr "visa ignorerade filer i utdata"
+#: builtin/merge-recursive.c:47
+#, c-format
+msgid "unknown option %s"
+msgstr "okänd flagga %s"
 
-#: builtin/ls-files.c:534
-msgid "show staged contents' object name in the output"
-msgstr "visa köat innehålls objektnamn i utdata"
+#: builtin/merge-recursive.c:53
+#, c-format
+msgid "could not parse object '%s'"
+msgstr "kunde inte tolka objektet \"%s\""
 
-#: builtin/ls-files.c:536
-msgid "show files on the filesystem that need to be removed"
-msgstr "visa filer i filsystemet som behöver tas bort"
+#: builtin/merge-recursive.c:57
+#, c-format
+msgid "cannot handle more than %d base. Ignoring %s."
+msgid_plural "cannot handle more than %d bases. Ignoring %s."
+msgstr[0] "kan inte hantera mer än %d bas. Ignorerar %s."
+msgstr[1] "kan inte hantera mer än %d baser. Ignorerar %s."
 
-#: builtin/ls-files.c:538
-msgid "show 'other' directories' names only"
-msgstr "visa endast namn för \"andra\" kataloger"
+#: builtin/merge-recursive.c:65
+msgid "not handling anything other than two heads merge."
+msgstr "hanterar inte något annat än en sammanslagning av två huvuden."
 
-#: builtin/ls-files.c:540
-msgid "show line endings of files"
-msgstr "visa radslut i filer"
+#: builtin/merge-recursive.c:74 builtin/merge-recursive.c:76
+#, c-format
+msgid "could not resolve ref '%s'"
+msgstr "kunde inte bestämma referensen \"%s\""
 
-#: builtin/ls-files.c:542
-msgid "don't show empty directories"
-msgstr "visa inte tomma kataloger"
+#: builtin/merge-recursive.c:82
+#, c-format
+msgid "Merging %s with %s\n"
+msgstr "Slår ihop %s med %s\n"
 
-#: builtin/ls-files.c:545
-msgid "show unmerged files in the output"
-msgstr "visa ej sammanslagna filer i utdata"
+#: builtin/mktree.c:66
+msgid "git mktree [-z] [--missing] [--batch]"
+msgstr "git mktree [-z] [--missing] [--batch]"
 
-#: builtin/ls-files.c:547
-msgid "show resolve-undo information"
-msgstr "visa \"resolve-undo\"-information"
+#: builtin/mktree.c:154
+msgid "input is NUL terminated"
+msgstr "indata är NUL-terminerad"
 
-#: builtin/ls-files.c:549
-msgid "skip files matching pattern"
-msgstr "hoppa över filer som motsvarar mönster"
+#: builtin/mktree.c:155 builtin/write-tree.c:26
+msgid "allow missing objects"
+msgstr "tillåt saknade objekt"
 
-#: builtin/ls-files.c:552
-msgid "exclude patterns are read from <file>"
-msgstr "exkludera mönster som läses från <fil>"
+#: builtin/mktree.c:156
+msgid "allow creation of more than one tree"
+msgstr "tillåt skapa mer än ett träd"
 
-#: builtin/ls-files.c:555
-msgid "read additional per-directory exclude patterns in <file>"
-msgstr "läs ytterligare per-katalog-exkluderingsmönster från <fil>"
+#: builtin/multi-pack-index.c:9
+msgid ""
+"git multi-pack-index [<options>] (write|verify|expire|repack --batch-"
+"size=<size>)"
+msgstr ""
+"git multi-pack-index [<flaggor>] (write|verify|expire|repack --batch-"
+"size=<storlek>)"
 
-#: builtin/ls-files.c:557
-msgid "add the standard git exclusions"
-msgstr "lägg till git:s standardexkluderingar"
+#: builtin/multi-pack-index.c:26
+msgid "object directory containing set of packfile and pack-index pairs"
+msgstr "objektkatalog med uppsättning av par med paketfiler och pack-index"
 
-#: builtin/ls-files.c:560
-msgid "make the output relative to the project top directory"
-msgstr "gör utdata relativ till projektets toppkatalog"
+#: builtin/multi-pack-index.c:29
+msgid ""
+"during repack, collect pack-files of smaller size into a batch that is "
+"larger than this size"
+msgstr ""
+"vid ompackning, samla mindre paketfiler i en bunt som är större än denna "
+"storlekt"
 
-#: builtin/ls-files.c:563
-msgid "recurse through submodules"
-msgstr "rekursera ner i undermoduler"
+#: builtin/multi-pack-index.c:50 builtin/prune-packed.c:67
+msgid "too many arguments"
+msgstr "för många argument"
 
-#: builtin/ls-files.c:565
-msgid "if any <file> is not in the index, treat this as an error"
-msgstr "om en <fil> inte är indexet, betrakta det som ett fel"
+#: builtin/multi-pack-index.c:60
+msgid "--batch-size option is only for 'repack' subcommand"
+msgstr "flaggan --batch-size används bara i underkommandot \"repack\""
 
-#: builtin/ls-files.c:566
-msgid "tree-ish"
-msgstr "träd-igt"
+#: builtin/multi-pack-index.c:69
+#, c-format
+msgid "unrecognized subcommand: %s"
+msgstr "okänt underkommando: %s"
 
-#: builtin/ls-files.c:567
-msgid "pretend that paths removed since <tree-ish> are still present"
-msgstr "låtsas att sökvägar borttagna sedan <träd-igt> fortfarande finns"
+#: builtin/mv.c:18
+msgid "git mv [<options>] <source>... <destination>"
+msgstr "git mv [<flaggor>] <källa>... <mål>"
 
-#: builtin/ls-files.c:569
-msgid "show debugging data"
-msgstr "visa felsökningsutdata"
+#: builtin/mv.c:83
+#, c-format
+msgid "Directory %s is in index and no submodule?"
+msgstr "Katalogen %s är i indexet och inte en undermodul?"
 
-#: builtin/ls-remote.c:9
-msgid ""
-"git ls-remote [--heads] [--tags] [--refs] [--upload-pack=<exec>]\n"
-"                     [-q | --quiet] [--exit-code] [--get-url]\n"
-"                     [--symref] [<repository> [<refs>...]]"
+#: builtin/mv.c:85
+msgid "Please stage your changes to .gitmodules or stash them to proceed"
 msgstr ""
-"git ls-remote [--heads] [--tags] [--refs] [--upload-pack=<exec>]\n"
-"                     [-q | --quiet] [--exit-code] [--get-url]\n"
-"                     [--symref] [<arkiv> [<referenser>...]]"
+"Köa dina ändringar i .gitmodules eller använd \"stash\" för att fortsätta"
 
-#: builtin/ls-remote.c:59
-msgid "do not print remote URL"
-msgstr "visa inte fjärr-URL"
+#: builtin/mv.c:103
+#, c-format
+msgid "%.*s is in index"
+msgstr "%.*s är i indexet"
 
-#: builtin/ls-remote.c:60 builtin/ls-remote.c:62
-msgid "exec"
-msgstr "exec"
+#: builtin/mv.c:125
+msgid "force move/rename even if target exists"
+msgstr "tvinga flytta/ändra namn även om målet finns"
 
-#: builtin/ls-remote.c:61 builtin/ls-remote.c:63
-msgid "path of git-upload-pack on the remote host"
-msgstr "sökväg till git-upload-pack på fjärren"
+#: builtin/mv.c:127
+msgid "skip move/rename errors"
+msgstr "hoppa över fel vid flytt/namnändring"
 
-#: builtin/ls-remote.c:65
-msgid "limit to tags"
-msgstr "begränsa till taggar"
+#: builtin/mv.c:169
+#, c-format
+msgid "destination '%s' is not a directory"
+msgstr "destinationen \"%s\" är ingen katalog"
 
-#: builtin/ls-remote.c:66
-msgid "limit to heads"
-msgstr "begränsa till huvuden"
+#: builtin/mv.c:180
+#, c-format
+msgid "Checking rename of '%s' to '%s'\n"
+msgstr "Kontrollerar namnbyte av \"%s\" till \"%s\"\n"
 
-#: builtin/ls-remote.c:67
-msgid "do not show peeled tags"
-msgstr "visa inte avskalade taggar"
+#: builtin/mv.c:184
+msgid "bad source"
+msgstr "felaktig källa"
 
-#: builtin/ls-remote.c:69
-msgid "take url.<base>.insteadOf into account"
-msgstr "ta hänsyn till url.<bas>.insteadOf"
+#: builtin/mv.c:187
+msgid "can not move directory into itself"
+msgstr "kan inte flytta katalog till sig själv"
 
-#: builtin/ls-remote.c:73
-msgid "exit with exit code 2 if no matching refs are found"
-msgstr "avsluta med felkod 2 om motsvarande referenser inte hittas"
+#: builtin/mv.c:190
+msgid "cannot move directory over file"
+msgstr "kan inte flytta katalog över fil"
 
-#: builtin/ls-remote.c:76
-msgid "show underlying ref in addition to the object pointed by it"
-msgstr "visa underliggande referens och objektet det pekar på"
+#: builtin/mv.c:199
+msgid "source directory is empty"
+msgstr "källkatalogen är tom"
 
-#: builtin/ls-tree.c:29
-msgid "git ls-tree [<options>] <tree-ish> [<path>...]"
-msgstr "git ls-tree [<flaggor>] <träd-igt> [<sökväg>...]"
+#: builtin/mv.c:224
+msgid "not under version control"
+msgstr "inte versionshanterad"
 
-#: builtin/ls-tree.c:127
-msgid "only show trees"
-msgstr "visa endast träd"
+#: builtin/mv.c:227
+msgid "destination exists"
+msgstr "destinationen finns"
 
-#: builtin/ls-tree.c:129
-msgid "recurse into subtrees"
-msgstr "rekursera ner i underträd"
+#: builtin/mv.c:235
+#, c-format
+msgid "overwriting '%s'"
+msgstr "skriver över \"%s\""
 
-#: builtin/ls-tree.c:131
-msgid "show trees when recursing"
-msgstr "visa träd medan rekursering"
+#: builtin/mv.c:238
+msgid "Cannot overwrite"
+msgstr "Kan inte skriva över"
 
-#: builtin/ls-tree.c:134
-msgid "terminate entries with NUL byte"
-msgstr "terminera poster med NUL-byte"
+#: builtin/mv.c:241
+msgid "multiple sources for the same target"
+msgstr "flera källor för samma mål"
+
+#: builtin/mv.c:243
+msgid "destination directory does not exist"
+msgstr "destinationskatalogen finns inte"
+
+#: builtin/mv.c:250
+#, c-format
+msgid "%s, source=%s, destination=%s"
+msgstr "%s, källa=%s, mål=%s"
 
-#: builtin/ls-tree.c:135
-msgid "include object size"
-msgstr "inkludera objektstorlek"
+#: builtin/mv.c:271
+#, c-format
+msgid "Renaming %s to %s\n"
+msgstr "Byter namn på %s till %s\n"
 
-#: builtin/ls-tree.c:137 builtin/ls-tree.c:139
-msgid "list only filenames"
-msgstr "visa endast filnamn"
+#: builtin/mv.c:277 builtin/remote.c:716 builtin/repack.c:518
+#, c-format
+msgid "renaming '%s' failed"
+msgstr "misslyckades byta namn på \"%s\""
 
-#: builtin/ls-tree.c:142
-msgid "use full path names"
-msgstr "använd fullständiga sökvägsnamn"
+#: builtin/name-rev.c:403
+msgid "git name-rev [<options>] <commit>..."
+msgstr "git name-rev [<flaggor>] <incheckning>..."
 
-#: builtin/ls-tree.c:144
-msgid "list entire tree; not just current directory (implies --full-name)"
-msgstr "visa hela trädet; inte bara aktuell katalog (implicerar --full-name)"
+#: builtin/name-rev.c:404
+msgid "git name-rev [<options>] --all"
+msgstr "git name-rev [<flaggor>] --all"
 
-#: builtin/mailsplit.c:241
-#, c-format
-msgid "empty mbox: '%s'"
-msgstr "tom mbox: ”%s”"
+#: builtin/name-rev.c:405
+msgid "git name-rev [<options>] --stdin"
+msgstr "git name-rev [<flaggor>] --stdin"
 
-#: builtin/merge.c:51
-msgid "git merge [<options>] [<commit>...]"
-msgstr "git merge [<flaggor>] [<incheckning>...]"
+#: builtin/name-rev.c:462
+msgid "print only names (no SHA-1)"
+msgstr "skriv endast namn (ingen SHA-1)"
 
-#: builtin/merge.c:52
-msgid "git merge --abort"
-msgstr "git merge --abort"
+#: builtin/name-rev.c:463
+msgid "only use tags to name the commits"
+msgstr "använd endast taggar för att namnge incheckningar"
 
-#: builtin/merge.c:53
-msgid "git merge --continue"
-msgstr "git merge --continue"
+#: builtin/name-rev.c:465
+msgid "only use refs matching <pattern>"
+msgstr "använd endast referenser som motsvarar <mönster>"
 
-#: builtin/merge.c:110
-msgid "switch `m' requires a value"
-msgstr "flaggan \"m\" behöver ett värde"
+#: builtin/name-rev.c:467
+msgid "ignore refs matching <pattern>"
+msgstr "ignorera referenser som motsvarar <mönster>"
 
-#: builtin/merge.c:147
-#, c-format
-msgid "Could not find merge strategy '%s'.\n"
-msgstr "Kunde inte hitta sammanslagningsstrategin \"%s\".\n"
+#: builtin/name-rev.c:469
+msgid "list all commits reachable from all refs"
+msgstr "lista alla incheckningar som kan nås alla referenser"
 
-#: builtin/merge.c:148
-#, c-format
-msgid "Available strategies are:"
-msgstr "Tillgängliga strategier är:"
+#: builtin/name-rev.c:470
+msgid "read from stdin"
+msgstr "läs från standard in"
 
-#: builtin/merge.c:153
-#, c-format
-msgid "Available custom strategies are:"
-msgstr "Tillgängliga skräddarsydda strategier är:"
+#: builtin/name-rev.c:471
+msgid "allow to print `undefined` names (default)"
+msgstr "tillåt att skriva \"odefinierade\" namn (standard)"
 
-#: builtin/merge.c:203 builtin/pull.c:142
-msgid "do not show a diffstat at the end of the merge"
-msgstr "visa inte en diffstat när sammanslagningen är färdig"
+#: builtin/name-rev.c:477
+msgid "dereference tags in the input (internal use)"
+msgstr "avreferera taggar i indata (används internt)"
 
-#: builtin/merge.c:206 builtin/pull.c:145
-msgid "show a diffstat at the end of the merge"
-msgstr "visa en diffstat när sammanslagningen är färdig"
+#: builtin/notes.c:28
+msgid "git notes [--ref <notes-ref>] [list [<object>]]"
+msgstr "git notes [--ref <anteckningsref>] [list [<objekt>]]"
 
-#: builtin/merge.c:207 builtin/pull.c:148
-msgid "(synonym to --stat)"
-msgstr "(synonym till --stat)"
+#: builtin/notes.c:29
+msgid ""
+"git notes [--ref <notes-ref>] add [-f] [--allow-empty] [-m <msg> | -F <file> "
+"| (-c | -C) <object>] [<object>]"
+msgstr ""
+"git notes [--ref <anteckningsref>] add [-f] [--allow-empty] [-m <medd> | -F "
+"<fil> | (-c | -C) <objekt>] [<objekt>]"
 
-#: builtin/merge.c:209 builtin/pull.c:151
-msgid "add (at most <n>) entries from shortlog to merge commit message"
+#: builtin/notes.c:30
+msgid "git notes [--ref <notes-ref>] copy [-f] <from-object> <to-object>"
 msgstr ""
-"lägg till (som mest <n>) poster från shortlog till incheckningsmeddelandet"
+"git notes [--ref <anteckningsref>] copy [-f] <från-objekt> <till-objekt>"
 
-#: builtin/merge.c:212 builtin/pull.c:157
-msgid "create a single commit instead of doing a merge"
-msgstr "skapa en ensam incheckning istället för en sammanslagning"
+#: builtin/notes.c:31
+msgid ""
+"git notes [--ref <notes-ref>] append [--allow-empty] [-m <msg> | -F <file> | "
+"(-c | -C) <object>] [<object>]"
+msgstr ""
+"git notes [--ref <anteckningsref>] append [--allow-empty] [-m <medd> | -F "
+"<fil> | (-c | -C) <objekt>] [<objekt>]"
 
-#: builtin/merge.c:214 builtin/pull.c:160
-msgid "perform a commit if the merge succeeds (default)"
-msgstr "utför en incheckning om sammanslagningen lyckades (standard)"
+#: builtin/notes.c:32
+msgid "git notes [--ref <notes-ref>] edit [--allow-empty] [<object>]"
+msgstr "git notes [--ref <anteckningsref>] edit [--allow-empty] [<objekt>]"
 
-#: builtin/merge.c:216 builtin/pull.c:163
-msgid "edit message before committing"
-msgstr "redigera meddelande innan incheckning"
+#: builtin/notes.c:33
+msgid "git notes [--ref <notes-ref>] show [<object>]"
+msgstr "git notes [--ref <anteckningsref>] show [<objekt>]"
 
-#: builtin/merge.c:217
-msgid "allow fast-forward (default)"
-msgstr "tillåt snabbspolning (standard)"
+#: builtin/notes.c:34
+msgid ""
+"git notes [--ref <notes-ref>] merge [-v | -q] [-s <strategy>] <notes-ref>"
+msgstr ""
+"git notes [--ref <anteckningsref>] merge [-v | -q] [-s <strategi>] "
+"<anteckningsref>"
 
-#: builtin/merge.c:219 builtin/pull.c:169
-msgid "abort if fast-forward is not possible"
-msgstr "avbryt om snabbspolning inte är möjlig"
+#: builtin/notes.c:35
+msgid "git notes merge --commit [-v | -q]"
+msgstr "git notes merge --commit [-v | -q]"
 
-#: builtin/merge.c:223 builtin/pull.c:172
-msgid "verify that the named commit has a valid GPG signature"
-msgstr "bekräfta att den namngivna incheckningen har en giltig GPG-signatur"
+#: builtin/notes.c:36
+msgid "git notes merge --abort [-v | -q]"
+msgstr "git notes merge --abort [-v | -q]"
 
-#: builtin/merge.c:224 builtin/notes.c:777 builtin/pull.c:176
-#: builtin/revert.c:109
-msgid "strategy"
-msgstr "strategi"
+#: builtin/notes.c:37
+msgid "git notes [--ref <notes-ref>] remove [<object>...]"
+msgstr "git notes [--ref <anteckningsref>] remove [<objekt>...]"
 
-#: builtin/merge.c:225 builtin/pull.c:177
-msgid "merge strategy to use"
-msgstr "sammanslagningsstrategi att använda"
+#: builtin/notes.c:38
+msgid "git notes [--ref <notes-ref>] prune [-n] [-v]"
+msgstr "git notes [--ref <anteckningsref>] prune [-n] [-v]"
 
-#: builtin/merge.c:226 builtin/pull.c:180
-msgid "option=value"
-msgstr "alternativ=värde"
+#: builtin/notes.c:39
+msgid "git notes [--ref <notes-ref>] get-ref"
+msgstr "git notes [--ref <anteckningsref>] get-ref"
 
-#: builtin/merge.c:227 builtin/pull.c:181
-msgid "option for selected merge strategy"
-msgstr "alternativ för vald sammanslagningsstrategi"
+#: builtin/notes.c:44
+msgid "git notes [list [<object>]]"
+msgstr "git notes [list [<objekt>]]"
 
-#: builtin/merge.c:229
-msgid "merge commit message (for a non-fast-forward merge)"
-msgstr "incheckningsmeddelande för (icke snabbspolande) sammanslagning"
+#: builtin/notes.c:49
+msgid "git notes add [<options>] [<object>]"
+msgstr "git notes add [<flaggor>] [<objekt>]"
 
-#: builtin/merge.c:233
-msgid "abort the current in-progress merge"
-msgstr "avbryt den pågående sammanslagningen"
+#: builtin/notes.c:54
+msgid "git notes copy [<options>] <from-object> <to-object>"
+msgstr "git notes copy [<flaggor>] <från-objekt> <till-objekt>"
 
-#: builtin/merge.c:235
-msgid "continue the current in-progress merge"
-msgstr "fortsätt den pågående sammanslagningen"
+#: builtin/notes.c:55
+msgid "git notes copy --stdin [<from-object> <to-object>]..."
+msgstr "git notes copy --stdin [<från-objekt> <till-objekt>]..."
 
-#: builtin/merge.c:237 builtin/pull.c:188
-msgid "allow merging unrelated histories"
-msgstr "tillåt sammanslagning av orelaterade historier"
+#: builtin/notes.c:60
+msgid "git notes append [<options>] [<object>]"
+msgstr "git notes append [<flaggor>] [<objekt>]"
 
-#: builtin/merge.c:243
-msgid "verify commit-msg hook"
-msgstr "bekräfta commit-msg-krok"
+#: builtin/notes.c:65
+msgid "git notes edit [<object>]"
+msgstr "git notes edit [<objekt>]"
 
-#: builtin/merge.c:268
-msgid "could not run stash."
-msgstr "kunde köra stash."
+#: builtin/notes.c:70
+msgid "git notes show [<object>]"
+msgstr "git notes show [<objekt>]"
 
-#: builtin/merge.c:273
-msgid "stash failed"
-msgstr "stash misslyckades"
+#: builtin/notes.c:75
+msgid "git notes merge [<options>] <notes-ref>"
+msgstr "git notes merge [<flaggor>] <anteckningsref>"
 
-#: builtin/merge.c:278
-#, c-format
-msgid "not a valid object: %s"
-msgstr "inte ett giltigt objekt: %s"
+#: builtin/notes.c:76
+msgid "git notes merge --commit [<options>]"
+msgstr "git notes merge --commit [<flaggor>]"
 
-#: builtin/merge.c:300 builtin/merge.c:317
-msgid "read-tree failed"
-msgstr "read-tree misslyckades"
+#: builtin/notes.c:77
+msgid "git notes merge --abort [<options>]"
+msgstr "git notes merge --abort [<flaggor>]"
 
-#: builtin/merge.c:347
-msgid " (nothing to squash)"
-msgstr " (inget att platta till)"
+#: builtin/notes.c:82
+msgid "git notes remove [<object>]"
+msgstr "git notes remove [<objekt>]"
 
-#: builtin/merge.c:358
-#, c-format
-msgid "Squash commit -- not updating HEAD\n"
-msgstr "Tillplattningsincheckning -- uppdaterar inte HEAD\n"
+#: builtin/notes.c:87
+msgid "git notes prune [<options>]"
+msgstr "git notes prune [<flaggor>]"
 
-#: builtin/merge.c:408
-#, c-format
-msgid "No merge message -- not updating HEAD\n"
-msgstr "Inget sammanslagningsmeddelande -- uppdaterar inte HEAD\n"
+#: builtin/notes.c:92
+msgid "git notes get-ref"
+msgstr "git notes get-ref"
 
-#: builtin/merge.c:458
-#, c-format
-msgid "'%s' does not point to a commit"
-msgstr "\"%s\" verkar inte peka på en incheckning"
+#: builtin/notes.c:97
+msgid "Write/edit the notes for the following object:"
+msgstr "Skriv/redigera anteckningar för följande objekt:"
 
-#: builtin/merge.c:548
+#: builtin/notes.c:150
 #, c-format
-msgid "Bad branch.%s.mergeoptions string: %s"
-msgstr "Felaktig branch.%s.mergeoptions-sträng: %s"
+msgid "unable to start 'show' for object '%s'"
+msgstr "kunde inte starta \"show\" för objektet \"%s\""
 
-#: builtin/merge.c:669
-msgid "Not handling anything other than two heads merge."
-msgstr "Hanterar inte något annat än en sammanslagning av två huvuden."
+#: builtin/notes.c:154
+msgid "could not read 'show' output"
+msgstr "kunde inte läsa utdata från \"show\""
 
-#: builtin/merge.c:683
+#: builtin/notes.c:162
 #, c-format
-msgid "Unknown option for merge-recursive: -X%s"
-msgstr "Felaktig flagga för merge-recursive: -X%s"
+msgid "failed to finish 'show' for object '%s'"
+msgstr "kunde inte avsluta \"show\" för objektet \"%s\""
 
-#: builtin/merge.c:698
-#, c-format
-msgid "unable to write %s"
-msgstr "kunde inte skriva %s"
+#: builtin/notes.c:197
+msgid "please supply the note contents using either -m or -F option"
+msgstr "ange innehåll för anteckningen med antingen -m eller -F"
 
-#: builtin/merge.c:749
-#, c-format
-msgid "Could not read from '%s'"
-msgstr "Kunde inte läsa från \"%s\""
+#: builtin/notes.c:206
+msgid "unable to write note object"
+msgstr "kunde inte skriva anteckningsobjekt"
 
-#: builtin/merge.c:758
+#: builtin/notes.c:208
 #, c-format
-msgid "Not committing merge; use 'git commit' to complete the merge.\n"
-msgstr ""
-"Checkar inte in sammanslagningen; använd \"git commit\" för att slutföra "
-"den.\n"
+msgid "the note contents have been left in %s"
+msgstr "anteckningens innehåll har lämnats kvar i %s"
 
-#: builtin/merge.c:764
+#: builtin/notes.c:242 builtin/tag.c:532
 #, c-format
-msgid ""
-"Please enter a commit message to explain why this merge is necessary,\n"
-"especially if it merges an updated upstream into a topic branch.\n"
-"\n"
-"Lines starting with '%c' will be ignored, and an empty message aborts\n"
-"the commit.\n"
-msgstr ""
-"Ange ett incheckningsmeddelande för att förklara varför sammanslagningen\n"
-"är nödvändig, speciellt om den slår in en uppdaterad uppström i en\n"
-"temagren.\n"
-"\n"
-"Rader som inleds med \"%c\" kommer ignoreras, och ett tomt meddelande\n"
-"avbryter incheckningen.\n"
-
-#: builtin/merge.c:800
-msgid "Empty commit message."
-msgstr "Tomt incheckningsmeddelande."
+msgid "could not open or read '%s'"
+msgstr "kunde inte öppna eller läsa \"%s\""
 
-#: builtin/merge.c:819
+#: builtin/notes.c:263 builtin/notes.c:313 builtin/notes.c:315
+#: builtin/notes.c:383 builtin/notes.c:438 builtin/notes.c:526
+#: builtin/notes.c:531 builtin/notes.c:610 builtin/notes.c:672
 #, c-format
-msgid "Wonderful.\n"
-msgstr "Underbart.\n"
+msgid "failed to resolve '%s' as a valid ref."
+msgstr "kunde inte slå upp \"%s\" som en giltig referens."
 
-#: builtin/merge.c:872
+#: builtin/notes.c:265
 #, c-format
-msgid "Automatic merge failed; fix conflicts and then commit the result.\n"
-msgstr ""
-"Kunde inte slå ihop automatiskt; fixa konflikter och checka in resultatet.\n"
-
-#: builtin/merge.c:911
-msgid "No current branch."
-msgstr "Inte på någon gren."
+msgid "failed to read object '%s'."
+msgstr "kunde inte läsa objektet \"%s\"."
 
-#: builtin/merge.c:913
-msgid "No remote for the current branch."
-msgstr "Ingen fjärr för aktuell gren."
+#: builtin/notes.c:268
+#, c-format
+msgid "cannot read note data from non-blob object '%s'."
+msgstr "kan inte läsa anteckningsdata från icke-blob-objektet \"%s\"."
 
-#: builtin/merge.c:915
-msgid "No default upstream defined for the current branch."
-msgstr "Ingen standarduppström angiven för aktuell gren."
+#: builtin/notes.c:309
+#, c-format
+msgid "malformed input line: '%s'."
+msgstr "felaktig indatarad: \"%s\"."
 
-#: builtin/merge.c:920
+#: builtin/notes.c:324
 #, c-format
-msgid "No remote-tracking branch for %s from %s"
-msgstr "Ingen fjärrspårande gren för %s från %s"
+msgid "failed to copy notes from '%s' to '%s'"
+msgstr "misslyckades kopiera anteckningar från \"%s\" till \"%s\""
 
-#: builtin/merge.c:973
+#. TRANSLATORS: the first %s will be replaced by a git
+#. notes command: 'add', 'merge', 'remove', etc.
+#.
+#: builtin/notes.c:356
 #, c-format
-msgid "Bad value '%s' in environment '%s'"
-msgstr "Felaktigt värde \"%s\" i miljövariabeln \"%s\""
+msgid "refusing to %s notes in %s (outside of refs/notes/)"
+msgstr "vägrar utföra \"%s\" på anteckningar i %s (utanför refs/notes/)"
 
-#: builtin/merge.c:1075
+#: builtin/notes.c:376 builtin/notes.c:431 builtin/notes.c:509
+#: builtin/notes.c:521 builtin/notes.c:598 builtin/notes.c:665
+#: builtin/notes.c:815 builtin/notes.c:963 builtin/notes.c:985
+msgid "too many parameters"
+msgstr "för många parametrar"
+
+#: builtin/notes.c:389 builtin/notes.c:678
 #, c-format
-msgid "not something we can merge in %s: %s"
-msgstr "inte något vi kan slå ihop med %s: %s"
+msgid "no note found for object %s."
+msgstr "inga anteckningar hittades för objektet %s."
 
-#: builtin/merge.c:1109
-msgid "not something we can merge"
-msgstr "inte något vi kan slå ihop"
+#: builtin/notes.c:410 builtin/notes.c:576
+msgid "note contents as a string"
+msgstr "anteckningsinnehåll som sträng"
 
-#: builtin/merge.c:1211
-msgid "--abort expects no arguments"
-msgstr "--abort tar inga argument"
+#: builtin/notes.c:413 builtin/notes.c:579
+msgid "note contents in a file"
+msgstr "anteckningsinnehåll i en fil"
 
-#: builtin/merge.c:1215
-msgid "There is no merge to abort (MERGE_HEAD missing)."
-msgstr "Ingen sammanslagning att avbryta (MERGE_HEAD saknas)."
+#: builtin/notes.c:416 builtin/notes.c:582
+msgid "reuse and edit specified note object"
+msgstr "återanvänd och redigera angivet anteckningsobjekt"
 
-#: builtin/merge.c:1227
-msgid "--continue expects no arguments"
-msgstr "--continue tar inga argument"
+#: builtin/notes.c:419 builtin/notes.c:585
+msgid "reuse specified note object"
+msgstr "återanvänd angivet anteckningsobjekt"
 
-#: builtin/merge.c:1231
-msgid "There is no merge in progress (MERGE_HEAD missing)."
-msgstr "Ingen sammanslagning pågår (MERGE_HEAD saknas)."
+#: builtin/notes.c:422 builtin/notes.c:588
+msgid "allow storing empty note"
+msgstr "tillåt lagra tom anteckning"
 
-#: builtin/merge.c:1247
-msgid ""
-"You have not concluded your merge (MERGE_HEAD exists).\n"
-"Please, commit your changes before you merge."
-msgstr ""
-"Du har inte avslutat sammanslagningen (MERGE_HEAD finns).\n"
-"Checka in dina ändringar innan du slår ihop."
+#: builtin/notes.c:423 builtin/notes.c:496
+msgid "replace existing notes"
+msgstr "ersätt befintliga anteckningar"
 
-#: builtin/merge.c:1254
+#: builtin/notes.c:448
+#, c-format
 msgid ""
-"You have not concluded your cherry-pick (CHERRY_PICK_HEAD exists).\n"
-"Please, commit your changes before you merge."
+"Cannot add notes. Found existing notes for object %s. Use '-f' to overwrite "
+"existing notes"
 msgstr ""
-"Du har inte avslutat din \"cherry-pick\" (CHERRY_PICK_HEAD finns).\n"
-"Checka in dina ändringar innan du slår ihop."
-
-#: builtin/merge.c:1257
-msgid "You have not concluded your cherry-pick (CHERRY_PICK_HEAD exists)."
-msgstr "Du har inte avslutat din \"cherry-pick\" (CHERRY_PICK_HEAD finns)."
-
-#: builtin/merge.c:1266
-msgid "You cannot combine --squash with --no-ff."
-msgstr "Du kan inte kombinera --squash med --no-ff."
-
-#: builtin/merge.c:1274
-msgid "No commit specified and merge.defaultToUpstream not set."
-msgstr "Ingen incheckning angiven och merge.defaultToUpstream är ej satt."
-
-#: builtin/merge.c:1291
-msgid "Squash commit into empty head not supported yet"
-msgstr "Stöder inte en tillplattningsincheckning på ett tomt huvud ännu"
+"Kan inte lägga till anteckningar. Hittade befintliga anteckningar för "
+"objektet %s. Använd \"-f\" för att skriva över befintliga anteckningar"
 
-#: builtin/merge.c:1293
-msgid "Non-fast-forward commit does not make sense into an empty head"
-msgstr "Icke-snabbspolad incheckning kan inte användas med ett tomt huvud"
+#: builtin/notes.c:463 builtin/notes.c:544
+#, c-format
+msgid "Overwriting existing notes for object %s\n"
+msgstr "Skriver över befintliga anteckningar för objektet %s\n"
 
-#: builtin/merge.c:1298
+#: builtin/notes.c:475 builtin/notes.c:637 builtin/notes.c:902
 #, c-format
-msgid "%s - not something we can merge"
-msgstr "%s - inte något vi kan slå ihop"
+msgid "Removing note for object %s\n"
+msgstr "Tar bort anteckning för objektet %s\n"
 
-#: builtin/merge.c:1300
-msgid "Can merge only exactly one commit into empty head"
-msgstr "Kan endast slå ihop en enda incheckning i ett tomt huvud"
+#: builtin/notes.c:497
+msgid "read objects from stdin"
+msgstr "läs objekt från standard in"
 
-#: builtin/merge.c:1334
-#, c-format
-msgid "Commit %s has an untrusted GPG signature, allegedly by %s."
-msgstr ""
-"Incheckningen %s har en obetrodd GPG-signatur som påstås vara gjord av %s."
+#: builtin/notes.c:499
+msgid "load rewriting config for <command> (implies --stdin)"
+msgstr "läs omskrivningsinställning för <kommando> (implicerar --stdin)"
+
+#: builtin/notes.c:517
+msgid "too few parameters"
+msgstr "för få parametrar"
 
-#: builtin/merge.c:1337
+#: builtin/notes.c:538
 #, c-format
-msgid "Commit %s has a bad GPG signature allegedly by %s."
+msgid ""
+"Cannot copy notes. Found existing notes for object %s. Use '-f' to overwrite "
+"existing notes"
 msgstr ""
-"Incheckningen %s har en felaktig GPG-signatur som påstås vara gjord av %s."
+"Kan inte kopiera anteckningar. Hittade befintliga anteckningar för objektet "
+"%s. Använd \"-f\" för att skriva över befintliga anteckningar"
 
-#: builtin/merge.c:1340
+#: builtin/notes.c:550
 #, c-format
-msgid "Commit %s does not have a GPG signature."
-msgstr "Incheckning %s har inte någon GPG-signatur."
+msgid "missing notes on source object %s. Cannot copy."
+msgstr "anteckningar på källobjektet %s saknas. Kan inte kopiera."
 
-#: builtin/merge.c:1343
+#: builtin/notes.c:603
 #, c-format
-msgid "Commit %s has a good GPG signature by %s\n"
-msgstr "Incheckningen %s har en korrekt GPG-signatur av %s\n"
-
-#: builtin/merge.c:1402
-msgid "refusing to merge unrelated histories"
-msgstr "vägrar slå samman orelaterad historik"
+msgid ""
+"The -m/-F/-c/-C options have been deprecated for the 'edit' subcommand.\n"
+"Please use 'git notes add -f -m/-F/-c/-C' instead.\n"
+msgstr ""
+"Flaggorna -m/-F/-c/-C rekommenderas inte för underkommandot \"edit\".\n"
+"Använd \"git notes add -f -m/-F/-c/-C\" istället.\n"
 
-#: builtin/merge.c:1411
-msgid "Already up to date."
-msgstr "Redan à jour."
+#: builtin/notes.c:698
+msgid "failed to delete ref NOTES_MERGE_PARTIAL"
+msgstr "misslyckades ta bort referensen NOTES_MERGE_PARTIAL"
 
-#: builtin/merge.c:1421
-#, c-format
-msgid "Updating %s..%s\n"
-msgstr "Uppdaterar %s..%s\n"
+#: builtin/notes.c:700
+msgid "failed to delete ref NOTES_MERGE_REF"
+msgstr "misslyckades ta bort referensen NOTES_MERGE_REF"
 
-#: builtin/merge.c:1462
-#, c-format
-msgid "Trying really trivial in-index merge...\n"
-msgstr "Försöker riktigt enkel sammanslagning i indexet...\n"
+#: builtin/notes.c:702
+msgid "failed to remove 'git notes merge' worktree"
+msgstr "misslyckades ta bort arbetskatalogen för \"git notes merge\""
 
-#: builtin/merge.c:1469
-#, c-format
-msgid "Nope.\n"
-msgstr "Nej.\n"
+#: builtin/notes.c:722
+msgid "failed to read ref NOTES_MERGE_PARTIAL"
+msgstr "misslyckades läsa references NOTES_MERGE_PARTIAL"
 
-#: builtin/merge.c:1494
-msgid "Already up to date. Yeeah!"
-msgstr "Redan à jour. Toppen!"
+#: builtin/notes.c:724
+msgid "could not find commit from NOTES_MERGE_PARTIAL."
+msgstr "kunde inte hitta incheckning från NOTES_MERGE_PARTIAL."
 
-#: builtin/merge.c:1500
-msgid "Not possible to fast-forward, aborting."
-msgstr "Kan inte snabbspola, avbryter."
+#: builtin/notes.c:726
+msgid "could not parse commit from NOTES_MERGE_PARTIAL."
+msgstr "kunde inte tolka incheckning från NOTES_MERGE_PARTIAL."
 
-#: builtin/merge.c:1523 builtin/merge.c:1602
-#, c-format
-msgid "Rewinding the tree to pristine...\n"
-msgstr "Återspolar trädet till orört...\n"
+#: builtin/notes.c:739
+msgid "failed to resolve NOTES_MERGE_REF"
+msgstr "misslyckades bestämma NOTES_MERGE_REF"
 
-#: builtin/merge.c:1527
-#, c-format
-msgid "Trying merge strategy %s...\n"
-msgstr "Försöker sammanslagningsstrategin %s...\n"
+#: builtin/notes.c:742
+msgid "failed to finalize notes merge"
+msgstr "misslyckades färdigställa sammanslagning av anteckningar"
 
-#: builtin/merge.c:1593
+#: builtin/notes.c:768
 #, c-format
-msgid "No merge strategy handled the merge.\n"
-msgstr "Ingen sammanslagningsstrategi hanterade sammanslagningen.\n"
+msgid "unknown notes merge strategy %s"
+msgstr "okänd sammanslagningsstrategi för anteckningar: %s"
 
-#: builtin/merge.c:1595
-#, c-format
-msgid "Merge with strategy %s failed.\n"
-msgstr "Sammanslagning med strategin %s misslyckades.\n"
+#: builtin/notes.c:784
+msgid "General options"
+msgstr "Allmänna flaggor"
 
-#: builtin/merge.c:1604
-#, c-format
-msgid "Using the %s to prepare resolving by hand.\n"
-msgstr "Använder %s för att förbereda lösning för hand.\n"
+#: builtin/notes.c:786
+msgid "Merge options"
+msgstr "Flaggor för sammanslagning"
 
-#: builtin/merge.c:1616
-#, c-format
-msgid "Automatic merge went well; stopped before committing as requested\n"
+#: builtin/notes.c:788
+msgid ""
+"resolve notes conflicts using the given strategy (manual/ours/theirs/union/"
+"cat_sort_uniq)"
 msgstr ""
-"Automatisk sammanslagning lyckades; stoppar före incheckning som önskat\n"
-
-#: builtin/merge-base.c:30
-msgid "git merge-base [-a | --all] <commit> <commit>..."
-msgstr "git merge-base [-a | --all] <incheckning> <incheckning>..."
+"läs konflikter i anteckningar med angiven strategi (manual/ours/theirs/union/"
+"cat_sort_uniq)"
 
-#: builtin/merge-base.c:31
-msgid "git merge-base [-a | --all] --octopus <commit>..."
-msgstr "git merge-base [-a | --all] --octopus <incheckning>..."
+#: builtin/notes.c:790
+msgid "Committing unmerged notes"
+msgstr "Checkar in ej sammanslagna anteckningar"
 
-#: builtin/merge-base.c:32
-msgid "git merge-base --independent <commit>..."
-msgstr "git merge-base --independent <incheckning>..."
+#: builtin/notes.c:792
+msgid "finalize notes merge by committing unmerged notes"
+msgstr ""
+"färdigställ sammanslagning av anteckningar genom att checka in ej "
+"sammanslagna anteckningar"
 
-#: builtin/merge-base.c:33
-msgid "git merge-base --is-ancestor <commit> <commit>"
-msgstr "git merge-base --is-ancestor <incheckning> <incheckning>"
+#: builtin/notes.c:794
+msgid "Aborting notes merge resolution"
+msgstr "Avbryt lösning av sammanslagning av anteckningar"
 
-#: builtin/merge-base.c:34
-msgid "git merge-base --fork-point <ref> [<commit>]"
-msgstr "git merge-base --fork-point <ref> [<incheckning>]"
+#: builtin/notes.c:796
+msgid "abort notes merge"
+msgstr "avbryt sammanslagning av anteckningar"
 
-#: builtin/merge-base.c:220
-msgid "output all common ancestors"
-msgstr "skriv ut alla gemensamma anfäder"
+#: builtin/notes.c:807
+msgid "cannot mix --commit, --abort or -s/--strategy"
+msgstr "kan inte blanda --commit, --abort eller -s/--strategy"
 
-#: builtin/merge-base.c:222
-msgid "find ancestors for a single n-way merge"
-msgstr "hitta anfader för enkel n-vägssammanslagning"
+#: builtin/notes.c:812
+msgid "must specify a notes ref to merge"
+msgstr "måste ange en antecknings-referens att slå ihop"
 
-#: builtin/merge-base.c:224
-msgid "list revs not reachable from others"
-msgstr "visa revisioner som inte kan nås från andra"
+#: builtin/notes.c:836
+#, c-format
+msgid "unknown -s/--strategy: %s"
+msgstr "okänd -s/--strategy: %s"
 
-#: builtin/merge-base.c:226
-msgid "is the first one ancestor of the other?"
-msgstr "är den första anfader till den andra?"
+#: builtin/notes.c:873
+#, c-format
+msgid "a notes merge into %s is already in-progress at %s"
+msgstr "sammanslagning av anteckningar till %s är redan igångsatt på %s"
 
-#: builtin/merge-base.c:228
-msgid "find where <commit> forked from reflog of <ref>"
-msgstr "se var <incheckning> grenades av från referensloggen från <ref>"
+#: builtin/notes.c:876
+#, c-format
+msgid "failed to store link to current notes ref (%s)"
+msgstr "misslyckades lagra länk till aktuell anteckningsreferens (%s)"
 
-#: builtin/merge-file.c:9
+#: builtin/notes.c:878
+#, c-format
 msgid ""
-"git merge-file [<options>] [-L <name1> [-L <orig> [-L <name2>]]] <file1> "
-"<orig-file> <file2>"
+"Automatic notes merge failed. Fix conflicts in %s and commit the result with "
+"'git notes merge --commit', or abort the merge with 'git notes merge --"
+"abort'.\n"
 msgstr ""
-"git merge-file [<alternativ>] [-L <namn1> [-L <orig> [-L <namn2>]]] <fil1> "
-"<origfil> <fil2>"
+"Automatisk sammanslagning av anteckningar misslyckades. Rätta konflikter i "
+"%s och checka in resultatet med \"git notes merge --commit\", eller avbryt "
+"sammanslagningen med \"git notes merge --abort\".\n"
 
-#: builtin/merge-file.c:33
-msgid "send results to standard output"
-msgstr "sänd resultat till standard ut"
+#: builtin/notes.c:897 builtin/tag.c:545
+#, c-format
+msgid "Failed to resolve '%s' as a valid ref."
+msgstr "Kunde inte slå upp \"%s\" som en giltig referens."
 
-#: builtin/merge-file.c:34
-msgid "use a diff3 based merge"
-msgstr "använd diff3-baserad sammanslagning"
+#: builtin/notes.c:900
+#, c-format
+msgid "Object %s has no note\n"
+msgstr "Objektet %s har ingen anteckning\n"
 
-#: builtin/merge-file.c:35
-msgid "for conflicts, use our version"
-msgstr "för konflikter, använd vår version"
+#: builtin/notes.c:912
+msgid "attempt to remove non-existent note is not an error"
+msgstr "försök att ta bort icke-existerande anteckningar är inte ett fel"
+
+#: builtin/notes.c:915
+msgid "read object names from the standard input"
+msgstr "läs objektnamn från standard in"
+
+#: builtin/notes.c:954 builtin/prune.c:130 builtin/worktree.c:164
+msgid "do not remove, show only"
+msgstr "ta inte bort, bara visa"
 
-#: builtin/merge-file.c:37
-msgid "for conflicts, use their version"
-msgstr "för konflikter, använd deras version"
+#: builtin/notes.c:955
+msgid "report pruned notes"
+msgstr "rapportera borttagna anteckningar"
 
-#: builtin/merge-file.c:39
-msgid "for conflicts, use a union version"
-msgstr "för konflikter, använd en förenad version"
+#: builtin/notes.c:998
+msgid "notes-ref"
+msgstr "anteckningar-ref"
 
-#: builtin/merge-file.c:42
-msgid "for conflicts, use this marker size"
-msgstr "för konflikter, använd denna markörstorlek"
+#: builtin/notes.c:999
+msgid "use notes from <notes-ref>"
+msgstr "använd anteckningar från <anteckningsref>"
 
-#: builtin/merge-file.c:43
-msgid "do not warn about conflicts"
-msgstr "varna inte om konflikter"
+#: builtin/notes.c:1034 builtin/stash.c:1607
+#, c-format
+msgid "unknown subcommand: %s"
+msgstr "okänt underkommando: %s"
 
-#: builtin/merge-file.c:45
-msgid "set labels for file1/orig-file/file2"
-msgstr "sätt etiketter för fil1/origfil/fil2"
+#: builtin/pack-objects.c:52
+msgid ""
+"git pack-objects --stdout [<options>...] [< <ref-list> | < <object-list>]"
+msgstr ""
+"git pack-objects --stdout [<flaggor>...] [< <reflista> | < <objektlista>]"
+
+#: builtin/pack-objects.c:53
+msgid ""
+"git pack-objects [<options>...] <base-name> [< <ref-list> | < <object-list>]"
+msgstr ""
+"git pack-objects [<flaggor>...] <basnamn> [< <reflista> | < <objektlista>]"
 
-#: builtin/merge-recursive.c:45
+#: builtin/pack-objects.c:428
 #, c-format
-msgid "unknown option %s"
-msgstr "okänd flagga %s"
+msgid "bad packed object CRC for %s"
+msgstr "felaktig CRC för packat objekt %s"
 
-#: builtin/merge-recursive.c:51
+#: builtin/pack-objects.c:439
 #, c-format
-msgid "could not parse object '%s'"
-msgstr "kunde inte tolka objektet \"%s\""
+msgid "corrupt packed object for %s"
+msgstr "trasigt packat objekt för %s"
 
-#: builtin/merge-recursive.c:55
+#: builtin/pack-objects.c:570
 #, c-format
-msgid "cannot handle more than %d base. Ignoring %s."
-msgid_plural "cannot handle more than %d bases. Ignoring %s."
-msgstr[0] "kan inte hantera mer än %d bas. Ignorerar %s."
-msgstr[1] "kan inte hantera mer än %d baser. Ignorerar %s."
+msgid "recursive delta detected for object %s"
+msgstr "rekursivt delta upptäcktes för objektet %s"
 
-#: builtin/merge-recursive.c:63
-msgid "not handling anything other than two heads merge."
-msgstr "hanterar inte något annat än en sammanslagning av två huvuden."
+#: builtin/pack-objects.c:781
+#, c-format
+msgid "ordered %u objects, expected %<PRIu32>"
+msgstr "ordnade %u objekt, förväntade %<PRIu32>"
 
-#: builtin/merge-recursive.c:69 builtin/merge-recursive.c:71
+#: builtin/pack-objects.c:794
 #, c-format
-msgid "could not resolve ref '%s'"
-msgstr "kunde inte bestämma referensen ”%s”"
+msgid "packfile is invalid: %s"
+msgstr "packfil är ogiltig: %s"
 
-#: builtin/merge-recursive.c:77
+#: builtin/pack-objects.c:798
 #, c-format
-msgid "Merging %s with %s\n"
-msgstr "Slår ihop %s med %s\n"
+msgid "unable to open packfile for reuse: %s"
+msgstr "kan inte öppna packfil för återanvändning: %s"
 
-#: builtin/mktree.c:65
-msgid "git mktree [-z] [--missing] [--batch]"
-msgstr "git mktree [-z] [--missing] [--batch]"
+#: builtin/pack-objects.c:802
+msgid "unable to seek in reused packfile"
+msgstr "kan inte söka i återanvänd packfil"
 
-#: builtin/mktree.c:153
-msgid "input is NUL terminated"
-msgstr "indata är NUL-terminerad"
+#: builtin/pack-objects.c:813
+msgid "unable to read from reused packfile"
+msgstr "kan inte läsa från återanvänd packfil"
 
-#: builtin/mktree.c:154 builtin/write-tree.c:25
-msgid "allow missing objects"
-msgstr "tillåt saknade objekt"
+#: builtin/pack-objects.c:841
+msgid "disabling bitmap writing, packs are split due to pack.packSizeLimit"
+msgstr ""
+"inaktiverar skrivning av bitkarta, paket delas på grund av pack.packSizeLimit"
 
-#: builtin/mktree.c:155
-msgid "allow creation of more than one tree"
-msgstr "tillåt skapa mer än ett träd"
+#: builtin/pack-objects.c:854
+msgid "Writing objects"
+msgstr "Skriver objekt"
 
-#: builtin/mv.c:17
-msgid "git mv [<options>] <source>... <destination>"
-msgstr "git mv [<flaggor>] <källa>... <mål>"
+#: builtin/pack-objects.c:917 builtin/update-index.c:90
+#, c-format
+msgid "failed to stat %s"
+msgstr "misslyckades ta status på %s"
 
-#: builtin/mv.c:82
+#: builtin/pack-objects.c:970
 #, c-format
-msgid "Directory %s is in index and no submodule?"
-msgstr "Katalogen %s är i indexet och inte en undermodul?"
+msgid "wrote %<PRIu32> objects while expecting %<PRIu32>"
+msgstr "skrev %<PRIu32> objekt medan %<PRIu32> förväntades"
 
-#: builtin/mv.c:84 builtin/rm.c:288
-msgid "Please stage your changes to .gitmodules or stash them to proceed"
-msgstr ""
-"Köa dina ändringar i .gitmodules eller använd \"stash\" för att fortsätta"
+#: builtin/pack-objects.c:1164
+msgid "disabling bitmap writing, as some objects are not being packed"
+msgstr "inaktiverar skrivning av bitkarta då några objekt inte packas"
 
-#: builtin/mv.c:102
+#: builtin/pack-objects.c:1592
 #, c-format
-msgid "%.*s is in index"
-msgstr "%.*s är i indexet"
+msgid "delta base offset overflow in pack for %s"
+msgstr "deltabasoffset utanför gränsen i pack för %s"
 
-#: builtin/mv.c:124
-msgid "force move/rename even if target exists"
-msgstr "tvinga flytta/ändra namn även om målet finns"
+#: builtin/pack-objects.c:1601
+#, c-format
+msgid "delta base offset out of bound for %s"
+msgstr "deltabasoffset utanför gränsvärden för %s"
 
-#: builtin/mv.c:126
-msgid "skip move/rename errors"
-msgstr "hoppa över fel vid flytt/namnändring"
+#: builtin/pack-objects.c:1870
+msgid "Counting objects"
+msgstr "Räknar objekt"
 
-#: builtin/mv.c:168
+#: builtin/pack-objects.c:2000
 #, c-format
-msgid "destination '%s' is not a directory"
-msgstr "destinationen \"%s\" är ingen katalog"
+msgid "unable to get size of %s"
+msgstr "kan inte hämta storlek på %s"
 
-#: builtin/mv.c:179
+#: builtin/pack-objects.c:2015
 #, c-format
-msgid "Checking rename of '%s' to '%s'\n"
-msgstr "Kontrollerar namnbyte av \"%s\" till \"%s\"\n"
+msgid "unable to parse object header of %s"
+msgstr "kunde inte tolka objekthuvud för %s"
 
-#: builtin/mv.c:183
-msgid "bad source"
-msgstr "felaktig källa"
+#: builtin/pack-objects.c:2085 builtin/pack-objects.c:2101
+#: builtin/pack-objects.c:2111
+#, c-format
+msgid "object %s cannot be read"
+msgstr "objektet %s kunde inte läsas"
 
-#: builtin/mv.c:186
-msgid "can not move directory into itself"
-msgstr "kan inte flytta katalog till sig själv"
+#: builtin/pack-objects.c:2088 builtin/pack-objects.c:2115
+#, c-format
+msgid "object %s inconsistent object length (%<PRIuMAX> vs %<PRIuMAX>)"
+msgstr "objektet %s har inkonsistent objektlängd (%<PRIuMAX> mot %<PRIuMAX>)"
 
-#: builtin/mv.c:189
-msgid "cannot move directory over file"
-msgstr "kan inte flytta katalog över fil"
+#: builtin/pack-objects.c:2125
+msgid "suboptimal pack - out of memory"
+msgstr "icke-optimalt pack - minnet slut"
 
-#: builtin/mv.c:198
-msgid "source directory is empty"
-msgstr "källkatalogen är tom"
+#: builtin/pack-objects.c:2440
+#, c-format
+msgid "Delta compression using up to %d threads"
+msgstr "Deltakomprimering använder upp till %d trådar"
 
-#: builtin/mv.c:223
-msgid "not under version control"
-msgstr "inte versionshanterad"
+#: builtin/pack-objects.c:2572
+#, c-format
+msgid "unable to pack objects reachable from tag %s"
+msgstr "kan inte packa objekt nåbara från taggen %s"
 
-#: builtin/mv.c:226
-msgid "destination exists"
-msgstr "destinationen finns"
+#: builtin/pack-objects.c:2659
+msgid "Compressing objects"
+msgstr "Komprimerar objekt"
 
-#: builtin/mv.c:234
+#: builtin/pack-objects.c:2665
+msgid "inconsistency with delta count"
+msgstr "deltaräknaren är inkonsekvent"
+
+#: builtin/pack-objects.c:2742
 #, c-format
-msgid "overwriting '%s'"
-msgstr "skriver över \"%s\""
+msgid ""
+"expected edge object ID, got garbage:\n"
+" %s"
+msgstr ""
+"förväntade kant-objekt-id, fick skräp:\n"
+" %s"
 
-#: builtin/mv.c:237
-msgid "Cannot overwrite"
-msgstr "Kan inte skriva över"
+#: builtin/pack-objects.c:2748
+#, c-format
+msgid ""
+"expected object ID, got garbage:\n"
+" %s"
+msgstr ""
+"förväntade objekt-id, fick skräp:\n"
+" %s"
 
-#: builtin/mv.c:240
-msgid "multiple sources for the same target"
-msgstr "flera källor för samma mål"
+#: builtin/pack-objects.c:2846
+msgid "invalid value for --missing"
+msgstr "ogiltigt värde för --missing"
 
-#: builtin/mv.c:242
-msgid "destination directory does not exist"
-msgstr "destinationskatalogen finns inte"
+#: builtin/pack-objects.c:2905 builtin/pack-objects.c:3013
+msgid "cannot open pack index"
+msgstr "kan inte öppna paketfilen"
 
-#: builtin/mv.c:249
+#: builtin/pack-objects.c:2936
 #, c-format
-msgid "%s, source=%s, destination=%s"
-msgstr "%s, källa=%s, mål=%s"
+msgid "loose object at %s could not be examined"
+msgstr "lösa objekt på %s kunde inte underökas"
 
-#: builtin/mv.c:270
+#: builtin/pack-objects.c:3021
+msgid "unable to force loose object"
+msgstr "kan inte tvinga lösa objekt"
+
+#: builtin/pack-objects.c:3113
 #, c-format
-msgid "Renaming %s to %s\n"
-msgstr "Byter namn på %s till %s\n"
+msgid "not a rev '%s'"
+msgstr "inte en referens \"%s\""
+
+#: builtin/pack-objects.c:3116
+#, c-format
+msgid "bad revision '%s'"
+msgstr "felaktig revision \"%s\""
+
+#: builtin/pack-objects.c:3141
+msgid "unable to add recent objects"
+msgstr "kan inte lägga till nya objekt"
 
-#: builtin/mv.c:276 builtin/remote.c:715 builtin/repack.c:409
+#: builtin/pack-objects.c:3194
 #, c-format
-msgid "renaming '%s' failed"
-msgstr "misslyckades byta namn på \"%s\""
+msgid "unsupported index version %s"
+msgstr "indexversionen %s stöds ej"
 
-#: builtin/name-rev.c:338
-msgid "git name-rev [<options>] <commit>..."
-msgstr "git name-rev [<flaggor>] <incheckning>..."
+#: builtin/pack-objects.c:3198
+#, c-format
+msgid "bad index version '%s'"
+msgstr "felaktig indexversion \"%s\""
 
-#: builtin/name-rev.c:339
-msgid "git name-rev [<options>] --all"
-msgstr "git name-rev [<flaggor>] --all"
+#: builtin/pack-objects.c:3236
+msgid "<version>[,<offset>]"
+msgstr "<version>[,<offset>]"
 
-#: builtin/name-rev.c:340
-msgid "git name-rev [<options>] --stdin"
-msgstr "git name-rev [<flaggor>] --stdin"
+#: builtin/pack-objects.c:3237
+msgid "write the pack index file in the specified idx format version"
+msgstr "skriv paketindexfilen i angiven indexformatversion"
 
-#: builtin/name-rev.c:395
-msgid "print only names (no SHA-1)"
-msgstr "skriv endast namn (ingen SHA-1)"
+#: builtin/pack-objects.c:3240
+msgid "maximum size of each output pack file"
+msgstr "maximal storlek på varje utdatapaketfil"
 
-#: builtin/name-rev.c:396
-msgid "only use tags to name the commits"
-msgstr "använd endast taggar för att namnge incheckningar"
+#: builtin/pack-objects.c:3242
+msgid "ignore borrowed objects from alternate object store"
+msgstr "ignorera lånade objekt från supplerande objektlager"
 
-#: builtin/name-rev.c:398
-msgid "only use refs matching <pattern>"
-msgstr "använd endast referenser som motsvarar <mönster>"
+#: builtin/pack-objects.c:3244
+msgid "ignore packed objects"
+msgstr "ignorera packade objekt"
 
-#: builtin/name-rev.c:400
-msgid "ignore refs matching <pattern>"
-msgstr "ignorera referenser som motsvarar <mönster>"
+#: builtin/pack-objects.c:3246
+msgid "limit pack window by objects"
+msgstr "begränsa paketfönster efter objekt"
 
-#: builtin/name-rev.c:402
-msgid "list all commits reachable from all refs"
-msgstr "lista alla incheckningar som kan nås alla referenser"
+#: builtin/pack-objects.c:3248
+msgid "limit pack window by memory in addition to object limit"
+msgstr "begränsa paketfönster efter minne förutom objektgräns"
 
-#: builtin/name-rev.c:403
-msgid "read from stdin"
-msgstr "läs från standard in"
+#: builtin/pack-objects.c:3250
+msgid "maximum length of delta chain allowed in the resulting pack"
+msgstr "maximal längd på deltakedja tillåten i slutligt paket"
 
-#: builtin/name-rev.c:404
-msgid "allow to print `undefined` names (default)"
-msgstr "tillåt att skriva \"odefinierade\" namn (standard)"
+#: builtin/pack-objects.c:3252
+msgid "reuse existing deltas"
+msgstr "återanvänd befintliga delta"
 
-#: builtin/name-rev.c:410
-msgid "dereference tags in the input (internal use)"
-msgstr "avreferera taggar i indata (används internt)"
+#: builtin/pack-objects.c:3254
+msgid "reuse existing objects"
+msgstr "återanvänd befintliga objekt"
 
-#: builtin/notes.c:26
-msgid "git notes [--ref <notes-ref>] [list [<object>]]"
-msgstr "git notes [--ref <anteckningsref>] [list [<objekt>]]"
+#: builtin/pack-objects.c:3256
+msgid "use OFS_DELTA objects"
+msgstr "använd OFS_DELTA-objekt"
 
-#: builtin/notes.c:27
-msgid ""
-"git notes [--ref <notes-ref>] add [-f] [--allow-empty] [-m <msg> | -F <file> "
-"| (-c | -C) <object>] [<object>]"
-msgstr ""
-"git notes [--ref <anteckningsref>] add [-f] [--allow-empty] [-m <medd> | -F "
-"<fil> | (-c | -C) <objekt>] [<objekt>]"
+#: builtin/pack-objects.c:3258
+msgid "use threads when searching for best delta matches"
+msgstr "använd trådar vid sökning efter bästa deltaträffar"
 
-#: builtin/notes.c:28
-msgid "git notes [--ref <notes-ref>] copy [-f] <from-object> <to-object>"
-msgstr ""
-"git notes [--ref <anteckningsref>] copy [-f] <från-objekt> <till-objekt>"
+#: builtin/pack-objects.c:3260
+msgid "do not create an empty pack output"
+msgstr "försök inte skapa tom paketutdata"
 
-#: builtin/notes.c:29
-msgid ""
-"git notes [--ref <notes-ref>] append [--allow-empty] [-m <msg> | -F <file> | "
-"(-c | -C) <object>] [<object>]"
-msgstr ""
-"git notes [--ref <anteckningsref>] append [--allow-empty] [-m <medd> | -F "
-"<fil> | (-c | -C) <objekt>] [<objekt>]"
+#: builtin/pack-objects.c:3262
+msgid "read revision arguments from standard input"
+msgstr "läs revisionsargument från standard in"
 
-#: builtin/notes.c:30
-msgid "git notes [--ref <notes-ref>] edit [--allow-empty] [<object>]"
-msgstr "git notes [--ref <anteckningsref>] edit [--allow-empty] [<objekt>]"
+#: builtin/pack-objects.c:3264
+msgid "limit the objects to those that are not yet packed"
+msgstr "begränsa objekt till dem som ännu inte packats"
 
-#: builtin/notes.c:31
-msgid "git notes [--ref <notes-ref>] show [<object>]"
-msgstr "git notes [--ref <anteckningsref>] show [<objekt>]"
+#: builtin/pack-objects.c:3267
+msgid "include objects reachable from any reference"
+msgstr "inkludera objekt som kan nås från någon referens"
 
-#: builtin/notes.c:32
-msgid ""
-"git notes [--ref <notes-ref>] merge [-v | -q] [-s <strategy>] <notes-ref>"
-msgstr ""
-"git notes [--ref <anteckningsref>] merge [-v | -q] [-s <strategi>] "
-"<anteckningsref>"
+#: builtin/pack-objects.c:3270
+msgid "include objects referred by reflog entries"
+msgstr "inkludera objekt som refereras från referensloggposter"
 
-#: builtin/notes.c:33
-msgid "git notes merge --commit [-v | -q]"
-msgstr "git notes merge --commit [-v | -q]"
+#: builtin/pack-objects.c:3273
+msgid "include objects referred to by the index"
+msgstr "inkludera objekt som refereras från indexet"
 
-#: builtin/notes.c:34
-msgid "git notes merge --abort [-v | -q]"
-msgstr "git notes merge --abort [-v | -q]"
+#: builtin/pack-objects.c:3276
+msgid "output pack to stdout"
+msgstr "skriv paket på standard ut"
 
-#: builtin/notes.c:35
-msgid "git notes [--ref <notes-ref>] remove [<object>...]"
-msgstr "git notes [--ref <anteckningsref>] remove [<objekt>...]"
+#: builtin/pack-objects.c:3278
+msgid "include tag objects that refer to objects to be packed"
+msgstr "inkludera taggobjekt som refererar objekt som skall packas"
 
-#: builtin/notes.c:36
-msgid "git notes [--ref <notes-ref>] prune [-n] [-v]"
-msgstr "git notes [--ref <anteckningsref>] prune [-n] [-v]"
+#: builtin/pack-objects.c:3280
+msgid "keep unreachable objects"
+msgstr "behåll onåbara objekt"
 
-#: builtin/notes.c:37
-msgid "git notes [--ref <notes-ref>] get-ref"
-msgstr "git notes [--ref <anteckningsref>] get-ref"
+#: builtin/pack-objects.c:3282
+msgid "pack loose unreachable objects"
+msgstr "packa lösa onåbara objekt"
 
-#: builtin/notes.c:42
-msgid "git notes [list [<object>]]"
-msgstr "git notes [list [<objekt>]]"
+#: builtin/pack-objects.c:3284
+msgid "unpack unreachable objects newer than <time>"
+msgstr "packa upp onåbara objekt nyare än <tid>"
 
-#: builtin/notes.c:47
-msgid "git notes add [<options>] [<object>]"
-msgstr "git notes add [<flaggor>] [<objekt>]"
+#: builtin/pack-objects.c:3287
+msgid "use the sparse reachability algorithm"
+msgstr "använd gles-nåbarhetsalgoritmen"
+
+#: builtin/pack-objects.c:3289
+msgid "create thin packs"
+msgstr "skapa tunna paket"
 
-#: builtin/notes.c:52
-msgid "git notes copy [<options>] <from-object> <to-object>"
-msgstr "git notes copy [<flaggor>] <från-objekt> <till-objekt>"
+#: builtin/pack-objects.c:3291
+msgid "create packs suitable for shallow fetches"
+msgstr "skapa packfiler lämpade för grunda hämtningar"
 
-#: builtin/notes.c:53
-msgid "git notes copy --stdin [<from-object> <to-object>]..."
-msgstr "git notes copy --stdin [<från-objekt> <till-objekt>]..."
+#: builtin/pack-objects.c:3293
+msgid "ignore packs that have companion .keep file"
+msgstr "ignorera paket som har tillhörande .keep-fil"
 
-#: builtin/notes.c:58
-msgid "git notes append [<options>] [<object>]"
-msgstr "git notes append [<flaggor>] [<objekt>]"
+#: builtin/pack-objects.c:3295
+msgid "ignore this pack"
+msgstr "ignorera detta paket"
 
-#: builtin/notes.c:63
-msgid "git notes edit [<object>]"
-msgstr "git notes edit [<objekt>]"
+#: builtin/pack-objects.c:3297
+msgid "pack compression level"
+msgstr "komprimeringsgrad för paket"
 
-#: builtin/notes.c:68
-msgid "git notes show [<object>]"
-msgstr "git notes show [<objekt>]"
+#: builtin/pack-objects.c:3299
+msgid "do not hide commits by grafts"
+msgstr "göm inte incheckningar med ympningar (\"grafts\")"
 
-#: builtin/notes.c:73
-msgid "git notes merge [<options>] <notes-ref>"
-msgstr "git notes merge [<flaggor>] <anteckningsref>"
+#: builtin/pack-objects.c:3301
+msgid "use a bitmap index if available to speed up counting objects"
+msgstr "använd bitkartindex om tillgängligt för att räkna objekt snabbare"
 
-#: builtin/notes.c:74
-msgid "git notes merge --commit [<options>]"
-msgstr "git notes merge --commit [<flaggor>]"
+#: builtin/pack-objects.c:3303
+msgid "write a bitmap index together with the pack index"
+msgstr "använd bitkartindex tillsammans med packindexet"
 
-#: builtin/notes.c:75
-msgid "git notes merge --abort [<options>]"
-msgstr "git notes merge --abort [<flaggor>]"
+#: builtin/pack-objects.c:3307
+msgid "write a bitmap index if possible"
+msgstr "skriv bitkartindex om möjligt"
 
-#: builtin/notes.c:80
-msgid "git notes remove [<object>]"
-msgstr "git notes remove [<objekt>]"
+#: builtin/pack-objects.c:3311
+msgid "handling for missing objects"
+msgstr "hantering av saknade objekt"
 
-#: builtin/notes.c:85
-msgid "git notes prune [<options>]"
-msgstr "git notes prune [<flaggor>]"
+#: builtin/pack-objects.c:3314
+msgid "do not pack objects in promisor packfiles"
+msgstr "packa inte objekt i kontraktspackfiler"
 
-#: builtin/notes.c:90
-msgid "git notes get-ref"
-msgstr "git notes get-ref"
+#: builtin/pack-objects.c:3316
+msgid "respect islands during delta compression"
+msgstr "respektera öar under deltakomprimering"
 
-#: builtin/notes.c:95
-msgid "Write/edit the notes for the following object:"
-msgstr "Skriv/redigera anteckningar för följande objekt:"
+#: builtin/pack-objects.c:3345
+#, c-format
+msgid "delta chain depth %d is too deep, forcing %d"
+msgstr "deltakedjedjupet %d är för djupt, påtvingar %d"
 
-#: builtin/notes.c:148
+#: builtin/pack-objects.c:3350
 #, c-format
-msgid "unable to start 'show' for object '%s'"
-msgstr "kunde inte starta \"show\" för objektet \"%s\""
+msgid "pack.deltaCacheLimit is too high, forcing %d"
+msgstr "pack.deltaCacheLimit är för högt, påtvingar %d"
 
-#: builtin/notes.c:152
-msgid "could not read 'show' output"
-msgstr "kunde inte läsa utdata från \"show\""
+#: builtin/pack-objects.c:3404
+msgid "--max-pack-size cannot be used to build a pack for transfer"
+msgstr ""
+"--max-pack-size kan inte användas för att bygga ett paket som skall överföras"
 
-#: builtin/notes.c:160
-#, c-format
-msgid "failed to finish 'show' for object '%s'"
-msgstr "kunde inte avsluta \"show\" för objektet \"%s\""
+#: builtin/pack-objects.c:3406
+msgid "minimum pack size limit is 1 MiB"
+msgstr "minsta packstorlek är 1 MiB"
 
-#: builtin/notes.c:195
-msgid "please supply the note contents using either -m or -F option"
-msgstr "ange innehåll för anteckningen med antingen -m eller -F"
+#: builtin/pack-objects.c:3411
+msgid "--thin cannot be used to build an indexable pack"
+msgstr "--thin kan inte användas för att bygga ett indexerbart paket"
 
-#: builtin/notes.c:204
-msgid "unable to write note object"
-msgstr "kunde inte skriva anteckningsobjekt"
+#: builtin/pack-objects.c:3414
+msgid "--keep-unreachable and --unpack-unreachable are incompatible"
+msgstr "--keep-unreachable och -unpack-unreachable kan inte användas samtidigt"
 
-#: builtin/notes.c:206
-#, c-format
-msgid "the note contents have been left in %s"
-msgstr "anteckningens innehåll har lämnats kvar i %s"
+#: builtin/pack-objects.c:3420
+msgid "cannot use --filter without --stdout"
+msgstr "kan inte använda --filter utan --stdout"
 
-#: builtin/notes.c:234 builtin/tag.c:507
-#, c-format
-msgid "cannot read '%s'"
-msgstr "kunde inte läsa \"%s\""
+#: builtin/pack-objects.c:3481
+msgid "Enumerating objects"
+msgstr "Räknar upp objekt"
 
-#: builtin/notes.c:236 builtin/tag.c:510
+#: builtin/pack-objects.c:3511
 #, c-format
-msgid "could not open or read '%s'"
-msgstr "kunde inte öppna eller läsa \"%s\""
+msgid "Total %<PRIu32> (delta %<PRIu32>), reused %<PRIu32> (delta %<PRIu32>)"
+msgstr ""
+"Totalt %<PRIu32> (delta %<PRIu32>), återanvände %<PRIu32> (delta %<PRIu32>)"
 
-#: builtin/notes.c:255 builtin/notes.c:306 builtin/notes.c:308
-#: builtin/notes.c:376 builtin/notes.c:431 builtin/notes.c:517
-#: builtin/notes.c:522 builtin/notes.c:600 builtin/notes.c:662
-#, c-format
-msgid "failed to resolve '%s' as a valid ref."
-msgstr "kunde inte slå upp \"%s\" som en giltig referens."
+#: builtin/pack-refs.c:8
+msgid "git pack-refs [<options>]"
+msgstr "git pack-refs [<flaggor>]"
 
-#: builtin/notes.c:258
-#, c-format
-msgid "failed to read object '%s'."
-msgstr "kunde inte läsa objektet \"%s\"."
+#: builtin/pack-refs.c:16
+msgid "pack everything"
+msgstr "packa allt"
 
-#: builtin/notes.c:262
-#, c-format
-msgid "cannot read note data from non-blob object '%s'."
-msgstr "kan inte läsa anteckningsdata från icke-blob-objektet \"%s\"."
+#: builtin/pack-refs.c:17
+msgid "prune loose refs (default)"
+msgstr "ta bort lösa referenser (standard)"
 
-#: builtin/notes.c:302
-#, c-format
-msgid "malformed input line: '%s'."
-msgstr "felaktig indatarad: \"%s\"."
+#: builtin/prune-packed.c:9
+msgid "git prune-packed [-n | --dry-run] [-q | --quiet]"
+msgstr "git prune-packed [-n | --dry-run] [-q | --quiet]"
 
-#: builtin/notes.c:317
-#, c-format
-msgid "failed to copy notes from '%s' to '%s'"
-msgstr "misslyckades kopiera anteckningar från \"%s\" till \"%s\""
+#: builtin/prune-packed.c:42
+msgid "Removing duplicate objects"
+msgstr "Tar bort duplicerade objekt"
 
-#. TRANSLATORS: the first %s will be replaced by a git
-#. notes command: 'add', 'merge', 'remove', etc.
-#.
-#: builtin/notes.c:349
-#, c-format
-msgid "refusing to %s notes in %s (outside of refs/notes/)"
-msgstr "vägrar utföra \"%s\" på anteckningar i %s (utanför refs/notes/)"
+#: builtin/prune.c:12
+msgid "git prune [-n] [-v] [--progress] [--expire <time>] [--] [<head>...]"
+msgstr "git prune [-n] [-v] [--progress] [--expire <tid>] [--] [<huvud>...]"
 
-#: builtin/notes.c:369 builtin/notes.c:424 builtin/notes.c:500
-#: builtin/notes.c:512 builtin/notes.c:588 builtin/notes.c:655
-#: builtin/notes.c:805 builtin/notes.c:952 builtin/notes.c:973
-msgid "too many parameters"
-msgstr "för många parametrar"
+#: builtin/prune.c:131
+msgid "report pruned objects"
+msgstr "rapportera borttagna objekt"
 
-#: builtin/notes.c:382 builtin/notes.c:668
-#, c-format
-msgid "no note found for object %s."
-msgstr "inga anteckningar hittades för objektet %s."
+#: builtin/prune.c:134
+msgid "expire objects older than <time>"
+msgstr "låt tid gå ut för objekt äldre än <tid>"
 
-#: builtin/notes.c:403 builtin/notes.c:566
-msgid "note contents as a string"
-msgstr "anteckningsinnehåll som sträng"
+#: builtin/prune.c:136
+msgid "limit traversal to objects outside promisor packfiles"
+msgstr "begränsa vandring av objekt utanför kontraktspackfiler."
 
-#: builtin/notes.c:406 builtin/notes.c:569
-msgid "note contents in a file"
-msgstr "anteckningsinnehåll i en fil"
+#: builtin/prune.c:150
+msgid "cannot prune in a precious-objects repo"
+msgstr "kan inte rensa i ett \"precious-objekt\"-arkiv"
 
-#: builtin/notes.c:409 builtin/notes.c:572
-msgid "reuse and edit specified note object"
-msgstr "återanvänd och redigera angivet anteckningsobjekt"
+#: builtin/pull.c:66 builtin/pull.c:68
+#, c-format
+msgid "Invalid value for %s: %s"
+msgstr "Felaktigt värde för %s: %s"
 
-#: builtin/notes.c:412 builtin/notes.c:575
-msgid "reuse specified note object"
-msgstr "återanvänd angivet anteckningsobjekt"
+#: builtin/pull.c:88
+msgid "git pull [<options>] [<repository> [<refspec>...]]"
+msgstr "git pull [<flaggor>] [<arkiv> [<refspec>...]]"
 
-#: builtin/notes.c:415 builtin/notes.c:578
-msgid "allow storing empty note"
-msgstr "tillåt lagra tom anteckning"
+#: builtin/pull.c:142
+msgid "control for recursive fetching of submodules"
+msgstr "styrning för rekursiv hämtning av undermoduler"
 
-#: builtin/notes.c:416 builtin/notes.c:487
-msgid "replace existing notes"
-msgstr "ersätt befintliga anteckningar"
+#: builtin/pull.c:146
+msgid "Options related to merging"
+msgstr "Alternativ gällande sammanslagning"
 
-#: builtin/notes.c:441
-#, c-format
-msgid ""
-"Cannot add notes. Found existing notes for object %s. Use '-f' to overwrite "
-"existing notes"
-msgstr ""
-"Kan inte lägga till anteckningar. Hittade befintliga anteckningar för "
-"objektet %s. Använd \"-f\" för att skriva över befintliga anteckningar"
+#: builtin/pull.c:149
+msgid "incorporate changes by rebasing rather than merging"
+msgstr "inlemma ändringar genom ombasering i stället för sammanslagning"
 
-#: builtin/notes.c:456 builtin/notes.c:535
-#, c-format
-msgid "Overwriting existing notes for object %s\n"
-msgstr "Skriver över befintliga anteckningar för objektet %s\n"
+#: builtin/pull.c:177 builtin/rebase.c:467 builtin/revert.c:126
+msgid "allow fast-forward"
+msgstr "tillåt snabbspolning"
 
-#: builtin/notes.c:467 builtin/notes.c:627 builtin/notes.c:892
-#, c-format
-msgid "Removing note for object %s\n"
-msgstr "Tar bort anteckning för objektet %s\n"
+#: builtin/pull.c:186
+msgid "automatically stash/stash pop before and after rebase"
+msgstr "utför automatiskt stash/stash pop före och efter ombasering"
 
-#: builtin/notes.c:488
-msgid "read objects from stdin"
-msgstr "läs objekt från standard in"
+#: builtin/pull.c:202
+msgid "Options related to fetching"
+msgstr "Alternativ gällande hämtningar"
 
-#: builtin/notes.c:490
-msgid "load rewriting config for <command> (implies --stdin)"
-msgstr "läs omskrivningsinställning för <kommando> (implicerar --stdin)"
+#: builtin/pull.c:212
+msgid "force overwrite of local branch"
+msgstr "tvinga överskrivning av lokal gren"
 
-#: builtin/notes.c:508
-msgid "too few parameters"
-msgstr "för få parametrar"
+#: builtin/pull.c:220
+msgid "number of submodules pulled in parallel"
+msgstr "antal undermoduler som hämtas parallellt"
 
-#: builtin/notes.c:529
+#: builtin/pull.c:320
 #, c-format
+msgid "Invalid value for pull.ff: %s"
+msgstr "Felaktigt värde för pull.ff: %s"
+
+#: builtin/pull.c:437
 msgid ""
-"Cannot copy notes. Found existing notes for object %s. Use '-f' to overwrite "
-"existing notes"
+"There is no candidate for rebasing against among the refs that you just "
+"fetched."
 msgstr ""
-"Kan inte kopiera anteckningar. Hittade befintliga anteckningar för objektet "
-"%s. Använd \"-f\" för att skriva över befintliga anteckningar"
-
-#: builtin/notes.c:541
-#, c-format
-msgid "missing notes on source object %s. Cannot copy."
-msgstr "anteckningar på källobjektet %s saknas. Kan inte kopiera."
+"Det finns ingen kandidat för ombasering bland referenserna du precis har "
+"hämtat."
 
-#: builtin/notes.c:593
-#, c-format
+#: builtin/pull.c:439
 msgid ""
-"The -m/-F/-c/-C options have been deprecated for the 'edit' subcommand.\n"
-"Please use 'git notes add -f -m/-F/-c/-C' instead.\n"
+"There are no candidates for merging among the refs that you just fetched."
 msgstr ""
-"Flaggorna -m/-F/-c/-C rekommenderas inte för underkommandot \"edit\".\n"
-"Använd \"git notes add -f -m/-F/-c/-C\" istället.\n"
-
-#: builtin/notes.c:688
-msgid "failed to delete ref NOTES_MERGE_PARTIAL"
-msgstr "misslyckades ta bort referensen NOTES_MERGE_PARTIAL"
-
-#: builtin/notes.c:690
-msgid "failed to delete ref NOTES_MERGE_REF"
-msgstr "misslyckades ta bort referensen NOTES_MERGE_REF"
-
-#: builtin/notes.c:692
-msgid "failed to remove 'git notes merge' worktree"
-msgstr "misslyckades ta bort arbetskatalogen för \"git notes merge\""
-
-#: builtin/notes.c:712
-msgid "failed to read ref NOTES_MERGE_PARTIAL"
-msgstr "misslyckades läsa references NOTES_MERGE_PARTIAL"
+"Det finns ingen kandidat för sammanslagning bland referenserna du precis har "
+"hämtat."
 
-#: builtin/notes.c:714
-msgid "could not find commit from NOTES_MERGE_PARTIAL."
-msgstr "kunde inte hitta incheckning från NOTES_MERGE_PARTIAL."
+#: builtin/pull.c:440
+msgid ""
+"Generally this means that you provided a wildcard refspec which had no\n"
+"matches on the remote end."
+msgstr ""
+"Det betyder vanligtvis att du använt en jokertecken-refspec som inte\n"
+"motsvarade något i fjärränden."
 
-#: builtin/notes.c:716
-msgid "could not parse commit from NOTES_MERGE_PARTIAL."
-msgstr "kunde inte tolka incheckning från NOTES_MERGE_PARTIAL."
+#: builtin/pull.c:443
+#, c-format
+msgid ""
+"You asked to pull from the remote '%s', but did not specify\n"
+"a branch. Because this is not the default configured remote\n"
+"for your current branch, you must specify a branch on the command line."
+msgstr ""
+"Du bad om att hämta från fjärren \"%s\", men angav inte någon\n"
+"gren. Eftersom det inte är den fjärr som är konfigurerad som\n"
+"standard för aktuell gren måste du ange en gren på kommandoraden."
 
-#: builtin/notes.c:729
-msgid "failed to resolve NOTES_MERGE_REF"
-msgstr "misslyckades bestämma NOTES_MERGE_REF"
+#: builtin/pull.c:448 builtin/rebase.c:1375 git-parse-remote.sh:73
+msgid "You are not currently on a branch."
+msgstr "Du är inte på någon gren för närvarande."
 
-#: builtin/notes.c:732
-msgid "failed to finalize notes merge"
-msgstr "misslyckades färdigställa sammanslagning av anteckningar"
+#: builtin/pull.c:450 builtin/pull.c:465 git-parse-remote.sh:79
+msgid "Please specify which branch you want to rebase against."
+msgstr "Ange vilken gren du vill ombasera mot."
 
-#: builtin/notes.c:758
-#, c-format
-msgid "unknown notes merge strategy %s"
-msgstr "okänd sammanslagningsstrategi för anteckningar: %s"
+#: builtin/pull.c:452 builtin/pull.c:467 git-parse-remote.sh:82
+msgid "Please specify which branch you want to merge with."
+msgstr "Ange vilken gren du vill slå samman med."
 
-#: builtin/notes.c:774
-msgid "General options"
-msgstr "Allmänna flaggor"
+#: builtin/pull.c:453 builtin/pull.c:468
+msgid "See git-pull(1) for details."
+msgstr "Se git-pull(1) för detaljer."
 
-#: builtin/notes.c:776
-msgid "Merge options"
-msgstr "Flaggor för sammanslagning"
+#: builtin/pull.c:455 builtin/pull.c:461 builtin/pull.c:470
+#: builtin/rebase.c:1381 git-parse-remote.sh:64
+msgid "<remote>"
+msgstr "<fjärr>"
 
-#: builtin/notes.c:778
-msgid ""
-"resolve notes conflicts using the given strategy (manual/ours/theirs/union/"
-"cat_sort_uniq)"
-msgstr ""
-"läs konflikter i anteckningar med angiven strategi (manual/ours/theirs/union/"
-"cat_sort_uniq)"
+#: builtin/pull.c:455 builtin/pull.c:470 builtin/pull.c:475
+#: git-parse-remote.sh:65
+msgid "<branch>"
+msgstr "<gren>"
 
-#: builtin/notes.c:780
-msgid "Committing unmerged notes"
-msgstr "Checkar in ej sammanslagna anteckningar"
+#: builtin/pull.c:463 builtin/rebase.c:1373 git-parse-remote.sh:75
+msgid "There is no tracking information for the current branch."
+msgstr "Det finns ingen spårningsinformation för aktuell gren."
 
-#: builtin/notes.c:782
-msgid "finalize notes merge by committing unmerged notes"
+#: builtin/pull.c:472 git-parse-remote.sh:95
+msgid ""
+"If you wish to set tracking information for this branch you can do so with:"
+msgstr "Om du vill ange spårningsinformation för grenen kan du göra det med:"
+
+#: builtin/pull.c:477
+#, c-format
+msgid ""
+"Your configuration specifies to merge with the ref '%s'\n"
+"from the remote, but no such ref was fetched."
 msgstr ""
-"färdigställ sammanslagning av anteckningar genom att checka in ej "
-"sammanslagna anteckningar"
+"Dina inställningar anger sammanslagning med referensen \"%s\"\n"
+"från fjärren, men någon sådan referens togs inte emot."
 
-#: builtin/notes.c:784
-msgid "Aborting notes merge resolution"
-msgstr "Avbryt lösning av sammanslagning av anteckningar"
+#: builtin/pull.c:587
+#, c-format
+msgid "unable to access commit %s"
+msgstr "kunde inte komma åt incheckningen %s"
 
-#: builtin/notes.c:786
-msgid "abort notes merge"
-msgstr "avbryt sammanslagning av anteckningar"
+#: builtin/pull.c:867
+msgid "ignoring --verify-signatures for rebase"
+msgstr "ignorera --verify-signatures för ombasering"
 
-#: builtin/notes.c:797
-msgid "cannot mix --commit, --abort or -s/--strategy"
-msgstr "kan inte blanda --commit, --abort eller -s/--strategy"
+#: builtin/pull.c:922
+msgid "--[no-]autostash option is only valid with --rebase."
+msgstr "--[no-]autostash är endast giltig med --rebase."
 
-#: builtin/notes.c:802
-msgid "must specify a notes ref to merge"
-msgstr "måste ange en antecknings-referens att slå ihop"
+#: builtin/pull.c:930
+msgid "Updating an unborn branch with changes added to the index."
+msgstr "Uppdaterar en ofödd gren med ändringar som lagts till i indexet."
 
-#: builtin/notes.c:826
-#, c-format
-msgid "unknown -s/--strategy: %s"
-msgstr "okänd -s/--strategy: %s"
+#: builtin/pull.c:934
+msgid "pull with rebase"
+msgstr "pull med ombasering"
 
-#: builtin/notes.c:863
-#, c-format
-msgid "a notes merge into %s is already in-progress at %s"
-msgstr "sammanslagning av anteckningar till %s är redan igångsatt på %s"
+#: builtin/pull.c:935
+msgid "please commit or stash them."
+msgstr "checka in eller använd \"stash\" på dem."
 
-#: builtin/notes.c:866
+#: builtin/pull.c:960
 #, c-format
-msgid "failed to store link to current notes ref (%s)"
-msgstr "misslyckades lagra länk till aktuell anteckningsreferens (%s)"
+msgid ""
+"fetch updated the current branch head.\n"
+"fast-forwarding your working tree from\n"
+"commit %s."
+msgstr ""
+"fetch uppdaterade huvudet för aktuell gren.\n"
+"snabbspolar din arbetskatalog från\n"
+"incheckningen %s."
 
-#: builtin/notes.c:868
+#: builtin/pull.c:966
 #, c-format
 msgid ""
-"Automatic notes merge failed. Fix conflicts in %s and commit the result with "
-"'git notes merge --commit', or abort the merge with 'git notes merge --"
-"abort'.\n"
+"Cannot fast-forward your working tree.\n"
+"After making sure that you saved anything precious from\n"
+"$ git diff %s\n"
+"output, run\n"
+"$ git reset --hard\n"
+"to recover."
 msgstr ""
-"Automatisk sammanslagning av anteckningar misslyckades. Rätta konflikter i "
-"%s och checka in resultatet med \"git notes merge --commit\", eller avbryt "
-"sammanslagningen med \"git notes merge --abort\".\n"
+"Kan inte snabbspola din arbetskatalog.\n"
+"När du är säker på att du har sparat allt värdefullt i utdata från\n"
+"$ git diff %s\n"
+"kör du\n"
+"$ git reset --hard\n"
+"för att återgå."
 
-#: builtin/notes.c:890
-#, c-format
-msgid "Object %s has no note\n"
-msgstr "Objektet %s har ingen anteckning\n"
+#: builtin/pull.c:981
+msgid "Cannot merge multiple branches into empty head."
+msgstr "Kan inte slå ihop flera grenar i ett tomt huvud."
 
-#: builtin/notes.c:902
-msgid "attempt to remove non-existent note is not an error"
-msgstr "försök att ta bort icke-existerande anteckningar är inte ett fel"
+#: builtin/pull.c:985
+msgid "Cannot rebase onto multiple branches."
+msgstr "Kan inte ombasera ovanpå flera grenar."
 
-#: builtin/notes.c:905
-msgid "read object names from the standard input"
-msgstr "läs objektnamn från standard in"
+#: builtin/pull.c:992
+msgid "cannot rebase with locally recorded submodule modifications"
+msgstr "kan inte ombasera med lokalt lagrade ändringar i undermoful"
 
-#: builtin/notes.c:943 builtin/prune.c:107 builtin/worktree.c:151
-msgid "do not remove, show only"
-msgstr "ta inte bort, bara visa"
+#: builtin/push.c:19
+msgid "git push [<options>] [<repository> [<refspec>...]]"
+msgstr "git push [<flaggor>] [<arkiv> [<refspec>...]]"
 
-#: builtin/notes.c:944
-msgid "report pruned notes"
-msgstr "rapportera borttagna anteckningar"
+#: builtin/push.c:112
+msgid "tag shorthand without <tag>"
+msgstr "taggförkortning utan <tagg>"
 
-#: builtin/notes.c:986
-msgid "notes-ref"
-msgstr "anteckningar-ref"
+#: builtin/push.c:122
+msgid "--delete only accepts plain target ref names"
+msgstr "--delete godtar endast enkla målreferensnamn"
 
-#: builtin/notes.c:987
-msgid "use notes from <notes-ref>"
-msgstr "använd anteckningar från <anteckningsref>"
+#: builtin/push.c:168
+msgid ""
+"\n"
+"To choose either option permanently, see push.default in 'git help config'."
+msgstr ""
+"\n"
+"För att välja ett av alternativen permanent, se push.default i \"git help "
+"config\"."
 
-#: builtin/notes.c:1022
+#: builtin/push.c:171
 #, c-format
-msgid "unknown subcommand: %s"
-msgstr "okänt underkommando: %s"
-
-#: builtin/pack-objects.c:48
 msgid ""
-"git pack-objects --stdout [<options>...] [< <ref-list> | < <object-list>]"
+"The upstream branch of your current branch does not match\n"
+"the name of your current branch.  To push to the upstream branch\n"
+"on the remote, use\n"
+"\n"
+"    git push %s HEAD:%s\n"
+"\n"
+"To push to the branch of the same name on the remote, use\n"
+"\n"
+"    git push %s HEAD\n"
+"%s"
 msgstr ""
-"git pack-objects --stdout [<flaggor>...] [< <reflista> | < <objektlista>]"
+"Uppströmsgrenen för din nuvarande gren stämmer inte överens\n"
+"med namnet på din aktuella gren. För att sända till uppströmsgrenen\n"
+"i fjärrarkivet använder du\n"
+"\n"
+"    git push %s HEAD:%s\n"
+"\n"
+"För att sända till grenen med samma namn i fjärrarkivet använder du\n"
+"\n"
+"    git push %s HEAD\n"
+"%s"
 
-#: builtin/pack-objects.c:49
+#: builtin/push.c:186
+#, c-format
 msgid ""
-"git pack-objects [<options>...] <base-name> [< <ref-list> | < <object-list>]"
+"You are not currently on a branch.\n"
+"To push the history leading to the current (detached HEAD)\n"
+"state now, use\n"
+"\n"
+"    git push %s HEAD:<name-of-remote-branch>\n"
 msgstr ""
-"git pack-objects [<flaggor>...] <basnamn> [< <reflista> | < <objektlista>]"
+"Du är inte på någon gren för närvarande.\n"
+"För att sända in historiken som leder till den aktuella (frånkopplat\n"
+"HEAD) situationen använder du\n"
+"\n"
+"    git push %s HEAD:<namn-på-fjärrgren>\n"
 
-#: builtin/pack-objects.c:211 builtin/pack-objects.c:214
+#: builtin/push.c:200
 #, c-format
-msgid "deflate error (%d)"
-msgstr "fel i deflate (%d)"
-
-#: builtin/pack-objects.c:810
-msgid "disabling bitmap writing, packs are split due to pack.packSizeLimit"
+msgid ""
+"The current branch %s has no upstream branch.\n"
+"To push the current branch and set the remote as upstream, use\n"
+"\n"
+"    git push --set-upstream %s %s\n"
 msgstr ""
-"inaktiverar skrivning av bitkarta, paket delas på grund av pack.packSizeLimit"
-
-#: builtin/pack-objects.c:823
-msgid "Writing objects"
-msgstr "Skriver objekt"
-
-#: builtin/pack-objects.c:1106
-msgid "disabling bitmap writing, as some objects are not being packed"
-msgstr "inaktiverar skrivning av bitkarta då några objekt inte packas"
-
-#: builtin/pack-objects.c:1765
-msgid "Counting objects"
-msgstr "Räknar objekt"
+"Den aktuella grenen %s har ingen uppströmsgren.\n"
+"För att sända aktuell gren och ange fjärrarkiv som uppström använder du\n"
+"\n"
+"    git push --set-upstream %s %s\n"
 
-#: builtin/pack-objects.c:1895
+#: builtin/push.c:208
 #, c-format
-msgid "unable to get size of %s"
-msgstr "kan inte hämta storlek på %s"
+msgid "The current branch %s has multiple upstream branches, refusing to push."
+msgstr "Den aktuella grenen %s har flera uppströmsgrenar, vägrar sända."
 
-#: builtin/pack-objects.c:1910
+#: builtin/push.c:211
 #, c-format
-msgid "unable to parse object header of %s"
-msgstr "kunde inte tolka objekthuvud för %s"
+msgid ""
+"You are pushing to remote '%s', which is not the upstream of\n"
+"your current branch '%s', without telling me what to push\n"
+"to update which remote branch."
+msgstr ""
+"Du sänder till fjärren \"%s\", som inte är uppströms för den\n"
+"aktuella grenen \"%s\", utan att tala om för mig vad som\n"
+"skall sändas för att uppdatera fjärrgrenen."
 
-#: builtin/pack-objects.c:2564
-msgid "Compressing objects"
-msgstr "Komprimerar objekt"
+#: builtin/push.c:270
+msgid ""
+"You didn't specify any refspecs to push, and push.default is \"nothing\"."
+msgstr ""
+"Du angav inga referensspecifikationer att sända, och push.default är "
+"\"nothing\"."
 
-#: builtin/pack-objects.c:2735
-msgid "invalid value for --missing"
-msgstr "ogiltigt värde för --missing"
+#: builtin/push.c:277
+msgid ""
+"Updates were rejected because the tip of your current branch is behind\n"
+"its remote counterpart. Integrate the remote changes (e.g.\n"
+"'git pull ...') before pushing again.\n"
+"See the 'Note about fast-forwards' in 'git push --help' for details."
+msgstr ""
+"Uppdateringar avvisades då änden på din befintliga gren är bakom\n"
+"dess fjärrmotsvarighet. Integrera fjärrändringarna (t.ex\n"
+"\"git pull ....\") innan du sänder igen.\n"
+"Se avsnittet \"Note about fast-forward\" i \"git push --help\" för detaljer."
 
-#: builtin/pack-objects.c:3067
-#, c-format
-msgid "unsupported index version %s"
-msgstr "indexversionen %s stöds ej"
+#: builtin/push.c:283
+msgid ""
+"Updates were rejected because a pushed branch tip is behind its remote\n"
+"counterpart. Check out this branch and integrate the remote changes\n"
+"(e.g. 'git pull ...') before pushing again.\n"
+"See the 'Note about fast-forwards' in 'git push --help' for details."
+msgstr ""
+"Uppdateringar avvisades då änden på en gren som sänds in är bakom dess\n"
+"fjärrmotsvarighet. Checka ut grenen och integrera fjärrändringarna (t.ex.\n"
+"\"git pull ...\") innan du sänder igen.\n"
+"Se avsnittet \"Note about fast-forward\" i \"git push --help\" för detaljer."
 
-#: builtin/pack-objects.c:3071
-#, c-format
-msgid "bad index version '%s'"
-msgstr "felaktig indexversion \"%s\""
+#: builtin/push.c:289
+msgid ""
+"Updates were rejected because the remote contains work that you do\n"
+"not have locally. This is usually caused by another repository pushing\n"
+"to the same ref. You may want to first integrate the remote changes\n"
+"(e.g., 'git pull ...') before pushing again.\n"
+"See the 'Note about fast-forwards' in 'git push --help' for details."
+msgstr ""
+"Uppdateringar avvisades då fjärren innehåller ändringar som du inte\n"
+"har lokalt. Det beror oftast på att ett annat arkiv har sänt in samma\n"
+"referenser. Det kan vara en idé att först integrera fjärrändringarna\n"
+"(t.ex. \"git pull ...\") innan du sänder igen.\n"
+"Se avsnittet \"Note about fast-forwards\" i \"git push --help\" för detaljer."
 
-#: builtin/pack-objects.c:3102
-msgid "do not show progress meter"
-msgstr "visa inte förloppsindikator"
+#: builtin/push.c:296
+msgid "Updates were rejected because the tag already exists in the remote."
+msgstr "Uppdateringarna avvisades eftersom taggen redan finns på fjärren."
 
-#: builtin/pack-objects.c:3104
-msgid "show progress meter"
-msgstr "visa förloppsindikator"
+#: builtin/push.c:299
+msgid ""
+"You cannot update a remote ref that points at a non-commit object,\n"
+"or update a remote ref to make it point at a non-commit object,\n"
+"without using the '--force' option.\n"
+msgstr ""
+"Du kan inte uppdatera en fjärr-referens som pekar på ett objekt som\n"
+"inte är en incheckning, eller uppdatera en fjärr-referens så att den\n"
+"pekar på något som inte är en incheckning, utan att använda flaggan\n"
+"\"--force\".\n"
 
-#: builtin/pack-objects.c:3106
-msgid "show progress meter during object writing phase"
-msgstr "visa förloppsindikator under objektskrivningsfasen"
+#: builtin/push.c:360
+#, c-format
+msgid "Pushing to %s\n"
+msgstr "Sänder till %s\n"
 
-#: builtin/pack-objects.c:3109
-msgid "similar to --all-progress when progress meter is shown"
-msgstr "som --all-progress när förloppsindikatorn visas"
+#: builtin/push.c:367
+#, c-format
+msgid "failed to push some refs to '%s'"
+msgstr "misslyckades sända vissa referenser till \"%s\""
 
-#: builtin/pack-objects.c:3110
-msgid "version[,offset]"
-msgstr "version[,offset]"
+#: builtin/push.c:542
+msgid "repository"
+msgstr "arkiv"
 
-#: builtin/pack-objects.c:3111
-msgid "write the pack index file in the specified idx format version"
-msgstr "skriv paketindexfilen i angiven indexformatversion"
+#: builtin/push.c:543 builtin/send-pack.c:164
+msgid "push all refs"
+msgstr "sänd alla referenser"
 
-#: builtin/pack-objects.c:3114
-msgid "maximum size of each output pack file"
-msgstr "maximal storlek på varje utdatapaketfil"
+#: builtin/push.c:544 builtin/send-pack.c:166
+msgid "mirror all refs"
+msgstr "spegla alla referenser"
 
-#: builtin/pack-objects.c:3116
-msgid "ignore borrowed objects from alternate object store"
-msgstr "ignorera lånade objekt från alternativa objektlager"
+#: builtin/push.c:546
+msgid "delete refs"
+msgstr "ta bort referenser"
 
-#: builtin/pack-objects.c:3118
-msgid "ignore packed objects"
-msgstr "ignorera packade objekt"
+#: builtin/push.c:547
+msgid "push tags (can't be used with --all or --mirror)"
+msgstr "sänd taggar (kan inte användas med --all eller --mirror)"
 
-#: builtin/pack-objects.c:3120
-msgid "limit pack window by objects"
-msgstr "begränsa paketfönster efter objekt"
+#: builtin/push.c:550 builtin/send-pack.c:167
+msgid "force updates"
+msgstr "tvinga uppdateringar"
 
-#: builtin/pack-objects.c:3122
-msgid "limit pack window by memory in addition to object limit"
-msgstr "begränsa paketfönster efter minne förutom objektgräns"
+#: builtin/push.c:552 builtin/send-pack.c:181
+msgid "<refname>:<expect>"
+msgstr "<refnamn>:<förvänta>"
 
-#: builtin/pack-objects.c:3124
-msgid "maximum length of delta chain allowed in the resulting pack"
-msgstr "maximal längd på deltakedja tillåten i slutligt paket"
+#: builtin/push.c:553 builtin/send-pack.c:182
+msgid "require old value of ref to be at this value"
+msgstr "kräv att ref:s tidigare värde är detta"
 
-#: builtin/pack-objects.c:3126
-msgid "reuse existing deltas"
-msgstr "återanvänd befintliga delta"
+#: builtin/push.c:556
+msgid "control recursive pushing of submodules"
+msgstr "styr rekursiv insändning av undermoduler"
 
-#: builtin/pack-objects.c:3128
-msgid "reuse existing objects"
-msgstr "återanvänd befintliga objekt"
+#: builtin/push.c:558 builtin/send-pack.c:175
+msgid "use thin pack"
+msgstr "använd tunna paket"
 
-#: builtin/pack-objects.c:3130
-msgid "use OFS_DELTA objects"
-msgstr "använd OFS_DELTA-objekt"
+#: builtin/push.c:559 builtin/push.c:560 builtin/send-pack.c:161
+#: builtin/send-pack.c:162
+msgid "receive pack program"
+msgstr "program för att ta emot paket"
 
-#: builtin/pack-objects.c:3132
-msgid "use threads when searching for best delta matches"
-msgstr "använd trådar vid sökning efter bästa deltaträffar"
+#: builtin/push.c:561
+msgid "set upstream for git pull/status"
+msgstr "ställ in uppström för git pull/status"
 
-#: builtin/pack-objects.c:3134
-msgid "do not create an empty pack output"
-msgstr "försök inte skapa tom paketutdata"
+#: builtin/push.c:564
+msgid "prune locally removed refs"
+msgstr "ta bort lokalt borttagna referenser"
 
-#: builtin/pack-objects.c:3136
-msgid "read revision arguments from standard input"
-msgstr "läs revisionsargument från standard in"
+#: builtin/push.c:566
+msgid "bypass pre-push hook"
+msgstr "förbigå pre-push-krok"
 
-#: builtin/pack-objects.c:3138
-msgid "limit the objects to those that are not yet packed"
-msgstr "begränsa objekt till de som ännu inte packats"
+#: builtin/push.c:567
+msgid "push missing but relevant tags"
+msgstr "sänd in saknade men relevanta taggar"
 
-#: builtin/pack-objects.c:3141
-msgid "include objects reachable from any reference"
-msgstr "inkludera objekt som kan nås från någon referens"
+#: builtin/push.c:570 builtin/send-pack.c:169
+msgid "GPG sign the push"
+msgstr "GPG-signera insändningen"
 
-#: builtin/pack-objects.c:3144
-msgid "include objects referred by reflog entries"
-msgstr "inkludera objekt som refereras från referensloggposter"
+#: builtin/push.c:572 builtin/send-pack.c:176
+msgid "request atomic transaction on remote side"
+msgstr "begär atomiska transaktioner på fjärrsidan"
 
-#: builtin/pack-objects.c:3147
-msgid "include objects referred to by the index"
-msgstr "inkludera objekt som refereras från indexet"
+#: builtin/push.c:590
+msgid "--delete is incompatible with --all, --mirror and --tags"
+msgstr "--delete är inkompatibel med --all, --mirror och --tags"
 
-#: builtin/pack-objects.c:3150
-msgid "output pack to stdout"
-msgstr "skriv paket på standard ut"
+#: builtin/push.c:592
+msgid "--delete doesn't make sense without any refs"
+msgstr "--delete kan inte användas utan referenser"
 
-#: builtin/pack-objects.c:3152
-msgid "include tag objects that refer to objects to be packed"
-msgstr "inkludera taggobjekt som refererar objekt som skall packas"
+#: builtin/push.c:612
+#, c-format
+msgid "bad repository '%s'"
+msgstr "felaktigt arkiv \"%s\""
 
-#: builtin/pack-objects.c:3154
-msgid "keep unreachable objects"
-msgstr "behåll onåbara objekt"
+#: builtin/push.c:613
+msgid ""
+"No configured push destination.\n"
+"Either specify the URL from the command-line or configure a remote "
+"repository using\n"
+"\n"
+"    git remote add <name> <url>\n"
+"\n"
+"and then push using the remote name\n"
+"\n"
+"    git push <name>\n"
+msgstr ""
+"Ingen destination har angivits.\n"
+"Ange antingen URL:en på kommandoraden eller ställ in ett uppströmsarkiv med\n"
+"\n"
+"    git remote add <namn> <url>\n"
+"\n"
+"och sänd sedan med hjälp av fjärrnamnet\n"
+"\n"
+"    git push <namn>\n"
 
-#: builtin/pack-objects.c:3156
-msgid "pack loose unreachable objects"
-msgstr "packa lösa onåbara objekt"
+#: builtin/push.c:628
+msgid "--all and --tags are incompatible"
+msgstr "--all och --tags är inkompatibla"
 
-#: builtin/pack-objects.c:3158
-msgid "unpack unreachable objects newer than <time>"
-msgstr "packa upp onåbara objekt nyare än <tid>"
+#: builtin/push.c:630
+msgid "--all can't be combined with refspecs"
+msgstr "--all kan inte kombineras med referensspecifikationer"
 
-#: builtin/pack-objects.c:3161
-msgid "create thin packs"
-msgstr "skapa tunna paket"
+#: builtin/push.c:634
+msgid "--mirror and --tags are incompatible"
+msgstr "--mirror och --tags är inkompatibla"
 
-#: builtin/pack-objects.c:3163
-msgid "create packs suitable for shallow fetches"
-msgstr "skapa packfiler lämpade för grunda hämtningar"
+#: builtin/push.c:636
+msgid "--mirror can't be combined with refspecs"
+msgstr "--mirror kan inte kombineras med referensspecifikationer"
 
-#: builtin/pack-objects.c:3165
-msgid "ignore packs that have companion .keep file"
-msgstr "ignorera paket som har tillhörande .keep-fil"
+#: builtin/push.c:639
+msgid "--all and --mirror are incompatible"
+msgstr "--all och --mirror är inkompatibla"
 
-#: builtin/pack-objects.c:3167
-msgid "ignore this pack"
-msgstr "ignorera detta paket"
+#: builtin/push.c:643
+msgid "push options must not have new line characters"
+msgstr "push-flaggor kan inte innehålla radbrytning"
 
-#: builtin/pack-objects.c:3169
-msgid "pack compression level"
-msgstr "komprimeringsgrad för paket"
+#: builtin/range-diff.c:8
+msgid "git range-diff [<options>] <old-base>..<old-tip> <new-base>..<new-tip>"
+msgstr ""
+"git range-diff [<flaggor>] <gammal-bas>..<gammal-ända> <ny-bas>..<ny-ända>"
 
-#: builtin/pack-objects.c:3171
-msgid "do not hide commits by grafts"
-msgstr "göm inte incheckningar med ympningar (\"grafts\")"
+#: builtin/range-diff.c:9
+msgid "git range-diff [<options>] <old-tip>...<new-tip>"
+msgstr "git range-diff [<flaggor>] <gammal-bas>..<ny-ända>"
 
-#: builtin/pack-objects.c:3173
-msgid "use a bitmap index if available to speed up counting objects"
-msgstr "använd bitkartindex om tillgängligt för att räkna objekt snabbare"
+#: builtin/range-diff.c:10
+msgid "git range-diff [<options>] <base> <old-tip> <new-tip>"
+msgstr "git range-diff [<flaggor>] <bas> <gammal-ända> <ny-ända>"
 
-#: builtin/pack-objects.c:3175
-msgid "write a bitmap index together with the pack index"
-msgstr "använd bitkartindex tillsammans med packindexet"
+#: builtin/range-diff.c:22
+msgid "Percentage by which creation is weighted"
+msgstr "Procent som skapelse vägs med"
 
-#: builtin/pack-objects.c:3178
-msgid "handling for missing objects"
-msgstr "hantering av saknade objekt"
+#: builtin/range-diff.c:24
+msgid "use simple diff colors"
+msgstr "använd enkla diff-färger"
 
-#: builtin/pack-objects.c:3181
-msgid "do not pack objects in promisor packfiles"
-msgstr "packa inte objekt i kontraktspackfiler"
+#: builtin/range-diff.c:26
+msgid "notes"
+msgstr "anteckningar"
 
-#: builtin/pack-objects.c:3205
-#, c-format
-msgid "delta chain depth %d is too deep, forcing %d"
-msgstr "deltakedjedjupet %d är för djupt, påtvingar %d"
+#: builtin/range-diff.c:26
+msgid "passed to 'git log'"
+msgstr "sänds till \"git log\""
 
-#: builtin/pack-objects.c:3210
+#: builtin/range-diff.c:50 builtin/range-diff.c:54
 #, c-format
-msgid "pack.deltaCacheLimit is too high, forcing %d"
-msgstr "pack.deltaCacheLimit är för högt, påtvingar %d"
-
-#: builtin/pack-objects.c:3338
-msgid "Enumerating objects"
-msgstr "Räknar upp objekt"
+msgid "no .. in range: '%s'"
+msgstr ".. saknas i intervall: \"%s\""
 
-#: builtin/pack-refs.c:7
-msgid "git pack-refs [<options>]"
-msgstr "git pack-refs [<flaggor>]"
-
-#: builtin/pack-refs.c:15
-msgid "pack everything"
-msgstr "packa allt"
+#: builtin/range-diff.c:64
+msgid "single arg format must be symmetric range"
+msgstr "ensamt argument måste vara symmetriskt intervall"
 
-#: builtin/pack-refs.c:16
-msgid "prune loose refs (default)"
-msgstr "ta bort lösa referenser (standard)"
+#: builtin/range-diff.c:79
+msgid "need two commit ranges"
+msgstr "behöver två incheckningsintervall"
 
-#: builtin/prune-packed.c:8
-msgid "git prune-packed [-n | --dry-run] [-q | --quiet]"
-msgstr "git prune-packed [-n | --dry-run] [-q | --quiet]"
+#: builtin/read-tree.c:41
+msgid ""
+"git read-tree [(-m [--trivial] [--aggressive] | --reset | --prefix=<prefix>) "
+"[-u [--exclude-per-directory=<gitignore>] | -i]] [--no-sparse-checkout] [--"
+"index-output=<file>] (--empty | <tree-ish1> [<tree-ish2> [<tree-ish3>]])"
+msgstr ""
+"git read-tree [(-m [--trivial] [--aggressive] | --reset | --prefix=<prefix>) "
+"[-u [--exclude-per-directory=<gitignore>] | -i]] [--no-sparse-checkout] [--"
+"index-output=<fil>] (--empty | <träd-igt1> [<träd-igt2> [<träd-igt3>]])"
 
-#: builtin/prune-packed.c:41
-msgid "Removing duplicate objects"
-msgstr "Tar bort duplicerade objekt"
+#: builtin/read-tree.c:124
+msgid "write resulting index to <file>"
+msgstr "skriv resulterande index till <fil>"
 
-#: builtin/prune.c:11
-msgid "git prune [-n] [-v] [--progress] [--expire <time>] [--] [<head>...]"
-msgstr "git prune [-n] [-v] [--progress] [--expire <tid>] [--] [<huvud>...]"
+#: builtin/read-tree.c:127
+msgid "only empty the index"
+msgstr "töm bara indexet"
 
-#: builtin/prune.c:108
-msgid "report pruned objects"
-msgstr "rapportera borttagna objekt"
+#: builtin/read-tree.c:129
+msgid "Merging"
+msgstr "Sammanslagning"
 
-#: builtin/prune.c:111
-msgid "expire objects older than <time>"
-msgstr "låt tid gå ut för objekt äldre än <tid>"
+#: builtin/read-tree.c:131
+msgid "perform a merge in addition to a read"
+msgstr "utför en sammanslagning i tillägg till en läsning"
 
-#: builtin/prune.c:113
-msgid "limit traversal to objects outside promisor packfiles"
-msgstr "begränsa vandring av objekt utanför kontraktspackfiler."
+#: builtin/read-tree.c:133
+msgid "3-way merge if no file level merging required"
+msgstr "3-vägssammanslagning om sammanslagning på filnivå ej krävs"
 
-#: builtin/prune.c:127
-msgid "cannot prune in a precious-objects repo"
-msgstr "kan inte rensa i ett \"precious-objekt\"-arkiv"
+#: builtin/read-tree.c:135
+msgid "3-way merge in presence of adds and removes"
+msgstr "3-vägssammanslagning när det finns tillägg och borttagningar"
 
-#: builtin/pull.c:59 builtin/pull.c:61
-#, c-format
-msgid "Invalid value for %s: %s"
-msgstr "Felaktigt värde för %s: %s"
+#: builtin/read-tree.c:137
+msgid "same as -m, but discard unmerged entries"
+msgstr "som -m, men kasta bort ej sammanslagna poster"
 
-#: builtin/pull.c:81
-msgid "git pull [<options>] [<repository> [<refspec>...]]"
-msgstr "git pull [<flaggor>] [<arkiv> [<refspec>...]]"
+#: builtin/read-tree.c:138
+msgid "<subdirectory>/"
+msgstr "<underkatalog>/"
 
-#: builtin/pull.c:132
-msgid "control for recursive fetching of submodules"
-msgstr "styrning för rekursiv hämtning av undermoduler"
+#: builtin/read-tree.c:139
+msgid "read the tree into the index under <subdirectory>/"
+msgstr "läs in trädet i indexet under <underkatalog>/"
 
-#: builtin/pull.c:136
-msgid "Options related to merging"
-msgstr "Alternativ gällande sammanslagning"
+#: builtin/read-tree.c:142
+msgid "update working tree with merge result"
+msgstr "uppdatera arbetskatalogen med resultatet från sammanslagningen"
 
-#: builtin/pull.c:139
-msgid "incorporate changes by rebasing rather than merging"
-msgstr "inlemma ändringar genom ombasering i stället för sammanslagning"
+#: builtin/read-tree.c:144
+msgid "gitignore"
+msgstr "gitignore"
 
-#: builtin/pull.c:166 builtin/rebase--helper.c:23 builtin/revert.c:121
-msgid "allow fast-forward"
-msgstr "tillåt snabbspolning"
+#: builtin/read-tree.c:145
+msgid "allow explicitly ignored files to be overwritten"
+msgstr "tillåt explicit ignorerade filer att skrivas över"
 
-#: builtin/pull.c:175
-msgid "automatically stash/stash pop before and after rebase"
-msgstr "utför automatiskt stash/stash pop före och efter ombasering"
+#: builtin/read-tree.c:148
+msgid "don't check the working tree after merging"
+msgstr "kontrollera inte arbetskatalogen efter sammanslagning"
 
-#: builtin/pull.c:191
-msgid "Options related to fetching"
-msgstr "Alternativ gällande hämtningar"
+#: builtin/read-tree.c:149
+msgid "don't update the index or the work tree"
+msgstr "uppdatera inte indexet eller arbetskatalogen"
 
-#: builtin/pull.c:209
-msgid "number of submodules pulled in parallel"
-msgstr "antal undermoduler som hämtas parallellt"
+#: builtin/read-tree.c:151
+msgid "skip applying sparse checkout filter"
+msgstr "hoppa över att applicera filter för gles utcheckning"
 
-#: builtin/pull.c:304
-#, c-format
-msgid "Invalid value for pull.ff: %s"
-msgstr "Felaktigt värde för pull.ff: %s"
+#: builtin/read-tree.c:153
+msgid "debug unpack-trees"
+msgstr "felsök unpack-trees"
 
-#: builtin/pull.c:420
-msgid ""
-"There is no candidate for rebasing against among the refs that you just "
-"fetched."
-msgstr ""
-"Det finns ingen kandidat för ombasering bland referenserna du precis har "
-"hämtat."
+#: builtin/read-tree.c:157
+msgid "suppress feedback messages"
+msgstr "undertryck återkopplingsmeddelanden"
 
-#: builtin/pull.c:422
-msgid ""
-"There are no candidates for merging among the refs that you just fetched."
-msgstr ""
-"Det finns ingen kandidat för sammanslagning bland referenserna du precis har "
-"hämtat."
+#: builtin/read-tree.c:188
+msgid "You need to resolve your current index first"
+msgstr "Du måste lösa ditt befintliga index först"
 
-#: builtin/pull.c:423
+#: builtin/rebase.c:32
 msgid ""
-"Generally this means that you provided a wildcard refspec which had no\n"
-"matches on the remote end."
+"git rebase [-i] [options] [--exec <cmd>] [--onto <newbase> | --keep-base] "
+"[<upstream> [<branch>]]"
 msgstr ""
-"Det betyder vanligtvis att du använt en jokertecken-refspec som inte\n"
-"motsvarade något i fjärränden."
+"git rebase [-i] [flaggor] [--exec <kmd>] [--onto <nybas> | --keep-base] "
+"[<uppström> [<gren>]]"
 
-#: builtin/pull.c:426
-#, c-format
+#: builtin/rebase.c:34
 msgid ""
-"You asked to pull from the remote '%s', but did not specify\n"
-"a branch. Because this is not the default configured remote\n"
-"for your current branch, you must specify a branch on the command line."
+"git rebase [-i] [options] [--exec <cmd>] [--onto <newbase>] --root [<branch>]"
 msgstr ""
-"Du bad om att hämta från fjärren \"%s\", men angav inte någon\n"
-"gren. Eftersom det inte är den fjärr som är konfigurerad som\n"
-"standard för aktuell gren måste du ange en gren på kommandoraden."
+"git rebase [-i] [flaggor] [--exec <kmd>] [--onto <nybas>] --root [<gren>]"
 
-#: builtin/pull.c:431 git-parse-remote.sh:73
-msgid "You are not currently on a branch."
-msgstr "Du är inte på någon gren för närvarande."
+#: builtin/rebase.c:36
+msgid "git rebase --continue | --abort | --skip | --edit-todo"
+msgstr "git rebase --continue | --abort | --skip | --edit-todo"
 
-#: builtin/pull.c:433 builtin/pull.c:448 git-parse-remote.sh:79
-msgid "Please specify which branch you want to rebase against."
-msgstr "Ange vilken gren du vill ombasera mot."
+#: builtin/rebase.c:177 builtin/rebase.c:201 builtin/rebase.c:228
+#, c-format
+msgid "unusable todo list: '%s'"
+msgstr "oanvändbar todo-lista: %s"
 
-#: builtin/pull.c:435 builtin/pull.c:450 git-parse-remote.sh:82
-msgid "Please specify which branch you want to merge with."
-msgstr "Ange vilken gren du vill slå samman med."
+#: builtin/rebase.c:186 builtin/rebase.c:212 builtin/rebase.c:236
+#, c-format
+msgid "could not write '%s'."
+msgstr "kunde inte skriva \"%s\"."
 
-#: builtin/pull.c:436 builtin/pull.c:451
-msgid "See git-pull(1) for details."
-msgstr "Se git-pull(1) för detaljer."
+#: builtin/rebase.c:271
+msgid "no HEAD?"
+msgstr "inget HEAD?"
 
-#: builtin/pull.c:438 builtin/pull.c:444 builtin/pull.c:453
-#: git-parse-remote.sh:64
-msgid "<remote>"
-msgstr "<fjärr>"
+#: builtin/rebase.c:298
+#, c-format
+msgid "could not create temporary %s"
+msgstr "kunde inte skapa temporär %s"
 
-#: builtin/pull.c:438 builtin/pull.c:453 builtin/pull.c:458 git-rebase.sh:523
-#: git-parse-remote.sh:65
-msgid "<branch>"
-msgstr "<gren>"
+#: builtin/rebase.c:304
+msgid "could not mark as interactive"
+msgstr "kunde inte markera som interaktiv"
 
-#: builtin/pull.c:446 git-parse-remote.sh:75
-msgid "There is no tracking information for the current branch."
-msgstr "Det finns ingen spårningsinformation för aktuell gren."
+#: builtin/rebase.c:362
+msgid "could not generate todo list"
+msgstr "Kunde inte skapa attgöra-lista"
 
-#: builtin/pull.c:455 git-parse-remote.sh:95
-msgid ""
-"If you wish to set tracking information for this branch you can do so with:"
-msgstr "Om du vill ange spårningsinformation för grenen kan du göra det med:"
+#: builtin/rebase.c:402
+msgid "a base commit must be provided with --upstream or --onto"
+msgstr "en basincheckning måste anges med --upstream eller --onto"
 
-#: builtin/pull.c:460
-#, c-format
-msgid ""
-"Your configuration specifies to merge with the ref '%s'\n"
-"from the remote, but no such ref was fetched."
-msgstr ""
-"Dina inställningar anger sammanslagning med referensen \"%s\"\n"
-"från fjärren, men någon sådan referens togs inte emot."
+#: builtin/rebase.c:457
+msgid "git rebase--interactive [<options>]"
+msgstr "git rebase--interactive [<flaggor>]"
 
-#: builtin/pull.c:826
-msgid "ignoring --verify-signatures for rebase"
-msgstr "ignorera --verify-signatures för ombasering"
+#: builtin/rebase.c:469
+msgid "keep empty commits"
+msgstr "behåll tomma incheckningar"
 
-#: builtin/pull.c:874
-msgid "--[no-]autostash option is only valid with --rebase."
-msgstr "--[no-]autostash är endast giltig med --rebase."
+#: builtin/rebase.c:471 builtin/revert.c:128
+msgid "allow commits with empty messages"
+msgstr "tillåt incheckningar med tomt meddelande"
 
-#: builtin/pull.c:882
-msgid "Updating an unborn branch with changes added to the index."
-msgstr "Uppdaterar en ofödd gren med ändringar som lagts till i indexet."
+#: builtin/rebase.c:472
+msgid "rebase merge commits"
+msgstr "ombasera sammanslagningar"
 
-#: builtin/pull.c:885
-msgid "pull with rebase"
-msgstr "pull med ombasering"
+#: builtin/rebase.c:474
+msgid "keep original branch points of cousins"
+msgstr "behåll ursprungliga förgreningspunkter för kusiner"
 
-#: builtin/pull.c:886
-msgid "please commit or stash them."
-msgstr "checka in eller använd \"stash\" på dem."
+#: builtin/rebase.c:476
+msgid "move commits that begin with squash!/fixup!"
+msgstr "flytta incheckningar som inleds med squash!/fixup!"
+
+#: builtin/rebase.c:477
+msgid "sign commits"
+msgstr "signera incheckningar"
+
+#: builtin/rebase.c:479 builtin/rebase.c:1455
+msgid "display a diffstat of what changed upstream"
+msgstr "vis diffstat för vad som ändrats uppströms"
 
-#: builtin/pull.c:911
-#, c-format
-msgid ""
-"fetch updated the current branch head.\n"
-"fast-forwarding your working tree from\n"
-"commit %s."
-msgstr ""
-"fetch uppdaterade huvudet för aktuell gren.\n"
-"snabbspolar din arbetskatalog från\n"
-"incheckningen %s."
+#: builtin/rebase.c:481
+msgid "continue rebase"
+msgstr "fortsätt ombasering"
 
-#: builtin/pull.c:916
-#, c-format
-msgid ""
-"Cannot fast-forward your working tree.\n"
-"After making sure that you saved anything precious from\n"
-"$ git diff %s\n"
-"output, run\n"
-"$ git reset --hard\n"
-"to recover."
-msgstr ""
-"Kan inte snabbspola din arbetskatalog.\n"
-"När du är säker på att du har sparat allt värdefullt i utdata från\n"
-"$ git diff %s\n"
-"kör du\n"
-"$ git reset --hard\n"
-"för att återgå."
+#: builtin/rebase.c:483
+msgid "skip commit"
+msgstr "hoppa över incheckning"
+
+#: builtin/rebase.c:484
+msgid "edit the todo list"
+msgstr "redigera attgöra-listan"
+
+#: builtin/rebase.c:486
+msgid "show the current patch"
+msgstr "visa nuvarande patch"
 
-#: builtin/pull.c:931
-msgid "Cannot merge multiple branches into empty head."
-msgstr "Kan inte slå ihop flera grenar i ett tomt huvud."
+#: builtin/rebase.c:489
+msgid "shorten commit ids in the todo list"
+msgstr "förkorta inchecknings-id i todo-listan"
 
-#: builtin/pull.c:935
-msgid "Cannot rebase onto multiple branches."
-msgstr "Kan inte ombasera ovanpå flera grenar."
+#: builtin/rebase.c:491
+msgid "expand commit ids in the todo list"
+msgstr "utöka inchecknings-id i todo-listan"
 
-#: builtin/pull.c:942
-msgid "cannot rebase with locally recorded submodule modifications"
-msgstr "kan inte ombasera med lokalt lagrade ändringar i undermoful"
+#: builtin/rebase.c:493
+msgid "check the todo list"
+msgstr "kontrollera todo-listan"
 
-#: builtin/push.c:19
-msgid "git push [<options>] [<repository> [<refspec>...]]"
-msgstr "git push [<flaggor>] [<arkiv> [<refspec>...]]"
+#: builtin/rebase.c:495
+msgid "rearrange fixup/squash lines"
+msgstr "ordna om fixup-/squash-rader"
 
-#: builtin/push.c:111
-msgid "tag shorthand without <tag>"
-msgstr "taggförkortning utan <tagg>"
+#: builtin/rebase.c:497
+msgid "insert exec commands in todo list"
+msgstr "lägg in exec-kommandon i todo-listan"
 
-#: builtin/push.c:121
-msgid "--delete only accepts plain target ref names"
-msgstr "--delete godtar endast enkla målreferensnamn"
+#: builtin/rebase.c:498
+msgid "onto"
+msgstr "ovanpå"
+
+#: builtin/rebase.c:501
+msgid "restrict-revision"
+msgstr "restrict-revision"
+
+#: builtin/rebase.c:501
+msgid "restrict revision"
+msgstr "begränsa revision"
+
+#: builtin/rebase.c:503
+msgid "squash-onto"
+msgstr "squash-onto"
+
+#: builtin/rebase.c:504
+msgid "squash onto"
+msgstr "tryck ihop ovanpå"
+
+#: builtin/rebase.c:506
+msgid "the upstream commit"
+msgstr "uppströmsincheckningen"
+
+#: builtin/rebase.c:508
+msgid "head-name"
+msgstr "head-name"
+
+#: builtin/rebase.c:508
+msgid "head name"
+msgstr "namn på huvud"
 
-#: builtin/push.c:165
-msgid ""
-"\n"
-"To choose either option permanently, see push.default in 'git help config'."
-msgstr ""
-"\n"
-"För att välja ett av alternativen permanent, se push.default i \"git help "
-"config\"."
+#: builtin/rebase.c:513
+msgid "rebase strategy"
+msgstr "sammanslagningsstrategi"
 
-#: builtin/push.c:168
-#, c-format
-msgid ""
-"The upstream branch of your current branch does not match\n"
-"the name of your current branch.  To push to the upstream branch\n"
-"on the remote, use\n"
-"\n"
-"    git push %s HEAD:%s\n"
-"\n"
-"To push to the branch of the same name on the remote, use\n"
-"\n"
-"    git push %s %s\n"
-"%s"
-msgstr ""
-"Uppströmsgrenen för din nuvarande gren stämmer inte överens\n"
-"med namnet på din aktuella gren. För att sända till uppströmsgrenen\n"
-"i fjärrarkivet använder du\n"
-"\n"
-"    git push %s HEAD:%s\n"
-"\n"
-"För att sända till grenen med samma namn i fjärrarkivet använder du\n"
-"\n"
-"    git push %s %s\n"
-"%s"
+#: builtin/rebase.c:514
+msgid "strategy-opts"
+msgstr "strategy-opts"
+
+#: builtin/rebase.c:515
+msgid "strategy options"
+msgstr "strategiflaggor"
+
+#: builtin/rebase.c:516
+msgid "switch-to"
+msgstr "switch-to"
+
+#: builtin/rebase.c:517
+msgid "the branch or commit to checkout"
+msgstr "gren eller inchecking att checka ut"
+
+#: builtin/rebase.c:518
+msgid "onto-name"
+msgstr "onto-name"
+
+#: builtin/rebase.c:518
+msgid "onto name"
+msgstr "på-namn"
+
+#: builtin/rebase.c:519
+msgid "cmd"
+msgstr "kmd"
+
+#: builtin/rebase.c:519
+msgid "the command to run"
+msgstr "kommando att köra"
+
+#: builtin/rebase.c:522 builtin/rebase.c:1540
+msgid "automatically re-schedule any `exec` that fails"
+msgstr "kör automatiskt alla \"exec\" som misslyckas på nytt"
+
+#: builtin/rebase.c:540
+msgid "--[no-]rebase-cousins has no effect without --rebase-merges"
+msgstr "--[no-]rebase-cousins har ingen effekt utan --rebase-merges"
 
-#: builtin/push.c:183
+#: builtin/rebase.c:556
 #, c-format
-msgid ""
-"You are not currently on a branch.\n"
-"To push the history leading to the current (detached HEAD)\n"
-"state now, use\n"
-"\n"
-"    git push %s HEAD:<name-of-remote-branch>\n"
-msgstr ""
-"Du är inte på någon gren för närvarande.\n"
-"För att sända in historiken som leder till den aktuella (frånkopplat\n"
-"HEAD) situationen använder du\n"
-"\n"
-"    git push %s HEAD:<namn-på-fjärrgren>\n"
+msgid "%s requires an interactive rebase"
+msgstr "%s kräver en interaktiv ombasering"
 
-#: builtin/push.c:197
+#: builtin/rebase.c:608
 #, c-format
-msgid ""
-"The current branch %s has no upstream branch.\n"
-"To push the current branch and set the remote as upstream, use\n"
-"\n"
-"    git push --set-upstream %s %s\n"
-msgstr ""
-"Den aktuella grenen %s har ingen uppströmsgren.\n"
-"För att sända aktuell gren och ange fjärrarkiv som uppström använder du\n"
-"\n"
-"    git push --set-upstream %s %s\n"
+msgid "could not get 'onto': '%s'"
+msgstr "kunde inte hämta \"onto\": \"%s\""
 
-#: builtin/push.c:205
+#: builtin/rebase.c:623
 #, c-format
-msgid "The current branch %s has multiple upstream branches, refusing to push."
-msgstr "Den aktuella grenen %s har flera uppströmsgrenar, vägrar sända."
+msgid "invalid orig-head: '%s'"
+msgstr "ogiltigt orig-head: \"%s\""
 
-#: builtin/push.c:208
+#: builtin/rebase.c:648
 #, c-format
-msgid ""
-"You are pushing to remote '%s', which is not the upstream of\n"
-"your current branch '%s', without telling me what to push\n"
-"to update which remote branch."
-msgstr ""
-"Du sänder till fjärren \"%s\", som inte är uppströms för den\n"
-"aktuella grenen \"%s\", utan att tala om för mig vad som\n"
-"skall sändas för att uppdatera fjärrgrenen."
+msgid "ignoring invalid allow_rerere_autoupdate: '%s'"
+msgstr "ignorera ogiltigt allow_rerere_autoupdate: \"%s\""
 
-#: builtin/push.c:267
-msgid ""
-"You didn't specify any refspecs to push, and push.default is \"nothing\"."
-msgstr ""
-"Du angav inga referensspecifikationer att sända, och push.default är "
-"\"nothing\"."
+#: builtin/rebase.c:724
+#, c-format
+msgid "Could not read '%s'"
+msgstr "Kunde inte läsa \"%s\""
 
-#: builtin/push.c:274
-msgid ""
-"Updates were rejected because the tip of your current branch is behind\n"
-"its remote counterpart. Integrate the remote changes (e.g.\n"
-"'git pull ...') before pushing again.\n"
-"See the 'Note about fast-forwards' in 'git push --help' for details."
-msgstr ""
-"Uppdateringar avvisades då änden på din befintliga gren är bakom\n"
-"dess fjärrmotsvarighet. Integrera fjärrändringarna (t.ex\n"
-"\"git pull ....\") innan du sänder igen.\n"
-"Se avsnittet \"Note about fast-forward\" i \"git push --help\" för detaljer."
+#: builtin/rebase.c:742
+#, c-format
+msgid "Cannot store %s"
+msgstr "Kan inte spara %s"
 
-#: builtin/push.c:280
-msgid ""
-"Updates were rejected because a pushed branch tip is behind its remote\n"
-"counterpart. Check out this branch and integrate the remote changes\n"
-"(e.g. 'git pull ...') before pushing again.\n"
-"See the 'Note about fast-forwards' in 'git push --help' for details."
-msgstr ""
-"Uppdateringar avvisades då änden på en gren som sänds in är bakom dess\n"
-"fjärrmotsvarighet. Checka ut grenen och integrera fjärrändringarna (t.ex.\n"
-"\"git pull ...\") innan du sänder igen.\n"
-"Se avsnittet \"Note about fast-forward\" i \"git push --help\" för detaljer."
+#: builtin/rebase.c:849
+msgid "could not determine HEAD revision"
+msgstr "kunde inte bestämma HEAD-revision"
 
-#: builtin/push.c:286
+#: builtin/rebase.c:972 git-rebase--preserve-merges.sh:81
 msgid ""
-"Updates were rejected because the remote contains work that you do\n"
-"not have locally. This is usually caused by another repository pushing\n"
-"to the same ref. You may want to first integrate the remote changes\n"
-"(e.g., 'git pull ...') before pushing again.\n"
-"See the 'Note about fast-forwards' in 'git push --help' for details."
+"Resolve all conflicts manually, mark them as resolved with\n"
+"\"git add/rm <conflicted_files>\", then run \"git rebase --continue\".\n"
+"You can instead skip this commit: run \"git rebase --skip\".\n"
+"To abort and get back to the state before \"git rebase\", run \"git rebase --"
+"abort\"."
 msgstr ""
-"Uppdateringar avvisades då fjärren innehåller ändringar som du inte\n"
-"har lokalt. Det beror oftast på att ett annat arkiv har sänt in samma\n"
-"referenser. Det kan vara en idé att först integrera fjärrändringarna\n"
-"(t.ex. \"git pull ...\") innan du sänder igen.\n"
-"Se avsnittet \"Note about fast-forwards\" i \"git push --help\" för detaljer."
-
-#: builtin/push.c:293
-msgid "Updates were rejected because the tag already exists in the remote."
-msgstr "Uppdateringarna avvisades eftersom taggen redan finns på fjärren."
+"Lös alla konflikter manuellt, märk dem som lösta med\n"
+"\"git add/rm <filer_i_konflikt>\", kör sedan \"git rebase --continue\".\n"
+"Du kan hoppa över incheckningen istället: kör \"git rebase --skip\".\n"
+"För att avbryta och återgå till där du var före ombaseringen, kör \"git "
+"rebase --abort\"."
 
-#: builtin/push.c:296
+#: builtin/rebase.c:1060
+#, c-format
 msgid ""
-"You cannot update a remote ref that points at a non-commit object,\n"
-"or update a remote ref to make it point at a non-commit object,\n"
-"without using the '--force' option.\n"
+"\n"
+"git encountered an error while preparing the patches to replay\n"
+"these revisions:\n"
+"\n"
+"    %s\n"
+"\n"
+"As a result, git cannot rebase them."
 msgstr ""
-"Du kan inte uppdatera en fjärr-referens som pekar på ett objekt som\n"
-"inte är en incheckning, eller uppdatera en fjärr-referens så att den\n"
-"pekar på något som inte är en incheckning, utan att använda flaggan\n"
-"\"--force\".\n"
-
-#: builtin/push.c:357
-#, c-format
-msgid "Pushing to %s\n"
-msgstr "Sänder till %s\n"
-
-#: builtin/push.c:361
-#, c-format
-msgid "failed to push some refs to '%s'"
-msgstr "misslyckades sända vissa referenser till \"%s\""
+"\n"
+"git upptäckte ett fel när det skulle förbereda patchar för att\n"
+"återskapa dessa revisioner:\n"
+"\n"
+"    %s\n"
+"\n"
+"Därför kan inte git ombasera dessa."
 
-#: builtin/push.c:395
+#: builtin/rebase.c:1367
 #, c-format
-msgid "bad repository '%s'"
-msgstr "felaktigt arkiv \"%s\""
-
-#: builtin/push.c:396
 msgid ""
-"No configured push destination.\n"
-"Either specify the URL from the command-line or configure a remote "
-"repository using\n"
+"%s\n"
+"Please specify which branch you want to rebase against.\n"
+"See git-rebase(1) for details.\n"
+"\n"
+"    git rebase '<branch>'\n"
+"\n"
+msgstr ""
+"%s\n"
+"Ange vilken gren du vill ombasera mot.\n"
+"Se git-rebase(1) för detaljer.\n"
+"\n"
+"    git rebase '<gren>'\n"
 "\n"
-"    git remote add <name> <url>\n"
+
+#: builtin/rebase.c:1383
+#, c-format
+msgid ""
+"If you wish to set tracking information for this branch you can do so with:\n"
 "\n"
-"and then push using the remote name\n"
+"    git branch --set-upstream-to=%s/<branch> %s\n"
 "\n"
-"    git push <name>\n"
 msgstr ""
-"Ingen destination har angivits.\n"
-"Ange antingen URL:en på kommandoraden eller ställ in ett uppströmsarkiv med\n"
+"Om du vill ange spårningsinformation för grenen kan du göra det med:\n"
 "\n"
-"    git remote add <namn> <url>\n"
-"\n"
-"och sänd sedan med hjälp av fjärrnamnet\n"
+"    git branch --set-upstream-to=%s/<gren> %s\n"
 "\n"
-"    git push <namn>\n"
 
-#: builtin/push.c:551
-msgid "repository"
-msgstr "arkiv"
+#: builtin/rebase.c:1413
+msgid "exec commands cannot contain newlines"
+msgstr "exec-kommandon kan inte innehålla nyradstecken"
 
-#: builtin/push.c:552 builtin/send-pack.c:164
-msgid "push all refs"
-msgstr "sänd alla referenser"
+#: builtin/rebase.c:1417
+msgid "empty exec command"
+msgstr "tomt exec-kommando"
 
-#: builtin/push.c:553 builtin/send-pack.c:166
-msgid "mirror all refs"
-msgstr "spegla alla referenser"
+#: builtin/rebase.c:1446
+msgid "rebase onto given branch instead of upstream"
+msgstr "ombasera mot given grenen istället för uppström"
 
-#: builtin/push.c:555
-msgid "delete refs"
-msgstr "ta bort referenser"
+#: builtin/rebase.c:1448
+msgid "use the merge-base of upstream and branch as the current base"
+msgstr "använd sammanslagningsbasen mellan uppströms och gren som aktuell bas"
 
-#: builtin/push.c:556
-msgid "push tags (can't be used with --all or --mirror)"
-msgstr "sänd taggar (kan inte användas med --all eller --mirror)"
+#: builtin/rebase.c:1450
+msgid "allow pre-rebase hook to run"
+msgstr "tillåt pre-rebase-krok att köra"
 
-#: builtin/push.c:559 builtin/send-pack.c:167
-msgid "force updates"
-msgstr "tvinga uppdateringar"
+#: builtin/rebase.c:1452
+msgid "be quiet. implies --no-stat"
+msgstr "var tyst. implicerar --no-stat"
 
-#: builtin/push.c:561 builtin/send-pack.c:181
-msgid "refname>:<expect"
-msgstr "refnamn>:<förvänta"
+#: builtin/rebase.c:1458
+msgid "do not show diffstat of what changed upstream"
+msgstr "visa inte en diffstat för vad som ändrats uppströms"
 
-#: builtin/push.c:562 builtin/send-pack.c:182
-msgid "require old value of ref to be at this value"
-msgstr "kräv att ref:s tidigare värde är detta"
+#: builtin/rebase.c:1461
+msgid "add a Signed-off-by: line to each commit"
+msgstr "lägg \"Signed-off-by:\"-rad till varje incheckning"
 
-#: builtin/push.c:565
-msgid "control recursive pushing of submodules"
-msgstr "styr rekursiv insändning av undermoduler"
+#: builtin/rebase.c:1464
+msgid "make committer date match author date"
+msgstr "sätt incheckningsdatum till författardatum"
 
-#: builtin/push.c:567 builtin/send-pack.c:175
-msgid "use thin pack"
-msgstr "använd tunna paket"
+#: builtin/rebase.c:1466
+msgid "ignore author date and use current date"
+msgstr "ignorera författardatum och använd nuvarande"
 
-#: builtin/push.c:568 builtin/push.c:569 builtin/send-pack.c:161
-#: builtin/send-pack.c:162
-msgid "receive pack program"
-msgstr "program för att ta emot paket"
+#: builtin/rebase.c:1468
+msgid "synonym of --reset-author-date"
+msgstr "synonym för --reset-author-date"
 
-#: builtin/push.c:570
-msgid "set upstream for git pull/status"
-msgstr "ställ in uppström för git pull/status"
+#: builtin/rebase.c:1470 builtin/rebase.c:1474
+msgid "passed to 'git apply'"
+msgstr "sänds till \"git apply\""
 
-#: builtin/push.c:573
-msgid "prune locally removed refs"
-msgstr "ta bort lokalt borttagna referenser"
+#: builtin/rebase.c:1472
+msgid "ignore changes in whitespace"
+msgstr "ignorera ändringar i blanksteg"
 
-#: builtin/push.c:575
-msgid "bypass pre-push hook"
-msgstr "förbigå pre-push-krok"
+#: builtin/rebase.c:1476 builtin/rebase.c:1479
+msgid "cherry-pick all commits, even if unchanged"
+msgstr "utför cherry-pick på alla incheckningar, även om oändrad"
 
-#: builtin/push.c:576
-msgid "push missing but relevant tags"
-msgstr "sänd in saknade men relevanta taggar"
+#: builtin/rebase.c:1481
+msgid "continue"
+msgstr "fortsätt"
 
-#: builtin/push.c:579 builtin/send-pack.c:169
-msgid "GPG sign the push"
-msgstr "GPG-signera insändningen"
+#: builtin/rebase.c:1484
+msgid "skip current patch and continue"
+msgstr "hoppa över nuvarande patch och fortsätt"
 
-#: builtin/push.c:581 builtin/send-pack.c:176
-msgid "request atomic transaction on remote side"
-msgstr "begär atomiska transaktioner på fjärrsidan"
+#: builtin/rebase.c:1486
+msgid "abort and check out the original branch"
+msgstr "avbryt och checka ut ursprungsgrenen"
 
-#: builtin/push.c:599
-msgid "--delete is incompatible with --all, --mirror and --tags"
-msgstr "--delete är inkompatibel med --all, --mirror och --tags"
+#: builtin/rebase.c:1489
+msgid "abort but keep HEAD where it is"
+msgstr "avbryt men behåll HEAD där det är"
 
-#: builtin/push.c:601
-msgid "--delete doesn't make sense without any refs"
-msgstr "--delete kan inte användas utan referenser"
+#: builtin/rebase.c:1490
+msgid "edit the todo list during an interactive rebase"
+msgstr "redigera attgöra-listan under interaktiv ombasering."
 
-#: builtin/push.c:604
-msgid "--all and --tags are incompatible"
-msgstr "--all och --tags är inkompatibla"
+#: builtin/rebase.c:1493
+msgid "show the patch file being applied or merged"
+msgstr "visa patchen som tillämpas eller slås samman"
 
-#: builtin/push.c:606
-msgid "--all can't be combined with refspecs"
-msgstr "--all kan inte kombineras med referensspecifikationer"
+#: builtin/rebase.c:1496
+msgid "use merging strategies to rebase"
+msgstr "använd sammanslagningsstrategier för sammanslagning"
 
-#: builtin/push.c:610
-msgid "--mirror and --tags are incompatible"
-msgstr "--mirror och --tags är inkompatibla"
+#: builtin/rebase.c:1500
+msgid "let the user edit the list of commits to rebase"
+msgstr "låt användaren redigera listan över incheckningar att ombasera"
 
-#: builtin/push.c:612
-msgid "--mirror can't be combined with refspecs"
-msgstr "--mirror kan inte kombineras med referensspecifikationer"
+#: builtin/rebase.c:1504
+msgid "(DEPRECATED) try to recreate merges instead of ignoring them"
+msgstr ""
+"(AVRÅDS) försök återskapa sammanslagningar istället för att ignorera dem"
 
-#: builtin/push.c:615
-msgid "--all and --mirror are incompatible"
-msgstr "--all och --mirror är inkompatibla"
+#: builtin/rebase.c:1509
+msgid "preserve empty commits during rebase"
+msgstr "behåll tomma incheckningar under ombasering"
 
-#: builtin/push.c:634
-msgid "push options must not have new line characters"
-msgstr "push-flaggor kan inte innehålla radbrytning"
+#: builtin/rebase.c:1511
+msgid "move commits that begin with squash!/fixup! under -i"
+msgstr "flytta incheckningar som börjar med squash!/fixup! under -i"
+
+#: builtin/rebase.c:1517
+msgid "automatically stash/stash pop before and after"
+msgstr "utför automatiskt stash/stash pop före och efter"
+
+#: builtin/rebase.c:1519
+msgid "add exec lines after each commit of the editable list"
+msgstr "lägg till exec-rader efter varje incheckning i den redigerbara listan"
+
+#: builtin/rebase.c:1523
+msgid "allow rebasing commits with empty messages"
+msgstr "tillåt ombasering av incheckningar med tomt meddelande"
+
+#: builtin/rebase.c:1526
+msgid "try to rebase merges instead of skipping them"
+msgstr "försök ombasera sammanslagningar istället för att ignorera dem"
+
+#: builtin/rebase.c:1529
+msgid "use 'merge-base --fork-point' to refine upstream"
+msgstr "använd \"merge-base --fork-point\" för att förfina uppström"
+
+#: builtin/rebase.c:1531
+msgid "use the given merge strategy"
+msgstr "använd angiven sammanslagningsstrategi"
 
-#: builtin/read-tree.c:40
+#: builtin/rebase.c:1533 builtin/revert.c:115
+msgid "option"
+msgstr "alternativ"
+
+#: builtin/rebase.c:1534
+msgid "pass the argument through to the merge strategy"
+msgstr "sänd flaggan till sammanslagningsstrategin"
+
+#: builtin/rebase.c:1537
+msgid "rebase all reachable commits up to the root(s)"
+msgstr "ombasera alla nåbara incheckningar upp till roten/rötterna"
+
+#: builtin/rebase.c:1554
 msgid ""
-"git read-tree [(-m [--trivial] [--aggressive] | --reset | --prefix=<prefix>) "
-"[-u [--exclude-per-directory=<gitignore>] | -i]] [--no-sparse-checkout] [--"
-"index-output=<file>] (--empty | <tree-ish1> [<tree-ish2> [<tree-ish3>]])"
+"the rebase.useBuiltin support has been removed!\n"
+"See its entry in 'git help config' for details."
 msgstr ""
-"git read-tree [(-m [--trivial] [--aggressive] | --reset | --prefix=<prefix>) "
-"[-u [--exclude-per-directory=<gitignore>] | -i]] [--no-sparse-checkout] [--"
-"index-output=<fil>] (--empty | <träd-igt1> [<träd-igt2> [<träd-igt3>]])"
+"stödet för rebase.useBuiltin har tagits bort!\n"
+"Se posten för det i \"git help config\" för detaljer."
 
-#: builtin/read-tree.c:120
-msgid "write resulting index to <file>"
-msgstr "skriv resulterande index till <fil>"
+#: builtin/rebase.c:1560
+msgid "It looks like 'git am' is in progress. Cannot rebase."
+msgstr "Det verkar som en \"git am\" körs. Kan inte ombasera."
 
-#: builtin/read-tree.c:123
-msgid "only empty the index"
-msgstr "töm bara indexet"
+#: builtin/rebase.c:1601
+msgid ""
+"git rebase --preserve-merges is deprecated. Use --rebase-merges instead."
+msgstr ""
+"git rebase --preserve-merges avråds från. Använd --rebase-merges istället."
 
-#: builtin/read-tree.c:125
-msgid "Merging"
-msgstr "Sammanslagning"
+#: builtin/rebase.c:1606
+msgid "cannot combine '--keep-base' with '--onto'"
+msgstr "kan inte kombinera \"--keep-base\" med \"--onto\""
 
-#: builtin/read-tree.c:127
-msgid "perform a merge in addition to a read"
-msgstr "utför en sammanslagning i tillägg till en läsning"
+#: builtin/rebase.c:1608
+msgid "cannot combine '--keep-base' with '--root'"
+msgstr "kan inte kombinera \"--keep-base\" med \"--root\""
 
-#: builtin/read-tree.c:129
-msgid "3-way merge if no file level merging required"
-msgstr "3-vägssammanslagning om sammanslagning på filnivå ej krävs"
+#: builtin/rebase.c:1612
+msgid "No rebase in progress?"
+msgstr "Ingen ombasering pågår?"
 
-#: builtin/read-tree.c:131
-msgid "3-way merge in presence of adds and removes"
-msgstr "3-vägssammanslagning när det finns tillägg och borttagningar"
+#: builtin/rebase.c:1616
+msgid "The --edit-todo action can only be used during interactive rebase."
+msgstr "Åtgärden --edit-todo kan endast användas under interaktiv ombasering."
 
-#: builtin/read-tree.c:133
-msgid "same as -m, but discard unmerged entries"
-msgstr "som -m, men kasta bort ej sammanslagna poster"
+#: builtin/rebase.c:1639
+msgid "Cannot read HEAD"
+msgstr "Kan inte läsa HEAD"
 
-#: builtin/read-tree.c:134
-msgid "<subdirectory>/"
-msgstr "<underkatalog>/"
+#: builtin/rebase.c:1651
+msgid ""
+"You must edit all merge conflicts and then\n"
+"mark them as resolved using git add"
+msgstr ""
+"Du måste redigera alla sammanslagningskonflikter och\n"
+"därefter markera dem som lösta med git add"
 
-#: builtin/read-tree.c:135
-msgid "read the tree into the index under <subdirectory>/"
-msgstr "läs in trädet i indexet under <underkatalog>/"
+#: builtin/rebase.c:1670
+msgid "could not discard worktree changes"
+msgstr "kunde inte kasta ändringar i arbetskatalogen"
 
-#: builtin/read-tree.c:138
-msgid "update working tree with merge result"
-msgstr "uppdatera arbetskatalogen med resultatet från sammanslagningen"
+#: builtin/rebase.c:1689
+#, c-format
+msgid "could not move back to %s"
+msgstr "kunde inte flytta tillbaka till %s"
 
-#: builtin/read-tree.c:140
-msgid "gitignore"
-msgstr "gitignore"
+#: builtin/rebase.c:1734
+#, c-format
+msgid ""
+"It seems that there is already a %s directory, and\n"
+"I wonder if you are in the middle of another rebase.  If that is the\n"
+"case, please try\n"
+"\t%s\n"
+"If that is not the case, please\n"
+"\t%s\n"
+"and run me again.  I am stopping in case you still have something\n"
+"valuable there.\n"
+msgstr ""
+"Det verkar som katalogen %s redan existerar, och\n"
+"jag undrar om du redan är mitt i en annan ombasering. Om så är\n"
+"fallet, försök\n"
+"\t%s\n"
+"Om så inte är fallet, kör\n"
+"\t%s\n"
+"och kör programmet igen. Jag avslutar ifall du fortfarande har\n"
+"något av värde där.\n"
 
-#: builtin/read-tree.c:141
-msgid "allow explicitly ignored files to be overwritten"
-msgstr "tillåt explicit ignorerade filer att skrivas över"
+#: builtin/rebase.c:1757
+msgid "switch `C' expects a numerical value"
+msgstr "flaggan \"C\" förväntar ett numeriskt värde"
 
-#: builtin/read-tree.c:144
-msgid "don't check the working tree after merging"
-msgstr "kontrollera inte arbetskatalogen efter sammanslagning"
+#: builtin/rebase.c:1798
+#, c-format
+msgid "Unknown mode: %s"
+msgstr "Okänt läge: %s"
 
-#: builtin/read-tree.c:145
-msgid "don't update the index or the work tree"
-msgstr "uppdatera inte indexet eller arbetskatalogen"
+#: builtin/rebase.c:1820
+msgid "--strategy requires --merge or --interactive"
+msgstr "--strategy kräver --merge eller --interactive"
 
-#: builtin/read-tree.c:147
-msgid "skip applying sparse checkout filter"
-msgstr "hoppa över att applicera filter för gles utcheckning"
+#: builtin/rebase.c:1860
+msgid "--reschedule-failed-exec requires --exec or --interactive"
+msgstr "--reschedule-failed-exec kräver --exec eller --interactive"
 
-#: builtin/read-tree.c:149
-msgid "debug unpack-trees"
-msgstr "felsök unpack-trees"
+#: builtin/rebase.c:1872
+msgid "cannot combine am options with either interactive or merge options"
+msgstr ""
+"kan inte kombinera am-flaggor med varken interaktiv- eller "
+"sammanslagningsflaggor"
 
-#: builtin/rebase--helper.c:8
-msgid "git rebase--helper [<options>]"
-msgstr "git rebase--helper [<flaggor>]"
+#: builtin/rebase.c:1891
+msgid "cannot combine '--preserve-merges' with '--rebase-merges'"
+msgstr "kan inte kombinera \"--preserve-merges\" med \"--rebase-merges\""
 
-#: builtin/rebase--helper.c:24
-msgid "keep empty commits"
-msgstr "behåll tomma incheckningar"
+#: builtin/rebase.c:1895
+msgid ""
+"error: cannot combine '--preserve-merges' with '--reschedule-failed-exec'"
+msgstr ""
+"fel: kan inte kombinera \"--preserve-merges\" med \"--reschedule-failed-exec"
+"\""
 
-#: builtin/rebase--helper.c:26 builtin/revert.c:123
-msgid "allow commits with empty messages"
-msgstr "tillåt incheckningar med tomt meddelande"
+#: builtin/rebase.c:1919
+#, c-format
+msgid "invalid upstream '%s'"
+msgstr "felaktig uppström \"%s\""
 
-#: builtin/rebase--helper.c:27
-msgid "rebase merge commits"
-msgstr "ombasera sammanslagningar"
+#: builtin/rebase.c:1925
+msgid "Could not create new root commit"
+msgstr "kunde inte skapa ny rotincheckning"
 
-#: builtin/rebase--helper.c:29
-msgid "keep original branch points of cousins"
-msgstr "behåll ursprungliga förgreningspunkter för kusiner"
+#: builtin/rebase.c:1951
+#, c-format
+msgid "'%s': need exactly one merge base with branch"
+msgstr "\"%s\": behöver precis en sammanslagningsbas med gren"
 
-#: builtin/rebase--helper.c:30
-msgid "continue rebase"
-msgstr "fortsätt ombasering"
+#: builtin/rebase.c:1954
+#, c-format
+msgid "'%s': need exactly one merge base"
+msgstr "\"%s\": behöver precis en sammanslagningsbas"
 
-#: builtin/rebase--helper.c:32
-msgid "abort rebase"
-msgstr "avbryt ombasering"
-
-#: builtin/rebase--helper.c:35
-msgid "make rebase script"
-msgstr "skapa ombaseringsskript"
+#: builtin/rebase.c:1962
+#, c-format
+msgid "Does not point to a valid commit '%s'"
+msgstr "Pekar inte på en giltig incheckning: \"%s\""
 
-#: builtin/rebase--helper.c:37
-msgid "shorten commit ids in the todo list"
-msgstr "förkorta inchecknings-id i todo-listan"
+#: builtin/rebase.c:1987
+#, c-format
+msgid "fatal: no such branch/commit '%s'"
+msgstr "ödesdigert: ingen sådan gren/incheckning: \"%s\""
 
-#: builtin/rebase--helper.c:39
-msgid "expand commit ids in the todo list"
-msgstr "utöka inchecknings-id i todo-listan"
+#: builtin/rebase.c:1995 builtin/submodule--helper.c:40
+#: builtin/submodule--helper.c:1961
+#, c-format
+msgid "No such ref: %s"
+msgstr "Ingen sådan referens: %s"
 
-#: builtin/rebase--helper.c:41
-msgid "check the todo list"
-msgstr "kontrollera todo-listan"
+#: builtin/rebase.c:2006
+msgid "Could not resolve HEAD to a revision"
+msgstr "Kunde inte bestämma HEAD:s incheckning"
 
-#: builtin/rebase--helper.c:43
-msgid "skip unnecessary picks"
-msgstr "hoppa över onödiga \"pick\"-kommandon"
+#: builtin/rebase.c:2044
+msgid "Cannot autostash"
+msgstr "Kan inte utföra \"autostash\""
 
-#: builtin/rebase--helper.c:45
-msgid "rearrange fixup/squash lines"
-msgstr "ordna om fixup-/squash-rader"
+#: builtin/rebase.c:2047
+#, c-format
+msgid "Unexpected stash response: '%s'"
+msgstr "Oväntat svar från stash: \"%s\""
 
-#: builtin/rebase--helper.c:47
-msgid "insert exec commands in todo list"
-msgstr "lägg in exec-kommandon i todo-listan"
+#: builtin/rebase.c:2053
+#, c-format
+msgid "Could not create directory for '%s'"
+msgstr "Kunde inte skapa katalog för \"%s\""
 
-#: builtin/rebase--helper.c:68
-msgid "--[no-]rebase-cousins has no effect without --rebase-merges"
-msgstr "--[no-]rebase-cousins har ingen effekt utan --rebase-merges"
+#: builtin/rebase.c:2056
+#, c-format
+msgid "Created autostash: %s\n"
+msgstr "Skapade autostash: %s\n"
+
+#: builtin/rebase.c:2059
+msgid "could not reset --hard"
+msgstr "kunde inte utföra \"reset --hard\""
+
+#: builtin/rebase.c:2068
+msgid "Please commit or stash them."
+msgstr "Checka in eller använd \"stash\" på dem."
+
+#: builtin/rebase.c:2095
+#, c-format
+msgid "could not parse '%s'"
+msgstr "kunde inte tolka \"%s\""
+
+#: builtin/rebase.c:2108
+#, c-format
+msgid "could not switch to %s"
+msgstr "kunde inte växla till %s"
+
+#: builtin/rebase.c:2119
+msgid "HEAD is up to date."
+msgstr "HEAD är à jour."
+
+#: builtin/rebase.c:2121
+#, c-format
+msgid "Current branch %s is up to date.\n"
+msgstr "Aktuell gren %s är à jour.\n"
+
+#: builtin/rebase.c:2129
+msgid "HEAD is up to date, rebase forced."
+msgstr "HEAD är à jour, ombasering framtvingad."
+
+#: builtin/rebase.c:2131
+#, c-format
+msgid "Current branch %s is up to date, rebase forced.\n"
+msgstr "Aktuell gren %s är à jour, ombasering framtvingad.\n"
+
+#: builtin/rebase.c:2139
+msgid "The pre-rebase hook refused to rebase."
+msgstr "Kroken pre-rebase vägrade ombaseringen."
+
+#: builtin/rebase.c:2146
+#, c-format
+msgid "Changes to %s:\n"
+msgstr "Ändringar till %s:\n"
+
+#: builtin/rebase.c:2149
+#, c-format
+msgid "Changes from %s to %s:\n"
+msgstr "Ändringar från %s till %s:\n"
+
+#: builtin/rebase.c:2174
+#, c-format
+msgid "First, rewinding head to replay your work on top of it...\n"
+msgstr ""
+"Först, spolar tillbaka huvudet för att spela av ditt arbete ovanpå det...\n"
 
-#: builtin/receive-pack.c:31
+#: builtin/rebase.c:2183
+msgid "Could not detach HEAD"
+msgstr "Kunde inte koppla från HEAD"
+
+#: builtin/rebase.c:2192
+#, c-format
+msgid "Fast-forwarded %s to %s.\n"
+msgstr "Snabbspolade %s till %s.\n"
+
+#: builtin/receive-pack.c:32
 msgid "git receive-pack <git-dir>"
 msgstr "git receive-pack <git-katalog>"
 
-#: builtin/receive-pack.c:842
+#: builtin/receive-pack.c:830
 msgid ""
 "By default, updating the current branch in a non-bare repository\n"
 "is denied, because it will make the index and work tree inconsistent\n"
@@ -12733,7 +18275,7 @@ msgstr ""
 "För att undvika detta meddelande och fortfarande behålla det\n"
 "normala beteendet, sätt \"receive.denyCurrentBranch\" till \"refuse\"."
 
-#: builtin/receive-pack.c:862
+#: builtin/receive-pack.c:850
 msgid ""
 "By default, deleting the current branch is denied, because the next\n"
 "'git clone' won't result in any file checked out, causing confusion.\n"
@@ -12754,24 +18296,79 @@ msgstr ""
 "\n"
 "För att undvika detta meddelande kan du sätta det till \"refuse\"."
 
-#: builtin/receive-pack.c:1935
+#: builtin/receive-pack.c:1936
 msgid "quiet"
 msgstr "tyst"
 
-#: builtin/receive-pack.c:1949
+#: builtin/receive-pack.c:1950
 msgid "You must specify a directory."
 msgstr "Du måste ange en katalog."
 
-#: builtin/reflog.c:532 builtin/reflog.c:537
+#: builtin/reflog.c:17
+msgid ""
+"git reflog expire [--expire=<time>] [--expire-unreachable=<time>] [--"
+"rewrite] [--updateref] [--stale-fix] [--dry-run | -n] [--verbose] [--all] "
+"<refs>..."
+msgstr ""
+"git reflog expire [--expire=<tid>] [--expire-unreachable=<tid>] [--rewrite] "
+"[--updateref] [--stale-fix] [--dry-run | -n] [--verbose] [--all] "
+"<referenser>..."
+
+#: builtin/reflog.c:22
+msgid ""
+"git reflog delete [--rewrite] [--updateref] [--dry-run | -n] [--verbose] "
+"<refs>..."
+msgstr ""
+"git reflog delete [--rewrite] [--updateref] [--dry-run | -n] [--verbose] "
+"<referenser>..."
+
+#: builtin/reflog.c:25
+msgid "git reflog exists <ref>"
+msgstr "git reflog exists <referens>"
+
+#: builtin/reflog.c:567 builtin/reflog.c:572
 #, c-format
 msgid "'%s' is not a valid timestamp"
 msgstr "\"%s\" är inte en giltig tidsstämpel"
 
-#: builtin/remote.c:14
+#: builtin/reflog.c:605
+#, c-format
+msgid "Marking reachable objects..."
+msgstr "Markerar nåbara objekt..."
+
+#: builtin/reflog.c:643
+#, c-format
+msgid "%s points nowhere!"
+msgstr "%s pekar ingenstans!"
+
+#: builtin/reflog.c:695
+msgid "no reflog specified to delete"
+msgstr "ingen referenslogg att ta bort angavs"
+
+#: builtin/reflog.c:704
+#, c-format
+msgid "not a reflog: %s"
+msgstr "inte en referenslogg: %s"
+
+#: builtin/reflog.c:709
+#, c-format
+msgid "no reflog for '%s'"
+msgstr "ingen referenslogg för \"%s\""
+
+#: builtin/reflog.c:755
+#, c-format
+msgid "invalid ref format: %s"
+msgstr "felaktigt referensformat: %s"
+
+#: builtin/reflog.c:764
+msgid "git reflog [ show | expire | delete | exists ]"
+msgstr "git reflog [ show | expire | delete | exists ]"
+
+#: builtin/remote.c:16
 msgid "git remote [-v | --verbose]"
 msgstr "git remote [-v | --verbose]"
 
-#: builtin/remote.c:15
+#: builtin/remote.c:17
 msgid ""
 "git remote add [-t <branch>] [-m <master>] [-f] [--tags | --no-tags] [--"
 "mirror=<fetch|push>] <name> <url>"
@@ -12779,82 +18376,82 @@ msgstr ""
 "git remote add [-t <gren>] [-m <master>] [-f] [--tags | --no-tags] [--"
 "mirror=<fetch|push>] <namn> <url>"
 
-#: builtin/remote.c:16 builtin/remote.c:36
+#: builtin/remote.c:18 builtin/remote.c:38
 msgid "git remote rename <old> <new>"
 msgstr "git remote rename <gammal> <ny>"
 
-#: builtin/remote.c:17 builtin/remote.c:41
+#: builtin/remote.c:19 builtin/remote.c:43
 msgid "git remote remove <name>"
 msgstr "git remote remove <namn>"
 
-#: builtin/remote.c:18 builtin/remote.c:46
+#: builtin/remote.c:20 builtin/remote.c:48
 msgid "git remote set-head <name> (-a | --auto | -d | --delete | <branch>)"
 msgstr "git remote set-head <namn> (-a | --auto | -d | --delete | <gren>)"
 
-#: builtin/remote.c:19
+#: builtin/remote.c:21
 msgid "git remote [-v | --verbose] show [-n] <name>"
 msgstr "git remote [-v | --verbose] show [-n] <namn>"
 
-#: builtin/remote.c:20
+#: builtin/remote.c:22
 msgid "git remote prune [-n | --dry-run] <name>"
 msgstr "git remote prune [-n | --dry-run] <namn>"
 
-#: builtin/remote.c:21
+#: builtin/remote.c:23
 msgid ""
 "git remote [-v | --verbose] update [-p | --prune] [(<group> | <remote>)...]"
 msgstr ""
 "git remote [-v | --verbose] update [-p | --prune] [(<grupp> | <fjärr>)...]"
 
-#: builtin/remote.c:22
+#: builtin/remote.c:24
 msgid "git remote set-branches [--add] <name> <branch>..."
 msgstr "git remote set-branches [--add] <namn> <gren>..."
 
-#: builtin/remote.c:23 builtin/remote.c:72
+#: builtin/remote.c:25 builtin/remote.c:74
 msgid "git remote get-url [--push] [--all] <name>"
 msgstr "git remote get-url [--push] [--all] <namn>"
 
-#: builtin/remote.c:24 builtin/remote.c:77
+#: builtin/remote.c:26 builtin/remote.c:79
 msgid "git remote set-url [--push] <name> <newurl> [<oldurl>]"
 msgstr "git remote set-url [--push] <namn> <nyurl> [<gammalurl>]"
 
-#: builtin/remote.c:25 builtin/remote.c:78
+#: builtin/remote.c:27 builtin/remote.c:80
 msgid "git remote set-url --add <name> <newurl>"
 msgstr "git remote set-url --add <namn> <nyurl>"
 
-#: builtin/remote.c:26 builtin/remote.c:79
+#: builtin/remote.c:28 builtin/remote.c:81
 msgid "git remote set-url --delete <name> <url>"
 msgstr "git remote set-url --delete <namn> <url>"
 
-#: builtin/remote.c:31
+#: builtin/remote.c:33
 msgid "git remote add [<options>] <name> <url>"
 msgstr "git remote add [<flaggor>] <namn> <url>"
 
-#: builtin/remote.c:51
+#: builtin/remote.c:53
 msgid "git remote set-branches <name> <branch>..."
 msgstr "git remote set-branches <namn> <gren>..."
 
-#: builtin/remote.c:52
+#: builtin/remote.c:54
 msgid "git remote set-branches --add <name> <branch>..."
 msgstr "git remote set-branches --add <namn> <gren>..."
 
-#: builtin/remote.c:57
+#: builtin/remote.c:59
 msgid "git remote show [<options>] <name>"
 msgstr "git remote show [<flaggor>] <namn>"
 
-#: builtin/remote.c:62
+#: builtin/remote.c:64
 msgid "git remote prune [<options>] <name>"
 msgstr "git remote prune [<flaggor>] <namn>"
 
-#: builtin/remote.c:67
+#: builtin/remote.c:69
 msgid "git remote update [<options>] [<group> | <remote>]..."
 msgstr "git remote update [<flaggor>] [<grupp> | <fjärr>]..."
 
-#: builtin/remote.c:96
+#: builtin/remote.c:98
 #, c-format
 msgid "Updating %s"
 msgstr "Uppdaterar %s"
 
-#: builtin/remote.c:128
+#: builtin/remote.c:130
 msgid ""
 "--mirror is dangerous and deprecated; please\n"
 "\t use --mirror=fetch or --mirror=push instead"
@@ -12862,86 +18459,82 @@ msgstr ""
 "--mirror är farlig och föråldrad; använd\n"
 "\t --mirror=fetch eller --mirror=push istället"
 
-#: builtin/remote.c:145
+#: builtin/remote.c:147
 #, c-format
 msgid "unknown mirror argument: %s"
 msgstr "okänt argument till mirror: %s"
 
-#: builtin/remote.c:161
+#: builtin/remote.c:163
 msgid "fetch the remote branches"
 msgstr "hämta fjärrgrenarna"
 
-#: builtin/remote.c:163
+#: builtin/remote.c:165
 msgid "import all tags and associated objects when fetching"
 msgstr "importera alla taggar och associerade objekt vid hämtning"
 
-#: builtin/remote.c:166
+#: builtin/remote.c:168
 msgid "or do not fetch any tag at all (--no-tags)"
 msgstr "eller hämta inte några taggar alls (--no-tags)"
 
-#: builtin/remote.c:168
+#: builtin/remote.c:170
 msgid "branch(es) to track"
 msgstr "gren(ar) att spåra"
 
-#: builtin/remote.c:169
+#: builtin/remote.c:171
 msgid "master branch"
 msgstr "huvudgren"
 
-#: builtin/remote.c:170
-msgid "push|fetch"
-msgstr "push|fetch"
-
-#: builtin/remote.c:171
+#: builtin/remote.c:173
 msgid "set up remote as a mirror to push to or fetch from"
 msgstr "ställ in arkiv som spegel att sända eller ta emot från"
 
-#: builtin/remote.c:183
+#: builtin/remote.c:185
 msgid "specifying a master branch makes no sense with --mirror"
 msgstr "att ange en master-gren ger ingen mening med --mirror"
 
-#: builtin/remote.c:185
+#: builtin/remote.c:187
 msgid "specifying branches to track makes sense only with fetch mirrors"
 msgstr "att ange grenar att spåra ger mening bara med hämtningsspeglar"
 
-#: builtin/remote.c:192 builtin/remote.c:634
+#: builtin/remote.c:194 builtin/remote.c:636
 #, c-format
 msgid "remote %s already exists."
 msgstr "fjärrarkivet %s finns redan."
 
-#: builtin/remote.c:196 builtin/remote.c:638
+#: builtin/remote.c:198 builtin/remote.c:640
 #, c-format
 msgid "'%s' is not a valid remote name"
 msgstr "\"%s\" är inte ett giltigt namn på fjärrarkiv"
 
-#: builtin/remote.c:236
+#: builtin/remote.c:238
 #, c-format
 msgid "Could not setup master '%s'"
 msgstr "Kunde inte skapa master \"%s\""
 
-#: builtin/remote.c:342
+#: builtin/remote.c:344
 #, c-format
 msgid "Could not get fetch map for refspec %s"
 msgstr "Kunde inte hämta mappning för referensspecifikation %s"
 
-#: builtin/remote.c:441 builtin/remote.c:449
+#: builtin/remote.c:443 builtin/remote.c:451
 msgid "(matching)"
 msgstr "(matchande)"
 
-#: builtin/remote.c:453
+#: builtin/remote.c:455
 msgid "(delete)"
 msgstr "(ta bort)"
 
-#: builtin/remote.c:627 builtin/remote.c:762 builtin/remote.c:861
+#: builtin/remote.c:629 builtin/remote.c:764 builtin/remote.c:863
 #, c-format
-msgid "No such remote: %s"
-msgstr "Inget sådant fjärrarkiv: %s"
+msgid "No such remote: '%s'"
+msgstr "Ingen sådan fjärr: \"%s\""
 
-#: builtin/remote.c:644
+#: builtin/remote.c:646
 #, c-format
 msgid "Could not rename config section '%s' to '%s'"
 msgstr "Kunde inte byta namn på konfigurationssektionen \"%s\" till \"%s\""
 
-#: builtin/remote.c:664
+#: builtin/remote.c:666
 #, c-format
 msgid ""
 "Not updating non-default fetch refspec\n"
@@ -12952,17 +18545,17 @@ msgstr ""
 "\t%s\n"
 "\tUppdatera konfigurationen manuellt om nödvändigt."
 
-#: builtin/remote.c:700
+#: builtin/remote.c:701
 #, c-format
 msgid "deleting '%s' failed"
 msgstr "misslyckades ta bort \"%s\""
 
-#: builtin/remote.c:734
+#: builtin/remote.c:735
 #, c-format
 msgid "creating '%s' failed"
 msgstr "misslyckades skapa \"%s\""
 
-#: builtin/remote.c:799
+#: builtin/remote.c:801
 msgid ""
 "Note: A branch outside the refs/remotes/ hierarchy was not removed;\n"
 "to delete it, use:"
@@ -12976,118 +18569,118 @@ msgstr[1] ""
 "Observera: Några grenar utanför hierarkin refs/remotes/ togs inte bort;\n"
 "för att ta bort dem, använd:"
 
-#: builtin/remote.c:813
+#: builtin/remote.c:815
 #, c-format
 msgid "Could not remove config section '%s'"
 msgstr "Kunde inte ta bort konfigurationssektionen \"%s\""
 
-#: builtin/remote.c:914
+#: builtin/remote.c:916
 #, c-format
 msgid " new (next fetch will store in remotes/%s)"
 msgstr " ny (nästa hämtning sparar i remotes/%s)"
 
-#: builtin/remote.c:917
+#: builtin/remote.c:919
 msgid " tracked"
 msgstr " spårad"
 
-#: builtin/remote.c:919
+#: builtin/remote.c:921
 msgid " stale (use 'git remote prune' to remove)"
 msgstr " förlegad (använd \"git remote prune\" för att ta bort)"
 
-#: builtin/remote.c:921
+#: builtin/remote.c:923
 msgid " ???"
 msgstr " ???"
 
-#: builtin/remote.c:962
+#: builtin/remote.c:964
 #, c-format
 msgid "invalid branch.%s.merge; cannot rebase onto > 1 branch"
 msgstr "ogiltig branch.%s.merge; kan inte ombasera över > 1 gren"
 
-#: builtin/remote.c:971
+#: builtin/remote.c:973
 #, c-format
 msgid "rebases interactively onto remote %s"
 msgstr "ombaseras interaktivt på fjärren %s"
 
-#: builtin/remote.c:973
+#: builtin/remote.c:975
 #, c-format
 msgid "rebases interactively (with merges) onto remote %s"
 msgstr "ombaseras interaktivt (med sammanslagningar) på fjärren %s"
 
-#: builtin/remote.c:976
+#: builtin/remote.c:978
 #, c-format
 msgid "rebases onto remote %s"
 msgstr "ombaseras på fjärren %s"
 
-#: builtin/remote.c:980
+#: builtin/remote.c:982
 #, c-format
 msgid " merges with remote %s"
 msgstr " sammanslås med fjärren %s"
 
-#: builtin/remote.c:983
+#: builtin/remote.c:985
 #, c-format
 msgid "merges with remote %s"
 msgstr "sammanslås med fjärren %s"
 
-#: builtin/remote.c:986
+#: builtin/remote.c:988
 #, c-format
 msgid "%-*s    and with remote %s\n"
 msgstr "%-*s    och med fjärren %s\n"
 
-#: builtin/remote.c:1029
+#: builtin/remote.c:1031
 msgid "create"
 msgstr "skapa"
 
-#: builtin/remote.c:1032
+#: builtin/remote.c:1034
 msgid "delete"
 msgstr "ta bort"
 
-#: builtin/remote.c:1036
+#: builtin/remote.c:1038
 msgid "up to date"
 msgstr "àjour"
 
-#: builtin/remote.c:1039
+#: builtin/remote.c:1041
 msgid "fast-forwardable"
 msgstr "kan snabbspolas"
 
-#: builtin/remote.c:1042
+#: builtin/remote.c:1044
 msgid "local out of date"
 msgstr "lokal föråldrad"
 
-#: builtin/remote.c:1049
+#: builtin/remote.c:1051
 #, c-format
 msgid "    %-*s forces to %-*s (%s)"
 msgstr "    %-*s tvingar till %-*s (%s)"
 
-#: builtin/remote.c:1052
+#: builtin/remote.c:1054
 #, c-format
 msgid "    %-*s pushes to %-*s (%s)"
 msgstr "    %-*s sänder till %-*s (%s)"
 
-#: builtin/remote.c:1056
+#: builtin/remote.c:1058
 #, c-format
 msgid "    %-*s forces to %s"
 msgstr "    %-*s tvingar till %s"
 
-#: builtin/remote.c:1059
+#: builtin/remote.c:1061
 #, c-format
 msgid "    %-*s pushes to %s"
 msgstr "    %-*s sänder till %s"
 
-#: builtin/remote.c:1127
+#: builtin/remote.c:1129
 msgid "do not query remotes"
 msgstr "fråga inte fjärrar"
 
-#: builtin/remote.c:1154
+#: builtin/remote.c:1156
 #, c-format
 msgid "* remote %s"
 msgstr "* fjärr %s"
 
-#: builtin/remote.c:1155
+#: builtin/remote.c:1157
 #, c-format
 msgid "  Fetch URL: %s"
 msgstr "  Hämt-URL: %s"
 
-#: builtin/remote.c:1156 builtin/remote.c:1172 builtin/remote.c:1311
+#: builtin/remote.c:1158 builtin/remote.c:1174 builtin/remote.c:1313
 msgid "(no URL)"
 msgstr "(ingen URL)"
 
@@ -13095,193 +18688,184 @@ msgstr "(ingen URL)"
 #. with the one in " Fetch URL: %s"
 #. translation.
 #.
-#: builtin/remote.c:1170 builtin/remote.c:1172
+#: builtin/remote.c:1172 builtin/remote.c:1174
 #, c-format
 msgid "  Push  URL: %s"
 msgstr "  Sänd-URL: %s"
 
-#: builtin/remote.c:1174 builtin/remote.c:1176 builtin/remote.c:1178
+#: builtin/remote.c:1176 builtin/remote.c:1178 builtin/remote.c:1180
 #, c-format
 msgid "  HEAD branch: %s"
 msgstr "  HEAD-gren: %s"
 
-#: builtin/remote.c:1174
+#: builtin/remote.c:1176
 msgid "(not queried)"
 msgstr "(inte förfrågad)"
 
-#: builtin/remote.c:1176
+#: builtin/remote.c:1178
 msgid "(unknown)"
 msgstr "(okänd)"
 
-#: builtin/remote.c:1180
+#: builtin/remote.c:1182
 #, c-format
 msgid ""
 "  HEAD branch (remote HEAD is ambiguous, may be one of the following):\n"
 msgstr "  HEAD-gren (HEAD på fjärr är tvetydig, kan vara en av följande):\n"
 
-#: builtin/remote.c:1192
+#: builtin/remote.c:1194
 #, c-format
 msgid "  Remote branch:%s"
 msgid_plural "  Remote branches:%s"
 msgstr[0] "  Fjärrgren:%s"
 msgstr[1] "  Fjärrgrenar:%s"
 
-#: builtin/remote.c:1195 builtin/remote.c:1221
+#: builtin/remote.c:1197 builtin/remote.c:1223
 msgid " (status not queried)"
 msgstr " (status inte förfrågad)"
 
-#: builtin/remote.c:1204
+#: builtin/remote.c:1206
 msgid "  Local branch configured for 'git pull':"
 msgid_plural "  Local branches configured for 'git pull':"
 msgstr[0] "  Lokal gren konfigurerad för \"git pull\":"
 msgstr[1] "  Lokala grenar konfigurerade för \"git pull\":"
 
-#: builtin/remote.c:1212
+#: builtin/remote.c:1214
 msgid "  Local refs will be mirrored by 'git push'"
 msgstr "  Lokala referenser speglas av \"git push\""
 
-#: builtin/remote.c:1218
+#: builtin/remote.c:1220
 #, c-format
 msgid "  Local ref configured for 'git push'%s:"
 msgid_plural "  Local refs configured for 'git push'%s:"
 msgstr[0] "  Lokal referens konfigurerad för \"git push\"%s:"
 msgstr[1] "  Lokala referenser konfigurerade för \"git push\"%s:"
 
-#: builtin/remote.c:1239
+#: builtin/remote.c:1241
 msgid "set refs/remotes/<name>/HEAD according to remote"
 msgstr "sätt refs/remotes/<namn>/HEAD enligt fjärren"
 
-#: builtin/remote.c:1241
+#: builtin/remote.c:1243
 msgid "delete refs/remotes/<name>/HEAD"
 msgstr "ta bort refs/remotes/<namn>/HEAD"
 
-#: builtin/remote.c:1256
+#: builtin/remote.c:1258
 msgid "Cannot determine remote HEAD"
 msgstr "Kan inte bestämma HEAD på fjärren"
 
-#: builtin/remote.c:1258
+#: builtin/remote.c:1260
 msgid "Multiple remote HEAD branches. Please choose one explicitly with:"
 msgstr "Flera HEAD-grenar på fjärren. Välj en explicit med:"
 
-#: builtin/remote.c:1268
+#: builtin/remote.c:1270
 #, c-format
 msgid "Could not delete %s"
 msgstr "Kunde inte ta bort %s"
 
-#: builtin/remote.c:1276
+#: builtin/remote.c:1278
 #, c-format
 msgid "Not a valid ref: %s"
 msgstr "Inte en giltig referens: %s"
 
-#: builtin/remote.c:1278
+#: builtin/remote.c:1280
 #, c-format
 msgid "Could not setup %s"
 msgstr "Kunde inte ställa in %s"
 
-#: builtin/remote.c:1296
+#: builtin/remote.c:1298
 #, c-format
 msgid " %s will become dangling!"
 msgstr " %s kommer bli dinglande!"
 
-#: builtin/remote.c:1297
+#: builtin/remote.c:1299
 #, c-format
 msgid " %s has become dangling!"
 msgstr " %s har blivit dinglande!"
 
-#: builtin/remote.c:1307
+#: builtin/remote.c:1309
 #, c-format
 msgid "Pruning %s"
 msgstr "Rensar %s"
 
-#: builtin/remote.c:1308
+#: builtin/remote.c:1310
 #, c-format
 msgid "URL: %s"
 msgstr "URL: %s"
 
-#: builtin/remote.c:1324
+#: builtin/remote.c:1326
 #, c-format
 msgid " * [would prune] %s"
 msgstr " * [skulle rensa] %s"
 
-#: builtin/remote.c:1327
+#: builtin/remote.c:1329
 #, c-format
 msgid " * [pruned] %s"
 msgstr " * [rensad] %s"
 
-#: builtin/remote.c:1372
+#: builtin/remote.c:1374
 msgid "prune remotes after fetching"
 msgstr "rensa fjärrar efter hämtning"
 
-#: builtin/remote.c:1435 builtin/remote.c:1489 builtin/remote.c:1557
+#: builtin/remote.c:1437 builtin/remote.c:1491 builtin/remote.c:1559
 #, c-format
 msgid "No such remote '%s'"
 msgstr "Ingen sådan fjärr \"%s\""
 
-#: builtin/remote.c:1451
+#: builtin/remote.c:1453
 msgid "add branch"
 msgstr "lägg till gren"
 
-#: builtin/remote.c:1458
+#: builtin/remote.c:1460
 msgid "no remote specified"
 msgstr "ingen fjärr angavs"
 
-#: builtin/remote.c:1475
+#: builtin/remote.c:1477
 msgid "query push URLs rather than fetch URLs"
 msgstr "fråga sänd-URL:er istället för hämta-URL:er"
 
-#: builtin/remote.c:1477
+#: builtin/remote.c:1479
 msgid "return all URLs"
 msgstr "returnera alla URL:er"
 
-#: builtin/remote.c:1505
+#: builtin/remote.c:1507
 #, c-format
 msgid "no URLs configured for remote '%s'"
 msgstr "ingen URL:er angivna för fjärren \"%s\""
 
-#: builtin/remote.c:1531
+#: builtin/remote.c:1533
 msgid "manipulate push URLs"
 msgstr "manipulera URL:ar för sändning"
 
-#: builtin/remote.c:1533
+#: builtin/remote.c:1535
 msgid "add URL"
 msgstr "lägg till URL"
 
-#: builtin/remote.c:1535
+#: builtin/remote.c:1537
 msgid "delete URLs"
 msgstr "ta bort URL:ar"
 
-#: builtin/remote.c:1542
+#: builtin/remote.c:1544
 msgid "--add --delete doesn't make sense"
 msgstr "--add --delete ger ingen mening"
 
-#: builtin/remote.c:1581
+#: builtin/remote.c:1583
 #, c-format
 msgid "Invalid old URL pattern: %s"
 msgstr "Felaktig gammalt URL-mönster: %s"
 
-#: builtin/remote.c:1589
+#: builtin/remote.c:1591
 #, c-format
 msgid "No such URL found: %s"
 msgstr "Ingen sådan URL hittades: %s"
 
-#: builtin/remote.c:1591
+#: builtin/remote.c:1593
 msgid "Will not delete all non-push URLs"
 msgstr "Kommer inte ta bort alla icke-sänd-URL:er"
 
-#: builtin/remote.c:1607
-msgid "be verbose; must be placed before a subcommand"
-msgstr "var pratsam; måste skrivas före ett underkommando"
-
-#: builtin/remote.c:1638
-#, c-format
-msgid "Unknown subcommand: %s"
-msgstr "Okänt underkommando: %s"
-
-#: builtin/repack.c:18
+#: builtin/repack.c:23
 msgid "git repack [<options>]"
 msgstr "git repack [<flaggor>]"
 
-#: builtin/repack.c:23
+#: builtin/repack.c:28
 msgid ""
 "Incremental repacks are incompatible with bitmap indexes.  Use\n"
 "--no-write-bitmap-index or disable the pack.writebitmaps configuration."
@@ -13290,91 +18874,131 @@ msgstr ""
 "Använd --no-write-bitmap-index eller inaktivera inställningen\n"
 "pack.writebitmaps"
 
-#: builtin/repack.c:180
+#: builtin/repack.c:191
+msgid "could not start pack-objects to repack promisor objects"
+msgstr "kunde inte starta pack-objects för att packa om kontraktsobjekt"
+
+#: builtin/repack.c:230 builtin/repack.c:416
+msgid "repack: Expecting full hex object ID lines only from pack-objects."
+msgstr ""
+"repack: Förväntar kompletta hex-objekt-id-rader endast från pack-objects."
+
+#: builtin/repack.c:254
+msgid "could not finish pack-objects to repack promisor objects"
+msgstr "kunde inte avsluta pack-objects för att packa om kontraktsobjekt"
+
+#: builtin/repack.c:292
 msgid "pack everything in a single pack"
 msgstr "packa allt i ett enda paket"
 
-#: builtin/repack.c:182
+#: builtin/repack.c:294
 msgid "same as -a, and turn unreachable objects loose"
 msgstr "samma som -a, och gör onåbara objekt lösa"
 
-#: builtin/repack.c:185
+#: builtin/repack.c:297
 msgid "remove redundant packs, and run git-prune-packed"
 msgstr "ta bort överflödiga paket, och kör git-prune-packed"
 
-#: builtin/repack.c:187
+#: builtin/repack.c:299
 msgid "pass --no-reuse-delta to git-pack-objects"
 msgstr "sänd --no-reuse-delta till git-pack-objects"
 
-#: builtin/repack.c:189
+#: builtin/repack.c:301
 msgid "pass --no-reuse-object to git-pack-objects"
 msgstr "sänd --no-reuse-object till git-pack-objects"
 
-#: builtin/repack.c:191
+#: builtin/repack.c:303
 msgid "do not run git-update-server-info"
 msgstr "kör inte git-update-server-info"
 
-#: builtin/repack.c:194
+#: builtin/repack.c:306
 msgid "pass --local to git-pack-objects"
 msgstr "sänd --local till git-pack-objects"
 
-#: builtin/repack.c:196
+#: builtin/repack.c:308
 msgid "write bitmap index"
 msgstr "skriv bitkartindex"
 
-#: builtin/repack.c:197
+#: builtin/repack.c:310
+msgid "pass --delta-islands to git-pack-objects"
+msgstr "sänd --delta-islands till git-pack-objects"
+
+#: builtin/repack.c:311
 msgid "approxidate"
 msgstr "cirkadatum"
 
-#: builtin/repack.c:198
+#: builtin/repack.c:312
 msgid "with -A, do not loosen objects older than this"
 msgstr "med -A, lös inte upp objekt äldre än detta"
 
-#: builtin/repack.c:200
+#: builtin/repack.c:314
 msgid "with -a, repack unreachable objects"
 msgstr "med -a, packa om onåbara objekt"
 
-#: builtin/repack.c:202
+#: builtin/repack.c:316
 msgid "size of the window used for delta compression"
 msgstr "storlek på fönster använt för deltakomprimering"
 
-#: builtin/repack.c:203 builtin/repack.c:209
+#: builtin/repack.c:317 builtin/repack.c:323
 msgid "bytes"
 msgstr "byte"
 
-#: builtin/repack.c:204
+#: builtin/repack.c:318
 msgid "same as the above, but limit memory size instead of entries count"
 msgstr "samma som ovan, men begränsa minnesstorleken istället för postantal"
 
-#: builtin/repack.c:206
+#: builtin/repack.c:320
 msgid "limits the maximum delta depth"
 msgstr "begränsa maximalt deltadjup"
 
-#: builtin/repack.c:208
+#: builtin/repack.c:322
 msgid "limits the maximum number of threads"
 msgstr "begränsar maximalt antal trådar"
 
-#: builtin/repack.c:210
+#: builtin/repack.c:324
 msgid "maximum size of each packfile"
 msgstr "maximal storlek på varje paketfil"
 
-#: builtin/repack.c:212
+#: builtin/repack.c:326
 msgid "repack objects in packs marked with .keep"
 msgstr "packa om objekt i paket märkta med .keep"
 
-#: builtin/repack.c:214
+#: builtin/repack.c:328
 msgid "do not repack this pack"
 msgstr "packa inte om detta paket"
 
-#: builtin/repack.c:224
+#: builtin/repack.c:338
 msgid "cannot delete packs in a precious-objects repo"
 msgstr "kan inte ta bort paket i ett \"precious-objects\"-arkiv"
 
-#: builtin/repack.c:228
+#: builtin/repack.c:342
 msgid "--keep-unreachable and -A are incompatible"
 msgstr "--keep-unreachable och -A kan inte användas samtidigt"
 
-#: builtin/repack.c:425 builtin/worktree.c:139
+#: builtin/repack.c:425
+msgid "Nothing new to pack."
+msgstr "Inget nytt att packa."
+
+#: builtin/repack.c:486
+#, c-format
+msgid ""
+"WARNING: Some packs in use have been renamed by\n"
+"WARNING: prefixing old- to their name, in order to\n"
+"WARNING: replace them with the new version of the\n"
+"WARNING: file.  But the operation failed, and the\n"
+"WARNING: attempt to rename them back to their\n"
+"WARNING: original names also failed.\n"
+"WARNING: Please rename them in %s manually:\n"
+msgstr ""
+"VARNING: Namnen på några paket har bytts genom att\n"
+"VARNING: lägga till old- före namnen, för att byta\n"
+"VARNING: dem mot den nya versionen av filen. Men\n"
+"VARNING: operationen misslyckades, och försöket att\n"
+"VARNING: byta tillbaka till det ursprungliga\n"
+"VARNING: namnet misslyckades också.\n"
+"VARNING: Byt namn på dem i %s manuellt:\n"
+
+#: builtin/repack.c:534
 #, c-format
 msgid "failed to remove '%s'"
 msgstr "misslyckades ta bort \"%s\""
@@ -13403,22 +19027,121 @@ msgstr "git replace -d <objekt>..."
 msgid "git replace [--format=<format>] [-l [<pattern>]]"
 msgstr "git replace [--format=<format>] [-l [<mönster>]]"
 
-#: builtin/replace.c:371 builtin/replace.c:415 builtin/replace.c:445
+#: builtin/replace.c:90
+#, c-format
+msgid ""
+"invalid replace format '%s'\n"
+"valid formats are 'short', 'medium' and 'long'"
+msgstr ""
+"ogiltigt ersättningsformat \"%s\"\n"
+"giltiga format är \"short\", \"medium\" och \"long\""
+
+#: builtin/replace.c:125
+#, c-format
+msgid "replace ref '%s' not found"
+msgstr "ersättningsreferensen \"%s\" hittades inte"
+
+#: builtin/replace.c:141
+#, c-format
+msgid "Deleted replace ref '%s'"
+msgstr "Tog bort ersättningsreferensen \"%s\""
+
+#: builtin/replace.c:153
+#, c-format
+msgid "'%s' is not a valid ref name"
+msgstr "\"%s\" är inte ett giltigt referensnamn"
+
+#: builtin/replace.c:158
+#, c-format
+msgid "replace ref '%s' already exists"
+msgstr "ersättningsreferensen \"%s\" finns redan"
+
+#: builtin/replace.c:178
+#, c-format
+msgid ""
+"Objects must be of the same type.\n"
+"'%s' points to a replaced object of type '%s'\n"
+"while '%s' points to a replacement object of type '%s'."
+msgstr ""
+"Objekt måste vara av samma typ.\n"
+"\"%s\" pekar på ett ersatt objekt med typen \"%s\"\n"
+"medan \"%s\" pekar på ett ersättningsobjekt av typen \"%s\"."
+
+#: builtin/replace.c:229
+#, c-format
+msgid "unable to open %s for writing"
+msgstr "kan inte öppna %s för skrivning"
+
+#: builtin/replace.c:242
+msgid "cat-file reported failure"
+msgstr "cat-file rapporterade misslyckande"
+
+#: builtin/replace.c:258
+#, c-format
+msgid "unable to open %s for reading"
+msgstr "kan inte öppna %s för läsning"
+
+#: builtin/replace.c:272
+msgid "unable to spawn mktree"
+msgstr "kan inte starta mktree"
+
+#: builtin/replace.c:276
+msgid "unable to read from mktree"
+msgstr "kan inte läsa från mktree"
+
+#: builtin/replace.c:285
+msgid "mktree reported failure"
+msgstr "mktree rapporterade misslyckande"
+
+#: builtin/replace.c:289
+msgid "mktree did not return an object name"
+msgstr "mktree returnerade inte ett objektnamn"
+
+#: builtin/replace.c:298
+#, c-format
+msgid "unable to fstat %s"
+msgstr "kan inte utföra \"fstat\" på %s"
+
+#: builtin/replace.c:303
+msgid "unable to write object to database"
+msgstr "kan inte skriva objektet till databasen"
+
+#: builtin/replace.c:322 builtin/replace.c:378 builtin/replace.c:423
+#: builtin/replace.c:453
+#, c-format
+msgid "not a valid object name: '%s'"
+msgstr "objektnamnet är inte giltigt: \"%s\""
+
+#: builtin/replace.c:326
+#, c-format
+msgid "unable to get object type for %s"
+msgstr "kan inte läsa objekttyp för %s"
+
+#: builtin/replace.c:342
+msgid "editing object file failed"
+msgstr "misslyckades redigera objektfilen"
+
+#: builtin/replace.c:351
+#, c-format
+msgid "new object is the same as the old one: '%s'"
+msgstr "nytt objekt är samma som det gamla: \"%s\""
+
+#: builtin/replace.c:384
 #, c-format
-msgid "Not a valid object name: '%s'"
-msgstr "Objektnamnet är inte giltigt: \"%s\""
+msgid "could not parse %s as a commit"
+msgstr "kunde inte tolka %s som incheckning"
 
-#: builtin/replace.c:407
+#: builtin/replace.c:415
 #, c-format
 msgid "bad mergetag in commit '%s'"
 msgstr "felaktig sammanslagningstagg i incheckningen \"%s\""
 
-#: builtin/replace.c:409
+#: builtin/replace.c:417
 #, c-format
 msgid "malformed mergetag in commit '%s'"
 msgstr "felformad sammanslagningstagg i incheckningen \"%s\""
 
-#: builtin/replace.c:421
+#: builtin/replace.c:429
 #, c-format
 msgid ""
 "original commit '%s' contains mergetag '%s' that is discarded; use --edit "
@@ -13427,21 +19150,31 @@ msgstr ""
 "den ursprungliga incheckningen \"%s\" innehåller sammanslagningstaggen \"%s"
 "\" som har förkastats; använd --edit istället för --graft"
 
-#: builtin/replace.c:460
+#: builtin/replace.c:468
 #, c-format
-msgid "the original commit '%s' has a gpg signature."
-msgstr "den ursprungliga incheckningen \"%s\" har en gpg-signatur."
+msgid "the original commit '%s' has a gpg signature"
+msgstr "den ursprungliga incheckningen \"%s\" har en gpg-signatur"
 
-#: builtin/replace.c:461
+#: builtin/replace.c:469
 msgid "the signature will be removed in the replacement commit!"
 msgstr "signaturen kommer att tas bort i ersättningsincheckningen!"
 
-#: builtin/replace.c:471
+#: builtin/replace.c:479
 #, c-format
 msgid "could not write replacement commit for: '%s'"
 msgstr "kunde inte skriva ersättningsincheckning för: \"%s\""
 
-#: builtin/replace.c:514
+#: builtin/replace.c:487
+#, c-format
+msgid "graft for '%s' unnecessary"
+msgstr "ympning för \"%s\" behövs inte"
+
+#: builtin/replace.c:491
+#, c-format
+msgid "new commit is the same as the old one: '%s'"
+msgstr "ny incheckning är samma som den gamla: \"%s\""
+
+#: builtin/replace.c:526
 #, c-format
 msgid ""
 "could not convert the following graft(s):\n"
@@ -13450,211 +19183,272 @@ msgstr ""
 "kunde inte konvertera följande ympning(ar):\n"
 "%s"
 
-#: builtin/replace.c:535
+#: builtin/replace.c:547
 msgid "list replace refs"
 msgstr "visa ersättningsreferenser"
 
-#: builtin/replace.c:536
+#: builtin/replace.c:548
 msgid "delete replace refs"
 msgstr "ta bort ersättningsreferenser"
 
-#: builtin/replace.c:537
+#: builtin/replace.c:549
 msgid "edit existing object"
 msgstr "redigera befintligt objekt"
 
-#: builtin/replace.c:538
+#: builtin/replace.c:550
 msgid "change a commit's parents"
 msgstr "ändra en inchecknings föräldrar"
 
-#: builtin/replace.c:539
+#: builtin/replace.c:551
 msgid "convert existing graft file"
 msgstr "konvertera befintlig ympningsfil"
 
-#: builtin/replace.c:540
+#: builtin/replace.c:552
 msgid "replace the ref if it exists"
 msgstr "ersätt referensen om den finns"
 
-#: builtin/replace.c:542
+#: builtin/replace.c:554
 msgid "do not pretty-print contents for --edit"
 msgstr "använd inte snygg visning av innehåll för --edit"
 
-#: builtin/replace.c:543
+#: builtin/replace.c:555
 msgid "use this format"
 msgstr "använd detta format"
 
+#: builtin/replace.c:568
+msgid "--format cannot be used when not listing"
+msgstr "--format kan inte användas utanför listning"
+
+#: builtin/replace.c:576
+msgid "-f only makes sense when writing a replacement"
+msgstr "-f kan endast användas vid skrivning av ersättning"
+
+#: builtin/replace.c:580
+msgid "--raw only makes sense with --edit"
+msgstr "--raw kan bara användas med --edit"
+
+#: builtin/replace.c:586
+msgid "-d needs at least one argument"
+msgstr "-d behöver minst ett argument"
+
+#: builtin/replace.c:592
+msgid "bad number of arguments"
+msgstr "fel antal argument"
+
+#: builtin/replace.c:598
+msgid "-e needs exactly one argument"
+msgstr "-e tar exakt ett argument"
+
+#: builtin/replace.c:604
+msgid "-g needs at least one argument"
+msgstr "-g tar minst ett argument"
+
+#: builtin/replace.c:610
+msgid "--convert-graft-file takes no argument"
+msgstr "--convert-graft-file tar inga argument"
+
+#: builtin/replace.c:616
+msgid "only one pattern can be given with -l"
+msgstr "endast ett mönster kan anges med -l"
+
 #: builtin/rerere.c:13
 msgid "git rerere [clear | forget <path>... | status | remaining | diff | gc]"
 msgstr "git rerere [clear | forget <path>... | status | remaining | diff | gc]"
 
-#: builtin/rerere.c:59
+#: builtin/rerere.c:60
 msgid "register clean resolutions in index"
 msgstr "registrera rena lösningar i indexet"
 
-#: builtin/reset.c:29
+#: builtin/rerere.c:79
+msgid "'git rerere forget' without paths is deprecated"
+msgstr "\"git rerere forget\" utan sökvägar är föråldrat"
+
+#: builtin/rerere.c:113
+#, c-format
+msgid "unable to generate diff for '%s'"
+msgstr "misslyckades skapa diff för \"%s\""
+
+#: builtin/reset.c:32
 msgid ""
 "git reset [--mixed | --soft | --hard | --merge | --keep] [-q] [<commit>]"
 msgstr ""
 "git reset [--mixed | --soft | --hard | --merge | --keep] [-q] [<incheckning>]"
 
-#: builtin/reset.c:30
-msgid "git reset [-q] [<tree-ish>] [--] <paths>..."
+#: builtin/reset.c:33
+msgid "git reset [-q] [<tree-ish>] [--] <pathspec>..."
 msgstr "git reset [-q] [<träd-igt>] [--] <sökvägar>..."
 
-#: builtin/reset.c:31
-msgid "git reset --patch [<tree-ish>] [--] [<paths>...]"
+#: builtin/reset.c:34
+msgid ""
+"git reset [-q] [--pathspec-from-file [--pathspec-file-nul]] [<tree-ish>]"
+msgstr ""
+"git reset [-q] [--pathspec-from-file [--pathspec-file-nul]] [<träd-igt>]"
+
+#: builtin/reset.c:35
+msgid "git reset --patch [<tree-ish>] [--] [<pathspec>...]"
 msgstr "git reset --patch [<träd-igt>] [--] [<sökvägar>...]"
 
-#: builtin/reset.c:37
+#: builtin/reset.c:41
 msgid "mixed"
 msgstr "blandad"
 
-#: builtin/reset.c:37
+#: builtin/reset.c:41
 msgid "soft"
 msgstr "mjuk"
 
-#: builtin/reset.c:37
+#: builtin/reset.c:41
 msgid "hard"
 msgstr "hård"
 
-#: builtin/reset.c:37
+#: builtin/reset.c:41
 msgid "merge"
 msgstr "sammanslagning"
 
-#: builtin/reset.c:37
+#: builtin/reset.c:41
 msgid "keep"
 msgstr "behåll"
 
-#: builtin/reset.c:78
+#: builtin/reset.c:82
 msgid "You do not have a valid HEAD."
 msgstr "Du har inte en giltig HEAD."
 
-#: builtin/reset.c:80
+#: builtin/reset.c:84
 msgid "Failed to find tree of HEAD."
 msgstr "Kunde inte hitta trädet för HEAD."
 
-#: builtin/reset.c:86
+#: builtin/reset.c:90
 #, c-format
 msgid "Failed to find tree of %s."
 msgstr "Kunde inte hitta trädet för %s."
 
-#: builtin/reset.c:111
+#: builtin/reset.c:115
 #, c-format
 msgid "HEAD is now at %s"
 msgstr "HEAD är nu på %s"
 
-#: builtin/reset.c:189
+#: builtin/reset.c:194
 #, c-format
 msgid "Cannot do a %s reset in the middle of a merge."
 msgstr "Kan inte utföra en %s återställning mitt i en sammanslagning."
 
-#: builtin/reset.c:289
+#: builtin/reset.c:294 builtin/stash.c:519 builtin/stash.c:594
+#: builtin/stash.c:618
 msgid "be quiet, only report errors"
 msgstr "var tyst, rapportera endast fel"
 
-#: builtin/reset.c:291
+#: builtin/reset.c:296
 msgid "reset HEAD and index"
 msgstr "återställ HEAD och index"
 
-#: builtin/reset.c:292
+#: builtin/reset.c:297
 msgid "reset only HEAD"
 msgstr "återställ endast HEAD"
 
-#: builtin/reset.c:294 builtin/reset.c:296
+#: builtin/reset.c:299 builtin/reset.c:301
 msgid "reset HEAD, index and working tree"
 msgstr "återställ HEAD, index och arbetskatalog"
 
-#: builtin/reset.c:298
+#: builtin/reset.c:303
 msgid "reset HEAD but keep local changes"
 msgstr "återställ HEAD men behåll lokala ändringar"
 
-#: builtin/reset.c:304
+#: builtin/reset.c:309
 msgid "record only the fact that removed paths will be added later"
 msgstr "registrera endast att borttagna sökvägar kommer läggas till senare"
 
-#: builtin/reset.c:321
+#: builtin/reset.c:343
 #, c-format
 msgid "Failed to resolve '%s' as a valid revision."
 msgstr "Kunde inte slå upp \"%s\" som en giltig revision."
 
-#: builtin/reset.c:329
+#: builtin/reset.c:351
 #, c-format
 msgid "Failed to resolve '%s' as a valid tree."
 msgstr "Kunde inte slå upp \"%s\" som ett giltigt träd."
 
-#: builtin/reset.c:338
+#: builtin/reset.c:360
 msgid "--patch is incompatible with --{hard,mixed,soft}"
 msgstr "--patch är inkompatibel med --{hard,mixed,soft}"
 
-#: builtin/reset.c:347
+#: builtin/reset.c:370
 msgid "--mixed with paths is deprecated; use 'git reset -- <paths>' instead."
 msgstr ""
 "--mixed rekommenderas inte med sökvägar; använd \"git reset -- <sökvägar>\"."
 
-#: builtin/reset.c:349
+#: builtin/reset.c:372
 #, c-format
 msgid "Cannot do %s reset with paths."
 msgstr "Kan inte göra %s återställning med sökvägar."
 
-#: builtin/reset.c:359
+#: builtin/reset.c:387
 #, c-format
 msgid "%s reset is not allowed in a bare repository"
 msgstr "%s återställning tillåts inte i ett naket arkiv"
 
-#: builtin/reset.c:363
+#: builtin/reset.c:391
 msgid "-N can only be used with --mixed"
 msgstr "-N kan endast användas med --mixed"
 
-#: builtin/reset.c:380
+#: builtin/reset.c:412
 msgid "Unstaged changes after reset:"
 msgstr "Oköade ändringar efter återställning:"
 
-#: builtin/reset.c:386
+#: builtin/reset.c:415
+#, c-format
+msgid ""
+"\n"
+"It took %.2f seconds to enumerate unstaged changes after reset.  You can\n"
+"use '--quiet' to avoid this.  Set the config setting reset.quiet to true\n"
+"to make this the default.\n"
+msgstr ""
+"\n"
+"Det tog %.2f sekunder att räkna upp oköade ändringar efter återställning.\n"
+"Du kan använda \"--quiet\" för att förhindra detta. Ställ "
+"konfigurationsvariabeln\n"
+"reset.quiet till true för att göra detta till förval.\n"
+
+#: builtin/reset.c:425
 #, c-format
 msgid "Could not reset index file to revision '%s'."
 msgstr "Kunde inte återställa indexfilen till versionen \"%s\"."
 
-#: builtin/reset.c:390
+#: builtin/reset.c:429
 msgid "Could not write new index file."
 msgstr "Kunde inte skriva ny indexfil."
 
-#: builtin/rev-list.c:397
+#: builtin/rev-list.c:411
 msgid "cannot combine --exclude-promisor-objects and --missing"
 msgstr "kan inte kombinera --exclude-promisor-objects och --missing"
 
-#: builtin/rev-list.c:455
+#: builtin/rev-list.c:472
 msgid "object filtering requires --objects"
 msgstr "objektfiltrering kräver --objects"
 
-#: builtin/rev-list.c:458
-#, c-format
-msgid "invalid sparse value '%s'"
-msgstr "ogiltigt värde för sparse: \"%s\""
-
-#: builtin/rev-list.c:499
+#: builtin/rev-list.c:522
 msgid "rev-list does not support display of notes"
 msgstr "rev-list stöder inte visning av anteckningar"
 
-#: builtin/rev-list.c:502
+#: builtin/rev-list.c:525
 msgid "cannot combine --use-bitmap-index with object filtering"
 msgstr "kan inte kombinera --use-bitmap-index med objektfiltrering"
 
-#: builtin/rev-parse.c:406
+#: builtin/rev-parse.c:408
 msgid "git rev-parse --parseopt [<options>] -- [<args>...]"
 msgstr "git rev-parse --parseopt [<options>] -- [<argument>...]"
 
-#: builtin/rev-parse.c:411
+#: builtin/rev-parse.c:413
 msgid "keep the `--` passed as an arg"
 msgstr "behåll \"--\" sänt som argument"
 
-#: builtin/rev-parse.c:413
+#: builtin/rev-parse.c:415
 msgid "stop parsing after the first non-option argument"
 msgstr "sluta tolka efter första argument som inte är flagga"
 
-#: builtin/rev-parse.c:416
+#: builtin/rev-parse.c:418
 msgid "output in stuck long form"
 msgstr "utdata fast i lång form"
 
-#: builtin/rev-parse.c:549
+#: builtin/rev-parse.c:551
 msgid ""
 "git rev-parse --parseopt [<options>] -- [<args>...]\n"
 "   or: git rev-parse --sq-quote [<arg>...]\n"
@@ -13669,92 +19463,97 @@ msgstr ""
 "Kör \"git rev-parse --parseopt -h\" för mer information om den första "
 "varianten."
 
-#: builtin/revert.c:23
+#: builtin/revert.c:24
 msgid "git revert [<options>] <commit-ish>..."
 msgstr "git revert [<flaggor>] <incheckning-igt>..."
 
-#: builtin/revert.c:24
+#: builtin/revert.c:25
 msgid "git revert <subcommand>"
 msgstr "git revert <underkommando>"
 
-#: builtin/revert.c:29
+#: builtin/revert.c:30
 msgid "git cherry-pick [<options>] <commit-ish>..."
 msgstr "git cherry-pick [<flaggor>] <incheckning-igt>..."
 
-#: builtin/revert.c:30
+#: builtin/revert.c:31
 msgid "git cherry-pick <subcommand>"
 msgstr "git cherry-pick <underkommando>"
 
-#: builtin/revert.c:90
+#: builtin/revert.c:72
+#, c-format
+msgid "option `%s' expects a number greater than zero"
+msgstr "flaggan \"%s\" antar ett numeriskt värde större än noll"
+
+#: builtin/revert.c:92
 #, c-format
 msgid "%s: %s cannot be used with %s"
 msgstr "%s: %s kan inte användas med %s"
 
-#: builtin/revert.c:99
+#: builtin/revert.c:102
 msgid "end revert or cherry-pick sequence"
 msgstr "avsluta revert- eller cherry-pick-sekvens"
 
-#: builtin/revert.c:100
+#: builtin/revert.c:103
 msgid "resume revert or cherry-pick sequence"
 msgstr "återuppta revert- eller cherry-pick-sekvens"
 
-#: builtin/revert.c:101
+#: builtin/revert.c:104
 msgid "cancel revert or cherry-pick sequence"
 msgstr "avbryt revert- eller cherry-pick-sekvens"
 
-#: builtin/revert.c:102
+#: builtin/revert.c:105
+msgid "skip current commit and continue"
+msgstr "hoppa över nuvarande incheckning och fortsätt"
+
+#: builtin/revert.c:107
 msgid "don't automatically commit"
 msgstr "checka inte in automatiskt"
 
-#: builtin/revert.c:103
+#: builtin/revert.c:108
 msgid "edit the commit message"
 msgstr "redigera incheckningsmeddelandet"
 
-#: builtin/revert.c:106
+#: builtin/revert.c:111
 msgid "parent-number"
 msgstr "nummer-på-förälder"
 
-#: builtin/revert.c:107
+#: builtin/revert.c:112
 msgid "select mainline parent"
 msgstr "välj förälder för huvudlinje"
 
-#: builtin/revert.c:109
+#: builtin/revert.c:114
 msgid "merge strategy"
 msgstr "sammanslagningsstrategi"
 
-#: builtin/revert.c:110
-msgid "option"
-msgstr "alternativ"
-
-#: builtin/revert.c:111
+#: builtin/revert.c:116
 msgid "option for merge strategy"
 msgstr "alternativ för sammanslagningsstrategi"
 
-#: builtin/revert.c:120
+#: builtin/revert.c:125
 msgid "append commit name"
 msgstr "lägg till incheckningsnamn"
 
-#: builtin/revert.c:122
+#: builtin/revert.c:127
 msgid "preserve initially empty commits"
 msgstr "behåll incheckningar som börjar som tomma"
 
-#: builtin/revert.c:124
+#: builtin/revert.c:129
 msgid "keep redundant, empty commits"
 msgstr "behåll redundanta, tomma incheckningar"
 
-#: builtin/revert.c:214
+#: builtin/revert.c:232
 msgid "revert failed"
 msgstr "\"revert\" misslyckades"
 
-#: builtin/revert.c:227
+#: builtin/revert.c:245
 msgid "cherry-pick failed"
 msgstr "\"cherry-pick\" misslyckades"
 
-#: builtin/rm.c:18
+#: builtin/rm.c:19
 msgid "git rm [<options>] [--] <file>..."
 msgstr "git rm [<flaggor>] [--] <fil>..."
 
-#: builtin/rm.c:206
+#: builtin/rm.c:207
 msgid ""
 "the following file has staged content different from both the\n"
 "file and the HEAD:"
@@ -13766,7 +19565,7 @@ msgstr[0] ""
 msgstr[1] ""
 "följande filer har köat innehåll som skiljer sig både från filen och HEAD:"
 
-#: builtin/rm.c:211
+#: builtin/rm.c:212
 msgid ""
 "\n"
 "(use -f to force removal)"
@@ -13774,13 +19573,13 @@ msgstr ""
 "\n"
 "(använd -f för att tvinga borttagning)"
 
-#: builtin/rm.c:215
+#: builtin/rm.c:216
 msgid "the following file has changes staged in the index:"
 msgid_plural "the following files have changes staged in the index:"
 msgstr[0] "följande fil har ändringar köade i indexet:"
 msgstr[1] "följande filer har ändringar köade i indexet:"
 
-#: builtin/rm.c:219 builtin/rm.c:228
+#: builtin/rm.c:220 builtin/rm.c:229
 msgid ""
 "\n"
 "(use --cached to keep the file, or -f to force removal)"
@@ -13788,47 +19587,47 @@ msgstr ""
 "\n"
 "(använd --cached för att behålla filen eller -f för att tvinga borttagning)"
 
-#: builtin/rm.c:225
+#: builtin/rm.c:226
 msgid "the following file has local modifications:"
 msgid_plural "the following files have local modifications:"
 msgstr[0] "följande fil har lokala ändringar:"
 msgstr[1] "följande filer har lokala ändringar:"
 
-#: builtin/rm.c:241
+#: builtin/rm.c:242
 msgid "do not list removed files"
 msgstr "lista inte borttagna filer"
 
-#: builtin/rm.c:242
+#: builtin/rm.c:243
 msgid "only remove from the index"
 msgstr "ta bara bort från indexet"
 
-#: builtin/rm.c:243
+#: builtin/rm.c:244
 msgid "override the up-to-date check"
 msgstr "överstyr àjour-testet"
 
-#: builtin/rm.c:244
+#: builtin/rm.c:245
 msgid "allow recursive removal"
 msgstr "tillåt rekursiv borttagning"
 
-#: builtin/rm.c:246
+#: builtin/rm.c:247
 msgid "exit with a zero status even if nothing matched"
 msgstr "avsluta med nollstatus även om inget träffades"
 
-#: builtin/rm.c:306
+#: builtin/rm.c:289
+msgid "please stage your changes to .gitmodules or stash them to proceed"
+msgstr ""
+"löa dina ändringar i .gitmodules eller använd \"stash\" för att fortsätta"
+
+#: builtin/rm.c:307
 #, c-format
 msgid "not removing '%s' recursively without -r"
 msgstr "tar inte bort \"%s\" rekursivt utan -r"
 
-#: builtin/rm.c:345
+#: builtin/rm.c:346
 #, c-format
 msgid "git rm: unable to remove %s"
 msgstr "git rm: kan inte ta bort %s"
 
-#: builtin/rm.c:368
-#, c-format
-msgid "could not remove '%s'"
-msgstr "kunde inte ta bort \"%s\""
-
 #: builtin/send-pack.c:20
 msgid ""
 "git send-pack [--all | --mirror] [--dry-run] [--force] [--receive-pack=<git-"
@@ -13857,18 +19656,6 @@ msgstr "läs referenser från standard i
 msgid "print status from remote helper"
 msgstr "visa status från fjärrhjälpare"
 
-#: builtin/serve.c:7
-msgid "git serve [<options>]"
-msgstr "git serve [<flaggor>]"
-
-#: builtin/serve.c:17 builtin/upload-pack.c:23
-msgid "quit after a single request/response exchange"
-msgstr "avsluta omedelbart efter första anrop/svar-utväxling"
-
-#: builtin/serve.c:19
-msgid "exit immediately after advertising capabilities"
-msgstr "avsluta omedelbart efter kungörelse av kapabiliteter"
-
 #: builtin/shortlog.c:14
 msgid "git shortlog [<options>] [<revision-range>] [[--] <path>...]"
 msgstr "git shortlog [<flaggor>] [<versionsintervall>] [[--] <sökväg>...]"
@@ -13894,18 +19681,18 @@ msgid "Show the email address of each au
 msgstr "Visa e-postadress för varje författare"
 
 #: builtin/shortlog.c:271
-msgid "w[,i1[,i2]]"
-msgstr "w[,i1[,i2]]"
+msgid "<w>[,<i1>[,<i2>]]"
+msgstr "<w>[,<i1>[,<i2>]]"
 
 #: builtin/shortlog.c:272
 msgid "Linewrap output"
 msgstr "Radbryt utdata"
 
-#: builtin/shortlog.c:298
+#: builtin/shortlog.c:301
 msgid "too many arguments given outside repository"
 msgstr "för många flaggor givna utanför arkivet"
 
-#: builtin/show-branch.c:12
+#: builtin/show-branch.c:13
 msgid ""
 "git show-branch [-a | --all] [-r | --remotes] [--topo-order | --date-order]\n"
 "\t\t[--current] [--color[=<when>] | --no-color] [--sparse]\n"
@@ -13917,131 +19704,131 @@ msgstr ""
 "\t\t[--more=<n> | --list | --independent | --merge-base]\n"
 "\t\t[--no-name | --sha1-name] [--topics] [(<rev> | <mönster>)...]"
 
-#: builtin/show-branch.c:16
+#: builtin/show-branch.c:17
 msgid "git show-branch (-g | --reflog)[=<n>[,<base>]] [--list] [<ref>]"
 msgstr "git show-branch (-g | --reflog)[=<n>[,<bas>]] [--list] [<ref>]"
 
-#: builtin/show-branch.c:376
+#: builtin/show-branch.c:395
 #, c-format
 msgid "ignoring %s; cannot handle more than %d ref"
 msgid_plural "ignoring %s; cannot handle more than %d refs"
 msgstr[0] "ignorerar %s; kan inte hantera mer än %d referens"
 msgstr[1] "ignorerar %s; kan inte hantera mer än %d referenser"
 
-#: builtin/show-branch.c:530
+#: builtin/show-branch.c:548
 #, c-format
 msgid "no matching refs with %s"
 msgstr "inga motsvarande referenser med %s"
 
-#: builtin/show-branch.c:626
+#: builtin/show-branch.c:645
 msgid "show remote-tracking and local branches"
 msgstr "visa fjärrspårande och lokala grenar"
 
-#: builtin/show-branch.c:628
+#: builtin/show-branch.c:647
 msgid "show remote-tracking branches"
 msgstr "visa fjärrspårande grenar"
 
-#: builtin/show-branch.c:630
+#: builtin/show-branch.c:649
 msgid "color '*!+-' corresponding to the branch"
 msgstr "färga \"*!+-\" enligt grenen"
 
-#: builtin/show-branch.c:632
+#: builtin/show-branch.c:651
 msgid "show <n> more commits after the common ancestor"
 msgstr "visa <n> ytterligare incheckningar efter gemensam anfader"
 
-#: builtin/show-branch.c:634
+#: builtin/show-branch.c:653
 msgid "synonym to more=-1"
 msgstr "synonym till more=-1"
 
-#: builtin/show-branch.c:635
+#: builtin/show-branch.c:654
 msgid "suppress naming strings"
 msgstr "undertyck namnsträngar"
 
-#: builtin/show-branch.c:637
+#: builtin/show-branch.c:656
 msgid "include the current branch"
 msgstr "inkludera aktuell gren"
 
-#: builtin/show-branch.c:639
+#: builtin/show-branch.c:658
 msgid "name commits with their object names"
 msgstr "namnge incheckningar med deras objektnamn"
 
-#: builtin/show-branch.c:641
+#: builtin/show-branch.c:660
 msgid "show possible merge bases"
 msgstr "visa möjliga sammanslagningsbaser"
 
-#: builtin/show-branch.c:643
+#: builtin/show-branch.c:662
 msgid "show refs unreachable from any other ref"
 msgstr "visa referenser som inte kan nås från någon annan referens"
 
-#: builtin/show-branch.c:645
+#: builtin/show-branch.c:664
 msgid "show commits in topological order"
 msgstr "visa incheckningar i topologisk ordning"
 
-#: builtin/show-branch.c:648
+#: builtin/show-branch.c:667
 msgid "show only commits not on the first branch"
 msgstr "visa endast incheckningar inte på den första grenen"
 
-#: builtin/show-branch.c:650
+#: builtin/show-branch.c:669
 msgid "show merges reachable from only one tip"
 msgstr "visa sammanslagningar som endast kan nås från en spets"
 
-#: builtin/show-branch.c:652
+#: builtin/show-branch.c:671
 msgid "topologically sort, maintaining date order where possible"
 msgstr "sortera topologiskt, behåll datumordning när möjligt"
 
-#: builtin/show-branch.c:655
+#: builtin/show-branch.c:674
 msgid "<n>[,<base>]"
 msgstr "<n>[,<bas>]"
 
-#: builtin/show-branch.c:656
+#: builtin/show-branch.c:675
 msgid "show <n> most recent ref-log entries starting at base"
 msgstr "visa <n> nyaste refloggposter med början på bas"
 
-#: builtin/show-branch.c:690
+#: builtin/show-branch.c:711
 msgid ""
 "--reflog is incompatible with --all, --remotes, --independent or --merge-base"
 msgstr ""
 "--reflog är inkompatibel med --all, --remotes, --independent eller --merge-"
 "base"
 
-#: builtin/show-branch.c:714
+#: builtin/show-branch.c:735
 msgid "no branches given, and HEAD is not valid"
 msgstr "inga grenar angavs, och HEAD är inte giltigt"
 
-#: builtin/show-branch.c:717
+#: builtin/show-branch.c:738
 msgid "--reflog option needs one branch name"
 msgstr "--reflog behöver ett namn på en gren"
 
-#: builtin/show-branch.c:720
+#: builtin/show-branch.c:741
 #, c-format
 msgid "only %d entry can be shown at one time."
 msgid_plural "only %d entries can be shown at one time."
 msgstr[0] "maximalt %d poster kan visas samtidigt."
 msgstr[1] "maximalt %d poster kan visas samtidigt."
 
-#: builtin/show-branch.c:724
+#: builtin/show-branch.c:745
 #, c-format
 msgid "no such ref %s"
 msgstr "ingen sådan referens %s"
 
-#: builtin/show-branch.c:808
+#: builtin/show-branch.c:831
 #, c-format
 msgid "cannot handle more than %d rev."
 msgid_plural "cannot handle more than %d revs."
 msgstr[0] "kan inte hantera mer än %d revision."
 msgstr[1] "kan inte hantera mer än %d revisioner."
 
-#: builtin/show-branch.c:812
+#: builtin/show-branch.c:835
 #, c-format
 msgid "'%s' is not a valid ref."
 msgstr "\"%s\" är inte en giltig referens."
 
-#: builtin/show-branch.c:815
+#: builtin/show-branch.c:838
 #, c-format
 msgid "cannot find commit %s (%s)"
 msgstr "hittar inte incheckning %s (%s)"
 
-#: builtin/show-ref.c:10
+#: builtin/show-ref.c:12
 msgid ""
 "git show-ref [-q | --quiet] [--verify] [--head] [-d | --dereference] [-s | --"
 "hash[=<n>]] [--abbrev[=<n>]] [--tags] [--heads] [--] [<pattern>...]"
@@ -14049,41 +19836,317 @@ msgstr ""
 "git show-ref [-q | --quiet] [--verify] [--head] [-d | --dereference] [-s | --"
 "hash[=<n>]] [--abbrev[=<n>]] [--tags] [--heads] [--] [<mönster>...]"
 
-#: builtin/show-ref.c:11
+#: builtin/show-ref.c:13
 msgid "git show-ref --exclude-existing[=<pattern>]"
 msgstr "git show-ref --exclude-existing[=<mönster>]"
 
-#: builtin/show-ref.c:159
-msgid "only show tags (can be combined with heads)"
-msgstr "visa endast taggar (kan kombineras med huvuden)"
+#: builtin/show-ref.c:162
+msgid "only show tags (can be combined with heads)"
+msgstr "visa endast taggar (kan kombineras med huvuden)"
+
+#: builtin/show-ref.c:163
+msgid "only show heads (can be combined with tags)"
+msgstr "visa endast huvuden (kan kombineras med taggar)"
+
+#: builtin/show-ref.c:164
+msgid "stricter reference checking, requires exact ref path"
+msgstr "striktare referenskontroll, kräver exakt referenssökväg"
+
+#: builtin/show-ref.c:167 builtin/show-ref.c:169
+msgid "show the HEAD reference, even if it would be filtered out"
+msgstr "visa HEAD-refrens, även när den skulle filtreras ut"
+
+#: builtin/show-ref.c:171
+msgid "dereference tags into object IDs"
+msgstr "avreferera taggar till objekt-id"
+
+#: builtin/show-ref.c:173
+msgid "only show SHA1 hash using <n> digits"
+msgstr "visa SHA1-hash endast med <n> siffror"
+
+#: builtin/show-ref.c:177
+msgid "do not print results to stdout (useful with --verify)"
+msgstr "visa inte resultat på standard ut (användbart med --verify)"
+
+#: builtin/show-ref.c:179
+msgid "show refs from stdin that aren't in local repository"
+msgstr "visa referenser från standard in som inte finns i lokalt arkiv"
+
+#: builtin/sparse-checkout.c:20
+msgid "git sparse-checkout (init|list|set|disable) <options>"
+msgstr "git sparse-checkout (init|list|set|disable) <flaggor>"
+
+#: builtin/sparse-checkout.c:61
+msgid "this worktree is not sparse (sparse-checkout file may not exist)"
+msgstr ""
+"arbetskatalogen är inte glest (sparse-checkout-filen kanske inte finns)"
+
+#: builtin/sparse-checkout.c:220
+msgid "failed to set extensions.worktreeConfig setting"
+msgstr "misslyckades ändra inställningen extensions.worktreeConfig"
+
+#: builtin/sparse-checkout.c:237
+msgid "git sparse-checkout init [--cone]"
+msgstr "git sparse-checkout init [--cone]"
+
+#: builtin/sparse-checkout.c:256
+msgid "initialize the sparse-checkout in cone mode"
+msgstr "initiera sparse-checkout i konläge"
+
+#: builtin/sparse-checkout.c:262
+msgid "initialize sparse-checkout"
+msgstr "initiera sparse-checkout"
+
+#: builtin/sparse-checkout.c:295
+#, c-format
+msgid "failed to open '%s'"
+msgstr "misslyckades öppna \"%s\""
+
+#: builtin/sparse-checkout.c:361
+msgid "git sparse-checkout set (--stdin | <patterns>)"
+msgstr "git sparse-checkout set (--stdin | <mönster>)"
+
+#: builtin/sparse-checkout.c:378
+msgid "read patterns from standard in"
+msgstr "läs mönster från standard in"
+
+#: builtin/sparse-checkout.c:384
+msgid "set sparse-checkout patterns"
+msgstr "ställ in filter för gles utcheckning"
+
+#: builtin/sparse-checkout.c:447
+msgid "disable sparse-checkout"
+msgstr "inaktivera gles utcheckning"
+
+#: builtin/sparse-checkout.c:459
+msgid "error while refreshing working directory"
+msgstr "fel vid uppdatering av arbetskatalog"
+
+#: builtin/stash.c:22 builtin/stash.c:37
+msgid "git stash list [<options>]"
+msgstr "git stash list [<flaggor>]"
+
+#: builtin/stash.c:23 builtin/stash.c:42
+msgid "git stash show [<options>] [<stash>]"
+msgstr "git stash show [<flaggor>] [<stash>]"
+
+#: builtin/stash.c:24 builtin/stash.c:47
+msgid "git stash drop [-q|--quiet] [<stash>]"
+msgstr "git stash drop [-q|--quiet] [<stash>]"
+
+#: builtin/stash.c:25
+msgid "git stash ( pop | apply ) [--index] [-q|--quiet] [<stash>]"
+msgstr "git stash ( pop | apply ) [--index] [-q|--quiet] [<stash>]"
+
+#: builtin/stash.c:26 builtin/stash.c:62
+msgid "git stash branch <branchname> [<stash>]"
+msgstr "git stash branch <grennamn> [<stash>]"
+
+#: builtin/stash.c:27 builtin/stash.c:67
+msgid "git stash clear"
+msgstr "git stash clear"
+
+#: builtin/stash.c:28 builtin/stash.c:77
+msgid ""
+"git stash [push [-p|--patch] [-k|--[no-]keep-index] [-q|--quiet]\n"
+"          [-u|--include-untracked] [-a|--all] [-m|--message <message>]\n"
+"          [--] [<pathspec>...]]"
+msgstr ""
+"git stash [push [-p|--patch] [-k|--[no-]keep-index] [-q|--quiet]\n"
+"          [-u|--include-untracked] [-a|--all] [-m|--message <meddelande>]\n"
+"          [--] [<sökväg>...]]"
+
+#: builtin/stash.c:31 builtin/stash.c:84
+msgid ""
+"git stash save [-p|--patch] [-k|--[no-]keep-index] [-q|--quiet]\n"
+"          [-u|--include-untracked] [-a|--all] [<message>]"
+msgstr ""
+"git stash save [-p|--patch] [-k|--[no-]keep-index] [-q|--quiet]\n"
+"          [-u|--include-untracked] [-a|--all] [<meddelande>]"
+
+#: builtin/stash.c:52
+msgid "git stash pop [--index] [-q|--quiet] [<stash>]"
+msgstr "git stash pop [--index] [-q|--quiet] [<stash>]"
+
+#: builtin/stash.c:57
+msgid "git stash apply [--index] [-q|--quiet] [<stash>]"
+msgstr "git stash apply [--index] [-q|--quiet] [<stash>]"
+
+#: builtin/stash.c:72
+msgid "git stash store [-m|--message <message>] [-q|--quiet] <commit>"
+msgstr "git stash store [-m|--message <meddelande>] [-q|--quiet] <incheckning>"
+
+#: builtin/stash.c:127
+#, c-format
+msgid "'%s' is not a stash-like commit"
+msgstr "\"%s\" är inte en \"stash\"-liknande incheckning"
+
+#: builtin/stash.c:147
+#, c-format
+msgid "Too many revisions specified:%s"
+msgstr "För många revisioner angivna:%s"
+
+#: builtin/stash.c:161 git-legacy-stash.sh:549
+msgid "No stash entries found."
+msgstr "Inga \"stash\"-poster hittades."
+
+#: builtin/stash.c:175
+#, c-format
+msgid "%s is not a valid reference"
+msgstr "%s är inte en giltigt referens"
+
+#: builtin/stash.c:224 git-legacy-stash.sh:75
+msgid "git stash clear with parameters is unimplemented"
+msgstr "\"git stash clear\" med parametrar har inte implementerats"
+
+#: builtin/stash.c:403
+msgid "cannot apply a stash in the middle of a merge"
+msgstr "kan inte tillämpa en \"stash\" mitt i en sammanslagning"
+
+#: builtin/stash.c:414
+#, c-format
+msgid "could not generate diff %s^!."
+msgstr "kunde inte skapa diff %s^!."
+
+#: builtin/stash.c:421
+msgid "conflicts in index.Try without --index."
+msgstr "konflikter i indexet. Testa utan --index."
+
+#: builtin/stash.c:427
+msgid "could not save index tree"
+msgstr "kunde inte spara indexträd"
+
+#: builtin/stash.c:436
+msgid "could not restore untracked files from stash"
+msgstr "kunde inte återställa ospårade filer från stash-post"
+
+#: builtin/stash.c:450
+#, c-format
+msgid "Merging %s with %s"
+msgstr "Slår ihop %s med %s"
+
+#: builtin/stash.c:460 git-legacy-stash.sh:681
+msgid "Index was not unstashed."
+msgstr "Indexet har inte tagits upp ur \"stash\":en"
+
+#: builtin/stash.c:521 builtin/stash.c:620
+msgid "attempt to recreate the index"
+msgstr "försök återskapa indexet"
+
+#: builtin/stash.c:554
+#, c-format
+msgid "Dropped %s (%s)"
+msgstr "Kastade %s (%s)"
+
+#: builtin/stash.c:557
+#, c-format
+msgid "%s: Could not drop stash entry"
+msgstr "%s: Kunde inte kasta \"stash\"-post"
+
+#: builtin/stash.c:582
+#, c-format
+msgid "'%s' is not a stash reference"
+msgstr "\"%s\" är inte en \"stash\"-referens"
+
+#: builtin/stash.c:632 git-legacy-stash.sh:695
+msgid "The stash entry is kept in case you need it again."
+msgstr "Stash-posten behålls ifall du behöver den igen."
+
+#: builtin/stash.c:655 git-legacy-stash.sh:713
+msgid "No branch name specified"
+msgstr "Inget grennamn angavs"
+
+#: builtin/stash.c:795 builtin/stash.c:832
+#, c-format
+msgid "Cannot update %s with %s"
+msgstr "Kan inte uppdatera %s med %s"
+
+#: builtin/stash.c:813 builtin/stash.c:1470 builtin/stash.c:1506
+msgid "stash message"
+msgstr "\"stash\"-meddelande"
+
+#: builtin/stash.c:823
+msgid "\"git stash store\" requires one <commit> argument"
+msgstr "\"git stash store\" kräver ett <incheckning>-argument"
+
+#: builtin/stash.c:1045 git-legacy-stash.sh:218
+msgid "No changes selected"
+msgstr "Inga ändringar valda"
+
+#: builtin/stash.c:1145 git-legacy-stash.sh:150
+msgid "You do not have the initial commit yet"
+msgstr "Du har inte den första incheckningen ännu"
+
+#: builtin/stash.c:1172 git-legacy-stash.sh:165
+msgid "Cannot save the current index state"
+msgstr "Kan inte spara aktuellt tillstånd för indexet"
+
+#: builtin/stash.c:1181 git-legacy-stash.sh:180
+msgid "Cannot save the untracked files"
+msgstr "Kan inte spara ospårade filer"
+
+#: builtin/stash.c:1192 builtin/stash.c:1201 git-legacy-stash.sh:201
+#: git-legacy-stash.sh:214
+msgid "Cannot save the current worktree state"
+msgstr "Kan inte spara aktuellt tillstånd för arbetskatalogen"
+
+#: builtin/stash.c:1229 git-legacy-stash.sh:234
+msgid "Cannot record working tree state"
+msgstr "Kan inte registrera tillstånd för arbetskatalog"
+
+#: builtin/stash.c:1278 git-legacy-stash.sh:338
+msgid "Can't use --patch and --include-untracked or --all at the same time"
+msgstr "Kan inte använda --patch och --include-untracked eller --all samtidigt"
+
+#: builtin/stash.c:1294
+msgid "Did you forget to 'git add'?"
+msgstr "Glömde du använda \"git add\"?"
 
-#: builtin/show-ref.c:160
-msgid "only show heads (can be combined with tags)"
-msgstr "visa endast huvuden (kan kombineras med taggar)"
+#: builtin/stash.c:1309 git-legacy-stash.sh:346
+msgid "No local changes to save"
+msgstr "Inga lokala ändringar att spara"
 
-#: builtin/show-ref.c:161
-msgid "stricter reference checking, requires exact ref path"
-msgstr "striktare referenskontroll, kräver exakt referenssökväg"
+#: builtin/stash.c:1316 git-legacy-stash.sh:351
+msgid "Cannot initialize stash"
+msgstr "Kan inte initiera \"stash\""
 
-#: builtin/show-ref.c:164 builtin/show-ref.c:166
-msgid "show the HEAD reference, even if it would be filtered out"
-msgstr "visa HEAD-refrens, även när den skulle filtreras ut"
+#: builtin/stash.c:1331 git-legacy-stash.sh:355
+msgid "Cannot save the current status"
+msgstr "Kan inte spara aktuell status"
 
-#: builtin/show-ref.c:168
-msgid "dereference tags into object IDs"
-msgstr "avreferera taggar till objekt-id"
+#: builtin/stash.c:1336
+#, c-format
+msgid "Saved working directory and index state %s"
+msgstr "Sparade arbetskatalogen och indexstatus %s"
 
-#: builtin/show-ref.c:170
-msgid "only show SHA1 hash using <n> digits"
-msgstr "visa SHA1-hash endast med <n> siffror"
+#: builtin/stash.c:1426 git-legacy-stash.sh:385
+msgid "Cannot remove worktree changes"
+msgstr "Kan inte ta bort ändringar i arbetskatalogen"
 
-#: builtin/show-ref.c:174
-msgid "do not print results to stdout (useful with --verify)"
-msgstr "visa inte resultat på standard ut (användbart med --verify)"
+#: builtin/stash.c:1461 builtin/stash.c:1497
+msgid "keep index"
+msgstr "behåll indexet"
+
+#: builtin/stash.c:1463 builtin/stash.c:1499
+msgid "stash in patch mode"
+msgstr "\"stash\" i \"patch\"-läge"
+
+#: builtin/stash.c:1464 builtin/stash.c:1500
+msgid "quiet mode"
+msgstr "tyst läge"
+
+#: builtin/stash.c:1466 builtin/stash.c:1502
+msgid "include untracked files in stash"
+msgstr "ta med ospårade filer i \"stash\""
+
+#: builtin/stash.c:1468 builtin/stash.c:1504
+msgid "include ignore files"
+msgstr "ta med ignorerade filer"
 
-#: builtin/show-ref.c:176
-msgid "show refs from stdin that aren't in local repository"
-msgstr "visa referenser från standard in som inte finns i lokalt arkiv"
+#: builtin/stash.c:1564
+#, c-format
+msgid "could not exec %s"
+msgstr "kunde inte köra %s"
 
 #: builtin/stripspace.c:18
 msgid "git stripspace [-s | --strip-comments]"
@@ -14093,103 +20156,136 @@ msgstr "git stripspace [-s | --strip-com
 msgid "git stripspace [-c | --comment-lines]"
 msgstr "git stripspace [-c | --comment-lines]"
 
-#: builtin/stripspace.c:36
+#: builtin/stripspace.c:37
 msgid "skip and remove all lines starting with comment character"
 msgstr "hoppa över och ta bort alla rader som inleds med kommentarstecken"
 
-#: builtin/stripspace.c:39
+#: builtin/stripspace.c:40
 msgid "prepend comment character and space to each line"
 msgstr "lägg in kommentarstecken och blanksteg först på varje rad"
 
-#: builtin/submodule--helper.c:37 builtin/submodule--helper.c:1688
-#, c-format
-msgid "No such ref: %s"
-msgstr "Ingen sådan referens: %s"
-
-#: builtin/submodule--helper.c:44 builtin/submodule--helper.c:1697
+#: builtin/submodule--helper.c:47 builtin/submodule--helper.c:1970
 #, c-format
 msgid "Expecting a full ref name, got %s"
 msgstr "Förväntade fullt referensnamn, fick %s"
 
-#: builtin/submodule--helper.c:61
+#: builtin/submodule--helper.c:64
 msgid "submodule--helper print-default-remote takes no arguments"
 msgstr "submodule--helper print-default-remote tar inga argument"
 
-#: builtin/submodule--helper.c:98
+#: builtin/submodule--helper.c:102
 #, c-format
 msgid "cannot strip one component off url '%s'"
 msgstr "kan inte ta bort en komponent från url:en \"%s\""
 
-#: builtin/submodule--helper.c:406 builtin/submodule--helper.c:1211
+#: builtin/submodule--helper.c:410 builtin/submodule--helper.c:1380
 msgid "alternative anchor for relative paths"
 msgstr "alternativa ankare för relativa sökvägar"
 
-#: builtin/submodule--helper.c:411
+#: builtin/submodule--helper.c:415
 msgid "git submodule--helper list [--prefix=<path>] [<path>...]"
 msgstr "git submodule--helper list [--prefix=<sökväg>] [<sökväg>...]"
 
-#: builtin/submodule--helper.c:462 builtin/submodule--helper.c:485
+#: builtin/submodule--helper.c:472 builtin/submodule--helper.c:630
+#: builtin/submodule--helper.c:653
 #, c-format
 msgid "No url found for submodule path '%s' in .gitmodules"
 msgstr "Hittade ingen url för undermodulsökvägen \"%s\" i .gitmodules"
 
-#: builtin/submodule--helper.c:500
+#: builtin/submodule--helper.c:524
+#, c-format
+msgid "Entering '%s'\n"
+msgstr "Går in i \"%s\"\n"
+
+#: builtin/submodule--helper.c:527
+#, c-format
+msgid ""
+"run_command returned non-zero status for %s\n"
+"."
+msgstr ""
+"run_command returnerade icke-nollstatus för %s\n"
+"."
+
+#: builtin/submodule--helper.c:549
+#, c-format
+msgid ""
+"run_command returned non-zero status while recursing in the nested "
+"submodules of %s\n"
+"."
+msgstr ""
+"run_command returnerade icke-nollstatus vid rekursering in i nästlade "
+"undermoduler för %s\n"
+"."
+
+#: builtin/submodule--helper.c:565
+msgid "Suppress output of entering each submodule command"
+msgstr "Dölj utdata från för varje undermodulskommando som startas"
+
+#: builtin/submodule--helper.c:567 builtin/submodule--helper.c:1053
+msgid "Recurse into nested submodules"
+msgstr "Rekursera in i nästlade undermoduler"
+
+#: builtin/submodule--helper.c:572
+msgid "git submodule--helper foreach [--quiet] [--recursive] [--] <command>"
+msgstr "git submodule--helper sync [--quiet] [--recursive] [--] [<kommando>]"
+
+#: builtin/submodule--helper.c:599
 #, c-format
 msgid ""
-"could not lookup configuration '%s'. Assuming this repository is its own "
+"could not look up configuration '%s'. Assuming this repository is its own "
 "authoritative upstream."
 msgstr ""
-"kunde inte slå upp konfigurationen \"%s\". Antar att arkivet är sn eget "
+"kunde inte slå upp konfigurationen \"%s\". Antar att arkivet är sin eget "
 "officiella uppström."
 
-#: builtin/submodule--helper.c:511
+#: builtin/submodule--helper.c:667
 #, c-format
 msgid "Failed to register url for submodule path '%s'"
 msgstr "Misslyckades registrera url för undermodulsökväg \"%s\""
 
-#: builtin/submodule--helper.c:515
+#: builtin/submodule--helper.c:671
 #, c-format
 msgid "Submodule '%s' (%s) registered for path '%s'\n"
 msgstr "Undermodulen \"%s\" (%s) registrerad för sökvägen \"%s\"\n"
 
-#: builtin/submodule--helper.c:525
+#: builtin/submodule--helper.c:681
 #, c-format
 msgid "warning: command update mode suggested for submodule '%s'\n"
 msgstr "varning: kommandouppdateringsläge föreslogs för undermodulen \"%s\"\n"
 
-#: builtin/submodule--helper.c:532
+#: builtin/submodule--helper.c:688
 #, c-format
 msgid "Failed to register update mode for submodule path '%s'"
 msgstr "Misslyckades registrera uppdateringsläge för undermodulsökväg \"%s\""
 
-#: builtin/submodule--helper.c:554
+#: builtin/submodule--helper.c:710
 msgid "Suppress output for initializing a submodule"
 msgstr "Dölj utdata från initiering av undermodul"
 
-#: builtin/submodule--helper.c:559
-msgid "git submodule--helper init [<path>]"
-msgstr "git submodule--helper init [<sökväg>]"
+#: builtin/submodule--helper.c:715
+msgid "git submodule--helper init [<options>] [<path>]"
+msgstr "git submodule--helper init [<flaggor>] [<sökväg>]"
 
-#: builtin/submodule--helper.c:631 builtin/submodule--helper.c:757
+#: builtin/submodule--helper.c:787 builtin/submodule--helper.c:914
 #, c-format
 msgid "no submodule mapping found in .gitmodules for path '%s'"
 msgstr "hittade ingen undermodulmappning i .gitmodules för sökvägen \"%s\""
 
-#: builtin/submodule--helper.c:670
+#: builtin/submodule--helper.c:827
 #, c-format
 msgid "could not resolve HEAD ref inside the submodule '%s'"
 msgstr "kunde inte bestämma HEAD:s incheckning i undermodulen \"%s\""
 
-#: builtin/submodule--helper.c:697 builtin/submodule--helper.c:866
+#: builtin/submodule--helper.c:854 builtin/submodule--helper.c:1023
 #, c-format
 msgid "failed to recurse into submodule '%s'"
 msgstr "misslyckades rekursera in i undermodulen \"%s\""
 
-#: builtin/submodule--helper.c:721 builtin/submodule--helper.c:1031
+#: builtin/submodule--helper.c:878 builtin/submodule--helper.c:1189
 msgid "Suppress submodule status output"
 msgstr "Hindra statusutskrift för undermodul"
 
-#: builtin/submodule--helper.c:722
+#: builtin/submodule--helper.c:879
 msgid ""
 "Use commit stored in the index instead of the one stored in the submodule "
 "HEAD"
@@ -14197,51 +20293,47 @@ msgstr ""
 "Visa incheckning från indexet istället för den som lagrats i undermodulens "
 "HEAD"
 
-#: builtin/submodule--helper.c:723
+#: builtin/submodule--helper.c:880
 msgid "recurse into nested submodules"
 msgstr "rekursera in i nästlade undermoduler"
 
-#: builtin/submodule--helper.c:728
+#: builtin/submodule--helper.c:885
 msgid "git submodule status [--quiet] [--cached] [--recursive] [<path>...]"
 msgstr "git submodule status [--quitet] [--cached] [--recursive] [<sökväg>...]"
 
-#: builtin/submodule--helper.c:752
+#: builtin/submodule--helper.c:909
 msgid "git submodule--helper name <path>"
 msgstr "git submodule--helper name <sökväg>"
 
-#: builtin/submodule--helper.c:816
+#: builtin/submodule--helper.c:973
 #, c-format
 msgid "Synchronizing submodule url for '%s'\n"
 msgstr "Synkroniserar undermodul-url för \"%s\"\n"
 
-#: builtin/submodule--helper.c:822
+#: builtin/submodule--helper.c:979
 #, c-format
 msgid "failed to register url for submodule path '%s'"
 msgstr "misslyckades registrera url för undermodulsökväg \"%s\""
 
-#: builtin/submodule--helper.c:836
+#: builtin/submodule--helper.c:993
 #, c-format
 msgid "failed to get the default remote for submodule '%s'"
 msgstr "misslyckades hämta standardfjärr för undermodulsökväg \"%s\""
 
-#: builtin/submodule--helper.c:847
+#: builtin/submodule--helper.c:1004
 #, c-format
 msgid "failed to update remote for submodule '%s'"
 msgstr "misslyckades uppdatera fjärr för undermodulsökväg \"%s\""
 
-#: builtin/submodule--helper.c:895
+#: builtin/submodule--helper.c:1051
 msgid "Suppress output of synchronizing submodule url"
 msgstr "Dölj utdata från synkroniering av undermodul-url"
 
-#: builtin/submodule--helper.c:897
-msgid "Recurse into nested submodules"
-msgstr "Rekursera in i nästlade undermoduler"
-
-#: builtin/submodule--helper.c:902
+#: builtin/submodule--helper.c:1058
 msgid "git submodule--helper sync [--quiet] [--recursive] [<path>]"
 msgstr "git submodule--helper sync [--quiet] [--recursive] [<sökväg>]"
 
-#: builtin/submodule--helper.c:956
+#: builtin/submodule--helper.c:1112
 #, c-format
 msgid ""
 "Submodule work tree '%s' contains a .git directory (use 'rm -rf' if you "
@@ -14250,7 +20342,7 @@ msgstr ""
 "Undermodulsarbetskatalogen \"%s\" innehåller en .git-katalog (använd \"rm -rf"
 "\" om du verkligen vill ta bort den och all dess historik)"
 
-#: builtin/submodule--helper.c:968
+#: builtin/submodule--helper.c:1124
 #, c-format
 msgid ""
 "Submodule work tree '%s' contains local modifications; use '-f' to discard "
@@ -14259,81 +20351,97 @@ msgstr ""
 "Undermodulens arbetskatalog \"%s\" har lokala ändringar; \"-f\" kastar bort "
 "dem"
 
-#: builtin/submodule--helper.c:976
+#: builtin/submodule--helper.c:1132
 #, c-format
 msgid "Cleared directory '%s'\n"
 msgstr "Rensade katalogen \"%s\"\n"
 
-#: builtin/submodule--helper.c:978
+#: builtin/submodule--helper.c:1134
 #, c-format
 msgid "Could not remove submodule work tree '%s'\n"
 msgstr "Kunde inte ta bort undermodulens arbetskatalog \"%s\"\n"
 
-#: builtin/submodule--helper.c:987
+#: builtin/submodule--helper.c:1145
 #, c-format
 msgid "could not create empty submodule directory %s"
 msgstr "kunde inte skapa tom undermodulskatalog %s"
 
-#: builtin/submodule--helper.c:1003
+#: builtin/submodule--helper.c:1161
 #, c-format
 msgid "Submodule '%s' (%s) unregistered for path '%s'\n"
 msgstr "Undermodulen \"%s\" (%s) registrerad för sökvägen \"%s\"\n"
 
-#: builtin/submodule--helper.c:1032
+#: builtin/submodule--helper.c:1190
 msgid "Remove submodule working trees even if they contain local changes"
 msgstr ""
 "Ta bort undermodulers arbetskataloger även om de innehåller lokala ändringar"
 
-#: builtin/submodule--helper.c:1033
+#: builtin/submodule--helper.c:1191
 msgid "Unregister all submodules"
 msgstr "Avregistrera alla undermoduler"
 
-#: builtin/submodule--helper.c:1038
+#: builtin/submodule--helper.c:1196
 msgid ""
 "git submodule deinit [--quiet] [-f | --force] [--all | [--] [<path>...]]"
 msgstr ""
 "git submodule deinit [--quiet] [-f | --force] [--all | [--] [<sökväg>...]]"
 
-#: builtin/submodule--helper.c:1052
+#: builtin/submodule--helper.c:1210
 msgid "Use '--all' if you really want to deinitialize all submodules"
 msgstr "Använd \"--all\" om du verkligen vill avinitiera alla undermoduler"
 
-#: builtin/submodule--helper.c:1145 builtin/submodule--helper.c:1148
+#: builtin/submodule--helper.c:1275
+msgid ""
+"An alternate computed from a superproject's alternate is invalid.\n"
+"To allow Git to clone without an alternate in such a case, set\n"
+"submodule.alternateErrorStrategy to 'info' or, equivalently, clone with\n"
+"'--reference-if-able' instead of '--reference'."
+msgstr ""
+"En suppleant beräknad från överprojektets suppleant är ogiltig.\n"
+"För att i så fall låta Git klona utan ett suppleant, sätt\n"
+"submodule.alternateErrorStrategy till \"info\" eller, likvärdigt, klona\n"
+"med \"--reference-if-able\" istället för \"--reference\"."
+
+#: builtin/submodule--helper.c:1314 builtin/submodule--helper.c:1317
 #, c-format
 msgid "submodule '%s' cannot add alternate: %s"
-msgstr "undermodulen \"%s\" kan inte lägga till alternativ: %s"
+msgstr "undermodulen \"%s\" kan inte lägga till suppleant: %s"
 
-#: builtin/submodule--helper.c:1184
+#: builtin/submodule--helper.c:1353
 #, c-format
 msgid "Value '%s' for submodule.alternateErrorStrategy is not recognized"
 msgstr "Värdet \"%s\" i submodule.alternateErrorStrategy förstås inte"
 
-#: builtin/submodule--helper.c:1191
+#: builtin/submodule--helper.c:1360
 #, c-format
 msgid "Value '%s' for submodule.alternateLocation is not recognized"
 msgstr "Värdet \"%s\" i submodule.alternateLocation förstås inte"
 
-#: builtin/submodule--helper.c:1214
+#: builtin/submodule--helper.c:1383
 msgid "where the new submodule will be cloned to"
 msgstr "var den nya undermodulen skall klonas till"
 
-#: builtin/submodule--helper.c:1217
+#: builtin/submodule--helper.c:1386
 msgid "name of the new submodule"
 msgstr "namn på den nya undermodulen"
 
-#: builtin/submodule--helper.c:1220
+#: builtin/submodule--helper.c:1389
 msgid "url where to clone the submodule from"
 msgstr "URL att klona undermodulen från"
 
-#: builtin/submodule--helper.c:1228
+#: builtin/submodule--helper.c:1397
 msgid "depth for shallow clones"
 msgstr "djup för grunda kloner"
 
-#: builtin/submodule--helper.c:1231 builtin/submodule--helper.c:1606
+#: builtin/submodule--helper.c:1400 builtin/submodule--helper.c:1897
 msgid "force cloning progress"
 msgstr "tvinga kloningsförlopp"
 
-#: builtin/submodule--helper.c:1236
+#: builtin/submodule--helper.c:1402 builtin/submodule--helper.c:1899
+msgid "disallow cloning into non-empty directory"
+msgstr "förhindra kloning till icke-tom katalog"
+
+#: builtin/submodule--helper.c:1407
 msgid ""
 "git submodule--helper clone [--prefix=<path>] [--quiet] [--reference "
 "<repository>] [--name <name>] [--depth <depth>] --url <url> --path <path>"
@@ -14341,82 +20449,103 @@ msgstr ""
 "git submodule--helper clone [--prefix=<sökväg>] [--quiet] [--reference "
 "<arkvi>] [--name <namn>] [--depth <djup>] --url <url> --path <sökväg>"
 
-#: builtin/submodule--helper.c:1267
+#: builtin/submodule--helper.c:1431
+#, c-format
+msgid "refusing to create/use '%s' in another submodule's git dir"
+msgstr "vägrar skapa/använda \"%s\" i en annan undermoduls gitkatalog"
+
+#: builtin/submodule--helper.c:1442
 #, c-format
 msgid "clone of '%s' into submodule path '%s' failed"
-msgstr "misslyckades klona \"%s\" till undermodulsökvägen ”%s”"
+msgstr "misslyckades klona \"%s\" till undermodulsökvägen \"%s\""
 
-#: builtin/submodule--helper.c:1281
+#: builtin/submodule--helper.c:1446
+#, c-format
+msgid "directory not empty: '%s'"
+msgstr "katalogen inte tom: \"%s\""
+
+#: builtin/submodule--helper.c:1458
 #, c-format
 msgid "could not get submodule directory for '%s'"
 msgstr "kunde inte få tag i undermodulkatalog för \"%s\""
 
-#: builtin/submodule--helper.c:1347
+#: builtin/submodule--helper.c:1494
+#, c-format
+msgid "Invalid update mode '%s' for submodule path '%s'"
+msgstr "Ogiltigt uppdateringsläge \"%s\" för undermodulsökväg \"%s\""
+
+#: builtin/submodule--helper.c:1498
+#, c-format
+msgid "Invalid update mode '%s' configured for submodule path '%s'"
+msgstr ""
+"Ogiltigt uppdateringsläge \"%s\" konfigurerat för undermodulsökväg \"%s\""
+
+#: builtin/submodule--helper.c:1594
 #, c-format
 msgid "Submodule path '%s' not initialized"
 msgstr "Undermodulsökvägen \"%s\" har inte initierats"
 
-#: builtin/submodule--helper.c:1351
+#: builtin/submodule--helper.c:1598
 msgid "Maybe you want to use 'update --init'?"
 msgstr "Kanske menade du att använda \"update --init\"?"
 
-#: builtin/submodule--helper.c:1380
+#: builtin/submodule--helper.c:1628
 #, c-format
 msgid "Skipping unmerged submodule %s"
 msgstr "Hoppar över ej sammanslagen undermodul %s"
 
-#: builtin/submodule--helper.c:1409
+#: builtin/submodule--helper.c:1657
 #, c-format
 msgid "Skipping submodule '%s'"
 msgstr "Hoppar över undermodulen \"%s\""
 
-#: builtin/submodule--helper.c:1544
+#: builtin/submodule--helper.c:1803
 #, c-format
 msgid "Failed to clone '%s'. Retry scheduled"
 msgstr "Misslyckades klona \"%s\". Nytt försök planlagt"
 
-#: builtin/submodule--helper.c:1555
+#: builtin/submodule--helper.c:1814
 #, c-format
 msgid "Failed to clone '%s' a second time, aborting"
 msgstr "Misslyckades klona \"%s\" för andra gången, avbryter"
 
-#: builtin/submodule--helper.c:1585 builtin/submodule--helper.c:1808
+#: builtin/submodule--helper.c:1876 builtin/submodule--helper.c:2120
 msgid "path into the working tree"
 msgstr "sökväg inuti arbetskatalogen"
 
-#: builtin/submodule--helper.c:1588
+#: builtin/submodule--helper.c:1879
 msgid "path into the working tree, across nested submodule boundaries"
 msgstr "sökväg inuti arbetskatalogen, genom nästlade undermodulgränser"
 
-#: builtin/submodule--helper.c:1592
+#: builtin/submodule--helper.c:1883
 msgid "rebase, merge, checkout or none"
 msgstr "rebase, merge, checkout eller none"
 
-#: builtin/submodule--helper.c:1598
+#: builtin/submodule--helper.c:1889
 msgid "Create a shallow clone truncated to the specified number of revisions"
 msgstr "Skapa en grund klon trunkerad till angivet antal revisioner"
 
-#: builtin/submodule--helper.c:1601
+#: builtin/submodule--helper.c:1892
 msgid "parallel jobs"
 msgstr "parallella jobb"
 
-#: builtin/submodule--helper.c:1603
+#: builtin/submodule--helper.c:1894
 msgid "whether the initial clone should follow the shallow recommendation"
 msgstr "om den första klonen skall följa rekommendation för grund kloning"
 
-#: builtin/submodule--helper.c:1604
+#: builtin/submodule--helper.c:1895
 msgid "don't print cloning progress"
 msgstr "skriv inte klonförlopp"
 
-#: builtin/submodule--helper.c:1611
-msgid "git submodule--helper update_clone [--prefix=<path>] [<path>...]"
-msgstr "git submodule--helper update_clone [--prefix=<sökväg>] [<sökväg>...]"
+#: builtin/submodule--helper.c:1904
+msgid "git submodule--helper update-clone [--prefix=<path>] [<path>...]"
+msgstr "git submodule--helper update-clone [--prefix=<sökväg>] [<sökväg>...]"
 
-#: builtin/submodule--helper.c:1624
+#: builtin/submodule--helper.c:1917
 msgid "bad value for update parameter"
 msgstr "felaktigt värde för parametern update"
 
-#: builtin/submodule--helper.c:1692
+#: builtin/submodule--helper.c:1965
 #, c-format
 msgid ""
 "Submodule (%s) branch configured to inherit branch from superproject, but "
@@ -14425,20 +20554,50 @@ msgstr ""
 "Undermodulens (%s) gren inställd på att ärva gren från huvudprojektet, men "
 "huvudprojektet är inte på någon gren"
 
-#: builtin/submodule--helper.c:1809
+#: builtin/submodule--helper.c:2088
+#, c-format
+msgid "could not get a repository handle for submodule '%s'"
+msgstr "kunde inte få tag i arkivhandtag för undermodulen \"%s\""
+
+#: builtin/submodule--helper.c:2121
 msgid "recurse into submodules"
 msgstr "rekursera ner i undermoduler"
 
-#: builtin/submodule--helper.c:1815
-msgid "git submodule--helper embed-git-dir [<path>...]"
-msgstr "git submodule--helper embed-git-dir [<sökväg>...]"
+#: builtin/submodule--helper.c:2127
+msgid "git submodule--helper absorb-git-dirs [<options>] [<path>...]"
+msgstr "git submodule--helper absorb-git-dir [<flaggor>] [<sökväg>...]"
+
+#: builtin/submodule--helper.c:2183
+msgid "check if it is safe to write to the .gitmodules file"
+msgstr "se om det är säkert att skriva till .gitmodules-filen"
+
+#: builtin/submodule--helper.c:2186
+msgid "unset the config in the .gitmodules file"
+msgstr "ta bort konfigurationen från .gitmodules-filen"
+
+#: builtin/submodule--helper.c:2191
+msgid "git submodule--helper config <name> [<value>]"
+msgstr "git submodule--helper config <namn> [<värde>]"
+
+#: builtin/submodule--helper.c:2192
+msgid "git submodule--helper config --unset <name>"
+msgstr "git submodule--helper config --unset <namn>"
 
-#: builtin/submodule--helper.c:1901
+#: builtin/submodule--helper.c:2193
+msgid "git submodule--helper config --check-writeable"
+msgstr "git submodule--helper config --check-writeable"
+
+#: builtin/submodule--helper.c:2212 git-submodule.sh:173
+#, sh-format
+msgid "please make sure that the .gitmodules file is in the working tree"
+msgstr "se till att .gitmodules finns i arbetskatalogen"
+
+#: builtin/submodule--helper.c:2262 git.c:433 git.c:684
 #, c-format
 msgid "%s doesn't support --super-prefix"
 msgstr "%s stöder inte --super-prefix"
 
-#: builtin/submodule--helper.c:1907
+#: builtin/submodule--helper.c:2268
 #, c-format
 msgid "'%s' is not a valid submodule--helper subcommand"
 msgstr "\"%s\" är inte ett giltigt underkommando till submodule--helper"
@@ -14464,27 +20623,27 @@ msgstr "ta bort symbolisk referens"
 msgid "shorten ref output"
 msgstr "förkorta ref-utdata"
 
-#: builtin/symbolic-ref.c:43 builtin/update-ref.c:362
+#: builtin/symbolic-ref.c:43 builtin/update-ref.c:363
 msgid "reason"
 msgstr "skäl"
 
-#: builtin/symbolic-ref.c:43 builtin/update-ref.c:362
+#: builtin/symbolic-ref.c:43 builtin/update-ref.c:363
 msgid "reason of the update"
 msgstr "skäl till uppdateringen"
 
-#: builtin/tag.c:24
+#: builtin/tag.c:25
 msgid ""
-"git tag [-a | -s | -u <key-id>] [-f] [-m <msg> | -F <file>] <tagname> "
-"[<head>]"
+"git tag [-a | -s | -u <key-id>] [-f] [-m <msg> | -F <file>]\n"
+"\t\t<tagname> [<head>]"
 msgstr ""
-"git tag [-a | -s | -u <nyckel-id>] [-f] [-m <medd> | -F <fil>] <taggnamn> "
-"[<huvud>]"
+"git tag [-a | -s | -u <nyckel-id>] [-f] [-m <medd> | -F <fil>]\n"
+"\t\t<taggnamn> [<huvud>]"
 
-#: builtin/tag.c:25
+#: builtin/tag.c:27
 msgid "git tag -d <tagname>..."
 msgstr "git tag -d <taggnamn>..."
 
-#: builtin/tag.c:26
+#: builtin/tag.c:28
 msgid ""
 "git tag -l [-n[<num>]] [--contains <commit>] [--no-contains <commit>] [--"
 "points-at <object>]\n"
@@ -14494,21 +20653,21 @@ msgstr ""
 "<incheckning>] [--points-at <objekt>]\n"
 "\t\t[--format=<format>] [--[no-]merged [<incheckning>]] [<mönster>...]"
 
-#: builtin/tag.c:28
+#: builtin/tag.c:30
 msgid "git tag -v [--format=<format>] <tagname>..."
 msgstr "git tag -v [--format=<format>] <taggnamn>..."
 
-#: builtin/tag.c:86
+#: builtin/tag.c:89
 #, c-format
 msgid "tag '%s' not found."
 msgstr "taggen \"%s\" hittades inte."
 
-#: builtin/tag.c:102
+#: builtin/tag.c:105
 #, c-format
 msgid "Deleted tag '%s' (was %s)\n"
 msgstr "Tog bort tagg \"%s\" (var %s)\n"
 
-#: builtin/tag.c:132
+#: builtin/tag.c:135
 #, c-format
 msgid ""
 "\n"
@@ -14521,7 +20680,7 @@ msgstr ""
 "  %s\n"
 "Rader som inleds med \"%c\" ignoreras.\n"
 
-#: builtin/tag.c:136
+#: builtin/tag.c:139
 #, c-format
 msgid ""
 "\n"
@@ -14536,352 +20695,364 @@ msgstr ""
 "Rader som inleds med \"%c\" kommer behållas; du kan själv ta bort dem om\n"
 "du vill.\n"
 
-#: builtin/tag.c:190
+#: builtin/tag.c:198
 msgid "unable to sign the tag"
 msgstr "kunde inte signera taggen"
 
-#: builtin/tag.c:192
+#: builtin/tag.c:200
 msgid "unable to write tag file"
 msgstr "kunde inte skriva tagg-filen"
 
-#: builtin/tag.c:217
+#: builtin/tag.c:216
+#, c-format
+msgid ""
+"You have created a nested tag. The object referred to by your new tag is\n"
+"already a tag. If you meant to tag the object that it points to, use:\n"
+"\n"
+"\tgit tag -f %s %s^{}"
+msgstr ""
+"Du har skapat en nästlad tagg. Objektet som refereras av din nya tagg är\n"
+"redan en tagg. Om du skulle tagga objektet den pekar på, använd:\n"
+"\n"
+"\tgit tag -f %s %s^{}"
+
+#: builtin/tag.c:232
 msgid "bad object type."
 msgstr "felaktig objekttyp."
 
-#: builtin/tag.c:266
+#: builtin/tag.c:284
 msgid "no tag message?"
 msgstr "inget taggmeddelande?"
 
-#: builtin/tag.c:273
+#: builtin/tag.c:291
 #, c-format
 msgid "The tag message has been left in %s\n"
 msgstr "Taggmeddelandet har lämnats i %s\n"
 
-#: builtin/tag.c:382
+#: builtin/tag.c:402
 msgid "list tag names"
 msgstr "lista taggnamn"
 
-#: builtin/tag.c:384
+#: builtin/tag.c:404
 msgid "print <n> lines of each tag message"
 msgstr "visa <n> rader från varje taggmeddelande"
 
-#: builtin/tag.c:386
+#: builtin/tag.c:406
 msgid "delete tags"
 msgstr "ta bort taggar"
 
-#: builtin/tag.c:387
+#: builtin/tag.c:407
 msgid "verify tags"
 msgstr "verifiera taggar"
 
-#: builtin/tag.c:389
+#: builtin/tag.c:409
 msgid "Tag creation options"
 msgstr "Alternativ för att skapa taggar"
 
-#: builtin/tag.c:391
+#: builtin/tag.c:411
 msgid "annotated tag, needs a message"
 msgstr "annoterad tagg, behöver meddelande"
 
-#: builtin/tag.c:393
+#: builtin/tag.c:413
 msgid "tag message"
 msgstr "taggmeddelande"
 
-#: builtin/tag.c:395
+#: builtin/tag.c:415
 msgid "force edit of tag message"
 msgstr "tvinga redigering av incheckningsmeddelande"
 
-#: builtin/tag.c:396
+#: builtin/tag.c:416
 msgid "annotated and GPG-signed tag"
 msgstr "annoterad och GPG-signerad tagg"
 
-#: builtin/tag.c:400
+#: builtin/tag.c:419
 msgid "use another key to sign the tag"
 msgstr "använd annan nyckel för att signera taggen"
 
-#: builtin/tag.c:401
+#: builtin/tag.c:420
 msgid "replace the tag if exists"
 msgstr "ersätt taggen om den finns"
 
-#: builtin/tag.c:402 builtin/update-ref.c:368
+#: builtin/tag.c:421 builtin/update-ref.c:369
 msgid "create a reflog"
 msgstr "skapa en reflog"
 
-#: builtin/tag.c:404
+#: builtin/tag.c:423
 msgid "Tag listing options"
 msgstr "Alternativ för listning av taggar"
 
-#: builtin/tag.c:405
+#: builtin/tag.c:424
 msgid "show tag list in columns"
 msgstr "lista taggar i spalter"
 
-#: builtin/tag.c:406 builtin/tag.c:408
+#: builtin/tag.c:425 builtin/tag.c:427
 msgid "print only tags that contain the commit"
 msgstr "visa endast taggar som innehåller incheckningen"
 
-#: builtin/tag.c:407 builtin/tag.c:409
+#: builtin/tag.c:426 builtin/tag.c:428
 msgid "print only tags that don't contain the commit"
 msgstr "visa endast taggar som inte innehåller incheckningen"
 
-#: builtin/tag.c:410
+#: builtin/tag.c:429
 msgid "print only tags that are merged"
 msgstr "visa endast taggar som slagits samman"
 
-#: builtin/tag.c:411
+#: builtin/tag.c:430
 msgid "print only tags that are not merged"
 msgstr "visa endast taggar som ej slagits samman"
 
-#: builtin/tag.c:416
+#: builtin/tag.c:434
 msgid "print only tags of the object"
 msgstr "visa endast taggar för objektet"
 
-#: builtin/tag.c:460
+#: builtin/tag.c:482
 msgid "--column and -n are incompatible"
 msgstr "--column och -n är inkompatibla"
 
-#: builtin/tag.c:482
+#: builtin/tag.c:504
 msgid "-n option is only allowed in list mode"
 msgstr "Flaggan -n är endast tillåten i listläge"
 
-#: builtin/tag.c:484
+#: builtin/tag.c:506
 msgid "--contains option is only allowed in list mode"
 msgstr "Flaggan --contains är endast tillåten i listläge"
 
-#: builtin/tag.c:486
+#: builtin/tag.c:508
 msgid "--no-contains option is only allowed in list mode"
 msgstr "Flaggan --no-contains är endast tillåten i listläge"
 
-#: builtin/tag.c:488
+#: builtin/tag.c:510
 msgid "--points-at option is only allowed in list mode"
 msgstr "Flaggan --points-at är endast tillåten i listläge"
 
-#: builtin/tag.c:490
+#: builtin/tag.c:512
 msgid "--merged and --no-merged options are only allowed in list mode"
 msgstr "Flaggorna --merged och --no-merged är endast tillåtna i listläge"
 
-#: builtin/tag.c:501
+#: builtin/tag.c:523
 msgid "only one -F or -m option is allowed."
 msgstr "endast en av flaggorna -F eller -m tillåts."
 
-#: builtin/tag.c:520
+#: builtin/tag.c:542
 msgid "too many params"
 msgstr "för många parametrar"
 
-#: builtin/tag.c:526
+#: builtin/tag.c:548
 #, c-format
 msgid "'%s' is not a valid tag name."
 msgstr "\"%s\" är inte ett giltigt taggnamn."
 
-#: builtin/tag.c:531
+#: builtin/tag.c:553
 #, c-format
 msgid "tag '%s' already exists"
 msgstr "taggen \"%s\" finns redan"
 
-#: builtin/tag.c:562
+#: builtin/tag.c:584
 #, c-format
 msgid "Updated tag '%s' (was %s)\n"
 msgstr "Uppdaterad tagg \"%s\" (var %s)\n"
 
-#: builtin/unpack-objects.c:498
+#: builtin/unpack-objects.c:501
 msgid "Unpacking objects"
 msgstr "Packar upp objekt"
 
-#: builtin/update-index.c:82
+#: builtin/update-index.c:84
 #, c-format
 msgid "failed to create directory %s"
 msgstr "misslyckades skapa katalogen %s"
 
-#: builtin/update-index.c:88
-#, c-format
-msgid "failed to stat %s"
-msgstr "misslyckades ta status på %s"
-
-#: builtin/update-index.c:98
+#: builtin/update-index.c:100
 #, c-format
 msgid "failed to create file %s"
 msgstr "misslyckades skapa filen %s"
 
-#: builtin/update-index.c:106
+#: builtin/update-index.c:108
 #, c-format
 msgid "failed to delete file %s"
 msgstr "misslyckades ta bort filen %s"
 
-#: builtin/update-index.c:113 builtin/update-index.c:219
+#: builtin/update-index.c:115 builtin/update-index.c:221
 #, c-format
 msgid "failed to delete directory %s"
 msgstr "misslyckades ta bort katalogen %s"
 
-#: builtin/update-index.c:138
+#: builtin/update-index.c:140
 #, c-format
 msgid "Testing mtime in '%s' "
 msgstr "Testar mtime i \"%s\" "
 
-#: builtin/update-index.c:152
+#: builtin/update-index.c:154
 msgid "directory stat info does not change after adding a new file"
 msgstr "stat-informationen för en katalog ändras inte när nya filer läggs till"
 
-#: builtin/update-index.c:165
+#: builtin/update-index.c:167
 msgid "directory stat info does not change after adding a new directory"
 msgstr ""
 "stat-informationen för en katalog ändras inte när nya kataloger läggs till"
 
-#: builtin/update-index.c:178
+#: builtin/update-index.c:180
 msgid "directory stat info changes after updating a file"
 msgstr "stat-informationen för en katalog ändras när filer uppdateras"
 
-#: builtin/update-index.c:189
+#: builtin/update-index.c:191
 msgid "directory stat info changes after adding a file inside subdirectory"
 msgstr ""
 "stat-informationen för en katalog ändras när filer läggs till i en "
 "underkatalog"
 
-#: builtin/update-index.c:200
+#: builtin/update-index.c:202
 msgid "directory stat info does not change after deleting a file"
 msgstr "stat-informationen för en katalog ändras inte när en fil tas bort"
 
-#: builtin/update-index.c:213
+#: builtin/update-index.c:215
 msgid "directory stat info does not change after deleting a directory"
 msgstr "stat-informationen för en katalog ändras inte när en katalog tas bort"
 
-#: builtin/update-index.c:220
+#: builtin/update-index.c:222
 msgid " OK"
 msgstr " OK"
 
-#: builtin/update-index.c:589
+#: builtin/update-index.c:591
 msgid "git update-index [<options>] [--] [<file>...]"
 msgstr "git update-index [<flaggor>] [--] [<fil>...]"
 
-#: builtin/update-index.c:946
+#: builtin/update-index.c:974
 msgid "continue refresh even when index needs update"
 msgstr "fortsätt uppdatera även när index inte är àjour"
 
-#: builtin/update-index.c:949
+#: builtin/update-index.c:977
 msgid "refresh: ignore submodules"
 msgstr "refresh: ignorera undermoduler"
 
-#: builtin/update-index.c:952
+#: builtin/update-index.c:980
 msgid "do not ignore new files"
 msgstr "ignorera inte nya filer"
 
-#: builtin/update-index.c:954
+#: builtin/update-index.c:982
 msgid "let files replace directories and vice-versa"
 msgstr "låt filer ersätta kataloger och omvänt"
 
-#: builtin/update-index.c:956
+#: builtin/update-index.c:984
 msgid "notice files missing from worktree"
 msgstr "lägg märke till filer som saknas i arbetskatalogen"
 
-#: builtin/update-index.c:958
+#: builtin/update-index.c:986
 msgid "refresh even if index contains unmerged entries"
 msgstr "uppdatera även om indexet innehåller ej sammanslagna poster"
 
-#: builtin/update-index.c:961
+#: builtin/update-index.c:989
 msgid "refresh stat information"
 msgstr "uppdatera statusinformation"
 
-#: builtin/update-index.c:965
+#: builtin/update-index.c:993
 msgid "like --refresh, but ignore assume-unchanged setting"
 msgstr "som --refresh, men ignorera assume-unchanged-inställning"
 
-#: builtin/update-index.c:969
+#: builtin/update-index.c:997
 msgid "<mode>,<object>,<path>"
 msgstr "<läge>,<objekt>,<sökväg>"
 
-#: builtin/update-index.c:970
+#: builtin/update-index.c:998
 msgid "add the specified entry to the index"
 msgstr "lägg till angiven post i indexet"
 
-#: builtin/update-index.c:979
+#: builtin/update-index.c:1008
 msgid "mark files as \"not changing\""
 msgstr "markera filer som \"ändras inte\""
 
-#: builtin/update-index.c:982
+#: builtin/update-index.c:1011
 msgid "clear assumed-unchanged bit"
 msgstr "rensa \"assume-unchanged\"-biten"
 
-#: builtin/update-index.c:985
+#: builtin/update-index.c:1014
 msgid "mark files as \"index-only\""
 msgstr "markera filer som \"endast index\""
 
-#: builtin/update-index.c:988
+#: builtin/update-index.c:1017
 msgid "clear skip-worktree bit"
 msgstr "töm \"skip-worktree\"-biten"
 
-#: builtin/update-index.c:991
+#: builtin/update-index.c:1020
+msgid "do not touch index-only entries"
+msgstr "rör inte \"endast index\"-poster"
+
+#: builtin/update-index.c:1022
 msgid "add to index only; do not add content to object database"
 msgstr "lägg endast till indexet; lägg inte till innehållet i objektdatabasen"
 
-#: builtin/update-index.c:993
+#: builtin/update-index.c:1024
 msgid "remove named paths even if present in worktree"
 msgstr "ta bort namngivna sökvägar även om de finns i arbetskatalogen"
 
-#: builtin/update-index.c:995
+#: builtin/update-index.c:1026
 msgid "with --stdin: input lines are terminated by null bytes"
 msgstr "med --stdin: indatarader termineras med null-byte"
 
-#: builtin/update-index.c:997
+#: builtin/update-index.c:1028
 msgid "read list of paths to be updated from standard input"
 msgstr "läs lista över sökvägar att uppdatera från standard in"
 
-#: builtin/update-index.c:1001
+#: builtin/update-index.c:1032
 msgid "add entries from standard input to the index"
 msgstr "lägg poster från standard in till indexet"
 
-#: builtin/update-index.c:1005
+#: builtin/update-index.c:1036
 msgid "repopulate stages #2 and #3 for the listed paths"
 msgstr "återfyll etapp 2 och 3 från angivna sökvägar"
 
-#: builtin/update-index.c:1009
+#: builtin/update-index.c:1040
 msgid "only update entries that differ from HEAD"
 msgstr "uppdatera endast poster som skiljer sig från HEAD"
 
-#: builtin/update-index.c:1013
+#: builtin/update-index.c:1044
 msgid "ignore files missing from worktree"
 msgstr "ignorera filer som saknas i arbetskatalogen"
 
-#: builtin/update-index.c:1016
+#: builtin/update-index.c:1047
 msgid "report actions to standard output"
 msgstr "rapportera åtgärder på standard ut"
 
-#: builtin/update-index.c:1018
+#: builtin/update-index.c:1049
 msgid "(for porcelains) forget saved unresolved conflicts"
 msgstr "(för porslin) glöm sparade olösta konflikter"
 
-#: builtin/update-index.c:1022
+#: builtin/update-index.c:1053
 msgid "write index in this format"
 msgstr "skriv index i detta format"
 
-#: builtin/update-index.c:1024
+#: builtin/update-index.c:1055
 msgid "enable or disable split index"
 msgstr "aktivera eller inaktivera delat index"
 
-#: builtin/update-index.c:1026
+#: builtin/update-index.c:1057
 msgid "enable/disable untracked cache"
 msgstr "aktivera/inaktivera ospårad cache"
 
-#: builtin/update-index.c:1028
+#: builtin/update-index.c:1059
 msgid "test if the filesystem supports untracked cache"
 msgstr "testa om filsystemet stöder ospårad cache"
 
-#: builtin/update-index.c:1030
+#: builtin/update-index.c:1061
 msgid "enable untracked cache without testing the filesystem"
 msgstr "aktivera ospårad cache utan att testa filsystemet"
 
-#: builtin/update-index.c:1032
+#: builtin/update-index.c:1063
 msgid "write out the index even if is not flagged as changed"
 msgstr "skriv ut indexet även om det inte angivits som ändrat"
 
-#: builtin/update-index.c:1034
+#: builtin/update-index.c:1065
 msgid "enable or disable file system monitor"
 msgstr "aktivera eller inaktivera filsystemsövervakning"
 
-#: builtin/update-index.c:1036
+#: builtin/update-index.c:1067
 msgid "mark files as fsmonitor valid"
 msgstr "markera filer som \"fsmonitor valid\""
 
-#: builtin/update-index.c:1039
+#: builtin/update-index.c:1070
 msgid "clear fsmonitor valid bit"
 msgstr "töm \"fsmonitor valid\"-bit"
 
-#: builtin/update-index.c:1138
+#: builtin/update-index.c:1173
 msgid ""
 "core.splitIndex is set to false; remove or change it, if you really want to "
 "enable split index"
@@ -14889,7 +21060,7 @@ msgstr ""
 "core.splitIndex är satt till false; ta bort eller ändra det om du verkligen "
 "vill aktivera delat index"
 
-#: builtin/update-index.c:1147
+#: builtin/update-index.c:1182
 msgid ""
 "core.splitIndex is set to true; remove or change it, if you really want to "
 "disable split index"
@@ -14897,7 +21068,7 @@ msgstr ""
 "core.splitIndex är satt till true; ta bort eller ändra det om du verkligen "
 "vill inaktivera delat index"
 
-#: builtin/update-index.c:1158
+#: builtin/update-index.c:1194
 msgid ""
 "core.untrackedCache is set to true; remove or change it, if you really want "
 "to disable the untracked cache"
@@ -14905,11 +21076,11 @@ msgstr ""
 "core.untrackedCache är satt till true; ta bort eller ändra det om du "
 "verkligen vill inaktivera den ospårade cachen"
 
-#: builtin/update-index.c:1162
+#: builtin/update-index.c:1198
 msgid "Untracked cache disabled"
 msgstr "Ospårad cache är inaktiverad"
 
-#: builtin/update-index.c:1170
+#: builtin/update-index.c:1206
 msgid ""
 "core.untrackedCache is set to false; remove or change it, if you really want "
 "to enable the untracked cache"
@@ -14917,26 +21088,26 @@ msgstr ""
 "core.untrackedCache är satt till false; ta bort eller ändra det om du "
 "verkligen vill aktivera den ospårade cachen"
 
-#: builtin/update-index.c:1174
+#: builtin/update-index.c:1210
 #, c-format
 msgid "Untracked cache enabled for '%s'"
 msgstr "Ospårad cache är aktiverad för \"%s\""
 
-#: builtin/update-index.c:1182
+#: builtin/update-index.c:1218
 msgid "core.fsmonitor is unset; set it if you really want to enable fsmonitor"
 msgstr "core.fsmonitor inte satt; sätt om du verkligen vill aktivera fsmonitor"
 
-#: builtin/update-index.c:1186
+#: builtin/update-index.c:1222
 msgid "fsmonitor enabled"
 msgstr "fsmonitor aktiverat"
 
-#: builtin/update-index.c:1189
+#: builtin/update-index.c:1225
 msgid ""
 "core.fsmonitor is set; remove it if you really want to disable fsmonitor"
 msgstr ""
 "core.fsmonitor är satt; ta bort om du verkligen vill inaktivera fsmonitor"
 
-#: builtin/update-index.c:1193
+#: builtin/update-index.c:1229
 msgid "fsmonitor disabled"
 msgstr "fsmonitor inaktiverat"
 
@@ -14952,19 +21123,19 @@ msgstr "git update-ref [<flaggor>]    <r
 msgid "git update-ref [<options>] --stdin [-z]"
 msgstr "git update-ref [<flaggor>] --stdin [-z]"
 
-#: builtin/update-ref.c:363
+#: builtin/update-ref.c:364
 msgid "delete the reference"
 msgstr "ta bort referensen"
 
-#: builtin/update-ref.c:365
+#: builtin/update-ref.c:366
 msgid "update <refname> not the one it points to"
 msgstr "uppdatera <refnamn> inte det den pekar på"
 
-#: builtin/update-ref.c:366
+#: builtin/update-ref.c:367
 msgid "stdin has NUL-terminated arguments"
 msgstr "standard in har NUL-terminerade argument"
 
-#: builtin/update-ref.c:367
+#: builtin/update-ref.c:368
 msgid "read updates from stdin"
 msgstr "läs uppdateringar från standard in"
 
@@ -14980,6 +21151,10 @@ msgstr "uppdatera informationsfilerna fr
 msgid "git upload-pack [<options>] <dir>"
 msgstr "git upload-pack [<flaggor>] <katalog>"
 
+#: builtin/upload-pack.c:23 t/helper/test-serve-v2.c:17
+msgid "quit after a single request/response exchange"
+msgstr "avsluta omedelbart efter första anrop/svar-utväxling"
+
 #: builtin/upload-pack.c:25
 msgid "exit immediately after initial ref advertisement"
 msgstr "avsluta omedelbart efter inledande kungörelse av referenser"
@@ -14992,15 +21167,15 @@ msgstr "testa inte <katalog>/.git/ om <k
 msgid "interrupt transfer after <n> seconds of inactivity"
 msgstr "avbryt överföringen efter <n> sekunders inaktivitet"
 
-#: builtin/verify-commit.c:18
+#: builtin/verify-commit.c:19
 msgid "git verify-commit [-v | --verbose] <commit>..."
 msgstr "git verify-commit [-v | --verbose] <incheckning>..."
 
-#: builtin/verify-commit.c:73
+#: builtin/verify-commit.c:68
 msgid "print commit contents"
 msgstr "visa innehåll för incheckning"
 
-#: builtin/verify-commit.c:74 builtin/verify-tag.c:38
+#: builtin/verify-commit.c:69 builtin/verify-tag.c:37
 msgid "print raw gpg status output"
 msgstr "visa råa gpg-statusdata"
 
@@ -15016,11 +21191,11 @@ msgstr "pratsam"
 msgid "show statistics only"
 msgstr "visa endast statistik"
 
-#: builtin/verify-tag.c:19
+#: builtin/verify-tag.c:18
 msgid "git verify-tag [-v | --verbose] [--format=<format>] <tag>..."
 msgstr "git verify-tag [-v | --verbose] [--format=<format] <tagg>..."
 
-#: builtin/verify-tag.c:37
+#: builtin/verify-tag.c:36
 msgid "print tag contents"
 msgstr "visa innehåll för tag"
 
@@ -15052,22 +21227,27 @@ msgstr "git worktree remove [<flaggor>]
 msgid "git worktree unlock <path>"
 msgstr "git worktree unlock <sökväg>"
 
-#: builtin/worktree.c:58
+#: builtin/worktree.c:60 builtin/worktree.c:898
+#, c-format
+msgid "failed to delete '%s'"
+msgstr "misslyckades ta bort \"%s\""
+
+#: builtin/worktree.c:79
 #, c-format
 msgid "Removing worktrees/%s: not a valid directory"
 msgstr "Tar bort worktrees/%s: inte en giltig katalog"
 
-#: builtin/worktree.c:64
+#: builtin/worktree.c:85
 #, c-format
 msgid "Removing worktrees/%s: gitdir file does not exist"
 msgstr "Tar bort worktrees/%s: gitdir-filen existerar inte"
 
-#: builtin/worktree.c:69 builtin/worktree.c:78
+#: builtin/worktree.c:90 builtin/worktree.c:99
 #, c-format
 msgid "Removing worktrees/%s: unable to read gitdir file (%s)"
 msgstr "Tar bort worktrees/%s: kan inte läsa gitdir-filen (%s)"
 
-#: builtin/worktree.c:88
+#: builtin/worktree.c:109
 #, c-format
 msgid ""
 "Removing worktrees/%s: short read (expected %<PRIuMAX> bytes, read "
@@ -15076,205 +21256,247 @@ msgstr ""
 "Tar bort worktrees/%s: kort läsning (förväntade %<PRIuMAX> byte, läste "
 "%<PRIuMAX>)"
 
-#: builtin/worktree.c:96
+#: builtin/worktree.c:117
 #, c-format
 msgid "Removing worktrees/%s: invalid gitdir file"
 msgstr "Tar bort worktrees/%s: felaktig gitdir-fil"
 
-#: builtin/worktree.c:105
+#: builtin/worktree.c:126
 #, c-format
 msgid "Removing worktrees/%s: gitdir file points to non-existent location"
 msgstr "Tar bort worktrees/%s: gitdir-filen pekar på en ickeexisterande plats"
 
-#: builtin/worktree.c:152
+#: builtin/worktree.c:165
 msgid "report pruned working trees"
 msgstr "rapportera borttagna arbetskataloger"
 
-#: builtin/worktree.c:154
+#: builtin/worktree.c:167
 msgid "expire working trees older than <time>"
 msgstr "låt tid gå ut för arbetskataloger äldre än <tid>"
 
-#: builtin/worktree.c:229
+#: builtin/worktree.c:234
 #, c-format
 msgid "'%s' already exists"
 msgstr "\"%s\" finns redan"
 
-#: builtin/worktree.c:260
+#: builtin/worktree.c:251
+#, c-format
+msgid "unable to re-add worktree '%s'"
+msgstr "kunde inte lägga in arbetskatalogen \"%s\" igen"
+
+#: builtin/worktree.c:256
+#, c-format
+msgid ""
+"'%s' is a missing but locked worktree;\n"
+"use 'add -f -f' to override, or 'unlock' and 'prune' or 'remove' to clear"
+msgstr ""
+"\"%s\" är en saknad men låst arbetskatalog;\n"
+"använd \"add -f -f\" för att överstyra, eller \"unlock\" och \"prune\" eller "
+"\"remove\" för att rensa"
+
+#: builtin/worktree.c:258
+#, c-format
+msgid ""
+"'%s' is a missing but already registered worktree;\n"
+"use 'add -f' to override, or 'prune' or 'remove' to clear"
+msgstr ""
+"\"%s\" är en saknad men redan registrerad arbetskatalog;\n"
+"använd \"add -f\" för att överstyra, eller \"prune\" eller \"remove\" för "
+"att rensa"
+
+#: builtin/worktree.c:308
 #, c-format
 msgid "could not create directory of '%s'"
 msgstr "kunde inte skapa katalogen \"%s\""
 
-#: builtin/worktree.c:373 builtin/worktree.c:379
+#: builtin/worktree.c:439 builtin/worktree.c:445
 #, c-format
 msgid "Preparing worktree (new branch '%s')"
 msgstr "Förbereder arbetskatalog (ny gren \"%s\")"
 
-#: builtin/worktree.c:375
+#: builtin/worktree.c:441
 #, c-format
 msgid "Preparing worktree (resetting branch '%s'; was at %s)"
 msgstr "Förbereder arbetskatalog (återställer gren \"%s\"; var på %s)"
 
-#: builtin/worktree.c:384
+#: builtin/worktree.c:450
 #, c-format
 msgid "Preparing worktree (checking out '%s')"
 msgstr "Förbereder arbetskatalog (checkar ut \"%s\")"
 
-#: builtin/worktree.c:390
+#: builtin/worktree.c:456
 #, c-format
 msgid "Preparing worktree (detached HEAD %s)"
 msgstr "Förbereder arbetskatalog (frånkopplat HEAD %s)"
 
-#: builtin/worktree.c:431
+#: builtin/worktree.c:497
 msgid "checkout <branch> even if already checked out in other worktree"
 msgstr ""
 "checka ut <gren> även om den redan är utcheckad i en annan arbetskatalog"
 
-#: builtin/worktree.c:434
+#: builtin/worktree.c:500
 msgid "create a new branch"
 msgstr "skapa en ny gren"
 
-#: builtin/worktree.c:436
+#: builtin/worktree.c:502
 msgid "create or reset a branch"
 msgstr "skapa eller återställ en gren"
 
-#: builtin/worktree.c:438
+#: builtin/worktree.c:504
 msgid "populate the new working tree"
 msgstr "befolka den nya arbetskatalogen"
 
-#: builtin/worktree.c:439
+#: builtin/worktree.c:505
 msgid "keep the new working tree locked"
 msgstr "låt arbetskatalogen förbli låst"
 
-#: builtin/worktree.c:441
+#: builtin/worktree.c:508
 msgid "set up tracking mode (see git-branch(1))"
 msgstr "ställ in spårningsläge (se git-branch(1))"
 
-#: builtin/worktree.c:444
+#: builtin/worktree.c:511
 msgid "try to match the new branch name with a remote-tracking branch"
 msgstr "försök matcha namn på ny gren mot en fjärrspårande gren"
 
-#: builtin/worktree.c:452
+#: builtin/worktree.c:519
 msgid "-b, -B, and --detach are mutually exclusive"
 msgstr "-b, -B och --detach är ömsesidigt uteslutande"
 
-#: builtin/worktree.c:511
+#: builtin/worktree.c:580
 msgid "--[no-]track can only be used if a new branch is created"
 msgstr "--[no-]track kan endast användas när ny gran skapas"
 
-#: builtin/worktree.c:611
+#: builtin/worktree.c:680
 msgid "reason for locking"
 msgstr "orsak till lås"
 
-#: builtin/worktree.c:623 builtin/worktree.c:656 builtin/worktree.c:710
-#: builtin/worktree.c:850
+#: builtin/worktree.c:692 builtin/worktree.c:725 builtin/worktree.c:799
+#: builtin/worktree.c:926
 #, c-format
 msgid "'%s' is not a working tree"
 msgstr "\"%s\" är inte en arbetskatalog"
 
-#: builtin/worktree.c:625 builtin/worktree.c:658
+#: builtin/worktree.c:694 builtin/worktree.c:727
 msgid "The main working tree cannot be locked or unlocked"
 msgstr "Huvudarbetskatalogen kan inte låsas eller låsas upp"
 
-#: builtin/worktree.c:630
+#: builtin/worktree.c:699
 #, c-format
 msgid "'%s' is already locked, reason: %s"
 msgstr "\"%s\" är redan låst, orsak: %s"
 
-#: builtin/worktree.c:632
+#: builtin/worktree.c:701
 #, c-format
 msgid "'%s' is already locked"
 msgstr "\"%s\" är redan låst"
 
-#: builtin/worktree.c:660
+#: builtin/worktree.c:729
 #, c-format
 msgid "'%s' is not locked"
 msgstr "\"%s\" är inte låst"
 
-#: builtin/worktree.c:685
+#: builtin/worktree.c:770
 msgid "working trees containing submodules cannot be moved or removed"
 msgstr "arbetskataloger med undermoduler kan inte flyttas eller tas bort"
 
-#: builtin/worktree.c:712 builtin/worktree.c:852
+#: builtin/worktree.c:778
+msgid "force move even if worktree is dirty or locked"
+msgstr "tvinga flyttning även om arbetskatalogen är smutsig eller låst"
+
+#: builtin/worktree.c:801 builtin/worktree.c:928
 #, c-format
 msgid "'%s' is a main working tree"
 msgstr "\"%s\" är inte en huvudarbetskatalog"
 
-#: builtin/worktree.c:717
+#: builtin/worktree.c:806
 #, c-format
 msgid "could not figure out destination name from '%s'"
 msgstr "kunde inte lista ut målnamn från \"%s\""
 
-#: builtin/worktree.c:723
+#: builtin/worktree.c:812
 #, c-format
 msgid "target '%s' already exists"
 msgstr "målet \"%s\" finns redan"
 
-#: builtin/worktree.c:730
+#: builtin/worktree.c:820
 #, c-format
-msgid "cannot move a locked working tree, lock reason: %s"
-msgstr "kan inte flytta en låst arbetskatalog, orsak till lås: %s"
+msgid ""
+"cannot move a locked working tree, lock reason: %s\n"
+"use 'move -f -f' to override or unlock first"
+msgstr ""
+"kan inte flytta en låst arbetskatalog, orsak till lås: %s\n"
+"använd \"move -f -f\" för att överstyra, eller lås upp först"
 
-#: builtin/worktree.c:732
-msgid "cannot move a locked working tree"
-msgstr "kan inte flytta en låst arbetskatalog"
+#: builtin/worktree.c:822
+msgid ""
+"cannot move a locked working tree;\n"
+"use 'move -f -f' to override or unlock first"
+msgstr ""
+"kan inte flytta en låst arbetskatalog;\n"
+"använd \"move -f -f\" för att överstyra, eller lås upp först"
 
-#: builtin/worktree.c:735
+#: builtin/worktree.c:825
 #, c-format
 msgid "validation failed, cannot move working tree: %s"
 msgstr "kontroll misslyckades, kan inte flytta arbetskatalog: %s"
 
-#: builtin/worktree.c:740
+#: builtin/worktree.c:830
 #, c-format
 msgid "failed to move '%s' to '%s'"
 msgstr "misslyckades flytta \"%s\" till \"%s\""
 
-#: builtin/worktree.c:788
+#: builtin/worktree.c:878
 #, c-format
 msgid "failed to run 'git status' on '%s'"
 msgstr "misslyckades köra \"git status\" på \"%s\""
 
-#: builtin/worktree.c:792
+#: builtin/worktree.c:882
 #, c-format
-msgid "'%s' is dirty, use --force to delete it"
-msgstr "\"%s\" är smutsigt, använd --force för att ta bort det"
+msgid "'%s' contains modified or untracked files, use --force to delete it"
+msgstr ""
+"\"%s\" innehåller ändrade eller ospårade filer, använd --force för att ta "
+"bort det"
 
-#: builtin/worktree.c:797
+#: builtin/worktree.c:887
 #, c-format
 msgid "failed to run 'git status' on '%s', code %d"
 msgstr "misslyckades köra \"git status\" på \"%s\", kod %d"
 
-#: builtin/worktree.c:808 builtin/worktree.c:822
-#, c-format
-msgid "failed to delete '%s'"
-msgstr "misslyckades ta bort \"%s\""
-
-#: builtin/worktree.c:834
-msgid "force removing even if the worktree is dirty"
-msgstr "tvinga ta bort även om arbetskatalogen är smutsig"
+#: builtin/worktree.c:910
+msgid "force removal even if worktree is dirty or locked"
+msgstr "tvinga ta bort även om arbetskatalogen är smutsig eller låst"
 
-#: builtin/worktree.c:856
+#: builtin/worktree.c:933
 #, c-format
-msgid "cannot remove a locked working tree, lock reason: %s"
-msgstr "kan inte ta bort en låst arbetskatalog, orsak till låset: %s"
+msgid ""
+"cannot remove a locked working tree, lock reason: %s\n"
+"use 'remove -f -f' to override or unlock first"
+msgstr ""
+"kan inte ta bort en låst arbetskatalog, orsak till låset: %s\n"
+"använd \"remove -f -f\" för att överstyra, eller lås upp först"
 
-#: builtin/worktree.c:858
-msgid "cannot remove a locked working tree"
-msgstr "kan inte ta bort en låst arbetskatalog"
+#: builtin/worktree.c:935
+msgid ""
+"cannot remove a locked working tree;\n"
+"use 'remove -f -f' to override or unlock first"
+msgstr ""
+"kan inte ta bort en låst arbetskatalog;\n"
+"använd \"remove -f -f\" för att överstyra, eller lås upp först"
 
-#: builtin/worktree.c:861
+#: builtin/worktree.c:938
 #, c-format
 msgid "validation failed, cannot remove working tree: %s"
 msgstr "kontroll misslyckades, kan inte ta bort arbetskatalog: %s"
 
-#: builtin/write-tree.c:14
+#: builtin/write-tree.c:15
 msgid "git write-tree [--missing-ok] [--prefix=<prefix>/]"
 msgstr "git write-tree [--missing-ok] [--prefix=<prefix>/]"
 
-#: builtin/write-tree.c:27
+#: builtin/write-tree.c:28
 msgid "<prefix>/"
 msgstr "<prefix>/"
 
-#: builtin/write-tree.c:28
+#: builtin/write-tree.c:29
 msgid "write tree object for a subdirectory <prefix>"
 msgstr "visa trädobjekt för underkatalogen <prefix>"
 
@@ -15282,7 +21504,22 @@ msgstr "visa trädobjekt för underkatal
 msgid "only useful for debugging"
 msgstr "endast användbart vid felsökning"
 
-#: credential-cache--daemon.c:222
+#: fast-import.c:3125
+#, c-format
+msgid "Expected 'mark' command, got %s"
+msgstr "Förväntade \"mark\"-kommando, fick %s"
+
+#: fast-import.c:3130
+#, c-format
+msgid "Expected 'to' command, got %s"
+msgstr "Förväntade \"to\"-kommando, fick %s"
+
+#: fast-import.c:3254
+#, c-format
+msgid "feature '%s' forbidden in input without --allow-unsafe-features"
+msgstr "funktionen \"%s\" förbjuden i indata utan --allow-unsafe-features"
+
+#: credential-cache--daemon.c:223
 #, c-format
 msgid ""
 "The permissions on your socket directory are too loose; other\n"
@@ -15295,10 +21532,27 @@ msgstr ""
 "\n"
 "\tchmod 0700 %s"
 
-#: credential-cache--daemon.c:271
+#: credential-cache--daemon.c:272
 msgid "print debugging messages to stderr"
 msgstr "skriv felsökningsmeddelanden på standard fel"
 
+#: t/helper/test-reach.c:152
+#, c-format
+msgid "commit %s is not marked reachable"
+msgstr "incheckning %s är inte märkt nåbar"
+
+#: t/helper/test-reach.c:162
+msgid "too many commits marked reachable"
+msgstr "för många incheckningar markerade nåbara"
+
+#: t/helper/test-serve-v2.c:7
+msgid "test-tool serve-v2 [<options>]"
+msgstr "test-tool serve-v2 [<flaggor>]"
+
+#: t/helper/test-serve-v2.c:19
+msgid "exit immediately after advertising capabilities"
+msgstr "avsluta omedelbart efter kungörelse av kapabiliteter"
+
 #: git.c:27
 msgid ""
 "git [--version] [--help] [-C <path>] [-c <name>=<value>]\n"
@@ -15320,115 +21574,332 @@ msgstr ""
 msgid ""
 "'git help -a' and 'git help -g' list available subcommands and some\n"
 "concept guides. See 'git help <command>' or 'git help <concept>'\n"
-"to read about a specific subcommand or concept."
+"to read about a specific subcommand or concept.\n"
+"See 'git help git' for an overview of the system."
 msgstr ""
 "\"git help -a\" och \"git help -g\" visar tillgängliga underkommandon och\n"
 "några konceptvägledningar. Se \"git help <kommando>\" eller \"git help\n"
-"<koncept>\" för att läsa mer om specifika underkommandon och koncept."
+"<koncept>\" för att läsa mer om specifika underkommandon och koncept.\n"
+"See \"git help git\" för en översikt över systemet."
 
-#: git.c:173
+#: git.c:186
 #, c-format
 msgid "no directory given for --git-dir\n"
 msgstr "ingen katalog angavs för --git-dir\n"
 
-#: git.c:187
+#: git.c:200
 #, c-format
 msgid "no namespace given for --namespace\n"
 msgstr "ingen namnrymd angavs för --namespace\n"
 
-#: git.c:201
+#: git.c:214
 #, c-format
 msgid "no directory given for --work-tree\n"
 msgstr "ingen katalog angavs för --work-tree\n"
 
-#: git.c:215
+#: git.c:228
 #, c-format
 msgid "no prefix given for --super-prefix\n"
 msgstr "inget prefix angavs för --super-prefix\n"
 
-#: git.c:237
+#: git.c:250
 #, c-format
 msgid "-c expects a configuration string\n"
 msgstr "-c förväntar en konfigurationssträng\n"
 
-#: git.c:275
+#: git.c:288
 #, c-format
 msgid "no directory given for -C\n"
 msgstr "ingen katalog angavs för -C\n"
 
-#: git.c:300
+#: git.c:314
 #, c-format
 msgid "unknown option: %s\n"
 msgstr "okänd flagga: %s\n"
 
-#: git.c:765
+#: git.c:360
+#, c-format
+msgid "while expanding alias '%s': '%s'"
+msgstr "vid expandering av aliaset \"%s\": \"%s\""
+
+#: git.c:369
+#, c-format
+msgid ""
+"alias '%s' changes environment variables.\n"
+"You can use '!git' in the alias to do this"
+msgstr ""
+"aliaset \"%s\" ändrar miljövariabler.\n"
+"Du kan använda \"!git\" i aliaset för att göra det"
+
+#: git.c:376
+#, c-format
+msgid "empty alias for %s"
+msgstr "tomt alias för %s"
+
+#: git.c:379
+#, c-format
+msgid "recursive alias: %s"
+msgstr "rekursivt alias: %s"
+
+#: git.c:459
+msgid "write failure on standard output"
+msgstr "skrivfel på standard ut"
+
+#: git.c:461
+msgid "unknown write failure on standard output"
+msgstr "okänt skrivfel på standard ut"
+
+#: git.c:463
+msgid "close failed on standard output"
+msgstr "stäng misslyckades på standard ut"
+
+#: git.c:793
+#, c-format
+msgid "alias loop detected: expansion of '%s' does not terminate:%s"
+msgstr "alias-slinga detekterades: expansionen av \"%s\" avslutas aldrig:%s"
+
+#: git.c:843
+#, c-format
+msgid "cannot handle %s as a builtin"
+msgstr "kan inte hantera %s som inbyggd"
+
+#: git.c:856
+#, c-format
+msgid ""
+"usage: %s\n"
+"\n"
+msgstr ""
+"användning: %s\n"
+"\n"
+
+#: git.c:876
 #, c-format
 msgid "expansion of alias '%s' failed; '%s' is not a git command\n"
 msgstr ""
 "expandering av alias \"%s\" misslyckades; \"%s\" är inte ett git-kommando\n"
 
-#: git.c:777
+#: git.c:888
 #, c-format
 msgid "failed to run command '%s': %s\n"
 msgstr "misslyckades köra kommandot \"%s\": %s\n"
 
-#: http.c:348
+#: http.c:378
+#, c-format
+msgid "negative value for http.postbuffer; defaulting to %d"
+msgstr "http.postbuffer har negativt värde; använder förvalet %d"
+
+#: http.c:399
+msgid "Delegation control is not supported with cURL < 7.22.0"
+msgstr "Delegerad styrning stöds inte av cURL < 7.22.0"
+
+#: http.c:408
+msgid "Public key pinning not supported with cURL < 7.44.0"
+msgstr "Fastnålning av öppen nyckel stöds inte av cURL < 7.44.0"
+
+#: http.c:876
+msgid "CURLSSLOPT_NO_REVOKE not supported with cURL < 7.44.0"
+msgstr "CURLSSLOPT_NO_REVOKE stöds inte av cURL < 7.44.0"
+
+#: http.c:949
+msgid "Protocol restrictions not supported with cURL < 7.19.4"
+msgstr "Prtokollbegränsningar stöds inte av cURL < 7.19.4"
+
+#: http.c:1086
+#, c-format
+msgid "Unsupported SSL backend '%s'. Supported SSL backends:"
+msgstr "SSL-bakändan \"%s\" stöds inte. Dessa SSL-bakändor stöds:"
+
+#: http.c:1093
+#, c-format
+msgid "Could not set SSL backend to '%s': cURL was built without SSL backends"
+msgstr "Kan inte sätta SSL-bakända till \"%s\": cURL byggdes utan SSL-bakändor"
+
+#: http.c:1097
+#, c-format
+msgid "Could not set SSL backend to '%s': already set"
+msgstr "Kunde inte sätta SSL-bakända till \"%s\": redan valt"
+
+#: http.c:1966
+#, c-format
+msgid ""
+"unable to update url base from redirection:\n"
+"  asked for: %s\n"
+"   redirect: %s"
+msgstr ""
+"kan inte uppdatera urlbas från omdirigerin:\n"
+"        bad om: %s\n"
+"  omdirigering: %s"
+
+#: remote-curl.c:166
+#, c-format
+msgid "invalid quoting in push-option value: '%s'"
+msgstr "felaktig citering på värde för push-option: \"%s\""
+
+#: remote-curl.c:263
+#, c-format
+msgid "%sinfo/refs not valid: is this a git repository?"
+msgstr "%sinfo/refs inte giltig: är detta ett git-arkiv?"
+
+#: remote-curl.c:364
+msgid "invalid server response; expected service, got flush packet"
+msgstr "ogiltigt svar från servern; förväntade tjänst, fick flush-paket"
+
+#: remote-curl.c:395
+#, c-format
+msgid "invalid server response; got '%s'"
+msgstr "ogiltigt svar från servern; fick \"%s\""
+
+#: remote-curl.c:455
+#, c-format
+msgid "repository '%s' not found"
+msgstr "arkivet \"%s\" hittades inte"
+
+#: remote-curl.c:459
+#, c-format
+msgid "Authentication failed for '%s'"
+msgstr "Autentisering misslyckades \"%s\""
+
+#: remote-curl.c:463
+#, c-format
+msgid "unable to access '%s': %s"
+msgstr "kan inte komma åt \"%s\": %s"
+
+#: remote-curl.c:469
+#, c-format
+msgid "redirecting to %s"
+msgstr "omdirigerar till %s"
+
+#: remote-curl.c:593
+msgid "shouldn't have EOF when not gentle on EOF"
+msgstr "borde inte ha EOF när inte försiktig på EOF"
+
+#: remote-curl.c:673
+msgid "unable to rewind rpc post data - try increasing http.postBuffer"
+msgstr "kunde inte spola tillbaka rpc-postdata - försök öka http.postBuffer"
+
+#: remote-curl.c:733
+#, c-format
+msgid "RPC failed; %s"
+msgstr "RPC misslyckades; %s"
+
+#: remote-curl.c:773
+msgid "cannot handle pushes this big"
+msgstr "kan inte hantera så stora sändningar"
+
+#: remote-curl.c:888
+#, c-format
+msgid "cannot deflate request; zlib deflate error %d"
+msgstr "kan inte packa upp anrop; zlib-deflate-fel %d"
+
+#: remote-curl.c:892
+#, c-format
+msgid "cannot deflate request; zlib end error %d"
+msgstr "kan inte packa upp anrop; zlib-slutfel %d"
+
+#: remote-curl.c:1023
+msgid "dumb http transport does not support shallow capabilities"
+msgstr "dum http-transport stöder inte grunda arkiv"
+
+#: remote-curl.c:1037
+msgid "fetch failed."
+msgstr "mottagning misslyckades."
+
+#: remote-curl.c:1085
+msgid "cannot fetch by sha1 over smart http"
+msgstr "kan inte hämta med sha1 över smart http"
+
+#: remote-curl.c:1129 remote-curl.c:1135
+#, c-format
+msgid "protocol error: expected sha/ref, got '%s'"
+msgstr "protokollfel: förväntade sha/ref, fick \"%s\""
+
+#: remote-curl.c:1147 remote-curl.c:1261
 #, c-format
-msgid "negative value for http.postbuffer; defaulting to %d"
-msgstr "http.postbuffer har negativt värde; använder förvalet %d"
+msgid "http transport does not support %s"
+msgstr "http-transporten stöder inte %s"
 
-#: http.c:369
-msgid "Delegation control is not supported with cURL < 7.22.0"
-msgstr "Delegerad styrning stöds inte av cURL < 7.22.0"
+#: remote-curl.c:1183
+msgid "git-http-push failed"
+msgstr "git-http-push misslyckades"
 
-#: http.c:378
-msgid "Public key pinning not supported with cURL < 7.44.0"
-msgstr "Fastnålning av öppen nyckel stöds inte av cURL < 7.44.0"
+#: remote-curl.c:1367
+msgid "remote-curl: usage: git remote-curl <remote> [<url>]"
+msgstr "remote-curl: användning: git remote-curl <fjärr> [<url>]"
 
-#: http.c:1854
-#, c-format
-msgid ""
-"unable to update url base from redirection:\n"
-"  asked for: %s\n"
-"   redirect: %s"
-msgstr ""
-"kan inte uppdatera urlbas från omdirigerin:\n"
-"        bad om: %s\n"
-"  omdirigering: %s"
+#: remote-curl.c:1399
+msgid "remote-curl: error reading command stream from git"
+msgstr "remote-curl: fel vid läsning av kommandoström från git"
+
+#: remote-curl.c:1406
+msgid "remote-curl: fetch attempted without a local repo"
+msgstr "remote-curl: försökte ta emot utan lokalt arkiv"
 
-#: remote-curl.c:401
+#: remote-curl.c:1446
 #, c-format
-msgid "redirecting to %s"
-msgstr "omdirigerar till %s"
+msgid "remote-curl: unknown command '%s' from git"
+msgstr "remote-curl: okänt kommando \"%s\" från git"
 
-#: list-objects-filter-options.h:59
+#: list-objects-filter-options.h:85
 msgid "args"
 msgstr "argument"
 
-#: list-objects-filter-options.h:60
+#: list-objects-filter-options.h:86
 msgid "object filtering"
 msgstr "objektfiltrering"
 
-#: parse-options.h:157
+#: parse-options.h:183
 msgid "expiry-date"
 msgstr "giltig-till"
 
-#: parse-options.h:172
+#: parse-options.h:197
 msgid "no-op (backward compatibility)"
 msgstr "ingen funktion (bakåtkompatibilitet)"
 
-#: parse-options.h:251
+#: parse-options.h:309
 msgid "be more verbose"
 msgstr "var mer pratsam"
 
-#: parse-options.h:253
+#: parse-options.h:311
 msgid "be more quiet"
 msgstr "var mer tyst"
 
-#: parse-options.h:259
+#: parse-options.h:317
 msgid "use <n> digits to display SHA-1s"
 msgstr "använd <n> siffror för att visa SHA-1:or"
 
+#: parse-options.h:336
+msgid "how to strip spaces and #comments from message"
+msgstr "hur blanksteg och #kommentarer skall tas bort från meddelande"
+
+#: parse-options.h:337
+msgid "read pathspec from file"
+msgstr "läs sökvägsangivelse från fil"
+
+#: parse-options.h:338
+msgid ""
+"with --pathspec-from-file, pathspec elements are separated with NUL character"
+msgstr "med --pathspec-from-file, sökvägsangivelser avdelas med NUL-tecken"
+
+#: ref-filter.h:101
+msgid "key"
+msgstr "nyckel"
+
+#: ref-filter.h:101
+msgid "field name to sort on"
+msgstr "fältnamn att sortera på"
+
+#: rerere.h:44
+msgid "update the index with reused conflict resolution if possible"
+msgstr "uppdatera indexet med återanvänd konfliktlösning om möjligt"
+
+#: wt-status.h:67
+msgid "HEAD detached at "
+msgstr "HEAD frånkopplad vid "
+
+#: wt-status.h:68
+msgid "HEAD detached from "
+msgstr "HEAD frånkopplad från "
+
 #: command-list.h:50
 msgid "Add file contents to the index"
 msgstr "Lägg filinnehåll till indexet"
@@ -15446,8 +21917,8 @@ msgid "Apply a patch to files and/or to
 msgstr "Tillämpa en patch på filer och/eller indexet"
 
 #: command-list.h:54
-msgid "Import an Arch repository into Git"
-msgstr "Importera ett Arch-arkiv till Git"
+msgid "Import a GNU Arch repository into Git"
+msgstr "Importera ett GNU Arch-arkiv till Git"
 
 #: command-list.h:55
 msgid "Create an archive of files from a named tree"
@@ -15472,7 +21943,7 @@ msgstr "Flytta objekt och referenser eft
 #: command-list.h:60
 msgid "Provide content or type and size information for repository objects"
 msgstr ""
-"Visa innehåller eller typ- och storleksinformation för objekt i arkivet."
+"Visa innehåller eller typ- och storleksinformation för objekt i arkivet"
 
 #: command-list.h:61
 msgid "Display gitattributes information"
@@ -15527,7 +21998,7 @@ msgid "Record changes to the repository"
 msgstr "Protokollför ändringar i arkivet"
 
 #: command-list.h:74
-msgid "Write and verify Git commit graph files"
+msgid "Write and verify Git commit-graph files"
 msgstr "Skriv och verifiera Git-incheckningsgraffiler"
 
 #: command-list.h:75
@@ -15588,7 +22059,7 @@ msgstr "Jämför en träd med arbetskata
 
 #: command-list.h:89
 msgid "Compares the content and mode of blobs found via two tree objects"
-msgstr "Visar innehåll och läge för blob:ar som hittats via två trädobjekt"
+msgstr "Visar innehåll och läge för blobbar som hittats via två trädobjekt"
 
 #: command-list.h:90
 msgid "Show changes using common diff tools"
@@ -15636,7 +22107,7 @@ msgstr "Städa onödiga filer och optime
 
 #: command-list.h:101
 msgid "Extract commit ID from an archive created using git-archive"
-msgstr "Hämta inchecknings-ID från ett arkiv skapat med git-archive"
+msgstr "Hämta inchecknings-id från ett arkiv skapat med git-archive"
 
 #: command-list.h:102
 msgid "Print lines matching a pattern"
@@ -15648,7 +22119,7 @@ msgstr "Ett portabelt grafiskt gränssni
 
 #: command-list.h:104
 msgid "Compute object ID and optionally creates a blob from a file"
-msgstr "Beräkna objekt-ID och möjligen skapa en blob från en fil"
+msgstr "Beräkna objekt-id och möjligen skapa en blob från en fil"
 
 #: command-list.h:105
 msgid "Display help information about Git"
@@ -15683,9 +22154,9 @@ msgid "Instantly browse your working rep
 msgstr "Omedelbart bläddra i din arbetskatalog med gitweb"
 
 #: command-list.h:113
-msgid "add or parse structured information in commit messages"
+msgid "Add or parse structured information in commit messages"
 msgstr ""
-"lägg till eller tolka strukturerad information i incheckningsmeddelanden"
+"Lägg till eller tolka strukturerad information i incheckningsmeddelanden"
 
 #: command-list.h:114
 msgid "The Git repository browser"
@@ -15744,326 +22215,346 @@ msgid "Show three-way merge without touc
 msgstr "Visa trevägssammanslagning utan att röra indexet"
 
 #: command-list.h:128
+msgid "Write and verify multi-pack-indexes"
+msgstr "Skriv och verifiera multi-pack-index"
+
+#: command-list.h:129
 msgid "Creates a tag object"
 msgstr "Skapar ett taggobjekt"
 
-#: command-list.h:129
+#: command-list.h:130
 msgid "Build a tree-object from ls-tree formatted text"
 msgstr "Bygg ett trädobjekt från ls-tree-formaterad text"
 
-#: command-list.h:130
+#: command-list.h:131
 msgid "Move or rename a file, a directory, or a symlink"
 msgstr "Flytta eller byt namn på en fil, katalog eller symbolisk länk"
 
-#: command-list.h:131
+#: command-list.h:132
 msgid "Find symbolic names for given revs"
 msgstr "Hitta symboliska namn för givna referenser"
 
-#: command-list.h:132
+#: command-list.h:133
 msgid "Add or inspect object notes"
 msgstr "Lägg till eller inspektera objektanteckningar"
 
-#: command-list.h:133
+#: command-list.h:134
 msgid "Import from and submit to Perforce repositories"
 msgstr "Importera från eller sänd till Perforce-arkiv"
 
-#: command-list.h:134
+#: command-list.h:135
 msgid "Create a packed archive of objects"
 msgstr "Skapa ett packat arkiv med objekt"
 
-#: command-list.h:135
+#: command-list.h:136
 msgid "Find redundant pack files"
 msgstr "Hitta redundanta pack-filer"
 
-#: command-list.h:136
+#: command-list.h:137
 msgid "Pack heads and tags for efficient repository access"
 msgstr "Packa huvuden och taggar för effektiv arkivåtkomst"
 
-#: command-list.h:137
+#: command-list.h:138
 msgid "Routines to help parsing remote repository access parameters"
 msgstr ""
 "Rutiner för att göra det lättare att tolka åtkomstparametrar för fjärrarkiv"
 
-#: command-list.h:138
+#: command-list.h:139
 msgid "Compute unique ID for a patch"
 msgstr "Beräkna unik ID för en patch"
 
-#: command-list.h:139
+#: command-list.h:140
 msgid "Prune all unreachable objects from the object database"
 msgstr "Ta bort alla onåbara objekt från objektdatabasen"
 
-#: command-list.h:140
+#: command-list.h:141
 msgid "Remove extra objects that are already in pack files"
 msgstr "Ta bort extraobjekt som redan finns i pack-filerna"
 
-#: command-list.h:141
+#: command-list.h:142
 msgid "Fetch from and integrate with another repository or a local branch"
 msgstr "Hämta från och integrera med annat arkiv eller en lokal gren"
 
-#: command-list.h:142
+#: command-list.h:143
 msgid "Update remote refs along with associated objects"
 msgstr "Uppdatera fjärr-referenser och tillhörande objekt"
 
-#: command-list.h:143
+#: command-list.h:144
 msgid "Applies a quilt patchset onto the current branch"
 msgstr "Tillämpar en quilt-patchuppsättning på aktiv gren"
 
-#: command-list.h:144
+#: command-list.h:145
+msgid "Compare two commit ranges (e.g. two versions of a branch)"
+msgstr "Jämför två incheckningsintervall (dvs. två versioner av en gren)"
+
+#: command-list.h:146
 msgid "Reads tree information into the index"
 msgstr "Läser trädinformation in i indexet"
 
-#: command-list.h:145
+#: command-list.h:147
 msgid "Reapply commits on top of another base tip"
 msgstr "Applicera incheckningar på nytt ovanpå en annan bastopp"
 
-#: command-list.h:146
+#: command-list.h:148
 msgid "Receive what is pushed into the repository"
 msgstr "Ta emot det som sänds till arkivet"
 
-#: command-list.h:147
+#: command-list.h:149
 msgid "Manage reflog information"
 msgstr "Hantera referenslogg-information"
 
-#: command-list.h:148
+#: command-list.h:150
 msgid "Manage set of tracked repositories"
 msgstr "Hantera uppsättningen spårade arkiv"
 
-#: command-list.h:149
+#: command-list.h:151
 msgid "Pack unpacked objects in a repository"
 msgstr "Packa opackade objekt i ett arkiv"
 
-#: command-list.h:150
+#: command-list.h:152
 msgid "Create, list, delete refs to replace objects"
 msgstr "Skapa, visa, ta bort referenser för att ersätta objekt"
 
-#: command-list.h:151
+#: command-list.h:153
 msgid "Generates a summary of pending changes"
 msgstr "Skapar en sammanfattning av väntande ändringar"
 
-#: command-list.h:152
+#: command-list.h:154
 msgid "Reuse recorded resolution of conflicted merges"
 msgstr "Återanvänd sparad lösning av sammanslagningskonflikter"
 
-#: command-list.h:153
+#: command-list.h:155
 msgid "Reset current HEAD to the specified state"
 msgstr "Återställ aktuell HEAD till angivet tillstånd"
 
-#: command-list.h:154
+#: command-list.h:156
+msgid "Restore working tree files"
+msgstr "Återställ filer i arbetskatalogen"
+
+#: command-list.h:157
 msgid "Revert some existing commits"
 msgstr "Återställ några befintliga incheckningar"
 
-#: command-list.h:155
+#: command-list.h:158
 msgid "Lists commit objects in reverse chronological order"
 msgstr "Visa incheckningsobjekt i omvänd kronologisk ordning"
 
-#: command-list.h:156
+#: command-list.h:159
 msgid "Pick out and massage parameters"
 msgstr "Plocka ut och massera parametrar"
 
-#: command-list.h:157
+#: command-list.h:160
 msgid "Remove files from the working tree and from the index"
 msgstr "Ta bort filer från arbetskatalogen och från indexet"
 
-#: command-list.h:158
+#: command-list.h:161
 msgid "Send a collection of patches as emails"
 msgstr "Sänd en uppsättning patchar som e-post"
 
-#: command-list.h:159
+#: command-list.h:162
 msgid "Push objects over Git protocol to another repository"
 msgstr "Sänd objekt över Git-protokollet till annat arkiv"
 
-#: command-list.h:160
+#: command-list.h:163
 msgid "Restricted login shell for Git-only SSH access"
 msgstr "Begränsat inloggningsskal för SSH-åtkomst till bara Git"
 
-#: command-list.h:161
+#: command-list.h:164
 msgid "Summarize 'git log' output"
 msgstr "Summera \"git log\"-utdata"
 
-#: command-list.h:162
+#: command-list.h:165
 msgid "Show various types of objects"
 msgstr "Visa olika sorters objekt"
 
-#: command-list.h:163
+#: command-list.h:166
 msgid "Show branches and their commits"
 msgstr "Visa grenar och deras incheckningar"
 
-#: command-list.h:164
+#: command-list.h:167
 msgid "Show packed archive index"
 msgstr "Skapa packat arkivindex"
 
-#: command-list.h:165
+#: command-list.h:168
 msgid "List references in a local repository"
 msgstr "Visa referenser i ett lokalt arkiv"
 
-#: command-list.h:166
+#: command-list.h:169
 msgid "Git's i18n setup code for shell scripts"
 msgstr "Git:s i18n-startkod för skalskript"
 
-#: command-list.h:167
+#: command-list.h:170
 msgid "Common Git shell script setup code"
 msgstr "Gemensam skriptstartkod för Git"
 
-#: command-list.h:168
+#: command-list.h:171
+msgid "Initialize and modify the sparse-checkout"
+msgstr "Initiera och modifiera sparse-checkout"
+
+#: command-list.h:172
 msgid "Stash the changes in a dirty working directory away"
 msgstr "Spara undan ändringar i en lortig arbetskatalog"
 
-#: command-list.h:169
+#: command-list.h:173
 msgid "Add file contents to the staging area"
 msgstr "Lägg filinnehållet till indexet"
 
-#: command-list.h:170
+#: command-list.h:174
 msgid "Show the working tree status"
 msgstr "Visa status för arbetskatalogen"
 
-#: command-list.h:171
+#: command-list.h:175
 msgid "Remove unnecessary whitespace"
 msgstr "Ta bort onödiga blanksteg"
 
-#: command-list.h:172
+#: command-list.h:176
 msgid "Initialize, update or inspect submodules"
 msgstr "Initiera, uppdatera eller inspektera undermoduler"
 
-#: command-list.h:173
+#: command-list.h:177
 msgid "Bidirectional operation between a Subversion repository and Git"
 msgstr "Dubbelriktad verkan mellan ett Subversion-arkiv och Git"
 
-#: command-list.h:174
+#: command-list.h:178
+msgid "Switch branches"
+msgstr "Byt gren"
+
+#: command-list.h:179
 msgid "Read, modify and delete symbolic refs"
 msgstr "Läs, modifiera eller ta bort symbolisk referens"
 
-#: command-list.h:175
+#: command-list.h:180
 msgid "Create, list, delete or verify a tag object signed with GPG"
 msgstr "Skapa, visa, ta bort eller verifiera GPG-signerat taggobjekt"
 
-#: command-list.h:176
+#: command-list.h:181
 msgid "Creates a temporary file with a blob's contents"
 msgstr "Skapar temporära filer med innehållet från en blob"
 
-#: command-list.h:177
+#: command-list.h:182
 msgid "Unpack objects from a packed archive"
 msgstr "Packa upp objekt från ett pakat arkiv"
 
-#: command-list.h:178
+#: command-list.h:183
 msgid "Register file contents in the working tree to the index"
 msgstr "Registrera filinnehållet från arbetskatalogen i indexet"
 
-#: command-list.h:179
+#: command-list.h:184
 msgid "Update the object name stored in a ref safely"
 msgstr "Uppdatera objektnamnet i en referens på ett säkert sätt"
 
-#: command-list.h:180
+#: command-list.h:185
 msgid "Update auxiliary info file to help dumb servers"
 msgstr "Uppdatera tilläggsinfofil för att hjälpa dumma servrar"
 
-#: command-list.h:181
+#: command-list.h:186
 msgid "Send archive back to git-archive"
 msgstr "Sänd arkivet tillbaka till git-archive"
 
-#: command-list.h:182
+#: command-list.h:187
 msgid "Send objects packed back to git-fetch-pack"
 msgstr "Sänd packade objekt tillbaka till git-fetch-pack"
 
-#: command-list.h:183
+#: command-list.h:188
 msgid "Show a Git logical variable"
 msgstr "Visa en logisk Git-variabel"
 
-#: command-list.h:184
+#: command-list.h:189
 msgid "Check the GPG signature of commits"
 msgstr "Kontrollera GPG-signaturer för incheckningar"
 
-#: command-list.h:185
+#: command-list.h:190
 msgid "Validate packed Git archive files"
 msgstr "Bekräfta packade Git-arkivfiler"
 
-#: command-list.h:186
+#: command-list.h:191
 msgid "Check the GPG signature of tags"
 msgstr "Kontrollera GPG-signaturer i taggar"
 
-#: command-list.h:187
+#: command-list.h:192
 msgid "Git web interface (web frontend to Git repositories)"
 msgstr "Git-webbgränssnitt (webbframända för Git-arkiv)"
 
-#: command-list.h:188
+#: command-list.h:193
 msgid "Show logs with difference each commit introduces"
 msgstr "Visa loggar med differenser varje incheckning introducerar"
 
-#: command-list.h:189
+#: command-list.h:194
 msgid "Manage multiple working trees"
 msgstr "Hantera ytterligare arbetskataloger"
 
-#: command-list.h:190
+#: command-list.h:195
 msgid "Create a tree object from the current index"
 msgstr "Skapa ett trädobjekt från aktuellt index"
 
-#: command-list.h:191
+#: command-list.h:196
 msgid "Defining attributes per path"
 msgstr "Definierar attribut per sökväg"
 
-#: command-list.h:192
+#: command-list.h:197
 msgid "Git command-line interface and conventions"
 msgstr "Gits kommandoradsgränssnitt och -konventioner"
 
-#: command-list.h:193
+#: command-list.h:198
 msgid "A Git core tutorial for developers"
 msgstr "Grundläggande Git-handledning för utvecklare"
 
-#: command-list.h:194
+#: command-list.h:199
 msgid "Git for CVS users"
 msgstr "Git för CVS-användare"
 
-#: command-list.h:195
+#: command-list.h:200
 msgid "Tweaking diff output"
 msgstr "Justrea diff-utdata"
 
-#: command-list.h:196
+#: command-list.h:201
 msgid "A useful minimum set of commands for Everyday Git"
 msgstr "Ett användbart minsta uppsättning kommandon för vardags-Git"
 
-#: command-list.h:197
+#: command-list.h:202
 msgid "A Git Glossary"
 msgstr "En Git-ordlista"
 
-#: command-list.h:198
+#: command-list.h:203
 msgid "Hooks used by Git"
 msgstr "Krokar som används av Git"
 
-#: command-list.h:199
+#: command-list.h:204
 msgid "Specifies intentionally untracked files to ignore"
 msgstr "Ange avsiktligen ospårade filer att ignorera"
 
-#: command-list.h:200
+#: command-list.h:205
 msgid "Defining submodule properties"
 msgstr "Ange egenskaper för undermoduler"
 
-#: command-list.h:201
+#: command-list.h:206
 msgid "Git namespaces"
 msgstr "Git-namnrymder"
 
-#: command-list.h:202
+#: command-list.h:207
 msgid "Git Repository Layout"
 msgstr "Gits arkivlayout"
 
-#: command-list.h:203
+#: command-list.h:208
 msgid "Specifying revisions and ranges for Git"
 msgstr "Ange versioner och intervall i Git"
 
-#: command-list.h:204
+#: command-list.h:209
+msgid "Mounting one repository inside another"
+msgstr "Monterar ett arkiv inuti ett annat"
+
+#: command-list.h:210
 msgid "A tutorial introduction to Git: part two"
 msgstr "Introduktion till Git: del två"
 
-#: command-list.h:205
+#: command-list.h:211
 msgid "A tutorial introduction to Git"
 msgstr "Introduktion till Git"
 
-#: command-list.h:206
+#: command-list.h:212
 msgid "An overview of recommended workflows with Git"
 msgstr "Översikt över rekommenderade arbetsflöden med Git"
 
-#: rerere.h:40
-msgid "update the index with reused conflict resolution if possible"
-msgstr "uppdatera indexet med återanvänd konfliktlösning om möjligt"
-
 #: git-bisect.sh:54
 msgid "You need to start by \"git bisect start\""
 msgstr "Du måste starta med \"git bisect start\""
@@ -16075,140 +22566,49 @@ msgstr "Du måste starta med \"git bisec
 msgid "Do you want me to do it for you [Y/n]? "
 msgstr "Vill du att jag ska göra det åt dig [Y=ja/N=nej]? "
 
-#: git-bisect.sh:121
-#, sh-format
-msgid "unrecognised option: '$arg'"
-msgstr "flaggan känns inte igen: \"$arg\""
-
-#: git-bisect.sh:125
-#, sh-format
-msgid "'$arg' does not appear to be a valid revision"
-msgstr "\"$arg\" verkar inte vara en giltig revision"
-
-#: git-bisect.sh:154
-msgid "Bad HEAD - I need a HEAD"
-msgstr "Felaktigt HEAD - Jag behöver ett HEAD"
-
-#: git-bisect.sh:167
-#, sh-format
-msgid ""
-"Checking out '$start_head' failed. Try 'git bisect reset <valid-branch>'."
-msgstr ""
-"Misslyckades checka ut \"$start_head\". Försök \"git bisect reset "
-"<giltig_gren>”."
-
-# cogito-relaterat
-#: git-bisect.sh:177
-msgid "won't bisect on cg-seek'ed tree"
-msgstr "kör inte \"bisect\" på träd där \"cg-seek\" använts"
-
-#: git-bisect.sh:181
-msgid "Bad HEAD - strange symbolic ref"
-msgstr "Felaktigt HEAD - konstig symbolisk referens"
-
-#: git-bisect.sh:233
-#, sh-format
-msgid "Bad bisect_write argument: $state"
-msgstr "Felaktigt argument till bisect_write: $state"
-
-#: git-bisect.sh:246
+#: git-bisect.sh:101
 #, sh-format
 msgid "Bad rev input: $arg"
 msgstr "Felaktig rev-indata: $arg"
 
-#: git-bisect.sh:265
+#: git-bisect.sh:121
 #, sh-format
 msgid "Bad rev input: $bisected_head"
-msgstr "Felaktig rev-indata: $bisected_head"
-
-#: git-bisect.sh:274
-#, sh-format
-msgid "Bad rev input: $rev"
-msgstr "Felaktig rev-indata: $rev"
-
-#: git-bisect.sh:283
-#, sh-format
-msgid "'git bisect $TERM_BAD' can take only one argument."
-msgstr "\"git bisect $TERM_BAD\" kan bara ta ett argument."
-
-#: git-bisect.sh:306
-#, sh-format
-msgid "Warning: bisecting only with a $TERM_BAD commit."
-msgstr ""
-"Varning: utför \"bisect\" med endast en dålig (\"$TERM_BAD\") incheckning."
-
-#. TRANSLATORS: Make sure to include [Y] and [n] in your
-#. translation. The program will only accept English input
-#. at this point.
-#: git-bisect.sh:312
-msgid "Are you sure [Y/n]? "
-msgstr "Är du säker [Y=ja/N=nej]? "
-
-#: git-bisect.sh:324
-#, sh-format
-msgid ""
-"You need to give me at least one $bad_syn and one $good_syn revision.\n"
-"(You can use \"git bisect $bad_syn\" and \"git bisect $good_syn\" for that.)"
-msgstr ""
-"Du måste ange åtminstone en dålig (\"$bad_syn\") och en bra (\"$good_syn\") "
-"version.\n"
-"(Du kan använda \"git bisect $bad_syn\" och \"git bisect $good_syn\" för "
-"detta.)"
-
-#: git-bisect.sh:327
-#, sh-format
-msgid ""
-"You need to start by \"git bisect start\".\n"
-"You then need to give me at least one $good_syn and one $bad_syn revision.\n"
-"(You can use \"git bisect $bad_syn\" and \"git bisect $good_syn\" for that.)"
-msgstr ""
-"Du måste starta med \"git bisect start\".\n"
-"Du måste sedan ange åtminstone en bra (\"$good_syn\") och en dålig "
-"(\"$bad_syn\") version.\n"
-"(Du kan använda \"git bisect $bad_syn\" och \"git bisect $good_syn\" för "
-"detta.)"
-
-#: git-bisect.sh:398 git-bisect.sh:512
-msgid "We are not bisecting."
-msgstr "Vi utför ingen bisect för tillfället."
+msgstr "Felaktig rev-indata: $bisected_head"
 
-#: git-bisect.sh:405
+#: git-bisect.sh:130
 #, sh-format
-msgid "'$invalid' is not a valid commit"
-msgstr "\"$invalid\" är inte en giltig incheckning"
+msgid "Bad rev input: $rev"
+msgstr "Felaktig rev-indata: $rev"
 
-#: git-bisect.sh:414
+#: git-bisect.sh:139
 #, sh-format
-msgid ""
-"Could not check out original HEAD '$branch'.\n"
-"Try 'git bisect reset <commit>'."
-msgstr ""
-"Kunde inte checka ut original-HEAD \"$branch\".\n"
-"Försök \"git bisect reset <incheckning>\"."
+msgid "'git bisect $TERM_BAD' can take only one argument."
+msgstr "\"git bisect $TERM_BAD\" kan bara ta ett argument."
 
-#: git-bisect.sh:422
+#: git-bisect.sh:209
 msgid "No logfile given"
 msgstr "Ingen loggfil angiven"
 
-#: git-bisect.sh:423
+#: git-bisect.sh:210
 #, sh-format
 msgid "cannot read $file for replaying"
 msgstr "kan inte läsa $file för uppspelning"
 
-#: git-bisect.sh:444
+#: git-bisect.sh:232
 msgid "?? what are you talking about?"
 msgstr "?? vad menar du?"
 
-#: git-bisect.sh:453
+#: git-bisect.sh:241
 msgid "bisect run failed: no command provided."
 msgstr "bisect-körning misslyckades: inget kommando gavs."
 
-#: git-bisect.sh:458
+#: git-bisect.sh:246
 #, sh-format
 msgid "running $command"
 msgstr "kör $command"
 
-#: git-bisect.sh:465
+#: git-bisect.sh:253
 #, sh-format
 msgid ""
 "bisect run failed:\n"
@@ -16217,11 +22617,11 @@ msgstr ""
 "\"bisect\"-körningen misslyckades:\n"
 "felkod $res från \"$command\" är < 0 eller >= 128"
 
-#: git-bisect.sh:491
+#: git-bisect.sh:279
 msgid "bisect run cannot continue any more"
 msgstr "\"bisect\"-körningen kan inte fortsätta längre"
 
-#: git-bisect.sh:497
+#: git-bisect.sh:285
 #, sh-format
 msgid ""
 "bisect run failed:\n"
@@ -16230,28 +22630,13 @@ msgstr ""
 "\"bisect\"-körningen misslyckades:\n"
 "\"bisect_state $state\" avslutades med felkoden $res"
 
-#: git-bisect.sh:504
+#: git-bisect.sh:292
 msgid "bisect run success"
 msgstr "\"bisect\"-körningen lyckades"
 
-#: git-bisect.sh:533
-#, sh-format
-msgid "Invalid command: you're currently in a $TERM_BAD/$TERM_GOOD bisect."
-msgstr ""
-"Ogiltigt kommando: du utför just nu en \"bisect\" med $TERM_BAD/$TERM_GOOD."
-
-#: git-bisect.sh:567
-msgid "no terms defined"
-msgstr "inga termer angivna"
-
-#: git-bisect.sh:584
-#, sh-format
-msgid ""
-"invalid argument $arg for 'git bisect terms'.\n"
-"Supported options are: --term-good|--term-old and --term-bad|--term-new."
-msgstr ""
-"ogiltigt argument $arg för \"git bisect terms\".\n"
-"Flaggor som stöds är: --term-good|--term-old och --term-bad|--term-new."
+#: git-bisect.sh:300
+msgid "We are not bisecting."
+msgstr "Vi utför ingen bisect för tillfället."
 
 #: git-merge-octopus.sh:46
 msgid ""
@@ -16293,326 +22678,113 @@ msgstr "Försök enkel sammanslagning me
 msgid "Simple merge did not work, trying automatic merge."
 msgstr "Enkel sammanslagning misslyckades, försöker automatisk sammanslagning."
 
-#: git-rebase.sh:61
-msgid ""
-"Resolve all conflicts manually, mark them as resolved with\n"
-"\"git add/rm <conflicted_files>\", then run \"git rebase --continue\".\n"
-"You can instead skip this commit: run \"git rebase --skip\".\n"
-"To abort and get back to the state before \"git rebase\", run \"git rebase --"
-"abort\"."
-msgstr ""
-"Lös alla konflikter manuellt, märk dem som lösta med\n"
-"\"git add/rm <filer_i_konflikt>\", kör sedan \"git rebase --continue\".\n"
-"Du kan hoppa över incheckningen istället: kör \"git rebase --skip\".\n"
-"För att avbryta och återgå till där du var före ombaseringen, kör \"git "
-"rebase --abort\"."
-
-#: git-rebase.sh:173 git-rebase.sh:442
-#, sh-format
-msgid "Could not move back to $head_name"
-msgstr "Kunde inte flytta tillbaka till $head_name"
-
-#: git-rebase.sh:184
-msgid "Applied autostash."
-msgstr "Tillämpade autostash."
-
-#: git-rebase.sh:187
-#, sh-format
-msgid "Cannot store $stash_sha1"
-msgstr "Kan inte spara $stash_sha1"
-
-#: git-rebase.sh:229
-msgid "The pre-rebase hook refused to rebase."
-msgstr "Kroken pre-rebase vägrade ombaseringen."
-
-#: git-rebase.sh:234
-msgid "It looks like 'git am' is in progress. Cannot rebase."
-msgstr "Det verkar som en \"git am\" körs. Kan inte ombasera."
-
-#: git-rebase.sh:403
-msgid "No rebase in progress?"
-msgstr "Ingen ombasering pågår?"
-
-#: git-rebase.sh:414
-msgid "The --edit-todo action can only be used during interactive rebase."
-msgstr "Åtgärden --edit-todo kan endast användas under interaktiv ombasering."
-
-#: git-rebase.sh:421
-msgid "Cannot read HEAD"
-msgstr "Kan inte läsa HEAD"
-
-#: git-rebase.sh:424
-msgid ""
-"You must edit all merge conflicts and then\n"
-"mark them as resolved using git add"
-msgstr ""
-"Du måste redigera alla sammanslagningskonflikter och\n"
-"därefter markera dem som lösta med git add"
-
-#: git-rebase.sh:468
-#, sh-format
-msgid ""
-"It seems that there is already a $state_dir_base directory, and\n"
-"I wonder if you are in the middle of another rebase.  If that is the\n"
-"case, please try\n"
-"\t$cmd_live_rebase\n"
-"If that is not the case, please\n"
-"\t$cmd_clear_stale_rebase\n"
-"and run me again.  I am stopping in case you still have something\n"
-"valuable there."
-msgstr ""
-"Det verkar som katalogen $state_dir_base redan existerar, och\n"
-"jag undrar om du redan är mitt i en annan ombasering. Om så är\n"
-"fallet, försök\n"
-"\t$cmd_live_rebase\n"
-"Om så inte är fallet, kör\n"
-"\t$cmd_clear_stale_rebase\n"
-"och kör programmet igen. Jag avslutar ifall du fortfarande har\n"
-"något av värde där."
-
-#: git-rebase.sh:509
-msgid "error: cannot combine '--signoff' with '--preserve-merges'"
-msgstr "fel: kan inte kombinera \"--signoff\" med \"--preserve-merges\""
-
-#: git-rebase.sh:537
-#, sh-format
-msgid "invalid upstream '$upstream_name'"
-msgstr "ogiltig uppström \"$upstream_name\""
-
-#: git-rebase.sh:561
-#, sh-format
-msgid "$onto_name: there are more than one merge bases"
-msgstr "$onto_name: mer än en sammanslagningsbas finns"
-
-#: git-rebase.sh:564 git-rebase.sh:568
-#, sh-format
-msgid "$onto_name: there is no merge base"
-msgstr "$onto_name: ingen sammanslagningsbas finns"
-
-#: git-rebase.sh:573
-#, sh-format
-msgid "Does not point to a valid commit: $onto_name"
-msgstr "Peka på en giltig incheckning: $onto_name"
-
-#: git-rebase.sh:599
-#, sh-format
-msgid "fatal: no such branch/commit '$branch_name'"
-msgstr "ödesdigert: ingen sådan gren/incheckning: $branch_name"
-
-#: git-rebase.sh:632
-msgid "Cannot autostash"
-msgstr "Kan inte utföra \"autostash\""
-
-#: git-rebase.sh:637
-#, sh-format
-msgid "Created autostash: $stash_abbrev"
-msgstr "Skapade autostash: $stash_abbrev"
-
-#: git-rebase.sh:641
-msgid "Please commit or stash them."
-msgstr "Checka in eller använd \"stash\" på dem."
-
-#: git-rebase.sh:664
-#, sh-format
-msgid "HEAD is up to date."
-msgstr "HEAD är à jour."
-
-#: git-rebase.sh:666
-#, sh-format
-msgid "Current branch $branch_name is up to date."
-msgstr "Aktuell gren $branch_name är à jour."
-
-#: git-rebase.sh:674
-#, sh-format
-msgid "HEAD is up to date, rebase forced."
-msgstr "HEAD är à jour, ombasering framtvingad."
-
-#: git-rebase.sh:676
-#, sh-format
-msgid "Current branch $branch_name is up to date, rebase forced."
-msgstr "Aktuell gren $branch_name är à jour, ombasering framtvingad."
-
-#: git-rebase.sh:688
-#, sh-format
-msgid "Changes from $mb to $onto:"
-msgstr "Ändringar från $mb till $onto:"
-
-#: git-rebase.sh:697
-msgid "First, rewinding head to replay your work on top of it..."
-msgstr ""
-"Först, spolar tillbaka huvudet för att spela av ditt arbete ovanpå det..."
-
-#: git-rebase.sh:707
-#, sh-format
-msgid "Fast-forwarded $branch_name to $onto_name."
-msgstr "Snabbspolade $branch_name till $onto_name."
-
-#: git-stash.sh:61
-msgid "git stash clear with parameters is unimplemented"
-msgstr "\"git stash clear\" med parametrar har inte implementerats"
-
-#: git-stash.sh:108
-msgid "You do not have the initial commit yet"
-msgstr "Du har inte den första incheckningen ännu"
-
-#: git-stash.sh:123
-msgid "Cannot save the current index state"
-msgstr "Kan inte spara aktuellt tillstånd för indexet"
-
-#: git-stash.sh:138
-msgid "Cannot save the untracked files"
-msgstr "Kan inte spara ospårade filer"
-
-#: git-stash.sh:158 git-stash.sh:171
-msgid "Cannot save the current worktree state"
-msgstr "Kan inte spara aktuellt tillstånd för arbetskatalogen"
-
-#: git-stash.sh:175
-msgid "No changes selected"
-msgstr "Inga ändringar valda"
-
-#: git-stash.sh:178
+#: git-legacy-stash.sh:221
 msgid "Cannot remove temporary index (can't happen)"
 msgstr "Kan inte ta bort temporärt index (kan inte inträffa)"
 
-#: git-stash.sh:191
-msgid "Cannot record working tree state"
-msgstr "Kan inte registrera tillstånd för arbetskatalog"
-
-#: git-stash.sh:229
+#: git-legacy-stash.sh:272
 #, sh-format
 msgid "Cannot update $ref_stash with $w_commit"
 msgstr "Kan inte uppdatera $ref_stash med $w_commit"
 
-#: git-stash.sh:281
+#: git-legacy-stash.sh:324
 #, sh-format
 msgid "error: unknown option for 'stash push': $option"
 msgstr "fel: okänd flagga för \"stash push\": $option"
 
-#: git-stash.sh:295
-msgid "Can't use --patch and --include-untracked or --all at the same time"
-msgstr "Kan inte använda --patch och --include-untracked eller --all samtidigt"
-
-#: git-stash.sh:303
-msgid "No local changes to save"
-msgstr "Inga lokala ändringar att spara"
-
-#: git-stash.sh:308
-msgid "Cannot initialize stash"
-msgstr "Kan inte initiera \"stash\""
-
-#: git-stash.sh:312
-msgid "Cannot save the current status"
-msgstr "Kan inte spara aktuell status"
-
-#: git-stash.sh:313
+#: git-legacy-stash.sh:356
 #, sh-format
 msgid "Saved working directory and index state $stash_msg"
 msgstr "Sparade arbetskatalogen och indexstatus $stash_msg"
 
-#: git-stash.sh:342
-msgid "Cannot remove worktree changes"
-msgstr "Kan inte ta bort ändringar i arbetskatalogen"
-
-#: git-stash.sh:490
+#: git-legacy-stash.sh:536
 #, sh-format
 msgid "unknown option: $opt"
 msgstr "okänd flagga: $opt"
 
-#: git-stash.sh:503
-msgid "No stash entries found."
-msgstr "Inga \"stash”-poster hittades."
-
-#: git-stash.sh:510
+#: git-legacy-stash.sh:556
 #, sh-format
 msgid "Too many revisions specified: $REV"
 msgstr "För många revisioner angivna: $REV"
 
-#: git-stash.sh:525
+#: git-legacy-stash.sh:571
 #, sh-format
 msgid "$reference is not a valid reference"
 msgstr "$reference är inte en giltig referens"
 
-#: git-stash.sh:553
+#: git-legacy-stash.sh:599
 #, sh-format
 msgid "'$args' is not a stash-like commit"
 msgstr "\"$args\" är inte en \"stash\"-liknande incheckning"
 
-#: git-stash.sh:564
+#: git-legacy-stash.sh:610
 #, sh-format
 msgid "'$args' is not a stash reference"
 msgstr "\"$args\" är inte en \"stash\"-referens"
 
-#: git-stash.sh:572
+#: git-legacy-stash.sh:618
 msgid "unable to refresh index"
 msgstr "kan inte uppdatera indexet"
 
-#: git-stash.sh:576
+#: git-legacy-stash.sh:622
 msgid "Cannot apply a stash in the middle of a merge"
 msgstr "Kan inte tillämpa en \"stash\" mitt i en sammanslagning"
 
-#: git-stash.sh:584
+#: git-legacy-stash.sh:630
 msgid "Conflicts in index. Try without --index."
 msgstr "Konflikter i indexet. Testa utan --index."
 
-#: git-stash.sh:586
+#: git-legacy-stash.sh:632
 msgid "Could not save index tree"
 msgstr "Kunde inte spara indexträd"
 
-#: git-stash.sh:595
+#: git-legacy-stash.sh:641
 msgid "Could not restore untracked files from stash entry"
 msgstr "Kunde inte återställa ospårade filer från stash-post"
 
-#: git-stash.sh:620
+#: git-legacy-stash.sh:666
 msgid "Cannot unstage modified files"
 msgstr "Kan inte ta bort ändrade filer ur kön"
 
-#: git-stash.sh:635
-msgid "Index was not unstashed."
-msgstr "Indexet har inte tagits ur kön."
-
-#: git-stash.sh:649
-msgid "The stash entry is kept in case you need it again."
-msgstr "Stash-posten behålls ifall du behöver den igen."
-
-#: git-stash.sh:658
+#: git-legacy-stash.sh:704
 #, sh-format
 msgid "Dropped ${REV} ($s)"
 msgstr "Kastade ${REV} ($s)"
 
-#: git-stash.sh:659
+#: git-legacy-stash.sh:705
 #, sh-format
 msgid "${REV}: Could not drop stash entry"
 msgstr "${REV}: Kunde inte kasta \"stash\"-post"
 
-#: git-stash.sh:667
-msgid "No branch name specified"
-msgstr "Inget grennamn angavs"
-
-#: git-stash.sh:746
+#: git-legacy-stash.sh:792
 msgid "(To restore them type \"git stash apply\")"
 msgstr "(För att återställa dem, skriv \"git stash apply\")"
 
-#: git-submodule.sh:188
+#: git-submodule.sh:202
 msgid "Relative path can only be used from the toplevel of the working tree"
 msgstr "Relativ sökväg kan endast användas från arbetskatalogens toppnivå"
 
-#: git-submodule.sh:198
+#: git-submodule.sh:212
 #, sh-format
 msgid "repo URL: '$repo' must be absolute or begin with ./|../"
 msgstr "arkiv-URL: \"$repo\" måste vara absolut eller börja med ./|../"
 
-#: git-submodule.sh:217
+#: git-submodule.sh:231
 #, sh-format
 msgid "'$sm_path' already exists in the index"
 msgstr "\"$sm_path\" finns redan i indexet"
 
-#: git-submodule.sh:220
+#: git-submodule.sh:234
 #, sh-format
 msgid "'$sm_path' already exists in the index and is not a submodule"
 msgstr "\"$sm_path\" finns redan i indexet och är inte en undermodul"
 
-#: git-submodule.sh:226
+#: git-submodule.sh:241
+#, sh-format
+msgid "'$sm_path' does not have a commit checked out"
+msgstr "\"$sm_path\" har inte någon utcheckad incheckning"
+
+#: git-submodule.sh:247
 #, sh-format
 msgid ""
 "The following path is ignored by one of your .gitignore files:\n"
@@ -16623,22 +22795,22 @@ msgstr ""
 "$sm_path\n"
 "Använd -f om du verkligen vill lägga till den."
 
-#: git-submodule.sh:249
+#: git-submodule.sh:270
 #, sh-format
 msgid "Adding existing repo at '$sm_path' to the index"
 msgstr "Lägger till befintligt arkiv i \"$sm_path\" i indexet"
 
-#: git-submodule.sh:251
+#: git-submodule.sh:272
 #, sh-format
 msgid "'$sm_path' already exists and is not a valid git repo"
 msgstr "\"$sm_path\" finns redan och är inte ett giltigt git-arkiv"
 
-#: git-submodule.sh:259
+#: git-submodule.sh:280
 #, sh-format
 msgid "A git directory for '$sm_name' is found locally with remote(s):"
 msgstr "En git-katalog för \"$sm_name\" hittades lokalt med fjärr(ar):"
 
-#: git-submodule.sh:261
+#: git-submodule.sh:282
 #, sh-format
 msgid ""
 "If you want to reuse this local git directory instead of cloning again from\n"
@@ -16656,48 +22828,37 @@ msgstr ""
 "arkiv eller om du är osäker på vad det här betyder, välj ett annat namn med\n"
 "flaggan \"--name\"."
 
-#: git-submodule.sh:267
+#: git-submodule.sh:288
 #, sh-format
 msgid "Reactivating local git directory for submodule '$sm_name'."
 msgstr "Aktiverar lokal git-katalog för undermodulen \"$sm_name\" på nytt."
 
-#: git-submodule.sh:279
+#: git-submodule.sh:300
 #, sh-format
 msgid "Unable to checkout submodule '$sm_path'"
 msgstr "Kan inte checka ut undermodulen \"$sm_path\""
 
-#: git-submodule.sh:284
+#: git-submodule.sh:305
 #, sh-format
 msgid "Failed to add submodule '$sm_path'"
 msgstr "Misslyckades lägga till undermodulen \"$sm_path\""
 
-#: git-submodule.sh:293
+#: git-submodule.sh:314
 #, sh-format
 msgid "Failed to register submodule '$sm_path'"
 msgstr "Misslyckades registrera undermodulen \"$sm_path\""
 
-#: git-submodule.sh:354
-#, sh-format
-msgid "Entering '$displaypath'"
-msgstr "Går in i \"$displaypath\""
-
-#: git-submodule.sh:374
-#, sh-format
-msgid "Stopping at '$displaypath'; script returned non-zero status."
-msgstr ""
-"Stoppar på \"$displaypath\"; skriptet returnerade en status skild från noll."
-
-#: git-submodule.sh:600
+#: git-submodule.sh:580
 #, sh-format
 msgid "Unable to find current revision in submodule path '$displaypath'"
 msgstr "Kan inte hitta aktuell revision i undermodulsökvägen \"$displaypath\""
 
-#: git-submodule.sh:610
+#: git-submodule.sh:590
 #, sh-format
 msgid "Unable to fetch in submodule path '$sm_path'"
 msgstr "Kan inte hämta i undermodulsökväg \"$sm_path\""
 
-#: git-submodule.sh:615
+#: git-submodule.sh:595
 #, sh-format
 msgid ""
 "Unable to find current ${remote_name}/${branch} revision in submodule path "
@@ -16706,12 +22867,16 @@ msgstr ""
 "Kan inte hitta aktuell revision för ${remote_name}/${branch} i "
 "undermodulsökvägen \"$sm_path\""
 
-#: git-submodule.sh:633
+#: git-submodule.sh:613
 #, sh-format
-msgid "Unable to fetch in submodule path '$displaypath'"
-msgstr "Kan inte hämta i undermodulsökväg \"$displaypath\""
+msgid ""
+"Unable to fetch in submodule path '$displaypath'; trying to directly fetch "
+"$sha1:"
+msgstr ""
+"Kan inte hämta i undermodulsökväg \"$displaypath\"; försökte hämta $sha1 "
+"direkt:"
 
-#: git-submodule.sh:639
+#: git-submodule.sh:619
 #, sh-format
 msgid ""
 "Fetched in submodule path '$displaypath', but it did not contain $sha1. "
@@ -16720,72 +22885,72 @@ msgstr ""
 "Hämtade i undermodulssökvägen \"$displaypath\", men den innehöll inte $sha1. "
 "Direkt hämtning av incheckningen misslyckades."
 
-#: git-submodule.sh:646
+#: git-submodule.sh:626
 #, sh-format
 msgid "Unable to checkout '$sha1' in submodule path '$displaypath'"
 msgstr "Kan inte checka ut \"$sha1\" i undermodulsökvägen \"$displaypath\""
 
-#: git-submodule.sh:647
+#: git-submodule.sh:627
 #, sh-format
 msgid "Submodule path '$displaypath': checked out '$sha1'"
 msgstr "Undermodulsökvägen \"$displaypath\": checkade ut \"$sha1\""
 
-#: git-submodule.sh:651
+#: git-submodule.sh:631
 #, sh-format
 msgid "Unable to rebase '$sha1' in submodule path '$displaypath'"
 msgstr "Kan inte ombasera \"$sha1\" i undermodulsökvägen \"$displaypath\""
 
-#: git-submodule.sh:652
+#: git-submodule.sh:632
 #, sh-format
 msgid "Submodule path '$displaypath': rebased into '$sha1'"
 msgstr "Undermodulsökvägen \"$displaypath\": ombaserade in i \"$sha1\""
 
-#: git-submodule.sh:657
+#: git-submodule.sh:637
 #, sh-format
 msgid "Unable to merge '$sha1' in submodule path '$displaypath'"
 msgstr "Kan inte slå ihop \"$sha1\" i undermodulsökvägen \"$displaypath\""
 
-#: git-submodule.sh:658
+#: git-submodule.sh:638
 #, sh-format
 msgid "Submodule path '$displaypath': merged in '$sha1'"
 msgstr "Undermodulsökvägen \"$displaypath\": sammanslagen i \"$sha1\""
 
-#: git-submodule.sh:663
+#: git-submodule.sh:643
 #, sh-format
 msgid "Execution of '$command $sha1' failed in submodule path '$displaypath'"
 msgstr ""
 "Misslyckades köra \"$command $sha1\" i undermodulsökvägen \"$displaypath\""
 
-#: git-submodule.sh:664
+#: git-submodule.sh:644
 #, sh-format
 msgid "Submodule path '$displaypath': '$command $sha1'"
 msgstr "Undermodulsökvägen \"$displaypath\": \"$command $sha1\""
 
-#: git-submodule.sh:695
+#: git-submodule.sh:675
 #, sh-format
 msgid "Failed to recurse into submodule path '$displaypath'"
 msgstr "Misslyckades rekursera in i undermodulsökvägen \"$displaypath\""
 
-#: git-submodule.sh:791
+#: git-submodule.sh:886
 msgid "The --cached option cannot be used with the --files option"
 msgstr "Flaggan --cached kan inte användas med flaggan --files"
 
-#: git-submodule.sh:843
+#: git-submodule.sh:938
 #, sh-format
 msgid "unexpected mode $mod_dst"
 msgstr "oväntat läge $mod_dst"
 
-#: git-submodule.sh:863
+#: git-submodule.sh:958
 #, sh-format
 msgid "  Warn: $display_name doesn't contain commit $sha1_src"
 msgstr "  Varning: $display_name innehåller inte incheckningen $sha1_src"
 
-#: git-submodule.sh:866
+#: git-submodule.sh:961
 #, sh-format
 msgid "  Warn: $display_name doesn't contain commit $sha1_dst"
 msgstr "  Varning: $display_name innehåller inte incheckningen $sha1_dst"
 
-#: git-submodule.sh:869
+#: git-submodule.sh:964
 #, sh-format
 msgid "  Warn: $display_name doesn't contain commits $sha1_src and $sha1_dst"
 msgstr ""
@@ -16797,12 +22962,21 @@ msgstr ""
 msgid "See git-${cmd}(1) for details."
 msgstr "Se git-${cmd}(1) för detaljer."
 
-#: git-rebase--interactive.sh:142
+#: git-rebase--preserve-merges.sh:109
+msgid "Applied autostash."
+msgstr "Tillämpade autostash."
+
+#: git-rebase--preserve-merges.sh:112
+#, sh-format
+msgid "Cannot store $stash_sha1"
+msgstr "Kan inte spara $stash_sha1"
+
+#: git-rebase--preserve-merges.sh:191
 #, sh-format
 msgid "Rebasing ($new_count/$total)"
 msgstr "Ombaserar ($new_count/$total)"
 
-#: git-rebase--interactive.sh:158
+#: git-rebase--preserve-merges.sh:207
 msgid ""
 "\n"
 "Commands:\n"
@@ -16811,7 +22985,7 @@ msgid ""
 "e, edit <commit> = use commit, but stop for amending\n"
 "s, squash <commit> = use commit, but meld into previous commit\n"
 "f, fixup <commit> = like \"squash\", but discard this commit's log message\n"
-"x, exec <command> = run command (the rest of the line) using shell\n"
+"x, exec <commit> = run command (the rest of the line) using shell\n"
 "d, drop <commit> = remove commit\n"
 "l, label <label> = label current HEAD with a name\n"
 "t, reset <label> = reset HEAD to a label\n"
@@ -16832,7 +23006,7 @@ msgstr ""
 "incheckning\n"
 "f, fixup <incheckning> = som \"squash\", men förkasta "
 "incheckningsmeddelandet\n"
-"x, exec <kommando> = kör kommando (resten av raden) i skalet\n"
+"x, exec <incheckning> = kör kommando (resten av raden) i skalet\n"
 "d, drop <incheckning> = ta bort incheckning\n"
 "l, label <etikett> = ge aktuellt HEAD ett namn\n"
 "t, reset <etikett> = återställ HEAD till en etikett\n"
@@ -16843,24 +23017,7 @@ msgstr ""
 "\n"
 "Du kan byta ordning på raderna; de utförs uppifrån och ned.\n"
 
-#: git-rebase--interactive.sh:179
-msgid ""
-"\n"
-"Do not remove any line. Use 'drop' explicitly to remove a commit.\n"
-msgstr ""
-"\n"
-"Ta inte bort rader. Använd \"drop\" för att specifikt förkasta en "
-"incheckning.\n"
-
-#: git-rebase--interactive.sh:183
-msgid ""
-"\n"
-"If you remove a line here THAT COMMIT WILL BE LOST.\n"
-msgstr ""
-"\n"
-"Om du tar bort en rad KOMMER DEN INCHECKNINGEN ATT FÖRLORAS.\n"
-
-#: git-rebase--interactive.sh:221
+#: git-rebase--preserve-merges.sh:270
 #, sh-format
 msgid ""
 "You can amend the commit now, with\n"
@@ -16879,83 +23036,83 @@ msgstr ""
 "\n"
 "\tgit rebase --continue"
 
-#: git-rebase--interactive.sh:246
+#: git-rebase--preserve-merges.sh:295
 #, sh-format
 msgid "$sha1: not a commit that can be picked"
 msgstr "$sha1: inte en incheckning som kan väljas"
 
-#: git-rebase--interactive.sh:285
+#: git-rebase--preserve-merges.sh:334
 #, sh-format
 msgid "Invalid commit name: $sha1"
 msgstr "Felaktigt incheckningsnamn: $sha1"
 
-#: git-rebase--interactive.sh:325
+#: git-rebase--preserve-merges.sh:364
 msgid "Cannot write current commit's replacement sha1"
 msgstr "Kan inte skriva ersättnings-sha1 för aktuell incheckning"
 
-#: git-rebase--interactive.sh:376
+#: git-rebase--preserve-merges.sh:415
 #, sh-format
 msgid "Fast-forward to $sha1"
 msgstr "Snabbspolade till $sha1"
 
-#: git-rebase--interactive.sh:378
+#: git-rebase--preserve-merges.sh:417
 #, sh-format
 msgid "Cannot fast-forward to $sha1"
 msgstr "Kan inte snabbspola till $sha1"
 
-#: git-rebase--interactive.sh:387
+#: git-rebase--preserve-merges.sh:426
 #, sh-format
 msgid "Cannot move HEAD to $first_parent"
 msgstr "Kan inte flytta HEAD till $first_parent"
 
-#: git-rebase--interactive.sh:392
+#: git-rebase--preserve-merges.sh:431
 #, sh-format
 msgid "Refusing to squash a merge: $sha1"
 msgstr "Vägrar utföra \"squash\" på en sammanslagning: $sha1"
 
-#: git-rebase--interactive.sh:410
+#: git-rebase--preserve-merges.sh:449
 #, sh-format
 msgid "Error redoing merge $sha1"
 msgstr "Fel när sammanslagningen $sha1 skulle göras om"
 
-#: git-rebase--interactive.sh:419
+#: git-rebase--preserve-merges.sh:458
 #, sh-format
 msgid "Could not pick $sha1"
 msgstr "Kunde inte välja $sha1"
 
-#: git-rebase--interactive.sh:428
+#: git-rebase--preserve-merges.sh:467
 #, sh-format
 msgid "This is the commit message #${n}:"
 msgstr "Det här är incheckningsmeddelande ${n}:"
 
-#: git-rebase--interactive.sh:433
+#: git-rebase--preserve-merges.sh:472
 #, sh-format
 msgid "The commit message #${n} will be skipped:"
 msgstr "Incheckningsmeddelande ${n} kommer hoppas över:"
 
-#: git-rebase--interactive.sh:444
+#: git-rebase--preserve-merges.sh:483
 #, sh-format
 msgid "This is a combination of $count commit."
 msgid_plural "This is a combination of $count commits."
 msgstr[0] "Det här är en kombination av $count incheckning."
 msgstr[1] "Det här är en kombination av $count incheckningar."
 
-#: git-rebase--interactive.sh:453
+#: git-rebase--preserve-merges.sh:492
 #, sh-format
 msgid "Cannot write $fixup_msg"
 msgstr "Kan inte skriva $fixup_msg"
 
-#: git-rebase--interactive.sh:456
+#: git-rebase--preserve-merges.sh:495
 msgid "This is a combination of 2 commits."
 msgstr "Det här är en kombination av 2 incheckningar."
 
-#: git-rebase--interactive.sh:497 git-rebase--interactive.sh:540
-#: git-rebase--interactive.sh:543
+#: git-rebase--preserve-merges.sh:536 git-rebase--preserve-merges.sh:579
+#: git-rebase--preserve-merges.sh:582
 #, sh-format
 msgid "Could not apply $sha1... $rest"
 msgstr "Kunde inte tillämpa $sha1... $rest"
 
-#: git-rebase--interactive.sh:572
+#: git-rebase--preserve-merges.sh:611
 #, sh-format
 msgid ""
 "Could not amend commit after successfully picking $sha1... $rest\n"
@@ -16969,31 +23126,31 @@ msgstr ""
 "pre-commit-kroken misslyckades. Om pre-commit-kroken misslyckades kanske\n"
 "du måste lösa problemet innan du kan skriva om incheckningsmeddelandet."
 
-#: git-rebase--interactive.sh:587
+#: git-rebase--preserve-merges.sh:626
 #, sh-format
 msgid "Stopped at $sha1_abbrev... $rest"
 msgstr "Stoppade på $sha1_abbrev... $rest"
 
-#: git-rebase--interactive.sh:602
+#: git-rebase--preserve-merges.sh:641
 #, sh-format
 msgid "Cannot '$squash_style' without a previous commit"
 msgstr "Kan inte utföra \"$squash_style\" utan en föregående incheckning"
 
-#: git-rebase--interactive.sh:644
+#: git-rebase--preserve-merges.sh:683
 #, sh-format
 msgid "Executing: $rest"
 msgstr "Kör: $rest"
 
-#: git-rebase--interactive.sh:652
+#: git-rebase--preserve-merges.sh:691
 #, sh-format
 msgid "Execution failed: $rest"
 msgstr "Körning misslyckades: $rest"
 
-#: git-rebase--interactive.sh:654
+#: git-rebase--preserve-merges.sh:693
 msgid "and made changes to the index and/or the working tree"
 msgstr "och gjorde ändringar till indexet och/eller arbetskatalogen"
 
-#: git-rebase--interactive.sh:656
+#: git-rebase--preserve-merges.sh:695
 msgid ""
 "You can fix the problem, and then run\n"
 "\n"
@@ -17004,7 +23161,7 @@ msgstr ""
 "\tgit rebase --continue"
 
 #. TRANSLATORS: after these lines is a command to be issued by the user
-#: git-rebase--interactive.sh:669
+#: git-rebase--preserve-merges.sh:708
 #, sh-format
 msgid ""
 "Execution succeeded: $rest\n"
@@ -17019,29 +23176,25 @@ msgstr ""
 "\n"
 "\tgit rebase --continue"
 
-#: git-rebase--interactive.sh:680
+#: git-rebase--preserve-merges.sh:719
 #, sh-format
 msgid "Unknown command: $command $sha1 $rest"
 msgstr "Okänt kommando: $command $sha1 $rest"
 
-#: git-rebase--interactive.sh:681
+#: git-rebase--preserve-merges.sh:720
 msgid "Please fix this using 'git rebase --edit-todo'."
 msgstr "Rätta det med \"git rebase --edit-todo\"."
 
-#: git-rebase--interactive.sh:716
+#: git-rebase--preserve-merges.sh:755
 #, sh-format
 msgid "Successfully rebased and updated $head_name."
 msgstr "Lyckades ombasera och uppdatera $head_name."
 
-#: git-rebase--interactive.sh:740
-msgid "could not detach HEAD"
-msgstr "kunde inte koppla från HEAD"
-
-#: git-rebase--interactive.sh:778
+#: git-rebase--preserve-merges.sh:812
 msgid "Could not remove CHERRY_PICK_HEAD"
 msgstr "Kunde inte ta bort CHERRY_PICK_HEAD"
 
-#: git-rebase--interactive.sh:783
+#: git-rebase--preserve-merges.sh:817
 #, sh-format
 msgid ""
 "You have staged changes in your working tree.\n"
@@ -17072,86 +23225,52 @@ msgstr ""
 "\n"
 "  git rebase --continue\n"
 
-#: git-rebase--interactive.sh:800
+#: git-rebase--preserve-merges.sh:834
 msgid "Error trying to find the author identity to amend commit"
 msgstr "Fel vid försök att hitta författaridentitet för att utöka incheckning"
 
-#: git-rebase--interactive.sh:805
+#: git-rebase--preserve-merges.sh:839
 msgid ""
 "You have uncommitted changes in your working tree. Please commit them\n"
 "first and then run 'git rebase --continue' again."
 msgstr ""
 "Du har ändringar i arbetskatalogen som inte checkats in. Checka in dem\n"
-"först och kör sedan \"git rebase --continute\" igen."
+"först och kör sedan \"git rebase --continue\" igen."
 
-#: git-rebase--interactive.sh:810 git-rebase--interactive.sh:814
+#: git-rebase--preserve-merges.sh:844 git-rebase--preserve-merges.sh:848
 msgid "Could not commit staged changes."
 msgstr "Kunde inte checka in köade ändringar."
 
-#: git-rebase--interactive.sh:843
-msgid ""
-"\n"
-"You are editing the todo file of an ongoing interactive rebase.\n"
-"To continue rebase after editing, run:\n"
-"    git rebase --continue\n"
-"\n"
-msgstr ""
-"\n"
-"Du redigerar \"todo\"-filen för en pågående interaktiv ombasering.\n"
-"För att forsätta ombasera efter redigeringen, kör:\n"
-"    git rebase --continue\n"
-"\n"
-
-#: git-rebase--interactive.sh:851 git-rebase--interactive.sh:937
+#: git-rebase--preserve-merges.sh:879 git-rebase--preserve-merges.sh:965
 msgid "Could not execute editor"
 msgstr "Kunde inte starta textredigerare"
 
-#: git-rebase--interactive.sh:872
+#: git-rebase--preserve-merges.sh:900
 #, sh-format
 msgid "Could not checkout $switch_to"
 msgstr "Kunde inte checka ut $switch_to"
 
-#: git-rebase--interactive.sh:879
+#: git-rebase--preserve-merges.sh:907
 msgid "No HEAD?"
 msgstr "Inget HEAD?"
 
-#: git-rebase--interactive.sh:880
+#: git-rebase--preserve-merges.sh:908
 #, sh-format
 msgid "Could not create temporary $state_dir"
 msgstr "Kunde inte skapa temporär $state_dir"
 
-#: git-rebase--interactive.sh:883
+#: git-rebase--preserve-merges.sh:911
 msgid "Could not mark as interactive"
 msgstr "Kunde inte markera som interaktiv"
 
-#: git-rebase--interactive.sh:915
+#: git-rebase--preserve-merges.sh:943
 #, sh-format
 msgid "Rebase $shortrevisions onto $shortonto ($todocount command)"
 msgid_plural "Rebase $shortrevisions onto $shortonto ($todocount commands)"
 msgstr[0] "Ombasera $shortrevisions på $shortonto ($todocount incheckning)"
 msgstr[1] "Ombasera $shortrevisions på $shortonto ($todocount incheckningar)"
 
-#: git-rebase--interactive.sh:920
-msgid ""
-"\n"
-"\tHowever, if you remove everything, the rebase will be aborted.\n"
-"\n"
-"\t"
-msgstr ""
-"\n"
-"\tOmbaseringen kommer dock att avbrytas om du tar bort allting.\n"
-"\n"
-"\t"
-
-#: git-rebase--interactive.sh:927
-msgid "Note that empty commits are commented out"
-msgstr "Observera att tomma incheckningar är utkommenterade"
-
-#: git-rebase--interactive.sh:980
-msgid "Could not generate todo list"
-msgstr "Kunde inte skapa todo-lista"
-
-#: git-rebase--interactive.sh:1001 git-rebase--interactive.sh:1006
+#: git-rebase--preserve-merges.sh:997 git-rebase--preserve-merges.sh:1002
 msgid "Could not init rewritten commits"
 msgstr "Kunde inte initiera omskrivna incheckningar"
 
@@ -17160,137 +23279,75 @@ msgstr "Kunde inte initiera omskrivna in
 msgid "usage: $dashless $USAGE"
 msgstr "använd: $dashless $USAGE"
 
-#: git-sh-setup.sh:190
+#: git-sh-setup.sh:191
 #, sh-format
 msgid "Cannot chdir to $cdup, the toplevel of the working tree"
 msgstr "Kunde inte byta katalog till $cdup, toppnivån på arbetskatalogen"
 
-#: git-sh-setup.sh:199 git-sh-setup.sh:206
+#: git-sh-setup.sh:200 git-sh-setup.sh:207
 #, sh-format
 msgid "fatal: $program_name cannot be used without a working tree."
 msgstr "ödesdigetrt: $program_name kan inte användas utan arbetskatalog."
 
-#: git-sh-setup.sh:220
+#: git-sh-setup.sh:221
 msgid "Cannot rebase: You have unstaged changes."
 msgstr "Kan inte ombasera: Du har oköade ändringar."
 
-#: git-sh-setup.sh:223
+#: git-sh-setup.sh:224
 msgid "Cannot rewrite branches: You have unstaged changes."
 msgstr "Kan inte skriva om grenar: Du har oköade ändringar."
 
-#: git-sh-setup.sh:226
+#: git-sh-setup.sh:227
 msgid "Cannot pull with rebase: You have unstaged changes."
 msgstr "Kan inte hämta med ombasering: Du har oköade ändringar."
 
-#: git-sh-setup.sh:229
+#: git-sh-setup.sh:230
 #, sh-format
 msgid "Cannot $action: You have unstaged changes."
 msgstr "Kan inte $action: Du har oköade ändringar."
 
-#: git-sh-setup.sh:242
+#: git-sh-setup.sh:243
 msgid "Cannot rebase: Your index contains uncommitted changes."
 msgstr ""
 "Kan inte ombasera: Ditt index innehåller ändringar som inte checkats in."
 
-#: git-sh-setup.sh:245
+#: git-sh-setup.sh:246
 msgid "Cannot pull with rebase: Your index contains uncommitted changes."
 msgstr ""
 "Kan inte hämta med ombasering: Ditt index innehåller oincheckade ändringar."
 
-#: git-sh-setup.sh:248
+#: git-sh-setup.sh:249
 #, sh-format
 msgid "Cannot $action: Your index contains uncommitted changes."
 msgstr ""
 "Kan inte $action: Ditt index innehåller ändringar som inte checkats in."
 
-#: git-sh-setup.sh:252
+#: git-sh-setup.sh:253
 msgid "Additionally, your index contains uncommitted changes."
 msgstr "Dessutom innehåller dit index ändringar som inte har checkats in."
 
-#: git-sh-setup.sh:372
+#: git-sh-setup.sh:373
 msgid "You need to run this command from the toplevel of the working tree."
-msgstr "Du måste köra kommandot från arbetskatalogens toppnivå."
-
-#: git-sh-setup.sh:377
-msgid "Unable to determine absolute path of git directory"
-msgstr "Kunde inte bestämma absolut sökväg till git-katalogen"
-
-#. TRANSLATORS: you can adjust this to align "git add -i" status menu
-#: git-add--interactive.perl:196
-#, perl-format
-msgid "%12s %12s %s"
-msgstr "%12s %12s %s"
-
-#: git-add--interactive.perl:197
-msgid "staged"
-msgstr "köad"
-
-#: git-add--interactive.perl:197
-msgid "unstaged"
-msgstr "ej köad"
-
-#: git-add--interactive.perl:253 git-add--interactive.perl:278
-msgid "binary"
-msgstr "binär"
-
-#: git-add--interactive.perl:262 git-add--interactive.perl:316
-msgid "nothing"
-msgstr "ingenting"
-
-#: git-add--interactive.perl:298 git-add--interactive.perl:313
-msgid "unchanged"
-msgstr "oändrad"
-
-#: git-add--interactive.perl:609
-#, perl-format
-msgid "added %d path\n"
-msgid_plural "added %d paths\n"
-msgstr[0] "lade till %d sökväg\n"
-msgstr[1] "lade till %d sökvägar\n"
-
-#: git-add--interactive.perl:612
-#, perl-format
-msgid "updated %d path\n"
-msgid_plural "updated %d paths\n"
-msgstr[0] "uppdaterade %d sökväg\n"
-msgstr[1] "uppdaterade %d sökvägar\n"
+msgstr "Du måste köra kommandot från arbetskatalogens toppnivå."
+
+#: git-sh-setup.sh:378
+msgid "Unable to determine absolute path of git directory"
+msgstr "Kunde inte bestämma absolut sökväg till git-katalogen"
 
-#: git-add--interactive.perl:615
+#. TRANSLATORS: you can adjust this to align "git add -i" status menu
+#: git-add--interactive.perl:212
 #, perl-format
-msgid "reverted %d path\n"
-msgid_plural "reverted %d paths\n"
-msgstr[0] "återställde %d sökväg\n"
-msgstr[1] "återställde %d sökvägar\n"
+msgid "%12s %12s %s"
+msgstr "%12s %12s %s"
 
-#: git-add--interactive.perl:618
+#: git-add--interactive.perl:634
 #, perl-format
 msgid "touched %d path\n"
 msgid_plural "touched %d paths\n"
 msgstr[0] "rörde %d sökväg\n"
 msgstr[1] "rörde %d sökvägar\n"
 
-#: git-add--interactive.perl:627
-msgid "Update"
-msgstr "Uppdatera"
-
-#: git-add--interactive.perl:639
-msgid "Revert"
-msgstr "Återställ"
-
-#: git-add--interactive.perl:662
-#, perl-format
-msgid "note: %s is untracked now.\n"
-msgstr "observera: %s spåras inte längre.\n"
-
-#: git-add--interactive.perl:673
-msgid "Add untracked"
-msgstr "Lägg till ospårad"
-
-#: git-add--interactive.perl:679
-msgid "No untracked files.\n"
-msgstr "Inga ospårade filer.\n"
-
-#: git-add--interactive.perl:1033
+#: git-add--interactive.perl:1053
 msgid ""
 "If the patch applies cleanly, the edited hunk will immediately be\n"
 "marked for staging."
@@ -17298,7 +23355,7 @@ msgstr ""
 "Om patchen kan appliceras rent kommer det redigerade stycket att\n"
 "köas omedelbart."
 
-#: git-add--interactive.perl:1036
+#: git-add--interactive.perl:1056
 msgid ""
 "If the patch applies cleanly, the edited hunk will immediately be\n"
 "marked for stashing."
@@ -17306,7 +23363,7 @@ msgstr ""
 "Om patchen kan appliceras rent kommer det redigerade stycket att\n"
 "läggas till i \"stash\" omedelbart."
 
-#: git-add--interactive.perl:1039
+#: git-add--interactive.perl:1059
 msgid ""
 "If the patch applies cleanly, the edited hunk will immediately be\n"
 "marked for unstaging."
@@ -17314,7 +23371,8 @@ msgstr ""
 "Om patchen kan appliceras rent kommer det redigerade stycket att\n"
 "tas bort från kön omedelbart."
 
-#: git-add--interactive.perl:1042 git-add--interactive.perl:1051
+#: git-add--interactive.perl:1062 git-add--interactive.perl:1071
+#: git-add--interactive.perl:1077
 msgid ""
 "If the patch applies cleanly, the edited hunk will immediately be\n"
 "marked for applying."
@@ -17322,7 +23380,8 @@ msgstr ""
 "Om patchen kan appliceras rent kommer det redigerade stycket att\n"
 "markeras för applicering omedelbart."
 
-#: git-add--interactive.perl:1045 git-add--interactive.perl:1048
+#: git-add--interactive.perl:1065 git-add--interactive.perl:1068
+#: git-add--interactive.perl:1074
 msgid ""
 "If the patch applies cleanly, the edited hunk will immediately be\n"
 "marked for discarding."
@@ -17330,16 +23389,12 @@ msgstr ""
 "Om patchen kan appliceras rent kommer det redigerade stycket att\n"
 "markeras för kasta omedelbart."
 
-#: git-add--interactive.perl:1085
+#: git-add--interactive.perl:1111
 #, perl-format
 msgid "failed to open hunk edit file for writing: %s"
 msgstr "misslyckades öppna styckeredigeringsfil för skrivning: %s"
 
-#: git-add--interactive.perl:1086
-msgid "Manual hunk edit mode -- see bottom for a quick guide.\n"
-msgstr "Manuellt styckeredigeringsläge -- se nederst för snabbguide.\n"
-
-#: git-add--interactive.perl:1092
+#: git-add--interactive.perl:1118
 #, perl-format
 msgid ""
 "---\n"
@@ -17352,36 +23407,12 @@ msgstr ""
 "Ta bort \"%s\" rader genom att radera dem.\n"
 "Rader som börjar med %s kommer att tas bort.\n"
 
-#. TRANSLATORS: 'it' refers to the patch mentioned in the previous messages.
-#: git-add--interactive.perl:1100
-msgid ""
-"If it does not apply cleanly, you will be given an opportunity to\n"
-"edit again.  If all lines of the hunk are removed, then the edit is\n"
-"aborted and the hunk is left unchanged.\n"
-msgstr ""
-"Om patchen inte kan appliceras rent kommer du få en möjlighet att\n"
-"redigera den igen. Om alla rader i ett stycke tas bort avbryts\n"
-"redigeringen och stycket lämnas oförändrat.\n"
-
-#: git-add--interactive.perl:1114
+#: git-add--interactive.perl:1140
 #, perl-format
 msgid "failed to open hunk edit file for reading: %s"
 msgstr "misslyckades öppna styckesredigeringsfil för läsning: %s"
 
-#. TRANSLATORS: do not translate [y/n]
-#. The program will only accept that input
-#. at this point.
-#. Consider translating (saying "no" discards!) as
-#. (saying "n" for "no" discards!) if the translation
-#. of the word "no" does not start with n.
-#: git-add--interactive.perl:1213
-msgid ""
-"Your edited hunk does not apply. Edit again (saying \"no\" discards!) [y/n]? "
-msgstr ""
-"Ditt redigerade stycke kan inte appliceras. Redigera igen (\"nej\" kastar!) "
-"[y/n]? "
-
-#: git-add--interactive.perl:1222
+#: git-add--interactive.perl:1248
 msgid ""
 "y - stage this hunk\n"
 "n - do not stage this hunk\n"
@@ -17395,7 +23426,7 @@ msgstr ""
 "a - köa stycket och alla följande i filen\n"
 "d - köa inte stycket eller något av de följande i filen"
 
-#: git-add--interactive.perl:1228
+#: git-add--interactive.perl:1254
 msgid ""
 "y - stash this hunk\n"
 "n - do not stash this hunk\n"
@@ -17409,7 +23440,7 @@ msgstr ""
 "a - \"stash\":a stycket och alla följande i filen\n"
 "d - \"stash\":a inte stycket eller något av de följande i filen"
 
-#: git-add--interactive.perl:1234
+#: git-add--interactive.perl:1260
 msgid ""
 "y - unstage this hunk\n"
 "n - do not unstage this hunk\n"
@@ -17423,7 +23454,7 @@ msgstr ""
 "a - ta bort stycket och alla följande i filen från kön\n"
 "d - ta inte bort stycket eller något av de följande i filen från kön"
 
-#: git-add--interactive.perl:1240
+#: git-add--interactive.perl:1266
 msgid ""
 "y - apply this hunk to index\n"
 "n - do not apply this hunk to index\n"
@@ -17437,7 +23468,7 @@ msgstr ""
 "a - applicera stycket och alla följande i filen\n"
 "d - applicera inte stycket eller något av de följande i filen"
 
-#: git-add--interactive.perl:1246
+#: git-add--interactive.perl:1272 git-add--interactive.perl:1290
 msgid ""
 "y - discard this hunk from worktree\n"
 "n - do not discard this hunk from worktree\n"
@@ -17451,7 +23482,7 @@ msgstr ""
 "a - förkasta stycket och alla följande i filen\n"
 "d - förkasta inte stycket eller något av de följande i filen"
 
-#: git-add--interactive.perl:1252
+#: git-add--interactive.perl:1278
 msgid ""
 "y - discard this hunk from index and worktree\n"
 "n - do not discard this hunk from index and worktree\n"
@@ -17465,7 +23496,7 @@ msgstr ""
 "a - förkasta stycket och alla följande i filen\n"
 "d - förkasta inte stycket eller något av de följande i filen"
 
-#: git-add--interactive.perl:1258
+#: git-add--interactive.perl:1284
 msgid ""
 "y - apply this hunk to index and worktree\n"
 "n - do not apply this hunk to index and worktree\n"
@@ -17479,7 +23510,21 @@ msgstr ""
 "a - applicera stycket och alla följande i filen\n"
 "d - applicera inte stycket eller något av de följande i filen"
 
-#: git-add--interactive.perl:1273
+#: git-add--interactive.perl:1296
+msgid ""
+"y - apply this hunk to worktree\n"
+"n - do not apply this hunk to worktree\n"
+"q - quit; do not apply this hunk or any of the remaining ones\n"
+"a - apply this hunk and all later hunks in the file\n"
+"d - do not apply this hunk or any of the later hunks in the file"
+msgstr ""
+"y - applicera stycket på arbetskatalogen\n"
+"n - applicera inte stycket på arbetskatalogen\n"
+"q - avsluta; applicera inte stycket eller något av de följande\n"
+"a - applicera stycket och alla följande i filen\n"
+"d - applicera inte stycket eller något av de följande i filen"
+
+#: git-add--interactive.perl:1311
 msgid ""
 "g - select a hunk to go to\n"
 "/ - search for a hunk matching the given regex\n"
@@ -17501,211 +23546,198 @@ msgstr ""
 "e - redigera aktuellt stycke manuellt\n"
 "? - visa hjälp\n"
 
-#: git-add--interactive.perl:1304
+#: git-add--interactive.perl:1342
 msgid "The selected hunks do not apply to the index!\n"
 msgstr "Markerade stycken kan inte appliceras på indexet!\n"
 
-#: git-add--interactive.perl:1305
+#: git-add--interactive.perl:1343
 msgid "Apply them to the worktree anyway? "
 msgstr "Applicera dem på arbetskatalogen trots det? "
 
-#: git-add--interactive.perl:1308
+#: git-add--interactive.perl:1346
 msgid "Nothing was applied.\n"
 msgstr "Ingenting applicerades.\n"
 
-#: git-add--interactive.perl:1319
+#: git-add--interactive.perl:1357
 #, perl-format
 msgid "ignoring unmerged: %s\n"
 msgstr "ignorerar ej sammanslagen: %s\n"
 
-#: git-add--interactive.perl:1328
-msgid "Only binary files changed.\n"
-msgstr "Endast binära filer ändrade.\n"
-
-#: git-add--interactive.perl:1330
-msgid "No changes.\n"
-msgstr "Inga ändringar.\n"
-
-#: git-add--interactive.perl:1338
-msgid "Patch update"
-msgstr "Uppdatera patch"
-
-#: git-add--interactive.perl:1390
+#: git-add--interactive.perl:1428
 #, perl-format
 msgid "Stage mode change [y,n,q,a,d%s,?]? "
 msgstr "Köa ändrat läge [y,n,q,a,d%s,?]? "
 
-#: git-add--interactive.perl:1391
+#: git-add--interactive.perl:1429
 #, perl-format
 msgid "Stage deletion [y,n,q,a,d%s,?]? "
 msgstr "Köa borttagning [y,n,q,a,d%s,?]? "
 
-#: git-add--interactive.perl:1392
+#: git-add--interactive.perl:1430
 #, perl-format
 msgid "Stage this hunk [y,n,q,a,d%s,?]? "
 msgstr "Köa stycket [y,n,q,a,d%s,?]? "
 
-#: git-add--interactive.perl:1395
+#: git-add--interactive.perl:1433
 #, perl-format
 msgid "Stash mode change [y,n,q,a,d%s,?]? "
 msgstr "Stash:a ändrat läge [y,n,q,a,d%s,?]? "
 
-#: git-add--interactive.perl:1396
+#: git-add--interactive.perl:1434
 #, perl-format
 msgid "Stash deletion [y,n,q,a,d%s,?]? "
 msgstr "Stash:a borttagning [y,n,q,a,d%s,?]? "
 
-#: git-add--interactive.perl:1397
+#: git-add--interactive.perl:1435
 #, perl-format
 msgid "Stash this hunk [y,n,q,a,d%s,?]? "
 msgstr "Stash:a stycket [y,n,q,a,d%s,?]? "
 
-#: git-add--interactive.perl:1400
+#: git-add--interactive.perl:1438
 #, perl-format
 msgid "Unstage mode change [y,n,q,a,d%s,?]? "
 msgstr "Ta bort ändrat läge från kön [y,n,q,a,d%s,?]? "
 
-#: git-add--interactive.perl:1401
+#: git-add--interactive.perl:1439
 #, perl-format
 msgid "Unstage deletion [y,n,q,a,d%s,?]? "
 msgstr "Ta bort borttagning från kön [y,n,q,a,d%s,?]? "
 
-#: git-add--interactive.perl:1402
+#: git-add--interactive.perl:1440
 #, perl-format
 msgid "Unstage this hunk [y,n,q,a,d%s,?]? "
 msgstr "Ta bort stycket från kön [y,n,q,a,d%s,?]? "
 
-#: git-add--interactive.perl:1405
+#: git-add--interactive.perl:1443
 #, perl-format
 msgid "Apply mode change to index [y,n,q,a,d%s,?]? "
 msgstr "Applicera ändrat läge på indexet [y,n,q,a,d%s,?]? "
 
-#: git-add--interactive.perl:1406
+#: git-add--interactive.perl:1444
 #, perl-format
 msgid "Apply deletion to index [y,n,q,a,d%s,?]? "
 msgstr "Applicera borttagning på indexet [y,n,q,a,d%s,?]? "
 
-#: git-add--interactive.perl:1407
+#: git-add--interactive.perl:1445
 #, perl-format
 msgid "Apply this hunk to index [y,n,q,a,d%s,?]? "
 msgstr "Applicera stycket på indexet [y,n,q,a,d%s,?]? "
 
-#: git-add--interactive.perl:1410
+#: git-add--interactive.perl:1448 git-add--interactive.perl:1463
 #, perl-format
 msgid "Discard mode change from worktree [y,n,q,a,d%s,?]? "
 msgstr "Kasta ändrat läge från arbetskatalogen [y,n,q,a,d%s,?]? "
 
-#: git-add--interactive.perl:1411
+#: git-add--interactive.perl:1449 git-add--interactive.perl:1464
 #, perl-format
 msgid "Discard deletion from worktree [y,n,q,a,d%s,?]? "
 msgstr "Kasta borttagning från arbetskatalogen [y,n,q,a,d%s,?]? "
 
-#: git-add--interactive.perl:1412
+#: git-add--interactive.perl:1450 git-add--interactive.perl:1465
 #, perl-format
 msgid "Discard this hunk from worktree [y,n,q,a,d%s,?]? "
 msgstr "Kasta stycket från arbetskatalogen [y,n,q,a,d%s,?]? "
 
-#: git-add--interactive.perl:1415
+#: git-add--interactive.perl:1453
 #, perl-format
 msgid "Discard mode change from index and worktree [y,n,q,a,d%s,?]? "
 msgstr "Kasta ändrat läge från indexet och arbetskatalogen [y,n,q,a,d%s,?]? "
 
-#: git-add--interactive.perl:1416
+#: git-add--interactive.perl:1454
 #, perl-format
 msgid "Discard deletion from index and worktree [y,n,q,a,d%s,?]? "
 msgstr "Kasta borttagning från indexet och arbetskatalogen [y,n,q,a,d%s,?]? "
 
-#: git-add--interactive.perl:1417
+#: git-add--interactive.perl:1455
 #, perl-format
 msgid "Discard this hunk from index and worktree [y,n,q,a,d%s,?]? "
 msgstr "Kasta stycket från indexet och arbetskatalogen [y,n,q,a,d%s,?]? "
 
-#: git-add--interactive.perl:1420
+#: git-add--interactive.perl:1458
 #, perl-format
 msgid "Apply mode change to index and worktree [y,n,q,a,d%s,?]? "
 msgstr "Applicera ändrat läge på indexet och arbetskatalogen [y,n,q,a,d%s,?]? "
 
-#: git-add--interactive.perl:1421
+#: git-add--interactive.perl:1459
 #, perl-format
 msgid "Apply deletion to index and worktree [y,n,q,a,d%s,?]? "
 msgstr "Applicera borttagning på indexet och arbetskatalogen [y,n,q,a,d%s,?]? "
 
-#: git-add--interactive.perl:1422
+#: git-add--interactive.perl:1460
 #, perl-format
 msgid "Apply this hunk to index and worktree [y,n,q,a,d%s,?]? "
 msgstr "Applicera stycket på indexet och arbetskatalogen [y,n,q,a,d%s,?]? "
 
-#: git-add--interactive.perl:1522
-msgid "No other hunks to goto\n"
-msgstr "Inga andra stycken att gå till\n"
+#: git-add--interactive.perl:1468
+#, perl-format
+msgid "Apply mode change to worktree [y,n,q,a,d%s,?]? "
+msgstr "Applicera ändrat läge på arbetskatalogen [y,n,q,a,d%s,?]? "
 
-#: git-add--interactive.perl:1529
-msgid "go to which hunk (<ret> to see more)? "
-msgstr "gå till vilket stycke (<ret> för att se fler)? "
+#: git-add--interactive.perl:1469
+#, perl-format
+msgid "Apply deletion to worktree [y,n,q,a,d%s,?]? "
+msgstr "Applicera borttagning på arbetskatalogen [y,n,q,a,d%s,?]? "
 
-#: git-add--interactive.perl:1531
-msgid "go to which hunk? "
-msgstr "gå till vilket stycke? "
+#: git-add--interactive.perl:1470
+#, perl-format
+msgid "Apply this hunk to worktree [y,n,q,a,d%s,?]? "
+msgstr "Applicera stycket på arbetskatalogen [y,n,q,a,d%s,?]? "
+
+#: git-add--interactive.perl:1570
+msgid "No other hunks to goto\n"
+msgstr "Inga andra stycken att gå till\n"
 
-#: git-add--interactive.perl:1540
+#: git-add--interactive.perl:1588
 #, perl-format
 msgid "Invalid number: '%s'\n"
 msgstr "Ogiltigt siffervärde: \"%s\"\n"
 
-#: git-add--interactive.perl:1545
+#: git-add--interactive.perl:1593
 #, perl-format
 msgid "Sorry, only %d hunk available.\n"
 msgid_plural "Sorry, only %d hunks available.\n"
 msgstr[0] "Beklagar, det finns bara %d stycke.\n"
 msgstr[1] "Beklagar, det finns bara %d stycken.\n"
 
-#: git-add--interactive.perl:1571
+#: git-add--interactive.perl:1619
 msgid "No other hunks to search\n"
 msgstr "Inga andra stycken att söka efter\n"
 
-#: git-add--interactive.perl:1575
-msgid "search for regex? "
-msgstr "sök efter reguljärt uttryck? "
-
-#: git-add--interactive.perl:1588
+#: git-add--interactive.perl:1636
 #, perl-format
 msgid "Malformed search regexp %s: %s\n"
 msgstr "Felaktigt format på reguljärt sökuttryck %s: %s\n"
 
-#: git-add--interactive.perl:1598
+#: git-add--interactive.perl:1646
 msgid "No hunk matches the given pattern\n"
 msgstr "Inga stycken motsvarar givet mönster\n"
 
-#: git-add--interactive.perl:1610 git-add--interactive.perl:1632
+#: git-add--interactive.perl:1658 git-add--interactive.perl:1680
 msgid "No previous hunk\n"
 msgstr "Inget föregående stycke\n"
 
-#: git-add--interactive.perl:1619 git-add--interactive.perl:1638
+#: git-add--interactive.perl:1667 git-add--interactive.perl:1686
 msgid "No next hunk\n"
 msgstr "Inget följande stycke\n"
 
-#: git-add--interactive.perl:1644
+#: git-add--interactive.perl:1692
 msgid "Sorry, cannot split this hunk\n"
 msgstr "Beklagar, kan inte dela stycket\n"
 
-#: git-add--interactive.perl:1650
+#: git-add--interactive.perl:1698
 #, perl-format
 msgid "Split into %d hunk.\n"
 msgid_plural "Split into %d hunks.\n"
 msgstr[0] "Dela i %d stycke.\n"
 msgstr[1] "Dela i %d stycken.\n"
 
-#: git-add--interactive.perl:1660
+#: git-add--interactive.perl:1708
 msgid "Sorry, cannot edit this hunk\n"
 msgstr "Beklagar, kan inte redigera stycket\n"
 
-#: git-add--interactive.perl:1706
-msgid "Review diff"
-msgstr "Granska diff"
-
 #. TRANSLATORS: please do not translate the command names
 #. 'status', 'update', 'revert', etc.
-#: git-add--interactive.perl:1725
+#: git-add--interactive.perl:1773
 msgid ""
 "status        - show paths with changes\n"
 "update        - add working tree state to the staged set of changes\n"
@@ -17722,55 +23754,56 @@ msgstr ""
 "diff          - visa diff mellan HEAD och index\n"
 "add untracked - lägg till innehåll i ospårade filer till köade ändringar\n"
 
-#: git-add--interactive.perl:1742 git-add--interactive.perl:1747
-#: git-add--interactive.perl:1750 git-add--interactive.perl:1757
-#: git-add--interactive.perl:1761 git-add--interactive.perl:1767
+#: git-add--interactive.perl:1790 git-add--interactive.perl:1795
+#: git-add--interactive.perl:1798 git-add--interactive.perl:1805
+#: git-add--interactive.perl:1808 git-add--interactive.perl:1815
+#: git-add--interactive.perl:1819 git-add--interactive.perl:1825
 msgid "missing --"
 msgstr "saknad --"
 
-#: git-add--interactive.perl:1763
+#: git-add--interactive.perl:1821
 #, perl-format
 msgid "unknown --patch mode: %s"
 msgstr "okänt läge för --patch: %s"
 
-#: git-add--interactive.perl:1769 git-add--interactive.perl:1775
+#: git-add--interactive.perl:1827 git-add--interactive.perl:1833
 #, perl-format
 msgid "invalid argument %s, expecting --"
 msgstr "felaktigt argument %s, förväntar --"
 
-#: git-send-email.perl:130
+#: git-send-email.perl:138
 msgid "local zone differs from GMT by a non-minute interval\n"
 msgstr "lokal zon skiljer sig från GMT med delar av minuter\n"
 
-#: git-send-email.perl:137 git-send-email.perl:143
+#: git-send-email.perl:145 git-send-email.perl:151
 msgid "local time offset greater than or equal to 24 hours\n"
 msgstr "lokal tidszonförskjutning större än eller lika med 24 timmar\n"
 
-#: git-send-email.perl:211 git-send-email.perl:217
+#: git-send-email.perl:223 git-send-email.perl:229
 msgid "the editor exited uncleanly, aborting everything"
 msgstr "textredigeringsprogrammet avslutades med fel, avbryter allting"
 
-#: git-send-email.perl:294
+#: git-send-email.perl:310
 #, perl-format
 msgid ""
 "'%s' contains an intermediate version of the email you were composing.\n"
 msgstr ""
 "\"%s\" innehåller en mellanliggande version av e-postbrevet du skrev.\n"
 
-#: git-send-email.perl:299
+#: git-send-email.perl:315
 #, perl-format
 msgid "'%s.final' contains the composed email.\n"
 msgstr "\"%s.final\" innehåller det skrivna brevet.\n"
 
-#: git-send-email.perl:317
+#: git-send-email.perl:408
 msgid "--dump-aliases incompatible with other options\n"
 msgstr "--dump-alias är inkompatibelt med andra flaggor\n"
 
-#: git-send-email.perl:383 git-send-email.perl:638
+#: git-send-email.perl:481 git-send-email.perl:683
 msgid "Cannot run git format-patch from outside a repository\n"
 msgstr "Kan inte köra git format-patch från utanför arkivet\n"
 
-#: git-send-email.perl:386
+#: git-send-email.perl:484
 msgid ""
 "`batch-size` and `relogin` must be specified together (via command-line or "
 "configuration option)\n"
@@ -17778,37 +23811,37 @@ msgstr ""
 "\"batch-size\" och \"relogin\" måste anges tillsammans (via kommandorad "
 "eller konfigurationsflagga)\n"
 
-#: git-send-email.perl:456
+#: git-send-email.perl:497
 #, perl-format
 msgid "Unknown --suppress-cc field: '%s'\n"
 msgstr "Okänt fält i --suppress-cc: \"%s\"\n"
 
-#: git-send-email.perl:485
+#: git-send-email.perl:528
 #, perl-format
 msgid "Unknown --confirm setting: '%s'\n"
 msgstr "Okänd inställning i --confirm: \"%s\"\n"
 
-#: git-send-email.perl:513
+#: git-send-email.perl:556
 #, perl-format
 msgid "warning: sendmail alias with quotes is not supported: %s\n"
 msgstr "varning: sendmail-alias med citationstecken stöds inte. %s\n"
 
-#: git-send-email.perl:515
+#: git-send-email.perl:558
 #, perl-format
 msgid "warning: `:include:` not supported: %s\n"
 msgstr "varning: \":include:\" stöds inte: %s\n"
 
-#: git-send-email.perl:517
+#: git-send-email.perl:560
 #, perl-format
 msgid "warning: `/file` or `|pipe` redirection not supported: %s\n"
 msgstr "varning: omdirigering til \"/fil\" eller \"|rör\" stöds inte: %s\n"
 
-#: git-send-email.perl:522
+#: git-send-email.perl:565
 #, perl-format
 msgid "warning: sendmail line is not recognized: %s\n"
 msgstr "varning: sendmail-raden känns inte igen: %s\n"
 
-#: git-send-email.perl:604
+#: git-send-email.perl:649
 #, perl-format
 msgid ""
 "File '%s' exists but it could also be the range of commits\n"
@@ -17823,12 +23856,12 @@ msgstr ""
 "    * Säga \"./%s\" om du menar en fil; eller\n"
 "    * Ange flaggan --format-patch om du menar ett intervall.\n"
 
-#: git-send-email.perl:625
+#: git-send-email.perl:670
 #, perl-format
 msgid "Failed to opendir %s: %s"
 msgstr "Misslyckades utföra opendir %s: %s"
 
-#: git-send-email.perl:649
+#: git-send-email.perl:694
 #, perl-format
 msgid ""
 "fatal: %s: %s\n"
@@ -17837,7 +23870,7 @@ msgstr ""
 "ödesdigert: %s: %s\n"
 "varning: inga patchar har sänts\n"
 
-#: git-send-email.perl:660
+#: git-send-email.perl:705
 msgid ""
 "\n"
 "No patch files specified!\n"
@@ -17847,17 +23880,17 @@ msgstr ""
 "Inga patchfiler angavs!\n"
 "\n"
 
-#: git-send-email.perl:673
+#: git-send-email.perl:718
 #, perl-format
 msgid "No subject line in %s?"
 msgstr "Ingen ärenderad i %s?"
 
-#: git-send-email.perl:683
+#: git-send-email.perl:728
 #, perl-format
 msgid "Failed to open for writing %s: %s"
 msgstr "Kunde inte öppna för skrivning %s: %s"
 
-#: git-send-email.perl:694
+#: git-send-email.perl:739
 msgid ""
 "Lines beginning in \"GIT:\" will be removed.\n"
 "Consider including an overall diffstat or table of contents\n"
@@ -17871,38 +23904,38 @@ msgstr ""
 "\n"
 "Rensa brevkroppen om du inte vill sända någon sammanfattning.\n"
 
-#: git-send-email.perl:718
+#: git-send-email.perl:763
 #, perl-format
 msgid "Failed to open %s: %s"
 msgstr "Misslyckades öppna %s: %s"
 
-#: git-send-email.perl:735
+#: git-send-email.perl:780
 #, perl-format
 msgid "Failed to open %s.final: %s"
 msgstr "Misslyckades öppna %s.final: %s"
 
-#: git-send-email.perl:778
+#: git-send-email.perl:823
 msgid "Summary email is empty, skipping it\n"
 msgstr "Sammanfattande brev tomt, hoppar över\n"
 
 #. TRANSLATORS: please keep [y/N] as is.
-#: git-send-email.perl:813
+#: git-send-email.perl:858
 #, perl-format
 msgid "Are you sure you want to use <%s> [y/N]? "
 msgstr "Är du säker på att du vill använda <%s> [Y=ja, N=nej]? "
 
-#: git-send-email.perl:868
+#: git-send-email.perl:913
 msgid ""
 "The following files are 8bit, but do not declare a Content-Transfer-"
 "Encoding.\n"
 msgstr ""
 "Följande filer är åttabitars, men anger inte en Content-Transfer-Encoding.\n"
 
-#: git-send-email.perl:873
+#: git-send-email.perl:918
 msgid "Which 8bit encoding should I declare [UTF-8]? "
 msgstr "Vilken åttabitarsteckenkodning skall jag ange [UTF-8]? "
 
-#: git-send-email.perl:881
+#: git-send-email.perl:926
 #, perl-format
 msgid ""
 "Refusing to send because the patch\n"
@@ -17915,21 +23948,21 @@ msgstr ""
 "har mallärendet \"*** SUBJECT HERE ***\". Använd --force om du verkligen "
 "vill sända.\n"
 
-#: git-send-email.perl:900
+#: git-send-email.perl:945
 msgid "To whom should the emails be sent (if anyone)?"
 msgstr "Till vem skall breven sändas (om någon)?"
 
-#: git-send-email.perl:918
+#: git-send-email.perl:963
 #, perl-format
 msgid "fatal: alias '%s' expands to itself\n"
 msgstr "ödesdigert: aliaset \"%s\" expanderar till sig själv\n"
 
-#: git-send-email.perl:930
+#: git-send-email.perl:975
 msgid "Message-ID to be used as In-Reply-To for the first email (if any)? "
 msgstr ""
 "Message-ID att använda som In-Reply-To för det första brevet (om något)? "
 
-#: git-send-email.perl:988 git-send-email.perl:996
+#: git-send-email.perl:1033 git-send-email.perl:1041
 #, perl-format
 msgid "error: unable to extract a valid address from: %s\n"
 msgstr "fel: kunde inte få fram en giltig adress från: %s\n"
@@ -17937,16 +23970,16 @@ msgstr "fel: kunde inte få fram en gilt
 #. TRANSLATORS: Make sure to include [q] [d] [e] in your
 #. translation. The program will only accept English input
 #. at this point.
-#: git-send-email.perl:1000
+#: git-send-email.perl:1045
 msgid "What to do with this address? ([q]uit|[d]rop|[e]dit): "
 msgstr "Vad vill du göra med adressen? (q=avsluta, d=kasta, e=redigera): "
 
-#: git-send-email.perl:1317
+#: git-send-email.perl:1362
 #, perl-format
 msgid "CA path \"%s\" does not exist"
 msgstr "CA-sökvägen \"%s\" finns inte"
 
-#: git-send-email.perl:1400
+#: git-send-email.perl:1445
 msgid ""
 "    The Cc list above has been expanded by additional\n"
 "    addresses found in the patch commit message. By default\n"
@@ -17973,124 +24006,124 @@ msgstr ""
 #. TRANSLATORS: Make sure to include [y] [n] [e] [q] [a] in your
 #. translation. The program will only accept English input
 #. at this point.
-#: git-send-email.perl:1415
+#: git-send-email.perl:1460
 msgid "Send this email? ([y]es|[n]o|[e]dit|[q]uit|[a]ll): "
 msgstr "Sända brevet? (y=ja, n=nej, e=redigera, q=avsluta, a=alla): "
 
-#: git-send-email.perl:1418
+#: git-send-email.perl:1463
 msgid "Send this email reply required"
 msgstr "Svar krävs på frågan \"Sända brevet?\""
 
-#: git-send-email.perl:1446
+#: git-send-email.perl:1491
 msgid "The required SMTP server is not properly defined."
 msgstr "Nödvändig SMTP-server har inte angivits korrekt."
 
-#: git-send-email.perl:1493
+#: git-send-email.perl:1538
 #, perl-format
 msgid "Server does not support STARTTLS! %s"
 msgstr "Servern stöder inte SMARTTLS! %s"
 
-#: git-send-email.perl:1498 git-send-email.perl:1502
+#: git-send-email.perl:1543 git-send-email.perl:1547
 #, perl-format
 msgid "STARTTLS failed! %s"
 msgstr "STARTTLS misslyckades! %s"
 
-#: git-send-email.perl:1512
+#: git-send-email.perl:1556
 msgid "Unable to initialize SMTP properly. Check config and use --smtp-debug."
 msgstr ""
 "Kan inte initiera SMTP korrekt. Kontrollera inställningarna och använd --"
 "smtp-debug."
 
-#: git-send-email.perl:1530
+#: git-send-email.perl:1574
 #, perl-format
 msgid "Failed to send %s\n"
 msgstr "Misslyckades sända %s\n"
 
-#: git-send-email.perl:1533
+#: git-send-email.perl:1577
 #, perl-format
 msgid "Dry-Sent %s\n"
 msgstr "Test-Sände %s\n"
 
-#: git-send-email.perl:1533
+#: git-send-email.perl:1577
 #, perl-format
 msgid "Sent %s\n"
 msgstr "Sände %s\n"
 
-#: git-send-email.perl:1535
+#: git-send-email.perl:1579
 msgid "Dry-OK. Log says:\n"
 msgstr "Test-OK. Loggen säger:\n"
 
-#: git-send-email.perl:1535
+#: git-send-email.perl:1579
 msgid "OK. Log says:\n"
 msgstr "OK. Loggen säger:\n"
 
-#: git-send-email.perl:1547
+#: git-send-email.perl:1591
 msgid "Result: "
 msgstr "Resultat: "
 
-#: git-send-email.perl:1550
+#: git-send-email.perl:1594
 msgid "Result: OK\n"
 msgstr "Resultat: OK\n"
 
-#: git-send-email.perl:1568
+#: git-send-email.perl:1612
 #, perl-format
 msgid "can't open file %s"
 msgstr "kan inte öppna filen %s"
 
-#: git-send-email.perl:1615 git-send-email.perl:1635
+#: git-send-email.perl:1659 git-send-email.perl:1679
 #, perl-format
 msgid "(mbox) Adding cc: %s from line '%s'\n"
 msgstr "(mbox) Lägger till cc: %s från raden \"%s\"\n"
 
-#: git-send-email.perl:1621
+#: git-send-email.perl:1665
 #, perl-format
 msgid "(mbox) Adding to: %s from line '%s'\n"
 msgstr "(mbox) Lägger till to: %s från raden \"%s\"\n"
 
-#: git-send-email.perl:1674
+#: git-send-email.perl:1718
 #, perl-format
 msgid "(non-mbox) Adding cc: %s from line '%s'\n"
 msgstr "(icke-mbox) Lägger till cc: %s från raden \"%s\"\n"
 
-#: git-send-email.perl:1699
+#: git-send-email.perl:1753
 #, perl-format
 msgid "(body) Adding cc: %s from line '%s'\n"
 msgstr "(kropp) Lägger till cc: %s från raden \"%s\"\n"
 
-#: git-send-email.perl:1817
+#: git-send-email.perl:1864
 #, perl-format
 msgid "(%s) Could not execute '%s'"
 msgstr "(%s) Kunde inte köra \"%s\""
 
-#: git-send-email.perl:1824
+#: git-send-email.perl:1871
 #, perl-format
 msgid "(%s) Adding %s: %s from: '%s'\n"
 msgstr "(%s) Lägger till %s: %s från: \"%s\"\n"
 
-#: git-send-email.perl:1828
+#: git-send-email.perl:1875
 #, perl-format
 msgid "(%s) failed to close pipe to '%s'"
 msgstr "(%s) misslyckades stänga röret till \"%s\""
 
-#: git-send-email.perl:1855
+#: git-send-email.perl:1905
 msgid "cannot send message as 7bit"
 msgstr "kan inte sända brev som sjubitars"
 
-#: git-send-email.perl:1863
+#: git-send-email.perl:1913
 msgid "invalid transfer encoding"
 msgstr "ogiltig överföringskondning"
 
-#: git-send-email.perl:1901 git-send-email.perl:1952 git-send-email.perl:1962
+#: git-send-email.perl:1954 git-send-email.perl:2006 git-send-email.perl:2016
 #, perl-format
 msgid "unable to open %s: %s\n"
 msgstr "kunde inte öppna %s: %s\n"
 
-#: git-send-email.perl:1904
+#: git-send-email.perl:1957
 #, perl-format
 msgid "%s: patch contains a line longer than 998 characters"
 msgstr "%s: patchen innehåller en rad längre än 998 tecken"
 
-#: git-send-email.perl:1920
+#: git-send-email.perl:1974
 #, perl-format
 msgid "Skipping %s with backup suffix '%s'.\n"
 msgstr ""
@@ -18098,11 +24131,358 @@ msgstr ""
 "säkerhetskopior.\n"
 
 #. TRANSLATORS: please keep "[y|N]" as is.
-#: git-send-email.perl:1924
+#: git-send-email.perl:1978
 #, perl-format
 msgid "Do you really want to send %s? [y|N]: "
 msgstr "Vill du verkligen sända %s? [y=ja, n=nej]: "
 
+#~ msgid "unable to get tree for %s"
+#~ msgstr "kunde inte hämta trädet på %s"
+
+#~ msgid "Use an experimental heuristic to improve diffs"
+#~ msgstr "Använd en experimentell algoritm för att förbättra diffar"
+
+#~ msgid "git commit-graph [--object-dir <objdir>]"
+#~ msgstr "git commit-graph [--object-dir <objkat>]"
+
+#~ msgid "git commit-graph read [--object-dir <objdir>]"
+#~ msgstr "git commit-graph read [--object-dir <objkat>]"
+
+#~ msgid "unknown core.untrackedCache value '%s'; using 'keep' default value"
+#~ msgstr ""
+#~ "okänt värde \"%s\" för core.untrackedCache; använder standardvärdet \"keep"
+#~ "\""
+
+#~ msgid "cannot change partial clone promisor remote"
+#~ msgstr "kan inte ändra kontraktsfjärr för delvis kloning"
+
+#~ msgid "error building trees"
+#~ msgstr "fel vid byggande av träd"
+
+#~ msgid "invalid date format '%s' in '%s'"
+#~ msgstr "ogiltigt datumformat \"%s\" i \"%s\""
+
+#~ msgid "writing root commit"
+#~ msgstr "skriver rotincheckning"
+
+#~ msgid "staged changes in the following files may be lost: %s"
+#~ msgstr "köade ändringar i följande filer kan gå förlorade: %s"
+
+#~ msgid ""
+#~ "--filter can only be used with the remote configured in extensions."
+#~ "partialClone"
+#~ msgstr ""
+#~ "--filter kan endast användas med fjärren konfigurerad i extensions."
+#~ "partialClone"
+
+#~ msgid "verify commit-msg hook"
+#~ msgstr "bekräfta commit-msg-krok"
+
+#~ msgid "cannot combine '--rebase-merges' with '--strategy-option'"
+#~ msgstr "kan inte kombinera \"--rebase-merges\" med \"--strategy-option\""
+
+#~ msgid "invalid sparse value '%s'"
+#~ msgstr "ogiltigt värde för sparse: \"%s\""
+
+#~ msgid ""
+#~ "Fetch normally indicates which branches had a forced update, but that "
+#~ "check has been disabled."
+#~ msgstr ""
+#~ "Hämtning visar vanligtvis vilka grenar som har en tvingad uppdatering, "
+#~ "men det testet har slagits av."
+
+#~ msgid ""
+#~ "or run 'git config fetch.showForcedUpdates false' to avoid this check.\n"
+#~ msgstr ""
+#~ "eller kör \"git config fetch.showForcedUpdates false\" för undvika "
+#~ "testet.\n"
+
+#~ msgid ""
+#~ "log.mailmap is not set; its implicit value will change in an\n"
+#~ "upcoming release. To squelch this message and preserve current\n"
+#~ "behaviour, set the log.mailmap configuration value to false.\n"
+#~ "\n"
+#~ "To squelch this message and adopt the new behaviour now, set the\n"
+#~ "log.mailmap configuration value to true.\n"
+#~ "\n"
+#~ "See 'git help config' and search for 'log.mailmap' for further "
+#~ "information."
+#~ msgstr ""
+#~ "log.mailmap har inte satts: förvalet kommer ändras i en kommande\n"
+#~ "version. För att dölja det här meddelandet och behålla nuvarande\n"
+#~ "beteende, sätt konfigurationsvariabeln log.mailmap till false.\n"
+#~ "\n"
+#~ "För att dölja det här meddelandet och använda det nya beteendet,\n"
+#~ "sätt konfigurationsvariabeln log.mailmap till true.\n"
+#~ "\n"
+#~ "Se \"git help config\" och sök efter \"log.mailmap\" för mer information."
+
+#~ msgid "Server supports multi_ack_detailed"
+#~ msgstr "Servern stöder \"multi_ack_detailed\""
+
+#~ msgid "Server supports no-done"
+#~ msgstr "Servern stöder \"no-done\""
+
+#~ msgid "Server supports multi_ack"
+#~ msgstr "Servern stöder \"multi_ack\""
+
+#~ msgid "Server supports side-band-64k"
+#~ msgstr "Servern stöder \"side-band-64k\""
+
+#~ msgid "Server supports side-band"
+#~ msgstr "Servern stöder \"side-band\""
+
+#~ msgid "Server supports allow-tip-sha1-in-want"
+#~ msgstr "Servern stöder \"allow-tip-sha1-in-want\""
+
+#~ msgid "Server supports allow-reachable-sha1-in-want"
+#~ msgstr "Servern stöder \"allow-reachable-sha1-in-want\""
+
+#~ msgid "Server supports ofs-delta"
+#~ msgstr "Servern stöder \"ofs-delta\""
+
+#~ msgid "(HEAD detached at %s)"
+#~ msgstr "(HEAD frånkopplat vid %s)"
+
+#~ msgid "(HEAD detached from %s)"
+#~ msgstr "(HEAD frånkopplat från %s)"
+
+#~ msgid "Checking out files"
+#~ msgstr "Checkar ut filer"
+
+#~ msgid "cannot be interactive without stdin connected to a terminal."
+#~ msgstr ""
+#~ "kan inte vara interaktiv om standard in inte är ansluten till en terminal."
+
+#~ msgid "failed to stat %s\n"
+#~ msgstr "misslyckades ta status på %s\n"
+
+#~ msgid ""
+#~ "If you wish to skip this commit, use:\n"
+#~ "\n"
+#~ "    git reset\n"
+#~ "\n"
+#~ "Then \"git cherry-pick --continue\" will resume cherry-picking\n"
+#~ "the remaining commits.\n"
+#~ msgstr ""
+#~ "Om du vill hoppa över incheckningen, använd:\n"
+#~ "\n"
+#~ "    git reset\n"
+#~ "\n"
+#~ "\"git cherry-pick --continue\" kommer därefter att återuppta\n"
+#~ "cherry-pick för återstående incheckningar.\n"
+
+#~ msgid "unrecognized verb: %s"
+#~ msgstr "okänt verb: %s"
+
+#~ msgid "hash version %X does not match version %X"
+#~ msgstr "hash-versionen %X stämmer inte med versionen %X"
+
+#~ msgid "option '%s' requires a value"
+#~ msgstr "flaggan \"%s\" behöver ett värde"
+
+#~ msgid "could not transform the todo list"
+#~ msgstr "kunde inte transformera att göra-listan"
+
+#~ msgid "default"
+#~ msgstr "standard"
+
+#~ msgid "Could not create directory '%s'"
+#~ msgstr "Kunde inte skapa katalogen \"%s\""
+
+#~ msgid "allow rerere to update index with resolved conflict"
+#~ msgstr "tillåt rerere att uppdatera index med lösa konflikter"
+
+#~ msgid "could not open %s"
+#~ msgstr "kunde inte öppna %s"
+
+#~ msgid "Could not move back to $head_name"
+#~ msgstr "Kunde inte flytta tillbaka till $head_name"
+
+#~ msgid ""
+#~ "It seems that there is already a $state_dir_base directory, and\n"
+#~ "I wonder if you are in the middle of another rebase.  If that is the\n"
+#~ "case, please try\n"
+#~ "\t$cmd_live_rebase\n"
+#~ "If that is not the case, please\n"
+#~ "\t$cmd_clear_stale_rebase\n"
+#~ "and run me again.  I am stopping in case you still have something\n"
+#~ "valuable there."
+#~ msgstr ""
+#~ "Det verkar som katalogen $state_dir_base redan existerar, och\n"
+#~ "jag undrar om du redan är mitt i en annan ombasering. Om så är\n"
+#~ "fallet, försök\n"
+#~ "\t$cmd_live_rebase\n"
+#~ "Om så inte är fallet, kör\n"
+#~ "\t$cmd_clear_stale_rebase\n"
+#~ "och kör programmet igen. Jag avslutar ifall du fortfarande har\n"
+#~ "något av värde där."
+
+#~ msgid ""
+#~ "fatal: cannot combine am options with either interactive or merge options"
+#~ msgstr ""
+#~ "ödesdigert: kan inte kombinera am-flaggor med antingen interaktiv- eller "
+#~ "sammanslagningsflaggor"
+
+#~ msgid "fatal: cannot combine '--signoff' with '--preserve-merges'"
+#~ msgstr ""
+#~ "ödesdigert: kan inte kombinera \"--signoff\" med \"--preserve-merges\""
+
+#~ msgid "fatal: cannot combine '--preserve-merges' with '--rebase-merges'"
+#~ msgstr ""
+#~ "ödesdigert: kan inte kombinera \"--preserve-merges\" med \"--rebase-merges"
+#~ "\""
+
+#~ msgid "fatal: cannot combine '--rebase-merges' with '--strategy-option'"
+#~ msgstr ""
+#~ "ödesdigert: kan inte kombinera \"--rebase-merges\" med \"--strategy-option"
+#~ "\""
+
+#~ msgid "fatal: cannot combine '--rebase-merges' with '--strategy'"
+#~ msgstr ""
+#~ "ödesdigert: kan inte kombinera \"--rebase-merges\" med \"--strategy\""
+
+#~ msgid "invalid upstream '$upstream_name'"
+#~ msgstr "ogiltig uppström \"$upstream_name\""
+
+#~ msgid "$onto_name: there are more than one merge bases"
+#~ msgstr "$onto_name: mer än en sammanslagningsbas finns"
+
+#~ msgid "$onto_name: there is no merge base"
+#~ msgstr "$onto_name: ingen sammanslagningsbas finns"
+
+#~ msgid "Does not point to a valid commit: $onto_name"
+#~ msgstr "Peka på en giltig incheckning: $onto_name"
+
+#~ msgid "fatal: no such branch/commit '$branch_name'"
+#~ msgstr "ödesdigert: ingen sådan gren/incheckning: $branch_name"
+
+#~ msgid "Created autostash: $stash_abbrev"
+#~ msgstr "Skapade autostash: $stash_abbrev"
+
+#~ msgid "Current branch $branch_name is up to date."
+#~ msgstr "Aktuell gren $branch_name är à jour."
+
+#~ msgid "Current branch $branch_name is up to date, rebase forced."
+#~ msgstr "Aktuell gren $branch_name är à jour, ombasering framtvingad."
+
+#~ msgid "Changes to $onto:"
+#~ msgstr "Ändringar till $onto:"
+
+#~ msgid "Changes from $mb to $onto:"
+#~ msgstr "Ändringar från $mb till $onto:"
+
+#~ msgid "Fast-forwarded $branch_name to $onto_name."
+#~ msgstr "Snabbspolade $branch_name till $onto_name."
+
+#~ msgid "First, rewinding head to replay your work on top of it..."
+#~ msgstr ""
+#~ "Först, spolar tillbaka huvudet för att spela av ditt arbete ovanpå det..."
+
+#~ msgid "ignoring unknown color-moved-ws mode '%s'"
+#~ msgstr "ignorerar okänt läge för color-mode-ws \"%s\""
+
+#~ msgid "only 'tree:0' is supported"
+#~ msgstr "endast \"tree:0\" stöds"
+
+#~ msgid "Renaming %s to %s and %s to %s instead"
+#~ msgstr "Byter namn på %s till %s och %s till %s istället"
+
+#~ msgid "Adding merged %s"
+#~ msgstr "Lägger till sammanslagen %s"
+
+#~ msgid "Internal error"
+#~ msgstr "Internt fel"
+
+#~ msgid "mainline was specified but commit %s is not a merge."
+#~ msgstr "huvudlinje angavs, men incheckningen %s är inte en sammanslagning."
+
+#~ msgid "unable to write sha1 filename %s"
+#~ msgstr "kan inte skriva sha1-filnamn %s"
+
+#~ msgid "cannot read sha1_file for %s"
+#~ msgstr "kan inte läsa sha1_file för %s"
+
+#~ msgid ""
+#~ "error: cannot combine interactive options (--interactive, --exec, --"
+#~ "rebase-merges, --preserve-merges, --keep-empty, --root + --onto) with am "
+#~ "options (%s)"
+#~ msgstr ""
+#~ "fel: kan inte kombinera interaktiva flaggor (--interactive, --exec, --"
+#~ "rebase-merges, --preserve-merges, --keep-empty, --root + --onto) med am-"
+#~ "flaggor (%s)"
+
+#~ msgid ""
+#~ "error: cannot combine merge options (--merge, --strategy, --strategy-"
+#~ "option) with am options (%s)"
+#~ msgstr ""
+#~ "fel: kan inte kombinera sammanslagningsflaggor (--merge, --strategy, --"
+#~ "strategy-option) med am-flaggor (%s)"
+
+#~ msgid "unrecognised option: '$arg'"
+#~ msgstr "flaggan känns inte igen: \"$arg\""
+
+#~ msgid "'$invalid' is not a valid commit"
+#~ msgstr "\"$invalid\" är inte en giltig incheckning"
+
+#~ msgid "could not parse '%s' (looking for '%s')"
+#~ msgstr "kunde inte tolka \"%s\" (letar efter \"%s\")"
+
+#~ msgid "deprecated synonym for --create-reflog"
+#~ msgstr "avrådd synonym för --create-reflog"
+
+#~ msgid "Can't stat %s"
+#~ msgstr "Kan inte ta status på %s"
+
+#~ msgid "abort rebase"
+#~ msgstr "avbryt ombasering"
+
+#~ msgid "make rebase script"
+#~ msgstr "skapa ombaseringsskript"
+
+#~ msgid "No such remote: %s"
+#~ msgstr "Inget sådant fjärrarkiv: %s"
+
+#~ msgid "cannot move a locked working tree"
+#~ msgstr "kan inte flytta en låst arbetskatalog"
+
+#~ msgid "cannot remove a locked working tree"
+#~ msgstr "kan inte ta bort en låst arbetskatalog"
+
+#~ msgid ""
+#~ "\n"
+#~ "\tHowever, if you remove everything, the rebase will be aborted.\n"
+#~ "\n"
+#~ "\t"
+#~ msgstr ""
+#~ "\n"
+#~ "\tOmbaseringen kommer dock att avbrytas om du tar bort allting.\n"
+#~ "\n"
+#~ "\t"
+
+#~ msgid "Dirty index: cannot merge (dirty: %s)"
+#~ msgstr "Smutsigt index: kan inte slå ihop (smutsiga: %s)"
+
+#~ msgid "(+/-)x"
+#~ msgstr "(+/-)x"
+
+#~ msgid "<command>"
+#~ msgstr "<kommando>"
+
+#~ msgid "push|fetch"
+#~ msgstr "push|fetch"
+
+#~ msgid "w[,i1[,i2]]"
+#~ msgstr "w[,i1[,i2]]"
+
+#~ msgid "Entering '$displaypath'"
+#~ msgstr "Går in i \"$displaypath\""
+
+#~ msgid "Stopping at '$displaypath'; script returned non-zero status."
+#~ msgstr ""
+#~ "Stoppar på \"$displaypath\"; skriptet returnerade en status skild från "
+#~ "noll."
+
 #~ msgid "Everyday Git With 20 Commands Or So"
 #~ msgstr "Git för dagligt bruk i ungefär 20 kommandon"
 
@@ -18159,18 +24539,9 @@ msgstr "Vill du verkligen sända %s? [y=
 #~ "tomma strängar som sökvägsangivelser kommer bli ogiltiga i en kommande "
 #~ "utgåva. använd istället . om du vill träffa alla sökvägar"
 
-#~ msgid "unable to open '%s' for writing"
-#~ msgstr "kunde inte öppna \"%s\" för skrivning"
-
 #~ msgid "could not truncate '%s'"
 #~ msgstr "kunde inte trunkera \"%s\""
 
-#~ msgid "could not finish '%s'"
-#~ msgstr "kunde inte avsluta \"%s\""
-
-#~ msgid "could not write to %s"
-#~ msgstr "kunde inte skriva till %s"
-
 #~ msgid "could not close %s"
 #~ msgstr "kunde inte stänga %s"
 
@@ -18183,12 +24554,6 @@ msgstr "Vill du verkligen sända %s? [y=
 #~ msgid "Don't know how to clone %s"
 #~ msgstr "Vet inte hur man klonar %s"
 
-#~ msgid "show ignored files"
-#~ msgstr "visa ignorerade filer"
-
-#~ msgid "%s is not a valid '%s' object"
-#~ msgstr "%s är inte ett giltigt \"%s\"-objekt"
-
 #~ msgid "Don't know how to fetch from %s"
 #~ msgstr "Vet inte hur man hämtar från %s"
 
@@ -18242,9 +24607,6 @@ msgstr "Vill du verkligen sända %s? [y=
 #~ msgid "basename"
 #~ msgstr "basnamn"
 
-#~ msgid "prepend parent project's basename to output"
-#~ msgstr "lägg till föräldraprojektets basnamn i utdata"
-
 #~ msgid ""
 #~ "Warning: the SHA-1 is missing or isn't a commit in the following line:\n"
 #~ " - $line"
@@ -18262,9 +24624,6 @@ msgstr "Vill du verkligen sända %s? [y=
 #~ msgid "Or you can abort the rebase with 'git rebase --abort'."
 #~ msgstr "Eller så kan du avbryta ombaseringen med \"git rebase --abort\"."
 
-#~ msgid "Could not open file '%s'"
-#~ msgstr "Kunde inte öppna filen \"%s\""
-
 #~ msgid "in %0.1f seconds automatically..."
 #~ msgstr "automatiskt om %0.1f sekunder..."
 
@@ -18282,7 +24641,7 @@ msgstr "Vill du verkligen sända %s? [y=
 #~ "Did you forget to use 'git add'?"
 #~ msgstr ""
 #~ "Du har fortfarande sökvägar som inte slagits samman i ditt index.\n"
-#~ "Glömde du använda \"git add\"?"
+#~ "Glömde du att använda \"git add\"?"
 
 #~ msgid ""
 #~ "Cannot update paths and switch to branch '%s' at the same time.\n"
@@ -18308,9 +24667,6 @@ msgstr "Vill du verkligen sända %s? [y=
 #~ msgid "tag: tagging "
 #~ msgstr "tag: taggar"
 
-#~ msgid "object of unknown type"
-#~ msgstr "objekt av okänd typ"
-
 #~ msgid "commit object"
 #~ msgstr "incheckningsobjekt"
 
@@ -18336,9 +24692,6 @@ msgstr "Vill du verkligen sända %s? [y=
 #~ msgid "ref '%s' does not have %ld components to :strip"
 #~ msgstr "referensen \"%s\" har inte %ld komponenter för :strip"
 
-#~ msgid "unknown %.*s format %s"
-#~ msgstr "okänt \"%.*s\"-format %s"
-
 #~ msgid "[%s: gone]"
 #~ msgstr "[%s: försvunnen]"
 
@@ -18363,12 +24716,6 @@ msgstr "Vill du verkligen sända %s? [y=
 #~ msgid "git merge [<options>] <msg> HEAD <commit>"
 #~ msgstr "git merge [<flaggor>] <meddelande> HEAD <incheckning>"
 
-#~ msgid "cannot open file '%s'"
-#~ msgstr "kan inte öppna filen \"%s\""
-
-#~ msgid "could not close file %s"
-#~ msgstr "kunde inte stänga filen %s"
-
 #~ msgid "tag name too long: %.*s..."
 #~ msgstr "taggnamnet för långt: %.*s..."
 
@@ -18423,24 +24770,15 @@ msgstr "Vill du verkligen sända %s? [y=
 #~ msgid "Cannot cherry-pick during another cherry-pick."
 #~ msgstr "Kan inte utföra \"cherry-pick\" under en annan \"cherry-pick\"."
 
-#~ msgid "Could not parse line %d."
-#~ msgstr "Kan inte tolka rad %d."
-
 #~ msgid "Could not open %s"
 #~ msgstr "Kunde inte öppna %s"
 
-#~ msgid "Could not read %s."
-#~ msgstr "kunde inte läsa %s."
-
 #~ msgid "Could not format %s."
 #~ msgstr "Kunde inte formatera %s."
 
 #~ msgid "%s: %s"
 #~ msgstr "%s: %s"
 
-#~ msgid "cannot open %s: %s"
-#~ msgstr "kan inte öppna %s: %s"
-
 #~ msgid "You need to set your committer info first"
 #~ msgstr "Du måste ställa in din incheckarinformation först"
 
@@ -18633,9 +24971,6 @@ msgstr "Vill du verkligen sända %s? [y=
 #~ msgid "removing '%s' failed"
 #~ msgstr "misslyckades ta bort \"%s\""
 
-#~ msgid "program error"
-#~ msgstr "programfel"
-
 #~ msgid "Please call 'bisect_state' with at least one argument."
 #~ msgstr "Anropa \"bisect_state\" med minst ett argument."
 
@@ -18673,9 +25008,6 @@ msgstr "Vill du verkligen sända %s? [y=
 #~ msgid "'%s': %s"
 #~ msgstr "\"%s\": %s"
 
-#~ msgid "unable to access '%s': %s"
-#~ msgstr "kan inte komma åt \"%s\": %s"
-
 #~ msgid "    git branch -d %s\n"
 #~ msgstr "    git branch -d %s\n"
 
@@ -18692,9 +25024,6 @@ msgstr "Vill du verkligen sända %s? [y=
 #~ msgid "failed to remove: %s"
 #~ msgstr "misslyckades ta bort: %s"
 
-#~ msgid "The --exec option must be used with the --interactive option"
-#~ msgstr "Flaggan --exec måste användas tillsammans med flaggan --interactive"
-
 #~ msgid ""
 #~ "Submodule path '$displaypath' not initialized\n"
 #~ "Maybe you want to use 'update --init'?"
@@ -18708,9 +25037,6 @@ msgstr "Vill du verkligen sända %s? [y=
 #~ msgid "improper format entered align:%s"
 #~ msgstr "felaktigt format angivet align:%s"
 
-#~ msgid "Could not set core.worktree in %s"
-#~ msgstr "Kunde inte sätta core.worktree i %s"
-
 #~ msgid ""
 #~ "push.default is unset; its implicit value has changed in\n"
 #~ "Git 2.0 from 'matching' to 'simple'. To squelch this message\n"
@@ -18766,9 +25092,6 @@ msgstr "Vill du verkligen sända %s? [y=
 #~ msgid "Could not append '%s'"
 #~ msgstr "Kunde inte lägga till på \"%s\""
 
-#~ msgid "Missing author: %s"
-#~ msgstr "Författare saknas: %s"
-
 #~ msgid "Testing "
 #~ msgstr "Testar"
 
@@ -18781,12 +25104,6 @@ msgstr "Vill du verkligen sända %s? [y=
 #~ msgid "branch '%s' does not point at a commit"
 #~ msgstr "grenen \"%s\" pekar inte på en incheckning"
 
-#~ msgid "object '%s' does not point to a commit"
-#~ msgstr "objektet \"%s\" pekar på en incheckning"
-
-#~ msgid "some refs could not be read"
-#~ msgstr "vissa referenser kunde inte läsas"
-
 #~ msgid "print only merged branches"
 #~ msgstr "visa endast sammanslagna grenar"
 
@@ -18805,9 +25122,6 @@ msgstr "Vill du verkligen sända %s? [y=
 #~ msgid "insanely long template path %s"
 #~ msgstr "tokigt lång mallsökväg %s"
 
-#~ msgid "insane git directory %s"
-#~ msgstr "tokig git-katalog %s"
-
 #~ msgid "false|true|preserve"
 #~ msgstr "false|true|preserve"
 
@@ -18820,9 +25134,6 @@ msgstr "Vill du verkligen sända %s? [y=
 #~ msgid "switch 'points-at' requires an object"
 #~ msgstr "flaggan \"points-at\" behöver ett objekt"
 
-#~ msgid "sort tags"
-#~ msgstr "sortera taggar"
-
 #~ msgid "--sort and -n are incompatible"
 #~ msgstr "--sort och -n är inkompatibla"
 
@@ -18838,9 +25149,6 @@ msgstr "Vill du verkligen sända %s? [y=
 #~ msgid "option %s does not accept negative form"
 #~ msgstr "flaggan %s godtar inte negativ form"
 
-#~ msgid "unable to parse value '%s' for option %s"
-#~ msgstr "kunde inte tolka värdet \"%s\" för flaggan %s"
-
 #~ msgid "-b and -B are mutually exclusive"
 #~ msgstr "-b och -B kan inte användas samtidigt"
 
@@ -18941,9 +25249,6 @@ msgstr "Vill du verkligen sända %s? [y=
 #~ msgid "%s: cannot lock the ref"
 #~ msgstr "%s: kan inte låsa referensen"
 
-#~ msgid "%s: cannot update the ref"
-#~ msgstr "%s: kan inte uppdatera referensen"
-
 #~ msgid "commit has empty message"
 #~ msgstr "incheckningen har ett tomt meddelande"
 
@@ -19124,25 +25429,12 @@ msgstr "Vill du verkligen sända %s? [y=
 #~ msgstr ""
 #~ "git shortlog [-n] [-s] [-e] [-w] [rev-flaggor] [--] [<incheckning-id>... ]"
 
-#~ msgid "See 'git help <command>' for more information on a specific command."
-#~ msgstr ""
-#~ "Se \"git help <kommando>\" för mer information om ett specifikt kommando."
-
 #~ msgid "use any ref in .git/refs"
 #~ msgstr "använd alla referenser i .git/refs"
 
 #~ msgid "use any tag in .git/refs/tags"
 #~ msgstr "använd alla taggar i .git/refs/tags"
 
-#~ msgid "bad object %s"
-#~ msgstr "felaktigt objekt %s"
-
-#~ msgid "bogus committer info %s"
-#~ msgstr "felaktig incheckarinformation %s"
-
-#~ msgid "can't fdopen 'show' output fd"
-#~ msgstr "kunde inte öppna (fdopen) \"show\"-utdata-filhandtag"
-
 #~ msgid "failed to close pipe to 'show' for object '%s'"
 #~ msgstr "kunde inte stänga röret till \"show\" för objektet \"%s\""
 
@@ -19211,9 +25503,6 @@ msgstr "Vill du verkligen sända %s? [y=
 #~ msgid "'%s': not a documentation directory."
 #~ msgstr "\"%s\": inte en dokumentationskatalog."
 
-#~ msgid "-d option is no longer supported.  Do not use."
-#~ msgstr "Flaggan -d stöds inte lägre. Använd inte."
-
 #~ msgid "Could not extract email from committer identity."
 #~ msgstr "Kunde inte extrahera e-postadress från incheckarens identitet."
 
diff -pruN 1.2.1+git2.18.0-1/git/po/TEAMS 1.2.3+git2.25.1-1/git/po/TEAMS
--- 1.2.1+git2.18.0-1/git/po/TEAMS	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/po/TEAMS	2020-02-17 04:47:35.000000000 +0000
@@ -11,11 +11,15 @@ Leader:		Jordi Mas <jmas@softcatala.org>
 Members:	Alex Henrie <alexhenrie24@gmail.com>
 
 Language:	de (German)
-Repository:	https://github.com/ralfth/git-po-de
-Leader:		Ralf Thielow <ralf.thielow@gmail.com>
-Members:	Matthias Rüster <matthias.ruester@gmail.com>
+Repository:	https://github.com/ruester/git-po-de
+Leader:		Matthias Rüster <matthias.ruester@gmail.com>
+Members:	Ralf Thielow <ralf.thielow@gmail.com>
 		Phillip Szelat <phillip.szelat@gmail.com>
 
+Language:	el (Greek)
+Repository:	https://github.com/vyruss/git-po-el
+Leader:		Jimmy Angelakos <vyruss@hellug.gr>
+
 Language:	es (Spanish)
 Repository:	https://github.com/ChrisADR/git-po
 Leader:		Christopher Díaz <christopher.diaz.riv@gmail.com>
@@ -29,9 +33,8 @@ Language:	is (Icelandic)
 Leader:		Ævar Arnfjörð Bjarmason <avarab@gmail.com>
 
 Language:	it (Italian)
-Repository:	https://github.com/quizzlo/git-po-it/
-Leader:		Marco Paolone <marcopaolone AT gmail.com>
-Members:	Stefano Lattarini <stefano.lattarini AT gmail.com>
+Repository:	https://github.com/AlessandroMenti/git-po
+Leader:		Alessandro Menti <alessandro.menti@alessandromenti.it>
 
 Language:	ko (Korean)
 Repository:	https://github.com/git-l10n-ko/git-l10n-ko/
@@ -63,4 +66,9 @@ Repository:	https://github.com/jiangxin/
 Leader:		Jiang Xin <worldhello.net AT gmail.com>
 Members:	Ray Chen <oldsharp AT gmail.com>
 		依云 <lilydjwg AT gmail.com>
-		Fangyi Zhou <fangyi.zhou AT yuriko.moe>
+		Fangyi Zhou <me AT fangyi.io>
+
+Language:	zh_TW (Traditional Chinese)
+Respository:	https://github.com/l10n-tw/git-po
+Leader: 	Yi-Jyun Pan <pan93412 AT gmail.com>
+Members:	Franklin Weng <franklin AT goodhorse.idv.tw>
diff -pruN 1.2.1+git2.18.0-1/git/po/vi.po 1.2.3+git2.25.1-1/git/po/vi.po
--- 1.2.1+git2.18.0-1/git/po/vi.po	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/po/vi.po	2020-02-17 04:47:35.000000000 +0000
@@ -2,14 +2,14 @@
 # Bản dịch tiếng Việt dành cho GIT-CORE.
 # This file is distributed under the same license as the git-core package.
 # Nguyễn Thái Ngọc Duy <pclouds@gmail.com>, 2012.
-# Trần Ngọc Quân <vnwildman@gmail.com>, 2012, 2013, 2014, 2015, 2016, 2017, 2018.
+# Trần Ngọc Quân <vnwildman@gmail.com>, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019, 2020.
 #
 msgid ""
 msgstr ""
-"Project-Id-Version: git v2.18.0.round3\n"
+"Project-Id-Version: git v2.25.0\n"
 "Report-Msgid-Bugs-To: Git Mailing List <git@vger.kernel.org>\n"
-"POT-Creation-Date: 2018-06-16 22:06+0800\n"
-"PO-Revision-Date: 2018-06-17 07:06+0700\n"
+"POT-Creation-Date: 2019-12-30 08:48+0800\n"
+"PO-Revision-Date: 2020-01-03 14:08+0700\n"
 "Last-Translator: Trần Ngọc Quân <vnwildman@gmail.com>\n"
 "Language-Team: Vietnamese <translation-team-vi@lists.sourceforge.net>\n"
 "Language: vi\n"
@@ -19,48 +19,477 @@ msgstr ""
 "Plural-Forms: nplurals=1; plural=0;\n"
 "X-Language-Team-Website: <http://translationproject.org/team/vi.html>\n"
 "X-Poedit-SourceCharset: UTF-8\n"
-"X-Poedit-Basepath: ../\n"
+"X-Poedit-Basepath: ..\n"
 "X-Generator: Gtranslator 2.91.7\n"
 
-#: advice.c:92
+#: add-interactive.c:347
+#, c-format
+msgid "Huh (%s)?"
+msgstr "Hả (%s)?"
+
+#: add-interactive.c:500 add-interactive.c:801 sequencer.c:3216
+#: sequencer.c:3656 builtin/rebase.c:871 builtin/rebase.c:1643
+#: builtin/rebase.c:2019 builtin/rebase.c:2063
+msgid "could not read index"
+msgstr "không thể đọc bảng mục lục"
+
+#: add-interactive.c:555 git-add--interactive.perl:269
+#: git-add--interactive.perl:294
+msgid "binary"
+msgstr "nhị phân"
+
+#: add-interactive.c:613 git-add--interactive.perl:278
+#: git-add--interactive.perl:332
+msgid "nothing"
+msgstr "không có gì"
+
+#: add-interactive.c:614 git-add--interactive.perl:314
+#: git-add--interactive.perl:329
+msgid "unchanged"
+msgstr "không thay đổi"
+
+#: add-interactive.c:651 git-add--interactive.perl:643
+msgid "Update"
+msgstr "Cập nhật"
+
+#: add-interactive.c:668 add-interactive.c:856
+#, c-format
+msgid "could not stage '%s'"
+msgstr "không thể đưa “%s” lên bệ phóng"
+
+#: add-interactive.c:674 add-interactive.c:863 sequencer.c:3409
+#: builtin/rebase.c:895
+msgid "could not write index"
+msgstr "không thể ghi bảng mục lục"
+
+#: add-interactive.c:677 git-add--interactive.perl:628
+#, c-format, perl-format
+msgid "updated %d path\n"
+msgid_plural "updated %d paths\n"
+msgstr[0] "đã cập nhật %d đường dẫn\n"
+
+#: add-interactive.c:695 git-add--interactive.perl:678
+#, c-format, perl-format
+msgid "note: %s is untracked now.\n"
+msgstr "chú ý: %s giờ đã bỏ theo dõi.\n"
+
+#: add-interactive.c:700 apply.c:4108 builtin/checkout.c:281
+#: builtin/reset.c:144
+#, c-format
+msgid "make_cache_entry failed for path '%s'"
+msgstr "make_cache_entry gặp lỗi đối với đường dẫn “%s”"
+
+#: add-interactive.c:730 git-add--interactive.perl:655
+msgid "Revert"
+msgstr "Hoàn nguyên"
+
+#: add-interactive.c:746
+msgid "Could not parse HEAD^{tree}"
+msgstr "Không thể phân tích cú pháp HEAD^{tree}"
+
+#: add-interactive.c:784 git-add--interactive.perl:631
+#, c-format, perl-format
+msgid "reverted %d path\n"
+msgid_plural "reverted %d paths\n"
+msgstr[0] "đã hoàn nguyên %d đường dẫn\n"
+
+#: add-interactive.c:835 git-add--interactive.perl:695
+#, c-format
+msgid "No untracked files.\n"
+msgstr "Không có tập tin nào chưa được theo dõi.\n"
+
+#: add-interactive.c:839 git-add--interactive.perl:689
+msgid "Add untracked"
+msgstr "Thêm các cái chưa được theo dõi"
+
+#: add-interactive.c:866 git-add--interactive.perl:625
+#, c-format, perl-format
+msgid "added %d path\n"
+msgid_plural "added %d paths\n"
+msgstr[0] "đã thêm %d đường dẫn\n"
+
+#: add-interactive.c:896
+#, c-format
+msgid "ignoring unmerged: %s"
+msgstr "bỏ qua những thứ chưa hòa trộn: %s"
+
+#: add-interactive.c:908 add-patch.c:1331 git-add--interactive.perl:1366
+#, c-format
+msgid "Only binary files changed.\n"
+msgstr "Chỉ có các tập tin nhị phân là thay đổi.\n"
+
+#: add-interactive.c:910 add-patch.c:1329 git-add--interactive.perl:1368
+#, c-format
+msgid "No changes.\n"
+msgstr "Không có thay đổi nào.\n"
+
+#: add-interactive.c:914 git-add--interactive.perl:1376
+msgid "Patch update"
+msgstr "Cập nhật miếng vá"
+
+#: add-interactive.c:953 git-add--interactive.perl:1754
+msgid "Review diff"
+msgstr "Xem xét lại diff"
+
+#: add-interactive.c:981
+msgid "show paths with changes"
+msgstr "hiển thị đường dẫn với các thay đổi"
+
+#: add-interactive.c:983
+msgid "add working tree state to the staged set of changes"
+msgstr ""
+"thêm trạng thái cây làm việc vào tập hợp các thay đổi đã được đưa lên bệ "
+"phóng"
+
+#: add-interactive.c:985
+msgid "revert staged set of changes back to the HEAD version"
+msgstr ""
+"hoàn nguyên lại tập hợp các thay đổi đã được đưa lên bệ phóng trở lại phiên "
+"bản HEAD"
+
+#: add-interactive.c:987
+msgid "pick hunks and update selectively"
+msgstr "chọn các “khúc” và cập nhật có tuyển chọn"
+
+#: add-interactive.c:989
+msgid "view diff between HEAD and index"
+msgstr "xem khác biệt giữa HEAD và mục lục"
+
+#: add-interactive.c:991
+msgid "add contents of untracked files to the staged set of changes"
+msgstr ""
+"thêm nội dung của các tập tin chưa được theo dõi vào tập hợp các thay đổi đã "
+"được đưa lên bệ phóng"
+
+#: add-interactive.c:999 add-interactive.c:1048
+msgid "Prompt help:"
+msgstr "Trợ giúp về nhắc:"
+
+#: add-interactive.c:1001
+msgid "select a single item"
+msgstr "chọn một mục đơn"
+
+#: add-interactive.c:1003
+msgid "select a range of items"
+msgstr "chọn một vùng các mục"
+
+#: add-interactive.c:1005
+msgid "select multiple ranges"
+msgstr "chọn nhiều vùng"
+
+#: add-interactive.c:1007 add-interactive.c:1052
+msgid "select item based on unique prefix"
+msgstr "chọn mục dựa trên tiền tố duy nhất"
+
+#: add-interactive.c:1009
+msgid "unselect specified items"
+msgstr "bỏ chọn các mục đã cho"
+
+#: add-interactive.c:1011
+msgid "choose all items"
+msgstr "chọn tất cả các mục"
+
+#: add-interactive.c:1013
+msgid "(empty) finish selecting"
+msgstr "(để trống) hoàn tất chọn lựa"
+
+#: add-interactive.c:1050
+msgid "select a numbered item"
+msgstr "tùy chọn mục bằng số"
+
+#: add-interactive.c:1054
+msgid "(empty) select nothing"
+msgstr "(để trống) không chọn gì"
+
+#: add-interactive.c:1062 builtin/clean.c:822 git-add--interactive.perl:1851
+msgid "*** Commands ***"
+msgstr "*** Lệnh ***"
+
+#: add-interactive.c:1063 builtin/clean.c:823 git-add--interactive.perl:1848
+msgid "What now"
+msgstr "Giờ thì sao"
+
+#: add-interactive.c:1115 git-add--interactive.perl:213
+msgid "staged"
+msgstr "đã đưa lên bệ phóng"
+
+#: add-interactive.c:1115 git-add--interactive.perl:213
+msgid "unstaged"
+msgstr "chưa đưa lên bệ phóng"
+
+#: add-interactive.c:1115 apply.c:4965 apply.c:4968 builtin/am.c:2197
+#: builtin/am.c:2200 builtin/clone.c:123 builtin/fetch.c:144
+#: builtin/merge.c:273 builtin/pull.c:209 builtin/submodule--helper.c:409
+#: builtin/submodule--helper.c:1379 builtin/submodule--helper.c:1382
+#: builtin/submodule--helper.c:1875 builtin/submodule--helper.c:1878
+#: builtin/submodule--helper.c:2119 git-add--interactive.perl:213
+msgid "path"
+msgstr "đường-dẫn"
+
+#: add-interactive.c:1122
+msgid "could not refresh index"
+msgstr "không thể đọc lại bảng mục lục"
+
+#: add-interactive.c:1136 builtin/clean.c:787 git-add--interactive.perl:1765
+#, c-format
+msgid "Bye.\n"
+msgstr "Tạm biệt.\n"
+
+#: add-patch.c:15
+#, c-format
+msgid "Stage mode change [y,n,a,q,d%s,?]? "
+msgstr "Thay đổi chế độ bệ phóng [y,n,a,q,d%s,?]? "
+
+#: add-patch.c:16
+#, c-format
+msgid "Stage deletion [y,n,a,q,d%s,?]? "
+msgstr "Xóa khỏi bệ phóng [y,n,a,q,d%s,?]? "
+
+#: add-patch.c:17
+#, c-format
+msgid "Stage this hunk [y,n,a,q,d%s,?]? "
+msgstr "Đưa lên bệ phóng khúc này [y,n,a,q,d%s,?]? "
+
+#: add-patch.c:111
+#, c-format
+msgid "could not parse hunk header '%.*s'"
+msgstr "không thể phân tích cú pháp phần đầu của khúc “%.*s”"
+
+#: add-patch.c:130 add-patch.c:134
+#, c-format
+msgid "could not parse colored hunk header '%.*s'"
+msgstr "không thể phân tích cú pháp phần đầu khúc đã tô màu “%.*s”"
+
+#: add-patch.c:176
+msgid "could not parse diff"
+msgstr "không thể phân tích cú pháp khác biệt"
+
+#: add-patch.c:194
+msgid "could not parse colored diff"
+msgstr "không thể phân tích khác biệt được tô màu"
+
+#: add-patch.c:508
+#, c-format
+#| msgid "bad config line %d in %s"
+msgid ""
+"expected context line #%d in\n"
+"%.*s"
+msgstr ""
+"cần dòng nội dung #%d trong\n"
+"%.*s"
+
+#: add-patch.c:523
+#, c-format
+msgid ""
+"hunks do not overlap:\n"
+"%.*s\n"
+"\tdoes not end with:\n"
+"%.*s"
+msgstr ""
+"các khối không chồng đè lên nhau:\n"
+"%.*s\n"
+"\tkhông được kết thúc bằng:\n"
+"%.*s"
+
+#: add-patch.c:799 git-add--interactive.perl:1112
+msgid "Manual hunk edit mode -- see bottom for a quick guide.\n"
+msgstr "Chế độ sửa khúc bằng tay -- xem ở đáy để có hướng dẫn sử dụng nhanh.\n"
+
+#: add-patch.c:803
+#, c-format
+msgid ""
+"---\n"
+"To remove '%c' lines, make them ' ' lines (context).\n"
+"To remove '%c' lines, delete them.\n"
+"Lines starting with %c will be removed.\n"
+msgstr ""
+"---\n"
+"Để gỡ bỏ “%c” dòng, làm chúng thành những dòng ' ' (nội dung).\n"
+"Để gõ bỏ “%c” dòng, xóa chúng đi.\n"
+"Những dòng bắt đầu bằng %c sẽ bị loại bỏ.\n"
+
+#: add-patch.c:810
+msgid ""
+"If the patch applies cleanly, the edited hunk will immediately be\n"
+"marked for staging.\n"
+msgstr ""
+"Nếu miếng vá được áp dụng sạch sẽ, khúc đã sửa sẽ ngay lập tức\n"
+"được đánh dấu để chuyển lên bệ phóng.\n"
+
+#. TRANSLATORS: 'it' refers to the patch mentioned in the previous messages.
+#: add-patch.c:818 git-add--interactive.perl:1126
+msgid ""
+"If it does not apply cleanly, you will be given an opportunity to\n"
+"edit again.  If all lines of the hunk are removed, then the edit is\n"
+"aborted and the hunk is left unchanged.\n"
+msgstr ""
+"Nếu miếng vá không được áp dụng sạch sẽ, bạn sẽ có một cơ hội\n"
+"để sửa lần nữa. Nếu mọi dòng của khúc bị xóa bỏ, thế thì những\n"
+"sửa dổi sẽ bị loại bỏ, và khúc vẫn giữ nguyên.\n"
+
+#: add-patch.c:851
+msgid "could not parse hunk header"
+msgstr "không thể phân tích cú pháp phần đầu khúc"
+
+#: add-patch.c:895 add-patch.c:1294
+msgid "'git apply --cached' failed"
+msgstr "'git apply --cached' gặp lỗi"
+
+#. TRANSLATORS: do not translate [y/n]
+#. The program will only accept that input at this point.
+#. Consider translating (saying "no" discards!) as
+#. (saying "n" for "no" discards!) if the translation
+#. of the word "no" does not start with n.
+#.
+#. TRANSLATORS: do not translate [y/n]
+#. The program will only accept that input
+#. at this point.
+#. Consider translating (saying "no" discards!) as
+#. (saying "n" for "no" discards!) if the translation
+#. of the word "no" does not start with n.
+#: add-patch.c:952 git-add--interactive.perl:1239
+msgid ""
+"Your edited hunk does not apply. Edit again (saying \"no\" discards!) [y/n]? "
+msgstr ""
+"Hunk đã sửa của bạn không được áp dụng. Sửa lại lần nữa (nói \"n\" để loại "
+"bỏ!) [y/n]? "
+
+#: add-patch.c:1009
+msgid ""
+"y - stage this hunk\n"
+"n - do not stage this hunk\n"
+"q - quit; do not stage this hunk or any of the remaining ones\n"
+"a - stage this and all the remaining hunks\n"
+"d - do not stage this hunk nor any of the remaining hunks\n"
+msgstr ""
+"y - đưa lên bệ phóng khúc này\n"
+"n - đừng đưa lên bệ phóng khúc này\n"
+"q - thoát; đừng đưa lên bệ phóng khúc này cũng như bất kỳ cái nào còn lại\n"
+"a - đưa lên bệ phóng khúc này và tất cả các khúc còn lại sau này\n"
+"d - đừng đưa lên bệ phóng khúc này cũng như bất kỳ cái nào còn lại\n"
+
+#: add-patch.c:1016
+msgid ""
+"j - leave this hunk undecided, see next undecided hunk\n"
+"J - leave this hunk undecided, see next hunk\n"
+"k - leave this hunk undecided, see previous undecided hunk\n"
+"K - leave this hunk undecided, see previous hunk\n"
+"g - select a hunk to go to\n"
+"/ - search for a hunk matching the given regex\n"
+"s - split the current hunk into smaller hunks\n"
+"e - manually edit the current hunk\n"
+"? - print help\n"
+msgstr ""
+"j - để lại khúc này là chưa quyết định, xem khúc chưa quyết định kế tiếp\n"
+"J - để lại khúc này là chưa quyết định, xem khúc kế tiếp\n"
+"k - để lại khúc này là chưa quyết định, xem khúc chưa quyết định kế trước\n"
+"K - để lại khúc này là chưa quyết định, xem khúc kế trước\n"
+"g - chọn một khúc muốn tới\n"
+"/ - tìm một khúc khớp với biểu thức chính quy đưa ra\n"
+"s - chia khúc hiện tại thành các khúc nhỏ hơn\n"
+"e - sửa bằng tay khúc hiện hành\n"
+"? - hiển thị trợ giúp\n"
+
+#: add-patch.c:1137 add-patch.c:1147
+msgid "No previous hunk"
+msgstr "Không có khúc kế trước"
+
+#: add-patch.c:1142 add-patch.c:1152
+msgid "No next hunk"
+msgstr "Không có khúc kế tiếp"
+
+#: add-patch.c:1158
+msgid "No other hunks to goto"
+msgstr "Không còn khúc nào để mà nhảy đến"
+
+#: add-patch.c:1169 git-add--interactive.perl:1577
+msgid "go to which hunk (<ret> to see more)? "
+msgstr "nhảy đến khúc nào (<ret> để xem thêm)? "
+
+#: add-patch.c:1170 git-add--interactive.perl:1579
+msgid "go to which hunk? "
+msgstr "nhảy đến khúc nào? "
+
+#: add-patch.c:1181
+#, c-format
+msgid "Invalid number: '%s'"
+msgstr "Số không hợp lệ: “%s”"
+
+#: add-patch.c:1186
+#, c-format
+msgid "Sorry, only %d hunk available."
+msgid_plural "Sorry, only %d hunks available."
+msgstr[0] "Rất tiếc, chỉ có sẵn %d khúc."
+
+#: add-patch.c:1195
+msgid "No other hunks to search"
+msgstr "Không còn khúc nào để mà tìm kiếm"
+
+#: add-patch.c:1201 git-add--interactive.perl:1623
+msgid "search for regex? "
+msgstr "tìm kiếm cho biểu thức chính quy? "
+
+#: add-patch.c:1216
+#, c-format
+msgid "Malformed search regexp %s: %s"
+msgstr "Định dạng tìm kiếm của biểu thức chính quy không đúng %s: %s"
+
+#: add-patch.c:1233
+msgid "No hunk matches the given pattern"
+msgstr "Không thấy khúc nào khớp mẫu đã cho"
+
+#: add-patch.c:1240
+msgid "Sorry, cannot split this hunk"
+msgstr "Rất tiếc, không thể chia nhỏ khúc này"
+
+#: add-patch.c:1244
+#, c-format
+msgid "Split into %d hunks."
+msgstr "Chi nhỏ thành %d khúc."
+
+#: add-patch.c:1248
+msgid "Sorry, cannot edit this hunk"
+msgstr "Rất tiếc, không thể sửa khúc này"
+
+#: advice.c:111
 #, c-format
 msgid "%shint: %.*s%s\n"
 msgstr "%sgợi ý: %.*s%s\n"
 
-#: advice.c:137
+#: advice.c:164
 msgid "Cherry-picking is not possible because you have unmerged files."
 msgstr ""
 "Cherry-picking là không thể thực hiện bởi vì bạn có những tập tin chưa được "
 "hòa trộn."
 
-#: advice.c:139
+#: advice.c:166
 msgid "Committing is not possible because you have unmerged files."
 msgstr ""
 "Commit là không thể thực hiện bởi vì bạn có những tập tin chưa được hòa trộn."
 
-#: advice.c:141
+#: advice.c:168
 msgid "Merging is not possible because you have unmerged files."
 msgstr ""
 "Merge là không thể thực hiện bởi vì bạn có những tập tin chưa được hòa trộn."
 
-#: advice.c:143
+#: advice.c:170
 msgid "Pulling is not possible because you have unmerged files."
 msgstr ""
 "Pull là không thể thực hiện bởi vì bạn có những tập tin chưa được hòa trộn."
 
-#: advice.c:145
+#: advice.c:172
 msgid "Reverting is not possible because you have unmerged files."
 msgstr ""
 "Revert là không thể thực hiện bởi vì bạn có những tập tin chưa được hòa trộn."
 
-#: advice.c:147
+#: advice.c:174
 #, c-format
 msgid "It is not possible to %s because you have unmerged files."
 msgstr ""
-"Nó là không thể thực hiện với %s bởi vì bạn có những tập tin chưa được hòa "
-"trộn."
+"Việc này không thể thực hiện với %s bởi vì bạn có những tập tin chưa được "
+"hòa trộn."
 
-#: advice.c:155
+#: advice.c:182
 msgid ""
 "Fix them up in the work tree, and then use 'git add/rm <file>'\n"
 "as appropriate to mark resolution and make a commit."
@@ -68,140 +497,151 @@ msgstr ""
 "Sửa chúng trong cây làm việc, và sau đó dùng lệnh “git add/rm <tập-tin>”\n"
 "dành riêng cho việc đánh dấu cần giải quyết và tạo lần chuyển giao."
 
-#: advice.c:163
+#: advice.c:190
 msgid "Exiting because of an unresolved conflict."
 msgstr "Thoát ra bởi vì xung đột không thể giải quyết."
 
-#: advice.c:168 builtin/merge.c:1250
+#: advice.c:195 builtin/merge.c:1332
 msgid "You have not concluded your merge (MERGE_HEAD exists)."
 msgstr "Bạn chưa kết thúc việc hòa trộn (MERGE_HEAD vẫn tồn tại)."
 
-#: advice.c:170
+#: advice.c:197
 msgid "Please, commit your changes before merging."
 msgstr "Vui lòng chuyển giao các thay đổi trước khi hòa trộn."
 
-#: advice.c:171
+#: advice.c:198
 msgid "Exiting because of unfinished merge."
 msgstr "Thoát ra bởi vì việc hòa trộn không hoàn tất."
 
-#: advice.c:177
+#: advice.c:204
 #, c-format
 msgid ""
-"Note: checking out '%s'.\n"
+"Note: switching to '%s'.\n"
 "\n"
 "You are in 'detached HEAD' state. You can look around, make experimental\n"
 "changes and commit them, and you can discard any commits you make in this\n"
-"state without impacting any branches by performing another checkout.\n"
+"state without impacting any branches by switching back to a branch.\n"
 "\n"
 "If you want to create a new branch to retain commits you create, you may\n"
-"do so (now or later) by using -b with the checkout command again. Example:\n"
+"do so (now or later) by using -c with the switch command. Example:\n"
+"\n"
+"  git switch -c <new-branch-name>\n"
+"\n"
+"Or undo this operation with:\n"
+"\n"
+"  git switch -\n"
 "\n"
-"  git checkout -b <new-branch-name>\n"
+"Turn off this advice by setting config variable advice.detachedHead to "
+"false\n"
 "\n"
 msgstr ""
-"Chú ý: đang lấy ra “%s”.\n"
+"Chú ý: đang chuyển sang “%s”.\n"
 "\n"
 "Bạn đang ở tình trạng “detached HEAD”. Bạn có thể xem qua, tạo các thay\n"
 "đổi thử nghiệm và chuyển giao chúng, bạn có thể loại bỏ bất kỳ lần chuyển\n"
-"giao nào trong tình trạng này mà không cần đụng chậm đến bất kỳ nhánh nào\n"
-"bằng cách thực hiện lần lấy ra khác nữa.\n"
+"giao nào trong tình trạng này mà không cần đụng chạm đến bất kỳ nhánh nào\n"
+"bằng cách chuyển trở lại một nhánh.\n"
 "\n"
 "Nếu bạn muốn tạo một nhánh mới để giữ lại các lần chuyển giao bạn tạo,\n"
-"bạn có thể làm thế (ngay bây giờ hay sau này) bằng cách chạy lệnh checkout\n"
-"lần nữa với tùy chọn -b. Ví dụ:\n"
+"bạn có thể làm thế (ngay bây giờ hay sau này) bằng cách dùng tùy chọn\n"
+"dòng lệnh -b. Ví dụ:\n"
 "\n"
-"  git checkout -b <tên-nhánh-mới>\n"
+"  git checkout -c <tên-nhánh-mới>\n"
 "\n"
+"Hoàn lại thao tác này bằng:\n"
+"\n"
+"  git switch -\n"
+"\n"
+"Tắt hướng dẫn này bằng cách đặt biến advice.detachedHead thành false\n"
+"\n"
+
+#: alias.c:50
+msgid "cmdline ends with \\"
+msgstr "cmdline kết thúc với \\"
 
-#: apply.c:58
+#: alias.c:51
+msgid "unclosed quote"
+msgstr "chưa có dấu nháy đóng"
+
+#: apply.c:69
 #, c-format
 msgid "unrecognized whitespace option '%s'"
 msgstr "không nhận ra tùy chọn về khoảng trắng “%s”"
 
-#: apply.c:74
+#: apply.c:85
 #, c-format
 msgid "unrecognized whitespace ignore option '%s'"
 msgstr "không nhận ra tùy chọn bỏ qua khoảng trắng “%s”"
 
-#: apply.c:122
+#: apply.c:135
 msgid "--reject and --3way cannot be used together."
 msgstr "--reject và --3way không thể dùng cùng nhau."
 
-#: apply.c:124
+#: apply.c:137
 msgid "--cached and --3way cannot be used together."
 msgstr "--cached và --3way không thể dùng cùng nhau."
 
-#: apply.c:127
+#: apply.c:140
 msgid "--3way outside a repository"
 msgstr "--3way ở ngoài một kho chứa"
 
-#: apply.c:138
+#: apply.c:151
 msgid "--index outside a repository"
 msgstr "--index ở ngoài một kho chứa"
 
-#: apply.c:141
+#: apply.c:154
 msgid "--cached outside a repository"
 msgstr "--cached ở ngoài một kho chứa"
 
-#: apply.c:821
+#: apply.c:801
 #, c-format
 msgid "Cannot prepare timestamp regexp %s"
 msgstr ""
 "Không thể chuẩn bị biểu thức chính qui dấu vết thời gian (timestamp regexp) "
 "%s"
 
-#: apply.c:830
+#: apply.c:810
 #, c-format
 msgid "regexec returned %d for input: %s"
 msgstr "thi hành biểu thức chính quy trả về %d cho đầu vào: %s"
 
-#: apply.c:904
+#: apply.c:884
 #, c-format
 msgid "unable to find filename in patch at line %d"
 msgstr "không thể tìm thấy tên tập tin trong miếng vá tại dòng %d"
 
-#: apply.c:942
+#: apply.c:922
 #, c-format
 msgid "git apply: bad git-diff - expected /dev/null, got %s on line %d"
 msgstr ""
 "git apply: git-diff sai - cần /dev/null, nhưng lại nhận được %s trên dòng %d"
 
-#: apply.c:948
+#: apply.c:928
 #, c-format
 msgid "git apply: bad git-diff - inconsistent new filename on line %d"
 msgstr "git apply: git-diff sai - tên tập tin mới không nhất quán trên dòng %d"
 
-#: apply.c:949
+#: apply.c:929
 #, c-format
 msgid "git apply: bad git-diff - inconsistent old filename on line %d"
 msgstr "git apply: git-diff sai - tên tập tin cũ không nhất quán trên dòng %d"
 
-#: apply.c:954
+#: apply.c:934
 #, c-format
 msgid "git apply: bad git-diff - expected /dev/null on line %d"
 msgstr "git apply: git-diff sai - cần “/dev/null” trên dòng %d"
 
-#: apply.c:983
+#: apply.c:963
 #, c-format
 msgid "invalid mode on line %d: %s"
 msgstr "chế độ không hợp lệ trên dòng %d: %s"
 
-#: apply.c:1301
+#: apply.c:1282
 #, c-format
 msgid "inconsistent header lines %d and %d"
 msgstr "phần đầu mâu thuẫn dòng %d và %d"
 
-#: apply.c:1473
-#, c-format
-msgid "recount: unexpected line: %.*s"
-msgstr "chi tiết: dòng không cần: %.*s"
-
-#: apply.c:1542
-#, c-format
-msgid "patch fragment without header at line %d: %.*s"
-msgstr "miếng vá phân mảnh mà không có phần đầu tại dòng %d: %.*s"
-
-#: apply.c:1562
+#: apply.c:1372
 #, c-format
 msgid ""
 "git diff header lacks filename information when removing %d leading pathname "
@@ -213,81 +653,91 @@ msgstr[0] ""
 "phần đầu diff cho git  thiếu thông tin tên tập tin khi gỡ bỏ đi %d trong "
 "thành phần dẫn đầu tên của đường dẫn (dòng %d)"
 
-#: apply.c:1575
+#: apply.c:1385
 #, c-format
 msgid "git diff header lacks filename information (line %d)"
 msgstr "phần đầu diff cho git thiếu thông tin tên tập tin (dòng %d)"
 
-#: apply.c:1763
+#: apply.c:1481
+#, c-format
+msgid "recount: unexpected line: %.*s"
+msgstr "chi tiết: dòng không cần: %.*s"
+
+#: apply.c:1550
+#, c-format
+msgid "patch fragment without header at line %d: %.*s"
+msgstr "miếng vá phân mảnh mà không có phần đầu tại dòng %d: %.*s"
+
+#: apply.c:1753
 msgid "new file depends on old contents"
 msgstr "tập tin mới phụ thuộc vào nội dung cũ"
 
-#: apply.c:1765
+#: apply.c:1755
 msgid "deleted file still has contents"
 msgstr "tập tin đã xóa vẫn còn nội dung"
 
-#: apply.c:1799
+#: apply.c:1789
 #, c-format
 msgid "corrupt patch at line %d"
 msgstr "miếng vá hỏng tại dòng %d"
 
-#: apply.c:1836
+#: apply.c:1826
 #, c-format
 msgid "new file %s depends on old contents"
 msgstr "tập tin mới %s phụ thuộc vào nội dung cũ"
 
-#: apply.c:1838
+#: apply.c:1828
 #, c-format
 msgid "deleted file %s still has contents"
 msgstr "tập tin đã xóa %s vẫn còn nội dung"
 
-#: apply.c:1841
+#: apply.c:1831
 #, c-format
 msgid "** warning: file %s becomes empty but is not deleted"
 msgstr "** cảnh báo: tập tin %s trở nên trống rỗng nhưng không bị xóa"
 
-#: apply.c:1988
+#: apply.c:1978
 #, c-format
 msgid "corrupt binary patch at line %d: %.*s"
 msgstr "miếng vá định dạng nhị phân sai hỏng tại dòng %d: %.*s"
 
-#: apply.c:2025
+#: apply.c:2015
 #, c-format
 msgid "unrecognized binary patch at line %d"
 msgstr "miếng vá định dạng nhị phân không được nhận ra tại dòng %d"
 
-#: apply.c:2185
+#: apply.c:2177
 #, c-format
 msgid "patch with only garbage at line %d"
 msgstr "vá chỉ với “rác” tại dòng %d"
 
-#: apply.c:2271
+#: apply.c:2263
 #, c-format
 msgid "unable to read symlink %s"
 msgstr "không thể đọc liên kết mềm %s"
 
-#: apply.c:2275
+#: apply.c:2267
 #, c-format
 msgid "unable to open or read %s"
 msgstr "không thể mở hay đọc %s"
 
-#: apply.c:2934
+#: apply.c:2936
 #, c-format
 msgid "invalid start of line: '%c'"
 msgstr "sai khởi đầu dòng: “%c”"
 
-#: apply.c:3055
+#: apply.c:3057
 #, c-format
 msgid "Hunk #%d succeeded at %d (offset %d line)."
 msgid_plural "Hunk #%d succeeded at %d (offset %d lines)."
 msgstr[0] "Khối dữ liệu #%d thành công tại %d (offset %d dòng)."
 
-#: apply.c:3067
+#: apply.c:3069
 #, c-format
 msgid "Context reduced to (%ld/%ld) to apply fragment at %d"
 msgstr "Nội dung bị giảm xuống còn (%ld/%ld) để áp dụng mảnh dữ liệu tại %d"
 
-#: apply.c:3073
+#: apply.c:3075
 #, c-format
 msgid ""
 "while searching for:\n"
@@ -296,572 +746,638 @@ msgstr ""
 "trong khi đang tìm kiếm cho:\n"
 "%.*s"
 
-#: apply.c:3095
+#: apply.c:3097
 #, c-format
 msgid "missing binary patch data for '%s'"
 msgstr "thiếu dữ liệu của miếng vá định dạng nhị phân cho “%s”"
 
-#: apply.c:3103
+#: apply.c:3105
 #, c-format
 msgid "cannot reverse-apply a binary patch without the reverse hunk to '%s'"
 msgstr ""
-"không thể reverse-apply một miếng vá nhị phân mà không đảo ngược hunk thành "
+"không thể reverse-apply một miếng vá nhị phân mà không đảo ngược khúc thành "
 "“%s”"
 
-#: apply.c:3149
+#: apply.c:3152
 #, c-format
 msgid "cannot apply binary patch to '%s' without full index line"
 msgstr ""
 "không thể áp dụng miếng vá nhị phân thành “%s” mà không có dòng chỉ mục đầy "
 "đủ"
 
-#: apply.c:3159
+#: apply.c:3162
 #, c-format
 msgid ""
 "the patch applies to '%s' (%s), which does not match the current contents."
 msgstr ""
 "miếng vá áp dụng cho “%s” (%s), cái mà không khớp với các nội dung hiện tại."
 
-#: apply.c:3167
+#: apply.c:3170
 #, c-format
 msgid "the patch applies to an empty '%s' but it is not empty"
 msgstr "miếng vá áp dụng cho một “%s” trống rỗng nhưng nó lại không trống"
 
-#: apply.c:3185
+#: apply.c:3188
 #, c-format
 msgid "the necessary postimage %s for '%s' cannot be read"
 msgstr "không thể đọc postimage %s cần thiết cho “%s”"
 
-#: apply.c:3198
+#: apply.c:3201
 #, c-format
 msgid "binary patch does not apply to '%s'"
 msgstr "miếng vá định dạng nhị phân không được áp dụng cho “%s”"
 
-#: apply.c:3204
+#: apply.c:3207
 #, c-format
 msgid "binary patch to '%s' creates incorrect result (expecting %s, got %s)"
 msgstr ""
 "vá nhị phân cho “%s” tạo ra kết quả không chính xác (mong chờ %s, lại nhận "
 "%s)"
 
-#: apply.c:3225
+#: apply.c:3228
 #, c-format
 msgid "patch failed: %s:%ld"
 msgstr "gặp lỗi khi vá: %s:%ld"
 
-#: apply.c:3347
+#: apply.c:3351
 #, c-format
 msgid "cannot checkout %s"
 msgstr "không thể lấy ra %s"
 
-#: apply.c:3396 apply.c:3407 apply.c:3453 setup.c:278
+#: apply.c:3403 apply.c:3414 apply.c:3460 midx.c:61 setup.c:280
 #, c-format
 msgid "failed to read %s"
 msgstr "gặp lỗi khi đọc %s"
 
-#: apply.c:3404
+#: apply.c:3411
 #, c-format
 msgid "reading from '%s' beyond a symbolic link"
 msgstr "đọc từ “%s” vượt ra ngoài liên kết mềm"
 
-#: apply.c:3433 apply.c:3673
+#: apply.c:3440 apply.c:3683
 #, c-format
 msgid "path %s has been renamed/deleted"
 msgstr "đường dẫn %s đã bị xóa hoặc đổi tên"
 
-#: apply.c:3516 apply.c:3687
+#: apply.c:3526 apply.c:3698
 #, c-format
 msgid "%s: does not exist in index"
 msgstr "%s: không tồn tại trong bảng mục lục"
 
-#: apply.c:3525 apply.c:3695
+#: apply.c:3535 apply.c:3706
 #, c-format
 msgid "%s: does not match index"
 msgstr "%s: không khớp trong mục lục"
 
-#: apply.c:3560
+#: apply.c:3570
 msgid "repository lacks the necessary blob to fall back on 3-way merge."
-msgstr "Kho thiếu đối tượng blob cần thiết để trở về trên “3-way merge”."
+msgstr "kho thiếu đối tượng blob cần thiết để trở về trên “3-way merge”."
 
-#: apply.c:3563
+#: apply.c:3573
 #, c-format
 msgid "Falling back to three-way merge...\n"
 msgstr "Đang trở lại hòa trộn “3-đường”…\n"
 
-#: apply.c:3579 apply.c:3583
+#: apply.c:3589 apply.c:3593
 #, c-format
 msgid "cannot read the current contents of '%s'"
 msgstr "không thể đọc nội dung hiện hành của “%s”"
 
-#: apply.c:3595
+#: apply.c:3605
 #, c-format
 msgid "Failed to fall back on three-way merge...\n"
 msgstr "Gặp lỗi khi quay trở lại để hòa trộn kiểu “three-way”…\n"
 
-#: apply.c:3609
+#: apply.c:3619
 #, c-format
 msgid "Applied patch to '%s' with conflicts.\n"
 msgstr "Đã áp dụng miếng vá %s với các xung đột.\n"
 
-#: apply.c:3614
+#: apply.c:3624
 #, c-format
 msgid "Applied patch to '%s' cleanly.\n"
 msgstr "Đã áp dụng miếng vá %s một cách sạch sẽ.\n"
 
-#: apply.c:3640
+#: apply.c:3650
 msgid "removal patch leaves file contents"
 msgstr "loại bỏ miếng vá để lại nội dung tập tin"
 
-#: apply.c:3712
+#: apply.c:3723
 #, c-format
 msgid "%s: wrong type"
 msgstr "%s: sai kiểu"
 
-#: apply.c:3714
+#: apply.c:3725
 #, c-format
 msgid "%s has type %o, expected %o"
 msgstr "%s có kiểu %o, cần %o"
 
-#: apply.c:3864 apply.c:3866
+#: apply.c:3876 apply.c:3878 read-cache.c:830 read-cache.c:856
+#: read-cache.c:1320
 #, c-format
 msgid "invalid path '%s'"
 msgstr "đường dẫn không hợp lệ “%s”"
 
-#: apply.c:3922
+#: apply.c:3934
 #, c-format
 msgid "%s: already exists in index"
 msgstr "%s: đã có từ trước trong bảng mục lục"
 
-#: apply.c:3925
+#: apply.c:3937
 #, c-format
 msgid "%s: already exists in working directory"
 msgstr "%s: đã sẵn có trong thư mục đang làm việc"
 
-#: apply.c:3945
+#: apply.c:3957
 #, c-format
 msgid "new mode (%o) of %s does not match old mode (%o)"
 msgstr "chế độ mới (%o) của %s không khớp với chế độ cũ (%o)"
 
-#: apply.c:3950
+#: apply.c:3962
 #, c-format
 msgid "new mode (%o) of %s does not match old mode (%o) of %s"
 msgstr "chế độ mới (%o) của %s không khớp với chế độ cũ (%o) của %s"
 
-#: apply.c:3970
+#: apply.c:3982
 #, c-format
 msgid "affected file '%s' is beyond a symbolic link"
 msgstr "tập tin chịu tác động “%s” vượt ra ngoài liên kết mềm"
 
-#: apply.c:3974
+#: apply.c:3986
 #, c-format
 msgid "%s: patch does not apply"
 msgstr "%s: miếng vá không được áp dụng"
 
-#: apply.c:3989
+#: apply.c:4001
 #, c-format
 msgid "Checking patch %s..."
 msgstr "Đang kiểm tra miếng vá %s…"
 
-#: apply.c:4080
+#: apply.c:4093
 #, c-format
 msgid "sha1 information is lacking or useless for submodule %s"
 msgstr "thông tin sha1 thiếu hoặc không dùng được cho mô-đun %s"
 
-#: apply.c:4087
+#: apply.c:4100
 #, c-format
 msgid "mode change for %s, which is not in current HEAD"
 msgstr "thay đổi chế độ cho %s, cái mà không phải là HEAD hiện tại"
 
-#: apply.c:4090
+#: apply.c:4103
 #, c-format
 msgid "sha1 information is lacking or useless (%s)."
 msgstr "thông tin sha1 còn thiếu hay không dùng được(%s)."
 
-#: apply.c:4095 builtin/checkout.c:235 builtin/reset.c:140
-#, c-format
-msgid "make_cache_entry failed for path '%s'"
-msgstr "make_cache_entry gặp lỗi đối với đường dẫn “%s”"
-
-#: apply.c:4099
+#: apply.c:4112
 #, c-format
 msgid "could not add %s to temporary index"
 msgstr "không thể thêm %s vào chỉ mục tạm thời"
 
-#: apply.c:4109
+#: apply.c:4122
 #, c-format
 msgid "could not write temporary index to %s"
-msgstr "không thểghi mục lục tạm vào %s"
+msgstr "không thể ghi mục lục tạm vào %s"
 
-#: apply.c:4247
+#: apply.c:4260
 #, c-format
 msgid "unable to remove %s from index"
 msgstr "không thể gỡ bỏ %s từ mục lục"
 
-#: apply.c:4282
+#: apply.c:4294
 #, c-format
 msgid "corrupt patch for submodule %s"
 msgstr "miếng vá sai hỏng cho mô-đun-con %s"
 
-#: apply.c:4288
+#: apply.c:4300
 #, c-format
 msgid "unable to stat newly created file '%s'"
-msgstr "không thể lấy thống kề về tập tin %s mới hơn đã được tạo"
+msgstr "không thể lấy thống kê về tập tin %s mới hơn đã được tạo"
 
-#: apply.c:4296
+#: apply.c:4308
 #, c-format
 msgid "unable to create backing store for newly created file %s"
 msgstr "không thể tạo “kho lưu đằng sau” cho tập tin được tạo mới hơn %s"
 
-#: apply.c:4302 apply.c:4446
+#: apply.c:4314 apply.c:4459
 #, c-format
 msgid "unable to add cache entry for %s"
 msgstr "không thể thêm mục nhớ đệm cho %s"
 
-#: apply.c:4343
+#: apply.c:4357
 #, c-format
 msgid "failed to write to '%s'"
 msgstr "gặp lỗi khi ghi vào “%s”"
 
-#: apply.c:4347
+#: apply.c:4361
 #, c-format
 msgid "closing file '%s'"
 msgstr "đang đóng tập tin “%s”"
 
-#: apply.c:4417
+#: apply.c:4431
 #, c-format
 msgid "unable to write file '%s' mode %o"
 msgstr "không thể ghi vào tập tin “%s” chế độ %o"
 
-#: apply.c:4515
+#: apply.c:4529
 #, c-format
 msgid "Applied patch %s cleanly."
 msgstr "Đã áp dụng miếng vá %s một cách sạch sẽ."
 
-#: apply.c:4523
+#: apply.c:4537
 msgid "internal error"
 msgstr "lỗi nội bộ"
 
-#: apply.c:4526
+#: apply.c:4540
 #, c-format
 msgid "Applying patch %%s with %d reject..."
 msgid_plural "Applying patch %%s with %d rejects..."
 msgstr[0] "Đang áp dụng miếng vá %%s với %d lần từ chối…"
 
-#: apply.c:4537
+#: apply.c:4551
 #, c-format
 msgid "truncating .rej filename to %.*s.rej"
 msgstr "đang cắt ngắn tên tập tin .rej thành %.*s.rej"
 
-#: apply.c:4545 builtin/fetch.c:786 builtin/fetch.c:1036
+#: apply.c:4559 builtin/fetch.c:901 builtin/fetch.c:1192
 #, c-format
 msgid "cannot open %s"
 msgstr "không mở được “%s”"
 
-#: apply.c:4559
+#: apply.c:4573
 #, c-format
 msgid "Hunk #%d applied cleanly."
 msgstr "Khối nhớ #%d được áp dụng gọn gàng."
 
-#: apply.c:4563
+#: apply.c:4577
 #, c-format
 msgid "Rejected hunk #%d."
-msgstr "đoạn dữ liệu #%d bị từ chối."
+msgstr "Đoạn dữ liệu #%d bị từ chối."
 
-#: apply.c:4673
+#: apply.c:4696
 #, c-format
 msgid "Skipped patch '%s'."
-msgstr "bỏ qua đường dẫn “%s”."
+msgstr "Bỏ qua đường dẫn “%s”."
 
-#: apply.c:4681
+#: apply.c:4704
 msgid "unrecognized input"
 msgstr "không thừa nhận đầu vào"
 
-#: apply.c:4700
+#: apply.c:4724
 msgid "unable to read index file"
 msgstr "không thể đọc tập tin lưu bảng mục lục"
 
-#: apply.c:4837
+#: apply.c:4881
 #, c-format
 msgid "can't open patch '%s': %s"
 msgstr "không thể mở miếng vá “%s”: %s"
 
-#: apply.c:4864
+#: apply.c:4908
 #, c-format
 msgid "squelched %d whitespace error"
 msgid_plural "squelched %d whitespace errors"
 msgstr[0] "đã chấm dứt %d lỗi khoảng trắng"
 
-#: apply.c:4870 apply.c:4885
+#: apply.c:4914 apply.c:4929
 #, c-format
 msgid "%d line adds whitespace errors."
 msgid_plural "%d lines add whitespace errors."
 msgstr[0] "%d dòng thêm khoảng trắng lỗi."
 
-#: apply.c:4878
+#: apply.c:4922
 #, c-format
 msgid "%d line applied after fixing whitespace errors."
 msgid_plural "%d lines applied after fixing whitespace errors."
 msgstr[0] "%d dòng được áp dụng sau khi sửa các lỗi khoảng trắng."
 
-#: apply.c:4894 builtin/add.c:538 builtin/mv.c:300 builtin/rm.c:389
+#: apply.c:4938 builtin/add.c:579 builtin/mv.c:301 builtin/rm.c:390
 msgid "Unable to write new index file"
 msgstr "Không thể ghi tập tin lưu bảng mục lục mới"
 
-#: apply.c:4921 apply.c:4924 builtin/am.c:2254 builtin/am.c:2257
-#: builtin/clone.c:120 builtin/fetch.c:126 builtin/pull.c:198
-#: builtin/submodule--helper.c:405 builtin/submodule--helper.c:1210
-#: builtin/submodule--helper.c:1213 builtin/submodule--helper.c:1584
-#: builtin/submodule--helper.c:1587 builtin/submodule--helper.c:1807
-#: git-add--interactive.perl:197
-msgid "path"
-msgstr "đường-dẫn"
-
-#: apply.c:4922
+#: apply.c:4966
 msgid "don't apply changes matching the given path"
 msgstr "không áp dụng các thay đổi khớp với đường dẫn đã cho"
 
-#: apply.c:4925
+#: apply.c:4969
 msgid "apply changes matching the given path"
 msgstr "áp dụng các thay đổi khớp với đường dẫn đã cho"
 
-#: apply.c:4927 builtin/am.c:2263
+#: apply.c:4971 builtin/am.c:2206
 msgid "num"
 msgstr "số"
 
-#: apply.c:4928
+#: apply.c:4972
 msgid "remove <num> leading slashes from traditional diff paths"
 msgstr "gỡ bỏ <số> dấu gạch chéo dẫn đầu từ đường dẫn diff cổ điển"
 
-#: apply.c:4931
+#: apply.c:4975
 msgid "ignore additions made by the patch"
 msgstr "lờ đi phần bổ xung được tạo ra bởi miếng vá"
 
-#: apply.c:4933
+#: apply.c:4977
 msgid "instead of applying the patch, output diffstat for the input"
 msgstr ""
 "thay vì áp dụng một miếng vá, kết xuất kết quả từ lệnh diffstat cho đầu ra"
 
-#: apply.c:4937
+#: apply.c:4981
 msgid "show number of added and deleted lines in decimal notation"
 msgstr ""
 "hiển thị số lượng các dòng được thêm vào và xóa đi theo ký hiệu thập phân"
 
-#: apply.c:4939
+#: apply.c:4983
 msgid "instead of applying the patch, output a summary for the input"
 msgstr "thay vì áp dụng một miếng vá, kết xuất kết quả cho đầu vào"
 
-#: apply.c:4941
+#: apply.c:4985
 msgid "instead of applying the patch, see if the patch is applicable"
 msgstr "thay vì áp dụng miếng vá, hãy xem xem miếng vá có thích hợp không"
 
-#: apply.c:4943
+#: apply.c:4987
 msgid "make sure the patch is applicable to the current index"
 msgstr "hãy chắc chắn là miếng vá thích hợp với bảng mục lục hiện hành"
 
-#: apply.c:4945
+#: apply.c:4989
+msgid "mark new files with `git add --intent-to-add`"
+msgstr "đánh dấu các tập tin mới với “git add --intent-to-add”"
+
+#: apply.c:4991
 msgid "apply a patch without touching the working tree"
 msgstr "áp dụng một miếng vá mà không động chạm đến cây làm việc"
 
-#: apply.c:4947
+#: apply.c:4993
 msgid "accept a patch that touches outside the working area"
 msgstr "chấp nhận một miếng vá mà không động chạm đến cây làm việc"
 
-#: apply.c:4950
+#: apply.c:4996
 msgid "also apply the patch (use with --stat/--summary/--check)"
 msgstr ""
 "đồng thời áp dụng miếng vá (dùng với tùy chọn --stat/--summary/--check)"
 
-#: apply.c:4952
+#: apply.c:4998
 msgid "attempt three-way merge if a patch does not apply"
 msgstr "thử hòa trộn kiểu three-way nếu việc vá không thể thực hiện được"
 
-#: apply.c:4954
+#: apply.c:5000
 msgid "build a temporary index based on embedded index information"
 msgstr ""
 "xây dựng bảng mục lục tạm thời trên cơ sở thông tin bảng mục lục được nhúng"
 
-#: apply.c:4957 builtin/checkout-index.c:168 builtin/ls-files.c:515
+#: apply.c:5003 builtin/checkout-index.c:173 builtin/ls-files.c:524
 msgid "paths are separated with NUL character"
 msgstr "các đường dẫn bị ngăn cách bởi ký tự NULL"
 
-#: apply.c:4959
+#: apply.c:5005
 msgid "ensure at least <n> lines of context match"
 msgstr "đảm bảo rằng có ít nhất <n> dòng nội dung khớp"
 
-#: apply.c:4960 builtin/am.c:2242 builtin/interpret-trailers.c:95
-#: builtin/interpret-trailers.c:97 builtin/interpret-trailers.c:99
-#: builtin/pack-objects.c:3177
+#: apply.c:5006 builtin/am.c:2185 builtin/interpret-trailers.c:98
+#: builtin/interpret-trailers.c:100 builtin/interpret-trailers.c:102
+#: builtin/pack-objects.c:3310 builtin/rebase.c:1474
 msgid "action"
 msgstr "hành động"
 
-#: apply.c:4961
+#: apply.c:5007
 msgid "detect new or modified lines that have whitespace errors"
 msgstr "tìm thấy một dòng mới hoặc bị sửa đổi mà nó có lỗi do khoảng trắng"
 
-#: apply.c:4964 apply.c:4967
+#: apply.c:5010 apply.c:5013
 msgid "ignore changes in whitespace when finding context"
 msgstr "lờ đi sự thay đổi do khoảng trắng gây ra khi quét nội dung"
 
-#: apply.c:4970
+#: apply.c:5016
 msgid "apply the patch in reverse"
 msgstr "áp dụng miếng vá theo chiều ngược"
 
-#: apply.c:4972
+#: apply.c:5018
 msgid "don't expect at least one line of context"
 msgstr "đừng hy vọng có ít nhất một dòng nội dung"
 
-#: apply.c:4974
+#: apply.c:5020
 msgid "leave the rejected hunks in corresponding *.rej files"
 msgstr "để lại khối dữ liệu bị từ chối trong các tập tin *.rej tương ứng"
 
-#: apply.c:4976
+#: apply.c:5022
 msgid "allow overlapping hunks"
 msgstr "cho phép chồng khối nhớ"
 
-#: apply.c:4977 builtin/add.c:290 builtin/check-ignore.c:21
-#: builtin/commit.c:1301 builtin/count-objects.c:98 builtin/fsck.c:666
-#: builtin/log.c:1901 builtin/mv.c:122 builtin/read-tree.c:124
+#: apply.c:5023 builtin/add.c:309 builtin/check-ignore.c:22
+#: builtin/commit.c:1355 builtin/count-objects.c:98 builtin/fsck.c:774
+#: builtin/log.c:2166 builtin/mv.c:123 builtin/read-tree.c:128
 msgid "be verbose"
 msgstr "chi tiết"
 
-#: apply.c:4979
+#: apply.c:5025
 msgid "tolerate incorrectly detected missing new-line at the end of file"
 msgstr ""
 "đã dò tìm thấy dung sai không chính xác thiếu dòng mới tại cuối tập tin"
 
-#: apply.c:4982
+#: apply.c:5028
 msgid "do not trust the line counts in the hunk headers"
 msgstr "không tin số lượng dòng trong phần đầu khối dữ liệu"
 
-#: apply.c:4984 builtin/am.c:2251
+#: apply.c:5030 builtin/am.c:2194
 msgid "root"
 msgstr "gốc"
 
-#: apply.c:4985
+#: apply.c:5031
 msgid "prepend <root> to all filenames"
 msgstr "treo thêm <root> vào tất cả các tên tập tin"
 
-#: archive.c:13
+#: archive.c:14
 msgid "git archive [<options>] <tree-ish> [<path>...]"
-msgstr "git archive [<các-tùy-chọn>] <tree-ish> [<đường-dẫn>…]"
+msgstr "git archive [<các tùy chọn>] <tree-ish> [</đường/dẫn>…]"
 
-#: archive.c:14
+#: archive.c:15
 msgid "git archive --list"
 msgstr "git archive --list"
 
-#: archive.c:15
+#: archive.c:16
 msgid ""
 "git archive --remote <repo> [--exec <cmd>] [<options>] <tree-ish> [<path>...]"
 msgstr ""
-"git archive --remote <kho> [--exec <lệnh>] [<các-tùy-chọn>] <tree-ish> "
-"[<đường-dẫn>…]"
+"git archive --remote <kho> [--exec <lệnh>] [<các tùy chọn>] <tree-ish> [</"
+"đường/dẫn>…]"
 
-#: archive.c:16
+#: archive.c:17
 msgid "git archive --remote <repo> [--exec <cmd>] --list"
 msgstr "git archive --remote <kho> [--exec <lệnh>] --list"
 
-#: archive.c:351 builtin/add.c:176 builtin/add.c:514 builtin/rm.c:298
+#: archive.c:372 builtin/add.c:180 builtin/add.c:555 builtin/rm.c:299
 #, c-format
 msgid "pathspec '%s' did not match any files"
 msgstr "đặc tả đường dẫn “%s” không khớp với bất kỳ tập tin nào"
 
-#: archive.c:434
+#: archive.c:396
+#, c-format
+msgid "no such ref: %.*s"
+msgstr "không có tham chiếu nào như thế: %.*s"
+
+#: archive.c:401
+#, c-format
+msgid "not a valid object name: %s"
+msgstr "không phải là tên đối tượng hợp lệ: “%s”"
+
+#: archive.c:414
+#, c-format
+msgid "not a tree object: %s"
+msgstr "không phải là đối tượng cây: “%s”"
+
+#: archive.c:426
+msgid "current working directory is untracked"
+msgstr "thư mục làm việc hiện hành chưa được theo dõi"
+
+#: archive.c:457
 msgid "fmt"
 msgstr "định_dạng"
 
-#: archive.c:434
+#: archive.c:457
 msgid "archive format"
 msgstr "định dạng lưu trữ"
 
-#: archive.c:435 builtin/log.c:1462
+#: archive.c:458 builtin/log.c:1653
 msgid "prefix"
 msgstr "tiền_tố"
 
-#: archive.c:436
+#: archive.c:459
 msgid "prepend prefix to each pathname in the archive"
 msgstr "nối thêm tiền tố vào từng đường dẫn tập tin trong kho lưu"
 
-#: archive.c:437 builtin/blame.c:813 builtin/blame.c:814 builtin/config.c:127
-#: builtin/fast-export.c:1007 builtin/fast-export.c:1009 builtin/grep.c:869
-#: builtin/hash-object.c:103 builtin/ls-files.c:551 builtin/ls-files.c:554
-#: builtin/notes.c:405 builtin/notes.c:568 builtin/read-tree.c:119
-#: parse-options.h:165
+#: archive.c:460 builtin/blame.c:861 builtin/blame.c:865 builtin/blame.c:866
+#: builtin/commit-tree.c:117 builtin/config.c:129 builtin/fast-export.c:1162
+#: builtin/fast-export.c:1164 builtin/fast-export.c:1168 builtin/grep.c:899
+#: builtin/hash-object.c:105 builtin/ls-files.c:560 builtin/ls-files.c:563
+#: builtin/notes.c:412 builtin/notes.c:578 builtin/read-tree.c:123
+#: parse-options.h:190
 msgid "file"
 msgstr "tập_tin"
 
-#: archive.c:438 builtin/archive.c:89
+#: archive.c:461 builtin/archive.c:90
 msgid "write the archive to this file"
 msgstr "ghi kho lưu vào tập tin này"
 
-#: archive.c:440
+#: archive.c:463
 msgid "read .gitattributes in working directory"
 msgstr "đọc .gitattributes trong thư mục làm việc"
 
-#: archive.c:441
+#: archive.c:464
 msgid "report archived files on stderr"
 msgstr "liệt kê các tập tin được lưu trữ vào stderr (đầu ra lỗi tiêu chuẩn)"
 
-#: archive.c:442
+#: archive.c:465
 msgid "store only"
 msgstr "chỉ lưu (không nén)"
 
-#: archive.c:443
+#: archive.c:466
 msgid "compress faster"
 msgstr "nén nhanh hơn"
 
-#: archive.c:451
+#: archive.c:474
 msgid "compress better"
 msgstr "nén nhỏ hơn"
 
-#: archive.c:454
+#: archive.c:477
 msgid "list supported archive formats"
 msgstr "liệt kê các kiểu nén được hỗ trợ"
 
-#: archive.c:456 builtin/archive.c:90 builtin/clone.c:110 builtin/clone.c:113
-#: builtin/submodule--helper.c:1222 builtin/submodule--helper.c:1593
+#: archive.c:479 builtin/archive.c:91 builtin/clone.c:113 builtin/clone.c:116
+#: builtin/submodule--helper.c:1391 builtin/submodule--helper.c:1884
 msgid "repo"
 msgstr "kho"
 
-#: archive.c:457 builtin/archive.c:91
+#: archive.c:480 builtin/archive.c:92
 msgid "retrieve the archive from remote repository <repo>"
 msgstr "nhận kho nén từ kho chứa <kho> trên máy chủ"
 
-#: archive.c:458 builtin/archive.c:92 builtin/notes.c:489
+#: archive.c:481 builtin/archive.c:93 builtin/difftool.c:715
+#: builtin/notes.c:498
 msgid "command"
 msgstr "lệnh"
 
-#: archive.c:459 builtin/archive.c:93
+#: archive.c:482 builtin/archive.c:94
 msgid "path to the remote git-upload-archive command"
 msgstr "đường dẫn đến lệnh git-upload-pack trên máy chủ"
 
-#: archive.c:466
+#: archive.c:489
 msgid "Unexpected option --remote"
-msgstr "Gặp tùy chọn --remote không cần"
+msgstr "Gặp tùy chọn không cần --remote"
 
-#: archive.c:468
+#: archive.c:491
 msgid "Option --exec can only be used together with --remote"
 msgstr "Tùy chọn --exec chỉ có thể được dùng cùng với --remote"
 
-#: archive.c:470
+#: archive.c:493
 msgid "Unexpected option --output"
 msgstr "Gặp tùy chọn không cần --output"
 
-#: archive.c:492
+#: archive.c:515
 #, c-format
 msgid "Unknown archive format '%s'"
 msgstr "Không hiểu định dạng “%s”"
 
-#: archive.c:499
+#: archive.c:522
 #, c-format
 msgid "Argument not supported for format '%s': -%d"
 msgstr "Tham số không được hỗ trợ cho định dạng “%s”: -%d"
 
-#: attr.c:218
+#: archive-tar.c:125 archive-zip.c:350
+#, c-format
+msgid "cannot stream blob %s"
+msgstr "không thể stream blob “%s”"
+
+#: archive-tar.c:266 archive-zip.c:368
+#, c-format
+msgid "unsupported file mode: 0%o (SHA1: %s)"
+msgstr "chế độ tập tin lục không được hỗ trợ: 0%o (SHA1: %s)"
+
+#: archive-tar.c:293 archive-zip.c:358
+#, c-format
+msgid "cannot read %s"
+msgstr "không thể đọc %s"
+
+#: archive-tar.c:465
+#, c-format
+msgid "unable to start '%s' filter"
+msgstr "không thể bắt đầu bộ lọc “%s”"
+
+#: archive-tar.c:468
+msgid "unable to redirect descriptor"
+msgstr "không thể chuyển hướng mô tả"
+
+#: archive-tar.c:475
+#, c-format
+msgid "'%s' filter reported error"
+msgstr "bộ lọc “%s” đã báo cáo lỗi"
+
+#: archive-zip.c:319
+#, c-format
+msgid "path is not valid UTF-8: %s"
+msgstr "đường dẫn không hợp lệ UTF-8: %s"
+
+#: archive-zip.c:323
+#, c-format
+msgid "path too long (%d chars, SHA1: %s): %s"
+msgstr "đường dẫn quá dài (%d ký tự, SHA1: %s): %s"
+
+#: archive-zip.c:479 builtin/pack-objects.c:230 builtin/pack-objects.c:233
+#, c-format
+msgid "deflate error (%d)"
+msgstr "lỗi giải nén (%d)"
+
+#: archive-zip.c:614
+#, c-format
+msgid "timestamp too large for this system: %<PRIuMAX>"
+msgstr "dấu vết thời gian là quá lớn cho hệ thống này: %<PRIuMAX>"
+
+#: attr.c:212
 #, c-format
 msgid "%.*s is not a valid attribute name"
 msgstr "%.*s không phải tên thuộc tính hợp lệ"
 
-#: attr.c:415
+#: attr.c:369
+#, c-format
+msgid "%s not allowed: %s:%d"
+msgstr "%s không được phép: %s:%d"
+
+#: attr.c:409
 msgid ""
 "Negative patterns are ignored in git attributes\n"
 "Use '\\!' for literal leading exclamation."
@@ -869,22 +1385,22 @@ msgstr ""
 "Các mẫu dạng phủ định bị cấm dùng cho các thuộc tính của git\n"
 "Dùng “\\!” cho các chuỗi văn bản có dấu chấm than dẫn đầu."
 
-#: bisect.c:461
+#: bisect.c:468
 #, c-format
 msgid "Badly quoted content in file '%s': %s"
-msgstr "nội dung được trích dẫn sai tập tin “%s”: %s"
+msgstr "Nội dung được trích dẫn sai trong tập tin “%s”: %s"
 
-#: bisect.c:669
+#: bisect.c:678
 #, c-format
 msgid "We cannot bisect more!\n"
 msgstr "Chúng tôi không bisect thêm nữa!\n"
 
-#: bisect.c:723
+#: bisect.c:733
 #, c-format
 msgid "Not a valid commit name %s"
 msgstr "Không phải tên đối tượng commit %s hợp lệ"
 
-#: bisect.c:747
+#: bisect.c:758
 #, c-format
 msgid ""
 "The merge base %s is bad.\n"
@@ -893,7 +1409,7 @@ msgstr ""
 "Hòa trộn trên %s là sai.\n"
 "Điều đó có nghĩa là lỗi đã được sửa chữa giữa %s và [%s].\n"
 
-#: bisect.c:752
+#: bisect.c:763
 #, c-format
 msgid ""
 "The merge base %s is new.\n"
@@ -902,7 +1418,7 @@ msgstr ""
 "Hòa trộn trên %s là mới.\n"
 "Gần như chắc chắn là có thay đổi giữa %s và [%s].\n"
 
-#: bisect.c:757
+#: bisect.c:768
 #, c-format
 msgid ""
 "The merge base %s is %s.\n"
@@ -911,7 +1427,7 @@ msgstr ""
 "Hòa trộn trên %s là %s.\n"
 "Điều đó có nghĩa là lần chuyển giao “%s” đầu tiên là giữa %s và [%s].\n"
 
-#: bisect.c:765
+#: bisect.c:776
 #, c-format
 msgid ""
 "Some %s revs are not ancestors of the %s rev.\n"
@@ -922,7 +1438,7 @@ msgstr ""
 "git bisect không thể làm việc đúng đắn trong trường hợp này.\n"
 "Liệu có phải bạn nhầm lẫn các điểm %s và %s không?\n"
 
-#: bisect.c:778
+#: bisect.c:789
 #, c-format
 msgid ""
 "the merge base between %s and [%s] must be skipped.\n"
@@ -934,45 +1450,45 @@ msgstr ""
 "%s.\n"
 "Chúng tôi vẫn cứ tiếp tục."
 
-#: bisect.c:811
+#: bisect.c:822
 #, c-format
 msgid "Bisecting: a merge base must be tested\n"
 msgstr "Bisecting: nền hòa trộn cần phải được kiểm tra\n"
 
-#: bisect.c:851
+#: bisect.c:865
 #, c-format
 msgid "a %s revision is needed"
 msgstr "cần một điểm xét duyệt %s"
 
-#: bisect.c:870 builtin/notes.c:175 builtin/tag.c:236
+#: bisect.c:884 builtin/notes.c:177 builtin/tag.c:254
 #, c-format
 msgid "could not create file '%s'"
 msgstr "không thể tạo tập tin “%s”"
 
-#: bisect.c:921
+#: bisect.c:928 builtin/merge.c:148
 #, c-format
 msgid "could not read file '%s'"
 msgstr "không thể đọc tập tin “%s”"
 
-#: bisect.c:951
+#: bisect.c:958
 msgid "reading bisect refs failed"
 msgstr "việc đọc tham chiếu bisect gặp lỗi"
 
-#: bisect.c:970
+#: bisect.c:977
 #, c-format
 msgid "%s was both %s and %s\n"
 msgstr "%s là cả %s và %s\n"
 
-#: bisect.c:978
+#: bisect.c:985
 #, c-format
 msgid ""
 "No testable commit found.\n"
 "Maybe you started with bad path parameters?\n"
 msgstr ""
-"không tìm thấy lần chuyển giao kiểm tra được nào.\n"
+"Không tìm thấy lần chuyển giao kiểm tra được nào.\n"
 "Có lẽ bạn bắt đầu với các tham số đường dẫn sai?\n"
 
-#: bisect.c:997
+#: bisect.c:1004
 #, c-format
 msgid "(roughly %d step)"
 msgid_plural "(roughly %d steps)"
@@ -981,50 +1497,51 @@ msgstr[0] "(ước chừng %d bước)"
 #. TRANSLATORS: the last %s will be replaced with "(roughly %d
 #. steps)" translation.
 #.
-#: bisect.c:1003
+#: bisect.c:1010
 #, c-format
 msgid "Bisecting: %d revision left to test after this %s\n"
 msgid_plural "Bisecting: %d revisions left to test after this %s\n"
 msgstr[0] "Bisecting: còn %d điểm xét duyệt để kiểm sau %s này\n"
 
-#: blame.c:1756
+#: blame.c:2700
 msgid "--contents and --reverse do not blend well."
 msgstr "tùy chọn--contents và --reverse không được trộn vào nhau."
 
-#: blame.c:1767
+#: blame.c:2714
 msgid "cannot use --contents with final commit object name"
 msgstr "không thể dùng --contents với tên đối tượng chuyển giao cuối cùng"
 
-#: blame.c:1787
+#: blame.c:2735
 msgid "--reverse and --first-parent together require specified latest commit"
 msgstr ""
-"--reverse và --first-parent cùng nhau cần chỉ định lần chuyển giao cuối"
+"cùng sử dụng --reverse và --first-parent cần chỉ định lần chuyển giao cuối"
 
-#: blame.c:1796 bundle.c:160 ref-filter.c:2075 sequencer.c:1861
-#: sequencer.c:3632 builtin/commit.c:981 builtin/log.c:366 builtin/log.c:920
-#: builtin/log.c:1371 builtin/log.c:1702 builtin/log.c:1950 builtin/merge.c:372
+#: blame.c:2744 bundle.c:167 ref-filter.c:2203 remote.c:1941 sequencer.c:2093
+#: sequencer.c:4460 builtin/commit.c:1040 builtin/log.c:388 builtin/log.c:991
+#: builtin/log.c:1520 builtin/log.c:1925 builtin/log.c:2215 builtin/merge.c:411
+#: builtin/pack-objects.c:3128 builtin/pack-objects.c:3143
 #: builtin/shortlog.c:192
 msgid "revision walk setup failed"
 msgstr "cài đặt việc di chuyển qua các điểm xét duyệt gặp lỗi"
 
-#: blame.c:1814
+#: blame.c:2762
 msgid ""
 "--reverse --first-parent together require range along first-parent chain"
 msgstr ""
-"--reverse --first-parent cùng nhau yêu cầu vùng cùng với chuỗi cha-mẹ-đầu-"
+"cùng sử dụng --reverse --first-parent yêu cầu vùng cùng với chuỗi cha-mẹ-đầu-"
 "tiên"
 
-#: blame.c:1825
+#: blame.c:2773
 #, c-format
 msgid "no such path %s in %s"
 msgstr "không có đường dẫn %s trong “%s”"
 
-#: blame.c:1836
+#: blame.c:2784
 #, c-format
 msgid "cannot read blob %s for path %s"
 msgstr "không thể đọc blob %s cho đường dẫn “%s”"
 
-#: branch.c:54
+#: branch.c:53
 #, c-format
 msgid ""
 "\n"
@@ -1037,90 +1554,90 @@ msgstr ""
 "thông tin theo dõi máy chủ bằng cách gọi lệnh\n"
 "\"git branch --set-upstream-to=%s%s%s\"."
 
-#: branch.c:68
+#: branch.c:67
 #, c-format
 msgid "Not setting branch %s as its own upstream."
 msgstr "Chưa cài đặt nhánh %s như là thượng nguồn của nó."
 
-#: branch.c:94
+#: branch.c:93
 #, c-format
 msgid "Branch '%s' set up to track remote branch '%s' from '%s' by rebasing."
 msgstr ""
 "Nhánh “%s” cài đặt để theo dõi nhánh máy chủ “%s” từ “%s” bằng cách rebase."
 
-#: branch.c:95
+#: branch.c:94
 #, c-format
 msgid "Branch '%s' set up to track remote branch '%s' from '%s'."
 msgstr "Nhánh “%s” cài đặt để theo dõi nhánh máy chủ “%s” từ “%s”."
 
-#: branch.c:99
+#: branch.c:98
 #, c-format
 msgid "Branch '%s' set up to track local branch '%s' by rebasing."
 msgstr "Nhánh “%s” cài đặt để theo dõi nhánh nội bộ “%s” bằng cách rebase."
 
-#: branch.c:100
+#: branch.c:99
 #, c-format
 msgid "Branch '%s' set up to track local branch '%s'."
 msgstr "Nhánh “%s” cài đặt để theo dõi nhánh nội bộ “%s”."
 
-#: branch.c:105
+#: branch.c:104
 #, c-format
 msgid "Branch '%s' set up to track remote ref '%s' by rebasing."
 msgstr ""
 "Nhánh “%s” cài đặt để theo dõi tham chiếu máy chủ “%s” bằng cách rebase."
 
-#: branch.c:106
+#: branch.c:105
 #, c-format
 msgid "Branch '%s' set up to track remote ref '%s'."
 msgstr "Nhánh “%s” cài đặt để theo dõi tham chiếu máy chủ “%s”."
 
-#: branch.c:110
+#: branch.c:109
 #, c-format
 msgid "Branch '%s' set up to track local ref '%s' by rebasing."
 msgstr ""
 "Nhánh “%s” cài đặt để theo dõi tham chiếu nội bộ “%s” bằng cách rebase."
 
-#: branch.c:111
+#: branch.c:110
 #, c-format
 msgid "Branch '%s' set up to track local ref '%s'."
 msgstr "Nhánh “%s” cài đặt để theo dõi tham chiếu nội bộ “%s”."
 
-#: branch.c:120
+#: branch.c:119
 msgid "Unable to write upstream branch configuration"
 msgstr "Không thể ghi cấu hình nhánh thượng nguồn"
 
-#: branch.c:157
+#: branch.c:156
 #, c-format
 msgid "Not tracking: ambiguous information for ref %s"
 msgstr "Không theo dõi: thông tin chưa rõ ràng cho tham chiếu %s"
 
-#: branch.c:190
+#: branch.c:189
 #, c-format
 msgid "'%s' is not a valid branch name."
 msgstr "“%s” không phải là một tên nhánh hợp lệ."
 
-#: branch.c:209
+#: branch.c:208
 #, c-format
 msgid "A branch named '%s' already exists."
 msgstr "Đã có nhánh mang tên “%s”."
 
-#: branch.c:214
+#: branch.c:213
 msgid "Cannot force update the current branch."
 msgstr "Không thể ép buộc cập nhật nhánh hiện hành."
 
-#: branch.c:234
+#: branch.c:233
 #, c-format
 msgid "Cannot setup tracking information; starting point '%s' is not a branch."
 msgstr ""
 "Không thể cài đặt thông tin theo dõi; điểm bắt đầu “%s” không phải là một "
 "nhánh."
 
-#: branch.c:236
+#: branch.c:235
 #, c-format
 msgid "the requested upstream branch '%s' does not exist"
 msgstr "nhánh thượng nguồn đã yêu cầu “%s” không tồn tại"
 
-#: branch.c:238
+#: branch.c:237
 msgid ""
 "\n"
 "If you are planning on basing your work on an upstream\n"
@@ -1155,83 +1672,92 @@ msgstr "Tên đối tượng chưa rõ r
 msgid "Not a valid branch point: '%s'."
 msgstr "Nhánh không hợp lệ: “%s”."
 
-#: branch.c:360
+#: branch.c:364
 #, c-format
 msgid "'%s' is already checked out at '%s'"
 msgstr "“%s” đã được lấy ra tại “%s” rồi"
 
-#: branch.c:383
+#: branch.c:387
 #, c-format
 msgid "HEAD of working tree %s is not updated"
 msgstr "HEAD của cây làm việc %s chưa được cập nhật"
 
-#: bundle.c:34
+#: bundle.c:36
 #, c-format
 msgid "'%s' does not look like a v2 bundle file"
 msgstr "“%s” không giống như tập tin v2 bundle (định dạng dump của git)"
 
-#: bundle.c:62
+#: bundle.c:64
 #, c-format
 msgid "unrecognized header: %s%s (%d)"
 msgstr "phần đầu không được thừa nhận: %s%s (%d)"
 
-#: bundle.c:88 sequencer.c:2081 sequencer.c:2558 builtin/commit.c:755
+#: bundle.c:90 rerere.c:480 rerere.c:690 sequencer.c:2344 sequencer.c:3108
+#: builtin/commit.c:811
 #, c-format
 msgid "could not open '%s'"
 msgstr "không thể mở “%s”"
 
-#: bundle.c:139
+#: bundle.c:143
 msgid "Repository lacks these prerequisite commits:"
 msgstr "Kho chứa thiếu những lần chuyển giao tiên quyết này:"
 
-#: bundle.c:190
+#: bundle.c:146
+msgid "need a repository to verify a bundle"
+msgstr "cần một kho chứa để thẩm tra một bundle"
+
+#: bundle.c:197
 #, c-format
 msgid "The bundle contains this ref:"
 msgid_plural "The bundle contains these %d refs:"
 msgstr[0] "Bó dữ liệu chứa %d tham chiếu:"
 
-#: bundle.c:197
+#: bundle.c:204
 msgid "The bundle records a complete history."
 msgstr "Lệnh bundle ghi lại toàn bộ lịch sử."
 
-#: bundle.c:199
+#: bundle.c:206
 #, c-format
 msgid "The bundle requires this ref:"
 msgid_plural "The bundle requires these %d refs:"
 msgstr[0] "Lệnh bundle yêu cầu %d tham chiếu này:"
 
-#: bundle.c:258
+#: bundle.c:273
+msgid "unable to dup bundle descriptor"
+msgstr "không thể nhân đôi bộ mô tả bundle"
+
+#: bundle.c:280
 msgid "Could not spawn pack-objects"
 msgstr "Không thể sản sinh đối tượng gói"
 
-#: bundle.c:269
+#: bundle.c:291
 msgid "pack-objects died"
 msgstr "đối tượng gói đã chết"
 
-#: bundle.c:311
+#: bundle.c:333
 msgid "rev-list died"
 msgstr "rev-list đã chết"
 
-#: bundle.c:360
+#: bundle.c:382
 #, c-format
 msgid "ref '%s' is excluded by the rev-list options"
 msgstr "th.chiếu “%s” bị loại trừ bởi các tùy chọn rev-list"
 
-#: bundle.c:450 builtin/log.c:183 builtin/log.c:1607 builtin/shortlog.c:303
+#: bundle.c:461 builtin/log.c:203 builtin/log.c:1814 builtin/shortlog.c:306
 #, c-format
 msgid "unrecognized argument: %s"
 msgstr "đối số không được thừa nhận: %s"
 
-#: bundle.c:458
+#: bundle.c:469
 msgid "Refusing to create empty bundle."
 msgstr "Từ chối tạo một bó dữ liệu trống rỗng."
 
-#: bundle.c:470
+#: bundle.c:479
 #, c-format
 msgid "cannot create '%s'"
 msgstr "không thể tạo “%s”"
 
-#: bundle.c:498
+#: bundle.c:504
 msgid "index-pack died"
 msgstr "mục lục gói đã chết"
 
@@ -1240,19 +1766,18 @@ msgstr "mục lục gói đã chết"
 msgid "invalid color value: %.*s"
 msgstr "giá trị màu không hợp lệ: %.*s"
 
-#: commit.c:43 sequencer.c:2364 builtin/am.c:421 builtin/am.c:465
-#: builtin/am.c:1436 builtin/am.c:2072 builtin/replace.c:376
-#: builtin/replace.c:448
+#: commit.c:51 sequencer.c:2811 builtin/am.c:354 builtin/am.c:398
+#: builtin/am.c:1366 builtin/am.c:2009 builtin/replace.c:456
 #, c-format
 msgid "could not parse %s"
 msgstr "không thể phân tích cú pháp %s"
 
-#: commit.c:45
+#: commit.c:53
 #, c-format
 msgid "%s %s is not a commit!"
 msgstr "%s %s không phải là một lần chuyển giao!"
 
-#: commit.c:182
+#: commit.c:193
 msgid ""
 "Support for <GIT_DIR>/info/grafts is deprecated\n"
 "and will be removed in a future Git version.\n"
@@ -1272,7 +1797,28 @@ msgstr ""
 "Tắt lời nhắn này bằng cách chạy\n"
 "\"git config advice.graftFileDeprecated false\""
 
-#: commit.c:1540
+#: commit.c:1152
+#, c-format
+msgid "Commit %s has an untrusted GPG signature, allegedly by %s."
+msgstr ""
+"Lần chuyển giao %s có một chữ ký GPG không đáng tin, được cho là bởi %s."
+
+#: commit.c:1155
+#, c-format
+msgid "Commit %s has a bad GPG signature allegedly by %s."
+msgstr "Lần chuyển giao %s có một chữ ký GPG sai, được cho là bởi %s."
+
+#: commit.c:1158
+#, c-format
+msgid "Commit %s does not have a GPG signature."
+msgstr "Lần chuyển giao %s không có chữ ký GPG."
+
+#: commit.c:1161
+#, c-format
+msgid "Commit %s has a good GPG signature by %s\n"
+msgstr "Lần chuyển giao %s có một chữ ký GPG tốt bởi %s\n"
+
+#: commit.c:1415
 msgid ""
 "Warning: commit message did not conform to UTF-8.\n"
 "You may want to amend it after fixing the message, or set the config\n"
@@ -1282,185 +1828,594 @@ msgstr ""
 "Bạn có lẽ muốn tu bổ nó sau khi sửa lời chú thích, hoặc là đặt biến\n"
 "cấu hình i18n.commitencoding thành bảng mã mà dự án của bạn muốn dùng.\n"
 
-#: commit-graph.c:669
+#: commit-graph.c:130
+msgid "commit-graph file is too small"
+msgstr "tập tin đồ-thị-các-lần-chuyển-giao quá nhỏ"
+
+#: commit-graph.c:195
+#, c-format
+msgid "commit-graph signature %X does not match signature %X"
+msgstr "chữ ký đồ-thị-các-lần-chuyển-giao %X không khớp chữ ký %X"
+
+#: commit-graph.c:202
+#, c-format
+msgid "commit-graph version %X does not match version %X"
+msgstr "phiên bản đồ-thị-các-lần-chuyển-giao %X không khớp phiên bản %X"
+
+#: commit-graph.c:209
+#, c-format
+msgid "commit-graph hash version %X does not match version %X"
+msgstr "phiên bản đồ-thị-các-lần-chuyển-giao %X không khớp phiên bản %X"
+
+#: commit-graph.c:232
+msgid "commit-graph chunk lookup table entry missing; file may be incomplete"
+msgstr ""
+"bảng tìm kiếm mảnh đồ-thị-các-lần-chuyển-giao còn thiếu; tập tin có thể sẽ "
+"không hoàn thiện"
+
+#: commit-graph.c:243
+#, c-format
+msgid "commit-graph improper chunk offset %08x%08x"
+msgstr "bù mảnh đồ-thị-các-lần-chuyển-giao không đúng chỗ %08x%08x"
+
+#: commit-graph.c:286
+#, c-format
+msgid "commit-graph chunk id %08x appears multiple times"
+msgstr "mã mảnh đồ-thị-các-lần-chuyển-giao %08x xuất hiện nhiều lần"
+
+#: commit-graph.c:350
+msgid "commit-graph has no base graphs chunk"
+msgstr "đồ-thị-các-lần-chuyển-giao có không có mảnh các đồ họa cơ sở"
+
+#: commit-graph.c:360
+msgid "commit-graph chain does not match"
+msgstr "móc xích đồ-thị-các-lần-chuyển-giao không khớp"
+
+#: commit-graph.c:407
+#, c-format
+msgid "invalid commit-graph chain: line '%s' not a hash"
+msgstr ""
+"móc xích đồ-thị-các-lần-chuyển-giao không hợp lệ: dòng '%s' không phải là "
+"một mã băm"
+
+#: commit-graph.c:433
+msgid "unable to find all commit-graph files"
+msgstr "không thể tìm thấy tất cả các tập tin đồ-thị-các-lần-chuyển-giao"
+
+#: commit-graph.c:564 commit-graph.c:624
+msgid "invalid commit position. commit-graph is likely corrupt"
+msgstr ""
+"vị trí lần chuyển giao không hợp lệ. đồ-thị-các-lần-chuyển-giao có vẻ như đã "
+"bị hỏng"
+
+#: commit-graph.c:585
+#, c-format
+msgid "could not find commit %s"
+msgstr "không thể tìm thấy lần chuyển giao %s"
+
+#: commit-graph.c:858 builtin/am.c:1287
+#, c-format
+msgid "unable to parse commit %s"
+msgstr "không thể phân tích lần chuyển giao “%s”"
+
+#: commit-graph.c:1017 builtin/pack-objects.c:2641
+#, c-format
+msgid "unable to get type of object %s"
+msgstr "không thể lấy kiểu của đối tượng “%s”"
+
+#: commit-graph.c:1049
+msgid "Loading known commits in commit graph"
+msgstr "Đang tải các lần chuyển giao chưa biết trong đồ thị lần chuyển giao"
+
+#: commit-graph.c:1066
+msgid "Expanding reachable commits in commit graph"
+msgstr ""
+"Mở rộng các lần chuyển giao có thể tiếp cận được trong trong đồ thị lần "
+"chuyển giao"
+
+#: commit-graph.c:1085
+msgid "Clearing commit marks in commit graph"
+msgstr "Đang dọn dẹp các đánh dấu lần chuyển giao trong đồ thị lần chuyển giao"
+
+#: commit-graph.c:1104
+msgid "Computing commit graph generation numbers"
+msgstr "Đang tính toán số tạo đồ thị các lần chuyển giao"
+
+#: commit-graph.c:1179
+#, c-format
+msgid "Finding commits for commit graph in %d pack"
+msgid_plural "Finding commits for commit graph in %d packs"
+msgstr[0] ""
+"Đang tìm các lần chuyển giao cho đồ thị lần chuyển giao trong %d gói"
+
+#: commit-graph.c:1192
+#, c-format
+msgid "error adding pack %s"
+msgstr "gặp lỗi thêm gói %s"
+
+#: commit-graph.c:1196
+#, c-format
+msgid "error opening index for %s"
+msgstr "gặp lỗi khi mở mục lục cho “%s”"
+
+#: commit-graph.c:1220
+#, c-format
+msgid "Finding commits for commit graph from %d ref"
+msgid_plural "Finding commits for commit graph from %d refs"
+msgstr[0] ""
+"Đang tìm các lần chuyển giao cho đồ thị lần chuyển giao từ %d tham chiếu"
+
+#: commit-graph.c:1240
+#, c-format
+msgid "invalid commit object id: %s"
+msgstr "mã số đối tượng lần chuyển giao không hợp lệ: %s"
+
+#: commit-graph.c:1255
+msgid "Finding commits for commit graph among packed objects"
+msgstr ""
+"Đang tìm các lần chuyển giao cho đồ thị lần chuyển giao trong số các đối "
+"tượng đã đóng gói"
+
+#: commit-graph.c:1270
+msgid "Counting distinct commits in commit graph"
+msgstr "Đang đếm các lần chuyển giao khác nhau trong đồ thị lần chuyển giao"
+
+#: commit-graph.c:1300
+msgid "Finding extra edges in commit graph"
+msgstr "Đang tìm các cạnh mở tộng trong đồ thị lần chuyển giao"
+
+#: commit-graph.c:1346
+msgid "failed to write correct number of base graph ids"
+msgstr "gặp lỗi khi ghi số đúng của mã đồ họa cơ sở"
+
+#: commit-graph.c:1379 midx.c:814
+#, c-format
+msgid "unable to create leading directories of %s"
+msgstr "không thể tạo các thư mục dẫn đầu của “%s”"
+
+#: commit-graph.c:1391 builtin/index-pack.c:306 builtin/repack.c:248
+#, c-format
+msgid "unable to create '%s'"
+msgstr "không thể tạo “%s”"
+
+#: commit-graph.c:1451
+#, c-format
+msgid "Writing out commit graph in %d pass"
+msgid_plural "Writing out commit graph in %d passes"
+msgstr[0] "Đang ghi ra đồ thị các lần chuyển giao trong lần %d"
+
+#: commit-graph.c:1492
+msgid "unable to open commit-graph chain file"
+msgstr "không thể mở tập tin mắt xích đồ thị chuyển giao"
+
+#: commit-graph.c:1504
+msgid "failed to rename base commit-graph file"
+msgstr "gặp lỗi khi đổi tên tập tin đồ-thị-các-lần-chuyển-giao"
+
+#: commit-graph.c:1524
+msgid "failed to rename temporary commit-graph file"
+msgstr "gặp lỗi khi đổi tên tập tin đồ-thị-các-lần-chuyển-giao tạm thời"
+
+#: commit-graph.c:1635
+msgid "Scanning merged commits"
+msgstr "Đang quét các lần chuyển giao đã hòa trộn"
+
+#: commit-graph.c:1646
+#, c-format
+msgid "unexpected duplicate commit id %s"
+msgstr "gặp mã số tích lần chuyển giao bị trùng lặp “%s”"
+
+#: commit-graph.c:1670
+msgid "Merging commit-graph"
+msgstr "Đang hòa trộn đồ-thị-các-lần-chuyển-giao"
+
+#: commit-graph.c:1860
 #, c-format
 msgid "the commit graph format cannot write %d commits"
 msgstr "định dạng đồ họa các lần chuyển giao không thể ghi %d lần chuyển giao"
 
-#: commit-graph.c:696
+#: commit-graph.c:1871
 msgid "too many commits to write graph"
 msgstr "có quá nhiều lần chuyển giao để ghi đồ thị"
 
-#: commit-graph.c:707 builtin/init-db.c:516 builtin/init-db.c:521
+#: commit-graph.c:1961
+msgid "the commit-graph file has incorrect checksum and is likely corrupt"
+msgstr ""
+"tập tin đồ-thị-các-lần-chuyển-giao có tổng kiểm không đúng và có vẻ như là "
+"đã hỏng"
+
+#: commit-graph.c:1971
 #, c-format
-msgid "cannot mkdir %s"
-msgstr "không thể mkdir (tạo thư mục): %s"
+msgid "commit-graph has incorrect OID order: %s then %s"
+msgstr "đồ-thị-các-lần-chuyển-giao có thứ tự OID không đúng: %s sau %s"
+
+#: commit-graph.c:1981 commit-graph.c:1996
+#, c-format
+msgid "commit-graph has incorrect fanout value: fanout[%d] = %u != %u"
+msgstr ""
+"đồ-thị-các-lần-chuyển-giao có giá trị fanout không đúng: fanout[%d] = %u != "
+"%u"
+
+#: commit-graph.c:1988
+#, c-format
+msgid "failed to parse commit %s from commit-graph"
+msgstr "gặp lỗi khi phân tích lần chuyển giao từ %s đồ-thị-các-lần-chuyển-giao"
+
+#: commit-graph.c:2006
+msgid "Verifying commits in commit graph"
+msgstr "Đang thẩm tra các lần chuyển giao trong đồ thị lần chuyển giao"
+
+#: commit-graph.c:2020
+#, c-format
+msgid "failed to parse commit %s from object database for commit-graph"
+msgstr ""
+"gặp lỗi khi phân tích lần chuyển giao %s từ cơ sở dữ liệu đối tượng cho đồ "
+"thị lần chuyển giao"
+
+#: commit-graph.c:2027
+#, c-format
+msgid "root tree OID for commit %s in commit-graph is %s != %s"
+msgstr ""
+"OID cây gốc cho lần chuyển giao %s trong đồ-thị-các-lần-chuyển-giao là %s != "
+"%s"
+
+#: commit-graph.c:2037
+#, c-format
+msgid "commit-graph parent list for commit %s is too long"
+msgstr ""
+"danh sách cha mẹ đồ-thị-các-lần-chuyển-giao cho lần chuyển giao %s là quá dài"
+
+#: commit-graph.c:2046
+#, c-format
+msgid "commit-graph parent for %s is %s != %s"
+msgstr "cha mẹ đồ-thị-các-lần-chuyển-giao cho %s là %s != %s"
+
+#: commit-graph.c:2059
+#, c-format
+msgid "commit-graph parent list for commit %s terminates early"
+msgstr ""
+"danh sách cha mẹ đồ-thị-các-lần-chuyển-giao cho lần chuyển giao %s bị chấm "
+"dứt quá sớm"
+
+#: commit-graph.c:2064
+#, c-format
+msgid ""
+"commit-graph has generation number zero for commit %s, but non-zero elsewhere"
+msgstr ""
+"đồ-thị-các-lần-chuyển-giao có con số không lần tạo cho lần chuyển giao %s, "
+"nhưng không phải số không ở chỗ khác"
+
+#: commit-graph.c:2068
+#, c-format
+msgid ""
+"commit-graph has non-zero generation number for commit %s, but zero elsewhere"
+msgstr ""
+"đồ-thị-các-lần-chuyển-giao có con số không phải không lần tạo cho lần chuyển "
+"giao %s, nhưng số không ở chỗ khác"
+
+#: commit-graph.c:2083
+#, c-format
+msgid "commit-graph generation for commit %s is %u != %u"
+msgstr "tạo đồ-thị-các-lần-chuyển-giao cho lần chuyển giao %s là %u != %u"
 
-#: compat/obstack.c:405 compat/obstack.c:407
+#: commit-graph.c:2089
+#, c-format
+msgid "commit date for commit %s in commit-graph is %<PRIuMAX> != %<PRIuMAX>"
+msgstr ""
+"ngày chuyển giao cho lần chuyển giao %s trong đồ-thị-các-lần-chuyển-giao là "
+"%<PRIuMAX> != %<PRIuMAX>"
+
+#: compat/obstack.c:406 compat/obstack.c:408
 msgid "memory exhausted"
 msgstr "hết bộ nhớ"
 
-#: config.c:187
+#: config.c:124
+#, c-format
+msgid ""
+"exceeded maximum include depth (%d) while including\n"
+"\t%s\n"
+"from\n"
+"\t%s\n"
+"This might be due to circular includes."
+msgstr ""
+"vượt quá độ sâu bao gồm tối đa (%d) trong khi bao gồm\n"
+"\t%s\n"
+"từ\n"
+"\t%s\n"
+"Nguyên nhân có thể là gồm quẩn vòng."
+
+#: config.c:140
+#, c-format
+msgid "could not expand include path '%s'"
+msgstr "không thể khai triển đường dẫn “%s”"
+
+#: config.c:151
+msgid "relative config includes must come from files"
+msgstr "các bao gồm cấu hình liên quan phải đến từ các tập tin"
+
+#: config.c:197
 msgid "relative config include conditionals must come from files"
 msgstr "các điều kiện bao gồm cấu hình liên quan phải đến từ các tập tin"
 
-#: config.c:788
+#: config.c:376
+#, c-format
+msgid "key does not contain a section: %s"
+msgstr "khóa không chứa một phần: %s"
+
+#: config.c:382
+#, c-format
+msgid "key does not contain variable name: %s"
+msgstr "khóa không chứa bất kỳ một tên biến nào: %s"
+
+#: config.c:406 sequencer.c:2530
+#, c-format
+msgid "invalid key: %s"
+msgstr "khóa không đúng: %s"
+
+#: config.c:412
+#, c-format
+msgid "invalid key (newline): %s"
+msgstr "khóa không hợp lệ (dòng mới): %s"
+
+#: config.c:448 config.c:460
+#, c-format
+msgid "bogus config parameter: %s"
+msgstr "tham số cấu hình không có thực: %s"
+
+#: config.c:495
+#, c-format
+msgid "bogus format in %s"
+msgstr "định dạng không có thực trong %s"
+
+#: config.c:821
 #, c-format
 msgid "bad config line %d in blob %s"
 msgstr "tập tin cấu hình sai tại dòng %d trong blob %s"
 
-#: config.c:792
+#: config.c:825
 #, c-format
 msgid "bad config line %d in file %s"
 msgstr "cấu hình sai tại dòng %d trong tập tin %s"
 
-#: config.c:796
+#: config.c:829
 #, c-format
 msgid "bad config line %d in standard input"
 msgstr "cấu hình sai tại dòng %d trong đầu vào tiêu chuẩn"
 
-#: config.c:800
+#: config.c:833
 #, c-format
 msgid "bad config line %d in submodule-blob %s"
 msgstr "cấu hình sai tại dòng %d trong blob-mô-đun-con %s"
 
-#: config.c:804
+#: config.c:837
 #, c-format
 msgid "bad config line %d in command line %s"
 msgstr "cấu hình sai tại dòng %d trong dòng lệnh %s"
 
-#: config.c:808
+#: config.c:841
 #, c-format
 msgid "bad config line %d in %s"
 msgstr "cấu hình sai tại dòng %d trong %s"
 
-#: config.c:936
+#: config.c:978
 msgid "out of range"
 msgstr "nằm ngoài phạm vi"
 
-#: config.c:936
+#: config.c:978
 msgid "invalid unit"
 msgstr "đơn vị không hợp lệ"
 
-#: config.c:942
+#: config.c:979
 #, c-format
 msgid "bad numeric config value '%s' for '%s': %s"
 msgstr "sai giá trị bằng số của cấu hình “%s” cho “%s”: %s"
 
-#: config.c:947
+#: config.c:998
 #, c-format
 msgid "bad numeric config value '%s' for '%s' in blob %s: %s"
 msgstr "sai giá trị bằng số của cấu hình “%s” cho “%s” trong blob %s: %s"
 
-#: config.c:950
+#: config.c:1001
 #, c-format
 msgid "bad numeric config value '%s' for '%s' in file %s: %s"
 msgstr "sai giá trị bằng số của cấu hình “%s” cho “%s” trong tập tin %s: %s"
 
-#: config.c:953
+#: config.c:1004
 #, c-format
 msgid "bad numeric config value '%s' for '%s' in standard input: %s"
 msgstr ""
 "sai giá trị bằng số của cấu hình “%s” cho “%s” trong đầu vào tiêu chuẩn: %s"
 
-#: config.c:956
+#: config.c:1007
 #, c-format
 msgid "bad numeric config value '%s' for '%s' in submodule-blob %s: %s"
 msgstr ""
 "sai giá trị bằng số của cấu hình “%s” cho “%s” trong submodule-blob %s: %s"
 
-#: config.c:959
+#: config.c:1010
 #, c-format
 msgid "bad numeric config value '%s' for '%s' in command line %s: %s"
 msgstr "sai giá trị bằng số của cấu hình “%s” cho “%s” trong dòng lệnh %s: %s"
 
-#: config.c:962
+#: config.c:1013
 #, c-format
 msgid "bad numeric config value '%s' for '%s' in %s: %s"
 msgstr "sai giá trị bằng số của cấu hình “%s” cho “%s” trong %s: %s"
 
-#: config.c:1057
+#: config.c:1108
 #, c-format
 msgid "failed to expand user dir in: '%s'"
 msgstr "gặp lỗi mở rộng thư mục người dùng trong: “%s”"
 
-#: config.c:1066
+#: config.c:1117
 #, c-format
 msgid "'%s' for '%s' is not a valid timestamp"
 msgstr "“%s” dành cho “%s” không phải là dấu vết thời gian hợp lệ"
 
-#: config.c:1171 config.c:1182
+#: config.c:1208
+#, c-format
+msgid "abbrev length out of range: %d"
+msgstr "chiều dài abbrev nằm ngoài phạm vi: %d"
+
+#: config.c:1222 config.c:1233
 #, c-format
 msgid "bad zlib compression level %d"
 msgstr "mức nén zlib %d là sai"
 
-#: config.c:1307
+#: config.c:1325
+msgid "core.commentChar should only be one character"
+msgstr "core.commentChar chỉ được có một ký tự"
+
+#: config.c:1358
 #, c-format
 msgid "invalid mode for object creation: %s"
 msgstr "chế độ không hợp lệ đối với việc tạo đối tượng: %s"
 
-#: config.c:1473
+#: config.c:1430
+#, c-format
+msgid "malformed value for %s"
+msgstr "giá trị cho %s sai dạng"
+
+#: config.c:1456
+#, c-format
+msgid "malformed value for %s: %s"
+msgstr "giá trị cho %s sai dạng: %s"
+
+#: config.c:1457
+msgid "must be one of nothing, matching, simple, upstream or current"
+msgstr "phải là một trong số nothing, matching, simple, upstream hay current"
+
+#: config.c:1518 builtin/pack-objects.c:3394
 #, c-format
 msgid "bad pack compression level %d"
 msgstr "mức nén gói %d không hợp lệ"
 
-#: config.c:1681
+#: config.c:1639
+#, c-format
+msgid "unable to load config blob object '%s'"
+msgstr "không thể tải đối tượng blob cấu hình “%s”"
+
+#: config.c:1642
+#, c-format
+msgid "reference '%s' does not point to a blob"
+msgstr "tham chiếu “%s” không chỉ đến một blob nào cả"
+
+#: config.c:1659
+#, c-format
+msgid "unable to resolve config blob '%s'"
+msgstr "không thể phân giải điểm xét duyệt “%s”"
+
+#: config.c:1689
+#, c-format
+msgid "failed to parse %s"
+msgstr "gặp lỗi khi phân tích cú pháp %s"
+
+#: config.c:1745
 msgid "unable to parse command-line config"
 msgstr "không thể phân tích cấu hình dòng lệnh"
 
-#: config.c:2013
+#: config.c:2096
 msgid "unknown error occurred while reading the configuration files"
 msgstr "đã có lỗi chưa biết xảy ra trong khi đọc các tập tin cấu hình"
 
-#: config.c:2200
+#: config.c:2266
 #, c-format
 msgid "Invalid %s: '%s'"
 msgstr "%s không hợp lệ: “%s”"
 
-#: config.c:2243
-#, c-format
-msgid "unknown core.untrackedCache value '%s'; using 'keep' default value"
-msgstr ""
-"không hiểu giá trị core.untrackedCache “%s”; dùng giá trị mặc định “keep”"
-
-#: config.c:2269
+#: config.c:2311
 #, c-format
 msgid "splitIndex.maxPercentChange value '%d' should be between 0 and 100"
 msgstr "giá trị splitIndex.maxPercentChange “%d” phải nằm giữa 0 và 100"
 
-#: config.c:2294
+#: config.c:2357
 #, c-format
 msgid "unable to parse '%s' from command-line config"
 msgstr "không thể phân tích “%s” từ cấu hình dòng lệnh"
 
-#: config.c:2296
+#: config.c:2359
 #, c-format
 msgid "bad config variable '%s' in file '%s' at line %d"
 msgstr "sai biến cấu hình “%s” trong tập tin “%s” tại dòng %d"
 
-#: config.c:2402
+#: config.c:2440
+#, c-format
+msgid "invalid section name '%s'"
+msgstr "tên của phần không hợp lệ “%s”"
+
+#: config.c:2472
 #, c-format
 msgid "%s has multiple values"
 msgstr "%s có đa giá trị"
 
-#: config.c:2766 config.c:3019
+#: config.c:2501
+#, c-format
+msgid "failed to write new configuration file %s"
+msgstr "gặp lỗi khi ghi tập tin cấu hình “%s”"
+
+#: config.c:2753 config.c:3077
+#, c-format
+msgid "could not lock config file %s"
+msgstr "không thể khóa tập tin cấu hình %s"
+
+#: config.c:2764
+#, c-format
+msgid "opening %s"
+msgstr "đang mở “%s”"
+
+#: config.c:2799 builtin/config.c:328
+#, c-format
+msgid "invalid pattern: %s"
+msgstr "mẫu không hợp lệ: %s"
+
+#: config.c:2824
+#, c-format
+msgid "invalid config file %s"
+msgstr "tập tin cấu hình “%s” không hợp lệ"
+
+#: config.c:2837 config.c:3090
 #, c-format
 msgid "fstat on %s failed"
 msgstr "fstat trên %s gặp lỗi"
 
-#: config.c:2905
+#: config.c:2848
+#, c-format
+msgid "unable to mmap '%s'"
+msgstr "không thể mmap “%s”"
+
+#: config.c:2857 config.c:3095
+#, c-format
+msgid "chmod on %s failed"
+msgstr "chmod trên %s gặp lỗi"
+
+#: config.c:2942 config.c:3192
+#, c-format
+msgid "could not write config file %s"
+msgstr "không thể ghi tập tin cấu hình “%s”"
+
+#: config.c:2976
 #, c-format
 msgid "could not set '%s' to '%s'"
 msgstr "không thể đặt “%s” thành “%s”"
 
-#: config.c:2907 builtin/remote.c:779
+#: config.c:2978 builtin/remote.c:781
 #, c-format
 msgid "could not unset '%s'"
 msgstr "không thể thôi đặt “%s”"
 
+#: config.c:3068
+#, c-format
+msgid "invalid section name: %s"
+msgstr "tên của phần không hợp lệ: %s"
+
+#: config.c:3235
+#, c-format
+msgid "missing value for '%s'"
+msgstr "thiếu giá trị cho cho “%s”"
+
 #: connect.c:61
-msgid "The remote end hung up upon initial contact"
-msgstr "Máy chủ bị treo trên lần tiếp xúc đầu tiên"
+msgid "the remote end hung up upon initial contact"
+msgstr "máy chủ bị treo trên lần tiếp xúc đầu tiên"
 
 #: connect.c:63
 msgid ""
@@ -1474,63 +2429,211 @@ msgstr ""
 "Vui lòng chắc chắn là bạn có đủ thẩm quyền truy cập\n"
 "và kho chứa đã sẵn có."
 
-#: connected.c:66 builtin/fsck.c:201 builtin/prune.c:145
-msgid "Checking connectivity"
-msgstr "Đang kiểm tra kết nối"
+#: connect.c:81
+#, c-format
+msgid "server doesn't support '%s'"
+msgstr "máy chủ không hỗ trợ “%s”"
 
-#: connected.c:78
-msgid "Could not run 'git rev-list'"
-msgstr "Không thể chạy “git rev-list”"
+#: connect.c:103
+#, c-format
+msgid "server doesn't support feature '%s'"
+msgstr "máy chủ không hỗ trợ tính năng “%s”"
 
-#: connected.c:98
-msgid "failed write to rev-list"
-msgstr "gặp lỗi khi ghi vào rev-list"
+#: connect.c:114
+msgid "expected flush after capabilities"
+msgstr "cần đẩy dữ liệu lên đĩa sau các capabilities"
 
-#: connected.c:105
-msgid "failed to close rev-list's stdin"
-msgstr "gặp lỗi khi đóng đầu vào chuẩn stdin của rev-list"
+#: connect.c:233
+#, c-format
+msgid "ignoring capabilities after first line '%s'"
+msgstr "bỏ qua capabilities sau dòng đầu tiên “%s”"
 
-#: convert.c:206
+#: connect.c:252
+msgid "protocol error: unexpected capabilities^{}"
+msgstr "lỗi giao thức: không cần capabilities^{}"
+
+#: connect.c:273
 #, c-format
-msgid "CRLF would be replaced by LF in %s."
-msgstr "CRLF nên được thay bằng LF trong %s."
+msgid "protocol error: expected shallow sha-1, got '%s'"
+msgstr "lỗi giao thức: cần sha-1 shallow, nhưng lại nhận được “%s”"
+
+#: connect.c:275
+msgid "repository on the other end cannot be shallow"
+msgstr "kho đã ở điểm cuối khoác nên không thể được shallow"
 
-#: convert.c:208
+#: connect.c:313
+msgid "invalid packet"
+msgstr "gói không hợp lệ"
+
+#: connect.c:333
 #, c-format
-msgid ""
-"CRLF will be replaced by LF in %s.\n"
-"The file will have its original line endings in your working directory."
-msgstr ""
-"CRLF sẽ bị thay thế bằng LF trong %s.\n"
-"Tập tin sẽ có kiểu xuống dòng như bản gốc trong thư mục làm việc của bạn."
+msgid "protocol error: unexpected '%s'"
+msgstr "lỗi giao thức: không cần “%s”"
 
-#: convert.c:216
+#: connect.c:441
 #, c-format
-msgid "LF would be replaced by CRLF in %s"
+msgid "invalid ls-refs response: %s"
+msgstr "trả về của ls-refs không hợp lệ: %s"
+
+#: connect.c:445
+msgid "expected flush after ref listing"
+msgstr "cần đẩy dữ liệu lên đĩa sau khi liệt kê tham chiếu"
+
+#: connect.c:544
+#, c-format
+msgid "protocol '%s' is not supported"
+msgstr "giao thức “%s” chưa được hỗ trợ"
+
+#: connect.c:595
+msgid "unable to set SO_KEEPALIVE on socket"
+msgstr "không thể đặt SO_KEEPALIVE trên ổ cắm"
+
+#: connect.c:635 connect.c:698
+#, c-format
+msgid "Looking up %s ... "
+msgstr "Đang tìm kiếm %s … "
+
+#: connect.c:639
+#, c-format
+msgid "unable to look up %s (port %s) (%s)"
+msgstr "không tìm được %s (cổng %s) (%s)"
+
+#. TRANSLATORS: this is the end of "Looking up %s ... "
+#: connect.c:643 connect.c:714
+#, c-format
+msgid ""
+"done.\n"
+"Connecting to %s (port %s) ... "
+msgstr ""
+"xong.\n"
+"Đang kết nối đến %s (cổng %s) … "
+
+#: connect.c:665 connect.c:742
+#, c-format
+msgid ""
+"unable to connect to %s:\n"
+"%s"
+msgstr ""
+"không thể kết nối đến %s:\n"
+"%s"
+
+#. TRANSLATORS: this is the end of "Connecting to %s (port %s) ... "
+#: connect.c:671 connect.c:748
+msgid "done."
+msgstr "hoàn tất."
+
+#: connect.c:702
+#, c-format
+msgid "unable to look up %s (%s)"
+msgstr "không thể tìm thấy %s (%s)"
+
+#: connect.c:708
+#, c-format
+msgid "unknown port %s"
+msgstr "không hiểu cổng %s"
+
+#: connect.c:845 connect.c:1175
+#, c-format
+msgid "strange hostname '%s' blocked"
+msgstr "đã khóa tên máy lạ “%s”"
+
+#: connect.c:847
+#, c-format
+msgid "strange port '%s' blocked"
+msgstr "đã khóa cổng lạ “%s”"
+
+#: connect.c:857
+#, c-format
+msgid "cannot start proxy %s"
+msgstr "không thể khởi chạy ủy nhiệm “%s”"
+
+#: connect.c:928
+msgid "no path specified; see 'git help pull' for valid url syntax"
+msgstr "chưa chỉ định đường dẫn; xem'git help pull” để biết cú pháp url hợp lệ"
+
+#: connect.c:1123
+msgid "ssh variant 'simple' does not support -4"
+msgstr "ssh biến thể “simple” không hỗ trợ -4"
+
+#: connect.c:1135
+msgid "ssh variant 'simple' does not support -6"
+msgstr "ssh biến thể “simple” không hỗ trợ -6"
+
+#: connect.c:1152
+msgid "ssh variant 'simple' does not support setting port"
+msgstr "ssh biến thể “simple” không hỗ trợ đặt cổng"
+
+#: connect.c:1264
+#, c-format
+msgid "strange pathname '%s' blocked"
+msgstr "đã khóa tên đường dẫn lạ “%s”"
+
+#: connect.c:1311
+msgid "unable to fork"
+msgstr "không thể rẽ nhánh tiến trình con"
+
+#: connected.c:89 builtin/fsck.c:208 builtin/prune.c:43
+msgid "Checking connectivity"
+msgstr "Đang kiểm tra kết nối"
+
+#: connected.c:101
+msgid "Could not run 'git rev-list'"
+msgstr "Không thể chạy “git rev-list”"
+
+#: connected.c:121
+msgid "failed write to rev-list"
+msgstr "gặp lỗi khi ghi vào rev-list"
+
+#: connected.c:128
+msgid "failed to close rev-list's stdin"
+msgstr "gặp lỗi khi đóng đầu vào chuẩn stdin của rev-list"
+
+#: convert.c:194
+#, c-format
+msgid "illegal crlf_action %d"
+msgstr "crlf_action %d không hợp lệ"
+
+#: convert.c:207
+#, c-format
+msgid "CRLF would be replaced by LF in %s"
+msgstr "CRLF nên được thay bằng LF trong %s"
+
+#: convert.c:209
+#, c-format
+msgid ""
+"CRLF will be replaced by LF in %s.\n"
+"The file will have its original line endings in your working directory"
+msgstr ""
+"CRLF sẽ bị thay thế bằng LF trong %s.\n"
+"Tập tin sẽ có kiểu xuống dòng như bản gốc trong thư mục làm việc của bạn"
+
+#: convert.c:217
+#, c-format
+msgid "LF would be replaced by CRLF in %s"
 msgstr "LF nên thay bằng CRLF trong %s"
 
-#: convert.c:218
+#: convert.c:219
 #, c-format
 msgid ""
 "LF will be replaced by CRLF in %s.\n"
-"The file will have its original line endings in your working directory."
+"The file will have its original line endings in your working directory"
 msgstr ""
 "LF sẽ bị thay thế bằng CRLF trong %s.\n"
-"Tập tin sẽ có kiểu xuống dòng như bản gốc trong thư mục làm việc của bạn."
+"Tập tin sẽ có kiểu xuống dòng như bản gốc trong thư mục làm việc của bạn"
 
-#: convert.c:279
+#: convert.c:284
 #, c-format
 msgid "BOM is prohibited in '%s' if encoded as %s"
 msgstr "BOM bị cấm trong “%s” nếu được mã hóa là %s"
 
-#: convert.c:286
+#: convert.c:291
 #, c-format
 msgid ""
-"The file '%s' contains a byte order mark (BOM). Please use UTF-%s as working-"
-"tree-encoding."
+"The file '%s' contains a byte order mark (BOM). Please use UTF-%.*s as "
+"working-tree-encoding."
 msgstr ""
-"Tập tin “%s” có chứa ký hiệu thứ tự byte (BOM). Vui lòng dùng UTF-%s như là "
-"bảng mã cây làm việc."
+"Tập tin “%s” có chứa ký hiệu thứ tự byte (BOM). Vui lòng dùng UTF-%.*s như "
+"là bảng mã cây làm việc."
 
 #: convert.c:304
 #, c-format
@@ -1546,117 +2649,219 @@ msgstr ""
 "Tập tin “%s” còn thiếu ký hiệu thứ tự byte (BOM). Vui lòng dùng UTF-%sBE hay "
 "UTF-%sLE (còn phục thuộc vào thứ tự byte) như là bảng mã cây làm việc."
 
-#: convert.c:424
+#: convert.c:419 convert.c:490
 #, c-format
 msgid "failed to encode '%s' from %s to %s"
 msgstr "gặp lỗi khi mã hóa “%s”  từ “%s” sang “%s”"
 
-#: convert.c:467
+#: convert.c:462
 #, c-format
 msgid "encoding '%s' from %s to %s and back is not the same"
 msgstr "mã hóa “%s” từ %s thành %s và ngược trở lại không phải là cùng"
 
-#: convert.c:1225
+#: convert.c:668
+#, c-format
+msgid "cannot fork to run external filter '%s'"
+msgstr "không thể rẽ nhánh tiến trình để chạy bộ lọc bên ngoài “%s”"
+
+#: convert.c:688
+#, c-format
+msgid "cannot feed the input to external filter '%s'"
+msgstr "không thể cấp đầu vào cho bộ lọc bên ngoài “%s”"
+
+#: convert.c:695
+#, c-format
+msgid "external filter '%s' failed %d"
+msgstr "chạy bộ lọc bên ngoài “%s” gặp lỗi %d"
+
+#: convert.c:730 convert.c:733
+#, c-format
+msgid "read from external filter '%s' failed"
+msgstr "đọc từ bộ lọc bên ngoài “%s” gặp lỗi"
+
+#: convert.c:736 convert.c:791
+#, c-format
+msgid "external filter '%s' failed"
+msgstr "gặp lỗi khi chạy bộ lọc bên ngoài “%s”"
+
+#: convert.c:839
+msgid "unexpected filter type"
+msgstr "gặp kiểu bộ lọc thừa"
+
+#: convert.c:850
+msgid "path name too long for external filter"
+msgstr "tên đường dẫn quá dài cho bộ lọc bên ngoài"
+
+#: convert.c:924
+#, c-format
+msgid ""
+"external filter '%s' is not available anymore although not all paths have "
+"been filtered"
+msgstr ""
+"bộ lọc bên ngoài “%s” không sẵn sàng nữa mặc dù không phải tất cả các đường "
+"dẫn đã được lọc"
+
+#: convert.c:1223
 msgid "true/false are no valid working-tree-encodings"
-msgstr "true/false là không phải bảng mã cây làm việc hợp lệ "
+msgstr "true/false là không phải bảng-mã-cây-làm-việc hợp lệ"
+
+#: convert.c:1411 convert.c:1445
+#, c-format
+msgid "%s: clean filter '%s' failed"
+msgstr "%s: gặp lỗi khi xóa bộ lọc “%s”"
+
+#: convert.c:1489
+#, c-format
+msgid "%s: smudge filter %s failed"
+msgstr "%s: smudge bộ lọc %s gặp lỗi"
 
-#: date.c:116
+#: date.c:138
 msgid "in the future"
 msgstr "ở thời tương lai"
 
-#: date.c:122
+#: date.c:144
 #, c-format
 msgid "%<PRIuMAX> second ago"
 msgid_plural "%<PRIuMAX> seconds ago"
 msgstr[0] "%<PRIuMAX> giây trước"
 
-#: date.c:129
+#: date.c:151
 #, c-format
 msgid "%<PRIuMAX> minute ago"
 msgid_plural "%<PRIuMAX> minutes ago"
 msgstr[0] "%<PRIuMAX> phút trước"
 
-#: date.c:136
+#: date.c:158
 #, c-format
 msgid "%<PRIuMAX> hour ago"
 msgid_plural "%<PRIuMAX> hours ago"
 msgstr[0] "%<PRIuMAX> giờ trước"
 
-#: date.c:143
+#: date.c:165
 #, c-format
 msgid "%<PRIuMAX> day ago"
 msgid_plural "%<PRIuMAX> days ago"
 msgstr[0] "%<PRIuMAX> ngày trước"
 
-#: date.c:149
+#: date.c:171
 #, c-format
 msgid "%<PRIuMAX> week ago"
 msgid_plural "%<PRIuMAX> weeks ago"
 msgstr[0] "%<PRIuMAX> tuần trước"
 
-#: date.c:156
+#: date.c:178
 #, c-format
 msgid "%<PRIuMAX> month ago"
 msgid_plural "%<PRIuMAX> months ago"
 msgstr[0] "%<PRIuMAX> tháng trước"
 
-#: date.c:167
+#: date.c:189
 #, c-format
 msgid "%<PRIuMAX> year"
 msgid_plural "%<PRIuMAX> years"
 msgstr[0] "%<PRIuMAX> năm"
 
 #. TRANSLATORS: "%s" is "<n> years"
-#: date.c:170
+#: date.c:192
 #, c-format
 msgid "%s, %<PRIuMAX> month ago"
 msgid_plural "%s, %<PRIuMAX> months ago"
 msgstr[0] "%s, %<PRIuMAX> tháng trước"
 
-#: date.c:175 date.c:180
+#: date.c:197 date.c:202
 #, c-format
 msgid "%<PRIuMAX> year ago"
 msgid_plural "%<PRIuMAX> years ago"
 msgstr[0] "%<PRIuMAX> năm trước"
 
+#: delta-islands.c:272
+msgid "Propagating island marks"
+msgstr "Đang lan truyền các đánh dấu island"
+
+#: delta-islands.c:290
+#, c-format
+msgid "bad tree object %s"
+msgstr "đối tượng cây sai “%s”"
+
+#: delta-islands.c:334
+#, c-format
+msgid "failed to load island regex for '%s': %s"
+msgstr "gặp lỗi khi tải biểu thức chính quy island cho “%s”: %s"
+
+#: delta-islands.c:390
+#, c-format
+msgid "island regex from config has too many capture groups (max=%d)"
+msgstr ""
+"biểu thức chính quy island từ cấu hình có quá nhiều nhóm chụp (tối đa=%d)"
+
+#: delta-islands.c:467
+#, c-format
+msgid "Marked %d islands, done.\n"
+msgstr "Đã đánh dấu %d island, xong.\n"
+
 #: diffcore-order.c:24
 #, c-format
 msgid "failed to read orderfile '%s'"
 msgstr "gặp lỗi khi đọc tập-tin-thứ-tự “%s”"
 
-#: diffcore-rename.c:535
+#: diffcore-rename.c:543
 msgid "Performing inexact rename detection"
 msgstr "Đang thực hiện dò tìm đổi tên không chính xác"
 
-#: diff.c:74
-#, c-format
-msgid "option '%s' requires a value"
-msgstr "tùy chọn “%s” yêu cầu một giá trị"
+#: diff-no-index.c:238
+msgid "git diff --no-index [<options>] <path> <path>"
+msgstr "git diff --no-index [<các tùy chọn>] </đường/dẫn> </đường/dẫn>"
+
+#: diff-no-index.c:263
+msgid ""
+"Not a git repository. Use --no-index to compare two paths outside a working "
+"tree"
+msgstr ""
+"Không phải là một thư mục git. Dùng --no-index để so sánh hai đường dẫn bên "
+"ngoài một cây làm việc"
 
-#: diff.c:152
+#: diff.c:155
 #, c-format
 msgid "  Failed to parse dirstat cut-off percentage '%s'\n"
 msgstr "  Gặp lỗi khi phân tích dirstat cắt bỏ phần trăm “%s”\n"
 
-#: diff.c:157
+#: diff.c:160
 #, c-format
 msgid "  Unknown dirstat parameter '%s'\n"
 msgstr "  Không hiểu đối số dirstat “%s”\n"
 
-#: diff.c:281
+#: diff.c:296
 msgid ""
-"color moved setting must be one of 'no', 'default', 'zebra', 'dimmed_zebra', "
-"'plain'"
+"color moved setting must be one of 'no', 'default', 'blocks', 'zebra', "
+"'dimmed-zebra', 'plain'"
 msgstr ""
-"cài đặt màu đã di chuyển phải là một trong “no”, “default”, “zebra”, "
-"“dimmed_zebra”, “plain”"
+"cài đặt màu đã di chuyển phải là một trong “no”, “default”, “blocks”, "
+"“zebra”, “dimmed_zebra”, “plain”"
 
-#: diff.c:341
+#: diff.c:324
+#, c-format
+msgid ""
+"unknown color-moved-ws mode '%s', possible values are 'ignore-space-change', "
+"'ignore-space-at-eol', 'ignore-all-space', 'allow-indentation-change'"
+msgstr ""
+"không hiểu chế độ color-moved-ws “%s”, các giá trị có thể là “ignore-space-"
+"change”, “ignore-space-at-eol”, “ignore-all-space”, “allow-indentation-"
+"change”"
+
+#: diff.c:332
+msgid ""
+"color-moved-ws: allow-indentation-change cannot be combined with other "
+"whitespace modes"
+msgstr ""
+"color-moved-ws: allow-indentation-change không thể tổ hợp cùng với các chế "
+"độ khoảng trắng khác"
+
+#: diff.c:405
 #, c-format
 msgid "Unknown value for 'diff.submodule' config variable: '%s'"
 msgstr "Không hiểu giá trị cho biến cấu hình “diff.submodule”: “%s”"
 
-#: diff.c:401
+#: diff.c:465
 #, c-format
 msgid ""
 "Found errors in 'diff.dirstat' config variable:\n"
@@ -1665,24 +2870,35 @@ msgstr ""
 "Tìm thấy các lỗi trong biến cấu hình “diff.dirstat”:\n"
 "%s"
 
-#: diff.c:3823
+#: diff.c:4202
 #, c-format
 msgid "external diff died, stopping at %s"
 msgstr "phần mềm diff ở bên ngoài đã chết, dừng tại %s"
 
-#: diff.c:4153
+#: diff.c:4547
 msgid "--name-only, --name-status, --check and -s are mutually exclusive"
 msgstr "--name-only, --name-status, --check và -s loại từ lẫn nhau"
 
-#: diff.c:4156
+#: diff.c:4550
 msgid "-G, -S and --find-object are mutually exclusive"
 msgstr "Các tùy chọn -G, -S, và --find-object loại từ lẫn nhau"
 
-#: diff.c:4244
+#: diff.c:4628
 msgid "--follow requires exactly one pathspec"
 msgstr "--follow cần chính xác một đặc tả đường dẫn"
 
-#: diff.c:4410
+#: diff.c:4676
+#, c-format
+msgid "invalid --stat value: %s"
+msgstr "giá trị --stat không hợp lệ: “%s”"
+
+#: diff.c:4681 diff.c:4686 diff.c:4691 diff.c:4696 diff.c:5209
+#: parse-options.c:199 parse-options.c:203
+#, c-format
+msgid "%s expects a numerical value"
+msgstr "tùy chọn “%s” cần một giá trị bằng số"
+
+#: diff.c:4713
 #, c-format
 msgid ""
 "Failed to parse --dirstat/-X option parameter:\n"
@@ -1691,11107 +2907,15481 @@ msgstr ""
 "Gặp lỗi khi phân tích đối số tùy chọn --dirstat/-X:\n"
 "%s"
 
-#: diff.c:4424
+#: diff.c:4798
 #, c-format
-msgid "Failed to parse --submodule option parameter: '%s'"
-msgstr "Gặp lỗi khi phân tích đối số tùy chọn --submodule: “%s”"
+msgid "unknown change class '%c' in --diff-filter=%s"
+msgstr "không hiểu lớp thay đổi “%c” trong --diff-filter=%s"
 
-#: diff.c:5500
-msgid "inexact rename detection was skipped due to too many files."
-msgstr ""
-"nhận thấy đổi tên không chính xác đã bị bỏ qua bởi có quá nhiều tập tin."
+#: diff.c:4822
+#, c-format
+msgid "unknown value after ws-error-highlight=%.*s"
+msgstr "không hiểu giá trị sau ws-error-highlight=%.*s"
 
-#: diff.c:5503
-msgid "only found copies from modified paths due to too many files."
-msgstr ""
-"chỉ tìm thấy các bản sao từ đường dẫn đã sửa đổi bởi vì có quá nhiều tập tin."
+#: diff.c:4836
+#, c-format
+msgid "unable to resolve '%s'"
+msgstr "không thể phân giải “%s”"
 
-#: diff.c:5506
+#: diff.c:4886 diff.c:4892
 #, c-format
-msgid ""
-"you may want to set your %s variable to at least %d and retry the command."
-msgstr ""
-"bạn có lẽ muốn đặt biến %s của bạn thành ít nhất là %d và thử lại lệnh lần "
-"nữa."
+msgid "%s expects <n>/<m> form"
+msgstr "%s cần dạng <n>/<m>"
 
-#: dir.c:1867
+#: diff.c:4904
 #, c-format
-msgid "could not open directory '%s'"
-msgstr "không thể mở thư mục “%s”"
+msgid "%s expects a character, got '%s'"
+msgstr "%s cần một ký tự, nhưng lại nhận được “%s”"
 
-#: dir.c:2109
-msgid "failed to get kernel name and information"
-msgstr "gặp lỗi khi lấy tên và thông tin của nhân"
+#: diff.c:4925
+#, c-format
+msgid "bad --color-moved argument: %s"
+msgstr "đối số --color-moved sai: %s"
 
-#: dir.c:2233
-msgid "Untracked cache is disabled on this system or location."
-msgstr "Bộ nhớ tạm không theo vết bị tắt trên hệ thống hay vị trí này."
+#: diff.c:4944
+#, c-format
+msgid "invalid mode '%s' in --color-moved-ws"
+msgstr "chế độ “%s” không hợp lệ trong --color-moved-ws"
+
+#: diff.c:4984
+msgid ""
+"option diff-algorithm accepts \"myers\", \"minimal\", \"patience\" and "
+"\"histogram\""
+msgstr ""
+"tùy chọn  diff-algorithm chấp nhận \"myers\", \"minimal\", \"patience\" và "
+"\"histogram\""
 
-#: dir.c:3075 dir.c:3080
+#: diff.c:5020 diff.c:5040
 #, c-format
-msgid "could not create directories for %s"
-msgstr "không thể tạo thư mục cho %s"
+msgid "invalid argument to %s"
+msgstr "tham số cho %s không hợp lệ"
 
-#: dir.c:3109
+#: diff.c:5178
 #, c-format
-msgid "could not migrate git directory from '%s' to '%s'"
-msgstr "không thể di cư thư mục git từ “%s” sang “%s”"
+msgid "failed to parse --submodule option parameter: '%s'"
+msgstr "gặp lỗi khi phân tích đối số tùy chọn --submodule: “%s”"
 
-#: editor.c:61
+#: diff.c:5234
 #, c-format
-msgid "hint: Waiting for your editor to close the file...%c"
-msgstr "gợi ý: Chờ trình biên soạn của bạn đóng tập tin…%c"
+msgid "bad --word-diff argument: %s"
+msgstr "đối số --word-diff sai: %s"
 
-#: entry.c:177
-msgid "Filtering content"
-msgstr "Nội dung lọc"
+#: diff.c:5257
+msgid "Diff output format options"
+msgstr "Các tùy chọn định dạng khi xuất các khác biệt"
 
-#: entry.c:435
-#, c-format
-msgid "could not stat file '%s'"
-msgstr "không thể lấy thống kê tập tin “%s”"
+#: diff.c:5259 diff.c:5265
+msgid "generate patch"
+msgstr "tạo miếng vá"
 
-#: fetch-object.c:17
-msgid "Remote with no URL"
-msgstr "Máy chủ không có địa chỉ URL"
+#: diff.c:5262 builtin/log.c:173
+msgid "suppress diff output"
+msgstr "chặn mọi kết xuất từ diff"
 
-#: fetch-pack.c:254
-msgid "git fetch-pack: expected shallow list"
-msgstr "git fetch-pack: cần danh sách shallow"
+#: diff.c:5267 diff.c:5381 diff.c:5388
+msgid "<n>"
+msgstr "<n>"
 
-#: fetch-pack.c:266
-msgid "git fetch-pack: expected ACK/NAK, got a flush packet"
-msgstr "git fetch-pack: cần ACK/NAK, nhưng lại nhận được một gói flush"
+#: diff.c:5268 diff.c:5271
+msgid "generate diffs with <n> lines context"
+msgstr "tạo khác biệt với <n> dòng ngữ cảnh"
 
-#: fetch-pack.c:285 builtin/archive.c:63
-#, c-format
-msgid "remote error: %s"
-msgstr "lỗi máy chủ: %s"
+#: diff.c:5273
+msgid "generate the diff in raw format"
+msgstr "tạo khác biệt ở định dạng thô"
 
-#: fetch-pack.c:286
-#, c-format
-msgid "git fetch-pack: expected ACK/NAK, got '%s'"
-msgstr "git fetch-pack: cần ACK/NAK, nhưng lại nhận được “%s”"
+#: diff.c:5276
+msgid "synonym for '-p --raw'"
+msgstr "đồng nghĩa với “-p --raw”"
 
-#: fetch-pack.c:338
-msgid "--stateless-rpc requires multi_ack_detailed"
-msgstr "--stateless-rpc cần multi_ack_detailed"
+#: diff.c:5280
+msgid "synonym for '-p --stat'"
+msgstr "đồng nghĩa với “-p --stat”"
 
-#: fetch-pack.c:429 fetch-pack.c:1310
-#, c-format
-msgid "invalid shallow line: %s"
-msgstr "dòng shallow không hợp lệ: %s"
+#: diff.c:5284
+msgid "machine friendly --stat"
+msgstr "--stat thuận tiện cho máy đọc"
 
-#: fetch-pack.c:435 fetch-pack.c:1316
-#, c-format
-msgid "invalid unshallow line: %s"
-msgstr "dòng unshallow không hợp lệ: %s"
+#: diff.c:5287
+msgid "output only the last line of --stat"
+msgstr "chỉ xuất những dòng cuối của --stat"
 
-#: fetch-pack.c:437 fetch-pack.c:1318
-#, c-format
-msgid "object not found: %s"
-msgstr "Không tìm thấy đối tượng: %s"
+#: diff.c:5289 diff.c:5297
+msgid "<param1,param2>..."
+msgstr "<tham_số_1,tham_số_2>…"
 
-#: fetch-pack.c:440 fetch-pack.c:1321
-#, c-format
-msgid "error in object: %s"
-msgstr "lỗi trong đối tượng: %s"
+#: diff.c:5290
+msgid ""
+"output the distribution of relative amount of changes for each sub-directory"
+msgstr "đầu ra phân phối của số lượng thay đổi tương đối cho mỗi thư mục con"
 
-#: fetch-pack.c:442 fetch-pack.c:1323
-#, c-format
-msgid "no shallow found: %s"
-msgstr "không tìm shallow nào: %s"
+#: diff.c:5294
+msgid "synonym for --dirstat=cumulative"
+msgstr "đồng nghĩa với --dirstat=cumulative"
 
-#: fetch-pack.c:445 fetch-pack.c:1326
-#, c-format
-msgid "expected shallow/unshallow, got %s"
-msgstr "cần shallow/unshallow, nhưng lại nhận được %s"
+#: diff.c:5298
+msgid "synonym for --dirstat=files,param1,param2..."
+msgstr "đồng nghĩa với --dirstat=files,param1,param2…"
 
-#: fetch-pack.c:486
-#, c-format
-msgid "got %s %d %s"
-msgstr "nhận %s %d - %s"
+#: diff.c:5302
+msgid "warn if changes introduce conflict markers or whitespace errors"
+msgstr ""
+"cảnh báo nếu các thay đổi đưa ra các bộ tạo xung đột hay lỗi khoảng trắng"
 
-#: fetch-pack.c:500
-#, c-format
-msgid "invalid commit %s"
-msgstr "lần chuyển giao %s không hợp lệ"
+#: diff.c:5305
+msgid "condensed summary such as creations, renames and mode changes"
+msgstr "tổng hợp dạng xúc tích như là tạo, đổi tên và các thay đổi chế độ"
 
-#: fetch-pack.c:533
-msgid "giving up"
-msgstr "chịu thua"
+#: diff.c:5308
+msgid "show only names of changed files"
+msgstr "chỉ hiển thị tên của các tập tin đổi"
 
-#: fetch-pack.c:543 progress.c:229
-msgid "done"
-msgstr "xong"
+#: diff.c:5311
+msgid "show only names and status of changed files"
+msgstr "chỉ hiển thị tên tập tin và tình trạng của các tập tin bị thay đổi"
 
-#: fetch-pack.c:555
-#, c-format
-msgid "got %s (%d) %s"
-msgstr "nhận %s (%d) %s"
+#: diff.c:5313
+msgid "<width>[,<name-width>[,<count>]]"
+msgstr "<rộng>[,<name-width>[,<số-lượng>]]"
 
-#: fetch-pack.c:601
-#, c-format
-msgid "Marking %s as complete"
-msgstr "Đánh dấu %s là đã hoàn thành"
+#: diff.c:5314
+msgid "generate diffstat"
+msgstr "tạo diffstat"
 
-#: fetch-pack.c:828
-#, c-format
-msgid "already have %s (%s)"
-msgstr "đã sẵn có %s (%s)"
+#: diff.c:5316 diff.c:5319 diff.c:5322
+msgid "<width>"
+msgstr "<rộng>"
 
-#: fetch-pack.c:869
-msgid "fetch-pack: unable to fork off sideband demultiplexer"
-msgstr "fetch-pack: không thể rẽ nhánh sideband demultiplexer"
+#: diff.c:5317
+msgid "generate diffstat with a given width"
+msgstr "tạo diffstat với độ rộng đã cho"
 
-#: fetch-pack.c:877
-msgid "protocol error: bad pack header"
-msgstr "lỗi giao thức: phần đầu gói bị sai"
+#: diff.c:5320
+msgid "generate diffstat with a given name width"
+msgstr "tạo diffstat với tên độ rộng đã cho"
 
-#: fetch-pack.c:944
-#, c-format
-msgid "fetch-pack: unable to fork off %s"
-msgstr "fetch-pack: không thể rẽ nhánh %s"
+#: diff.c:5323
+msgid "generate diffstat with a given graph width"
+msgstr "tạo diffstat với độ rộng đồ thị đã cho"
 
-#: fetch-pack.c:960
-#, c-format
-msgid "%s failed"
-msgstr "%s gặp lỗi"
+#: diff.c:5325
+msgid "<count>"
+msgstr "<số_lượng>"
 
-#: fetch-pack.c:962
-msgid "error in sideband demultiplexer"
-msgstr "có lỗi trong sideband demultiplexer"
+#: diff.c:5326
+msgid "generate diffstat with limited lines"
+msgstr "tạo diffstat với các dòng bị giới hạn"
 
-#: fetch-pack.c:989
-msgid "Server does not support shallow clients"
-msgstr "Máy chủ không hỗ trợ máy khách shallow"
+#: diff.c:5329
+msgid "generate compact summary in diffstat"
+msgstr "tạo tổng hợp xúc tích trong diffstat"
 
-#: fetch-pack.c:993
-msgid "Server supports multi_ack_detailed"
-msgstr "Máy chủ hỗ trợ multi_ack_detailed"
-
-#: fetch-pack.c:996
-msgid "Server supports no-done"
-msgstr "Máy chủ hỗ trợ no-done"
-
-#: fetch-pack.c:1002
-msgid "Server supports multi_ack"
-msgstr "Máy chủ hỗ trợ multi_ack"
-
-#: fetch-pack.c:1006
-msgid "Server supports side-band-64k"
-msgstr "Máy chủ hỗ trợ side-band-64k"
-
-#: fetch-pack.c:1010
-msgid "Server supports side-band"
-msgstr "Máy chủ hỗ trợ side-band"
-
-#: fetch-pack.c:1014
-msgid "Server supports allow-tip-sha1-in-want"
-msgstr "Máy chủ hỗ trợ allow-tip-sha1-in-want"
-
-#: fetch-pack.c:1018
-msgid "Server supports allow-reachable-sha1-in-want"
-msgstr "Máy chủ hỗ trợ allow-reachable-sha1-in-want"
-
-#: fetch-pack.c:1028
-msgid "Server supports ofs-delta"
-msgstr "Máy chủ hỗ trợ ofs-delta"
+#: diff.c:5332
+msgid "output a binary diff that can be applied"
+msgstr "xuất ra một khác biệt dạng nhị phân cái mà có thể được áp dụng"
 
-#: fetch-pack.c:1034 fetch-pack.c:1204
-msgid "Server supports filter"
-msgstr "Máy chủ hỗ trợ bộ lọc"
+#: diff.c:5335
+msgid "show full pre- and post-image object names on the \"index\" lines"
+msgstr ""
+"hiển thị đầy đủ các tên đối tượng pre- và post-image trên các dòng \"mục lục"
+"\""
 
-#: fetch-pack.c:1042
-#, c-format
-msgid "Server version is %.*s"
-msgstr "Phiên bản máy chủ là %.*s"
+#: diff.c:5337
+msgid "show colored diff"
+msgstr "hiển thị thay đổi được tô màu"
 
-#: fetch-pack.c:1048
-msgid "Server does not support --shallow-since"
-msgstr "Máy chủ không hỗ trợ --shallow-since"
+#: diff.c:5338
+msgid "<kind>"
+msgstr "<kiểu>"
 
-#: fetch-pack.c:1052
-msgid "Server does not support --shallow-exclude"
-msgstr "Máy chủ không hỗ trợ --shallow-exclude"
+#: diff.c:5339
+msgid ""
+"highlight whitespace errors in the 'context', 'old' or 'new' lines in the "
+"diff"
+msgstr ""
+"tô sang các lỗi về khoảng trắng trong các dòng “context”, “old” và “new” "
+"trong khác biệt"
 
-#: fetch-pack.c:1054
-msgid "Server does not support --deepen"
-msgstr "Máy chủ không hỗ trợ --deepen"
+#: diff.c:5342
+msgid ""
+"do not munge pathnames and use NULs as output field terminators in --raw or "
+"--numstat"
+msgstr ""
+"không munge tên đường dẫn và sử dụng NUL làm bộ phân tách trường đầu ra "
+"trong --raw hay --numstat"
 
-#: fetch-pack.c:1065
-msgid "no common commits"
-msgstr "không có lần chuyển giao chung nào"
+#: diff.c:5345 diff.c:5348 diff.c:5351 diff.c:5457
+msgid "<prefix>"
+msgstr "<tiền_tố>"
 
-#: fetch-pack.c:1077 fetch-pack.c:1414
-msgid "git fetch-pack: fetch failed."
-msgstr "git fetch-pack: fetch gặp lỗi."
+#: diff.c:5346
+msgid "show the given source prefix instead of \"a/\""
+msgstr "hiển thị tiền tố nguồn đã cho thay cho \"a/\""
 
-#: fetch-pack.c:1199
-msgid "Server does not support shallow requests"
-msgstr "Máy chủ không hỗ trợ yêu cầu shallow"
+#: diff.c:5349
+msgid "show the given destination prefix instead of \"b/\""
+msgstr "hiển thị tiền tố đích đã cho thay cho \"b/\""
 
-#: fetch-pack.c:1584
-msgid "no matching remote head"
-msgstr "không khớp phần đầu máy chủ"
+#: diff.c:5352
+msgid "prepend an additional prefix to every line of output"
+msgstr "treo vào trước một tiền tố bổ sung cho mỗi dòng kết xuất"
 
-#: fetch-pack.c:1610
-#, c-format
-msgid "no such remote ref %s"
-msgstr "Không có máy chủ tham chiếu nào như %s"
+#: diff.c:5355
+msgid "do not show any source or destination prefix"
+msgstr "đừng hiển thị bất kỳ tiền tố nguồn hay đích"
 
-#: fetch-pack.c:1613
-#, c-format
-msgid "Server does not allow request for unadvertised object %s"
+#: diff.c:5358
+msgid "show context between diff hunks up to the specified number of lines"
 msgstr ""
-"Máy phục vụ không cho phép yêu cầu cho đối tượng không được báo trước %s"
+"hiển thị ngữ cảnh giữa các khúc khác biệt khi đạt đến số lượng dòng đã chỉ "
+"định"
 
-#: gpg-interface.c:185
-msgid "gpg failed to sign the data"
-msgstr "gpg gặp lỗi khi ký dữ liệu"
+#: diff.c:5362 diff.c:5367 diff.c:5372
+msgid "<char>"
+msgstr "<ký_tự>"
 
-#: gpg-interface.c:210
-msgid "could not create temporary file"
-msgstr "không thể tạo tập tin tạm thời"
+#: diff.c:5363
+msgid "specify the character to indicate a new line instead of '+'"
+msgstr "chỉ định một ký tự để biểu thị một dòng được thêm mới thay cho “+”"
 
-#: gpg-interface.c:213
-#, c-format
-msgid "failed writing detached signature to '%s'"
-msgstr "gặp lỗi khi ghi chữ ký đính kèm vào “%s”"
+#: diff.c:5368
+msgid "specify the character to indicate an old line instead of '-'"
+msgstr "chỉ định một ký tự để biểu thị một dòng đã cũ thay cho “-”"
 
-#: graph.c:97
-#, c-format
-msgid "ignore invalid color '%.*s' in log.graphColors"
-msgstr "bỏ qua màu không hợp lệ “%.*s” trong log.graphColors"
+#: diff.c:5373
+msgid "specify the character to indicate a context instead of ' '"
+msgstr "chỉ định một ký tự để biểu thị một ngữ cảnh thay cho “”"
 
-#: grep.c:2020
-#, c-format
-msgid "'%s': unable to read %s"
-msgstr "“%s”: không thể đọc %s"
+#: diff.c:5376
+msgid "Diff rename options"
+msgstr "Tùy chọn khác biệt đổi tên"
 
-#: grep.c:2037 setup.c:164 builtin/clone.c:409 builtin/diff.c:81
-#: builtin/rm.c:134
-#, c-format
-msgid "failed to stat '%s'"
-msgstr "gặp lỗi khi lấy thống kê về “%s”"
+#: diff.c:5377
+msgid "<n>[/<m>]"
+msgstr "<n>[/<m>]"
 
-#: grep.c:2048
-#, c-format
-msgid "'%s': short read"
-msgstr "“%s”: đọc ngắn"
+#: diff.c:5378
+msgid "break complete rewrite changes into pairs of delete and create"
+msgstr "ngắt các thay đổi ghi lại hoàn thiện thành cặp của xóa và tạo"
 
-#: help.c:23
-msgid "start a working area (see also: git help tutorial)"
-msgstr "bắt đầu một vùng làm việc (xem thêm: git help tutorial)"
+#: diff.c:5382
+msgid "detect renames"
+msgstr "dò tìm các tên thay đổi"
 
-#: help.c:24
-msgid "work on the current change (see also: git help everyday)"
-msgstr "làm việc trên thay đổi hiện tại (xem thêm: git help everyday)"
+#: diff.c:5386
+msgid "omit the preimage for deletes"
+msgstr "bỏ qua preimage (tiền ảnh??) cho các việc xóa"
 
-#: help.c:25
-msgid "examine the history and state (see also: git help revisions)"
-msgstr "xem xét lịch sử tình trạng (xem thêm: git help revisions)"
+#: diff.c:5389
+msgid "detect copies"
+msgstr "dò bản sao"
 
-#: help.c:26
-msgid "grow, mark and tweak your common history"
-msgstr "thêm, ghi dấu và chỉnh lịch sử chung của bạn"
+#: diff.c:5393
+msgid "use unmodified files as source to find copies"
+msgstr "dùng các tập tin không bị chỉnh sửa như là nguồn để tìm các bản sao"
 
-#: help.c:27
-msgid "collaborate (see also: git help workflows)"
-msgstr "làm việc nhóm (xem thêm: git help workflows)"
+#: diff.c:5395
+msgid "disable rename detection"
+msgstr "tắt dò tìm đổi tên"
 
-#: help.c:31
-msgid "Main Porcelain Commands"
-msgstr "Các lệnh Porcelain chính"
+#: diff.c:5398
+msgid "use empty blobs as rename source"
+msgstr "dung các blob trống rống như là nguồn đổi tên"
 
-#: help.c:32
-msgid "Ancillary Commands / Manipulators"
-msgstr "Lệnh/thao tác thứ cấp"
+#: diff.c:5400
+msgid "continue listing the history of a file beyond renames"
+msgstr "tiếp tục liệt kê lịch sử của một tập tin ngoài đổi tên"
 
-#: help.c:33
-msgid "Ancillary Commands / Interrogators"
-msgstr "Lệnh/bộ hỏi thứ cấp"
+#: diff.c:5403
+msgid ""
+"prevent rename/copy detection if the number of rename/copy targets exceeds "
+"given limit"
+msgstr ""
+"ngăn cản dò tìm đổi tên/bản sao nếu số lượng của đích đổi tên/bản sao vượt "
+"quá giới hạn đưa ra"
 
-#: help.c:34
-msgid "Interacting with Others"
-msgstr "Tương tác với những cái khác"
+#: diff.c:5405
+msgid "Diff algorithm options"
+msgstr "Tùy chọn thuật toán khác biệt"
 
-#: help.c:35
-msgid "Low-level Commands / Manipulators"
-msgstr "Lệnh/thao tác ở mức thấp"
+#: diff.c:5407
+msgid "produce the smallest possible diff"
+msgstr "sản sinh khác biệt ít nhất có thể"
 
-#: help.c:36
-msgid "Low-level Commands / Interrogators"
-msgstr "Lệnh/bộ hỏi ở mức thấp"
+#: diff.c:5410
+msgid "ignore whitespace when comparing lines"
+msgstr "lờ đi sự thay đổi do khoảng trắng gây ra khi so sánh các dòng"
 
-#: help.c:37
-msgid "Low-level Commands / Synching Repositories"
-msgstr "Lệnh/Đồng bộ kho ở mức thấp"
+#: diff.c:5413
+msgid "ignore changes in amount of whitespace"
+msgstr "lờ đi sự thay đổi do số lượng khoảng trắng gây ra"
 
-#: help.c:38
-msgid "Low-level Commands / Internal Helpers"
-msgstr "Lệnh/Hỗ trợ nội tại ở mức thấp"
+#: diff.c:5416
+msgid "ignore changes in whitespace at EOL"
+msgstr "lờ đi sự thay đổi do khoảng trắng gây ra khi ở cuối dòng EOL"
 
-#: help.c:293
-#, c-format
-msgid "available git commands in '%s'"
-msgstr "các lệnh git sẵn có trong thư mục “%s”:"
+#: diff.c:5419
+msgid "ignore carrier-return at the end of line"
+msgstr "bỏ qua ký tự về đầu dòng tại cuối dòng"
 
-#: help.c:300
-msgid "git commands available from elsewhere on your $PATH"
-msgstr "các lệnh git sẵn có từ một nơi khác trong $PATH của bạn"
+#: diff.c:5422
+msgid "ignore changes whose lines are all blank"
+msgstr "bỏ qua các thay đổi cho toàn bộ các dòng là trống"
 
-#: help.c:309
-msgid "These are common Git commands used in various situations:"
-msgstr "Có các lệnh Git chung được sử dụng trong các tình huống khác nhau:"
+#: diff.c:5425
+msgid "heuristic to shift diff hunk boundaries for easy reading"
+msgstr "heuristic để dịch hạn biên của khối khác biệt cho dễ đọc"
 
-#: help.c:358 git.c:90
-#, c-format
-msgid "unsupported command listing type '%s'"
-msgstr "không hỗ trợ liệt kê lệnh kiểu “%s”"
+#: diff.c:5428
+msgid "generate diff using the \"patience diff\" algorithm"
+msgstr "tạo khác biệt sử dung thuật toán \"patience diff\""
 
-#: help.c:405
-msgid "The common Git guides are:"
-msgstr "Các chỉ dẫn chung về Git là:"
+#: diff.c:5432
+msgid "generate diff using the \"histogram diff\" algorithm"
+msgstr "tạo khác biệt sử dung thuật toán \"histogram diff\""
 
-#: help.c:467
-#, c-format
-msgid ""
-"'%s' appears to be a git command, but we were not\n"
-"able to execute it. Maybe git-%s is broken?"
-msgstr ""
-"“%s” trông như là một lệnh git, nhưng chúng tôi không\n"
-"thể thực thi nó. Có lẽ là lệnh git-%s đã bị hỏng?"
+#: diff.c:5434
+msgid "<algorithm>"
+msgstr "<thuật toán>"
 
-#: help.c:526
-msgid "Uh oh. Your system reports no Git commands at all."
-msgstr "Ối chà. Hệ thống của bạn báo rằng chẳng có lệnh Git nào cả."
+#: diff.c:5435
+msgid "choose a diff algorithm"
+msgstr "chọn một thuật toán khác biệt"
 
-#: help.c:548
-#, c-format
-msgid "WARNING: You called a Git command named '%s', which does not exist."
-msgstr "CẢNH BÁO: Bạn đã gọi lệnh Git có tên “%s”, mà nó lại không có sẵn."
+#: diff.c:5437
+msgid "<text>"
+msgstr "<văn bản>"
 
-#: help.c:553
-#, c-format
-msgid "Continuing under the assumption that you meant '%s'."
-msgstr "Tiếp tục và coi rằng ý bạn là “%s”."
+#: diff.c:5438
+msgid "generate diff using the \"anchored diff\" algorithm"
+msgstr "tạo khác biệt sử dung thuật toán \"anchored diff\""
 
-#: help.c:558
-#, c-format
-msgid "Continuing in %0.1f seconds, assuming that you meant '%s'."
-msgstr "Tiếp tục trong %0.1f giây,và coi rằng ý bạn là “%s”."
+#: diff.c:5440 diff.c:5449 diff.c:5452
+msgid "<mode>"
+msgstr "<chế độ>"
 
-#: help.c:566
-#, c-format
-msgid "git: '%s' is not a git command. See 'git --help'."
-msgstr "git: “%s” không phải là một lệnh của git. Xem “git --help”."
+#: diff.c:5441
+msgid "show word diff, using <mode> to delimit changed words"
+msgstr ""
+"hiển thị khác biệt từ, sử dung <chế độ> để bỏ giới hạn các từ bị thay đổi"
 
-#: help.c:570
-msgid ""
-"\n"
-"The most similar command is"
-msgid_plural ""
-"\n"
-"The most similar commands are"
-msgstr[0] ""
-"\n"
-"Những lệnh giống nhất là"
+#: diff.c:5443 diff.c:5446 diff.c:5491
+msgid "<regex>"
+msgstr "<regex>"
 
-#: help.c:585
-msgid "git version [<options>]"
-msgstr "git version [<các-tùy-chọn>]"
+#: diff.c:5444
+msgid "use <regex> to decide what a word is"
+msgstr "dùng <regex> để quyết định từ là cái gì"
 
-#: help.c:652
-#, c-format
-msgid "%s: %s - %s"
-msgstr "%s: %s - %s"
+#: diff.c:5447
+msgid "equivalent to --word-diff=color --word-diff-regex=<regex>"
+msgstr "tương đương với --word-diff=color --word-diff-regex=<regex>"
 
-#: help.c:656
-msgid ""
-"\n"
-"Did you mean this?"
-msgid_plural ""
-"\n"
-"Did you mean one of these?"
-msgstr[0] ""
-"\n"
-"Có phải ý bạn là một trong số những cái này không?"
+#: diff.c:5450
+msgid "moved lines of code are colored differently"
+msgstr "các dòng di chuyển của mã mà được tô màu khác nhau"
 
-#: ident.c:342
-msgid ""
-"\n"
-"*** Please tell me who you are.\n"
-"\n"
-"Run\n"
-"\n"
-"  git config --global user.email \"you@example.com\"\n"
-"  git config --global user.name \"Your Name\"\n"
-"\n"
-"to set your account's default identity.\n"
-"Omit --global to set the identity only in this repository.\n"
-"\n"
+#: diff.c:5453
+msgid "how white spaces are ignored in --color-moved"
+msgstr "bỏ qua khoảng trắng như thế nào trong --color-moved"
+
+#: diff.c:5456
+msgid "Other diff options"
+msgstr "Các tùy chọn khác biệt khác"
+
+#: diff.c:5458
+msgid "when run from subdir, exclude changes outside and show relative paths"
 msgstr ""
-"\n"
-"*** Vui lòng cho biết bạn là ai.\n"
-"\n"
-"Chạy\n"
-"\n"
-"  git config --global user.email \"bạn@ví_dụ.com\"\n"
-"  git config --global user.name \"Tên Của Bạn\"\n"
-"\n"
-"để đặt định danh mặc định cho tài khoản của bạn.\n"
-"Bỏ tùy chọn --global nếu chỉ định danh riêng cho kho này.\n"
-"\n"
+"khi chạy từ thư mục con, thự thi các thay đổi bên ngoài và hiển thị các "
+"đường dẫn liên quan"
 
-#: ident.c:366
-msgid "no email was given and auto-detection is disabled"
-msgstr "không đưa ra địa chỉ thư điện tử và auto-detection bị tắt"
+#: diff.c:5462
+msgid "treat all files as text"
+msgstr "coi mọi tập tin là dạng văn bản thường"
 
-#: ident.c:371
-#, c-format
-msgid "unable to auto-detect email address (got '%s')"
-msgstr "không thể tự dò tìm địa chỉ thư điện tử (nhận “%s”)"
+#: diff.c:5464
+msgid "swap two inputs, reverse the diff"
+msgstr "tráo đổi hai đầu vào, đảo ngược khác biệt"
 
-#: ident.c:381
-msgid "no name was given and auto-detection is disabled"
-msgstr "chưa chỉ ra tên và tự-động-dò-tìm bị tắt"
+#: diff.c:5466
+msgid "exit with 1 if there were differences, 0 otherwise"
+msgstr "thoát với mã 1 nếu không có khác biệt gì, 0 nếu ngược lại"
 
-#: ident.c:387
-#, c-format
-msgid "unable to auto-detect name (got '%s')"
-msgstr "không thể dò-tìm-tự động tên (đã nhận “%s”)"
+#: diff.c:5468
+msgid "disable all output of the program"
+msgstr "tắt mọi kết xuất của chương trình"
 
-#: ident.c:395
-#, c-format
-msgid "empty ident name (for <%s>) not allowed"
-msgstr "không cho phép tên định danh là rỗng (cho <%s>)"
+#: diff.c:5470
+msgid "allow an external diff helper to be executed"
+msgstr "cho phép mộ bộ hỗ trợ xuất khác biệt ở bên ngoài được phép thực thi"
 
-#: ident.c:401
-#, c-format
-msgid "name consists only of disallowed characters: %s"
-msgstr "tên chỉ được phép bao gồm các ký tự sau: %s"
+#: diff.c:5472
+msgid "run external text conversion filters when comparing binary files"
+msgstr ""
+"chạy các bộ lọc văn bản thông thường bên ngoài khi so sánh các tập tin nhị "
+"phân"
 
-#: ident.c:416 builtin/commit.c:587
-#, c-format
-msgid "invalid date format: %s"
-msgstr "ngày tháng không hợp lệ: %s"
+#: diff.c:5474
+msgid "<when>"
+msgstr "<khi>"
 
-#: list-objects-filter-options.c:36
-msgid "multiple filter-specs cannot be combined"
-msgstr "không thể tổ hợp nhiều đặc tả kiểu lọc"
+#: diff.c:5475
+msgid "ignore changes to submodules in the diff generation"
+msgstr "bỏ qua các thay đổi trong mô-đun-con trong khi tạo khác biệt"
 
-#: list-objects-filter-options.c:126
-msgid "cannot change partial clone promisor remote"
-msgstr "không thể thay đổi nhân bản từng phần máy chủ promisor"
+#: diff.c:5478
+msgid "<format>"
+msgstr "<định dạng>"
 
-#: lockfile.c:151
-#, c-format
+#: diff.c:5479
+msgid "specify how differences in submodules are shown"
+msgstr "chi định khác biệt bao nhiêu trong các mô đun con được hiển thị"
+
+#: diff.c:5483
+msgid "hide 'git add -N' entries from the index"
+msgstr "ẩn các mục “git add -N” từ bảng mục lục"
+
+#: diff.c:5486
+msgid "treat 'git add -N' entries as real in the index"
+msgstr "coi các mục “git add -N” như là có thật trong bảng mục lục"
+
+#: diff.c:5488
+msgid "<string>"
+msgstr "<chuỗi>"
+
+#: diff.c:5489
 msgid ""
-"Unable to create '%s.lock': %s.\n"
-"\n"
-"Another git process seems to be running in this repository, e.g.\n"
-"an editor opened by 'git commit'. Please make sure all processes\n"
-"are terminated then try again. If it still fails, a git process\n"
-"may have crashed in this repository earlier:\n"
-"remove the file manually to continue."
+"look for differences that change the number of occurrences of the specified "
+"string"
 msgstr ""
-"Không thể tạo “%s.lock”: %s.\n"
-"\n"
-"Tiến trình git khác có lẽ đang chạy ở kho này, ví dụ\n"
-"một trình soạn thảo được mở bởi “git commit”. Vui lòng chắc chắn\n"
-"rằng mọi tiến trình đã chấm dứt và sau đó thử lại. Nếu vẫn lỗi,\n"
-"một tiến trình git có lẽ đã đổ vỡ khi thực hiện ở kho này trước đó:\n"
-"gõ bỏ tập tin một cách thủ công để tiếp tục."
+"tìm các khác biệt cái mà thay đổi số lượng xảy ra của các phát sinh của "
+"chuỗi được chỉ ra"
 
-#: lockfile.c:159
-#, c-format
-msgid "Unable to create '%s.lock': %s"
-msgstr "Không thể tạo “%s.lock”: %s"
+#: diff.c:5492
+msgid ""
+"look for differences that change the number of occurrences of the specified "
+"regex"
+msgstr ""
+"tìm các khác biệt cái mà thay đổi số lượng xảy ra của các phát sinh của biểu "
+"thức chính quy được chỉ ra"
 
-#: merge.c:71
-msgid "failed to read the cache"
-msgstr "gặp lỗi khi đọc bộ nhớ đệm"
+#: diff.c:5495
+msgid "show all changes in the changeset with -S or -G"
+msgstr "hiển thị tất cả các thay đổi trong một bộ các thay đổi với -S hay -G"
 
-#: merge.c:136 builtin/am.c:1946 builtin/am.c:1980 builtin/checkout.c:378
-#: builtin/checkout.c:606 builtin/clone.c:761
-msgid "unable to write new index file"
-msgstr "không thể ghi tập tin lưu bảng mục lục mới"
+#: diff.c:5498
+msgid "treat <string> in -S as extended POSIX regular expression"
+msgstr "coi <chuỗi> trong -S như là biểu thức chính qui POSIX có mở rộng"
 
-#: merge-recursive.c:298
-msgid "(bad commit)\n"
-msgstr "(commit sai)\n"
+#: diff.c:5501
+msgid "control the order in which files appear in the output"
+msgstr "điều khiển thứ tự xuát hiện các tập tin trong kết xuất"
 
-#: merge-recursive.c:320
-#, c-format
-msgid "add_cacheinfo failed for path '%s'; merge aborting."
-msgstr "addinfo_cache gặp lỗi đối với đường dẫn “%s”; việc hòa trộn bị bãi bỏ."
+#: diff.c:5502
+msgid "<object-id>"
+msgstr "<mã-số-đối-tượng>"
 
-#: merge-recursive.c:328
-#, c-format
-msgid "add_cacheinfo failed to refresh for path '%s'; merge aborting."
+#: diff.c:5503
+msgid ""
+"look for differences that change the number of occurrences of the specified "
+"object"
 msgstr ""
-"addinfo_cache gặp lỗi khi làm mới đối với đường dẫn “%s”; việc hòa trộn bị "
-"bãi bỏ."
+"tìm các khác biệt cái mà thay đổi số lượng xảy ra của các phát sinh của đối "
+"tượng được chỉ ra"
 
-#: merge-recursive.c:410
-msgid "error building trees"
-msgstr "gặp lỗi khi xây dựng cây"
+#: diff.c:5505
+msgid "[(A|C|D|M|R|T|U|X|B)...[*]]"
+msgstr "[(A|C|D|M|R|T|U|X|B)…[*]]"
 
-#: merge-recursive.c:881
-#, c-format
-msgid "failed to create path '%s'%s"
-msgstr "gặp lỗi khi tạo đường dẫn “%s”%s"
+#: diff.c:5506
+msgid "select files by diff type"
+msgstr "chọn các tập tin theo kiểu khác biệt"
 
-#: merge-recursive.c:892
-#, c-format
-msgid "Removing %s to make room for subdirectory\n"
-msgstr "Gỡ bỏ %s để tạo chỗ (room) cho thư mục con\n"
+#: diff.c:5508
+msgid "<file>"
+msgstr "<tập_tin>"
+
+#: diff.c:5509
+msgid "Output to a specific file"
+msgstr "Xuất ra một tập tin cụ thể"
 
-#: merge-recursive.c:906 merge-recursive.c:925
-msgid ": perhaps a D/F conflict?"
-msgstr ": có lẽ là một xung đột D/F?"
+#: diff.c:6164
+msgid "inexact rename detection was skipped due to too many files."
+msgstr ""
+"nhận thấy đổi tên không chính xác đã bị bỏ qua bởi có quá nhiều tập tin."
+
+#: diff.c:6167
+msgid "only found copies from modified paths due to too many files."
+msgstr ""
+"chỉ tìm thấy các bản sao từ đường dẫn đã sửa đổi bởi vì có quá nhiều tập tin."
 
-#: merge-recursive.c:915
+#: diff.c:6170
 #, c-format
-msgid "refusing to lose untracked file at '%s'"
-msgstr "từ chối đóng tập tin không được theo dõi tại “%s”"
+msgid ""
+"you may want to set your %s variable to at least %d and retry the command."
+msgstr ""
+"bạn có lẽ muốn đặt biến %s của bạn thành ít nhất là %d và thử lại lệnh lần "
+"nữa."
 
-#: merge-recursive.c:957 builtin/cat-file.c:37
+#: dir.c:554
 #, c-format
-msgid "cannot read object %s '%s'"
-msgstr "không thể đọc đối tượng %s “%s”"
+msgid "pathspec '%s' did not match any file(s) known to git"
+msgstr "đặc tả đường dẫn “%s” không khớp với bất kỳ tập tin nào mà git biết"
 
-#: merge-recursive.c:959
+#: dir.c:664
 #, c-format
-msgid "blob expected for %s '%s'"
-msgstr "mong đợi đối tượng blob cho %s “%s”"
+msgid "unrecognized pattern: '%s'"
+msgstr "mẫu không được thừa nhận: “%s”"
 
-#: merge-recursive.c:983
+#: dir.c:682 dir.c:696
 #, c-format
-msgid "failed to open '%s': %s"
-msgstr "gặp lỗi khi mở “%s”: %s"
+msgid "unrecognized negative pattern: '%s'"
+msgstr "mẫu âm không được thừa nhận: “%s”"
 
-#: merge-recursive.c:994
+#: dir.c:714
 #, c-format
-msgid "failed to symlink '%s': %s"
-msgstr "gặp lỗi khi tạo liên kết mềm (symlink) “%s”: %s"
+msgid "your sparse-checkout file may have issues: pattern '%s' is repeated"
+msgstr "tập tin sparse-checkout của bạn có lẽ gặp lỗi: mẫu '%s' đã bị lặp lại"
 
-#: merge-recursive.c:999
+#: dir.c:724
+msgid "disabling cone pattern matching"
+msgstr "vô hiệu khớp mẫu nón"
+
+#: dir.c:1101
 #, c-format
-msgid "do not know what to do with %06o %s '%s'"
-msgstr "không hiểu phải làm gì với %06o %s “%s”"
+msgid "cannot use %s as an exclude file"
+msgstr "không thể dùng %s như là một tập tin loại trừ"
 
-#: merge-recursive.c:1186
+#: dir.c:2078
 #, c-format
-msgid "Failed to merge submodule %s (not checked out)"
-msgstr "Gặp lỗi khi hòa trộn mô-đun-con “%s” (không lấy ra được)"
+msgid "could not open directory '%s'"
+msgstr "không thể mở thư mục “%s”"
+
+#: dir.c:2415
+msgid "failed to get kernel name and information"
+msgstr "gặp lỗi khi lấy tên và thông tin của nhân"
 
-#: merge-recursive.c:1193
+#: dir.c:2539
+msgid "untracked cache is disabled on this system or location"
+msgstr "bộ nhớ tạm không theo vết bị tắt trên hệ thống hay vị trí này"
+
+#: dir.c:3343
 #, c-format
-msgid "Failed to merge submodule %s (commits not present)"
-msgstr "Gặp lỗi khi hòa trộn mô-đun-con “%s” (lần chuyển giao không hiện diện)"
+msgid "index file corrupt in repo %s"
+msgstr "tập tin ghi bảng mục lục bị hỏng trong kho %s"
 
-#: merge-recursive.c:1200
+#: dir.c:3388 dir.c:3393
 #, c-format
-msgid "Failed to merge submodule %s (commits don't follow merge-base)"
-msgstr ""
-"Gặp lỗi khi hòa trộn mô-đun-con “%s” (lần chuyển giao không theo sau nền-hòa-"
-"trộn)"
+msgid "could not create directories for %s"
+msgstr "không thể tạo thư mục cho %s"
 
-#: merge-recursive.c:1208 merge-recursive.c:1220
+#: dir.c:3422
 #, c-format
-msgid "Fast-forwarding submodule %s to the following commit:"
-msgstr "Chuyển-tiếp-nhanh mô-đun-con “%s” đến lần chuyển giao sau đây:"
+msgid "could not migrate git directory from '%s' to '%s'"
+msgstr "không thể di cư thư mục git từ “%s” sang “%s”"
 
-#: merge-recursive.c:1211 merge-recursive.c:1223
+#: editor.c:73
 #, c-format
-msgid "Fast-forwarding submodule %s"
-msgstr "Chuyển-tiếp-nhanh mô-đun-con “%s”"
+msgid "hint: Waiting for your editor to close the file...%c"
+msgstr "gợi ý: Chờ trình biên soạn của bạn đóng tập tin…%c"
+
+#: entry.c:178
+msgid "Filtering content"
+msgstr "Nội dung lọc"
 
-#: merge-recursive.c:1245
+#: entry.c:476
 #, c-format
-msgid "Failed to merge submodule %s (merge following commits not found)"
-msgstr ""
-"Gặp lỗi khi hòa trộn mô-đun-con “%s” (không tìm thấy các lần chuyển giao "
-"theo sau hòa trộn)"
+msgid "could not stat file '%s'"
+msgstr "không thể lấy thống kê tập tin “%s”"
 
-#: merge-recursive.c:1249
+#: environment.c:149
 #, c-format
-msgid "Failed to merge submodule %s (not fast-forward)"
-msgstr "Gặp lỗi khi hòa trộn mô-đun-con “%s” (không chuyển tiếp nhanh được)"
-
-#: merge-recursive.c:1250
-msgid "Found a possible merge resolution for the submodule:\n"
-msgstr "Tìm thấy một giải pháp hòa trộn có thể cho mô-đun-con:\n"
+msgid "bad git namespace path \"%s\""
+msgstr "đường dẫn không gian tên git \"%s\" sai"
 
-#: merge-recursive.c:1253
+#: environment.c:331
 #, c-format
-msgid ""
-"If this is correct simply add it to the index for example\n"
-"by using:\n"
-"\n"
-"  git update-index --cacheinfo 160000 %s \"%s\"\n"
-"\n"
-"which will accept this suggestion.\n"
-msgstr ""
-"Nếu đây là đúng đơn giản thêm nó vào mục lục ví dụ\n"
-"bằng cách dùng:\n"
-"\n"
-"  git update-index --cacheinfo 160000 %s \"%s\"\n"
-"\n"
-"cái mà sẽ chấp nhận gợi ý này.\n"
+msgid "could not set GIT_DIR to '%s'"
+msgstr "không thể đặt GIT_DIR thành “%s”"
 
-#: merge-recursive.c:1262
+#: exec-cmd.c:363
 #, c-format
-msgid "Failed to merge submodule %s (multiple merges found)"
-msgstr "Gặp lỗi khi hòa trộn mô-đun-con “%s” (thấy nhiều hòa trộn đa trùng)"
+msgid "too many args to run %s"
+msgstr "quá nhiều tham số để chạy %s"
 
-#: merge-recursive.c:1321
-msgid "Failed to execute internal merge"
-msgstr "Gặp lỗi khi thực hiện trộn nội bộ"
+#: fetch-pack.c:150
+msgid "git fetch-pack: expected shallow list"
+msgstr "git fetch-pack: cần danh sách shallow"
 
-#: merge-recursive.c:1326
-#, c-format
-msgid "Unable to add %s to database"
-msgstr "Không thể thêm %s vào cơ sở dữ liệu"
+#: fetch-pack.c:153
+msgid "git fetch-pack: expected a flush packet after shallow list"
+msgstr "git fetch-pack: cần một gói đẩy sau danh sách shallow"
 
-#: merge-recursive.c:1358
-#, c-format
-msgid "Auto-merging %s"
-msgstr "Tự-động-hòa-trộn %s"
+#: fetch-pack.c:164
+msgid "git fetch-pack: expected ACK/NAK, got a flush packet"
+msgstr "git fetch-pack: cần ACK/NAK, nhưng lại nhận được một gói flush"
 
-#: merge-recursive.c:1423
+#: fetch-pack.c:184
 #, c-format
-msgid "Error: Refusing to lose untracked file at %s; writing to %s instead."
-msgstr ""
-"Lỗi: từ chối đóng tập tin không được theo dõi tại “%s”; thay vào đó ghi vào "
-"%s."
+msgid "git fetch-pack: expected ACK/NAK, got '%s'"
+msgstr "git fetch-pack: cần ACK/NAK, nhưng lại nhận được “%s”"
 
-#: merge-recursive.c:1475
-#, c-format
-msgid ""
-"CONFLICT (%s/delete): %s deleted in %s and %s in %s. Version %s of %s left "
-"in tree."
-msgstr ""
-"XUNG ĐỘT (%s/xóa): %s bị xóa trong %s và %s trong %s. Phiên bản %s của %s "
-"còn lại trong cây (tree)."
+#: fetch-pack.c:195
+msgid "unable to write to remote"
+msgstr "không thể ghi lên máy phục vụ"
 
-#: merge-recursive.c:1480
-#, c-format
-msgid ""
-"CONFLICT (%s/delete): %s deleted in %s and %s to %s in %s. Version %s of %s "
-"left in tree."
-msgstr ""
-"XUNG ĐỘT (%s/xóa): %s bị xóa trong %s và %s đến %s trong %s. Phiên bản %s "
-"của %s còn lại trong cây (tree)."
+#: fetch-pack.c:257
+msgid "--stateless-rpc requires multi_ack_detailed"
+msgstr "--stateless-rpc cần multi_ack_detailed"
 
-#: merge-recursive.c:1487
+#: fetch-pack.c:356 fetch-pack.c:1340
 #, c-format
-msgid ""
-"CONFLICT (%s/delete): %s deleted in %s and %s in %s. Version %s of %s left "
-"in tree at %s."
-msgstr ""
-"XUNG ĐỘT (%s/xóa): %s bị xóa trong %s và %s trong %s. Phiên bản %s của %s "
-"còn lại trong cây (tree) tại %s."
+msgid "invalid shallow line: %s"
+msgstr "dòng shallow không hợp lệ: %s"
 
-#: merge-recursive.c:1492
+#: fetch-pack.c:362 fetch-pack.c:1346
 #, c-format
-msgid ""
-"CONFLICT (%s/delete): %s deleted in %s and %s to %s in %s. Version %s of %s "
-"left in tree at %s."
-msgstr ""
-"XUNG ĐỘT (%s/xóa): %s bị xóa trong %s và %s đến %s trong %s. Phiên bản %s "
-"của %s còn lại trong cây (tree) tại %s."
+msgid "invalid unshallow line: %s"
+msgstr "dòng unshallow không hợp lệ: %s"
 
-#: merge-recursive.c:1526
-msgid "rename"
-msgstr "đổi tên"
+#: fetch-pack.c:364 fetch-pack.c:1348
+#, c-format
+msgid "object not found: %s"
+msgstr "không tìm thấy đối tượng: %s"
 
-#: merge-recursive.c:1526
-msgid "renamed"
-msgstr "đã đổi tên"
+#: fetch-pack.c:367 fetch-pack.c:1351
+#, c-format
+msgid "error in object: %s"
+msgstr "lỗi trong đối tượng: %s"
 
-#: merge-recursive.c:1580 merge-recursive.c:1736 merge-recursive.c:2368
-#: merge-recursive.c:3086
+#: fetch-pack.c:369 fetch-pack.c:1353
 #, c-format
-msgid "Refusing to lose dirty file at %s"
-msgstr "Từ chối đóng tập tin không được theo dõi tại “%s”"
+msgid "no shallow found: %s"
+msgstr "không tìm shallow nào: %s"
 
-#: merge-recursive.c:1594
+#: fetch-pack.c:372 fetch-pack.c:1357
 #, c-format
-msgid "%s is a directory in %s adding as %s instead"
-msgstr "%s là một thư mục trong %s thay vào đó thêm vào như là %s"
+msgid "expected shallow/unshallow, got %s"
+msgstr "cần shallow/unshallow, nhưng lại nhận được %s"
 
-#: merge-recursive.c:1599
+#: fetch-pack.c:414
 #, c-format
-msgid "Refusing to lose untracked file at %s; adding as %s instead"
-msgstr ""
-"Từ chối đóng tập tin không được theo dõi tại “%s”; thay vào đó đang thêm "
-"thành %s"
+msgid "got %s %d %s"
+msgstr "nhận %s %d - %s"
 
-#: merge-recursive.c:1625
+#: fetch-pack.c:431
 #, c-format
-msgid ""
-"CONFLICT (rename/rename): Rename \"%s\"->\"%s\" in branch \"%s\" rename \"%s"
-"\"->\"%s\" in \"%s\"%s"
-msgstr ""
-"XUNG ĐỘT (đổi-tên/đổi-tên): Đổi tên \"%s\"->\"%s\" trong nhánh \"%s\" đổi "
-"tên \"%s\"->\"%s\" trong \"%s\"%s"
+msgid "invalid commit %s"
+msgstr "lần chuyển giao %s không hợp lệ"
 
-#: merge-recursive.c:1630
-msgid " (left unresolved)"
-msgstr " (cần giải quyết)"
+#: fetch-pack.c:462
+msgid "giving up"
+msgstr "chịu thua"
 
-#: merge-recursive.c:1694
-#, c-format
-msgid "CONFLICT (rename/rename): Rename %s->%s in %s. Rename %s->%s in %s"
-msgstr ""
-"XUNG ĐỘT (đổi-tên/đổi-tên): Đổi tên %s->%s trong %s. Đổi tên %s->%s trong %s"
+#: fetch-pack.c:475 progress.c:323
+msgid "done"
+msgstr "xong"
 
-#: merge-recursive.c:1733
+#: fetch-pack.c:487
 #, c-format
-msgid "Renaming %s to %s and %s to %s instead"
-msgstr "Đang đổi tên %s thành %s thay vì %s thành %s"
+msgid "got %s (%d) %s"
+msgstr "nhận %s (%d) %s"
 
-#: merge-recursive.c:1745
+#: fetch-pack.c:533
 #, c-format
-msgid "Refusing to lose untracked file at %s, even though it's in the way."
-msgstr ""
-"Từ chối đóng tập tin không được theo dõi tại “%s”, ngay cả khi nó ở trên "
-"đường."
+msgid "Marking %s as complete"
+msgstr "Đánh dấu %s là đã hoàn thành"
 
-#: merge-recursive.c:1951
+#: fetch-pack.c:754
 #, c-format
-msgid ""
-"CONFLICT (directory rename split): Unclear where to place %s because "
-"directory %s was renamed to multiple other directories, with no destination "
-"getting a majority of the files."
-msgstr ""
-"XUNG ĐỘT: (thư mục đổi tên chia tách): Không rõ ràng để đặt địa điểm %s bởi "
-"vì thư mục %s đã bị đổi tên thành nhiều thư mục khác, với không đích đến "
-"nhận một phần nhiều của các tập tin."
+msgid "already have %s (%s)"
+msgstr "đã sẵn có %s (%s)"
 
-#: merge-recursive.c:1983
-#, c-format
-msgid ""
-"CONFLICT (implicit dir rename): Existing file/dir at %s in the way of "
-"implicit directory rename(s) putting the following path(s) there: %s."
-msgstr ""
-"XUNG ĐỘT: (ngầm đổi tên thư mục): Tập tin/thư mục đã sẵn có tại %s theo cách "
-"của các đổi tên thư mục ngầm đặt (các) đường dẫn sau ở đây: %s."
+#: fetch-pack.c:818
+msgid "fetch-pack: unable to fork off sideband demultiplexer"
+msgstr "fetch-pack: không thể rẽ nhánh sideband demultiplexer"
 
-#: merge-recursive.c:1993
-#, c-format
-msgid ""
-"CONFLICT (implicit dir rename): Cannot map more than one path to %s; "
-"implicit directory renames tried to put these paths there: %s"
-msgstr ""
-"XUNG ĐỘT: (ngầm đổi tên thư mục): Không thể ánh xạ một đường dẫn thành %s; "
-"các đổi tên thư mục ngầm cố đặt các đường dẫn ở đây: %s."
+#: fetch-pack.c:826
+msgid "protocol error: bad pack header"
+msgstr "lỗi giao thức: phần đầu gói bị sai"
 
-#: merge-recursive.c:2085
+#: fetch-pack.c:900
 #, c-format
-msgid ""
-"CONFLICT (rename/rename): Rename directory %s->%s in %s. Rename directory %s-"
-">%s in %s"
-msgstr ""
-"XUNG ĐỘT (đổi-tên/đổi-tên): Đổi tên thư mục %s->%s trong %s. Đổi tên thư mục "
-"%s->%s trong %s"
+msgid "fetch-pack: unable to fork off %s"
+msgstr "fetch-pack: không thể rẽ nhánh %s"
 
-#: merge-recursive.c:2330
+#: fetch-pack.c:916
 #, c-format
-msgid ""
-"WARNING: Avoiding applying %s -> %s rename to %s, because %s itself was "
-"renamed."
-msgstr ""
-"CẢNH BÁO: tránh áp dụng %s -> %s đổi thên thành %s, bởi vì bản thân %s cũng "
-"bị đổi tên."
+msgid "%s failed"
+msgstr "%s gặp lỗi"
 
-#: merge-recursive.c:2736
-#, c-format
-msgid "CONFLICT (rename/add): Rename %s->%s in %s. %s added in %s"
-msgstr ""
-"XUNG ĐỘT (đổi-tên/thêm): Đổi tên %s->%s trong %s. %s được thêm vào trong %s"
+#: fetch-pack.c:918
+msgid "error in sideband demultiplexer"
+msgstr "có lỗi trong sideband demultiplexer"
 
-#: merge-recursive.c:2751
+#: fetch-pack.c:965
 #, c-format
-msgid "Adding merged %s"
-msgstr "Thêm hòa trộn %s"
+msgid "Server version is %.*s"
+msgstr "Phiên bản máy chủ là %.*s"
 
-#: merge-recursive.c:2758 merge-recursive.c:3089
+#: fetch-pack.c:970 fetch-pack.c:976 fetch-pack.c:979 fetch-pack.c:985
+#: fetch-pack.c:989 fetch-pack.c:993 fetch-pack.c:997 fetch-pack.c:1001
+#: fetch-pack.c:1005 fetch-pack.c:1009 fetch-pack.c:1013 fetch-pack.c:1017
+#: fetch-pack.c:1023 fetch-pack.c:1029 fetch-pack.c:1034 fetch-pack.c:1039
 #, c-format
-msgid "Adding as %s instead"
-msgstr "Thay vào đó thêm vào %s"
+msgid "Server supports %s"
+msgstr "Máy chủ hỗ trợ %s"
 
-#: merge-recursive.c:2914
-#, c-format
-msgid "cannot read object %s"
-msgstr "không thể đọc đối tượng %s"
+#: fetch-pack.c:972
+msgid "Server does not support shallow clients"
+msgstr "Máy chủ không hỗ trợ máy khách shallow"
 
-#: merge-recursive.c:2917
-#, c-format
-msgid "object %s is not a blob"
-msgstr "đối tượng %s không phải là một blob"
+#: fetch-pack.c:1032
+msgid "Server does not support --shallow-since"
+msgstr "Máy chủ không hỗ trợ --shallow-since"
 
-#: merge-recursive.c:2986
-msgid "modify"
-msgstr "sửa đổi"
+#: fetch-pack.c:1037
+msgid "Server does not support --shallow-exclude"
+msgstr "Máy chủ không hỗ trợ --shallow-exclude"
 
-#: merge-recursive.c:2986
-msgid "modified"
-msgstr "đã sửa"
+#: fetch-pack.c:1041
+msgid "Server does not support --deepen"
+msgstr "Máy chủ không hỗ trợ --deepen"
 
-#: merge-recursive.c:2997
-msgid "content"
-msgstr "nội dung"
+#: fetch-pack.c:1058
+msgid "no common commits"
+msgstr "không có lần chuyển giao chung nào"
 
-#: merge-recursive.c:3004
-msgid "add/add"
-msgstr "thêm/thêm"
+#: fetch-pack.c:1070 fetch-pack.c:1536
+msgid "git fetch-pack: fetch failed."
+msgstr "git fetch-pack: fetch gặp lỗi."
 
-#: merge-recursive.c:3046
+#: fetch-pack.c:1209
+msgid "Server does not support shallow requests"
+msgstr "Máy chủ không hỗ trợ yêu cầu shallow"
+
+#: fetch-pack.c:1216
+msgid "Server supports filter"
+msgstr "Máy chủ hỗ trợ bộ lọc"
+
+#: fetch-pack.c:1239
+msgid "unable to write request to remote"
+msgstr "không thể ghi các yêu cầu lên máy phục vụ"
+
+#: fetch-pack.c:1257
 #, c-format
-msgid "Skipped %s (merged same as existing)"
-msgstr "Đã bỏ qua %s (đã có sẵn lần hòa trộn này)"
+msgid "error reading section header '%s'"
+msgstr "gặp lỗi khi đọc phần đầu của đoạn %s"
 
-#: merge-recursive.c:3055 git-submodule.sh:895
-msgid "submodule"
-msgstr "mô-đun-con"
+#: fetch-pack.c:1263
+#, c-format
+msgid "expected '%s', received '%s'"
+msgstr "cần “%s”, nhưng lại nhận “%s”"
 
-#: merge-recursive.c:3056
+#: fetch-pack.c:1303
 #, c-format
-msgid "CONFLICT (%s): Merge conflict in %s"
-msgstr "XUNG ĐỘT (%s): Xung đột hòa trộn trong %s"
+msgid "unexpected acknowledgment line: '%s'"
+msgstr "gặp dòng không được thừa nhận: “%s”"
 
-#: merge-recursive.c:3178
+#: fetch-pack.c:1308
 #, c-format
-msgid "Removing %s"
-msgstr "Đang xóa %s"
+msgid "error processing acks: %d"
+msgstr "gặp lỗi khi xử lý tín hiệu trả lời: %d"
 
-#: merge-recursive.c:3204
-msgid "file/directory"
-msgstr "tập-tin/thư-mục"
+#: fetch-pack.c:1318
+msgid "expected packfile to be sent after 'ready'"
+msgstr "cần tập tin gói để gửi sau “ready”"
 
-#: merge-recursive.c:3210
-msgid "directory/file"
-msgstr "thư-mục/tập-tin"
+#: fetch-pack.c:1320
+msgid "expected no other sections to be sent after no 'ready'"
+msgstr "không cần thêm phần nào để gửi sau “ready”"
 
-#: merge-recursive.c:3217
+#: fetch-pack.c:1362
 #, c-format
-msgid "CONFLICT (%s): There is a directory with name %s in %s. Adding %s as %s"
-msgstr ""
-"XUNG ĐỘT (%s): Ở đây không có thư mục nào có tên %s trong %s. Thêm %s như là "
-"%s"
+msgid "error processing shallow info: %d"
+msgstr "lỗi xử lý thông tin shallow: %d"
 
-#: merge-recursive.c:3226
+#: fetch-pack.c:1409
 #, c-format
-msgid "Adding %s"
-msgstr "Thêm \"%s\""
+msgid "expected wanted-ref, got '%s'"
+msgstr "cần wanted-ref, nhưng lại nhận được “%s”"
 
-#: merge-recursive.c:3267
+#: fetch-pack.c:1414
 #, c-format
-msgid "Dirty index: cannot merge (dirty: %s)"
-msgstr "Bảng mục lục bẩn: không thể hòa trộn (bẩn: %s)"
-
-#: merge-recursive.c:3271
-msgid "Already up to date!"
-msgstr "Đã cập nhật rồi!"
+msgid "unexpected wanted-ref: '%s'"
+msgstr "không cần wanted-ref: “%s”"
 
-#: merge-recursive.c:3280
+#: fetch-pack.c:1419
 #, c-format
-msgid "merging of trees %s and %s failed"
-msgstr "hòa trộn các cây %s và %s gặp lỗi"
+msgid "error processing wanted refs: %d"
+msgstr "lỗi khi xử lý wanted refs: %d"
 
-#: merge-recursive.c:3379
-msgid "Merging:"
-msgstr "Đang trộn:"
+#: fetch-pack.c:1762
+msgid "no matching remote head"
+msgstr "không khớp phần đầu máy chủ"
 
-#: merge-recursive.c:3392
-#, c-format
-msgid "found %u common ancestor:"
-msgid_plural "found %u common ancestors:"
-msgstr[0] "tìm thấy %u tổ tiên chung:"
+#: fetch-pack.c:1785 builtin/clone.c:688
+msgid "remote did not send all necessary objects"
+msgstr "máy chủ đã không gửi tất cả các đối tượng cần thiết"
 
-#: merge-recursive.c:3431
-msgid "merge returned no commit"
-msgstr "hòa trộn không trả về lần chuyển giao nào"
+#: fetch-pack.c:1812
+#, c-format
+msgid "no such remote ref %s"
+msgstr "không có máy chủ tham chiếu nào như %s"
 
-#: merge-recursive.c:3495
+#: fetch-pack.c:1815
 #, c-format
-msgid "Could not parse object '%s'"
-msgstr "Không thể phân tích đối tượng “%s”"
+msgid "Server does not allow request for unadvertised object %s"
+msgstr ""
+"Máy phục vụ không cho phép yêu cầu cho đối tượng không được báo trước %s"
 
-#: merge-recursive.c:3511 builtin/merge.c:659 builtin/merge.c:816
-msgid "Unable to write index."
-msgstr "Không thể ghi bảng mục lục"
+#: gpg-interface.c:223
+msgid "could not create temporary file"
+msgstr "không thể tạo tập tin tạm thời"
 
-#: notes-merge.c:272
+#: gpg-interface.c:226
 #, c-format
-msgid ""
-"You have not concluded your previous notes merge (%s exists).\n"
-"Please, use 'git notes merge --commit' or 'git notes merge --abort' to "
-"commit/abort the previous merge before you start a new notes merge."
-msgstr ""
-"Bạn đã chưa hoàn tất hòa trộn ghi chú trước đây (%s vẫn còn).\n"
-"Vui lòng dùng “git notes merge --commit” hay “git notes merge --abort” để "
-"chuyển giao hay bãi bỏ lần hòa trộn trước đây và bắt đầu một hòa trộn ghi "
-"chú mới."
+msgid "failed writing detached signature to '%s'"
+msgstr "gặp lỗi khi ghi chữ ký đính kèm vào “%s”"
+
+#: gpg-interface.c:390
+msgid "gpg failed to sign the data"
+msgstr "gpg gặp lỗi khi ký dữ liệu"
 
-#: notes-merge.c:279
+#: graph.c:98
 #, c-format
-msgid "You have not concluded your notes merge (%s exists)."
-msgstr "Bạn chưa kết thúc việc hòa trộn ghi chú (%s vẫn tồn tại)."
+msgid "ignore invalid color '%.*s' in log.graphColors"
+msgstr "bỏ qua màu không hợp lệ “%.*s” trong log.graphColors"
 
-#: notes-utils.c:43
-msgid "Cannot commit uninitialized/unreferenced notes tree"
+#: grep.c:668
+msgid ""
+"given pattern contains NULL byte (via -f <file>). This is only supported "
+"with -P under PCRE v2"
 msgstr ""
-"Không thể chuyển giao cây ghi chú chưa được khởi tạo hoặc không được tham "
-"chiếu"
+"mẫu đã cho có chứa NULL byte (qua -f <file>). Điều này chỉ được hỗ trợ với -"
+"P dưới PCRE v2"
 
-#: notes-utils.c:102
+#: grep.c:2124
 #, c-format
-msgid "Bad notes.rewriteMode value: '%s'"
-msgstr "Giá trị notes.rewriteMode sai: “%s”"
+msgid "'%s': unable to read %s"
+msgstr "“%s”: không thể đọc %s"
 
-#: notes-utils.c:112
+#: grep.c:2141 setup.c:165 builtin/clone.c:411 builtin/diff.c:82
+#: builtin/rm.c:135
 #, c-format
-msgid "Refusing to rewrite notes in %s (outside of refs/notes/)"
-msgstr "Từ chối ghi đè ghi chú trong %s (nằm ngoài refs/notes/)"
+msgid "failed to stat '%s'"
+msgstr "gặp lỗi khi lấy thống kê về “%s”"
 
-#. TRANSLATORS: The first %s is the name of
-#. the environment variable, the second %s is
-#. its value.
-#.
-#: notes-utils.c:142
+#: grep.c:2152
 #, c-format
-msgid "Bad %s value: '%s'"
-msgstr "Giá trị %s sai: “%s”"
+msgid "'%s': short read"
+msgstr "“%s”: đọc ngắn"
 
-#: object.c:242
-#, c-format
-msgid "unable to parse object: %s"
-msgstr "không thể phân tích đối tượng: “%s”"
+#: help.c:23
+msgid "start a working area (see also: git help tutorial)"
+msgstr "bắt đầu một vùng làm việc (xem thêm: git help tutorial)"
 
-#: packfile.c:563
-msgid "offset before end of packfile (broken .idx?)"
-msgstr "vị trí tương đối trước điểm kết thúc của tập tin gói (.idx hỏng à?)"
+#: help.c:24
+msgid "work on the current change (see also: git help everyday)"
+msgstr "làm việc trên thay đổi hiện tại (xem thêm: git help everyday)"
 
-#: packfile.c:1742
-#, c-format
-msgid "offset before start of pack index for %s (corrupt index?)"
-msgstr "vị trí tương đối nằm trước chỉ mục gói cho %s (mục lục bị hỏng à?)"
+#: help.c:25
+msgid "examine the history and state (see also: git help revisions)"
+msgstr "xem xét lịch sử tình trạng (xem thêm: git help revisions)"
 
-#: packfile.c:1746
-#, c-format
-msgid "offset beyond end of pack index for %s (truncated index?)"
-msgstr ""
-"vị trí tương đối vượt quá cuối của chỉ mục gói cho %s (mục lục bị cắt cụt à?)"
+#: help.c:26
+msgid "grow, mark and tweak your common history"
+msgstr "thêm, ghi dấu và chỉnh lịch sử chung của bạn"
 
-#: parse-options.c:621
-msgid "..."
-msgstr "…"
+#: help.c:27
+msgid "collaborate (see also: git help workflows)"
+msgstr "làm việc nhóm (xem thêm: git help workflows)"
+
+#: help.c:31
+msgid "Main Porcelain Commands"
+msgstr "Các lệnh Porcelain chính"
+
+#: help.c:32
+msgid "Ancillary Commands / Manipulators"
+msgstr "Lệnh/thao tác thứ cấp"
+
+#: help.c:33
+msgid "Ancillary Commands / Interrogators"
+msgstr "Lệnh/bộ hỏi thứ cấp"
+
+#: help.c:34
+msgid "Interacting with Others"
+msgstr "Tương tác với những cái khác"
+
+#: help.c:35
+msgid "Low-level Commands / Manipulators"
+msgstr "Lệnh/thao tác ở mức thấp"
+
+#: help.c:36
+msgid "Low-level Commands / Interrogators"
+msgstr "Lệnh/bộ hỏi ở mức thấp"
+
+#: help.c:37
+msgid "Low-level Commands / Syncing Repositories"
+msgstr "Lệnh/Đồng bộ kho ở mức thấp"
+
+#: help.c:38
+msgid "Low-level Commands / Internal Helpers"
+msgstr "Lệnh/Hỗ trợ nội tại ở mức thấp"
 
-#: parse-options.c:640
+#: help.c:298
 #, c-format
-msgid "usage: %s"
-msgstr "cách dùng: %s"
+msgid "available git commands in '%s'"
+msgstr "các lệnh git sẵn có trong thư mục “%s”:"
 
-#. TRANSLATORS: the colon here should align with the
-#. one in "usage: %s" translation.
-#.
-#: parse-options.c:646
+#: help.c:305
+msgid "git commands available from elsewhere on your $PATH"
+msgstr "các lệnh git sẵn có từ một nơi khác trong $PATH của bạn"
+
+#: help.c:314
+msgid "These are common Git commands used in various situations:"
+msgstr "Có các lệnh Git chung được sử dụng trong các tình huống khác nhau:"
+
+#: help.c:363 git.c:98
 #, c-format
-msgid "   or: %s"
-msgstr "     hoặc: %s"
+msgid "unsupported command listing type '%s'"
+msgstr "không hỗ trợ liệt kê lệnh kiểu “%s”"
+
+#: help.c:403
+msgid "The common Git guides are:"
+msgstr "Các chỉ dẫn chung về Git là:"
+
+#: help.c:512
+msgid "See 'git help <command>' to read about a specific subcommand"
+msgstr "Xem “git help <lệnh>” để đọc các đặc tả của lệnh con"
+
+#: help.c:517
+msgid "External commands"
+msgstr "Các lệnh bên ngoài"
+
+#: help.c:532
+msgid "Command aliases"
+msgstr "Các bí danh lệnh"
 
-#: parse-options.c:649
+#: help.c:596
 #, c-format
-msgid "    %s"
-msgstr "    %s"
+msgid ""
+"'%s' appears to be a git command, but we were not\n"
+"able to execute it. Maybe git-%s is broken?"
+msgstr ""
+"“%s” trông như là một lệnh git, nhưng chúng tôi không\n"
+"thể thực thi nó. Có lẽ là lệnh git-%s đã bị hỏng?"
 
-#: parse-options.c:688
-msgid "-NUM"
-msgstr "-SỐ"
+#: help.c:655
+msgid "Uh oh. Your system reports no Git commands at all."
+msgstr "Ối chà. Hệ thống của bạn báo rằng chẳng có lệnh Git nào cả."
 
-#: parse-options-cb.c:44
+#: help.c:677
 #, c-format
-msgid "malformed expiration date '%s'"
-msgstr "ngày tháng hết hạn dị hình “%s”"
+msgid "WARNING: You called a Git command named '%s', which does not exist."
+msgstr "CẢNH BÁO: Bạn đã gọi lệnh Git có tên “%s”, mà nó lại không có sẵn."
 
-#: parse-options-cb.c:112
+#: help.c:682
 #, c-format
-msgid "malformed object name '%s'"
-msgstr "tên đối tượng dị hình “%s”"
+msgid "Continuing under the assumption that you meant '%s'."
+msgstr "Tiếp tục và coi rằng ý bạn là “%s”."
 
-#: path.c:892
+#: help.c:687
 #, c-format
-msgid "Could not make %s writable by group"
-msgstr "Không thể làm %s được ghi bởi nhóm"
+msgid "Continuing in %0.1f seconds, assuming that you meant '%s'."
+msgstr "Tiếp tục trong %0.1f giây,và coi rằng ý bạn là “%s”."
 
-#: pathspec.c:129
-msgid "Escape character '\\' not allowed as last character in attr value"
-msgstr ""
-"Ký tự thoát chuỗi “\\” không được phép là ký tự cuối trong giá trị thuộc tính"
+#: help.c:695
+#, c-format
+msgid "git: '%s' is not a git command. See 'git --help'."
+msgstr "git: “%s” không phải là một lệnh của git. Xem “git --help”."
 
-#: pathspec.c:147
-msgid "Only one 'attr:' specification is allowed."
-msgstr "chỉ có một đặc tả “attr:” là được phép."
+#: help.c:699
+msgid ""
+"\n"
+"The most similar command is"
+msgid_plural ""
+"\n"
+"The most similar commands are"
+msgstr[0] ""
+"\n"
+"Những lệnh giống nhất là"
 
-#: pathspec.c:150
-msgid "attr spec must not be empty"
-msgstr "đặc tả attr phải không được để trống"
+#: help.c:714
+msgid "git version [<options>]"
+msgstr "git version [<các tùy chọn>]"
 
-#: pathspec.c:193
+#: help.c:783
 #, c-format
-msgid "invalid attribute name %s"
-msgstr "tên thuộc tính không hợp lệ %s"
+msgid "%s: %s - %s"
+msgstr "%s: %s - %s"
 
-#: pathspec.c:258
-msgid "global 'glob' and 'noglob' pathspec settings are incompatible"
-msgstr ""
-"các cài đặt đặc tả đường dẫn “glob” và “noglob” toàn cục là xung khắc nhau"
+#: help.c:787
+msgid ""
+"\n"
+"Did you mean this?"
+msgid_plural ""
+"\n"
+"Did you mean one of these?"
+msgstr[0] ""
+"\n"
+"Có phải ý bạn là một trong số những cái này không?"
 
-#: pathspec.c:265
+#: ident.c:349
 msgid ""
-"global 'literal' pathspec setting is incompatible with all other global "
-"pathspec settings"
+"\n"
+"*** Please tell me who you are.\n"
+"\n"
+"Run\n"
+"\n"
+"  git config --global user.email \"you@example.com\"\n"
+"  git config --global user.name \"Your Name\"\n"
+"\n"
+"to set your account's default identity.\n"
+"Omit --global to set the identity only in this repository.\n"
+"\n"
 msgstr ""
-"cài đặt đặc tả đường dẫn “literal” toàn cục là xung khắc với các cài đặt đặc "
-"tả đường dẫn toàn cục khác"
+"\n"
+"*** Vui lòng cho biết bạn là ai.\n"
+"\n"
+"Chạy\n"
+"\n"
+"  git config --global user.email \"bạn@ví_dụ.com\"\n"
+"  git config --global user.name \"Tên Của Bạn\"\n"
+"\n"
+"để đặt định danh mặc định cho tài khoản của bạn.\n"
+"Bỏ tùy chọn --global nếu chỉ định danh riêng cho kho này.\n"
+"\n"
 
-#: pathspec.c:305
-msgid "invalid parameter for pathspec magic 'prefix'"
-msgstr "tham số không hợp lệ cho “tiền tố” màu nhiệm đặc tả đường đẫn"
+#: ident.c:379
+msgid "no email was given and auto-detection is disabled"
+msgstr "không đưa ra địa chỉ thư điện tử và auto-detection bị tắt"
 
-#: pathspec.c:326
+#: ident.c:384
 #, c-format
-msgid "Invalid pathspec magic '%.*s' in '%s'"
-msgstr "Số màu nhiệm đặc tả đường dẫn không hợp lệ “%.*s” trong “%s”"
+msgid "unable to auto-detect email address (got '%s')"
+msgstr "không thể tự dò tìm địa chỉ thư điện tử (nhận “%s”)"
 
-#: pathspec.c:331
-#, c-format
-msgid "Missing ')' at the end of pathspec magic in '%s'"
-msgstr "Thiếu “)” tại cuối của số màu nhiệm đặc tả đường dẫn trong “%s”"
+#: ident.c:401
+msgid "no name was given and auto-detection is disabled"
+msgstr "chưa chỉ ra tên và tự-động-dò-tìm bị tắt"
 
-#: pathspec.c:369
+#: ident.c:407
 #, c-format
-msgid "Unimplemented pathspec magic '%c' in '%s'"
-msgstr "Chưa viết mã cho số màu nhiệm đặc tả đường dẫn “%c” trong “%s”"
+msgid "unable to auto-detect name (got '%s')"
+msgstr "không thể dò-tìm-tự động tên (đã nhận “%s”)"
 
-#: pathspec.c:428
+#: ident.c:415
 #, c-format
-msgid "%s: 'literal' and 'glob' are incompatible"
-msgstr "%s: “literal” và “glob” xung khắc nhau"
+msgid "empty ident name (for <%s>) not allowed"
+msgstr "không cho phép tên định danh là rỗng (cho <%s>)"
 
-#: pathspec.c:441
+#: ident.c:421
 #, c-format
-msgid "%s: '%s' is outside repository"
-msgstr "%s: “%s” ngoài một kho chứa"
+msgid "name consists only of disallowed characters: %s"
+msgstr "tên chỉ được phép bao gồm các ký tự sau: %s"
 
-#: pathspec.c:515
+#: ident.c:436 builtin/commit.c:631
 #, c-format
-msgid "'%s' (mnemonic: '%c')"
-msgstr "“%s” (mnemonic: “%c”)"
+msgid "invalid date format: %s"
+msgstr "ngày tháng không hợp lệ: %s"
 
-#: pathspec.c:525
+#: list-objects.c:127
 #, c-format
-msgid "%s: pathspec magic not supported by this command: %s"
-msgstr "%s: số mầu nhiệm đặc tả đường dẫn chưa được hỗ trợ bởi lệnh này: %s"
+msgid "entry '%s' in tree %s has tree mode, but is not a tree"
+msgstr "mục “%s” trong cây %s có nút cây, nhưng không phải là một cây"
 
-#: pathspec.c:592
+#: list-objects.c:140
 #, c-format
-msgid "pathspec '%s' is beyond a symbolic link"
-msgstr "đặc tả đường dẫn “%s” vượt ra ngoài liên kết mềm"
+msgid "entry '%s' in tree %s has blob mode, but is not a blob"
+msgstr "mục “%s” trong cây %s có nút blob, nhưng không phải là một blob"
 
-#: pretty.c:962
-msgid "unable to parse --pretty format"
-msgstr "không thể phân tích định dạng --pretty"
+#: list-objects.c:375
+#, c-format
+msgid "unable to load root tree for commit %s"
+msgstr "không thể tải cây gốc cho lần chuyển giao “%s”"
 
-#: read-cache.c:1500
+#: list-objects-filter.c:492
 #, c-format
-msgid ""
-"index.version set, but the value is invalid.\n"
-"Using version %i"
-msgstr ""
-"index.version được đặt, nhưng giá trị của nó lại không hợp lệ.\n"
-"Dùng phiên bản %i"
+msgid "unable to access sparse blob in '%s'"
+msgstr "không thể truy cập các blob rải rác trong '%s'"
 
-#: read-cache.c:1510
+#: list-objects-filter.c:495
 #, c-format
-msgid ""
-"GIT_INDEX_VERSION set, but the value is invalid.\n"
-"Using version %i"
-msgstr ""
-"GIT_INDEX_VERSION được đặt, nhưng giá trị của nó lại không hợp lệ.\n"
-"Dùng phiên bản %i"
+msgid "unable to parse sparse filter data in %s"
+msgstr "không thể phân tích dữ liệu bộ lọc rải rác trong %s"
 
-#: read-cache.c:2404 sequencer.c:4338 wrapper.c:658 builtin/merge.c:1048
+#: list-objects-filter-options.c:58
+msgid "expected 'tree:<depth>'"
+msgstr "cần “tree:<depth>”"
+
+#: list-objects-filter-options.c:73
+msgid "sparse:path filters support has been dropped"
+msgstr "việc hỗ trợ bộ lọc sparse:đường/dẫn đã bị bỏ"
+
+#: list-objects-filter-options.c:86
 #, c-format
-msgid "could not close '%s'"
-msgstr "không thể đóng “%s”"
+msgid "invalid filter-spec '%s'"
+msgstr "đặc tả bộ lọc không hợp lệ “%s”"
 
-#: read-cache.c:2477 sequencer.c:2102 sequencer.c:3234
+#: list-objects-filter-options.c:102
 #, c-format
-msgid "could not stat '%s'"
-msgstr "không thể lấy thông tin thống kê về “%s”"
+msgid "must escape char in sub-filter-spec: '%c'"
+msgstr "phải thoát char trong sub-filter-spec: '%c'"
 
-#: read-cache.c:2490
-#, c-format
-msgid "unable to open git dir: %s"
-msgstr "không thể mở thư mục git: %s"
+#: list-objects-filter-options.c:144
+msgid "expected something after combine:"
+msgstr "mong đợi một cái gì đó sau khi kết hợp:"
 
-#: read-cache.c:2502
-#, c-format
-msgid "unable to unlink: %s"
-msgstr "không thể bỏ liên kết (unlink): “%s”"
+#: list-objects-filter-options.c:226
+msgid "multiple filter-specs cannot be combined"
+msgstr "không thể tổ hợp nhiều đặc tả kiểu lọc"
 
-#: refs.c:732 sequencer.c:4334 sequencer.c:4393 wrapper.c:225 wrapper.c:395
-#: builtin/am.c:779
+#: lockfile.c:151
 #, c-format
-msgid "could not open '%s' for writing"
-msgstr "không thể mở “%s” để ghi"
-
-#: refs.c:1880
-msgid "ref updates forbidden inside quarantine environment"
-msgstr "cập nhật tham chiếu bị cấm trong môi trường kiểm tra"
+msgid ""
+"Unable to create '%s.lock': %s.\n"
+"\n"
+"Another git process seems to be running in this repository, e.g.\n"
+"an editor opened by 'git commit'. Please make sure all processes\n"
+"are terminated then try again. If it still fails, a git process\n"
+"may have crashed in this repository earlier:\n"
+"remove the file manually to continue."
+msgstr ""
+"Không thể tạo “%s.lock”: %s.\n"
+"\n"
+"Tiến trình git khác có lẽ đang chạy ở kho này, ví dụ\n"
+"một trình soạn thảo được mở bởi “git commit”. Vui lòng chắc chắn\n"
+"rằng mọi tiến trình đã chấm dứt và sau đó thử lại. Nếu vẫn lỗi,\n"
+"một tiến trình git có lẽ đã đổ vỡ khi thực hiện ở kho này trước đó:\n"
+"gõ bỏ tập tin một cách thủ công để tiếp tục."
 
-#: refs/files-backend.c:1191
+#: lockfile.c:159
 #, c-format
-msgid "could not remove reference %s"
-msgstr "không thể gỡ bỏ tham chiếu: %s"
+msgid "Unable to create '%s.lock': %s"
+msgstr "Không thể tạo “%s.lock”: %s"
 
-#: refs/files-backend.c:1205 refs/packed-backend.c:1531
-#: refs/packed-backend.c:1541
-#, c-format
-msgid "could not delete reference %s: %s"
-msgstr "không thể xóa bỏ tham chiếu %s: %s"
+#: merge.c:41
+msgid "failed to read the cache"
+msgstr "gặp lỗi khi đọc bộ nhớ đệm"
 
-#: refs/files-backend.c:1208 refs/packed-backend.c:1544
-#, c-format
-msgid "could not delete references: %s"
-msgstr "không thể xóa bỏ tham chiếu: %s"
+#: merge.c:107 rerere.c:720 builtin/am.c:1874 builtin/am.c:1908
+#: builtin/checkout.c:539 builtin/checkout.c:798 builtin/clone.c:809
+#: builtin/stash.c:264
+msgid "unable to write new index file"
+msgstr "không thể ghi tập tin lưu bảng mục lục mới"
 
-#: ref-filter.c:35 wt-status.c:1850
-msgid "gone"
-msgstr "đã ra đi"
+#: merge-recursive.c:367
+msgid "(bad commit)\n"
+msgstr "(commit sai)\n"
 
-#: ref-filter.c:36
+#: merge-recursive.c:390
 #, c-format
-msgid "ahead %d"
-msgstr "phía trước %d"
+msgid "add_cacheinfo failed for path '%s'; merge aborting."
+msgstr "addinfo_cache gặp lỗi đối với đường dẫn “%s”; việc hòa trộn bị bãi bỏ."
 
-#: ref-filter.c:37
+#: merge-recursive.c:399
 #, c-format
-msgid "behind %d"
-msgstr "đằng sau %d"
+msgid "add_cacheinfo failed to refresh for path '%s'; merge aborting."
+msgstr ""
+"addinfo_cache gặp lỗi khi làm mới đối với đường dẫn “%s”; việc hòa trộn bị "
+"bãi bỏ."
 
-#: ref-filter.c:38
+#: merge-recursive.c:885
 #, c-format
-msgid "ahead %d, behind %d"
-msgstr "trước %d, sau %d"
+msgid "failed to create path '%s'%s"
+msgstr "gặp lỗi khi tạo đường dẫn “%s”%s"
 
-#: ref-filter.c:121
+#: merge-recursive.c:896
 #, c-format
-msgid "expected format: %%(color:<color>)"
-msgstr "cần định dạng: %%(color:<color>)"
+msgid "Removing %s to make room for subdirectory\n"
+msgstr "Gỡ bỏ %s để tạo chỗ (room) cho thư mục con\n"
 
-#: ref-filter.c:123
-#, c-format
-msgid "unrecognized color: %%(color:%s)"
-msgstr "không nhận ra màu: %%(màu:%s)"
+#: merge-recursive.c:910 merge-recursive.c:929
+msgid ": perhaps a D/F conflict?"
+msgstr ": có lẽ là một xung đột D/F?"
 
-#: ref-filter.c:145
+#: merge-recursive.c:919
 #, c-format
-msgid "Integer value expected refname:lstrip=%s"
-msgstr "Giá trị nguyên cần tên tham chiếu:lstrip=%s"
+msgid "refusing to lose untracked file at '%s'"
+msgstr "từ chối đóng tập tin không được theo dõi tại “%s”"
 
-#: ref-filter.c:149
+#: merge-recursive.c:960 builtin/cat-file.c:41
 #, c-format
-msgid "Integer value expected refname:rstrip=%s"
-msgstr "Giá trị nguyên cần tên tham chiếu:rstrip=%s"
+msgid "cannot read object %s '%s'"
+msgstr "không thể đọc đối tượng %s “%s”"
 
-#: ref-filter.c:151
+#: merge-recursive.c:965
 #, c-format
-msgid "unrecognized %%(%s) argument: %s"
-msgstr "đối số không được thừa nhận %%(%s): %s"
+msgid "blob expected for %s '%s'"
+msgstr "mong đợi đối tượng blob cho %s “%s”"
 
-#: ref-filter.c:206
+#: merge-recursive.c:990
 #, c-format
-msgid "%%(body) does not take arguments"
-msgstr "%%(body) không nhận các đối số"
+msgid "failed to open '%s': %s"
+msgstr "gặp lỗi khi mở “%s”: %s"
 
-#: ref-filter.c:215
+#: merge-recursive.c:1001
 #, c-format
-msgid "%%(subject) does not take arguments"
-msgstr "%%(subject) không nhận các đối số"
+msgid "failed to symlink '%s': %s"
+msgstr "gặp lỗi khi tạo liên kết mềm (symlink) “%s”: %s"
 
-#: ref-filter.c:235
+#: merge-recursive.c:1006
 #, c-format
-msgid "unknown %%(trailers) argument: %s"
-msgstr "không hiểu tham số %%(trailers): %s"
+msgid "do not know what to do with %06o %s '%s'"
+msgstr "không hiểu phải làm gì với %06o %s “%s”"
 
-#: ref-filter.c:264
+#: merge-recursive.c:1199
 #, c-format
-msgid "positive value expected contents:lines=%s"
-msgstr "cần nội dung mang giá trị dương:lines=%s"
+msgid "Failed to merge submodule %s (not checked out)"
+msgstr "Gặp lỗi khi hòa trộn mô-đun-con “%s” (không lấy ra được)"
 
-#: ref-filter.c:266
+#: merge-recursive.c:1206
 #, c-format
-msgid "unrecognized %%(contents) argument: %s"
-msgstr "đối số không được thừa nhận %%(contents): %s"
+msgid "Failed to merge submodule %s (commits not present)"
+msgstr "Gặp lỗi khi hòa trộn mô-đun-con “%s” (lần chuyển giao không hiện diện)"
 
-#: ref-filter.c:281
+#: merge-recursive.c:1213
 #, c-format
-msgid "positive value expected objectname:short=%s"
-msgstr "cần nội dung mang giá trị dương:shot=%s"
+msgid "Failed to merge submodule %s (commits don't follow merge-base)"
+msgstr ""
+"Gặp lỗi khi hòa trộn mô-đun-con “%s” (lần chuyển giao không theo sau nền-hòa-"
+"trộn)"
 
-#: ref-filter.c:285
+#: merge-recursive.c:1221 merge-recursive.c:1233
 #, c-format
-msgid "unrecognized %%(objectname) argument: %s"
-msgstr "đối số không được thừa nhận %%(objectname): %s"
+msgid "Fast-forwarding submodule %s to the following commit:"
+msgstr "Chuyển-tiếp-nhanh mô-đun-con “%s” đến lần chuyển giao sau đây:"
 
-#: ref-filter.c:315
+#: merge-recursive.c:1224 merge-recursive.c:1236
 #, c-format
-msgid "expected format: %%(align:<width>,<position>)"
-msgstr "cần định dạng: %%(align:<width>,<position>)"
+msgid "Fast-forwarding submodule %s"
+msgstr "Chuyển-tiếp-nhanh mô-đun-con “%s”"
 
-#: ref-filter.c:327
+#: merge-recursive.c:1259
 #, c-format
-msgid "unrecognized position:%s"
-msgstr "vị trí không được thừa nhận:%s"
+msgid "Failed to merge submodule %s (merge following commits not found)"
+msgstr ""
+"Gặp lỗi khi hòa trộn mô-đun-con “%s” (không tìm thấy các lần chuyển giao "
+"theo sau hòa trộn)"
 
-#: ref-filter.c:334
+#: merge-recursive.c:1263
 #, c-format
-msgid "unrecognized width:%s"
-msgstr "chiều rộng không được thừa nhận:%s"
+msgid "Failed to merge submodule %s (not fast-forward)"
+msgstr "Gặp lỗi khi hòa trộn mô-đun-con “%s” (không chuyển tiếp nhanh được)"
 
-#: ref-filter.c:343
-#, c-format
-msgid "unrecognized %%(align) argument: %s"
-msgstr "đối số không được thừa nhận %%(align): %s"
+#: merge-recursive.c:1264
+msgid "Found a possible merge resolution for the submodule:\n"
+msgstr "Tìm thấy một giải pháp hòa trộn có thể cho mô-đun-con:\n"
 
-#: ref-filter.c:351
+#: merge-recursive.c:1267
 #, c-format
-msgid "positive width expected with the %%(align) atom"
-msgstr "cần giá trị độ rộng dương với nguyên tử %%(align)"
+msgid ""
+"If this is correct simply add it to the index for example\n"
+"by using:\n"
+"\n"
+"  git update-index --cacheinfo 160000 %s \"%s\"\n"
+"\n"
+"which will accept this suggestion.\n"
+msgstr ""
+"Nếu đây là đúng đơn giản thêm nó vào mục lục ví dụ\n"
+"bằng cách dùng:\n"
+"\n"
+"  git update-index --cacheinfo 160000 %s \"%s\"\n"
+"\n"
+"cái mà sẽ chấp nhận gợi ý này.\n"
 
-#: ref-filter.c:369
+#: merge-recursive.c:1276
 #, c-format
-msgid "unrecognized %%(if) argument: %s"
-msgstr "đối số không được thừa nhận %%(if): %s"
+msgid "Failed to merge submodule %s (multiple merges found)"
+msgstr "Gặp lỗi khi hòa trộn mô-đun-con “%s” (thấy nhiều hòa trộn đa trùng)"
 
-#: ref-filter.c:464
-#, c-format
-msgid "malformed field name: %.*s"
-msgstr "tên trường dị hình: %.*s"
+#: merge-recursive.c:1349
+msgid "Failed to execute internal merge"
+msgstr "Gặp lỗi khi thực hiện trộn nội bộ"
 
-#: ref-filter.c:491
+#: merge-recursive.c:1354
 #, c-format
-msgid "unknown field name: %.*s"
-msgstr "không hiểu tên trường: %.*s"
+msgid "Unable to add %s to database"
+msgstr "Không thể thêm %s vào cơ sở dữ liệu"
 
-#: ref-filter.c:608
+#: merge-recursive.c:1386
 #, c-format
-msgid "format: %%(if) atom used without a %%(then) atom"
-msgstr "định dạng: nguyên tử %%(if) được dùng mà không có nguyên tử %%(then)"
+msgid "Auto-merging %s"
+msgstr "Tự-động-hòa-trộn %s"
 
-#: ref-filter.c:671
+#: merge-recursive.c:1410
 #, c-format
-msgid "format: %%(then) atom used without an %%(if) atom"
-msgstr "định dạng: nguyên tử %%(then) được dùng mà không có nguyên tử %%(if)"
+msgid "Error: Refusing to lose untracked file at %s; writing to %s instead."
+msgstr ""
+"Lỗi: từ chối đóng tập tin không được theo dõi tại “%s”; thay vào đó ghi vào "
+"%s."
 
-#: ref-filter.c:673
+#: merge-recursive.c:1482
 #, c-format
-msgid "format: %%(then) atom used more than once"
-msgstr "định dạng: nguyên tử %%(then) được dùng nhiều hơn một lần"
+msgid ""
+"CONFLICT (%s/delete): %s deleted in %s and %s in %s. Version %s of %s left "
+"in tree."
+msgstr ""
+"XUNG ĐỘT (%s/xóa): %s bị xóa trong %s và %s trong %s. Phiên bản %s của %s "
+"còn lại trong cây (tree)."
 
-#: ref-filter.c:675
+#: merge-recursive.c:1487
 #, c-format
-msgid "format: %%(then) atom used after %%(else)"
-msgstr "định dạng: nguyên tử %%(then) được dùng sau %%(else)"
+msgid ""
+"CONFLICT (%s/delete): %s deleted in %s and %s to %s in %s. Version %s of %s "
+"left in tree."
+msgstr ""
+"XUNG ĐỘT (%s/xóa): %s bị xóa trong %s và %s đến %s trong %s. Phiên bản %s "
+"của %s còn lại trong cây (tree)."
 
-#: ref-filter.c:703
+#: merge-recursive.c:1494
 #, c-format
-msgid "format: %%(else) atom used without an %%(if) atom"
-msgstr "định dạng: nguyên tử %%(else) được dùng mà không có nguyên tử %%(if)"
+msgid ""
+"CONFLICT (%s/delete): %s deleted in %s and %s in %s. Version %s of %s left "
+"in tree at %s."
+msgstr ""
+"XUNG ĐỘT (%s/xóa): %s bị xóa trong %s và %s trong %s. Phiên bản %s của %s "
+"còn lại trong cây (tree) tại %s."
 
-#: ref-filter.c:705
+#: merge-recursive.c:1499
 #, c-format
-msgid "format: %%(else) atom used without a %%(then) atom"
-msgstr "định dạng: nguyên tử %%(else) được dùng mà không có nguyên tử %%(then)"
+msgid ""
+"CONFLICT (%s/delete): %s deleted in %s and %s to %s in %s. Version %s of %s "
+"left in tree at %s."
+msgstr ""
+"XUNG ĐỘT (%s/xóa): %s bị xóa trong %s và %s đến %s trong %s. Phiên bản %s "
+"của %s còn lại trong cây (tree) tại %s."
 
-#: ref-filter.c:707
-#, c-format
-msgid "format: %%(else) atom used more than once"
-msgstr "định dạng: nguyên tử %%(else) được dùng nhiều hơn một lần"
+#: merge-recursive.c:1534
+msgid "rename"
+msgstr "đổi tên"
 
-#: ref-filter.c:722
-#, c-format
-msgid "format: %%(end) atom used without corresponding atom"
-msgstr "định dạng: nguyên tử %%(end) được dùng mà không có nguyên tử tương ứng"
+#: merge-recursive.c:1534
+msgid "renamed"
+msgstr "đã đổi tên"
 
-#: ref-filter.c:779
+#: merge-recursive.c:1614 merge-recursive.c:2530 merge-recursive.c:3175
 #, c-format
-msgid "malformed format string %s"
-msgstr "chuỗi định dạng dị hình %s"
+msgid "Refusing to lose dirty file at %s"
+msgstr "Từ chối đóng tập tin không được theo dõi tại “%s”"
 
-#: ref-filter.c:1387
+#: merge-recursive.c:1624
 #, c-format
-msgid "(no branch, rebasing %s)"
-msgstr "(không nhánh, đang cải tổ %s)"
+msgid "Refusing to lose untracked file at %s, even though it's in the way."
+msgstr ""
+"Từ chối đóng tập tin không được theo dõi tại “%s”, ngay cả khi nó ở trên "
+"đường."
 
-#: ref-filter.c:1390
+#: merge-recursive.c:1682
 #, c-format
-msgid "(no branch, rebasing detached HEAD %s)"
-msgstr "(không nhánh, đang cải tổ HEAD %s đã tách rời)"
+msgid "CONFLICT (rename/add): Rename %s->%s in %s.  Added %s in %s"
+msgstr ""
+"XUNG ĐỘT (đổi-tên/thêm): Đổi tên %s->%s trong %s. %s được thêm trong %s"
 
-#: ref-filter.c:1393
+#: merge-recursive.c:1713
 #, c-format
-msgid "(no branch, bisect started on %s)"
-msgstr "(không nhánh, di chuyển nửa bước được bắt đầu tại %s)"
+msgid "%s is a directory in %s adding as %s instead"
+msgstr "%s là một thư mục trong %s thay vào đó thêm vào như là %s"
 
-#. TRANSLATORS: make sure this matches "HEAD
-#. detached at " in wt-status.c
-#.
-#: ref-filter.c:1401
+#: merge-recursive.c:1718
 #, c-format
-msgid "(HEAD detached at %s)"
-msgstr "(HEAD được tách rời tại %s)"
+msgid "Refusing to lose untracked file at %s; adding as %s instead"
+msgstr ""
+"Từ chối đóng tập tin không được theo dõi tại “%s”; thay vào đó đang thêm "
+"thành %s"
 
-#. TRANSLATORS: make sure this matches "HEAD
-#. detached from " in wt-status.c
-#.
-#: ref-filter.c:1408
+#: merge-recursive.c:1737
 #, c-format
-msgid "(HEAD detached from %s)"
-msgstr "(HEAD được tách rời từ %s)"
-
-#: ref-filter.c:1412
-msgid "(no branch)"
-msgstr "(không nhánh)"
+msgid ""
+"CONFLICT (rename/rename): Rename \"%s\"->\"%s\" in branch \"%s\" rename \"%s"
+"\"->\"%s\" in \"%s\"%s"
+msgstr ""
+"XUNG ĐỘT (đổi-tên/đổi-tên): Đổi tên \"%s\"->\"%s\" trong nhánh \"%s\" đổi "
+"tên \"%s\"->\"%s\" trong \"%s\"%s"
 
-#: ref-filter.c:1442
-#, c-format
-msgid "missing object %s for %s"
-msgstr "thiếu đối tượng %s cho %s"
+#: merge-recursive.c:1742
+msgid " (left unresolved)"
+msgstr " (cần giải quyết)"
 
-#: ref-filter.c:1445
+#: merge-recursive.c:1851
 #, c-format
-msgid "parse_object_buffer failed on %s for %s"
-msgstr "parse_object_buffer gặp lỗi trên %s cho %s"
+msgid "CONFLICT (rename/rename): Rename %s->%s in %s. Rename %s->%s in %s"
+msgstr ""
+"XUNG ĐỘT (đổi-tên/đổi-tên): Đổi tên %s->%s trong %s. Đổi tên %s->%s trong %s"
 
-#: ref-filter.c:1902
+#: merge-recursive.c:2114
 #, c-format
-msgid "malformed object at '%s'"
-msgstr "đối tượng dị hình tại “%s”"
-
-#: ref-filter.c:1984
+msgid ""
+"CONFLICT (directory rename split): Unclear where to place %s because "
+"directory %s was renamed to multiple other directories, with no destination "
+"getting a majority of the files."
+msgstr ""
+"XUNG ĐỘT: (thư mục đổi tên chia tách): Không rõ ràng để đặt địa điểm %s bởi "
+"vì thư mục %s đã bị đổi tên thành nhiều thư mục khác, với không đích đến "
+"nhận một phần nhiều của các tập tin."
+
+#: merge-recursive.c:2146
 #, c-format
-msgid "ignoring ref with broken name %s"
-msgstr "đang lờ đi tham chiếu với tên hỏng %s"
+msgid ""
+"CONFLICT (implicit dir rename): Existing file/dir at %s in the way of "
+"implicit directory rename(s) putting the following path(s) there: %s."
+msgstr ""
+"XUNG ĐỘT: (ngầm đổi tên thư mục): Tập tin/thư mục đã sẵn có tại %s theo cách "
+"của các đổi tên thư mục ngầm đặt (các) đường dẫn sau ở đây: %s."
 
-#: ref-filter.c:1989
+#: merge-recursive.c:2156
 #, c-format
-msgid "ignoring broken ref %s"
-msgstr "đang lờ đi tham chiếu hỏng %s"
+msgid ""
+"CONFLICT (implicit dir rename): Cannot map more than one path to %s; "
+"implicit directory renames tried to put these paths there: %s"
+msgstr ""
+"XUNG ĐỘT: (ngầm đổi tên thư mục): Không thể ánh xạ một đường dẫn thành %s; "
+"các đổi tên thư mục ngầm cố đặt các đường dẫn ở đây: %s"
 
-#: ref-filter.c:2261
+#: merge-recursive.c:2248
 #, c-format
-msgid "format: %%(end) atom missing"
-msgstr "định dạng: thiếu nguyên tử %%(end)"
+msgid ""
+"CONFLICT (rename/rename): Rename directory %s->%s in %s. Rename directory %s-"
+">%s in %s"
+msgstr ""
+"XUNG ĐỘT (đổi-tên/đổi-tên): Đổi tên thư mục %s->%s trong %s. Đổi tên thư mục "
+"%s->%s trong %s"
 
-#: ref-filter.c:2365
+#: merge-recursive.c:2493
 #, c-format
-msgid "malformed object name %s"
-msgstr "tên đối tượng dị hình %s"
+msgid ""
+"WARNING: Avoiding applying %s -> %s rename to %s, because %s itself was "
+"renamed."
+msgstr ""
+"CẢNH BÁO: tránh áp dụng %s -> %s đổi thên thành %s, bởi vì bản thân %s cũng "
+"bị đổi tên."
 
-#: remote.c:605
+#: merge-recursive.c:3019
 #, c-format
-msgid "Cannot fetch both %s and %s to %s"
-msgstr "Không thể lấy về cả %s và %s cho %s"
+msgid "cannot read object %s"
+msgstr "không thể đọc đối tượng %s"
 
-#: remote.c:609
+#: merge-recursive.c:3022
 #, c-format
-msgid "%s usually tracks %s, not %s"
-msgstr "%s thường theo dõi %s, không phải %s"
+msgid "object %s is not a blob"
+msgstr "đối tượng %s không phải là một blob"
 
-#: remote.c:613
+#: merge-recursive.c:3086
+msgid "modify"
+msgstr "sửa đổi"
+
+#: merge-recursive.c:3086
+msgid "modified"
+msgstr "đã sửa"
+
+#: merge-recursive.c:3098
+msgid "content"
+msgstr "nội dung"
+
+#: merge-recursive.c:3102
+msgid "add/add"
+msgstr "thêm/thêm"
+
+#: merge-recursive.c:3125
 #, c-format
-msgid "%s tracks both %s and %s"
-msgstr "%s theo dõi cả %s và %s"
+msgid "Skipped %s (merged same as existing)"
+msgstr "Đã bỏ qua %s (đã có sẵn lần hòa trộn này)"
 
-#: remote.c:621
-msgid "Internal error"
-msgstr "Lỗi nội bộ"
+#: merge-recursive.c:3147 git-submodule.sh:993
+msgid "submodule"
+msgstr "mô-đun-con"
 
-#: remote.c:1534 remote.c:1635
-msgid "HEAD does not point to a branch"
-msgstr "HEAD không chỉ đến một nhánh nào cả"
+#: merge-recursive.c:3148
+#, c-format
+msgid "CONFLICT (%s): Merge conflict in %s"
+msgstr "XUNG ĐỘT (%s): Xung đột hòa trộn trong %s"
 
-#: remote.c:1543
+#: merge-recursive.c:3178
 #, c-format
-msgid "no such branch: '%s'"
-msgstr "không có nhánh nào như thế: “%s”"
+msgid "Adding as %s instead"
+msgstr "Thay vào đó thêm vào %s"
 
-#: remote.c:1546
+#: merge-recursive.c:3261
 #, c-format
-msgid "no upstream configured for branch '%s'"
-msgstr "không có thượng nguồn được cấu hình cho nhánh “%s”"
+msgid ""
+"Path updated: %s added in %s inside a directory that was renamed in %s; "
+"moving it to %s."
+msgstr ""
+"Đường dẫn đã được cập nhật: %s được thêm vào trong %s bên trong một thư mục "
+"đã được đổi tên trong %s; di chuyển nó đến %s."
 
-#: remote.c:1552
+#: merge-recursive.c:3264
 #, c-format
-msgid "upstream branch '%s' not stored as a remote-tracking branch"
+msgid ""
+"CONFLICT (file location): %s added in %s inside a directory that was renamed "
+"in %s, suggesting it should perhaps be moved to %s."
 msgstr ""
-"nhánh thượng nguồn “%s” không được lưu lại như là một nhánh theo dõi máy chủ"
+"XUNG ĐỘT (vị trí tệp): %s được thêm vào trong %s trong một thư mục đã được "
+"đổi tên thành %s, đoán là nó nên được di chuyển đến %s."
 
-#: remote.c:1567
+#: merge-recursive.c:3268
 #, c-format
-msgid "push destination '%s' on remote '%s' has no local tracking branch"
-msgstr "đẩy lên đích “%s” trên máy chủ “%s” không có nhánh theo dõi nội bộ"
+msgid ""
+"Path updated: %s renamed to %s in %s, inside a directory that was renamed in "
+"%s; moving it to %s."
+msgstr ""
+"Đường dẫn đã được cập nhật: %s được đổi tên thành %s trong %s, bên trong một "
+"thư mục đã được đổi tên trong %s; di chuyển nó đến %s."
 
-#: remote.c:1579
+#: merge-recursive.c:3271
 #, c-format
-msgid "branch '%s' has no remote for pushing"
-msgstr "nhánh “%s” không có máy chủ để đẩy lên"
+msgid ""
+"CONFLICT (file location): %s renamed to %s in %s, inside a directory that "
+"was renamed in %s, suggesting it should perhaps be moved to %s."
+msgstr ""
+"XUNG ĐỘT (vị trí tệp): %s được đổi tên thành %s trong %s, bên trong một thư "
+"mục đã được đổi tên thành %s, đoán là nó nên được di chuyển đến %s."
 
-#: remote.c:1589
+#: merge-recursive.c:3385
 #, c-format
-msgid "push refspecs for '%s' do not include '%s'"
-msgstr "đẩy refspecs cho “%s” không bao gồm “%s”"
+msgid "Removing %s"
+msgstr "Đang xóa %s"
 
-#: remote.c:1602
-msgid "push has no destination (push.default is 'nothing')"
-msgstr "đẩy lên mà không có đích (push.default là “nothing”)"
+#: merge-recursive.c:3408
+msgid "file/directory"
+msgstr "tập-tin/thư-mục"
 
-#: remote.c:1624
-msgid "cannot resolve 'simple' push to a single destination"
-msgstr "không thể phân giải đẩy “đơn giản” đến một đích đơn"
+#: merge-recursive.c:3413
+msgid "directory/file"
+msgstr "thư-mục/tập-tin"
 
-#: remote.c:1939
+#: merge-recursive.c:3420
 #, c-format
-msgid "Your branch is based on '%s', but the upstream is gone.\n"
+msgid "CONFLICT (%s): There is a directory with name %s in %s. Adding %s as %s"
 msgstr ""
-"Nhánh của bạn dựa trên cơ sở là “%s”, nhưng trên thượng nguồn không còn.\n"
-
-#: remote.c:1943
-msgid "  (use \"git branch --unset-upstream\" to fixup)\n"
-msgstr "   (dùng \" git branch --unset-upstream\" để sửa)\n"
+"XUNG ĐỘT (%s): Ở đây không có thư mục nào có tên %s trong %s. Thêm %s như là "
+"%s"
 
-#: remote.c:1946
+#: merge-recursive.c:3429
 #, c-format
-msgid "Your branch is up to date with '%s'.\n"
-msgstr "Nhánh của bạn đã cập nhật với “%s”.\n"
+msgid "Adding %s"
+msgstr "Thêm \"%s\""
 
-#: remote.c:1950
+#: merge-recursive.c:3438
 #, c-format
-msgid "Your branch and '%s' refer to different commits.\n"
-msgstr "Nhánh của bạn và “%s” tham chiếu đến các lần chuyển giao khác nhau.\n"
+msgid "CONFLICT (add/add): Merge conflict in %s"
+msgstr "XUNG ĐỘT (thêm/thêm): Xung đột hòa trộn trong %s"
 
-#: remote.c:1953
-#, c-format
-msgid "  (use \"%s\" for details)\n"
-msgstr "  (dùng \"%s\" để biết thêm chi tiết)\n"
+#: merge-recursive.c:3482
+msgid "Already up to date!"
+msgstr "Đã cập nhật rồi!"
 
-#: remote.c:1957
+#: merge-recursive.c:3491
 #, c-format
-msgid "Your branch is ahead of '%s' by %d commit.\n"
-msgid_plural "Your branch is ahead of '%s' by %d commits.\n"
-msgstr[0] "Nhánh của bạn đứng trước “%s” %d lần chuyển giao.\n"
+msgid "merging of trees %s and %s failed"
+msgstr "hòa trộn các cây %s và %s gặp lỗi"
 
-#: remote.c:1963
-msgid "  (use \"git push\" to publish your local commits)\n"
-msgstr "  (dùng \"git push\" để xuất bản các lần chuyển giao nội bộ của bạn)\n"
+#: merge-recursive.c:3595
+msgid "Merging:"
+msgstr "Đang trộn:"
 
-#: remote.c:1966
+#: merge-recursive.c:3608
 #, c-format
-msgid "Your branch is behind '%s' by %d commit, and can be fast-forwarded.\n"
-msgid_plural ""
-"Your branch is behind '%s' by %d commits, and can be fast-forwarded.\n"
-msgstr[0] ""
-"Nhánh của bạn đứng đằng sau “%s” %d lần chuyển giao, và có thể được chuyển-"
-"tiếp-nhanh.\n"
+msgid "found %u common ancestor:"
+msgid_plural "found %u common ancestors:"
+msgstr[0] "tìm thấy %u tổ tiên chung:"
 
-#: remote.c:1974
-msgid "  (use \"git pull\" to update your local branch)\n"
-msgstr "  (dùng \"git pull\" để cập nhật nhánh nội bộ của bạn)\n"
+#: merge-recursive.c:3658
+msgid "merge returned no commit"
+msgstr "hòa trộn không trả về lần chuyển giao nào"
 
-#: remote.c:1977
+#: merge-recursive.c:3717
 #, c-format
 msgid ""
-"Your branch and '%s' have diverged,\n"
-"and have %d and %d different commit each, respectively.\n"
-msgid_plural ""
-"Your branch and '%s' have diverged,\n"
-"and have %d and %d different commits each, respectively.\n"
-msgstr[0] ""
-"Nhánh của bạn và “%s” bị phân kỳ,\n"
-"và có %d và %d lần chuyển giao khác nhau cho từng cái,\n"
-"tương ứng với mỗi lần.\n"
-
-#: remote.c:1987
-msgid "  (use \"git pull\" to merge the remote branch into yours)\n"
+"Your local changes to the following files would be overwritten by merge:\n"
+"  %s"
 msgstr ""
-"  (dùng \"git pull\" để hòa trộn nhánh trên máy chủ vào trong nhánh của "
-"bạn)\n"
-
-#: revision.c:2289
-msgid "your current branch appears to be broken"
-msgstr "nhánh hiện tại của bạn có vẻ như bị hỏng"
+"Các thay đổi nội bộ của bạn với các tập tin sau đây sẽ bị ghi đè bởi lệnh "
+"hòa trộn:\n"
+"  %s"
 
-#: revision.c:2292
+#: merge-recursive.c:3814
 #, c-format
-msgid "your current branch '%s' does not have any commits yet"
-msgstr "nhánh hiện tại của bạn “%s” không có một lần chuyển giao nào cả"
-
-#: revision.c:2489
-msgid "--first-parent is incompatible with --bisect"
-msgstr "--first-parent xung khắc với --bisect"
+msgid "Could not parse object '%s'"
+msgstr "Không thể phân tích đối tượng “%s”"
 
-#: run-command.c:728
-msgid "open /dev/null failed"
-msgstr "gặp lỗi khi mở “/dev/null”"
+#: merge-recursive.c:3832 builtin/merge.c:694 builtin/merge.c:874
+msgid "Unable to write index."
+msgstr "Không thể ghi bảng mục lục."
 
-#: run-command.c:1271
+#: midx.c:68
 #, c-format
-msgid ""
-"The '%s' hook was ignored because it's not set as executable.\n"
-"You can disable this warning with `git config advice.ignoredHook false`."
-msgstr ""
-"Móc “%s” bị bỏ qua bởi vì nó không thể đặt là thực thi được.\n"
-"Bạn có thể tắt cảnh báo này bằng “git config advice.ignoredHook false“."
+msgid "multi-pack-index file %s is too small"
+msgstr "tập tin đồ thị multi-pack-index %s quá nhỏ"
 
-#: send-pack.c:141
-msgid "unexpected flush packet while reading remote unpack status"
-msgstr ""
-"gặp gói flush không cần trong khi đọc tình trạng giải nén gói trên máy chủ"
+#: midx.c:84
+#, c-format
+msgid "multi-pack-index signature 0x%08x does not match signature 0x%08x"
+msgstr "chữ ký multi-pack-index 0x%08x không khớp chữ ký 0x%08x"
 
-#: send-pack.c:143
+#: midx.c:89
 #, c-format
-msgid "unable to parse remote unpack status: %s"
-msgstr "không thể phân tích tình trạng unpack máy chủ: %s"
+msgid "multi-pack-index version %d not recognized"
+msgstr "không nhận ra phiên bản %d của multi-pack-index"
 
-#: send-pack.c:145
+#: midx.c:94
 #, c-format
-msgid "remote unpack failed: %s"
-msgstr "máy chủ gặp lỗi unpack: %s"
+msgid "hash version %u does not match"
+msgstr "phiên bản băm “%u” không khớp"
 
-#: send-pack.c:308
-msgid "failed to sign the push certificate"
-msgstr "gặp lỗi khi ký chứng thực đẩy"
+#: midx.c:108
+msgid "invalid chunk offset (too large)"
+msgstr "khoảng bù đoạn không hợp lệ (quá lớn)"
 
-#: send-pack.c:421
-msgid "the receiving end does not support --signed push"
-msgstr "kết thúc nhận không hỗ trợ đẩy --signed"
+#: midx.c:132
+msgid "terminating multi-pack-index chunk id appears earlier than expected"
+msgstr "mã mảnh kết thúc multi-pack-index xuất hiện sớm hơn bình thường"
 
-#: send-pack.c:423
-msgid ""
-"not sending a push certificate since the receiving end does not support --"
-"signed push"
-msgstr ""
-"đừng gửi giấy chứng nhận đẩy trước khi kết thúc nhận không hỗ trợ đẩy --"
-"signed"
+#: midx.c:145
+msgid "multi-pack-index missing required pack-name chunk"
+msgstr "multi-pack-index thiếu mảnh pack-name cần thiết"
 
-#: send-pack.c:435
-msgid "the receiving end does not support --atomic push"
-msgstr "kết thúc nhận không hỗ trợ đẩy --atomic"
+#: midx.c:147
+msgid "multi-pack-index missing required OID fanout chunk"
+msgstr "multi-pack-index thiếu mảnh OID fanout cần thiết"
 
-#: send-pack.c:440
-msgid "the receiving end does not support push options"
-msgstr "kết thúc nhận không hỗ trợ các tùy chọn của lệnh push"
+#: midx.c:149
+msgid "multi-pack-index missing required OID lookup chunk"
+msgstr "multi-pack-index thiếu mảnh OID lookup cần thiết"
+
+#: midx.c:151
+msgid "multi-pack-index missing required object offsets chunk"
+msgstr "multi-pack-index thiếu mảnh các khoảng bù đối tượng cần thiết"
 
-#: sequencer.c:175
+#: midx.c:165
 #, c-format
-msgid "invalid commit message cleanup mode '%s'"
-msgstr "chế độ dọn dẹp ghi chú các lần chuyển giao không hợp lệ “%s”"
+msgid "multi-pack-index pack names out of order: '%s' before '%s'"
+msgstr "các tên gói multi-pack-index không đúng thứ tự: “%s” trước “%s”"
 
-#: sequencer.c:275
+#: midx.c:210
 #, c-format
-msgid "could not delete '%s'"
-msgstr "không thể xóa bỏ “%s”"
+msgid "bad pack-int-id: %u (%u total packs)"
+msgstr "pack-int-id sai: %u (%u các gói tổng)"
 
-#: sequencer.c:301
-msgid "revert"
-msgstr "hoàn nguyên"
+#: midx.c:260
+msgid "multi-pack-index stores a 64-bit offset, but off_t is too small"
+msgstr "multi-pack-index lưu trữ một khoảng bù 64-bít, nhưng off_t là quá nhỏ"
 
-#: sequencer.c:303
-msgid "cherry-pick"
-msgstr "cherry-pick"
+#: midx.c:288
+msgid "error preparing packfile from multi-pack-index"
+msgstr "lỗi chuẩn bị tập tin gói từ multi-pack-index"
 
-#: sequencer.c:305
-msgid "rebase -i"
-msgstr "rebase -i"
+#: midx.c:472
+#, c-format
+msgid "failed to add packfile '%s'"
+msgstr "gặp lỗi khi thêm tập tin gói “%s”"
 
-#: sequencer.c:307
+#: midx.c:478
 #, c-format
-msgid "Unknown action: %d"
-msgstr "Không nhận ra thao tác: %d"
+msgid "failed to open pack-index '%s'"
+msgstr "gặp lỗi khi mở pack-index “%s”"
 
-#: sequencer.c:364
-msgid ""
-"after resolving the conflicts, mark the corrected paths\n"
-"with 'git add <paths>' or 'git rm <paths>'"
-msgstr ""
-"sau khi giải quyết các xung đột, đánh dấu đường dẫn đã sửa\n"
-"với lệnh “git add <đường_dẫn>” hoặc “git rm <đường_dẫn>”"
+#: midx.c:538
+#, c-format
+msgid "failed to locate object %d in packfile"
+msgstr "gặp lỗi khi phân bổ đối tượng “%d” trong tập tin gói"
 
-#: sequencer.c:367
-msgid ""
-"after resolving the conflicts, mark the corrected paths\n"
-"with 'git add <paths>' or 'git rm <paths>'\n"
-"and commit the result with 'git commit'"
-msgstr ""
-"sau khi giải quyết các xung đột, đánh dấu đường dẫn đã sửa\n"
-"với lệnh “git add <đường_dẫn>” hoặc “git rm <đường_dẫn>”\n"
-"và chuyển giao kết quả bằng lệnh “git commit”"
+#: midx.c:842
+msgid "Adding packfiles to multi-pack-index"
+msgstr "Đang thêm tập tin gói từ multi-pack-index"
 
-#: sequencer.c:380 sequencer.c:2468
+#: midx.c:875
 #, c-format
-msgid "could not lock '%s'"
-msgstr "không thể khóa “%s”"
+msgid "did not see pack-file %s to drop"
+msgstr "đã không thấy tập tin gói %s để mà xóa"
 
-#: sequencer.c:382 sequencer.c:2346 sequencer.c:2472 sequencer.c:2486
-#: sequencer.c:2694 sequencer.c:4336 sequencer.c:4399 wrapper.c:656
-#, c-format
-msgid "could not write to '%s'"
-msgstr "không thể ghi vào “%s”"
+#: midx.c:973
+msgid "Writing chunks to multi-pack-index"
+msgstr "Đang ghi các khúc vào multi-pack-index"
 
-#: sequencer.c:387
+#: midx.c:1052
 #, c-format
-msgid "could not write eol to '%s'"
-msgstr "không thể ghi eol vào “%s”"
+msgid "failed to clear multi-pack-index at %s"
+msgstr "gặp lỗi khi xóa multi-pack-index tại %s"
 
-#: sequencer.c:392 sequencer.c:2351 sequencer.c:2474 sequencer.c:2488
-#: sequencer.c:2702
-#, c-format
-msgid "failed to finalize '%s'"
-msgstr "gặp lỗi khi hoàn thành “%s”"
+#: midx.c:1108
+msgid "Looking for referenced packfiles"
+msgstr "Đang khóa cho các gói bị tham chiếu"
 
-#: sequencer.c:415 sequencer.c:804 sequencer.c:1493 sequencer.c:2371
-#: sequencer.c:2684 sequencer.c:2788 builtin/am.c:259 builtin/commit.c:727
-#: builtin/merge.c:1046
+#: midx.c:1123
 #, c-format
-msgid "could not read '%s'"
-msgstr "Không thể đọc “%s”."
+msgid ""
+"oid fanout out of order: fanout[%d] = %<PRIx32> > %<PRIx32> = fanout[%d]"
+msgstr "fanout cũ sai thứ tự: fanout[%d] = %<PRIx32> > %<PRIx32> = fanout[%d]"
+
+#: midx.c:1128
+msgid "Verifying OID order in multi-pack-index"
+msgstr "Thẩm tra thứ tự OID trong multi-pack-index"
 
-#: sequencer.c:441
+#: midx.c:1137
 #, c-format
-msgid "your local changes would be overwritten by %s."
-msgstr "các thay đổi nội bộ của bạn có thể bị ghi đè bởi lệnh %s."
+msgid "oid lookup out of order: oid[%d] = %s >= %s = oid[%d]"
+msgstr "lookup cũ sai thứ tự: oid[%d] = %s >= %s = oid[%d]"
 
-#: sequencer.c:445
-msgid "commit your changes or stash them to proceed."
-msgstr "chuyển giao các thay đổi của bạn hay tạm cất (stash) chúng để xử lý."
+#: midx.c:1157
+msgid "Sorting objects by packfile"
+msgstr "Đang sắp xếp các đối tượng theo tập tin gói"
 
-#: sequencer.c:474
+#: midx.c:1164
+msgid "Verifying object offsets"
+msgstr "Đang thẩm tra các khoảng bù đối tượng"
+
+#: midx.c:1180
 #, c-format
-msgid "%s: fast-forward"
-msgstr "%s: chuyển-tiếp-nhanh"
+msgid "failed to load pack entry for oid[%d] = %s"
+msgstr "gặp lỗi khi tải mục gói cho oid[%d] = %s"
 
-#. TRANSLATORS: %s will be "revert", "cherry-pick" or
-#. "rebase -i".
-#.
-#: sequencer.c:563
+#: midx.c:1186
 #, c-format
-msgid "%s: Unable to write new index file"
-msgstr "%s: Không thể ghi tập tin lưu bảng mục lục mới"
+msgid "failed to load pack-index for packfile %s"
+msgstr "gặp lỗi khi tải pack-index cho tập tin gói %s"
 
-#: sequencer.c:579
-msgid "unable to update cache tree"
-msgstr "không thể cập nhật cây bộ nhớ đệm"
-
-#: sequencer.c:592
-msgid "could not resolve HEAD commit"
-msgstr "không thể phân giải lần chuyển giao HEAD"
-
-#: sequencer.c:749
+#: midx.c:1195
 #, c-format
-msgid ""
-"you have staged changes in your working tree\n"
-"If these changes are meant to be squashed into the previous commit, run:\n"
-"\n"
-"  git commit --amend %s\n"
-"\n"
-"If they are meant to go into a new commit, run:\n"
-"\n"
-"  git commit %s\n"
-"\n"
-"In both cases, once you're done, continue with:\n"
-"\n"
-"  git rebase --continue\n"
-msgstr ""
-"bạn có các thay đổi so với trong bệ phóng trong thư mục làm việc của bạn.\n"
-"Nếu các thay đổi này là muốn squash vào lần chuyển giao kế trước, chạy:\n"
-"\n"
-"  git commit --amend %s\n"
-"\n"
-"Nếu chúng có ý là đi đến lần chuyển giao mới, thì chạy:\n"
-"\n"
-"  git commit %s\n"
-"\n"
-"Trong cả hai trường hợp, một khi bạn làm xong, tiếp tục bằng:\n"
-"\n"
-"  git rebase --continue\n"
-
-#: sequencer.c:818
-msgid "writing root commit"
-msgstr "ghi chuyển giao gốc"
-
-#: sequencer.c:1043
-msgid "'prepare-commit-msg' hook failed"
-msgstr "móc “prepare-commit-msg” bị lỗi"
-
-#: sequencer.c:1050
-msgid ""
-"Your name and email address were configured automatically based\n"
-"on your username and hostname. Please check that they are accurate.\n"
-"You can suppress this message by setting them explicitly. Run the\n"
-"following command and follow the instructions in your editor to edit\n"
-"your configuration file:\n"
-"\n"
-"    git config --global --edit\n"
-"\n"
-"After doing this, you may fix the identity used for this commit with:\n"
-"\n"
-"    git commit --amend --reset-author\n"
-msgstr ""
-"Tên và địa chỉ thư điện tử của bạn được cấu hình một cách tự động trên cơ "
-"sở\n"
-"tài khoản và địa chỉ máy chủ của bạn. Xin hãy kiểm tra xem chúng có chính "
-"xác không.\n"
-"Bạn có thể chặn những thông báo kiểu này bằng cách cài đặt các thông tin "
-"trên\n"
-"một cách rõ ràng. Chạy lệnh sau đây là theo các hướng dẫn trong bộ soạn "
-"thảo\n"
-"để chỉnh sửa tập tin cấu hình của mình:\n"
-"\n"
-"    git config --global --edit\n"
-"\n"
-"Sau khi thực hiện xong, bạn có thể sửa chữa định danh được sử dụng cho\n"
-"lần chuyển giao này với lệnh:\n"
-"\n"
-"    git commit --amend --reset-author\n"
-
-#: sequencer.c:1063
-msgid ""
-"Your name and email address were configured automatically based\n"
-"on your username and hostname. Please check that they are accurate.\n"
-"You can suppress this message by setting them explicitly:\n"
-"\n"
-"    git config --global user.name \"Your Name\"\n"
-"    git config --global user.email you@example.com\n"
-"\n"
-"After doing this, you may fix the identity used for this commit with:\n"
-"\n"
-"    git commit --amend --reset-author\n"
+msgid "incorrect object offset for oid[%d] = %s: %<PRIx64> != %<PRIx64>"
 msgstr ""
-"Tên và địa chỉ thư điện tử của bạn được cấu hình một cách tự động trên cơ "
-"sở\n"
-"tài khoản và địa chỉ máy chủ của bạn. Xin hãy kiểm tra xem chúng có chính "
-"xác không.\n"
-"Bạn có thể chặn những thông báo kiểu này bằng cách cài đặt các thông tin "
-"trên một cách rõ ràng:\n"
-"\n"
-"    git config --global user.name \"Tên của bạn\"\n"
-"    git config --global user.email you@example.com\n"
-"\n"
-"Sau khi thực hiện xong, bạn có thể sửa chữa định danh được sử dụng cho lần "
-"chuyển giao này với lệnh:\n"
-"\n"
-"    git commit --amend --reset-author\n"
+"khoảng bù đối tượng không đúng cho oid[%d] = %s: %<PRIx64> != %<PRIx64>"
 
-#: sequencer.c:1103
-msgid "couldn't look up newly created commit"
-msgstr "không thể tìm thấy lần chuyển giao mới hơn đã được tạo"
+#: midx.c:1220
+msgid "Counting referenced objects"
+msgstr "Đang đếm các đối tượng được tham chiếu"
 
-#: sequencer.c:1105
-msgid "could not parse newly created commit"
-msgstr ""
-"không thể phân tích cú pháp của đối tượng chuyển giao mới hơn đã được tạo"
+#: midx.c:1230
+msgid "Finding and deleting unreferenced packfiles"
+msgstr "Đang tìm và xóa các gói không được tham chiếu"
 
-#: sequencer.c:1151
-msgid "unable to resolve HEAD after creating commit"
-msgstr "không thể phân giải HEAD sau khi tạo lần chuyển giao"
+#: midx.c:1388
+msgid "could not start pack-objects"
+msgstr "không thể lấy thông tin thống kê về các đối tượng gói"
 
-#: sequencer.c:1153
-msgid "detached HEAD"
-msgstr "đã rời khỏi HEAD"
+#: midx.c:1407
+msgid "could not finish pack-objects"
+msgstr "không thể hoàn thiện các đối tượng gói"
 
-#: sequencer.c:1157
-msgid " (root-commit)"
-msgstr " (root-commit)"
+#: name-hash.c:537
+#, c-format
+msgid "unable to create lazy_dir thread: %s"
+msgstr "không thể tạo tuyến lazy_dir: %s"
 
-#: sequencer.c:1178
-msgid "could not parse HEAD"
-msgstr "không thể phân tích HEAD"
+#: name-hash.c:559
+#, c-format
+msgid "unable to create lazy_name thread: %s"
+msgstr "không thể tạo tuyến lazy_name: %s"
 
-#: sequencer.c:1180
+#: name-hash.c:565
 #, c-format
-msgid "HEAD %s is not a commit!"
-msgstr "HEAD %s không phải là một lần chuyển giao!"
+msgid "unable to join lazy_name thread: %s"
+msgstr "không thể gia nhập tuyến lazy_name: %s"
 
-#: sequencer.c:1184 builtin/commit.c:1528
-msgid "could not parse HEAD commit"
-msgstr "không thể phân tích commit (lần chuyển giao) HEAD"
+#: notes-merge.c:277
+#, c-format
+msgid ""
+"You have not concluded your previous notes merge (%s exists).\n"
+"Please, use 'git notes merge --commit' or 'git notes merge --abort' to "
+"commit/abort the previous merge before you start a new notes merge."
+msgstr ""
+"Bạn đã chưa hoàn tất hòa trộn ghi chú trước đây (%s vẫn còn).\n"
+"Vui lòng dùng “git notes merge --commit” hay “git notes merge --abort” để "
+"chuyển giao hay bãi bỏ lần hòa trộn trước đây và bắt đầu một hòa trộn ghi "
+"chú mới."
 
-#: sequencer.c:1235 sequencer.c:1832
-msgid "unable to parse commit author"
-msgstr "không thể phân tích tác giả của lần chuyển giao"
+#: notes-merge.c:284
+#, c-format
+msgid "You have not concluded your notes merge (%s exists)."
+msgstr "Bạn chưa kết thúc việc hòa trộn ghi chú (%s vẫn tồn tại)."
 
-#: sequencer.c:1245 builtin/am.c:1630 builtin/merge.c:645
-msgid "git write-tree failed to write a tree"
-msgstr "lệnh git write-tree gặp lỗi khi ghi một cây"
+#: notes-utils.c:46
+msgid "Cannot commit uninitialized/unreferenced notes tree"
+msgstr ""
+"Không thể chuyển giao cây ghi chú chưa được khởi tạo hoặc không được tham "
+"chiếu"
 
-#: sequencer.c:1262 sequencer.c:1317
+#: notes-utils.c:105
 #, c-format
-msgid "unable to read commit message from '%s'"
-msgstr "không thể đọc phần chú thích (message) từ “%s”"
-
-#: sequencer.c:1284 builtin/am.c:1650 builtin/commit.c:1631 builtin/merge.c:825
-#: builtin/merge.c:850
-msgid "failed to write commit object"
-msgstr "gặp lỗi khi ghi đối tượng chuyển giao"
+msgid "Bad notes.rewriteMode value: '%s'"
+msgstr "Giá trị notes.rewriteMode sai: “%s”"
 
-#: sequencer.c:1344
+#: notes-utils.c:115
 #, c-format
-msgid "could not parse commit %s"
-msgstr "không thể phân tích lần chuyển giao %s"
+msgid "Refusing to rewrite notes in %s (outside of refs/notes/)"
+msgstr "Từ chối ghi đè ghi chú trong %s (nằm ngoài refs/notes/)"
 
-#: sequencer.c:1349
+#. TRANSLATORS: The first %s is the name of
+#. the environment variable, the second %s is
+#. its value.
+#.
+#: notes-utils.c:145
 #, c-format
-msgid "could not parse parent commit %s"
-msgstr "không thể phân tích lần chuyển giao cha mẹ “%s”"
+msgid "Bad %s value: '%s'"
+msgstr "Giá trị %s sai: “%s”"
 
-#: sequencer.c:1500 sequencer.c:1525
+#: object.c:53
 #, c-format
-msgid "This is a combination of %d commits."
-msgstr "Đây là tổ hợp của %d lần chuyển giao."
+msgid "invalid object type \"%s\""
+msgstr "kiểu đối tượng \"%s\" không hợp lệ"
 
-#: sequencer.c:1510 sequencer.c:4355
-msgid "need a HEAD to fixup"
-msgstr "cần một HEAD để sửa"
+#: object.c:173
+#, c-format
+msgid "object %s is a %s, not a %s"
+msgstr "đối tượng %s là một %s, không phải là một %s"
 
-#: sequencer.c:1512 sequencer.c:2729
-msgid "could not read HEAD"
-msgstr "không thể đọc HEAD"
+#: object.c:233
+#, c-format
+msgid "object %s has unknown type id %d"
+msgstr "đối tượng %s có mã kiểu %d chưa biết"
 
-#: sequencer.c:1514
-msgid "could not read HEAD's commit message"
-msgstr "không thể đọc phần chú thích (message) của HEAD"
+#: object.c:246
+#, c-format
+msgid "unable to parse object: %s"
+msgstr "không thể phân tích đối tượng: “%s”"
 
-#: sequencer.c:1520
+#: object.c:266 object.c:277
 #, c-format
-msgid "cannot write '%s'"
-msgstr "không thể ghi “%s”"
+msgid "hash mismatch %s"
+msgstr "mã băm không khớp %s"
 
-#: sequencer.c:1527 git-rebase--interactive.sh:457
-msgid "This is the 1st commit message:"
-msgstr "Đây là chú thích cho lần chuyển giao thứ nhất:"
+#: packfile.c:641
+msgid "offset before end of packfile (broken .idx?)"
+msgstr "vị trí tương đối trước điểm kết thúc của tập tin gói (.idx hỏng à?)"
 
-#: sequencer.c:1535
+#: packfile.c:1888
 #, c-format
-msgid "could not read commit message of %s"
-msgstr "không thể đọc phần chú thích (message) của %s"
+msgid "offset before start of pack index for %s (corrupt index?)"
+msgstr "vị trí tương đối nằm trước chỉ mục gói cho %s (mục lục bị hỏng à?)"
 
-#: sequencer.c:1542
+#: packfile.c:1892
 #, c-format
-msgid "This is the commit message #%d:"
-msgstr "Đây là chú thích cho lần chuyển giao thứ #%d:"
+msgid "offset beyond end of pack index for %s (truncated index?)"
+msgstr ""
+"vị trí tương đối vượt quá cuối của chỉ mục gói cho %s (mục lục bị cắt cụt à?)"
 
-#: sequencer.c:1548
+#: parse-options.c:38
 #, c-format
-msgid "The commit message #%d will be skipped:"
-msgstr "Chú thích cho lần chuyển giao thứ #%d sẽ bị bỏ qua:"
+msgid "%s requires a value"
+msgstr "“%s” yêu cầu một giá trị"
 
-#: sequencer.c:1553
+#: parse-options.c:73
 #, c-format
-msgid "unknown command: %d"
-msgstr "không hiểu câu lệnh %d"
-
-#: sequencer.c:1631
-msgid "your index file is unmerged."
-msgstr "tập tin lưu mục lục của bạn không được hòa trộn."
+msgid "%s is incompatible with %s"
+msgstr "%s là xung khắc với %s"
 
-#: sequencer.c:1638
-msgid "cannot fixup root commit"
-msgstr "không thể sửa chữa lần chuyển giao gốc"
+#: parse-options.c:78
+#, c-format
+msgid "%s : incompatible with something else"
+msgstr "%s : xung khắc với các cái khác"
 
-#: sequencer.c:1657
+#: parse-options.c:92 parse-options.c:96 parse-options.c:319
 #, c-format
-msgid "commit %s is a merge but no -m option was given."
-msgstr "lần chuyển giao %s là một lần hòa trộn nhưng không đưa ra tùy chọn -m."
+msgid "%s takes no value"
+msgstr "%s k nhận giá trị"
 
-#: sequencer.c:1665
+#: parse-options.c:94
 #, c-format
-msgid "commit %s does not have parent %d"
-msgstr "lần chuyển giao %s không có cha mẹ %d"
+msgid "%s isn't available"
+msgstr "%s không sẵn có"
 
-#: sequencer.c:1669
+#: parse-options.c:219
 #, c-format
-msgid "mainline was specified but commit %s is not a merge."
-msgstr ""
-"luồng chính đã được chỉ ra nhưng lần chuyển giao %s không phải là một lần "
-"hòa trộn."
+msgid "%s expects a non-negative integer value with an optional k/m/g suffix"
+msgstr "%s cần một giá trị dạng số không âm với một hậu tố tùy chọn k/m/g"
 
-#: sequencer.c:1675
+#: parse-options.c:389
 #, c-format
-msgid "cannot get commit message for %s"
-msgstr "không thể lấy ghi chú lần chuyển giao cho %s"
+msgid "ambiguous option: %s (could be --%s%s or --%s%s)"
+msgstr "tùy chọn chưa rõ rang: %s (nên là --%s%s hay --%s%s)"
 
-#. TRANSLATORS: The first %s will be a "todo" command like
-#. "revert" or "pick", the second %s a SHA1.
-#: sequencer.c:1694
+#: parse-options.c:423 parse-options.c:431
 #, c-format
-msgid "%s: cannot parse parent commit %s"
-msgstr "%s: không thể phân tích lần chuyển giao mẹ của %s"
+msgid "did you mean `--%s` (with two dashes ?)"
+msgstr "có phải ý bạn là “--%s“ (với hai dấu gạch ngang?)"
 
-#: sequencer.c:1759
+#: parse-options.c:860
 #, c-format
-msgid "could not rename '%s' to '%s'"
-msgstr "không thể đổi tên “%s” thành “%s”"
+msgid "unknown option `%s'"
+msgstr "không hiểu tùy chọn “%s”"
 
-#: sequencer.c:1813
+#: parse-options.c:862
 #, c-format
-msgid "could not revert %s... %s"
-msgstr "không thể hoàn nguyên %s… %s"
+msgid "unknown switch `%c'"
+msgstr "không hiểu tùy chọn “%c”"
 
-#: sequencer.c:1814
+#: parse-options.c:864
 #, c-format
-msgid "could not apply %s... %s"
-msgstr "không thể áp dụng miếng vá %s… %s"
+msgid "unknown non-ascii option in string: `%s'"
+msgstr "không hiểu tùy chọn non-ascii trong chuỗi: “%s”"
 
-#: sequencer.c:1864
-msgid "empty commit set passed"
-msgstr "lần chuyển giao trống rỗng đặt là hợp quy cách"
+#: parse-options.c:888
+msgid "..."
+msgstr "…"
 
-#: sequencer.c:1874
+#: parse-options.c:907
 #, c-format
-msgid "git %s: failed to read the index"
-msgstr "git %s: gặp lỗi đọc bảng mục lục"
+msgid "usage: %s"
+msgstr "cách dùng: %s"
 
-#: sequencer.c:1881
+#. TRANSLATORS: the colon here should align with the
+#. one in "usage: %s" translation.
+#.
+#: parse-options.c:913
 #, c-format
-msgid "git %s: failed to refresh the index"
-msgstr "git %s: gặp lỗi khi làm tươi mới bảng mục lục"
+msgid "   or: %s"
+msgstr "     hoặc: %s"
 
-#: sequencer.c:1961
+#: parse-options.c:916
 #, c-format
-msgid "%s does not accept arguments: '%s'"
-msgstr "%s không nhận các đối số: “%s”"
+msgid "    %s"
+msgstr "    %s"
+
+#: parse-options.c:955
+msgid "-NUM"
+msgstr "-SỐ"
 
-#: sequencer.c:1970
+#: parse-options.c:969
 #, c-format
-msgid "missing arguments for %s"
-msgstr "thiếu đối số cho %s"
+msgid "alias of --%s"
+msgstr "bí danh của --%s"
 
-#: sequencer.c:2029
+#: parse-options-cb.c:20 parse-options-cb.c:24
 #, c-format
-msgid "invalid line %d: %.*s"
-msgstr "dòng không hợp lệ %d: %.*s"
+msgid "option `%s' expects a numerical value"
+msgstr "tùy chọn “%s” cần một giá trị bằng số"
 
-#: sequencer.c:2037
+#: parse-options-cb.c:41
 #, c-format
-msgid "cannot '%s' without a previous commit"
-msgstr "không thể “%s” thể mà không có lần chuyển giao kế trước"
+msgid "malformed expiration date '%s'"
+msgstr "ngày tháng hết hạn dị hình “%s”"
 
-#: sequencer.c:2085 sequencer.c:4138 sequencer.c:4173
+#: parse-options-cb.c:54
 #, c-format
-msgid "could not read '%s'."
-msgstr "không thể đọc “%s”."
+msgid "option `%s' expects \"always\", \"auto\", or \"never\""
+msgstr "tùy chọn “%s” cần \"always\", \"auto\", hoặc \"never\""
 
-#: sequencer.c:2108
-msgid "please fix this using 'git rebase --edit-todo'."
-msgstr "vui lòng sửa lỗi này bằng cách dùng “git rebase --edit-todo”."
+#: parse-options-cb.c:130 parse-options-cb.c:147
+#, c-format
+msgid "malformed object name '%s'"
+msgstr "tên đối tượng dị hình “%s”"
 
-#: sequencer.c:2110
+#: path.c:915
 #, c-format
-msgid "unusable instruction sheet: '%s'"
-msgstr "bảng chỉ thị không thể dùng được: %s"
+msgid "Could not make %s writable by group"
+msgstr "Không thể làm %s được ghi bởi nhóm"
 
-#: sequencer.c:2115
-msgid "no commits parsed."
-msgstr "không có lần chuyển giao nào được phân tích."
+#: pathspec.c:130
+msgid "Escape character '\\' not allowed as last character in attr value"
+msgstr ""
+"Ký tự thoát chuỗi “\\” không được phép là ký tự cuối trong giá trị thuộc tính"
 
-#: sequencer.c:2126
-msgid "cannot cherry-pick during a revert."
-msgstr "không thể cherry-pick trong khi hoàn nguyên."
+#: pathspec.c:148
+msgid "Only one 'attr:' specification is allowed."
+msgstr "Chỉ có một đặc tả “attr:” là được phép."
 
-#: sequencer.c:2128
-msgid "cannot revert during a cherry-pick."
-msgstr "không thể thực hiện việc hoàn nguyên trong khi đang cherry-pick."
+#: pathspec.c:151
+msgid "attr spec must not be empty"
+msgstr "đặc tả attr phải không được để trống"
 
-#: sequencer.c:2195
+#: pathspec.c:194
 #, c-format
-msgid "invalid key: %s"
-msgstr "khóa không đúng: %s"
+msgid "invalid attribute name %s"
+msgstr "tên thuộc tính không hợp lệ %s"
 
-#: sequencer.c:2198
-#, c-format
-msgid "invalid value for %s: %s"
-msgstr "giá trị cho %s không hợp lệ: %s"
+#: pathspec.c:259
+msgid "global 'glob' and 'noglob' pathspec settings are incompatible"
+msgstr ""
+"các cài đặt đặc tả đường dẫn “glob” và “noglob” toàn cục là xung khắc nhau"
 
-#: sequencer.c:2269
-msgid "unusable squash-onto"
-msgstr "squash-onto không dùng được"
+#: pathspec.c:266
+msgid ""
+"global 'literal' pathspec setting is incompatible with all other global "
+"pathspec settings"
+msgstr ""
+"cài đặt đặc tả đường dẫn “literal” toàn cục là xung khắc với các cài đặt đặc "
+"tả đường dẫn toàn cục khác"
 
-#: sequencer.c:2285
+#: pathspec.c:306
+msgid "invalid parameter for pathspec magic 'prefix'"
+msgstr "tham số không hợp lệ cho “tiền tố” màu nhiệm đặc tả đường đẫn"
+
+#: pathspec.c:327
 #, c-format
-msgid "malformed options sheet: '%s'"
-msgstr "bảng tùy chọn dị hình: “%s”"
+msgid "Invalid pathspec magic '%.*s' in '%s'"
+msgstr "Số màu nhiệm đặc tả đường dẫn không hợp lệ “%.*s” trong “%s”"
 
-#: sequencer.c:2323
-msgid "a cherry-pick or revert is already in progress"
-msgstr "có một thao tác “cherry-pick” hoặc “revert” đang được thực hiện"
-
-#: sequencer.c:2324
-msgid "try \"git cherry-pick (--continue | --quit | --abort)\""
-msgstr "hãy thử \"git cherry-pick (--continue | --quit | --abort)\""
+#: pathspec.c:332
+#, c-format
+msgid "Missing ')' at the end of pathspec magic in '%s'"
+msgstr "Thiếu “)” tại cuối của số màu nhiệm đặc tả đường dẫn trong “%s”"
 
-#: sequencer.c:2327
+#: pathspec.c:370
 #, c-format
-msgid "could not create sequencer directory '%s'"
-msgstr "không thể tạo thư mục xếp dãy “%s”"
+msgid "Unimplemented pathspec magic '%c' in '%s'"
+msgstr "Chưa viết mã cho số màu nhiệm đặc tả đường dẫn “%c” trong “%s”"
 
-#: sequencer.c:2341
-msgid "could not lock HEAD"
-msgstr "không thể khóa HEAD"
+#: pathspec.c:429
+#, c-format
+msgid "%s: 'literal' and 'glob' are incompatible"
+msgstr "%s: “literal” và “glob” xung khắc nhau"
 
-#: sequencer.c:2396 sequencer.c:3403
-msgid "no cherry-pick or revert in progress"
-msgstr "không cherry-pick hay hoàn nguyên trong tiến trình"
+#: pathspec.c:442
+#, c-format
+msgid "%s: '%s' is outside repository"
+msgstr "%s: “%s” ngoài một kho chứa"
 
-#: sequencer.c:2398
-msgid "cannot resolve HEAD"
-msgstr "không thể phân giải HEAD"
+#: pathspec.c:516
+#, c-format
+msgid "'%s' (mnemonic: '%c')"
+msgstr "“%s” (mnemonic: “%c”)"
 
-#: sequencer.c:2400 sequencer.c:2435
-msgid "cannot abort from a branch yet to be born"
-msgstr "không thể hủy bỏ từ một nhánh mà nó còn chưa được tạo ra"
+#: pathspec.c:526
+#, c-format
+msgid "%s: pathspec magic not supported by this command: %s"
+msgstr "%s: số mầu nhiệm đặc tả đường dẫn chưa được hỗ trợ bởi lệnh này: %s"
 
-#: sequencer.c:2421 builtin/grep.c:720
+#: pathspec.c:593
 #, c-format
-msgid "cannot open '%s'"
-msgstr "không mở được “%s”"
+msgid "pathspec '%s' is beyond a symbolic link"
+msgstr "đặc tả đường dẫn “%s” vượt ra ngoài liên kết mềm"
 
-#: sequencer.c:2423
+#: pathspec.c:638
 #, c-format
-msgid "cannot read '%s': %s"
-msgstr "không thể đọc “%s”: %s"
+msgid "line is badly quoted: %s"
+msgstr "dòng được trích dẫn sai: %s"
 
-#: sequencer.c:2424
-msgid "unexpected end of file"
-msgstr "gặp kết thúc tập tin đột xuất"
+#: pkt-line.c:92
+msgid "unable to write flush packet"
+msgstr "không thể đẩy dữ liệu của gói lên đĩa"
 
-#: sequencer.c:2430
-#, c-format
-msgid "stored pre-cherry-pick HEAD file '%s' is corrupt"
-msgstr "tập tin HEAD “pre-cherry-pick” đã lưu “%s” bị hỏng"
+#: pkt-line.c:99
+msgid "unable to write delim packet"
+msgstr "không thể ghi gói delim"
 
-#: sequencer.c:2441
-msgid "You seem to have moved HEAD. Not rewinding, check your HEAD!"
-msgstr ""
-"Bạn có lẽ đã có HEAD đã bị di chuyển đi, Không thể tua, kiểm tra HEAD của "
-"bạn!"
+#: pkt-line.c:106
+msgid "flush packet write failed"
+msgstr "gặp lỗi khi ghi vào tập tin gói lúc đẩy dữ liệu lên bộ nhớ"
+
+#: pkt-line.c:146 pkt-line.c:232
+msgid "protocol error: impossibly long line"
+msgstr "lỗi giao thức: không thể làm được dòng dài"
+
+#: pkt-line.c:162 pkt-line.c:164
+msgid "packet write with format failed"
+msgstr "gặp lỗi khi ghi gói có định dạng"
+
+#: pkt-line.c:196
+msgid "packet write failed - data exceeds max packet size"
+msgstr "gặp lỗi khi ghi gói - dữ liệu vượt quá cỡ vói tối đa"
 
-#: sequencer.c:2545 sequencer.c:3321
+#: pkt-line.c:203 pkt-line.c:210
+msgid "packet write failed"
+msgstr "gặp lỗi khi ghi gói"
+
+#: pkt-line.c:295
+msgid "read error"
+msgstr "lỗi đọc"
+
+#: pkt-line.c:303
+msgid "the remote end hung up unexpectedly"
+msgstr "máy chủ bị treo bất ngờ"
+
+#: pkt-line.c:331
 #, c-format
-msgid "could not update %s"
-msgstr "không thể cập nhật %s"
+msgid "protocol error: bad line length character: %.4s"
+msgstr "lỗi giao thức: ký tự chiều dài dòng bị sai: %.4s"
 
-#: sequencer.c:2583 sequencer.c:3301
-msgid "cannot read HEAD"
-msgstr "không thể đọc HEAD"
+#: pkt-line.c:341 pkt-line.c:346
+#, c-format
+msgid "protocol error: bad line length %d"
+msgstr "lỗi giao thức: chiều dài dòng bị sai %d"
 
-#: sequencer.c:2618 sequencer.c:2622 builtin/difftool.c:639
+#: pkt-line.c:362
 #, c-format
-msgid "could not copy '%s' to '%s'"
-msgstr "không thể chép “%s” sang “%s”"
+msgid "remote error: %s"
+msgstr "lỗi máy chủ: %s"
 
-#: sequencer.c:2641
-msgid "could not read index"
-msgstr "không thể đọc bảng mục lục"
+#: preload-index.c:119
+msgid "Refreshing index"
+msgstr "Làm mới bảng mục lục"
 
-#: sequencer.c:2646
+#: preload-index.c:138
 #, c-format
-msgid ""
-"execution failed: %s\n"
-"%sYou can fix the problem, and then run\n"
-"\n"
-"  git rebase --continue\n"
-"\n"
-msgstr ""
-"thực thi gặp lỗi: %s\n"
-"%sBạn có thể sửa các trục trặc, và sau đó chạy lệnh\n"
-"\n"
-"  git rebase --continue\n"
-"\n"
+msgid "unable to create threaded lstat: %s"
+msgstr "không thể tạo tuyến trình lstat: %s"
 
-#: sequencer.c:2652
-msgid "and made changes to the index and/or the working tree\n"
-msgstr "và tạo các thay đổi bảng mục lục và/hay cây làm việc\n"
+#: pretty.c:981
+msgid "unable to parse --pretty format"
+msgstr "không thể phân tích định dạng --pretty"
+
+#: promisor-remote.c:23
+msgid "Remote with no URL"
+msgstr "Máy chủ không có địa chỉ URL"
 
-#: sequencer.c:2658
+#: promisor-remote.c:58
 #, c-format
-msgid ""
-"execution succeeded: %s\n"
-"but left changes to the index and/or the working tree\n"
-"Commit or stash your changes, and then run\n"
-"\n"
-"  git rebase --continue\n"
-"\n"
-msgstr ""
-"thực thi thành công: %s\n"
-"nhưng còn các thay đổi trong mục lục và/hoặc cây làm việc\n"
-"Chuyển giao hay tạm cất các thay đổi này đi, rồi chạy\n"
-"\n"
-"  git rebase --continue\n"
-"\n"
+msgid "promisor remote name cannot begin with '/': %s"
+msgstr "tên máy chủ hứa hẹn không thể bắt đầu bằng '/': %s"
 
-#: sequencer.c:2771
-msgid "writing fake root commit"
-msgstr "ghi lần chuyển giao gốc giả"
+#: range-diff.c:75
+msgid "could not start `log`"
+msgstr "không thể lấy thông tin thống kê về “log“"
 
-#: sequencer.c:2776
-msgid "writing squash-onto"
-msgstr "đang ghi squash-onto"
+#: range-diff.c:77
+msgid "could not read `log` output"
+msgstr "không thể đọc kết xuất “log”"
 
-#: sequencer.c:2811
+#: range-diff.c:96 sequencer.c:5163
 #, c-format
-msgid "failed to find tree of %s"
-msgstr "gặp lỗi khi tìm cây của %s"
+msgid "could not parse commit '%s'"
+msgstr "không thể phân tích lần chuyển giao “%s”"
 
-#: sequencer.c:2829
-msgid "could not write index"
-msgstr "không thể ghi bảng mục lục"
+#: range-diff.c:122
+#, c-format
+msgid "could not parse git header '%.*s'"
+msgstr "không thể phân tích cú pháp phần đầu git “%.*s”"
 
-#: sequencer.c:2861
-msgid "cannot merge without a current revision"
-msgstr "không thể hòa trộn mà không có một điểm xét duyệt hiện tại"
+#: range-diff.c:285
+msgid "failed to generate diff"
+msgstr "gặp lỗi khi tạo khác biệt"
 
-#: sequencer.c:2884
+#: range-diff.c:518 range-diff.c:520
 #, c-format
-msgid "could not resolve '%s'"
-msgstr "không thể phân giải “%s”"
+msgid "could not parse log for '%s'"
+msgstr "không thể phân tích nhật ký cho “%s”"
 
-#: sequencer.c:2906
+#: read-cache.c:680
 #, c-format
-msgid "could not get commit message of '%s'"
-msgstr "không thể lấy chú thích của lần chuyển giao của “%s”"
+msgid "will not add file alias '%s' ('%s' already exists in index)"
+msgstr ""
+"sẽ không thêm các bí danh “%s” (“%s” đã có từ trước trong bảng mục lục)"
+
+#: read-cache.c:696
+msgid "cannot create an empty blob in the object database"
+msgstr "không thể tạo một blob rỗng trong cơ sở dữ liệu đối tượng"
 
-#: sequencer.c:2916 sequencer.c:2941
+#: read-cache.c:718
 #, c-format
-msgid "could not write '%s'"
-msgstr "không thể ghi “%s”"
+msgid "%s: can only add regular files, symbolic links or git-directories"
+msgstr ""
+"%s: chỉ có thể thêm tập tin thông thường, liên kết mềm hoặc git-directories"
 
-#: sequencer.c:3005
+#: read-cache.c:723
 #, c-format
-msgid "could not even attempt to merge '%.*s'"
-msgstr "không thể ngay cả khi thử hòa trộn “%.*s”"
+msgid "'%s' does not have a commit checked out"
+msgstr "“%s” không có một lần chuyển giao nào được lấy ra"
 
-#: sequencer.c:3021
-msgid "merge: Unable to write new index file"
-msgstr "merge: Không thể ghi tập tin lưu bảng mục lục mới"
+#: read-cache.c:775
+#, c-format
+msgid "unable to index file '%s'"
+msgstr "không thể đánh mục lục tập tin “%s”"
 
-#: sequencer.c:3088
+#: read-cache.c:794
 #, c-format
-msgid "Applied autostash.\n"
-msgstr "Đã áp dụng autostash.\n"
+msgid "unable to add '%s' to index"
+msgstr "không thể thêm %s vào bảng mục lục"
 
-#: sequencer.c:3100
+#: read-cache.c:805
 #, c-format
-msgid "cannot store %s"
-msgstr "không thử lưu “%s”"
+msgid "unable to stat '%s'"
+msgstr "không thể lấy thống kê “%s”"
 
-#: sequencer.c:3103 git-rebase.sh:188
+#: read-cache.c:1325
+#, c-format
+msgid "'%s' appears as both a file and as a directory"
+msgstr "%s có vẻ không phải là tập tin và cũng chẳng phải là một thư mục"
+
+#: read-cache.c:1531
+msgid "Refresh index"
+msgstr "Làm tươi mới bảng mục lục"
+
+#: read-cache.c:1646
 #, c-format
 msgid ""
-"Applying autostash resulted in conflicts.\n"
-"Your changes are safe in the stash.\n"
-"You can run \"git stash pop\" or \"git stash drop\" at any time.\n"
+"index.version set, but the value is invalid.\n"
+"Using version %i"
 msgstr ""
-"Áp dụng autostash có hiệu quả trong các xung đột.\n"
-"Các thay đổi của bạn an toàn trong stash (tạm cất đi).\n"
-"Bạn có thể chạy lệnh \"git stash pop\" hay \"git stash drop\" bất kỳ lúc "
-"nào.\n"
+"index.version được đặt, nhưng giá trị của nó lại không hợp lệ.\n"
+"Dùng phiên bản %i"
 
-#: sequencer.c:3134
+#: read-cache.c:1656
 #, c-format
 msgid ""
-"Could not execute the todo command\n"
-"\n"
-"    %.*s\n"
-"It has been rescheduled; To edit the command before continuing, please\n"
-"edit the todo list first:\n"
-"\n"
-"    git rebase --edit-todo\n"
-"    git rebase --continue\n"
+"GIT_INDEX_VERSION set, but the value is invalid.\n"
+"Using version %i"
 msgstr ""
-"Không thể thực thi lệnh todo\n"
-"\n"
-"    %.*s\n"
-"Nó đã được lập lịch lại: Để sửa lệnh trước khi tiếp tục, vui lòng\n"
-"sửa danh sách todo trước:\n"
-"\n"
-"    git rebase --edit-todo\n"
-"    git rebase --continue\n"
+"GIT_INDEX_VERSION được đặt, nhưng giá trị của nó lại không hợp lệ.\n"
+"Dùng phiên bản %i"
 
-#: sequencer.c:3202
+#: read-cache.c:1712
 #, c-format
-msgid "Stopped at %s...  %.*s\n"
-msgstr "Dừng lại ở %s…  %.*s\n"
+msgid "bad signature 0x%08x"
+msgstr "chữ ký sai 0x%08x"
 
-#: sequencer.c:3264
+#: read-cache.c:1715
 #, c-format
-msgid "unknown command %d"
-msgstr "không hiểu câu lệnh %d"
+msgid "bad index version %d"
+msgstr "phiên bản mục lục sai %d"
 
-#: sequencer.c:3309
-msgid "could not read orig-head"
-msgstr "không thể đọc orig-head"
+#: read-cache.c:1724
+msgid "bad index file sha1 signature"
+msgstr "chữ ký dạng sha1 cho tập tin mục lục không đúng"
 
-#: sequencer.c:3314 sequencer.c:4352
-msgid "could not read 'onto'"
-msgstr "không thể đọc “onto”."
+#: read-cache.c:1754
+#, c-format
+msgid "index uses %.4s extension, which we do not understand"
+msgstr "mục lục dùng phần mở rộng %.4s, cái mà chúng tôi không hiểu được"
 
-#: sequencer.c:3328
+#: read-cache.c:1756
 #, c-format
-msgid "could not update HEAD to %s"
-msgstr "không thể cập nhật HEAD thành %s"
+msgid "ignoring %.4s extension"
+msgstr "đang lờ đi phần mở rộng %.4s"
 
-#: sequencer.c:3414
-msgid "cannot rebase: You have unstaged changes."
-msgstr "không thể cải tổ: Bạn có các thay đổi chưa được đưa lên bệ phóng."
+#: read-cache.c:1793
+#, c-format
+msgid "unknown index entry format 0x%08x"
+msgstr "không hiểu định dạng mục lục 0x%08x"
 
-#: sequencer.c:3423
-msgid "cannot amend non-existing commit"
-msgstr "không thể tu bỏ một lần chuyển giao không tồn tại"
+#: read-cache.c:1809
+#, c-format
+msgid "malformed name field in the index, near path '%s'"
+msgstr "trường tên sai sạng trong mục lục, gần đường dẫn “%s”"
 
-#: sequencer.c:3425
+#: read-cache.c:1866
+msgid "unordered stage entries in index"
+msgstr "các mục tin stage không đúng thứ tự trong mục lục"
+
+#: read-cache.c:1869
 #, c-format
-msgid "invalid file: '%s'"
-msgstr "tập tin không hợp lệ: “%s”"
+msgid "multiple stage entries for merged file '%s'"
+msgstr "nhiều mục stage cho tập tin hòa trộn “%s”"
 
-#: sequencer.c:3427
+#: read-cache.c:1872
 #, c-format
-msgid "invalid contents: '%s'"
-msgstr "nội dung không hợp lệ: “%s”"
+msgid "unordered stage entries for '%s'"
+msgstr "các mục tin stage không đúng thứ tự cho “%s”"
 
-#: sequencer.c:3430
-msgid ""
-"\n"
-"You have uncommitted changes in your working tree. Please, commit them\n"
-"first and then run 'git rebase --continue' again."
-msgstr ""
-"\n"
-"Bạn có các thay đổi chưa chuyển giao trong thư mục làm việc. Vui lòng\n"
-"chuyển giao chúng trước và sau đó chạy lệnh “git rebase --continue” lần nữa."
+#: read-cache.c:1978 read-cache.c:2266 rerere.c:565 rerere.c:599 rerere.c:1111
+#: builtin/add.c:499 builtin/check-ignore.c:178 builtin/checkout.c:470
+#: builtin/checkout.c:654 builtin/clean.c:967 builtin/commit.c:367
+#: builtin/diff-tree.c:120 builtin/grep.c:499 builtin/mv.c:145
+#: builtin/reset.c:246 builtin/rm.c:271 builtin/submodule--helper.c:332
+msgid "index file corrupt"
+msgstr "tập tin ghi bảng mục lục bị hỏng"
 
-#: sequencer.c:3455 sequencer.c:3493
+#: read-cache.c:2119
 #, c-format
-msgid "could not write file: '%s'"
-msgstr "không thể ghi tập tin: “%s”"
+msgid "unable to create load_cache_entries thread: %s"
+msgstr "không thể tạo tuyến load_cache_entries: %s"
 
-#: sequencer.c:3508
-msgid "could not remove CHERRY_PICK_HEAD"
-msgstr "không thể xóa bỏ CHERRY_PICK_HEAD"
+#: read-cache.c:2132
+#, c-format
+msgid "unable to join load_cache_entries thread: %s"
+msgstr "không thể gia nhập tuyến load_cache_entries: %s"
 
-#: sequencer.c:3515
-msgid "could not commit staged changes."
-msgstr "không thể chuyển giao các thay đổi đã đưa lên bệ phóng."
+#: read-cache.c:2165
+#, c-format
+msgid "%s: index file open failed"
+msgstr "%s: mở tập tin mục lục gặp lỗi"
 
-#: sequencer.c:3612
+#: read-cache.c:2169
 #, c-format
-msgid "%s: can't cherry-pick a %s"
-msgstr "%s: không thể cherry-pick một %s"
+msgid "%s: cannot stat the open index"
+msgstr "%s: không thể lấy thống kê bảng mục lục đã mở"
 
-#: sequencer.c:3616
+#: read-cache.c:2173
 #, c-format
-msgid "%s: bad revision"
-msgstr "%s: điểm xét duyệt sai"
+msgid "%s: index file smaller than expected"
+msgstr "%s: tập tin mục lục nhỏ hơn mong đợi"
 
-#: sequencer.c:3649
-msgid "can't revert as initial commit"
-msgstr "không thể hoàn nguyên một lần chuyển giao khởi tạo"
+#: read-cache.c:2177
+#, c-format
+msgid "%s: unable to map index file"
+msgstr "%s: không thể ánh xạ tập tin mục lục"
 
-#: sequencer.c:4098
-msgid "make_script: unhandled options"
-msgstr "make_script: các tùy chọn được không xử lý"
+#: read-cache.c:2219
+#, c-format
+msgid "unable to create load_index_extensions thread: %s"
+msgstr "không thể tạo tuyến load_index_extensions: %s"
 
-#: sequencer.c:4101
-msgid "make_script: error preparing revisions"
-msgstr "make_script: lỗi chuẩn bị điểm hiệu chỉnh"
+#: read-cache.c:2246
+#, c-format
+msgid "unable to join load_index_extensions thread: %s"
+msgstr "không thể gia nhập tuyến load_index_extensions: %s"
 
-#: sequencer.c:4142 sequencer.c:4177
+#: read-cache.c:2278
 #, c-format
-msgid "unusable todo list: '%s'"
-msgstr "danh sách cần làm không dùng được: “%s”"
+msgid "could not freshen shared index '%s'"
+msgstr "không thể làm tươi mới mục lục đã chia sẻ “%s”"
 
-#: sequencer.c:4236
+#: read-cache.c:2325
 #, c-format
-msgid ""
-"unrecognized setting %s for option rebase.missingCommitsCheck. Ignoring."
-msgstr ""
-"không nhận ra cài đặt %s cho tùy chọn rebase.missingCommitsCheck. Nên bỏ qua."
+msgid "broken index, expect %s in %s, got %s"
+msgstr "mục lục bị hỏng, cần %s trong %s, nhưng lại nhận được %s"
 
-#: sequencer.c:4302
+#: read-cache.c:3021 strbuf.c:1145 wrapper.c:622 builtin/merge.c:1119
 #, c-format
-msgid ""
-"Warning: some commits may have been dropped accidentally.\n"
-"Dropped commits (newer to older):\n"
-msgstr ""
-"Cảnh báo: một số lần chuyển giao có lẽ đã bị xóa một cách tình cờ.\n"
-"Các lần chuyển giao bị xóa (từ mới đến cũ):\n"
+msgid "could not close '%s'"
+msgstr "không thể đóng “%s”"
 
-#: sequencer.c:4309
+#: read-cache.c:3124 sequencer.c:2429 sequencer.c:4069
+#, c-format
+msgid "could not stat '%s'"
+msgstr "không thể lấy thông tin thống kê về “%s”"
+
+#: read-cache.c:3137
+#, c-format
+msgid "unable to open git dir: %s"
+msgstr "không thể mở thư mục git: %s"
+
+#: read-cache.c:3149
+#, c-format
+msgid "unable to unlink: %s"
+msgstr "không thể bỏ liên kết (unlink): “%s”"
+
+#: read-cache.c:3174
+#, c-format
+msgid "cannot fix permission bits on '%s'"
+msgstr "không thể sửa các bít phân quyền trên “%s”"
+
+#: read-cache.c:3323
+#, c-format
+msgid "%s: cannot drop to stage #0"
+msgstr "%s: không thể xóa bỏ stage #0"
+
+#: rebase-interactive.c:26
 #, c-format
 msgid ""
-"To avoid this message, use \"drop\" to explicitly remove a commit.\n"
+"unrecognized setting %s for option rebase.missingCommitsCheck. Ignoring."
+msgstr ""
+"không nhận ra cài đặt %s cho tùy chọn rebase.missingCommitsCheck. Nên bỏ qua."
+
+#: rebase-interactive.c:35
+msgid ""
 "\n"
-"Use 'git config rebase.missingCommitsCheck' to change the level of "
-"warnings.\n"
-"The possible behaviours are: ignore, warn, error.\n"
+"Commands:\n"
+"p, pick <commit> = use commit\n"
+"r, reword <commit> = use commit, but edit the commit message\n"
+"e, edit <commit> = use commit, but stop for amending\n"
+"s, squash <commit> = use commit, but meld into previous commit\n"
+"f, fixup <commit> = like \"squash\", but discard this commit's log message\n"
+"x, exec <command> = run command (the rest of the line) using shell\n"
+"b, break = stop here (continue rebase later with 'git rebase --continue')\n"
+"d, drop <commit> = remove commit\n"
+"l, label <label> = label current HEAD with a name\n"
+"t, reset <label> = reset HEAD to a label\n"
+"m, merge [-C <commit> | -c <commit>] <label> [# <oneline>]\n"
+".       create a merge commit using the original merge commit's\n"
+".       message (or the oneline, if no original merge commit was\n"
+".       specified). Use -c <commit> to reword the commit message.\n"
 "\n"
+"These lines can be re-ordered; they are executed from top to bottom.\n"
 msgstr ""
-"Để tránh thông báo này, dùng \"drop\" một cách rõ ràng để xóa bỏ một lần "
-"chuyển giao.\n"
 "\n"
-"Dùng “git config rebase.missingCommitsCheck” để thay đổi mức độ của cảnh "
-"báo.\n"
-"Cánh ứng xử có thể là: ignore, warn, error.\n"
+"Các lệnh:\n"
+"p, pick <commit> = dùng lần chuyển giao\n"
+"r, reword <commit> = dùng lần chuyển giao, nhưng sửa lại phần chú thích\n"
+"e, edit <commit> = dùng lần chuyển giao, nhưng dừng lại để tu bổ (amend)\n"
+"s, squash <commit> = dùng lần chuyển giao, nhưng meld vào lần chuyển giao kế "
+"trước\n"
+"f, fixup <commit> = giống như \"squash\", nhưng loại bỏ chú thích nhật ký "
+"của lần chuyển giao này\n"
+"x, exec <commit> = chạy lệnh (phần còn lại của dòng) dùng hệ vỏ\n"
+"b, break = dừng tại đây (tiếp tục cải tổ sau này bằng “git rebase --"
+"continue”)\n"
+"d, drop <commit> = xóa lần chuyển giao\n"
+"l, label <label> = đánh nhãn HEAD hiện tại bằng một tên\n"
+"t, reset <label> = đặt lại HEAD thành một nhãn\n"
+"m, merge [-C <commit> | -c <commit>] <nhãn> [# <một_dòng>]\n"
+".       tạo một lần chuyển giao hòa trộn sử dụng chú thích của lần chuyển\n"
+".       giao hòa trộn gốc (hoặc một_dòng, nếu không chỉ định lần chuyển giao "
+"hòa\n"
+".       trộn gốc). Dùng -c <commit> để reword chú thích của lần chuyển "
+"giao.\n"
 "\n"
+"Những dòng này có thể đảo ngược thứ tự; chúng chạy từ trên đỉnh xuống dưới "
+"đáy.\n"
 
-#: sequencer.c:4321
+#: rebase-interactive.c:56
 #, c-format
+msgid "Rebase %s onto %s (%d command)"
+msgid_plural "Rebase %s onto %s (%d commands)"
+msgstr[0] "Cải tổ %s vào %s (%d lệnh )"
+
+#: rebase-interactive.c:65 git-rebase--preserve-merges.sh:228
 msgid ""
-"You can fix this with 'git rebase --edit-todo' and then run 'git rebase --"
-"continue'.\n"
-"Or you can abort the rebase with 'git rebase --abort'.\n"
+"\n"
+"Do not remove any line. Use 'drop' explicitly to remove a commit.\n"
 msgstr ""
-"Bạn có thể sửa nó bằng “git rebase --edit-todo” và sau đó chạy “git rebase --"
-"continue”.\n"
-"Hoặc là bạn có thể bãi bỏ việc cải tổ bằng “git rebase --abort”.\n"
+"\n"
+"Đừng xóa bất kỳ dòng nào. Dùng “drop” một cách rõ ràng để xóa bỏ một lần "
+"chuyển giao.\n"
 
-#: sequencer.c:4375
-#, c-format
-msgid "could not parse commit '%s'"
-msgstr "không thể phân tích lần chuyển giao “%s”"
+#: rebase-interactive.c:68 git-rebase--preserve-merges.sh:232
+msgid ""
+"\n"
+"If you remove a line here THAT COMMIT WILL BE LOST.\n"
+msgstr ""
+"\n"
+"Nếu bạn xóa bỏ một dòng ở đây thì LẦN CHUYỂN GIAO ĐÓ SẼ MẤT.\n"
 
-#: sequencer.c:4490
-msgid "the script was already rearranged."
-msgstr "văn lệnh đã sẵn được sắp đặt rồi."
+#: rebase-interactive.c:74 git-rebase--preserve-merges.sh:871
+msgid ""
+"\n"
+"You are editing the todo file of an ongoing interactive rebase.\n"
+"To continue rebase after editing, run:\n"
+"    git rebase --continue\n"
+"\n"
+msgstr ""
+"\n"
+"Bạn đang sửa tập tin todo của một lần cải tổ tương tác đang thực hiện.\n"
+"Để tiếp tục cải tổ sau khi sửa, chạy:\n"
+"    git rebase --continue\n"
+"\n"
+
+#: rebase-interactive.c:79 git-rebase--preserve-merges.sh:948
+msgid ""
+"\n"
+"However, if you remove everything, the rebase will be aborted.\n"
+"\n"
+msgstr ""
+"\n"
+"Tuy nhiên, nếu bạn xóa bỏ mọi thứ, việc cải tổ sẽ bị bãi bỏ.\n"
+"\n"
+
+#: rebase-interactive.c:85 git-rebase--preserve-merges.sh:955
+msgid "Note that empty commits are commented out"
+msgstr "Chú ý rằng lần chuyển giao trống rỗng là ghi chú"
 
-#: setup.c:123
+#: rebase-interactive.c:105 rerere.c:485 rerere.c:692 sequencer.c:3536
+#: sequencer.c:3562 sequencer.c:5263 builtin/fsck.c:346 builtin/rebase.c:254
 #, c-format
-msgid "'%s' is outside repository"
-msgstr "“%s” ở ngoài một kho chứa"
+msgid "could not write '%s'"
+msgstr "không thể ghi “%s”"
+
+#: rebase-interactive.c:108
+#, c-format
+msgid "could not copy '%s' to '%s'."
+msgstr "không thể chép “%s” sang “%s”."
 
-#: setup.c:172
+#: rebase-interactive.c:173
 #, c-format
 msgid ""
-"%s: no such path in the working tree.\n"
-"Use 'git <command> -- <path>...' to specify paths that do not exist locally."
+"Warning: some commits may have been dropped accidentally.\n"
+"Dropped commits (newer to older):\n"
 msgstr ""
-"%s: không có đường dẫn nào như thế ở trong cây làm việc.\n"
-"Dùng “git <lệnh> -- <đường/dẫn>…” để chỉ định đường dẫn mà nó không tồn tại "
-"một cách nội bộ."
+"Cảnh báo: một số lần chuyển giao có lẽ đã bị xóa một cách tình cờ.\n"
+"Các lần chuyển giao bị xóa (từ mới đến cũ):\n"
 
-#: setup.c:185
+#: rebase-interactive.c:180
 #, c-format
 msgid ""
-"ambiguous argument '%s': unknown revision or path not in the working tree.\n"
-"Use '--' to separate paths from revisions, like this:\n"
-"'git <command> [<revision>...] -- [<file>...]'"
+"To avoid this message, use \"drop\" to explicitly remove a commit.\n"
+"\n"
+"Use 'git config rebase.missingCommitsCheck' to change the level of "
+"warnings.\n"
+"The possible behaviours are: ignore, warn, error.\n"
+"\n"
 msgstr ""
-"tham số chưa rõ ràng “%s”: chưa biết điểm xem xét hay đường dẫn không trong "
-"cây làm việc.\n"
-"Dùng “--” để ngăn cách các đường dẫn khỏi điểm xem xét, như thế này:\n"
-"“git <lệnh> [<điểm xem xét>…] -- [<tập tin>…]”"
+"Để tránh thông báo này, dùng \"drop\" một cách rõ ràng để xóa bỏ một lần "
+"chuyển giao.\n"
+"\n"
+"Dùng “git config rebase.missingCommitsCheck” để thay đổi mức độ của cảnh "
+"báo.\n"
+"Cánh ứng xử có thể là: ignore, warn, error.\n"
+"\n"
 
-#: setup.c:234
+#: refs.c:262
 #, c-format
-msgid "option '%s' must come before non-option arguments"
-msgstr "tùy chọn “%s” phải trước các đối số đầu tiên không có tùy chọn"
+msgid "%s does not point to a valid object!"
+msgstr "“%s” không chỉ đến một lần chuyển giao hợp lệ nào cả!"
 
-#: setup.c:253
+#: refs.c:667
 #, c-format
-msgid ""
-"ambiguous argument '%s': both revision and filename\n"
-"Use '--' to separate paths from revisions, like this:\n"
-"'git <command> [<revision>...] -- [<file>...]'"
-msgstr ""
-"tham số chưa rõ ràng “%s”: cả điểm xem xét và tên tập tin.\n"
-"Dùng “--” để ngăn cách các đường dẫn khỏi điểm xem xét, như thế này:\n"
-"“git <lệnh> [<điểm xem xét>…] -- [<tập tin>…]”"
-
-#: setup.c:389
-msgid "unable to set up work tree using invalid config"
-msgstr "Không thể đặt thư mục làm việc hiện hành sử dụng cấu hình không hợp lệ"
+msgid "ignoring dangling symref %s"
+msgstr "đang lờ đi tham chiếu mềm thừa %s"
 
-#: setup.c:393
-msgid "this operation must be run in a work tree"
-msgstr "thao tác này phải được thực hiện trong thư mục làm việc"
+#: refs.c:669 ref-filter.c:2098
+#, c-format
+msgid "ignoring broken ref %s"
+msgstr "đang lờ đi tham chiếu hỏng %s"
 
-#: setup.c:503
+#: refs.c:804
 #, c-format
-msgid "Expected git repo version <= %d, found %d"
-msgstr "Cần phiên bản kho git <= %d, nhưng lại nhận được %d"
+msgid "could not open '%s' for writing: %s"
+msgstr "không thể mở “%s” để ghi: %s"
 
-#: setup.c:511
-msgid "unknown repository extensions found:"
-msgstr "tìm thấy phần mở rộng kho chưa biết:"
+#: refs.c:814 refs.c:865
+#, c-format
+msgid "could not read ref '%s'"
+msgstr "không thể đọc tham chiếu “%s”"
 
-#: setup.c:530
+#: refs.c:820
 #, c-format
-msgid "error opening '%s'"
-msgstr "gặp lỗi khi mở “%s”"
+msgid "ref '%s' already exists"
+msgstr "tham chiếu “%s” đã có từ trước rồi"
 
-#: setup.c:532
+#: refs.c:825
 #, c-format
-msgid "too large to be a .git file: '%s'"
-msgstr "tập tin .git là quá lớn: “%s”"
+msgid "unexpected object ID when writing '%s'"
+msgstr "không cần ID đối tượng khi ghi “%s”"
 
-#: setup.c:534
+#: refs.c:833 sequencer.c:405 sequencer.c:2793 sequencer.c:2997
+#: sequencer.c:3011 sequencer.c:3269 sequencer.c:5179 strbuf.c:1142
+#: wrapper.c:620
 #, c-format
-msgid "error reading %s"
-msgstr "gặp lỗi khi đọc %s"
+msgid "could not write to '%s'"
+msgstr "không thể ghi vào “%s”"
 
-#: setup.c:536
+#: refs.c:860 strbuf.c:1140 wrapper.c:188 wrapper.c:358 builtin/am.c:714
+#: builtin/rebase.c:1031
 #, c-format
-msgid "invalid gitfile format: %s"
-msgstr "định dạng tập tin git không hợp lệ: %s"
+msgid "could not open '%s' for writing"
+msgstr "không thể mở “%s” để ghi"
 
-#: setup.c:538
+#: refs.c:867
 #, c-format
-msgid "no path in gitfile: %s"
-msgstr "không có đường dẫn trong tập tin git: %s"
+msgid "unexpected object ID when deleting '%s'"
+msgstr "gặp ID đối tượng không cần khi xóa “%s”"
 
-#: setup.c:540
+#: refs.c:998
 #, c-format
-msgid "not a git repository: %s"
-msgstr "Không phải là kho git: %s"
+msgid "log for ref %s has gap after %s"
+msgstr "nhật ký cho tham chiếu %s có khoảng trống sau %s"
 
-#: setup.c:639
+#: refs.c:1004
 #, c-format
-msgid "'$%s' too big"
-msgstr "“$%s” quá lớn"
+msgid "log for ref %s unexpectedly ended on %s"
+msgstr "nhật ký cho tham chiếu %s kết thúc bất ngờ trên %s"
 
-#: setup.c:653
+#: refs.c:1063
 #, c-format
-msgid "not a git repository: '%s'"
-msgstr "không phải là kho git: “%s”"
+msgid "log for %s is empty"
+msgstr "nhật ký cho %s trống rỗng"
 
-#: setup.c:682 setup.c:684 setup.c:715
+#: refs.c:1155
 #, c-format
-msgid "cannot chdir to '%s'"
-msgstr "không thể chdir (chuyển đổi thư mục) sang “%s”"
+msgid "refusing to update ref with bad name '%s'"
+msgstr "từ chối cập nhật tham chiếu với tên sai “%s”"
 
-#: setup.c:687 setup.c:743 setup.c:753 setup.c:792 setup.c:800 setup.c:815
-msgid "cannot come back to cwd"
-msgstr "không thể quay lại cwd"
+#: refs.c:1231
+#, c-format
+msgid "update_ref failed for ref '%s': %s"
+msgstr "update_ref bị lỗi cho ref “%s”: %s"
 
-#: setup.c:813
+#: refs.c:2023
 #, c-format
-msgid "not a git repository (or any of the parent directories): %s"
-msgstr "không phải là kho git (hoặc bất kỳ thư mục cha mẹ nào): %s"
+msgid "multiple updates for ref '%s' not allowed"
+msgstr "không cho phép đa cập nhật cho tham chiếu “%s”"
+
+#: refs.c:2055
+msgid "ref updates forbidden inside quarantine environment"
+msgstr "cập nhật tham chiếu bị cấm trong môi trường kiểm tra"
 
-#: setup.c:824
+#: refs.c:2151 refs.c:2181
 #, c-format
-msgid "failed to stat '%*s%s%s'"
-msgstr "gặp lỗi khi lấy thống kê về “%*s%s%s”"
+msgid "'%s' exists; cannot create '%s'"
+msgstr "“%s” sẵn có; không thể tạo “%s”"
 
-#: setup.c:1054
-msgid "Unable to read current working directory"
-msgstr "Không thể đọc thư mục làm việc hiện hành"
+#: refs.c:2157 refs.c:2192
+#, c-format
+msgid "cannot process '%s' and '%s' at the same time"
+msgstr "không thể xử lý “%s” và “%s” cùng một lúc"
 
-#: setup.c:1066 setup.c:1072
+#: refs/files-backend.c:1234
 #, c-format
-msgid "cannot change to '%s'"
-msgstr "không thể chuyển sang “%s”"
+msgid "could not remove reference %s"
+msgstr "không thể gỡ bỏ tham chiếu: %s"
 
-#: setup.c:1085
+#: refs/files-backend.c:1248 refs/packed-backend.c:1541
+#: refs/packed-backend.c:1551
 #, c-format
-msgid ""
-"not a git repository (or any parent up to mount point %s)\n"
-"Stopping at filesystem boundary (GIT_DISCOVERY_ACROSS_FILESYSTEM not set)."
-msgstr ""
-"không phải là kho git (hay bất kỳ cha mẹ nào đến tận điểm gắn kết %s)\n"
-"Dừng tại biên của hệ thống tập tin (GIT_DISCOVERY_ACROSS_FILESYSTEM chưa "
-"đặt)."
+msgid "could not delete reference %s: %s"
+msgstr "không thể xóa bỏ tham chiếu %s: %s"
 
-#: setup.c:1168
+#: refs/files-backend.c:1251 refs/packed-backend.c:1554
 #, c-format
-msgid ""
-"problem with core.sharedRepository filemode value (0%.3o).\n"
-"The owner of files must always have read and write permissions."
-msgstr ""
-"gặp vấn đề với giá trị chế độ tập tin core.sharedRepository (0%.3o).\n"
-"người sở hữu tập tin phải luôn có quyền đọc và ghi."
+msgid "could not delete references: %s"
+msgstr "không thể xóa bỏ tham chiếu: %s"
 
-#: setup.c:1211
-msgid "open /dev/null or dup failed"
-msgstr "gặp lỗi khi mở “/dev/null” hay dup"
+#: refspec.c:137
+#, c-format
+msgid "invalid refspec '%s'"
+msgstr "refspec không hợp lệ “%s”"
 
-#: setup.c:1226
-msgid "fork failed"
-msgstr "gặp lỗi khi rẽ nhánh tiến trình"
+#: ref-filter.c:42 wt-status.c:1938
+msgid "gone"
+msgstr "đã ra đi"
 
-#: setup.c:1231
-msgid "setsid failed"
-msgstr "setsid gặp lỗi"
+#: ref-filter.c:43
+#, c-format
+msgid "ahead %d"
+msgstr "phía trước %d"
 
-#: sha1-file.c:625
+#: ref-filter.c:44
 #, c-format
-msgid "path '%s' does not exist"
-msgstr "đường dẫn “%s” không tồn tại"
+msgid "behind %d"
+msgstr "đằng sau %d"
 
-#: sha1-file.c:651
+#: ref-filter.c:45
 #, c-format
-msgid "reference repository '%s' as a linked checkout is not supported yet."
-msgstr "kho tham chiếu “%s” như là lấy ra liên kết vẫn chưa được hỗ trợ."
+msgid "ahead %d, behind %d"
+msgstr "trước %d, sau %d"
 
-#: sha1-file.c:657
+#: ref-filter.c:165
 #, c-format
-msgid "reference repository '%s' is not a local repository."
-msgstr "kho tham chiếu “%s” không phải là một kho nội bộ."
+msgid "expected format: %%(color:<color>)"
+msgstr "cần định dạng: %%(color:<color>)"
 
-#: sha1-file.c:663
+#: ref-filter.c:167
 #, c-format
-msgid "reference repository '%s' is shallow"
-msgstr "kho tham chiếu “%s” là nông"
+msgid "unrecognized color: %%(color:%s)"
+msgstr "không nhận ra màu: %%(màu:%s)"
 
-#: sha1-file.c:671
+#: ref-filter.c:189
 #, c-format
-msgid "reference repository '%s' is grafted"
-msgstr "kho tham chiếu “%s” bị cấy ghép"
+msgid "Integer value expected refname:lstrip=%s"
+msgstr "Giá trị nguyên cần tên tham chiếu:lstrip=%s"
 
-#: sha1-name.c:442
+#: ref-filter.c:193
 #, c-format
-msgid "short SHA1 %s is ambiguous"
-msgstr "tóm lược SHA1 %s chưa rõ ràng"
+msgid "Integer value expected refname:rstrip=%s"
+msgstr "Giá trị nguyên cần tên tham chiếu:rstrip=%s"
 
-#: sha1-name.c:453
-msgid "The candidates are:"
-msgstr "Các ứng cử là:"
+#: ref-filter.c:195
+#, c-format
+msgid "unrecognized %%(%s) argument: %s"
+msgstr "đối số không được thừa nhận %%(%s): %s"
 
-#: sha1-name.c:695
-msgid ""
-"Git normally never creates a ref that ends with 40 hex characters\n"
-"because it will be ignored when you just specify 40-hex. These refs\n"
-"may be created by mistake. For example,\n"
-"\n"
-"  git checkout -b $br $(git rev-parse ...)\n"
-"\n"
-"where \"$br\" is somehow empty and a 40-hex ref is created. Please\n"
-"examine these refs and maybe delete them. Turn this message off by\n"
-"running \"git config advice.objectNameWarning false\""
-msgstr ""
-"Git thường không bao giờ tạo tham chiếu mà nó kết thúc với 40 ký tự hex\n"
-"bởi vì nó sẽ bị bỏ qua khi bạn chỉ định 40-hex. Những tham chiếu này\n"
-"có lẽ được tạo ra bởi một sai sót nào đó. Ví dụ,\n"
-"\n"
-"  git checkout -b $br $(git rev-parse …)\n"
-"\n"
-"với \"$br\" không hiểu lý do vì sao trống rỗng và một tham chiếu 40-hex được "
-"tạo ra.\n"
-"Xin hãy kiểm tra những tham chiếu này và có thể xóa chúng đi. Tắt lời nhắn "
-"này\n"
-"bằng cách chạy lệnh \"git config advice.objectNameWarning false\""
+#: ref-filter.c:250
+#, c-format
+msgid "%%(objecttype) does not take arguments"
+msgstr "%%(objecttype) không nhận các đối số"
 
-#: submodule.c:97 submodule.c:131
-msgid "Cannot change unmerged .gitmodules, resolve merge conflicts first"
-msgstr ""
-"Không thể thay đổi .gitmodules chưa hòa trộn, hãy giải quyết xung đột trộn "
-"trước"
+#: ref-filter.c:272
+#, c-format
+msgid "unrecognized %%(objectsize) argument: %s"
+msgstr "tham số không được thừa nhận %%(objectname): %s"
 
-#: submodule.c:101 submodule.c:135
+#: ref-filter.c:280
 #, c-format
-msgid "Could not find section in .gitmodules where path=%s"
-msgstr "Không thể tìm thấy phần trong .gitmodules nơi mà đường_dẫn=%s"
+msgid "%%(deltabase) does not take arguments"
+msgstr "%%(deltabase) không nhận các đối số"
 
-#: submodule.c:109
+#: ref-filter.c:292
 #, c-format
-msgid "Could not update .gitmodules entry %s"
-msgstr "Không thể cập nhật mục .gitmodules %s"
+msgid "%%(body) does not take arguments"
+msgstr "%%(body) không nhận các đối số"
 
-#: submodule.c:142
+#: ref-filter.c:301
 #, c-format
-msgid "Could not remove .gitmodules entry for %s"
-msgstr "Không thể gỡ bỏ mục .gitmodules dành cho %s"
+msgid "%%(subject) does not take arguments"
+msgstr "%%(subject) không nhận các đối số"
 
-#: submodule.c:153
-msgid "staging updated .gitmodules failed"
-msgstr "gặp lỗi khi tổ chức .gitmodules đã cập nhật"
+#: ref-filter.c:323
+#, c-format
+msgid "unknown %%(trailers) argument: %s"
+msgstr "không hiểu tham số %%(trailers): %s"
 
-#: submodule.c:315
+#: ref-filter.c:352
 #, c-format
-msgid "in unpopulated submodule '%s'"
-msgstr "Trong mô-đun-con không có gì “%s”"
+msgid "positive value expected contents:lines=%s"
+msgstr "cần nội dung mang giá trị dương:lines=%s"
 
-#: submodule.c:346
+#: ref-filter.c:354
 #, c-format
-msgid "Pathspec '%s' is in submodule '%.*s'"
-msgstr "Đặc tả đường dẫn “%s” thì ở trong mô-đun-con “%.*s”"
+msgid "unrecognized %%(contents) argument: %s"
+msgstr "đối số không được thừa nhận %%(contents): %s"
 
-#: submodule.c:837
+#: ref-filter.c:369
 #, c-format
-msgid "submodule entry '%s' (%s) is a %s, not a commit"
-msgstr ""
-"mục tin mô-đun-con “%s” (%s) là một %s, không phải là một lần chuyển giao"
+msgid "positive value expected objectname:short=%s"
+msgstr "cần nội dung mang giá trị dương:shot=%s"
 
-#: submodule.c:1069 builtin/branch.c:651 builtin/submodule--helper.c:1743
-msgid "Failed to resolve HEAD as a valid ref."
-msgstr "Gặp lỗi khi phân giải HEAD như là một tham chiếu hợp lệ."
+#: ref-filter.c:373
+#, c-format
+msgid "unrecognized %%(objectname) argument: %s"
+msgstr "đối số không được thừa nhận %%(objectname): %s"
 
-#: submodule.c:1375
+#: ref-filter.c:403
 #, c-format
-msgid "'%s' not recognized as a git repository"
-msgstr "không nhận ra “%s” là một kho git"
+msgid "expected format: %%(align:<width>,<position>)"
+msgstr "cần định dạng: %%(align:<width>,<position>)"
 
-#: submodule.c:1513
+#: ref-filter.c:415
 #, c-format
-msgid "could not start 'git status' in submodule '%s'"
-msgstr "không thể lấy thống kê “git status” trong mô-đun-con “%s”"
+msgid "unrecognized position:%s"
+msgstr "vị trí không được thừa nhận:%s"
 
-#: submodule.c:1526
+#: ref-filter.c:422
 #, c-format
-msgid "could not run 'git status' in submodule '%s'"
-msgstr "không thể chạy “git status” trong mô-đun-con “%s”"
+msgid "unrecognized width:%s"
+msgstr "chiều rộng không được thừa nhận:%s"
 
-#: submodule.c:1619
+#: ref-filter.c:431
 #, c-format
-msgid "submodule '%s' has dirty index"
-msgstr "mô-đun-con “%s” có mục lục còn bẩn"
+msgid "unrecognized %%(align) argument: %s"
+msgstr "đối số không được thừa nhận %%(align): %s"
 
-#: submodule.c:1718
+#: ref-filter.c:439
 #, c-format
-msgid ""
-"relocate_gitdir for submodule '%s' with more than one worktree not supported"
-msgstr ""
-"relocate_gitdir cho mô-đun-con “%s” với nhiều hơn một cây làm việc là chưa "
-"được hỗ trợ"
+msgid "positive width expected with the %%(align) atom"
+msgstr "cần giá trị độ rộng dương với nguyên tử %%(align)"
 
-#: submodule.c:1730 submodule.c:1786
+#: ref-filter.c:457
 #, c-format
-msgid "could not lookup name for submodule '%s'"
-msgstr "không thể tìm kiếm tên cho mô-đun-con “%s”"
+msgid "unrecognized %%(if) argument: %s"
+msgstr "đối số không được thừa nhận %%(if): %s"
 
-#: submodule.c:1734 builtin/submodule--helper.c:1261
-#: builtin/submodule--helper.c:1271
+#: ref-filter.c:559
 #, c-format
-msgid "could not create directory '%s'"
-msgstr "không thể tạo thư mục “%s”"
+msgid "malformed field name: %.*s"
+msgstr "tên trường dị hình: %.*s"
+
+#: ref-filter.c:586
+#, c-format
+msgid "unknown field name: %.*s"
+msgstr "không hiểu tên trường: %.*s"
 
-#: submodule.c:1737
+#: ref-filter.c:590
 #, c-format
 msgid ""
-"Migrating git directory of '%s%s' from\n"
-"'%s' to\n"
-"'%s'\n"
+"not a git repository, but the field '%.*s' requires access to object data"
 msgstr ""
-"Di cư thư mục git của “%s%s” từ\n"
-"“%s” sang\n"
-"“%s”\n"
+"không phải là một kho git, nhưng trường “%.*s” yêu cầu truy cập vào dữ liệu "
+"đối tượng"
 
-#: submodule.c:1821
+#: ref-filter.c:714
 #, c-format
-msgid "could not recurse into submodule '%s'"
-msgstr "không thể đệ quy vào trong mô-đun-con “%s”"
+msgid "format: %%(if) atom used without a %%(then) atom"
+msgstr "định dạng: nguyên tử %%(if) được dùng mà không có nguyên tử %%(then)"
 
-#: submodule.c:1865
-msgid "could not start ls-files in .."
-msgstr "không thể lấy thông tin thống kê về ls-files trong .."
+#: ref-filter.c:777
+#, c-format
+msgid "format: %%(then) atom used without an %%(if) atom"
+msgstr "định dạng: nguyên tử %%(then) được dùng mà không có nguyên tử %%(if)"
 
-#: submodule.c:1904
+#: ref-filter.c:779
 #, c-format
-msgid "ls-tree returned unexpected return code %d"
-msgstr "ls-tree trả về mã không như mong đợi %d"
+msgid "format: %%(then) atom used more than once"
+msgstr "định dạng: nguyên tử %%(then) được dùng nhiều hơn một lần"
 
-#: submodule-config.c:230
+#: ref-filter.c:781
 #, c-format
-msgid "ignoring suspicious submodule name: %s"
-msgstr "đang lờ đi tên mô-đun-con mập mờ: %s"
+msgid "format: %%(then) atom used after %%(else)"
+msgstr "định dạng: nguyên tử %%(then) được dùng sau %%(else)"
 
-#: submodule-config.c:294
-msgid "negative values not allowed for submodule.fetchjobs"
-msgstr "không cho phép giá trị âm ở submodule.fetchJobs"
+#: ref-filter.c:809
+#, c-format
+msgid "format: %%(else) atom used without an %%(if) atom"
+msgstr "định dạng: nguyên tử %%(else) được dùng mà không có nguyên tử %%(if)"
 
-#: submodule-config.c:467
+#: ref-filter.c:811
 #, c-format
-msgid "invalid value for %s"
-msgstr "giá trị cho %s không hợp lệ"
+msgid "format: %%(else) atom used without a %%(then) atom"
+msgstr "định dạng: nguyên tử %%(else) được dùng mà không có nguyên tử %%(then)"
 
-#: trailer.c:238
+#: ref-filter.c:813
 #, c-format
-msgid "running trailer command '%s' failed"
-msgstr "chạy lệnh kéo theo “%s” gặp lỗi"
+msgid "format: %%(else) atom used more than once"
+msgstr "định dạng: nguyên tử %%(else) được dùng nhiều hơn một lần"
 
-#: trailer.c:485 trailer.c:490 trailer.c:495 trailer.c:549 trailer.c:553
-#: trailer.c:557
+#: ref-filter.c:828
 #, c-format
-msgid "unknown value '%s' for key '%s'"
-msgstr "không hiểu giá trị “%s” cho khóa “%s”"
+msgid "format: %%(end) atom used without corresponding atom"
+msgstr "định dạng: nguyên tử %%(end) được dùng mà không có nguyên tử tương ứng"
 
-#: trailer.c:539 trailer.c:544 builtin/remote.c:293
+#: ref-filter.c:885
 #, c-format
-msgid "more than one %s"
-msgstr "nhiều hơn một %s"
+msgid "malformed format string %s"
+msgstr "chuỗi định dạng dị hình %s"
 
-#: trailer.c:730
+#: ref-filter.c:1488
 #, c-format
-msgid "empty trailer token in trailer '%.*s'"
-msgstr "thẻ thừa trống rỗng trong phần thừa “%.*s”"
+msgid "no branch, rebasing %s"
+msgstr "không nhánh, đang cải tổ %s"
 
-#: trailer.c:750
+#: ref-filter.c:1491
 #, c-format
-msgid "could not read input file '%s'"
-msgstr "không đọc được tập tin đầu vào “%s”"
+msgid "no branch, rebasing detached HEAD %s"
+msgstr "không nhánh, đang cải tổ HEAD %s đã tách rời"
 
-#: trailer.c:753
-msgid "could not read from stdin"
-msgstr "không thể đọc từ đầu vào tiêu chuẩn"
+#: ref-filter.c:1494
+#, c-format
+msgid "no branch, bisect started on %s"
+msgstr "không nhánh, di chuyển nửa bước được bắt đầu tại %s"
 
-#: trailer.c:1008 builtin/am.c:46
+#: ref-filter.c:1504
+msgid "no branch"
+msgstr "không nhánh"
+
+#: ref-filter.c:1540 ref-filter.c:1749
 #, c-format
-msgid "could not stat %s"
-msgstr "không thể lấy thông tin thống kê về %s"
+msgid "missing object %s for %s"
+msgstr "thiếu đối tượng %s cho %s"
 
-#: trailer.c:1010
+#: ref-filter.c:1550
 #, c-format
-msgid "file %s is not a regular file"
-msgstr "\"%s\" không phải là tập tin bình thường"
+msgid "parse_object_buffer failed on %s for %s"
+msgstr "parse_object_buffer gặp lỗi trên %s cho %s"
 
-#: trailer.c:1012
+#: ref-filter.c:2004
 #, c-format
-msgid "file %s is not writable by user"
-msgstr "tập tin %s người dùng không thể ghi được"
+msgid "malformed object at '%s'"
+msgstr "đối tượng dị hình tại “%s”"
 
-#: trailer.c:1024
-msgid "could not open temporary file"
-msgstr "không thể tạo tập tin tạm thời"
+#: ref-filter.c:2093
+#, c-format
+msgid "ignoring ref with broken name %s"
+msgstr "đang lờ đi tham chiếu với tên hỏng %s"
 
-#: trailer.c:1064
+#: ref-filter.c:2389
 #, c-format
-msgid "could not rename temporary file to %s"
-msgstr "không thể đổi tên tập tin tạm thời thành %s"
+msgid "format: %%(end) atom missing"
+msgstr "định dạng: thiếu nguyên tử %%(end)"
 
-#: transport.c:116
+#: ref-filter.c:2489
 #, c-format
-msgid "Would set upstream of '%s' to '%s' of '%s'\n"
-msgstr "Không thể đặt thượng nguồn của “%s” thành “%s” của “%s”\n"
+msgid "option `%s' is incompatible with --merged"
+msgstr "tùy chọn “%s” là xung khắc với tùy chọn --merged"
 
-#: transport.c:208
+#: ref-filter.c:2492
 #, c-format
-msgid "transport: invalid depth option '%s'"
-msgstr "vận chuyển: tùy chọn độ sâu “%s” không hợp lệ"
+msgid "option `%s' is incompatible with --no-merged"
+msgstr "tùy chọn “%s” là xung khắc với tùy chọn --no-merged"
 
-#: transport.c:584
-msgid "could not parse transport.color.* config"
-msgstr "không thể phân tích cú pháp cấu hình transport.color.*"
+#: ref-filter.c:2502
+#, c-format
+msgid "malformed object name %s"
+msgstr "tên đối tượng dị hình %s"
 
-#: transport.c:996
+#: ref-filter.c:2507
 #, c-format
-msgid ""
-"The following submodule paths contain changes that can\n"
-"not be found on any remote:\n"
-msgstr ""
-"Các đường dẫn mô-đun-con sau đây có chứa các thay đổi cái mà\n"
-"có thể được tìm thấy trên mọi máy phục vụ:\n"
+msgid "option `%s' must point to a commit"
+msgstr "tùy chọn “%s” phải chỉ đến một lần chuyển giao"
 
-#: transport.c:1000
+#: remote.c:366
 #, c-format
-msgid ""
-"\n"
-"Please try\n"
-"\n"
-"\tgit push --recurse-submodules=on-demand\n"
-"\n"
-"or cd to the path and use\n"
-"\n"
-"\tgit push\n"
-"\n"
-"to push them to a remote.\n"
-"\n"
-msgstr ""
-"\n"
-"Hãy thử\n"
-"\n"
-"\tgit push --recurse-submodules=on-demand\n"
-"\n"
-"hoặc cd đến đường dẫn và dùng\n"
-"\n"
-"\tgit push\n"
-"\n"
-"để đẩy chúng lên máy phục vụ.\n"
-"\n"
+msgid "config remote shorthand cannot begin with '/': %s"
+msgstr "cấu hình viết tắt máy chủ không thể bắt đầu bằng “/”: %s"
 
-#: transport.c:1008
-msgid "Aborting."
-msgstr "Bãi bỏ."
+#: remote.c:413
+msgid "more than one receivepack given, using the first"
+msgstr "đã đưa ra nhiều hơn một gói nhận về, đang sử dụng cái đầu tiên"
 
-#: transport-helper.c:1087
+#: remote.c:421
+msgid "more than one uploadpack given, using the first"
+msgstr "đã đưa ra nhiều hơn một gói tải lên, đang sử dụng cái đầu tiên"
+
+#: remote.c:611
 #, c-format
-msgid "Could not read ref %s"
-msgstr "Không thể đọc tham chiếu %s"
+msgid "Cannot fetch both %s and %s to %s"
+msgstr "Không thể lấy về cả %s và %s cho %s"
 
-#: tree-walk.c:31
-msgid "too-short tree object"
-msgstr "đối tượng cây quá ngắn"
+#: remote.c:615
+#, c-format
+msgid "%s usually tracks %s, not %s"
+msgstr "%s thường theo dõi %s, không phải %s"
 
-#: tree-walk.c:37
-msgid "malformed mode in tree entry"
-msgstr "chế độ dị hình trong đề mục cây"
+#: remote.c:619
+#, c-format
+msgid "%s tracks both %s and %s"
+msgstr "%s theo dõi cả %s và %s"
 
-#: tree-walk.c:41
-msgid "empty filename in tree entry"
-msgstr "tên tập tin trống rỗng trong mục tin cây"
+#: remote.c:687
+#, c-format
+msgid "key '%s' of pattern had no '*'"
+msgstr "khóa “%s” của mẫu k có “*”"
 
-#: tree-walk.c:113
-msgid "too-short tree file"
-msgstr "tập tin cây quá ngắn"
+#: remote.c:697
+#, c-format
+msgid "value '%s' of pattern has no '*'"
+msgstr "giá trị “%s” của mẫu k có “*”"
 
-#: unpack-trees.c:111
+#: remote.c:1003
 #, c-format
-msgid ""
-"Your local changes to the following files would be overwritten by checkout:\n"
-"%%sPlease commit your changes or stash them before you switch branches."
-msgstr ""
-"Các thay đổi nội bộ của bạn với các tập tin sau đây sẽ bị ghi đè bởi lệnh "
-"checkout:\n"
-"%%sVui lòng chuyển giao các thay đổi hay tạm cất chúng đi trước khi bạn "
-"chuyển nhánh."
+msgid "src refspec %s does not match any"
+msgstr "refspec %s nguồn không khớp bất kỳ cái gì"
+
+#: remote.c:1008
+#, c-format
+msgid "src refspec %s matches more than one"
+msgstr "refspec %s nguồn khớp nhiều hơn một"
 
-#: unpack-trees.c:113
+#. TRANSLATORS: "matches '%s'%" is the <dst> part of "git push
+#. <remote> <src>:<dst>" push, and "being pushed ('%s')" is
+#. the <src>.
+#.
+#: remote.c:1023
 #, c-format
 msgid ""
-"Your local changes to the following files would be overwritten by checkout:\n"
-"%%s"
+"The destination you provided is not a full refname (i.e.,\n"
+"starting with \"refs/\"). We tried to guess what you meant by:\n"
+"\n"
+"- Looking for a ref that matches '%s' on the remote side.\n"
+"- Checking if the <src> being pushed ('%s')\n"
+"  is a ref in \"refs/{heads,tags}/\". If so we add a corresponding\n"
+"  refs/{heads,tags}/ prefix on the remote side.\n"
+"\n"
+"Neither worked, so we gave up. You must fully qualify the ref."
 msgstr ""
-"Các thay đổi nội bộ của bạn với các tập tin sau đây sẽ bị ghi đè bởi lệnh "
-"checkout:\n"
-"%%s"
+"Đích bạn đã cung cấp không phải tên tham chiếu đầy đủ (tức là\n"
+"bắt đầu bằng \"refs/\"). Chúng tôi đã cố suy luận rằng ý của bạn là:\n"
+"\n"
+"- Tìm kiếm một tham chiếu mà nó khớp “%s” bên phía máy chủ.\n"
+"- Kiểm tra xem <src> được đẩy lên (“%s”)\n"
+"  là một tham chiếu trong \"refs/{heads,tags}/\". Nếu thế chúng tôi thêm một "
+"tiền tố\n"
+"  refs/{heads,tags}/ tương ứng bên phía máy chủ.\n"
+"\n"
+"Nếu cả hai là không thể, thì chúng tôi cũng chịu thua. Bạn phải dùng tham "
+"chiếu dạng đầy đủ."
 
-#: unpack-trees.c:116
+#: remote.c:1043
 #, c-format
 msgid ""
-"Your local changes to the following files would be overwritten by merge:\n"
-"%%sPlease commit your changes or stash them before you merge."
+"The <src> part of the refspec is a commit object.\n"
+"Did you mean to create a new branch by pushing to\n"
+"'%s:refs/heads/%s'?"
 msgstr ""
-"Các thay đổi nội bộ của bạn với các tập tin sau đây sẽ bị ghi đè bởi lệnh "
-"hòa trộn:\n"
-"%%sVui lòng chuyển giao các thay đổi hay tạm cất chúng đi trước khi bạn hòa "
-"trộn."
+"Phần <src> của đặc tả đường dẫn là một đối tượng lần chuyển giao.\n"
+"Có phải ý bạn là một tạo một nhánh mới bằng cách đẩy lên\n"
+"“%s:refs/heads/%s”?"
 
-#: unpack-trees.c:118
+#: remote.c:1048
 #, c-format
 msgid ""
-"Your local changes to the following files would be overwritten by merge:\n"
-"%%s"
+"The <src> part of the refspec is a tag object.\n"
+"Did you mean to create a new tag by pushing to\n"
+"'%s:refs/tags/%s'?"
 msgstr ""
-"Các thay đổi nội bộ của bạn với các tập tin sau đây sẽ bị ghi đè bởi lệnh "
-"hòa trộn:\n"
-"%%s"
+"Phần <src> của đặc tả đường dẫn là một đối tượng thẻ.\n"
+"Có phải ý bạn là một tạo một thẻ mới bằng cách đẩy lên\n"
+"“%s:refs/tags/%s”?"
 
-#: unpack-trees.c:121
+#: remote.c:1053
 #, c-format
 msgid ""
-"Your local changes to the following files would be overwritten by %s:\n"
-"%%sPlease commit your changes or stash them before you %s."
+"The <src> part of the refspec is a tree object.\n"
+"Did you mean to tag a new tree by pushing to\n"
+"'%s:refs/tags/%s'?"
 msgstr ""
-"Các thay đổi nội bộ của bạn với các tập tin sau đây sẽ bị ghi đè bởi lệnh "
-"%s:\n"
-"%%sVui lòng chuyển giao các thay đổi hay tạm cất chúng đi trước khi bạn %s."
+"Phần <src> của đặc tả đường dẫn là một đối tượng cây.\n"
+"Có phải ý bạn là một tạo một cây mới bằng cách đẩy lên\n"
+"“%s:refs/tags/%s”?"
 
-#: unpack-trees.c:123
+#: remote.c:1058
 #, c-format
 msgid ""
-"Your local changes to the following files would be overwritten by %s:\n"
-"%%s"
+"The <src> part of the refspec is a blob object.\n"
+"Did you mean to tag a new blob by pushing to\n"
+"'%s:refs/tags/%s'?"
 msgstr ""
-"Các thay đổi nội bộ của bạn với các tập tin sau đây sẽ bị ghi đè bởi lệnh "
-"%s:\n"
-"%%s"
+"Phần <src> của đặc tả đường dẫn là một đối tượng blob.\n"
+"Có phải ý bạn là một tạo một blob mới bằng cách đẩy lên\n"
+"“%s:refs/tags/%s”?"
 
-#: unpack-trees.c:128
+#: remote.c:1094
 #, c-format
-msgid ""
-"Updating the following directories would lose untracked files in them:\n"
-"%s"
-msgstr ""
-"Việc cập nhật các thư mục sau đây có thể làm mất các tập tin chưa theo dõi "
-"trong nó:\n"
-"%s"
+msgid "%s cannot be resolved to branch"
+msgstr "“%s” không thể được phân giải thành nhánh"
 
-#: unpack-trees.c:132
+#: remote.c:1105
 #, c-format
-msgid ""
-"The following untracked working tree files would be removed by checkout:\n"
-"%%sPlease move or remove them before you switch branches."
-msgstr ""
-"Các tập tin cây làm việc chưa được theo dõi sau đây sẽ bị gỡ bỏ bởi lệnh "
-"checkout:\n"
-"%%sVui lòng di chuyển hay gỡ bỏ chúng trước khi bạn chuyển nhánh."
+msgid "unable to delete '%s': remote ref does not exist"
+msgstr "không thể xóa “%s”: tham chiếu trên máy chủ không tồn tại"
 
-#: unpack-trees.c:134
+#: remote.c:1117
 #, c-format
-msgid ""
-"The following untracked working tree files would be removed by checkout:\n"
-"%%s"
-msgstr ""
-"Các tập tin cây làm việc chưa được theo dõi sau đây sẽ bị gỡ bỏ bởi lệnh "
-"checkout:\n"
-"%%s"
+msgid "dst refspec %s matches more than one"
+msgstr "dst refspec %s khớp nhiều hơn một"
 
-#: unpack-trees.c:137
+#: remote.c:1124
 #, c-format
-msgid ""
-"The following untracked working tree files would be removed by merge:\n"
-"%%sPlease move or remove them before you merge."
-msgstr ""
-"Các tập tin cây làm việc chưa được theo dõi sau đây sẽ bị gỡ bỏ bởi lệnh hòa "
-"trộn:\n"
-"%%sVui lòng di chuyển hay gỡ bỏ chúng trước khi bạn hòa trộn."
+msgid "dst ref %s receives from more than one src"
+msgstr "dst ref %s nhận từ hơn một nguồn"
 
-#: unpack-trees.c:139
+#: remote.c:1627 remote.c:1728
+msgid "HEAD does not point to a branch"
+msgstr "HEAD không chỉ đến một nhánh nào cả"
+
+#: remote.c:1636
 #, c-format
-msgid ""
-"The following untracked working tree files would be removed by merge:\n"
-"%%s"
-msgstr ""
-"Các tập tin cây làm việc chưa được theo dõi sau đây sẽ bị gỡ bỏ bởi lệnh hòa "
-"trộn:\n"
-"%%s"
+msgid "no such branch: '%s'"
+msgstr "không có nhánh nào như thế: “%s”"
 
-#: unpack-trees.c:142
+#: remote.c:1639
 #, c-format
-msgid ""
-"The following untracked working tree files would be removed by %s:\n"
-"%%sPlease move or remove them before you %s."
-msgstr ""
-"Các tập tin cây làm việc chưa được theo dõi sau đây sẽ bị gỡ bỏ bởi %s:\n"
-"%%sVui lòng di chuyển hay gỡ bỏ chúng trước khi bạn %s."
+msgid "no upstream configured for branch '%s'"
+msgstr "không có thượng nguồn được cấu hình cho nhánh “%s”"
 
-#: unpack-trees.c:144
+#: remote.c:1645
 #, c-format
-msgid ""
-"The following untracked working tree files would be removed by %s:\n"
-"%%s"
+msgid "upstream branch '%s' not stored as a remote-tracking branch"
 msgstr ""
-"Các tập tin cây làm việc chưa được theo dõi sau đây sẽ bị gỡ bỏ bởi %s:\n"
-"%%s"
+"nhánh thượng nguồn “%s” không được lưu lại như là một nhánh theo dõi máy chủ"
 
-#: unpack-trees.c:150
+#: remote.c:1660
 #, c-format
-msgid ""
-"The following untracked working tree files would be overwritten by "
-"checkout:\n"
-"%%sPlease move or remove them before you switch branches."
-msgstr ""
-"Các tập tin cây làm việc chưa được theo dõi sau đây sẽ bị ghi đè bởi lệnh "
-"checkout:\n"
-"%%sVui lòng di chuyển hay gỡ bỏ chúng trước khi bạn chuyển nhánh."
+msgid "push destination '%s' on remote '%s' has no local tracking branch"
+msgstr "đẩy lên đích “%s” trên máy chủ “%s” không có nhánh theo dõi nội bộ"
 
-#: unpack-trees.c:152
+#: remote.c:1672
 #, c-format
-msgid ""
-"The following untracked working tree files would be overwritten by "
-"checkout:\n"
-"%%s"
-msgstr ""
-"Các tập tin cây làm việc chưa được theo dõi sau đây sẽ bị ghi đè bởi lệnh "
-"checkout:\n"
-"%%s"
+msgid "branch '%s' has no remote for pushing"
+msgstr "nhánh “%s” không có máy chủ để đẩy lên"
 
-#: unpack-trees.c:155
+#: remote.c:1682
 #, c-format
-msgid ""
-"The following untracked working tree files would be overwritten by merge:\n"
-"%%sPlease move or remove them before you merge."
-msgstr ""
-"Các tập tin cây làm việc chưa được theo dõi sau đây sẽ bị ghi đè bởi lệnh "
-"hòa trộn:\n"
-"%%sVui lòng di chuyển hay gỡ bỏ chúng trước khi bạn hòa trộn."
+msgid "push refspecs for '%s' do not include '%s'"
+msgstr "đẩy refspecs cho “%s” không bao gồm “%s”"
 
-#: unpack-trees.c:157
+#: remote.c:1695
+msgid "push has no destination (push.default is 'nothing')"
+msgstr "đẩy lên mà không có đích (push.default là “nothing”)"
+
+#: remote.c:1717
+msgid "cannot resolve 'simple' push to a single destination"
+msgstr "không thể phân giải đẩy “đơn giản” đến một đích đơn"
+
+#: remote.c:1843
 #, c-format
-msgid ""
-"The following untracked working tree files would be overwritten by merge:\n"
-"%%s"
-msgstr ""
-"Các tập tin cây làm việc chưa được theo dõi sau đây sẽ bị ghi đè bởi lệnh "
-"hòa trộn:\n"
-"%%s"
+msgid "couldn't find remote ref %s"
+msgstr "không thể tìm thấy tham chiếu máy chủ %s"
 
-#: unpack-trees.c:160
+#: remote.c:1856
 #, c-format
-msgid ""
-"The following untracked working tree files would be overwritten by %s:\n"
-"%%sPlease move or remove them before you %s."
-msgstr ""
-"Các tập tin cây làm việc chưa được theo dõi sau đây sẽ bị ghi đè bởi lệnh "
-"%s:\n"
-"%%sVui lòng di chuyển hay gỡ bỏ chúng trước khi bạn %s."
+msgid "* Ignoring funny ref '%s' locally"
+msgstr "* Đang bỏ qua tham chiếu thú vị nội bộ “%s”"
 
-#: unpack-trees.c:162
+#: remote.c:2019
 #, c-format
-msgid ""
-"The following untracked working tree files would be overwritten by %s:\n"
-"%%s"
+msgid "Your branch is based on '%s', but the upstream is gone.\n"
 msgstr ""
-"Các tập tin cây làm việc chưa được theo dõi sau đây sẽ bị ghi đè bởi lệnh "
-"%s:\n"
-"%%s"
+"Nhánh của bạn dựa trên cơ sở là “%s”, nhưng trên thượng nguồn không còn.\n"
 
-#: unpack-trees.c:170
+#: remote.c:2023
+msgid "  (use \"git branch --unset-upstream\" to fixup)\n"
+msgstr "   (dùng \" git branch --unset-upstream\" để sửa)\n"
+
+#: remote.c:2026
 #, c-format
-msgid "Entry '%s' overlaps with '%s'.  Cannot bind."
-msgstr "Mục “%s” đè lên “%s”. Không thể buộc."
+msgid "Your branch is up to date with '%s'.\n"
+msgstr "Nhánh của bạn đã cập nhật với “%s”.\n"
 
-#: unpack-trees.c:173
+#: remote.c:2030
 #, c-format
-msgid ""
-"Cannot update sparse checkout: the following entries are not up to date:\n"
-"%s"
-msgstr ""
-"Không thể cập nhật checkout rải rác: các mục tin sau đây chưa cập nhật:\n"
-"%s"
+msgid "Your branch and '%s' refer to different commits.\n"
+msgstr "Nhánh của bạn và “%s” tham chiếu đến các lần chuyển giao khác nhau.\n"
 
-#: unpack-trees.c:175
+#: remote.c:2033
 #, c-format
-msgid ""
-"The following working tree files would be overwritten by sparse checkout "
-"update:\n"
-"%s"
-msgstr ""
-"Các tập tin cây làm việc chưa được theo dõi sau đây sẽ bị ghi đè bởi cập "
-"nhật checkout rải rác:\n"
-"%s"
+msgid "  (use \"%s\" for details)\n"
+msgstr "  (dùng \"%s\" để biết thêm chi tiết)\n"
 
-#: unpack-trees.c:177
+#: remote.c:2037
 #, c-format
-msgid ""
-"The following working tree files would be removed by sparse checkout "
-"update:\n"
-"%s"
-msgstr ""
-"Các tập tin cây làm việc chưa được theo dõi sau đây sẽ bị xóa bỏ bởi cập "
-"nhật checkout rải rác:\n"
-"%s"
+msgid "Your branch is ahead of '%s' by %d commit.\n"
+msgid_plural "Your branch is ahead of '%s' by %d commits.\n"
+msgstr[0] "Nhánh của bạn đứng trước “%s” %d lần chuyển giao.\n"
 
-#: unpack-trees.c:179
+#: remote.c:2043
+msgid "  (use \"git push\" to publish your local commits)\n"
+msgstr "  (dùng \"git push\" để xuất bản các lần chuyển giao nội bộ của bạn)\n"
+
+#: remote.c:2046
+#, c-format
+msgid "Your branch is behind '%s' by %d commit, and can be fast-forwarded.\n"
+msgid_plural ""
+"Your branch is behind '%s' by %d commits, and can be fast-forwarded.\n"
+msgstr[0] ""
+"Nhánh của bạn đứng đằng sau “%s” %d lần chuyển giao, và có thể được chuyển-"
+"tiếp-nhanh.\n"
+
+#: remote.c:2054
+msgid "  (use \"git pull\" to update your local branch)\n"
+msgstr "  (dùng \"git pull\" để cập nhật nhánh nội bộ của bạn)\n"
+
+#: remote.c:2057
 #, c-format
 msgid ""
-"Cannot update submodule:\n"
-"%s"
+"Your branch and '%s' have diverged,\n"
+"and have %d and %d different commit each, respectively.\n"
+msgid_plural ""
+"Your branch and '%s' have diverged,\n"
+"and have %d and %d different commits each, respectively.\n"
+msgstr[0] ""
+"Nhánh của bạn và “%s” bị phân kỳ,\n"
+"và có %d và %d lần chuyển giao khác nhau cho từng cái,\n"
+"tương ứng với mỗi lần.\n"
+
+#: remote.c:2067
+msgid "  (use \"git pull\" to merge the remote branch into yours)\n"
 msgstr ""
-"Không thể cập nhật mô-đun-con:\n"
-"%s"
+"  (dùng \"git pull\" để hòa trộn nhánh trên máy chủ vào trong nhánh của "
+"bạn)\n"
 
-#: unpack-trees.c:262
+#: remote.c:2250
 #, c-format
-msgid "Aborting\n"
-msgstr "Bãi bỏ\n"
+msgid "cannot parse expected object name '%s'"
+msgstr "không thể phân tích tên đối tượng mong muốn “%s”"
 
-#: unpack-trees.c:344
-msgid "Checking out files"
-msgstr "Đang lấy ra các tập tin"
+#: replace-object.c:21
+#, c-format
+msgid "bad replace ref name: %s"
+msgstr "tên tham chiếu thay thế bị sai: %s"
 
-#: urlmatch.c:163
-msgid "invalid URL scheme name or missing '://' suffix"
-msgstr "tên lược đồ URL không hợp lệ, hoặc thiếu hậu tố “://”"
+#: replace-object.c:30
+#, c-format
+msgid "duplicate replace ref: %s"
+msgstr "tham chiếu thay thế bị trùng: %s"
 
-#: urlmatch.c:187 urlmatch.c:346 urlmatch.c:405
+#: replace-object.c:73
 #, c-format
-msgid "invalid %XX escape sequence"
-msgstr "thoát chuỗi %XX không hợp lệ"
+msgid "replace depth too high for object %s"
+msgstr "độ sâu thay thế quá cao cho đối tượng %s"
 
-#: urlmatch.c:215
-msgid "missing host and scheme is not 'file:'"
-msgstr "thiếu máy chủ và lược đồ thì không phải là giao thức “file:”"
+#: rerere.c:217 rerere.c:226 rerere.c:229
+msgid "corrupt MERGE_RR"
+msgstr "MERGE_RR sai hỏng"
 
-#: urlmatch.c:232
-msgid "a 'file:' URL may not have a port number"
-msgstr "URL kiểu “file:” không được chứa cổng"
+#: rerere.c:264 rerere.c:269
+msgid "unable to write rerere record"
+msgstr "không thể ghi bản ghi rerere"
 
-#: urlmatch.c:247
-msgid "invalid characters in host name"
-msgstr "có các ký tự không hợp lệ trong tên máy"
+#: rerere.c:495
+#, c-format
+msgid "there were errors while writing '%s' (%s)"
+msgstr "gặp lỗi đọc khi đang ghi “%s” (%s)"
 
-#: urlmatch.c:292 urlmatch.c:303
-msgid "invalid port number"
-msgstr "tên cổng không hợp lệ"
+#: rerere.c:498
+#, c-format
+msgid "failed to flush '%s'"
+msgstr "gặp lỗi khi đẩy dữ liệu “%s” lên đĩa"
 
-#: urlmatch.c:371
-msgid "invalid '..' path segment"
-msgstr "đoạn đường dẫn “..” không hợp lệ"
+#: rerere.c:503 rerere.c:1039
+#, c-format
+msgid "could not parse conflict hunks in '%s'"
+msgstr "không thể phân tích các mảnh xung đột trong “%s”"
 
-#: worktree.c:245 builtin/am.c:2147
+#: rerere.c:684
 #, c-format
-msgid "failed to read '%s'"
-msgstr "gặp lỗi khi đọc “%s”"
+msgid "failed utime() on '%s'"
+msgstr "gặp lỗi utime() trên “%s”"
 
-#: worktree.c:291
+#: rerere.c:694
 #, c-format
-msgid "'%s' at main working tree is not the repository directory"
-msgstr "“%s” tại cây làm việc chình không phải là thư mục kho"
+msgid "writing '%s' failed"
+msgstr "gặp lỗi khi đang ghi “%s”"
 
-#: worktree.c:302
+#: rerere.c:714
 #, c-format
-msgid "'%s' file does not contain absolute path to the working tree location"
-msgstr ""
-"tập tin “%s” không chứa đường dẫn tuyệt đối đến vị trí cây làm việc hiện"
+msgid "Staged '%s' using previous resolution."
+msgstr "Đã tạm cất “%s” sử dụng cách phân giải kế trước."
 
-#: worktree.c:314
+#: rerere.c:753
 #, c-format
-msgid "'%s' does not exist"
-msgstr "\"%s\" không tồn tại"
+msgid "Recorded resolution for '%s'."
+msgstr "Cách giải quyết đã ghi lại cho “%s”."
 
-#: worktree.c:320
+#: rerere.c:788
 #, c-format
-msgid "'%s' is not a .git file, error code %d"
-msgstr "“%s” không phải là tập tin .git, mã lỗi %d"
+msgid "Resolved '%s' using previous resolution."
+msgstr "Đã phân giải giải “%s” sử dụng cách giải quyết kế trước."
 
-#: worktree.c:328
+#: rerere.c:803
 #, c-format
-msgid "'%s' does not point back to '%s'"
-msgstr "“%s” không chỉ ngược đến “%s”"
+msgid "cannot unlink stray '%s'"
+msgstr "không thể unlink stray “%s”"
 
-#: wrapper.c:223 wrapper.c:393
+#: rerere.c:807
 #, c-format
-msgid "could not open '%s' for reading and writing"
-msgstr "không thể mở “%s” để đọc và ghi"
+msgid "Recorded preimage for '%s'"
+msgstr "Preimage đã được ghi lại cho “%s”"
 
-#: wrapper.c:227 wrapper.c:397 builtin/am.c:320 builtin/am.c:770
-#: builtin/am.c:862 builtin/merge.c:1043
+#: rerere.c:881 submodule.c:2067 builtin/log.c:1871
+#: builtin/submodule--helper.c:1436 builtin/submodule--helper.c:1448
 #, c-format
-msgid "could not open '%s' for reading"
-msgstr "không thể mở “%s” để đọc"
+msgid "could not create directory '%s'"
+msgstr "không thể tạo thư mục “%s”"
 
-#: wrapper.c:424 wrapper.c:624
+#: rerere.c:1057
 #, c-format
-msgid "unable to access '%s'"
-msgstr "không thể truy cập “%s”"
+msgid "failed to update conflicted state in '%s'"
+msgstr "gặp lỗi khi chạy cập nhật trạng thái bị xung đột trong “%s”"
 
-#: wrapper.c:632
-msgid "unable to get current working directory"
-msgstr "Không thể lấy thư mục làm việc hiện hành"
+#: rerere.c:1068 rerere.c:1075
+#, c-format
+msgid "no remembered resolution for '%s'"
+msgstr "đừng nhó các giải quyết cho “%s”"
 
-#: wt-status.c:154
-msgid "Unmerged paths:"
-msgstr "Những đường dẫn chưa được hòa trộn:"
+#: rerere.c:1077
+#, c-format
+msgid "cannot unlink '%s'"
+msgstr "không thể unlink “%s”"
 
-#: wt-status.c:181 wt-status.c:208
+#: rerere.c:1087
 #, c-format
-msgid "  (use \"git reset %s <file>...\" to unstage)"
-msgstr "  (dùng \"git reset %s <tập-tin>…\" để bỏ ra khỏi bệ phóng)"
+msgid "Updated preimage for '%s'"
+msgstr "Đã cập nhật preimage cho “%s”"
 
-#: wt-status.c:183 wt-status.c:210
-msgid "  (use \"git rm --cached <file>...\" to unstage)"
-msgstr "  (dùng \"git rm --cached <tập-tin>…\" để bỏ ra khỏi bệ phóng)"
+#: rerere.c:1096
+#, c-format
+msgid "Forgot resolution for '%s'\n"
+msgstr "Quên phân giải cho “%s”\n"
 
-#: wt-status.c:187
-msgid "  (use \"git add <file>...\" to mark resolution)"
-msgstr "  (dùng \"git add <tập-tin>…\" để đánh dấu là cần giải quyết)"
+#: rerere.c:1199
+msgid "unable to open rr-cache directory"
+msgstr "không thể mở thư mục rr-cache"
 
-#: wt-status.c:189 wt-status.c:193
-msgid "  (use \"git add/rm <file>...\" as appropriate to mark resolution)"
-msgstr ""
-"  (dùng \"git add/rm <tập-tin>…\" như là một cách thích hợp để đánh dấu là "
-"cần được giải quyết)"
+#: revision.c:2497
+msgid "your current branch appears to be broken"
+msgstr "nhánh hiện tại của bạn có vẻ như bị hỏng"
 
-#: wt-status.c:191
-msgid "  (use \"git rm <file>...\" to mark resolution)"
-msgstr "  (dùng \"git rm <tập-tin>…\" để đánh dấu là cần giải quyết)"
+#: revision.c:2500
+#, c-format
+msgid "your current branch '%s' does not have any commits yet"
+msgstr "nhánh hiện tại của bạn “%s” không có một lần chuyển giao nào cả"
 
-#: wt-status.c:202 wt-status.c:1015
-msgid "Changes to be committed:"
-msgstr "Những thay đổi sẽ được chuyển giao:"
+#: revision.c:2708
+msgid "--first-parent is incompatible with --bisect"
+msgstr "--first-parent xung khắc với --bisect"
 
-#: wt-status.c:220 wt-status.c:1024
-msgid "Changes not staged for commit:"
-msgstr "Các thay đổi chưa được đặt lên bệ phóng để chuyển giao:"
+#: revision.c:2712
+msgid "-L does not yet support diff formats besides -p and -s"
+msgstr "-L vẫn chưa hỗ trợ định dạng khác biệt nào ngoài -p và -s"
 
-#: wt-status.c:224
-msgid "  (use \"git add <file>...\" to update what will be committed)"
-msgstr "  (dùng \"git add <tập-tin>…\" để cập nhật những gì sẽ chuyển giao)"
+#: run-command.c:762
+msgid "open /dev/null failed"
+msgstr "gặp lỗi khi mở “/dev/null”"
 
-#: wt-status.c:226
-msgid "  (use \"git add/rm <file>...\" to update what will be committed)"
-msgstr ""
-"  (dùng \"git add/rm <tập-tin>…\" để cập nhật những gì sẽ được chuyển giao)"
+#: run-command.c:1268
+#, c-format
+msgid "cannot create async thread: %s"
+msgstr "không thể tạo tuyến async: %s"
 
-#: wt-status.c:227
+#: run-command.c:1332
+#, c-format
 msgid ""
-"  (use \"git checkout -- <file>...\" to discard changes in working directory)"
+"The '%s' hook was ignored because it's not set as executable.\n"
+"You can disable this warning with `git config advice.ignoredHook false`."
 msgstr ""
-"  (dùng \"git checkout -- <tập-tin>…\" để loại bỏ các thay đổi trong thư mục "
-"làm việc)"
+"Móc “%s” bị bỏ qua bởi vì nó không thể đặt là thực thi được.\n"
+"Bạn có thể tắt cảnh báo này bằng “git config advice.ignoredHook false“."
 
-#: wt-status.c:229
-msgid "  (commit or discard the untracked or modified content in submodules)"
+#: send-pack.c:144
+msgid "unexpected flush packet while reading remote unpack status"
 msgstr ""
-"  (chuyển giao hoặc là loại bỏ các nội dung chưa được theo dõi hay đã sửa "
-"chữa trong mô-đun-con)"
+"gặp gói flush không cần trong khi đọc tình trạng giải nén gói trên máy chủ"
 
-#: wt-status.c:241
+#: send-pack.c:146
 #, c-format
-msgid "  (use \"git %s <file>...\" to include in what will be committed)"
-msgstr ""
-"  (dùng \"git %s <tập-tin>…\" để thêm vào những gì cần được chuyển giao)"
-
-#: wt-status.c:256
-msgid "both deleted:"
-msgstr "bị xóa bởi cả hai:"
-
-#: wt-status.c:258
-msgid "added by us:"
-msgstr "được thêm vào bởi chúng ta:"
-
-#: wt-status.c:260
-msgid "deleted by them:"
-msgstr "bị xóa đi bởi họ:"
-
-#: wt-status.c:262
-msgid "added by them:"
-msgstr "được thêm vào bởi họ:"
-
-#: wt-status.c:264
-msgid "deleted by us:"
-msgstr "bị xóa bởi chúng ta:"
-
-#: wt-status.c:266
-msgid "both added:"
-msgstr "được thêm vào bởi cả hai:"
+msgid "unable to parse remote unpack status: %s"
+msgstr "không thể phân tích tình trạng unpack máy chủ: %s"
 
-#: wt-status.c:268
-msgid "both modified:"
-msgstr "bị sửa bởi cả hai:"
+#: send-pack.c:148
+#, c-format
+msgid "remote unpack failed: %s"
+msgstr "máy chủ gặp lỗi unpack: %s"
 
-#: wt-status.c:278
-msgid "new file:"
-msgstr "tập tin mới:"
+#: send-pack.c:309
+msgid "failed to sign the push certificate"
+msgstr "gặp lỗi khi ký chứng thực đẩy"
 
-#: wt-status.c:280
-msgid "copied:"
-msgstr "đã chép:"
+#: send-pack.c:423
+msgid "the receiving end does not support --signed push"
+msgstr "kết thúc nhận không hỗ trợ đẩy --signed"
 
-#: wt-status.c:282
-msgid "deleted:"
-msgstr "đã xóa:"
+#: send-pack.c:425
+msgid ""
+"not sending a push certificate since the receiving end does not support --"
+"signed push"
+msgstr ""
+"đừng gửi giấy chứng nhận đẩy trước khi kết thúc nhận không hỗ trợ đẩy --"
+"signed"
 
-#: wt-status.c:284
-msgid "modified:"
-msgstr "đã sửa:"
+#: send-pack.c:437
+msgid "the receiving end does not support --atomic push"
+msgstr "kết thúc nhận không hỗ trợ đẩy --atomic"
 
-#: wt-status.c:286
-msgid "renamed:"
-msgstr "đã đổi tên:"
+#: send-pack.c:442
+msgid "the receiving end does not support push options"
+msgstr "kết thúc nhận không hỗ trợ các tùy chọn của lệnh push"
 
-#: wt-status.c:288
-msgid "typechange:"
-msgstr "đổi-kiểu:"
+#: sequencer.c:189
+#, c-format
+msgid "invalid commit message cleanup mode '%s'"
+msgstr "chế độ dọn dẹp ghi chú các lần chuyển giao không hợp lệ “%s”"
 
-#: wt-status.c:290
-msgid "unknown:"
-msgstr "không hiểu:"
+#: sequencer.c:294
+#, c-format
+msgid "could not delete '%s'"
+msgstr "không thể xóa bỏ “%s”"
 
-#: wt-status.c:292
-msgid "unmerged:"
-msgstr "chưa hòa trộn:"
+#: sequencer.c:313 builtin/rebase.c:781 builtin/rebase.c:1706 builtin/rm.c:369
+#, c-format
+msgid "could not remove '%s'"
+msgstr "không thể gỡ bỏ “%s”"
 
-#: wt-status.c:372
-msgid "new commits, "
-msgstr "lần chuyển giao mới, "
+#: sequencer.c:323
+msgid "revert"
+msgstr "hoàn nguyên"
 
-#: wt-status.c:374
-msgid "modified content, "
-msgstr "nội dung bị sửa đổi, "
+#: sequencer.c:325
+msgid "cherry-pick"
+msgstr "cherry-pick"
 
-#: wt-status.c:376
-msgid "untracked content, "
-msgstr "nội dung chưa được theo dõi, "
+#: sequencer.c:327
+msgid "rebase -i"
+msgstr "rebase -i"
 
-#: wt-status.c:853
+#: sequencer.c:329
 #, c-format
-msgid "Your stash currently has %d entry"
-msgid_plural "Your stash currently has %d entries"
-msgstr[0] "Bạn hiện nay ở trong phần cất đi đang có %d mục"
-
-#: wt-status.c:885
-msgid "Submodules changed but not updated:"
-msgstr "Những mô-đun-con đã bị thay đổi nhưng chưa được cập nhật:"
+msgid "unknown action: %d"
+msgstr "không nhận ra thao tác: %d"
 
-#: wt-status.c:887
-msgid "Submodule changes to be committed:"
-msgstr "Những mô-đun-con thay đổi đã được chuyển giao:"
+#: sequencer.c:387
+msgid ""
+"after resolving the conflicts, mark the corrected paths\n"
+"with 'git add <paths>' or 'git rm <paths>'"
+msgstr ""
+"sau khi giải quyết các xung đột, đánh dấu đường dẫn đã sửa\n"
+"với lệnh “git add </các/đường/dẫn>” hoặc “git rm </các/đường/dẫn>”"
 
-#: wt-status.c:969
+#: sequencer.c:390
 msgid ""
-"Do not modify or remove the line above.\n"
-"Everything below it will be ignored."
+"after resolving the conflicts, mark the corrected paths\n"
+"with 'git add <paths>' or 'git rm <paths>'\n"
+"and commit the result with 'git commit'"
 msgstr ""
-"Không sửa hay xóa bỏ đường ở trên.\n"
-"Mọi thứ phía dưới sẽ được xóa bỏ."
+"sau khi giải quyết các xung đột, đánh dấu đường dẫn đã sửa\n"
+"với lệnh “git add </các/đường/dẫn>” hoặc “git rm </các/đường/dẫn>”\n"
+"và chuyển giao kết quả bằng lệnh “git commit”"
 
-#: wt-status.c:1084
-msgid "You have unmerged paths."
-msgstr "Bạn có những đường dẫn chưa được hòa trộn."
+#: sequencer.c:403 sequencer.c:2993
+#, c-format
+msgid "could not lock '%s'"
+msgstr "không thể khóa “%s”"
 
-#: wt-status.c:1087
-msgid "  (fix conflicts and run \"git commit\")"
-msgstr "  (sửa các xung đột rồi chạy \"git commit\")"
+#: sequencer.c:410
+#, c-format
+msgid "could not write eol to '%s'"
+msgstr "không thể ghi eol vào “%s”"
 
-#: wt-status.c:1089
-msgid "  (use \"git merge --abort\" to abort the merge)"
-msgstr "  (dùng \"git merge --abort\" để bãi bỏ việc hòa trộn)"
+#: sequencer.c:415 sequencer.c:2798 sequencer.c:2999 sequencer.c:3013
+#: sequencer.c:3277
+#, c-format
+msgid "failed to finalize '%s'"
+msgstr "gặp lỗi khi hoàn thành “%s”"
 
-#: wt-status.c:1094
-msgid "All conflicts fixed but you are still merging."
-msgstr "Tất cả các xung đột đã được giải quyết nhưng bạn vẫn đang hòa trộn."
+#: sequencer.c:438 sequencer.c:1707 sequencer.c:2818 sequencer.c:3259
+#: sequencer.c:3368 builtin/am.c:244 builtin/commit.c:783 builtin/merge.c:1117
+#: builtin/rebase.c:589
+#, c-format
+msgid "could not read '%s'"
+msgstr "không thể đọc “%s”"
 
-#: wt-status.c:1097
-msgid "  (use \"git commit\" to conclude merge)"
-msgstr "  (dùng \"git commit\" để hoàn tất việc hòa trộn)"
+#: sequencer.c:464
+#, c-format
+msgid "your local changes would be overwritten by %s."
+msgstr "các thay đổi nội bộ của bạn có thể bị ghi đè bởi lệnh %s."
 
-#: wt-status.c:1107
-msgid "You are in the middle of an am session."
-msgstr "Bạn đang ở giữa của một phiên “am”."
+#: sequencer.c:468
+msgid "commit your changes or stash them to proceed."
+msgstr "chuyển giao các thay đổi của bạn hay tạm cất (stash) chúng để xử lý."
 
-#: wt-status.c:1110
-msgid "The current patch is empty."
-msgstr "Miếng vá hiện tại bị trống rỗng."
+#: sequencer.c:500
+#, c-format
+msgid "%s: fast-forward"
+msgstr "%s: chuyển-tiếp-nhanh"
 
-#: wt-status.c:1114
-msgid "  (fix conflicts and then run \"git am --continue\")"
-msgstr "  (sửa các xung đột và sau đó chạy lệnh \"git am --continue\")"
+#: sequencer.c:539 builtin/tag.c:565
+#, c-format
+msgid "Invalid cleanup mode %s"
+msgstr "Chế độ dọn dẹp không hợp lệ %s"
 
-#: wt-status.c:1116
-msgid "  (use \"git am --skip\" to skip this patch)"
-msgstr "  (dùng \"git am --skip\" để bỏ qua miếng vá này)"
+#. TRANSLATORS: %s will be "revert", "cherry-pick" or
+#. "rebase -i".
+#.
+#: sequencer.c:633
+#, c-format
+msgid "%s: Unable to write new index file"
+msgstr "%s: Không thể ghi tập tin lưu bảng mục lục mới"
 
-#: wt-status.c:1118
-msgid "  (use \"git am --abort\" to restore the original branch)"
-msgstr "  (dùng \"git am --abort\" để phục hồi lại nhánh nguyên thủy)"
+#: sequencer.c:650
+msgid "unable to update cache tree"
+msgstr "không thể cập nhật cây bộ nhớ đệm"
 
-#: wt-status.c:1250
-msgid "git-rebase-todo is missing."
-msgstr "thiếu git-rebase-todo"
+#: sequencer.c:664
+msgid "could not resolve HEAD commit"
+msgstr "không thể phân giải lần chuyển giao HEAD"
 
-#: wt-status.c:1252
-msgid "No commands done."
-msgstr "Không thực hiện lệnh nào."
+#: sequencer.c:744
+#, c-format
+msgid "no key present in '%.*s'"
+msgstr "không có khóa hiện diện trong “%.*s”"
 
-#: wt-status.c:1255
+#: sequencer.c:755
 #, c-format
-msgid "Last command done (%d command done):"
-msgid_plural "Last commands done (%d commands done):"
-msgstr[0] "Lệnh thực hiện cuối (%d lệnh được thực thi):"
+msgid "unable to dequote value of '%s'"
+msgstr "không thể giải trích dẫn giá trị của “%s”"
 
-#: wt-status.c:1266
+#: sequencer.c:792 wrapper.c:190 wrapper.c:360 builtin/am.c:705
+#: builtin/am.c:797 builtin/merge.c:1114 builtin/rebase.c:1074
 #, c-format
-msgid "  (see more in file %s)"
-msgstr "  (xem thêm trong %s)"
+msgid "could not open '%s' for reading"
+msgstr "không thể mở “%s” để đọc"
 
-#: wt-status.c:1271
-msgid "No commands remaining."
-msgstr "Không có lệnh nào còn lại."
+#: sequencer.c:802
+msgid "'GIT_AUTHOR_NAME' already given"
+msgstr "“GIT_AUTHOR_NAME” đã sẵn đưa ra rồi"
 
-#: wt-status.c:1274
-#, c-format
-msgid "Next command to do (%d remaining command):"
-msgid_plural "Next commands to do (%d remaining commands):"
-msgstr[0] "Lệnh cần làm kế tiếp (%d lệnh còn lại):"
+#: sequencer.c:807
+msgid "'GIT_AUTHOR_EMAIL' already given"
+msgstr "“GIT_AUTHOR_EMAIL” đã sẵn đưa ra rồi"
 
-#: wt-status.c:1282
-msgid "  (use \"git rebase --edit-todo\" to view and edit)"
-msgstr "  (dùng lệnh \"git rebase --edit-todo\" để xem và sửa)"
+#: sequencer.c:812
+msgid "'GIT_AUTHOR_DATE' already given"
+msgstr "“GIT_AUTHOR_DATE” đã sẵn đưa ra rồi"
 
-#: wt-status.c:1295
+#: sequencer.c:816
 #, c-format
-msgid "You are currently rebasing branch '%s' on '%s'."
-msgstr "Bạn hiện nay đang thực hiện việc “rebase” nhánh “%s” trên “%s”."
+msgid "unknown variable '%s'"
+msgstr "không hiểu biến “%s”"
 
-#: wt-status.c:1300
-msgid "You are currently rebasing."
-msgstr "Bạn hiện nay đang thực hiện việc “rebase” (“cải tổ”)."
-
-#: wt-status.c:1314
-msgid "  (fix conflicts and then run \"git rebase --continue\")"
-msgstr ""
-"  (sửa các xung đột và sau đó chạy lệnh “cải tổ” \"git rebase --continue\")"
+#: sequencer.c:821
+msgid "missing 'GIT_AUTHOR_NAME'"
+msgstr "thiếu “GIT_AUTHOR_NAME”"
 
-#: wt-status.c:1316
-msgid "  (use \"git rebase --skip\" to skip this patch)"
-msgstr "  (dùng lệnh “cải tổ” \"git rebase --skip\" để bỏ qua lần vá này)"
+#: sequencer.c:823
+msgid "missing 'GIT_AUTHOR_EMAIL'"
+msgstr "thiếu “GIT_AUTHOR_EMAIL”"
 
-#: wt-status.c:1318
-msgid "  (use \"git rebase --abort\" to check out the original branch)"
-msgstr ""
-"  (dùng lệnh “cải tổ” \"git rebase --abort\" để check-out nhánh nguyên thủy)"
+#: sequencer.c:825
+msgid "missing 'GIT_AUTHOR_DATE'"
+msgstr "thiếu “GIT_AUTHOR_DATE”"
 
-#: wt-status.c:1324
-msgid "  (all conflicts fixed: run \"git rebase --continue\")"
-msgstr ""
-"  (khi tất cả các xung đột đã sửa xong: chạy lệnh “cải tổ” \"git rebase --"
-"continue\")"
+#: sequencer.c:902 sequencer.c:1427
+msgid "malformed ident line"
+msgstr "thụt đầu dòng dị hình"
 
-#: wt-status.c:1328
+#: sequencer.c:925
 #, c-format
 msgid ""
-"You are currently splitting a commit while rebasing branch '%s' on '%s'."
-msgstr ""
-"Bạn hiện nay đang thực hiện việc chia tách một lần chuyển giao trong khi "
-"đang “rebase” nhánh “%s” trên “%s”."
-
-#: wt-status.c:1333
-msgid "You are currently splitting a commit during a rebase."
-msgstr ""
-"Bạn hiện tại đang cắt đôi một lần chuyển giao trong khi đang thực hiện việc "
-"rebase."
-
-#: wt-status.c:1336
-msgid "  (Once your working directory is clean, run \"git rebase --continue\")"
-msgstr ""
-"  (Một khi thư mục làm việc của bạn đã gọn gàng, chạy lệnh “cải tổ” \"git "
-"rebase --continue\")"
-
-#: wt-status.c:1340
-#, c-format
-msgid "You are currently editing a commit while rebasing branch '%s' on '%s'."
+"you have staged changes in your working tree\n"
+"If these changes are meant to be squashed into the previous commit, run:\n"
+"\n"
+"  git commit --amend %s\n"
+"\n"
+"If they are meant to go into a new commit, run:\n"
+"\n"
+"  git commit %s\n"
+"\n"
+"In both cases, once you're done, continue with:\n"
+"\n"
+"  git rebase --continue\n"
 msgstr ""
-"Bạn hiện nay đang thực hiện việc sửa chữa một lần chuyển giao trong khi đang "
-"rebase nhánh “%s” trên “%s”."
+"bạn có các thay đổi so với trong bệ phóng trong thư mục làm việc của bạn.\n"
+"Nếu các thay đổi này là muốn squash vào lần chuyển giao kế trước, chạy:\n"
+"\n"
+"  git commit --amend %s\n"
+"\n"
+"Nếu chúng có ý là đi đến lần chuyển giao mới, thì chạy:\n"
+"\n"
+"  git commit %s\n"
+"\n"
+"Trong cả hai trường hợp, một khi bạn làm xong, tiếp tục bằng:\n"
+"\n"
+"  git rebase --continue\n"
 
-#: wt-status.c:1345
-msgid "You are currently editing a commit during a rebase."
-msgstr "Bạn hiện đang sửa một lần chuyển giao trong khi bạn thực hiện rebase."
+#: sequencer.c:1218
+msgid "'prepare-commit-msg' hook failed"
+msgstr "móc “prepare-commit-msg” bị lỗi"
 
-#: wt-status.c:1348
-msgid "  (use \"git commit --amend\" to amend the current commit)"
-msgstr "  (dùng \"git commit --amend\" để “tu bổ” lần chuyển giao hiện tại)"
+#: sequencer.c:1224
+msgid ""
+"Your name and email address were configured automatically based\n"
+"on your username and hostname. Please check that they are accurate.\n"
+"You can suppress this message by setting them explicitly. Run the\n"
+"following command and follow the instructions in your editor to edit\n"
+"your configuration file:\n"
+"\n"
+"    git config --global --edit\n"
+"\n"
+"After doing this, you may fix the identity used for this commit with:\n"
+"\n"
+"    git commit --amend --reset-author\n"
+msgstr ""
+"Tên và địa chỉ thư điện tử của bạn được cấu hình một cách tự động trên cơ "
+"sở\n"
+"tài khoản và địa chỉ máy chủ của bạn. Xin hãy kiểm tra xem chúng có chính "
+"xác không.\n"
+"Bạn có thể chặn những thông báo kiểu này bằng cách cài đặt các thông tin "
+"trên\n"
+"một cách rõ ràng. Chạy lệnh sau đây là theo các hướng dẫn trong bộ soạn "
+"thảo\n"
+"để chỉnh sửa tập tin cấu hình của mình:\n"
+"\n"
+"    git config --global --edit\n"
+"\n"
+"Sau khi thực hiện xong, bạn có thể sửa chữa định danh được sử dụng cho\n"
+"lần chuyển giao này với lệnh:\n"
+"\n"
+"    git commit --amend --reset-author\n"
 
-#: wt-status.c:1350
+#: sequencer.c:1237
 msgid ""
-"  (use \"git rebase --continue\" once you are satisfied with your changes)"
+"Your name and email address were configured automatically based\n"
+"on your username and hostname. Please check that they are accurate.\n"
+"You can suppress this message by setting them explicitly:\n"
+"\n"
+"    git config --global user.name \"Your Name\"\n"
+"    git config --global user.email you@example.com\n"
+"\n"
+"After doing this, you may fix the identity used for this commit with:\n"
+"\n"
+"    git commit --amend --reset-author\n"
 msgstr ""
-"  (chạy lệnh “cải tổ” \"git rebase --continue\" một khi bạn cảm thấy hài "
-"lòng về những thay đổi của mình)"
+"Tên và địa chỉ thư điện tử của bạn được cấu hình một cách tự động trên cơ "
+"sở\n"
+"tài khoản và địa chỉ máy chủ của bạn. Xin hãy kiểm tra xem chúng có chính "
+"xác không.\n"
+"Bạn có thể chặn những thông báo kiểu này bằng cách cài đặt các thông tin "
+"trên một cách rõ ràng:\n"
+"\n"
+"    git config --global user.name \"Tên của bạn\"\n"
+"    git config --global user.email you@example.com\n"
+"\n"
+"Sau khi thực hiện xong, bạn có thể sửa chữa định danh được sử dụng cho lần "
+"chuyển giao này với lệnh:\n"
+"\n"
+"    git commit --amend --reset-author\n"
 
-#: wt-status.c:1360
-#, c-format
-msgid "You are currently cherry-picking commit %s."
-msgstr "Bạn hiện nay đang thực hiện việc cherry-pick lần chuyển giao %s."
+#: sequencer.c:1279
+msgid "couldn't look up newly created commit"
+msgstr "không thể tìm thấy lần chuyển giao mới hơn đã được tạo"
 
-#: wt-status.c:1365
-msgid "  (fix conflicts and run \"git cherry-pick --continue\")"
+#: sequencer.c:1281
+msgid "could not parse newly created commit"
 msgstr ""
-"  (sửa các xung đột và sau đó chạy lệnh \"git cherry-pick --continue\")"
+"không thể phân tích cú pháp của đối tượng chuyển giao mới hơn đã được tạo"
 
-#: wt-status.c:1368
-msgid "  (all conflicts fixed: run \"git cherry-pick --continue\")"
-msgstr ""
-"  (khi tất cả các xung đột đã sửa xong: chạy lệnh \"git cherry-pick --"
-"continue\")"
+#: sequencer.c:1327
+msgid "unable to resolve HEAD after creating commit"
+msgstr "không thể phân giải HEAD sau khi tạo lần chuyển giao"
 
-#: wt-status.c:1370
-msgid "  (use \"git cherry-pick --abort\" to cancel the cherry-pick operation)"
-msgstr "  (dùng \"git cherry-pick --abort\" để hủy bỏ thao tác cherry-pick)"
+#: sequencer.c:1329
+msgid "detached HEAD"
+msgstr "đã rời khỏi HEAD"
+
+#: sequencer.c:1333
+msgid " (root-commit)"
+msgstr " (root-commit)"
 
-#: wt-status.c:1379
+#: sequencer.c:1354
+msgid "could not parse HEAD"
+msgstr "không thể phân tích HEAD"
+
+#: sequencer.c:1356
 #, c-format
-msgid "You are currently reverting commit %s."
-msgstr "Bạn hiện nay đang thực hiện thao tác hoàn nguyên lần chuyển giao “%s”."
+msgid "HEAD %s is not a commit!"
+msgstr "HEAD %s không phải là một lần chuyển giao!"
 
-#: wt-status.c:1384
-msgid "  (fix conflicts and run \"git revert --continue\")"
-msgstr "  (sửa các xung đột và sau đó chạy lệnh \"git revert --continue\")"
+#: sequencer.c:1360 sequencer.c:1458 builtin/commit.c:1569
+msgid "could not parse HEAD commit"
+msgstr "không thể phân tích commit (lần chuyển giao) HEAD"
 
-#: wt-status.c:1387
-msgid "  (all conflicts fixed: run \"git revert --continue\")"
-msgstr ""
-"  (khi tất cả các xung đột đã sửa xong: chạy lệnh \"git revert --continue\")"
+#: sequencer.c:1411 sequencer.c:2055
+msgid "unable to parse commit author"
+msgstr "không thể phân tích tác giả của lần chuyển giao"
 
-#: wt-status.c:1389
-msgid "  (use \"git revert --abort\" to cancel the revert operation)"
-msgstr "  (dùng \"git revert --abort\" để hủy bỏ thao tác hoàn nguyên)"
+#: sequencer.c:1431
+msgid "corrupted author without date information"
+msgstr "tác giả sai hỏng không có thông tin này tháng"
 
-#: wt-status.c:1400
-#, c-format
-msgid "You are currently bisecting, started from branch '%s'."
-msgstr ""
-"Bạn hiện nay đang thực hiện thao tác di chuyển nửa bước (bisect), bắt đầu từ "
-"nhánh “%s”."
+#: sequencer.c:1447 builtin/am.c:1561 builtin/merge.c:684
+msgid "git write-tree failed to write a tree"
+msgstr "lệnh git write-tree gặp lỗi khi ghi một cây"
 
-#: wt-status.c:1404
-msgid "You are currently bisecting."
-msgstr "Bạn hiện tại đang thực hiện việc bisect (di chuyển nửa bước)."
+#: sequencer.c:1480 sequencer.c:1550
+#, c-format
+msgid "unable to read commit message from '%s'"
+msgstr "không thể đọc phần chú thích (message) từ “%s”"
 
-#: wt-status.c:1407
-msgid "  (use \"git bisect reset\" to get back to the original branch)"
-msgstr "  (dùng \"git bisect reset\" để quay trở lại nhánh nguyên thủy)"
+#: sequencer.c:1516 builtin/am.c:1583 builtin/commit.c:1668 builtin/merge.c:883
+#: builtin/merge.c:908
+msgid "failed to write commit object"
+msgstr "gặp lỗi khi ghi đối tượng chuyển giao"
 
-#: wt-status.c:1604
-msgid "On branch "
-msgstr "Trên nhánh "
+#: sequencer.c:1577
+#, c-format
+msgid "could not parse commit %s"
+msgstr "không thể phân tích lần chuyển giao %s"
 
-#: wt-status.c:1610
-msgid "interactive rebase in progress; onto "
-msgstr "rebase ở chế độ tương tác đang được thực hiện; lên trên "
+#: sequencer.c:1582
+#, c-format
+msgid "could not parse parent commit %s"
+msgstr "không thể phân tích lần chuyển giao cha mẹ “%s”"
 
-#: wt-status.c:1612
-msgid "rebase in progress; onto "
-msgstr "rebase đang được thực hiện: lên trên "
+#: sequencer.c:1656 sequencer.c:1767
+#, c-format
+msgid "unknown command: %d"
+msgstr "không hiểu câu lệnh %d"
 
-#: wt-status.c:1617
-msgid "HEAD detached at "
-msgstr "HEAD được tách rời tại "
+#: sequencer.c:1714 sequencer.c:1739
+#, c-format
+msgid "This is a combination of %d commits."
+msgstr "Đây là tổ hợp của %d lần chuyển giao."
 
-#: wt-status.c:1619
-msgid "HEAD detached from "
-msgstr "HEAD được tách rời từ "
+#: sequencer.c:1724
+msgid "need a HEAD to fixup"
+msgstr "cần một HEAD để sửa"
 
-#: wt-status.c:1622
-msgid "Not currently on any branch."
-msgstr "Hiện tại chẳng ở nhánh nào cả."
+#: sequencer.c:1726 sequencer.c:3304
+msgid "could not read HEAD"
+msgstr "không thể đọc HEAD"
 
-#: wt-status.c:1642
-msgid "Initial commit"
-msgstr "Lần chuyển giao khởi tạo"
+#: sequencer.c:1728
+msgid "could not read HEAD's commit message"
+msgstr "không thể đọc phần chú thích (message) của HEAD"
 
-#: wt-status.c:1643
-msgid "No commits yet"
-msgstr "Vẫn chưa chuyển giao"
+#: sequencer.c:1734
+#, c-format
+msgid "cannot write '%s'"
+msgstr "không thể ghi “%s”"
 
-#: wt-status.c:1657
-msgid "Untracked files"
-msgstr "Những tập tin chưa được theo dõi"
+#: sequencer.c:1741 git-rebase--preserve-merges.sh:496
+msgid "This is the 1st commit message:"
+msgstr "Đây là chú thích cho lần chuyển giao thứ nhất:"
 
-#: wt-status.c:1659
-msgid "Ignored files"
-msgstr "Những tập tin bị lờ đi"
+#: sequencer.c:1749
+#, c-format
+msgid "could not read commit message of %s"
+msgstr "không thể đọc phần chú thích (message) của %s"
 
-#: wt-status.c:1663
+#: sequencer.c:1756
 #, c-format
-msgid ""
-"It took %.2f seconds to enumerate untracked files. 'status -uno'\n"
-"may speed it up, but you have to be careful not to forget to add\n"
-"new files yourself (see 'git help status')."
-msgstr ""
-"Cần %.2f giây để liệt kê tất cả các tập tin chưa được theo dõi. “status -"
-"uno”\n"
-"có lẽ làm nó nhanh hơn, nhưng bạn phải cẩn thận đừng quên mình phải\n"
-"tự thêm các tập tin mới (xem “git help status”.."
+msgid "This is the commit message #%d:"
+msgstr "Đây là chú thích cho lần chuyển giao thứ #%d:"
 
-#: wt-status.c:1669
+#: sequencer.c:1762
 #, c-format
-msgid "Untracked files not listed%s"
-msgstr "Những tập tin chưa được theo dõi không được liệt kê ra %s"
+msgid "The commit message #%d will be skipped:"
+msgstr "Chú thích cho lần chuyển giao thứ #%d sẽ bị bỏ qua:"
 
-#: wt-status.c:1671
-msgid " (use -u option to show untracked files)"
-msgstr " (dùng tùy chọn -u để hiển thị các tập tin chưa được theo dõi)"
+#: sequencer.c:1850
+msgid "your index file is unmerged."
+msgstr "tập tin lưu mục lục của bạn không được hòa trộn."
 
-#: wt-status.c:1677
-msgid "No changes"
-msgstr "Không có thay đổi nào"
+#: sequencer.c:1857
+msgid "cannot fixup root commit"
+msgstr "không thể sửa chữa lần chuyển giao gốc"
 
-#: wt-status.c:1682
+#: sequencer.c:1876
 #, c-format
-msgid "no changes added to commit (use \"git add\" and/or \"git commit -a\")\n"
-msgstr ""
-"không có thay đổi nào được thêm vào để chuyển giao (dùng \"git add\" và/hoặc "
-"\"git commit -a\")\n"
+msgid "commit %s is a merge but no -m option was given."
+msgstr "lần chuyển giao %s là một lần hòa trộn nhưng không đưa ra tùy chọn -m."
 
-#: wt-status.c:1685
+#: sequencer.c:1884 sequencer.c:1892
 #, c-format
-msgid "no changes added to commit\n"
-msgstr "không có thay đổi nào được thêm vào để chuyển giao\n"
+msgid "commit %s does not have parent %d"
+msgstr "lần chuyển giao %s không có cha mẹ %d"
 
-#: wt-status.c:1688
+#: sequencer.c:1898
 #, c-format
-msgid ""
-"nothing added to commit but untracked files present (use \"git add\" to "
-"track)\n"
-msgstr ""
-"không có gì được thêm vào lần chuyển giao nhưng có những tập tin chưa được "
-"theo dõi hiện diện (dùng \"git add\" để đưa vào theo dõi)\n"
+msgid "cannot get commit message for %s"
+msgstr "không thể lấy ghi chú lần chuyển giao cho %s"
 
-#: wt-status.c:1691
+#. TRANSLATORS: The first %s will be a "todo" command like
+#. "revert" or "pick", the second %s a SHA1.
+#: sequencer.c:1917
 #, c-format
-msgid "nothing added to commit but untracked files present\n"
-msgstr ""
-"không có gì được thêm vào lần chuyển giao nhưng có những tập tin chưa được "
-"theo dõi hiện diện\n"
+msgid "%s: cannot parse parent commit %s"
+msgstr "%s: không thể phân tích lần chuyển giao mẹ của %s"
 
-#: wt-status.c:1694
+#: sequencer.c:1982
 #, c-format
-msgid "nothing to commit (create/copy files and use \"git add\" to track)\n"
-msgstr ""
-"không có gì để chuyển giao (tạo/sao-chép các tập tin và dùng \"git add\" để "
-"đưa vào theo dõi)\n"
+msgid "could not rename '%s' to '%s'"
+msgstr "không thể đổi tên “%s” thành “%s”"
 
-#: wt-status.c:1697 wt-status.c:1702
+#: sequencer.c:2037
 #, c-format
-msgid "nothing to commit\n"
-msgstr "không có gì để chuyển giao\n"
-
-#: wt-status.c:1700
-#, c-format
-msgid "nothing to commit (use -u to show untracked files)\n"
-msgstr ""
-"không có gì để chuyển giao (dùng -u xem các tập tin chưa được theo dõi)\n"
+msgid "could not revert %s... %s"
+msgstr "không thể hoàn nguyên %s… %s"
 
-#: wt-status.c:1704
+#: sequencer.c:2038
 #, c-format
-msgid "nothing to commit, working tree clean\n"
-msgstr "không có gì để chuyển giao, thư mục làm việc sạch sẽ\n"
-
-#: wt-status.c:1817
-msgid "No commits yet on "
-msgstr "Vẫn không thực hiện lệnh chuyển giao nào"
+msgid "could not apply %s... %s"
+msgstr "không thể áp dụng miếng vá %s… %s"
 
-#: wt-status.c:1821
-msgid "HEAD (no branch)"
-msgstr "HEAD (không nhánh)"
+#: sequencer.c:2105
+#, c-format
+msgid "git %s: failed to read the index"
+msgstr "git %s: gặp lỗi đọc bảng mục lục"
 
-#: wt-status.c:1852
-msgid "different"
-msgstr "khác"
+#: sequencer.c:2112
+#, c-format
+msgid "git %s: failed to refresh the index"
+msgstr "git %s: gặp lỗi khi làm tươi mới bảng mục lục"
 
-#: wt-status.c:1854 wt-status.c:1862
-msgid "behind "
-msgstr "đằng sau "
+#: sequencer.c:2189
+#, c-format
+msgid "%s does not accept arguments: '%s'"
+msgstr "%s không nhận các đối số: “%s”"
 
-#: wt-status.c:1857 wt-status.c:1860
-msgid "ahead "
-msgstr "phía trước "
+#: sequencer.c:2198
+#, c-format
+msgid "missing arguments for %s"
+msgstr "thiếu đối số cho %s"
 
-#. TRANSLATORS: the action is e.g. "pull with rebase"
-#: wt-status.c:2366
+#: sequencer.c:2235
 #, c-format
-msgid "cannot %s: You have unstaged changes."
-msgstr "không thể %s: Bạn có các thay đổi chưa được đưa lên bệ phóng."
+msgid "could not parse '%.*s'"
+msgstr "không thể phân tích cú pháp “%.*s”"
 
-#: wt-status.c:2372
-msgid "additionally, your index contains uncommitted changes."
-msgstr ""
-"thêm vào đó, bảng mục lục của bạn có chứa các thay đổi chưa được chuyển giao."
+#: sequencer.c:2289
+#, c-format
+msgid "invalid line %d: %.*s"
+msgstr "dòng không hợp lệ %d: %.*s"
 
-#: wt-status.c:2374
+#: sequencer.c:2300
 #, c-format
-msgid "cannot %s: Your index contains uncommitted changes."
-msgstr ""
-"không thể %s: Mục lục của bạn có chứa các thay đổi chưa được chuyển giao."
+msgid "cannot '%s' without a previous commit"
+msgstr "không thể “%s” thể mà không có lần chuyển giao kế trước"
 
-#: compat/precompose_utf8.c:58 builtin/clone.c:442
+#: sequencer.c:2348 builtin/rebase.c:172 builtin/rebase.c:197
+#: builtin/rebase.c:223 builtin/rebase.c:248
 #, c-format
-msgid "failed to unlink '%s'"
-msgstr "gặp lỗi khi bỏ liên kết (unlink) “%s”"
+msgid "could not read '%s'."
+msgstr "không thể đọc “%s”."
 
-#: builtin/add.c:24
-msgid "git add [<options>] [--] <pathspec>..."
-msgstr "git add [<các-tùy-chọn>] [--]  <pathspec>…"
+#: sequencer.c:2384
+msgid "cancelling a cherry picking in progress"
+msgstr "đang hủy bỏ thao tác cherry pick đang thực hiện"
+
+#: sequencer.c:2391
+msgid "cancelling a revert in progress"
+msgstr "đang hủy bỏ các thao tác hoàn nguyên đang thực hiện"
 
-#: builtin/add.c:83
+#: sequencer.c:2435
+msgid "please fix this using 'git rebase --edit-todo'."
+msgstr "vui lòng sửa lỗi này bằng cách dùng “git rebase --edit-todo”."
+
+#: sequencer.c:2437
 #, c-format
-msgid "unexpected diff status %c"
-msgstr "trạng thái lệnh diff không như mong đợi %c"
+msgid "unusable instruction sheet: '%s'"
+msgstr "bảng chỉ thị không thể dùng được: %s"
 
-#: builtin/add.c:88 builtin/commit.c:266
-msgid "updating files failed"
-msgstr "Cập nhật tập tin gặp lỗi"
+#: sequencer.c:2442
+msgid "no commits parsed."
+msgstr "không có lần chuyển giao nào được phân tích."
 
-#: builtin/add.c:98
-#, c-format
-msgid "remove '%s'\n"
-msgstr "gỡ bỏ “%s”\n"
+#: sequencer.c:2453
+msgid "cannot cherry-pick during a revert."
+msgstr "không thể cherry-pick trong khi hoàn nguyên."
 
-#: builtin/add.c:173
-msgid "Unstaged changes after refreshing the index:"
-msgstr ""
-"Đưa ra khỏi bệ phóng các thay đổi sau khi làm tươi mới lại bảng mục lục:"
+#: sequencer.c:2455
+msgid "cannot revert during a cherry-pick."
+msgstr "không thể thực hiện việc hoàn nguyên trong khi đang cherry-pick."
 
-#: builtin/add.c:233 builtin/rev-parse.c:892
-msgid "Could not read the index"
-msgstr "Không thể đọc bảng mục lục"
+#: sequencer.c:2533
+#, c-format
+msgid "invalid value for %s: %s"
+msgstr "giá trị cho %s không hợp lệ: %s"
+
+#: sequencer.c:2630
+msgid "unusable squash-onto"
+msgstr "squash-onto không dùng được"
 
-#: builtin/add.c:244
+#: sequencer.c:2646
 #, c-format
-msgid "Could not open '%s' for writing."
-msgstr "Không thể mở “%s” để ghi."
+msgid "malformed options sheet: '%s'"
+msgstr "bảng tùy chọn dị hình: “%s”"
 
-#: builtin/add.c:248
-msgid "Could not write patch"
-msgstr "Không thể ghi ra miếng vá"
+#: sequencer.c:2736 sequencer.c:4463
+msgid "empty commit set passed"
+msgstr "lần chuyển giao trống rỗng đặt là hợp quy cách"
 
-#: builtin/add.c:251
-msgid "editing patch failed"
-msgstr "gặp lỗi khi sửa miếng vá"
+#: sequencer.c:2752
+msgid "revert is already in progress"
+msgstr "có thao tác hoàn nguyên đang được thực hiện"
 
-#: builtin/add.c:254
+#: sequencer.c:2754
 #, c-format
-msgid "Could not stat '%s'"
-msgstr "Không thể lấy thông tin thống kê về “%s”"
+msgid "try \"git revert (--continue | %s--abort | --quit)\""
+msgstr "hãy thử \"git revert (--continue | %s--abort | --quit)\""
 
-#: builtin/add.c:256
-msgid "Empty patch. Aborted."
-msgstr "Miếng vá trống rỗng. Nên bỏ qua."
+#: sequencer.c:2757
+msgid "cherry-pick is already in progress"
+msgstr "có thao tác “cherry-pick” đang được thực hiện"
 
-#: builtin/add.c:261
+#: sequencer.c:2759
 #, c-format
-msgid "Could not apply '%s'"
-msgstr "Không thể áp dụng miếng vá “%s”"
+msgid "try \"git cherry-pick (--continue | %s--abort | --quit)\""
+msgstr "hãy thử \"git cherry-pick (--continue | %s--abort | --quit)\""
 
-#: builtin/add.c:269
-msgid "The following paths are ignored by one of your .gitignore files:\n"
-msgstr ""
-"Các đường dẫn theo sau đây sẽ bị lờ đi bởi một trong các tập tin .gitignore "
-"của bạn:\n"
+#: sequencer.c:2773
+#, c-format
+msgid "could not create sequencer directory '%s'"
+msgstr "không thể tạo thư mục xếp dãy “%s”"
 
-#: builtin/add.c:289 builtin/clean.c:911 builtin/fetch.c:145 builtin/mv.c:123
-#: builtin/prune-packed.c:55 builtin/pull.c:212 builtin/push.c:557
-#: builtin/remote.c:1342 builtin/rm.c:240 builtin/send-pack.c:165
-msgid "dry run"
-msgstr "chạy thử"
+#: sequencer.c:2788
+msgid "could not lock HEAD"
+msgstr "không thể khóa HEAD"
 
-#: builtin/add.c:292
-msgid "interactive picking"
-msgstr "sửa bằng cách tương tác"
+#: sequencer.c:2848 sequencer.c:4209
+msgid "no cherry-pick or revert in progress"
+msgstr "không cherry-pick hay hoàn nguyên trong tiến trình"
 
-#: builtin/add.c:293 builtin/checkout.c:1135 builtin/reset.c:302
-msgid "select hunks interactively"
-msgstr "chọn “hunks” theo kiểu tương tác"
+#: sequencer.c:2850 sequencer.c:2861
+msgid "cannot resolve HEAD"
+msgstr "không thể phân giải HEAD"
 
-#: builtin/add.c:294
-msgid "edit current diff and apply"
-msgstr "sửa diff hiện nay và áp dụng nó"
+#: sequencer.c:2852 sequencer.c:2896
+msgid "cannot abort from a branch yet to be born"
+msgstr "không thể hủy bỏ từ một nhánh mà nó còn chưa được tạo ra"
 
-#: builtin/add.c:295
-msgid "allow adding otherwise ignored files"
-msgstr "cho phép thêm các tập tin bị bỏ qua khác"
+#: sequencer.c:2882 builtin/grep.c:736
+#, c-format
+msgid "cannot open '%s'"
+msgstr "không mở được “%s”"
 
-#: builtin/add.c:296
-msgid "update tracked files"
-msgstr "cập nhật các tập tin được theo dõi"
+#: sequencer.c:2884
+#, c-format
+msgid "cannot read '%s': %s"
+msgstr "không thể đọc “%s”: %s"
 
-#: builtin/add.c:297
-msgid "renormalize EOL of tracked files (implies -u)"
-msgstr "thường hóa lại EOL của các tập tin được theo dõi (ý là -u)"
+#: sequencer.c:2885
+msgid "unexpected end of file"
+msgstr "gặp kết thúc tập tin đột xuất"
 
-#: builtin/add.c:298
-msgid "record only the fact that the path will be added later"
-msgstr "chỉ ghi lại sự việc mà đường dẫn sẽ được thêm vào sau"
+#: sequencer.c:2891
+#, c-format
+msgid "stored pre-cherry-pick HEAD file '%s' is corrupt"
+msgstr "tập tin HEAD “pre-cherry-pick” đã lưu “%s” bị hỏng"
 
-#: builtin/add.c:299
-msgid "add changes from all tracked and untracked files"
+#: sequencer.c:2902
+msgid "You seem to have moved HEAD. Not rewinding, check your HEAD!"
 msgstr ""
-"thêm các thay đổi từ tất cả các tập tin có cũng như không được theo dõi dấu "
-"vết"
+"Bạn có lẽ đã có HEAD đã bị di chuyển đi, Không thể tua, kiểm tra HEAD của "
+"bạn!"
 
-#: builtin/add.c:302
-msgid "ignore paths removed in the working tree (same as --no-all)"
-msgstr ""
-"lờ đi các đường dẫn bị gỡ bỏ trong cây thư mục làm việc (giống với --no-all)"
+#: sequencer.c:2943
+msgid "no revert in progress"
+msgstr "không có tiến trình hoàn nguyên nào"
 
-#: builtin/add.c:304
-msgid "don't add, only refresh the index"
-msgstr "không thêm, chỉ làm tươi mới bảng mục lục"
+#: sequencer.c:2951
+msgid "no cherry-pick in progress"
+msgstr "không có cherry-pick đang được thực hiện"
 
-#: builtin/add.c:305
-msgid "just skip files which cannot be added because of errors"
-msgstr "chie bỏ qua những tập tin mà nó không thể được thêm vào bởi vì gặp lỗi"
+#: sequencer.c:2961
+msgid "failed to skip the commit"
+msgstr "gặp lỗi khi bỏ qua đối tượng chuyển giao"
 
-#: builtin/add.c:306
-msgid "check if - even missing - files are ignored in dry run"
+#: sequencer.c:2968
+msgid "there is nothing to skip"
+msgstr "ở đây không có gì để mà bỏ qua cả"
+
+#: sequencer.c:2971
+#, c-format
+msgid ""
+"have you committed already?\n"
+"try \"git %s --continue\""
 msgstr ""
-"kiểm tra xem - thậm chí thiếu - tập tin bị bỏ qua trong quá trình chạy thử"
+"bạn đã sẵn sàng chuyển giao chưa?\n"
+"thử \"git %s --continue\""
 
-#: builtin/add.c:307 builtin/update-index.c:974
-msgid "(+/-)x"
-msgstr "(+/-)x"
+#: sequencer.c:3095 sequencer.c:4121
+#, c-format
+msgid "could not update %s"
+msgstr "không thể cập nhật %s"
 
-#: builtin/add.c:307 builtin/update-index.c:975
-msgid "override the executable bit of the listed files"
-msgstr "ghi đè lên bít thi hành của các tập tin được liệt kê"
+#: sequencer.c:3134 sequencer.c:4101
+msgid "cannot read HEAD"
+msgstr "không thể đọc HEAD"
 
-#: builtin/add.c:309
-msgid "warn when adding an embedded repository"
-msgstr "cảnh báo khi thêm một kho nhúng"
+#: sequencer.c:3151
+#, c-format
+msgid "unable to copy '%s' to '%s'"
+msgstr "không thể chép “%s” sang “%s”"
 
-#: builtin/add.c:324
+#: sequencer.c:3159
 #, c-format
 msgid ""
-"You've added another git repository inside your current repository.\n"
-"Clones of the outer repository will not contain the contents of\n"
-"the embedded repository and will not know how to obtain it.\n"
-"If you meant to add a submodule, use:\n"
-"\n"
-"\tgit submodule add <url> %s\n"
+"You can amend the commit now, with\n"
 "\n"
-"If you added this path by mistake, you can remove it from the\n"
-"index with:\n"
+"  git commit --amend %s\n"
 "\n"
-"\tgit rm --cached %s\n"
+"Once you are satisfied with your changes, run\n"
 "\n"
-"See \"git help submodule\" for more information."
+"  git rebase --continue\n"
 msgstr ""
-"Bạn vừa thêm một kho git vào bên trong kho hiện tại của bạn.\n"
-"Các bản sao của kho ngoài sẽ không chứa các nội dung của\n"
-"kho nhúng và sẽ không biết làm thế nào để lấy nó.\n"
-"Nếu ý bạn là thêm một mô-đun-con, hãy chạy:\n"
-"\n"
-"\tgit submodule add <url> %s\n"
+"Bạn có thể tu bổ lần chuyển giao ngay bây giờ bằng:\n"
 "\n"
-"Nếu bạn đã thêm miếng vá này chỉ là sai sót, bạn có thể xóa bỏ\n"
-"nó khỏi mục lục bằng:\n"
+"  git commit --amend %s\n"
 "\n"
-"\tgit rm --cached %s\n"
+"Một khi đã hài lòng với những thay đổi của mình, thì chạy:\n"
 "\n"
-"Xem \"git help submodule\" để biết thêm chi tiết."
+"  git rebase --continue\n"
 
-#: builtin/add.c:352
+#: sequencer.c:3169
 #, c-format
-msgid "adding embedded git repository: %s"
-msgstr "thêm cần một kho git nhúng: %s"
+msgid "Could not apply %s... %.*s"
+msgstr "Không thể áp dụng %s… %.*s"
 
-#: builtin/add.c:370
+#: sequencer.c:3176
 #, c-format
-msgid "Use -f if you really want to add them.\n"
-msgstr "Sử dụng tùy chọn -f nếu bạn thực sự muốn thêm chúng vào.\n"
-
-#: builtin/add.c:378
-msgid "adding files failed"
-msgstr "thêm tập tin gặp lỗi"
-
-#: builtin/add.c:416
-msgid "-A and -u are mutually incompatible"
-msgstr "-A và -u xung khắc nhau"
+msgid "Could not merge %.*s"
+msgstr "Không hòa trộn %.*s"
 
-#: builtin/add.c:423
-msgid "Option --ignore-missing can only be used together with --dry-run"
-msgstr "Tùy chọn --ignore-missing chỉ có thể được dùng cùng với --dry-run"
+#: sequencer.c:3190 sequencer.c:3194 builtin/difftool.c:641
+#, c-format
+msgid "could not copy '%s' to '%s'"
+msgstr "không thể chép “%s” sang “%s”"
 
-#: builtin/add.c:427
+#: sequencer.c:3221
 #, c-format
-msgid "--chmod param '%s' must be either -x or +x"
-msgstr "--chmod tham số “%s” phải hoặc là -x hay +x"
+msgid ""
+"execution failed: %s\n"
+"%sYou can fix the problem, and then run\n"
+"\n"
+"  git rebase --continue\n"
+"\n"
+msgstr ""
+"thực thi gặp lỗi: %s\n"
+"%sBạn có thể sửa các trục trặc, và sau đó chạy lệnh\n"
+"\n"
+"  git rebase --continue\n"
+"\n"
+
+#: sequencer.c:3227
+msgid "and made changes to the index and/or the working tree\n"
+msgstr "và tạo các thay đổi bảng mục lục và/hay cây làm việc\n"
 
-#: builtin/add.c:442
+#: sequencer.c:3233
 #, c-format
-msgid "Nothing specified, nothing added.\n"
-msgstr "Không có gì được chỉ ra, không có gì được thêm vào.\n"
+msgid ""
+"execution succeeded: %s\n"
+"but left changes to the index and/or the working tree\n"
+"Commit or stash your changes, and then run\n"
+"\n"
+"  git rebase --continue\n"
+"\n"
+msgstr ""
+"thực thi thành công: %s\n"
+"nhưng còn các thay đổi trong mục lục và/hoặc cây làm việc\n"
+"Chuyển giao hay tạm cất các thay đổi này đi, rồi chạy\n"
+"\n"
+"  git rebase --continue\n"
+"\n"
 
-#: builtin/add.c:443
+#: sequencer.c:3294
 #, c-format
-msgid "Maybe you wanted to say 'git add .'?\n"
-msgstr "Có lẽ ý bạn là “git add .” phải không?\n"
+msgid "illegal label name: '%.*s'"
+msgstr "tên nhãn dị hình: “%.*s”"
 
-#: builtin/add.c:448 builtin/check-ignore.c:177 builtin/checkout.c:280
-#: builtin/checkout.c:483 builtin/clean.c:958 builtin/commit.c:325
-#: builtin/diff-tree.c:114 builtin/mv.c:144 builtin/reset.c:241
-#: builtin/rm.c:270 builtin/submodule--helper.c:328
-msgid "index file corrupt"
-msgstr "tập tin ghi bảng mục lục bị hỏng"
+#: sequencer.c:3348
+msgid "writing fake root commit"
+msgstr "ghi lần chuyển giao gốc giả"
 
-#: builtin/am.c:414
-msgid "could not parse author script"
-msgstr "không thể phân tích cú pháp văn lệnh tác giả"
+#: sequencer.c:3353
+msgid "writing squash-onto"
+msgstr "đang ghi squash-onto"
 
-#: builtin/am.c:498
+#: sequencer.c:3391 builtin/rebase.c:876 builtin/rebase.c:882
 #, c-format
-msgid "'%s' was deleted by the applypatch-msg hook"
-msgstr "“%s” bị xóa bởi móc applypatch-msg"
+msgid "failed to find tree of %s"
+msgstr "gặp lỗi khi tìm cây của %s"
 
-#: builtin/am.c:539
+#: sequencer.c:3436
 #, c-format
-msgid "Malformed input line: '%s'."
-msgstr "Dòng đầu vào dị hình: “%s”."
+msgid "could not resolve '%s'"
+msgstr "không thể phân giải “%s”"
 
-#: builtin/am.c:576
-#, c-format
-msgid "Failed to copy notes from '%s' to '%s'"
-msgstr "Gặp lỗi khi sao chép ghi chú (note) từ “%s” tới “%s”"
+#: sequencer.c:3467
+msgid "cannot merge without a current revision"
+msgstr "không thể hòa trộn mà không có một điểm xét duyệt hiện tại"
 
-#: builtin/am.c:602
-msgid "fseek failed"
-msgstr "fseek gặp lỗi"
+#: sequencer.c:3489
+#, c-format
+msgid "unable to parse '%.*s'"
+msgstr "không thể phân tích “%.*s”"
 
-#: builtin/am.c:790
+#: sequencer.c:3498
 #, c-format
-msgid "could not parse patch '%s'"
-msgstr "không thể phân tích cú pháp “%s”"
+msgid "nothing to merge: '%.*s'"
+msgstr "chẳng có gì để hòa trộn: “%.*s”"
 
-#: builtin/am.c:855
-msgid "Only one StGIT patch series can be applied at once"
-msgstr "Chỉ có một sê-ri miếng vá StGIT được áp dụng một lúc"
+#: sequencer.c:3510
+msgid "octopus merge cannot be executed on top of a [new root]"
+msgstr "hòa trộn octopus không thể được thực thi trên đỉnh của một [new root]"
 
-#: builtin/am.c:903
-msgid "invalid timestamp"
-msgstr "dấu thời gian không hợp lệ"
+#: sequencer.c:3526
+#, c-format
+msgid "could not get commit message of '%s'"
+msgstr "không thể lấy chú thích của lần chuyển giao của “%s”"
 
-#: builtin/am.c:908 builtin/am.c:920
-msgid "invalid Date line"
-msgstr "dòng Ngày tháng không hợp lệ"
+#: sequencer.c:3688
+#, c-format
+msgid "could not even attempt to merge '%.*s'"
+msgstr "không thể ngay cả khi thử hòa trộn “%.*s”"
 
-#: builtin/am.c:915
-msgid "invalid timezone offset"
-msgstr "độ lệch múi giờ không hợp lệ"
+#: sequencer.c:3704
+msgid "merge: Unable to write new index file"
+msgstr "merge: Không thể ghi tập tin lưu bảng mục lục mới"
 
-#: builtin/am.c:1008
-msgid "Patch format detection failed."
-msgstr "Dò tìm định dạng miếng vá gặp lỗi."
+#: sequencer.c:3773 builtin/rebase.c:733
+#, c-format
+msgid "Applied autostash.\n"
+msgstr "Đã áp dụng autostash.\n"
 
-#: builtin/am.c:1013 builtin/clone.c:407
+#: sequencer.c:3785
 #, c-format
-msgid "failed to create directory '%s'"
-msgstr "tạo thư mục \"%s\" gặp lỗi"
+msgid "cannot store %s"
+msgstr "không thử lưu “%s”"
 
-#: builtin/am.c:1018
-msgid "Failed to split patches."
-msgstr "Gặp lỗi khi chia nhỏ các miếng vá."
+#: sequencer.c:3788 builtin/rebase.c:749 git-rebase--preserve-merges.sh:113
+#, c-format
+msgid ""
+"Applying autostash resulted in conflicts.\n"
+"Your changes are safe in the stash.\n"
+"You can run \"git stash pop\" or \"git stash drop\" at any time.\n"
+msgstr ""
+"Áp dụng autostash có hiệu quả trong các xung đột.\n"
+"Các thay đổi của bạn an toàn trong stash (tạm cất đi).\n"
+"Bạn có thể chạy lệnh \"git stash pop\" hay \"git stash drop\" bất kỳ lúc "
+"nào.\n"
 
-#: builtin/am.c:1148 builtin/commit.c:351
-msgid "unable to write index file"
-msgstr "không thể ghi tập tin lưu mục lục"
+#: sequencer.c:3849
+#, c-format
+msgid "could not checkout %s"
+msgstr "không thể lấy ra %s"
 
-#: builtin/am.c:1162
+#: sequencer.c:3863
 #, c-format
-msgid "When you have resolved this problem, run \"%s --continue\"."
-msgstr "Khi bạn đã phân giải xong trục trặc này, hãy chạy \"%s --continue\"."
+msgid "%s: not a valid OID"
+msgstr "%s không phải là một OID hợp lệ"
+
+#: sequencer.c:3868 git-rebase--preserve-merges.sh:779
+msgid "could not detach HEAD"
+msgstr "không thể tách rời HEAD"
 
-#: builtin/am.c:1163
+#: sequencer.c:3883
 #, c-format
-msgid "If you prefer to skip this patch, run \"%s --skip\" instead."
-msgstr ""
-"Nếu bạn muốn bỏ qua miếng vá này, hãy chạy lệnh \"%s --skip\" để thay thế."
+msgid "Stopped at HEAD\n"
+msgstr "Dừng lại ở HEAD\n"
 
-#: builtin/am.c:1164
+#: sequencer.c:3885
 #, c-format
-msgid "To restore the original branch and stop patching, run \"%s --abort\"."
-msgstr "Để phục hồi lại nhánh gốc và dừng vá, hãy chạy \"%s --abort\"."
+msgid "Stopped at %s\n"
+msgstr "Dừng lại ở %s\n"
 
-#: builtin/am.c:1271
-msgid "Patch is empty."
-msgstr "Miếng vá trống rỗng."
+#: sequencer.c:3893
+#, c-format
+msgid ""
+"Could not execute the todo command\n"
+"\n"
+"    %.*s\n"
+"It has been rescheduled; To edit the command before continuing, please\n"
+"edit the todo list first:\n"
+"\n"
+"    git rebase --edit-todo\n"
+"    git rebase --continue\n"
+msgstr ""
+"Không thể thực thi lệnh todo\n"
+"\n"
+"    %.*s\n"
+"Nó đã được lên lịch lại: Để sửa lệnh trước khi tiếp tục, vui lòng\n"
+"sửa danh sách todo trước:\n"
+"\n"
+"    git rebase --edit-todo\n"
+"    git rebase --continue\n"
 
-#: builtin/am.c:1337
+#: sequencer.c:3979
 #, c-format
-msgid "invalid ident line: %.*s"
-msgstr "dòng thụt lề không hợp lệ: %.*s"
+msgid "Stopped at %s...  %.*s\n"
+msgstr "Dừng lại ở %s…  %.*s\n"
 
-#: builtin/am.c:1359
+#: sequencer.c:4050
 #, c-format
-msgid "unable to parse commit %s"
-msgstr "không thể phân tích lần chuyển giao “%s”"
+msgid "unknown command %d"
+msgstr "không hiểu câu lệnh %d"
 
-#: builtin/am.c:1554
-msgid "Repository lacks necessary blobs to fall back on 3-way merge."
-msgstr "Kho thiếu đối tượng blob cần thiết để trở về trên “3-way merge”."
+#: sequencer.c:4109
+msgid "could not read orig-head"
+msgstr "không thể đọc orig-head"
 
-#: builtin/am.c:1556
-msgid "Using index info to reconstruct a base tree..."
-msgstr ""
-"Sử dụng thông tin trong bảng mục lục để cấu trúc lại một cây (tree) cơ sở…"
+#: sequencer.c:4114
+msgid "could not read 'onto'"
+msgstr "không thể đọc “onto”."
 
-#: builtin/am.c:1575
-msgid ""
-"Did you hand edit your patch?\n"
-"It does not apply to blobs recorded in its index."
-msgstr ""
-"Bạn đã sửa miếng vá của mình bằng cách thủ công à?\n"
-"Nó không thể áp dụng các blob đã được ghi lại trong bảng mục lục của nó."
+#: sequencer.c:4128
+#, c-format
+msgid "could not update HEAD to %s"
+msgstr "không thể cập nhật HEAD thành %s"
 
-#: builtin/am.c:1581
-msgid "Falling back to patching base and 3-way merge..."
-msgstr "Đang trở lại để vá cơ sở và “hòa trộn 3-đường”…"
+#: sequencer.c:4221
+msgid "cannot rebase: You have unstaged changes."
+msgstr "không thể cải tổ: Bạn có các thay đổi chưa được đưa lên bệ phóng."
 
-#: builtin/am.c:1606
-msgid "Failed to merge in the changes."
-msgstr "Gặp lỗi khi trộn vào các thay đổi."
+#: sequencer.c:4230
+msgid "cannot amend non-existing commit"
+msgstr "không thể tu bỏ một lần chuyển giao không tồn tại"
 
-#: builtin/am.c:1637
-msgid "applying to an empty history"
-msgstr "áp dụng vào một lịch sử trống rỗng"
+#: sequencer.c:4232
+#, c-format
+msgid "invalid file: '%s'"
+msgstr "tập tin không hợp lệ: “%s”"
 
-#: builtin/am.c:1683 builtin/am.c:1687
+#: sequencer.c:4234
 #, c-format
-msgid "cannot resume: %s does not exist."
-msgstr "không thể phục hồi: %s không tồn tại."
+msgid "invalid contents: '%s'"
+msgstr "nội dung không hợp lệ: “%s”"
 
-#: builtin/am.c:1703
-msgid "cannot be interactive without stdin connected to a terminal."
+#: sequencer.c:4237
+msgid ""
+"\n"
+"You have uncommitted changes in your working tree. Please, commit them\n"
+"first and then run 'git rebase --continue' again."
 msgstr ""
-"không thể được tương tác mà không có stdin kết nối với một thiết bị cuối"
+"\n"
+"Bạn có các thay đổi chưa chuyển giao trong thư mục làm việc. Vui lòng\n"
+"chuyển giao chúng trước và sau đó chạy lệnh “git rebase --continue” lần nữa."
 
-#: builtin/am.c:1708
-msgid "Commit Body is:"
-msgstr "Thân của lần chuyển giao là:"
+#: sequencer.c:4273 sequencer.c:4312
+#, c-format
+msgid "could not write file: '%s'"
+msgstr "không thể ghi tập tin: “%s”"
 
-#. TRANSLATORS: Make sure to include [y], [n], [e], [v] and [a]
-#. in your translation. The program will only accept English
-#. input at this point.
-#.
-#: builtin/am.c:1718
-msgid "Apply? [y]es/[n]o/[e]dit/[v]iew patch/[a]ccept all: "
-msgstr ""
-"Áp dụng? đồng ý [y]/khô[n]g/chỉnh sửa [e]/hiển thị miếng [v]á/chấp nhận tất "
-"cả [a]: "
+#: sequencer.c:4327
+msgid "could not remove CHERRY_PICK_HEAD"
+msgstr "không thể xóa bỏ CHERRY_PICK_HEAD"
+
+#: sequencer.c:4334
+msgid "could not commit staged changes."
+msgstr "không thể chuyển giao các thay đổi đã đưa lên bệ phóng."
 
-#: builtin/am.c:1768
+#: sequencer.c:4440
 #, c-format
-msgid "Dirty index: cannot apply patches (dirty: %s)"
-msgstr "Bảng mục lục bẩn: không thể áp dụng các miếng vá (bẩn: %s)"
+msgid "%s: can't cherry-pick a %s"
+msgstr "%s: không thể cherry-pick một %s"
 
-#: builtin/am.c:1808 builtin/am.c:1879
+#: sequencer.c:4444
 #, c-format
-msgid "Applying: %.*s"
-msgstr "Áp dụng: %.*s"
+msgid "%s: bad revision"
+msgstr "%s: điểm xét duyệt sai"
 
-#: builtin/am.c:1824
-msgid "No changes -- Patch already applied."
-msgstr "Không thay đổi gì cả -- Miếng vá đã được áp dụng rồi."
+#: sequencer.c:4479
+msgid "can't revert as initial commit"
+msgstr "không thể hoàn nguyên một lần chuyển giao khởi tạo"
 
-#: builtin/am.c:1832
-#, c-format
-msgid "Patch failed at %s %.*s"
-msgstr "Gặp lỗi khi vá tại %s %.*s"
+#: sequencer.c:4952
+msgid "make_script: unhandled options"
+msgstr "make_script: các tùy chọn được không xử lý"
 
-#: builtin/am.c:1838
-msgid "Use 'git am --show-current-patch' to see the failed patch"
-msgstr "Dùng “git am --show-current-patch” để xem miếng vá bị lỗi"
+#: sequencer.c:4955
+msgid "make_script: error preparing revisions"
+msgstr "make_script: lỗi chuẩn bị điểm hiệu chỉnh"
 
-#: builtin/am.c:1882
+#: sequencer.c:5113
 msgid ""
-"No changes - did you forget to use 'git add'?\n"
-"If there is nothing left to stage, chances are that something else\n"
-"already introduced the same changes; you might want to skip this patch."
+"You can fix this with 'git rebase --edit-todo' and then run 'git rebase --"
+"continue'.\n"
+"Or you can abort the rebase with 'git rebase --abort'.\n"
 msgstr ""
-"Không có thay đổi nào - bạn đã quên sử dụng lệnh “git add” à?\n"
-"Nếu ở đây không có gì còn lại stage, tình cờ là có một số thứ khác\n"
-"đã sẵn được đưa vào với cùng nội dung thay đổi; bạn có lẽ muốn bỏ qua miếng "
-"vá này."
+"Bạn có thể sửa nó bằng “git rebase --edit-todo” và sau đó chạy “git rebase --"
+"continue”.\n"
+"Hoặc là bạn có thể bãi bỏ việc cải tổ bằng “git rebase --abort”.\n"
 
-#: builtin/am.c:1889
-msgid ""
-"You still have unmerged paths in your index.\n"
-"You should 'git add' each file with resolved conflicts to mark them as "
-"such.\n"
-"You might run `git rm` on a file to accept \"deleted by them\" for it."
-msgstr ""
-"Bạn vẫn có những đường dẫn chưa hòa trộn trong chỉ mục của bạn.\n"
-"Bạn nên “git add” từng tập tin với các xung đột đã được giải quyết để đánh "
-"dấu chúng là thế.\n"
-"Bạn có lẽ muốn chạy “git rm“ trên một tập tin để chấp nhận \"được xóa bởi họ"
-"\" cho nó."
+#: sequencer.c:5226 sequencer.c:5243
+msgid "nothing to do"
+msgstr "không có gì để làm"
+
+#: sequencer.c:5257
+msgid "could not skip unnecessary pick commands"
+msgstr "không thể bỏ qua các lệnh cậy (pick) không cần thiết"
 
-#: builtin/am.c:1996 builtin/am.c:2000 builtin/am.c:2012 builtin/reset.c:324
-#: builtin/reset.c:332
-#, c-format
-msgid "Could not parse object '%s'."
-msgstr "không thể phân tích đối tượng “%s”."
+#: sequencer.c:5351
+msgid "the script was already rearranged."
+msgstr "văn lệnh đã sẵn được sắp đặt rồi."
 
-#: builtin/am.c:2048
-msgid "failed to clean index"
-msgstr "gặp lỗi khi dọn bảng mục lục"
+#: setup.c:124
+#, c-format
+msgid "'%s' is outside repository"
+msgstr "“%s” ở ngoài một kho chứa"
 
-#: builtin/am.c:2083
+#: setup.c:174
+#, c-format
 msgid ""
-"You seem to have moved HEAD since the last 'am' failure.\n"
-"Not rewinding to ORIG_HEAD"
+"%s: no such path in the working tree.\n"
+"Use 'git <command> -- <path>...' to specify paths that do not exist locally."
 msgstr ""
-"Bạn có lẽ đã có HEAD đã bị di chuyển đi kể từ lần “am” thất bại cuối cùng.\n"
-"Không thể chuyển tới ORIG_HEAD"
+"%s: không có đường dẫn nào như thế ở trong cây làm việc.\n"
+"Dùng “git <lệnh> -- <đường/dẫn>…” để chỉ định đường dẫn mà nó không tồn tại "
+"một cách nội bộ."
 
-#: builtin/am.c:2174
+#: setup.c:187
 #, c-format
-msgid "Invalid value for --patch-format: %s"
-msgstr "Giá trị không hợp lệ cho --patch-format: %s"
+msgid ""
+"ambiguous argument '%s': unknown revision or path not in the working tree.\n"
+"Use '--' to separate paths from revisions, like this:\n"
+"'git <command> [<revision>...] -- [<file>...]'"
+msgstr ""
+"tham số chưa rõ ràng “%s”: chưa biết điểm xem xét hay đường dẫn không trong "
+"cây làm việc.\n"
+"Dùng “--” để ngăn cách các đường dẫn khỏi điểm xem xét, như thế này:\n"
+"“git <lệnh> [<điểm xem xét>…] -- [<tập tin>…]”"
 
-#: builtin/am.c:2210
-msgid "git am [<options>] [(<mbox> | <Maildir>)...]"
-msgstr "git am [<các-tùy-chọn>] [(<mbox>|<Maildir>)…]"
+#: setup.c:236
+#, c-format
+msgid "option '%s' must come before non-option arguments"
+msgstr "tùy chọn “%s” phải trước các đối số đầu tiên không có tùy chọn"
 
-#: builtin/am.c:2211
-msgid "git am [<options>] (--continue | --skip | --abort)"
-msgstr "git am [<các-tùy-chọn>] (--continue | --skip | --abort)"
+#: setup.c:255
+#, c-format
+msgid ""
+"ambiguous argument '%s': both revision and filename\n"
+"Use '--' to separate paths from revisions, like this:\n"
+"'git <command> [<revision>...] -- [<file>...]'"
+msgstr ""
+"tham số chưa rõ ràng “%s”: cả điểm xem xét và tên tập tin.\n"
+"Dùng “--” để ngăn cách các đường dẫn khỏi điểm xem xét, như thế này:\n"
+"“git <lệnh> [<điểm xem xét>…] -- [<tập tin>…]”"
 
-#: builtin/am.c:2217
-msgid "run interactively"
-msgstr "chạy kiểu tương tác"
+#: setup.c:391
+msgid "unable to set up work tree using invalid config"
+msgstr "không thể cài đặt thư mục làm việc sử dụng cấu hình không hợp lệ"
 
-#: builtin/am.c:2219
-msgid "historical option -- no-op"
-msgstr "tùy chọn lịch sử -- không-toán-tử"
+#: setup.c:395
+msgid "this operation must be run in a work tree"
+msgstr "thao tác này phải được thực hiện trong thư mục làm việc"
 
-#: builtin/am.c:2221
-msgid "allow fall back on 3way merging if needed"
-msgstr "cho phép quay trở lại để hòa trộn kiểu “3way” nếu cần"
+#: setup.c:541
+#, c-format
+msgid "Expected git repo version <= %d, found %d"
+msgstr "Cần phiên bản kho git <= %d, nhưng lại nhận được %d"
 
-#: builtin/am.c:2222 builtin/init-db.c:484 builtin/prune-packed.c:57
-#: builtin/repack.c:192
-msgid "be quiet"
-msgstr "im lặng"
+#: setup.c:549
+msgid "unknown repository extensions found:"
+msgstr "tìm thấy phần mở rộng kho chưa biết:"
 
-#: builtin/am.c:2224
-msgid "add a Signed-off-by line to the commit message"
-msgstr "Thêm dòng Signed-off-by cho ghi chú của lần chuyển giao"
+#: setup.c:568
+#, c-format
+msgid "error opening '%s'"
+msgstr "gặp lỗi khi mở “%s”"
 
-#: builtin/am.c:2227
-msgid "recode into utf8 (default)"
-msgstr "chuyển mã thành utf8 (mặc định)"
+#: setup.c:570
+#, c-format
+msgid "too large to be a .git file: '%s'"
+msgstr "tập tin .git là quá lớn: “%s”"
 
-#: builtin/am.c:2229
-msgid "pass -k flag to git-mailinfo"
-msgstr "chuyển cờ -k cho git-mailinfo"
+#: setup.c:572
+#, c-format
+msgid "error reading %s"
+msgstr "gặp lỗi khi đọc %s"
 
-#: builtin/am.c:2231
-msgid "pass -b flag to git-mailinfo"
-msgstr "chuyển cờ -b cho git-mailinfo"
+#: setup.c:574
+#, c-format
+msgid "invalid gitfile format: %s"
+msgstr "định dạng tập tin git không hợp lệ: %s"
 
-#: builtin/am.c:2233
-msgid "pass -m flag to git-mailinfo"
-msgstr "chuyển cờ -m cho git-mailinfo"
+#: setup.c:576
+#, c-format
+msgid "no path in gitfile: %s"
+msgstr "không có đường dẫn trong tập tin git: %s"
 
-#: builtin/am.c:2235
-msgid "pass --keep-cr flag to git-mailsplit for mbox format"
-msgstr "chuyển cờ --keep-cr cho git-mailsplit với định dạng mbox"
+#: setup.c:578
+#, c-format
+msgid "not a git repository: %s"
+msgstr "không phải là kho git: %s"
 
-#: builtin/am.c:2238
-msgid "do not pass --keep-cr flag to git-mailsplit independent of am.keepcr"
-msgstr ""
-"đừng chuyển cờ --keep-cr cho git-mailsplit không phụ thuộc vào am.keepcr"
+#: setup.c:677
+#, c-format
+msgid "'$%s' too big"
+msgstr "“$%s” quá lớn"
 
-#: builtin/am.c:2241
-msgid "strip everything before a scissors line"
-msgstr "cắt mọi thứ trước dòng scissors"
+#: setup.c:691
+#, c-format
+msgid "not a git repository: '%s'"
+msgstr "không phải là kho git: “%s”"
 
-#: builtin/am.c:2243 builtin/am.c:2246 builtin/am.c:2249 builtin/am.c:2252
-#: builtin/am.c:2255 builtin/am.c:2258 builtin/am.c:2261 builtin/am.c:2264
-#: builtin/am.c:2270
-msgid "pass it through git-apply"
-msgstr "chuyển nó qua git-apply"
+#: setup.c:720 setup.c:722 setup.c:753
+#, c-format
+msgid "cannot chdir to '%s'"
+msgstr "không thể chdir (chuyển đổi thư mục) sang “%s”"
 
-#: builtin/am.c:2260 builtin/commit.c:1332 builtin/fmt-merge-msg.c:665
-#: builtin/fmt-merge-msg.c:668 builtin/grep.c:853 builtin/merge.c:208
-#: builtin/pull.c:150 builtin/pull.c:208 builtin/repack.c:201
-#: builtin/repack.c:205 builtin/repack.c:207 builtin/show-branch.c:631
-#: builtin/show-ref.c:169 builtin/tag.c:383 parse-options.h:144
-#: parse-options.h:146 parse-options.h:258
-msgid "n"
-msgstr "n"
+#: setup.c:725 setup.c:781 setup.c:791 setup.c:830 setup.c:838
+msgid "cannot come back to cwd"
+msgstr "không thể quay lại cwd"
 
-#: builtin/am.c:2266 builtin/branch.c:632 builtin/for-each-ref.c:38
-#: builtin/replace.c:543 builtin/tag.c:419 builtin/verify-tag.c:39
-msgid "format"
-msgstr "định dạng"
+#: setup.c:852
+#, c-format
+msgid "failed to stat '%*s%s%s'"
+msgstr "gặp lỗi khi lấy thống kê về “%*s%s%s”"
 
-#: builtin/am.c:2267
-msgid "format the patch(es) are in"
-msgstr "định dạng (các) miếng vá theo"
+#: setup.c:1090
+msgid "Unable to read current working directory"
+msgstr "Không thể đọc thư mục làm việc hiện hành"
 
-#: builtin/am.c:2273
-msgid "override error message when patch failure occurs"
-msgstr "đè lên các lời nhắn lỗi khi xảy ra lỗi vá nghiêm trọng"
+#: setup.c:1099 setup.c:1105
+#, c-format
+msgid "cannot change to '%s'"
+msgstr "không thể chuyển sang “%s”"
 
-#: builtin/am.c:2275
-msgid "continue applying patches after resolving a conflict"
-msgstr "tiếp tục áp dụng các miếng vá sau khi giải quyết xung đột"
+#: setup.c:1110
+#, c-format
+msgid "not a git repository (or any of the parent directories): %s"
+msgstr "không phải là kho git (hoặc bất kỳ thư mục cha mẹ nào): %s"
 
-#: builtin/am.c:2278
-msgid "synonyms for --continue"
-msgstr "đồng nghĩa với --continue"
+#: setup.c:1116
+#, c-format
+msgid ""
+"not a git repository (or any parent up to mount point %s)\n"
+"Stopping at filesystem boundary (GIT_DISCOVERY_ACROSS_FILESYSTEM not set)."
+msgstr ""
+"không phải là kho git (hay bất kỳ cha mẹ nào đến tận điểm gắn kết %s)\n"
+"Dừng tại biên của hệ thống tập tin (GIT_DISCOVERY_ACROSS_FILESYSTEM chưa "
+"đặt)."
 
-#: builtin/am.c:2281
-msgid "skip the current patch"
-msgstr "bỏ qua miếng vá hiện hành"
+#: setup.c:1227
+#, c-format
+msgid ""
+"problem with core.sharedRepository filemode value (0%.3o).\n"
+"The owner of files must always have read and write permissions."
+msgstr ""
+"gặp vấn đề với giá trị chế độ tập tin core.sharedRepository (0%.3o).\n"
+"người sở hữu tập tin phải luôn có quyền đọc và ghi."
 
-#: builtin/am.c:2284
-msgid "restore the original branch and abort the patching operation."
-msgstr "phục hồi lại nhánh gốc và loại bỏ thao tác vá."
+#: setup.c:1271
+msgid "open /dev/null or dup failed"
+msgstr "gặp lỗi khi mở “/dev/null” hay dup"
 
-#: builtin/am.c:2287
-msgid "abort the patching operation but keep HEAD where it is."
-msgstr "bỏ qua thao tác vá nhưng vẫn giữ HEAD chỉ đến nó."
+#: setup.c:1286
+msgid "fork failed"
+msgstr "gặp lỗi khi rẽ nhánh tiến trình"
 
-#: builtin/am.c:2290
-msgid "show the patch being applied."
-msgstr "hiển thị miếng vá đã được áp dụng rồi."
+#: setup.c:1291
+msgid "setsid failed"
+msgstr "setsid gặp lỗi"
 
-#: builtin/am.c:2294
-msgid "lie about committer date"
-msgstr "nói dối về ngày chuyển giao"
+#: sha1-file.c:452
+#, c-format
+msgid "object directory %s does not exist; check .git/objects/info/alternates"
+msgstr ""
+"thư mục đối tượng %s không tồn tại; kiểm tra .git/objects/info/alternates"
 
-#: builtin/am.c:2296
-msgid "use current timestamp for author date"
-msgstr "dùng dấu thời gian hiện tại cho ngày tác giả"
+#: sha1-file.c:503
+#, c-format
+msgid "unable to normalize alternate object path: %s"
+msgstr "không thể thường hóa đường dẫn đối tượng thay thế: “%s”"
 
-#: builtin/am.c:2298 builtin/commit.c:1468 builtin/merge.c:239
-#: builtin/pull.c:183 builtin/revert.c:112 builtin/tag.c:399
-msgid "key-id"
-msgstr "mã-số-khóa"
+#: sha1-file.c:575
+#, c-format
+msgid "%s: ignoring alternate object stores, nesting too deep"
+msgstr "%s: đang bỏ qua kho đối tượng thay thế, lồng nhau quá sâu"
 
-#: builtin/am.c:2299
-msgid "GPG-sign commits"
-msgstr "lần chuyển giao ký-GPG"
+#: sha1-file.c:582
+#, c-format
+msgid "unable to normalize object directory: %s"
+msgstr "không thể chuẩn hóa thư mục đối tượng: “%s”"
 
-#: builtin/am.c:2302
-msgid "(internal use for git-rebase)"
-msgstr "(dùng nội bộ cho git-rebase)"
+#: sha1-file.c:625
+msgid "unable to fdopen alternates lockfile"
+msgstr "không thể fdopen tập tin khóa thay thế"
 
-#: builtin/am.c:2320
-msgid ""
-"The -b/--binary option has been a no-op for long time, and\n"
-"it will be removed. Please do not use it anymore."
-msgstr ""
-"Tùy chọn -b/--binary đã không dùng từ lâu rồi, và\n"
-"nó sẽ được bỏ đi. Xin đừng sử dụng nó thêm nữa."
+#: sha1-file.c:643
+msgid "unable to read alternates file"
+msgstr "không thể đọc tập tin thay thế"
+
+#: sha1-file.c:650
+msgid "unable to move new alternates file into place"
+msgstr "không thể di chuyển tập tin thay thế vào chỗ"
 
-#: builtin/am.c:2327
-msgid "failed to read the index"
-msgstr "gặp lỗi đọc bảng mục lục"
+#: sha1-file.c:685
+#, c-format
+msgid "path '%s' does not exist"
+msgstr "đường dẫn “%s” không tồn tại"
 
-#: builtin/am.c:2342
+#: sha1-file.c:711
 #, c-format
-msgid "previous rebase directory %s still exists but mbox given."
-msgstr "thư mục rebase trước %s không sẵn có nhưng mbox lại đưa ra."
+msgid "reference repository '%s' as a linked checkout is not supported yet."
+msgstr "kho tham chiếu “%s” như là lấy ra liên kết vẫn chưa được hỗ trợ."
 
-#: builtin/am.c:2366
+#: sha1-file.c:717
 #, c-format
-msgid ""
-"Stray %s directory found.\n"
-"Use \"git am --abort\" to remove it."
-msgstr ""
-"Tìm thấy thư mục lạc %s.\n"
-"Dùng \"git am --abort\" để loại bỏ nó đi."
+msgid "reference repository '%s' is not a local repository."
+msgstr "kho tham chiếu “%s” không phải là một kho nội bộ."
 
-#: builtin/am.c:2372
-msgid "Resolve operation not in progress, we are not resuming."
-msgstr "Thao tác phân giải không được tiến hành, chúng ta không phục hồi lại."
+#: sha1-file.c:723
+#, c-format
+msgid "reference repository '%s' is shallow"
+msgstr "kho tham chiếu “%s” là nông"
 
-#: builtin/apply.c:8
-msgid "git apply [<options>] [<patch>...]"
-msgstr "git apply [<các-tùy-chọn>] [<miếng-vá>…]"
+#: sha1-file.c:731
+#, c-format
+msgid "reference repository '%s' is grafted"
+msgstr "kho tham chiếu “%s” bị cấy ghép"
 
-#: builtin/archive.c:17
+#: sha1-file.c:791
 #, c-format
-msgid "could not create archive file '%s'"
-msgstr "không thể tạo tập tin kho (lưu trữ, nén) “%s”"
+msgid "invalid line while parsing alternate refs: %s"
+msgstr "dòng không hợp lệ trong khi phân tích các tham chiếu thay thế: %s"
 
-#: builtin/archive.c:20
-msgid "could not redirect output"
-msgstr "không thể chuyển hướng kết xuất"
+#: sha1-file.c:943
+#, c-format
+msgid "attempting to mmap %<PRIuMAX> over limit %<PRIuMAX>"
+msgstr "đang cố để mmap %<PRIuMAX> vượt quá giới hạn %<PRIuMAX>"
 
-#: builtin/archive.c:37
-msgid "git archive: Remote with no URL"
-msgstr "git archive: Máy chủ không có địa chỉ URL"
+#: sha1-file.c:964
+msgid "mmap failed"
+msgstr "mmap gặp lỗi"
 
-#: builtin/archive.c:58
-msgid "git archive: expected ACK/NAK, got a flush packet"
-msgstr "git archive: cần ACK/NAK, nhưng lại nhận được gói flush"
+#: sha1-file.c:1128
+#, c-format
+msgid "object file %s is empty"
+msgstr "tập tin đối tượng %s trống rỗng"
 
-#: builtin/archive.c:61
+#: sha1-file.c:1252 sha1-file.c:2392
 #, c-format
-msgid "git archive: NACK %s"
-msgstr "git archive: NACK %s"
+msgid "corrupt loose object '%s'"
+msgstr "đối tượng mất hỏng “%s”"
 
-#: builtin/archive.c:64
-msgid "git archive: protocol error"
-msgstr "git archive: lỗi giao thức"
+#: sha1-file.c:1254 sha1-file.c:2396
+#, c-format
+msgid "garbage at end of loose object '%s'"
+msgstr "gặp rác tại cuối của đối tượng bị mất “%s”"
 
-#: builtin/archive.c:68
-msgid "git archive: expected a flush"
-msgstr "git archive: cần một flush (đẩy dữ liệu lên đĩa)"
+#: sha1-file.c:1296
+msgid "invalid object type"
+msgstr "kiểu đối tượng không hợp lệ"
 
-#: builtin/bisect--helper.c:12
-msgid "git bisect--helper --next-all [--no-checkout]"
-msgstr "git bisect--helper --next-all [--no-checkout]"
+#: sha1-file.c:1380
+#, c-format
+msgid "unable to unpack %s header with --allow-unknown-type"
+msgstr "không thể giải nén phần đầu gói %s với --allow-unknown-type"
 
-#: builtin/bisect--helper.c:13
-msgid "git bisect--helper --write-terms <bad_term> <good_term>"
-msgstr "git bisect--helper --write-terms <bad_term> <good_term>"
+#: sha1-file.c:1383
+#, c-format
+msgid "unable to unpack %s header"
+msgstr "không thể giải gói phần đầu %s"
 
-#: builtin/bisect--helper.c:14
-msgid "git bisect--helper --bisect-clean-state"
-msgstr "git bisect--helper --bisect-clean-state"
+#: sha1-file.c:1389
+#, c-format
+msgid "unable to parse %s header with --allow-unknown-type"
+msgstr "không thể phân tích phần đầu gói %s với --allow-unknown-type"
 
-#: builtin/bisect--helper.c:46
+#: sha1-file.c:1392
 #, c-format
-msgid "'%s' is not a valid term"
-msgstr "“%s” không phải một thời hạn hợp lệ."
+msgid "unable to parse %s header"
+msgstr "không thể phân tích phần đầu của “%s”"
 
-#: builtin/bisect--helper.c:50
+#: sha1-file.c:1584
 #, c-format
-msgid "can't use the builtin command '%s' as a term"
-msgstr "không thể dùng lệnh tích hợp “%s” như là một thời kỳ"
+msgid "failed to read object %s"
+msgstr "gặp lỗi khi đọc đối tượng “%s”"
 
-#: builtin/bisect--helper.c:60
+#: sha1-file.c:1588
 #, c-format
-msgid "can't change the meaning of the term '%s'"
-msgstr "không thể thay đổi nghĩa của thời kỳ “%s”"
+msgid "replacement %s not found for %s"
+msgstr "c%s thay thế không được tìm thấy cho %s"
 
-#: builtin/bisect--helper.c:71
-msgid "please use two different terms"
-msgstr "vui lòng dùng hai thời kỳ khác nhau"
+#: sha1-file.c:1592
+#, c-format
+msgid "loose object %s (stored in %s) is corrupt"
+msgstr "đối tượng mất %s (được lưu trong %s) bị hỏng"
 
-#: builtin/bisect--helper.c:78
-msgid "could not open the file BISECT_TERMS"
-msgstr "không thể mở tập tin BISECT_TERMS"
+#: sha1-file.c:1596
+#, c-format
+msgid "packed object %s (stored in %s) is corrupt"
+msgstr "đối tượng đã đóng gói %s (được lưu trong %s) bị hỏng"
 
-#: builtin/bisect--helper.c:120
-msgid "perform 'git bisect next'"
-msgstr "thực hiện “git bisect next”"
+#: sha1-file.c:1699
+#, c-format
+msgid "unable to write file %s"
+msgstr "không thể ghi tập tin %s"
 
-#: builtin/bisect--helper.c:122
-msgid "write the terms to .git/BISECT_TERMS"
-msgstr "ghi thời kỳ vào .git/BISECT_TERMS"
+#: sha1-file.c:1706
+#, c-format
+msgid "unable to set permission to '%s'"
+msgstr "không thể đặt quyền thành “%s”"
 
-#: builtin/bisect--helper.c:124
-msgid "cleanup the bisection state"
-msgstr "dọn dẹp tình trạng di chuyển nửa bước"
+#: sha1-file.c:1713
+msgid "file write error"
+msgstr "lỗi ghi tập tin"
 
-#: builtin/bisect--helper.c:126
-msgid "check for expected revs"
-msgstr "kiểm tra cho điểm xem xét cần dùng"
+#: sha1-file.c:1732
+msgid "error when closing loose object file"
+msgstr "gặp lỗi trong khi đóng tập tin đối tượng"
 
-#: builtin/bisect--helper.c:128
-msgid "update BISECT_HEAD instead of checking out the current commit"
+#: sha1-file.c:1797
+#, c-format
+msgid "insufficient permission for adding an object to repository database %s"
 msgstr ""
-"cập nhật BISECT_HEAD thay vì lấy ra (checking out) lần chuyển giao hiện hành"
+"không đủ thẩm quyền để thêm một đối tượng vào cơ sở dữ liệu kho chứa %s"
 
-#: builtin/bisect--helper.c:143
-msgid "--write-terms requires two arguments"
-msgstr "--write-terms cần hai tham số"
+#: sha1-file.c:1799
+msgid "unable to create temporary file"
+msgstr "không thể tạo tập tin tạm thời"
 
-#: builtin/bisect--helper.c:147
-msgid "--bisect-clean-state requires no arguments"
-msgstr "--bisect-clean-state không nhận đối số"
+#: sha1-file.c:1823
+msgid "unable to write loose object file"
+msgstr "không thể ghi tập tin đối tượng đã mất"
 
-#: builtin/blame.c:29
-msgid "git blame [<options>] [<rev-opts>] [<rev>] [--] <file>"
-msgstr "git blame [<các-tùy-chọn>] [<rev-opts>] [<rev>] [--] <tập-tin>"
+#: sha1-file.c:1829
+#, c-format
+msgid "unable to deflate new object %s (%d)"
+msgstr "không thể xả nén đối tượng mới %s (%d)"
 
-#: builtin/blame.c:34
-msgid "<rev-opts> are documented in git-rev-list(1)"
-msgstr "<rev-opts> được mô tả trong tài liệu git-rev-list(1)"
+#: sha1-file.c:1833
+#, c-format
+msgid "deflateEnd on object %s failed (%d)"
+msgstr "deflateEnd trên đối tượng %s gặp lỗi (%d)"
 
-#: builtin/blame.c:404
+#: sha1-file.c:1837
 #, c-format
-msgid "expecting a color: %s"
-msgstr "cần một màu: %s"
+msgid "confused by unstable object source data for %s"
+msgstr "chưa rõ ràng baowir dữ liệu nguồn đối tượng không ổn định cho %s"
 
-#: builtin/blame.c:411
-msgid "must end with a color"
-msgstr "phải kết thúc bằng một màu"
+#: sha1-file.c:1847 builtin/pack-objects.c:925
+#, c-format
+msgid "failed utime() on %s"
+msgstr "gặp lỗi utime() trên “%s”"
 
-#: builtin/blame.c:697
+#: sha1-file.c:1922
 #, c-format
-msgid "invalid color '%s' in color.blame.repeatedLines"
-msgstr "màu không hợp lệ “%s” trong color.blame.repeatedLines"
+msgid "cannot read object for %s"
+msgstr "không thể đọc đối tượng cho %s"
 
-#: builtin/blame.c:715
-msgid "invalid value for blame.coloring"
-msgstr "màu không hợp lệ cho blame.coloring"
+#: sha1-file.c:1962
+msgid "corrupt commit"
+msgstr "lần chuyển giao sai hỏng"
 
-#: builtin/blame.c:786
-msgid "Show blame entries as we find them, incrementally"
-msgstr "Hiển thị các mục “blame” như là chúng ta thấy chúng, tăng dần"
+#: sha1-file.c:1970
+msgid "corrupt tag"
+msgstr "thẻ sai hỏng"
 
-#: builtin/blame.c:787
-msgid "Show blank SHA-1 for boundary commits (Default: off)"
-msgstr ""
-"Hiển thị SHA-1 trắng cho những lần chuyển giao biên giới (Mặc định: off)"
+#: sha1-file.c:2069
+#, c-format
+msgid "read error while indexing %s"
+msgstr "gặp lỗi đọc khi đánh mục lục %s"
 
-#: builtin/blame.c:788
-msgid "Do not treat root commits as boundaries (Default: off)"
-msgstr "Không coi các lần chuyển giao gốc là giới hạn (Mặc định: off)"
+#: sha1-file.c:2072
+#, c-format
+msgid "short read while indexing %s"
+msgstr "không đọc ngắn khi đánh mục lục %s"
 
-#: builtin/blame.c:789
-msgid "Show work cost statistics"
-msgstr "Hiển thị thống kê công sức làm việc"
+#: sha1-file.c:2145 sha1-file.c:2154
+#, c-format
+msgid "%s: failed to insert into database"
+msgstr "%s: gặp lỗi khi thêm vào cơ sở dữ liệu"
 
-#: builtin/blame.c:790
-msgid "Force progress reporting"
-msgstr "Ép buộc báo cáo tiến triển công việc"
+#: sha1-file.c:2160
+#, c-format
+msgid "%s: unsupported file type"
+msgstr "%s: kiểu tập tin không được hỗ trợ"
 
-#: builtin/blame.c:791
-msgid "Show output score for blame entries"
-msgstr "Hiển thị kết xuất điểm số có các mục tin “blame”"
+#: sha1-file.c:2184
+#, c-format
+msgid "%s is not a valid object"
+msgstr "%s không phải là một đối tượng hợp lệ"
 
-#: builtin/blame.c:792
-msgid "Show original filename (Default: auto)"
-msgstr "Hiển thị tên tập tin gốc (Mặc định: auto)"
+#: sha1-file.c:2186
+#, c-format
+msgid "%s is not a valid '%s' object"
+msgstr "%s không phải là một đối tượng “%s” hợp lệ"
 
-#: builtin/blame.c:793
-msgid "Show original linenumber (Default: off)"
-msgstr "Hiển thị số dòng gốc (Mặc định: off)"
-
-#: builtin/blame.c:794
-msgid "Show in a format designed for machine consumption"
-msgstr "Hiển thị ở định dạng đã thiết kế cho sự tiêu dùng bằng máy"
-
-#: builtin/blame.c:795
-msgid "Show porcelain format with per-line commit information"
-msgstr "Hiển thị định dạng “porcelain” với thông tin chuyển giao mỗi dòng"
-
-#: builtin/blame.c:796
-msgid "Use the same output mode as git-annotate (Default: off)"
-msgstr "Dùng cùng chế độ xuất ra với git-annotate (Mặc định: off)"
-
-#: builtin/blame.c:797
-msgid "Show raw timestamp (Default: off)"
-msgstr "Hiển thị dấu vết thời gian dạng thô (Mặc định: off)"
-
-#: builtin/blame.c:798
-msgid "Show long commit SHA1 (Default: off)"
-msgstr "Hiển thị SHA1 của lần chuyển giao dạng dài (Mặc định: off)"
+#: sha1-file.c:2213 builtin/index-pack.c:155
+#, c-format
+msgid "unable to open %s"
+msgstr "không thể mở %s"
 
-#: builtin/blame.c:799
-msgid "Suppress author name and timestamp (Default: off)"
-msgstr "Không hiển thị tên tác giả và dấu vết thời gian (Mặc định: off)"
+#: sha1-file.c:2403 sha1-file.c:2455
+#, c-format
+msgid "hash mismatch for %s (expected %s)"
+msgstr "mã băm không khớp cho %s (cần %s)"
 
-#: builtin/blame.c:800
-msgid "Show author email instead of name (Default: off)"
-msgstr "Hiển thị thư điện tử của tác giả thay vì tên (Mặc định: off)"
+#: sha1-file.c:2427
+#, c-format
+msgid "unable to mmap %s"
+msgstr "không thể mmap %s"
 
-#: builtin/blame.c:801
-msgid "Ignore whitespace differences"
-msgstr "Bỏ qua các khác biệt do khoảng trắng gây ra"
+#: sha1-file.c:2432
+#, c-format
+msgid "unable to unpack header of %s"
+msgstr "không thể giải gói phần đầu của “%s”"
 
-#: builtin/blame.c:802
-msgid "color redundant metadata from previous line differently"
-msgstr "siêu dữ liệu dư thừa màu từ dòng trước khác hẳn"
+#: sha1-file.c:2438
+#, c-format
+msgid "unable to parse header of %s"
+msgstr "không thể phân tích phần đầu của “%s”"
 
-#: builtin/blame.c:803
-msgid "color lines by age"
-msgstr "các dòng màu theo tuổi"
+#: sha1-file.c:2449
+#, c-format
+msgid "unable to unpack contents of %s"
+msgstr "không thể giải gói nội dung của “%s”"
 
-#: builtin/blame.c:810
-msgid "Use an experimental heuristic to improve diffs"
-msgstr "Dùng một phỏng đoán thử nghiệm để tăng cường các diff"
+#: sha1-name.c:487
+#, c-format
+msgid "short SHA1 %s is ambiguous"
+msgstr "tóm lược SHA1 %s chưa rõ ràng"
 
-#: builtin/blame.c:812
-msgid "Spend extra cycles to find better match"
-msgstr "Tiêu thụ thêm năng tài nguyên máy móc để tìm kiếm tốt hơn nữa"
+#: sha1-name.c:498
+msgid "The candidates are:"
+msgstr "Các ứng cử là:"
 
-#: builtin/blame.c:813
-msgid "Use revisions from <file> instead of calling git-rev-list"
+#: sha1-name.c:797
+msgid ""
+"Git normally never creates a ref that ends with 40 hex characters\n"
+"because it will be ignored when you just specify 40-hex. These refs\n"
+"may be created by mistake. For example,\n"
+"\n"
+"  git switch -c $br $(git rev-parse ...)\n"
+"\n"
+"where \"$br\" is somehow empty and a 40-hex ref is created. Please\n"
+"examine these refs and maybe delete them. Turn this message off by\n"
+"running \"git config advice.objectNameWarning false\""
 msgstr ""
-"Sử dụng điểm xét duyệt (revision) từ <tập tin> thay vì gọi “git-rev-list”"
-
-#: builtin/blame.c:814
-msgid "Use <file>'s contents as the final image"
-msgstr "Sử dụng nội dung của <tập tin> như là ảnh cuối cùng"
-
-#: builtin/blame.c:815 builtin/blame.c:816
-msgid "score"
-msgstr "điểm số"
+"Git thường không bao giờ tạo tham chiếu mà nó kết thúc với 40 ký tự hex\n"
+"bởi vì nó sẽ bị bỏ qua khi bạn chỉ định 40-hex. Những tham chiếu này\n"
+"có lẽ được tạo ra bởi một sai sót nào đó. Ví dụ,\n"
+"\n"
+"  git switch -c $br $(git rev-parse ...)\n"
+"\n"
+"với \"$br\" không hiểu lý do vì sao trống rỗng và một tham chiếu 40-hex được "
+"tạo ra.\n"
+"Xin hãy kiểm tra những tham chiếu này và có thể xóa chúng đi. Tắt lời nhắn "
+"này\n"
+"bằng cách chạy lệnh \"git config advice.objectNameWarning false\""
 
-#: builtin/blame.c:815
-msgid "Find line copies within and across files"
-msgstr "Tìm các bản sao chép dòng trong và ngang qua tập tin"
+#. TRANSLATORS: IEC 80000-13:2008 gibibyte
+#: strbuf.c:822
+#, c-format
+msgid "%u.%2.2u GiB"
+msgstr "%u.%2.2u GiB"
 
-#: builtin/blame.c:816
-msgid "Find line movements within and across files"
-msgstr "Tìm các di chuyển dòng trong và ngang qua tập tin"
+#. TRANSLATORS: IEC 80000-13:2008 gibibyte/second
+#: strbuf.c:824
+#, c-format
+msgid "%u.%2.2u GiB/s"
+msgstr "%u.%2.2u GiB/giây"
 
-#: builtin/blame.c:817
-msgid "n,m"
-msgstr "n,m"
+#. TRANSLATORS: IEC 80000-13:2008 mebibyte
+#: strbuf.c:832
+#, c-format
+msgid "%u.%2.2u MiB"
+msgstr "%u.%2.2u MiB"
 
-#: builtin/blame.c:817
-msgid "Process only line range n,m, counting from 1"
-msgstr "Xử lý chỉ dòng vùng n,m, tính từ 1"
+#. TRANSLATORS: IEC 80000-13:2008 mebibyte/second
+#: strbuf.c:834
+#, c-format
+msgid "%u.%2.2u MiB/s"
+msgstr "%u.%2.2u MiB/giây"
 
-#: builtin/blame.c:866
-msgid "--progress can't be used with --incremental or porcelain formats"
-msgstr ""
-"--progress không được dùng cùng với --incremental hay các định dạng porcelain"
+#. TRANSLATORS: IEC 80000-13:2008 kibibyte
+#: strbuf.c:841
+#, c-format
+msgid "%u.%2.2u KiB"
+msgstr "%u.%2.2u KiB"
 
-#. TRANSLATORS: This string is used to tell us the
-#. maximum display width for a relative timestamp in
-#. "git blame" output.  For C locale, "4 years, 11
-#. months ago", which takes 22 places, is the longest
-#. among various forms of relative timestamps, but
-#. your language may need more or fewer display
-#. columns.
-#.
-#: builtin/blame.c:917
-msgid "4 years, 11 months ago"
-msgstr "4 năm, 11 tháng trước"
+#. TRANSLATORS: IEC 80000-13:2008 kibibyte/second
+#: strbuf.c:843
+#, c-format
+msgid "%u.%2.2u KiB/s"
+msgstr "%u.%2.2u KiB/giây"
 
-#: builtin/blame.c:1003
+#. TRANSLATORS: IEC 80000-13:2008 byte
+#: strbuf.c:849
 #, c-format
-msgid "file %s has only %lu line"
-msgid_plural "file %s has only %lu lines"
-msgstr[0] "tập tin %s chỉ có %lu dòng"
+msgid "%u byte"
+msgid_plural "%u bytes"
+msgstr[0] "%u byte"
 
-#: builtin/blame.c:1049
-msgid "Blaming lines"
-msgstr "Các dòng blame"
+#. TRANSLATORS: IEC 80000-13:2008 byte/second
+#: strbuf.c:851
+#, c-format
+msgid "%u byte/s"
+msgid_plural "%u bytes/s"
+msgstr[0] "%u byte/giây"
 
-#: builtin/branch.c:27
-msgid "git branch [<options>] [-r | -a] [--merged | --no-merged]"
-msgstr "git branch [<các-tùy-chọn>] [-r | -a] [--merged | --no-merged]"
+#: strbuf.c:1149
+#, c-format
+msgid "could not edit '%s'"
+msgstr "không thể sửa “%s”"
 
-#: builtin/branch.c:28
-msgid "git branch [<options>] [-l] [-f] <branch-name> [<start-point>]"
-msgstr "git branch [<các-tùy-chọn>] [-l] [-f] <tên-nhánh> [<điểm-đầu>]"
+#: submodule.c:114 submodule.c:143
+msgid "Cannot change unmerged .gitmodules, resolve merge conflicts first"
+msgstr ""
+"Không thể thay đổi .gitmodules chưa hòa trộn, hãy giải quyết xung đột trộn "
+"trước"
 
-#: builtin/branch.c:29
-msgid "git branch [<options>] [-r] (-d | -D) <branch-name>..."
-msgstr "git branch [<các-tùy-chọn>] [-r] (-d | -D) <tên-nhánh> …"
+#: submodule.c:118 submodule.c:147
+#, c-format
+msgid "Could not find section in .gitmodules where path=%s"
+msgstr "Không thể tìm thấy phần trong .gitmodules nơi mà đường_dẫn=%s"
 
-#: builtin/branch.c:30
-msgid "git branch [<options>] (-m | -M) [<old-branch>] <new-branch>"
-msgstr "git branch [<các-tùy-chọn>] (-m | -M) [<nhánh-cũ>] <nhánh-mới>"
+#: submodule.c:154
+#, c-format
+msgid "Could not remove .gitmodules entry for %s"
+msgstr "Không thể gỡ bỏ mục .gitmodules dành cho %s"
 
-#: builtin/branch.c:31
-msgid "git branch [<options>] (-c | -C) [<old-branch>] <new-branch>"
-msgstr "git branch [<các-tùy-chọn>] (-c | -C) [<nhánh-cũ>] <nhánh-mới>"
+#: submodule.c:165
+msgid "staging updated .gitmodules failed"
+msgstr "gặp lỗi khi tổ chức .gitmodules đã cập nhật"
 
-#: builtin/branch.c:32
-msgid "git branch [<options>] [-r | -a] [--points-at]"
-msgstr "git branch [<các-tùy-chọn>] [-r | -a] [--points-at]"
+#: submodule.c:327
+#, c-format
+msgid "in unpopulated submodule '%s'"
+msgstr "trong mô-đun-con không có gì “%s”"
 
-#: builtin/branch.c:33
-msgid "git branch [<options>] [-r | -a] [--format]"
-msgstr "git branch [<các-tùy-chọn>] [-r | -a] [--format]"
+#: submodule.c:358
+#, c-format
+msgid "Pathspec '%s' is in submodule '%.*s'"
+msgstr "Đặc tả đường dẫn “%s” thì ở trong mô-đun-con “%.*s”"
 
-#: builtin/branch.c:146
+#: submodule.c:910
 #, c-format
-msgid ""
-"deleting branch '%s' that has been merged to\n"
-"         '%s', but not yet merged to HEAD."
+msgid "submodule entry '%s' (%s) is a %s, not a commit"
 msgstr ""
-"đang xóa nhánh “%s” mà nó lại đã được hòa trộn vào\n"
-"         “%s”, nhưng vẫn chưa được hòa trộn vào HEAD."
+"mục tin mô-đun-con “%s” (%s) là một %s, không phải là một lần chuyển giao"
+
+#: submodule.c:1147 builtin/branch.c:680 builtin/submodule--helper.c:2016
+msgid "Failed to resolve HEAD as a valid ref."
+msgstr "Gặp lỗi khi phân giải HEAD như là một tham chiếu hợp lệ."
 
-#: builtin/branch.c:150
+#: submodule.c:1481
 #, c-format
-msgid ""
-"not deleting branch '%s' that is not yet merged to\n"
-"         '%s', even though it is merged to HEAD."
-msgstr ""
-"không xóa nhánh “%s” cái mà chưa được hòa trộn vào\n"
-"         “%s”, cho dù là nó đã được hòa trộn vào HEAD."
+msgid "Could not access submodule '%s'"
+msgstr "Không thể truy cập mô-đun-con “%s”"
 
-#: builtin/branch.c:164
+#: submodule.c:1651
 #, c-format
-msgid "Couldn't look up commit object for '%s'"
-msgstr "Không thể tìm kiếm đối tượng chuyển giao cho “%s”"
+msgid "'%s' not recognized as a git repository"
+msgstr "không nhận ra “%s” là một kho git"
 
-#: builtin/branch.c:168
+#: submodule.c:1789
 #, c-format
-msgid ""
-"The branch '%s' is not fully merged.\n"
-"If you are sure you want to delete it, run 'git branch -D %s'."
-msgstr ""
-"Nhánh “%s” không được trộn một cách đầy đủ.\n"
-"Nếu bạn thực sự muốn xóa nó, thì chạy lệnh “git branch -D %s”."
+msgid "could not start 'git status' in submodule '%s'"
+msgstr "không thể lấy thống kê “git status” trong mô-đun-con “%s”"
 
-#: builtin/branch.c:181
-msgid "Update of config-file failed"
-msgstr "Cập nhật tập tin cấu hình gặp lỗi"
+#: submodule.c:1802
+#, c-format
+msgid "could not run 'git status' in submodule '%s'"
+msgstr "không thể chạy “git status” trong mô-đun-con “%s”"
 
-#: builtin/branch.c:212
-msgid "cannot use -a with -d"
-msgstr "không thể dùng tùy chọn -a với -d"
+#: submodule.c:1817
+#, c-format
+msgid "Could not unset core.worktree setting in submodule '%s'"
+msgstr "Không thể đặt core.worktree trong mô-đun-con “%s”"
 
-#: builtin/branch.c:218
-msgid "Couldn't look up commit object for HEAD"
-msgstr "Không thể tìm kiếm đối tượng chuyển giao cho HEAD"
+#: submodule.c:1907
+#, c-format
+msgid "submodule '%s' has dirty index"
+msgstr "mô-đun-con “%s” có mục lục còn bẩn"
 
-#: builtin/branch.c:232
+#: submodule.c:1959
 #, c-format
-msgid "Cannot delete branch '%s' checked out at '%s'"
-msgstr "Không thể xóa nhánh “%s” đã được lấy ra tại “%s”"
+msgid "Submodule '%s' could not be updated."
+msgstr "Mô-đun-con “%s” không thể được cập nhật."
 
-#: builtin/branch.c:247
+#: submodule.c:2027
 #, c-format
-msgid "remote-tracking branch '%s' not found."
-msgstr "không tìm thấy nhánh theo dõi máy chủ “%s”."
+msgid "submodule git dir '%s' is inside git dir '%.*s'"
+msgstr "thư mục git mô đun con '%s' là bên trong git DIR '%.*s'"
 
-#: builtin/branch.c:248
+#: submodule.c:2048
 #, c-format
-msgid "branch '%s' not found."
-msgstr "không tìm thấy nhánh “%s”."
+msgid ""
+"relocate_gitdir for submodule '%s' with more than one worktree not supported"
+msgstr ""
+"relocate_gitdir cho mô-đun-con “%s” với nhiều hơn một cây làm việc là chưa "
+"được hỗ trợ"
 
-#: builtin/branch.c:263
+#: submodule.c:2060 submodule.c:2119
 #, c-format
-msgid "Error deleting remote-tracking branch '%s'"
-msgstr "Gặp lỗi khi đang xóa nhánh theo dõi máy chủ “%s”"
+msgid "could not lookup name for submodule '%s'"
+msgstr "không thể tìm kiếm tên cho mô-đun-con “%s”"
 
-#: builtin/branch.c:264
+#: submodule.c:2064
 #, c-format
-msgid "Error deleting branch '%s'"
-msgstr "Gặp lỗi khi xóa bỏ nhánh “%s”"
+msgid "refusing to move '%s' into an existing git dir"
+msgstr "từ chối di chuyển ' %s ' vào trong một thư mục git sẵn có"
 
-#: builtin/branch.c:271
+#: submodule.c:2071
 #, c-format
-msgid "Deleted remote-tracking branch %s (was %s).\n"
-msgstr "Đã xóa nhánh theo dõi máy chủ \"%s\" (từng là %s).\n"
+msgid ""
+"Migrating git directory of '%s%s' from\n"
+"'%s' to\n"
+"'%s'\n"
+msgstr ""
+"Di cư thư mục git của “%s%s” từ\n"
+"“%s” sang\n"
+"“%s”\n"
 
-#: builtin/branch.c:272
+#: submodule.c:2154
 #, c-format
-msgid "Deleted branch %s (was %s).\n"
-msgstr "Nhánh “%s” đã bị xóa (từng là %s)\n"
+msgid "could not recurse into submodule '%s'"
+msgstr "không thể đệ quy vào trong mô-đun-con “%s”"
 
-#: builtin/branch.c:416 builtin/tag.c:58
-msgid "unable to parse format string"
-msgstr "không thể phân tích chuỗi định dạng"
+#: submodule.c:2198
+msgid "could not start ls-files in .."
+msgstr "không thể lấy thông tin thống kê về ls-files trong .."
 
-#: builtin/branch.c:453
+#: submodule.c:2237
 #, c-format
-msgid "Branch %s is being rebased at %s"
-msgstr "Nhánh %s đang được cải tổ lại tại %s"
+msgid "ls-tree returned unexpected return code %d"
+msgstr "ls-tree trả về mã không như mong đợi %d"
 
-#: builtin/branch.c:457
+#: submodule-config.c:236
 #, c-format
-msgid "Branch %s is being bisected at %s"
-msgstr "Nhánh %s đang được di chuyển phân đôi (bisect) tại %s"
+msgid "ignoring suspicious submodule name: %s"
+msgstr "đang lờ đi tên mô-đun-con mập mờ: %s"
 
-#: builtin/branch.c:474
-msgid "cannot copy the current branch while not on any."
-msgstr "không thể sao chép nhánh hiện hành trong khi nó chẳng ở đâu cả."
+#: submodule-config.c:303
+msgid "negative values not allowed for submodule.fetchjobs"
+msgstr "không cho phép giá trị âm ở submodule.fetchJobs"
 
-#: builtin/branch.c:476
-msgid "cannot rename the current branch while not on any."
-msgstr "không thể đổi tên nhánh hiện hành trong khi nó chẳng ở đâu cả."
+#: submodule-config.c:401
+#, c-format
+msgid "ignoring '%s' which may be interpreted as a command-line option: %s"
+msgstr ""
+"đang bỏ qua “%s” cái mà có thể được phiên dịch như là một tùy chọn dòng "
+"lệnh: %s"
 
-#: builtin/branch.c:487
+#: submodule-config.c:498
 #, c-format
-msgid "Invalid branch name: '%s'"
-msgstr "Tên nhánh không hợp lệ: “%s”"
+msgid "invalid value for %s"
+msgstr "giá trị cho %s không hợp lệ"
 
-#: builtin/branch.c:514
-msgid "Branch rename failed"
-msgstr "Gặp lỗi khi đổi tên nhánh"
+#: submodule-config.c:769
+#, c-format
+msgid "Could not update .gitmodules entry %s"
+msgstr "Không thể cập nhật mục .gitmodules %s"
 
-#: builtin/branch.c:516
-msgid "Branch copy failed"
-msgstr "Gặp lỗi khi sao chép nhánh"
+#: trailer.c:238
+#, c-format
+msgid "running trailer command '%s' failed"
+msgstr "chạy lệnh kéo theo “%s” gặp lỗi"
 
-#: builtin/branch.c:520
+#: trailer.c:485 trailer.c:490 trailer.c:495 trailer.c:549 trailer.c:553
+#: trailer.c:557
 #, c-format
-msgid "Created a copy of a misnamed branch '%s'"
-msgstr "Đã tạo một bản sao của nhánh khuyết danh “%s”"
+msgid "unknown value '%s' for key '%s'"
+msgstr "không hiểu giá trị “%s” cho khóa “%s”"
 
-#: builtin/branch.c:523
+#: trailer.c:539 trailer.c:544 builtin/remote.c:295
 #, c-format
-msgid "Renamed a misnamed branch '%s' away"
-msgstr "Đã đổi tên nhánh khuyết danh “%s” đi"
+msgid "more than one %s"
+msgstr "nhiều hơn một %s"
 
-#: builtin/branch.c:529
+#: trailer.c:730
 #, c-format
-msgid "Branch renamed to %s, but HEAD is not updated!"
-msgstr "Nhánh bị đổi tên thành %s, nhưng HEAD lại không được cập nhật!"
+msgid "empty trailer token in trailer '%.*s'"
+msgstr "thẻ thừa trống rỗng trong phần thừa “%.*s”"
 
-#: builtin/branch.c:538
-msgid "Branch is renamed, but update of config-file failed"
-msgstr "Nhánh bị đổi tên, nhưng cập nhật tập tin cấu hình gặp lỗi"
+#: trailer.c:750
+#, c-format
+msgid "could not read input file '%s'"
+msgstr "không đọc được tập tin đầu vào “%s”"
 
-#: builtin/branch.c:540
-msgid "Branch is copied, but update of config-file failed"
-msgstr "Nhánh đã được sao chép, nhưng cập nhật tập tin cấu hình gặp lỗi"
+#: trailer.c:753
+msgid "could not read from stdin"
+msgstr "không thể đọc từ đầu vào tiêu chuẩn"
 
-#: builtin/branch.c:556
+#: trailer.c:1011 wrapper.c:665
 #, c-format
-msgid ""
-"Please edit the description for the branch\n"
-"  %s\n"
-"Lines starting with '%c' will be stripped.\n"
-msgstr ""
-"Viết các ghi chú cho nhánh:\n"
-"  %s\n"
-"Những dòng được bắt đầu bằng “%c” sẽ được cắt bỏ.\n"
-
-#: builtin/branch.c:589
-msgid "Generic options"
-msgstr "Tùy chọn chung"
+msgid "could not stat %s"
+msgstr "không thể lấy thông tin thống kê về %s"
 
-#: builtin/branch.c:591
-msgid "show hash and subject, give twice for upstream branch"
-msgstr "hiển thị mã băm và chủ đề, đưa ra hai lần cho nhánh thượng nguồn"
+#: trailer.c:1013
+#, c-format
+msgid "file %s is not a regular file"
+msgstr "\"%s\" không phải là tập tin bình thường"
 
-#: builtin/branch.c:592
-msgid "suppress informational messages"
-msgstr "không xuất các thông tin"
+#: trailer.c:1015
+#, c-format
+msgid "file %s is not writable by user"
+msgstr "tập tin %s người dùng không thể ghi được"
 
-#: builtin/branch.c:593
-msgid "set up tracking mode (see git-pull(1))"
-msgstr "cài đặt chế độ theo dõi (xem git-pull(1))"
+#: trailer.c:1027
+msgid "could not open temporary file"
+msgstr "không thể tạo tập tin tạm thời"
 
-#: builtin/branch.c:595
-msgid "do not use"
-msgstr "không dùng"
+#: trailer.c:1067
+#, c-format
+msgid "could not rename temporary file to %s"
+msgstr "không thể đổi tên tập tin tạm thời thành %s"
 
-#: builtin/branch.c:597
-msgid "upstream"
-msgstr "thượng nguồn"
+#: transport.c:116
+#, c-format
+msgid "Would set upstream of '%s' to '%s' of '%s'\n"
+msgstr "Không thể đặt thượng nguồn của “%s” thành “%s” của “%s”\n"
 
-#: builtin/branch.c:597
-msgid "change the upstream info"
-msgstr "thay đổi thông tin thượng nguồn"
+#: transport.c:145
+#, c-format
+msgid "could not read bundle '%s'"
+msgstr "không thể đọc bó “%s”"
 
-#: builtin/branch.c:598
-msgid "Unset the upstream info"
-msgstr "Bỏ đặt thông tin thượng nguồn"
+#: transport.c:214
+#, c-format
+msgid "transport: invalid depth option '%s'"
+msgstr "vận chuyển: tùy chọn độ sâu “%s” không hợp lệ"
 
-#: builtin/branch.c:599
-msgid "use colored output"
-msgstr "tô màu kết xuất"
+#: transport.c:266
+msgid "see protocol.version in 'git help config' for more details"
+msgstr "xem protocol.version trong “git help config” để có thêm thông tin"
+
+#: transport.c:267
+msgid "server options require protocol version 2 or later"
+msgstr "các tùy chọn máy chủ yêu cầu giao thức phiên bản 2 hoặc mới hơn"
 
-#: builtin/branch.c:600
-msgid "act on remote-tracking branches"
-msgstr "thao tác trên nhánh “remote-tracking”"
+#: transport.c:632
+msgid "could not parse transport.color.* config"
+msgstr "không thể phân tích cú pháp cấu hình transport.color.*"
 
-#: builtin/branch.c:602 builtin/branch.c:604
-msgid "print only branches that contain the commit"
-msgstr "chỉ hiển thị những nhánh mà nó chứa lần chuyển giao"
+#: transport.c:705
+msgid "support for protocol v2 not implemented yet"
+msgstr "việc hỗ trợ giao thức v2 chưa được thực hiện"
 
-#: builtin/branch.c:603 builtin/branch.c:605
-msgid "print only branches that don't contain the commit"
-msgstr "chỉ hiển thị những nhánh mà nó không chứa lần chuyển giao"
+#: transport.c:831
+#, c-format
+msgid "unknown value for config '%s': %s"
+msgstr "không hiểu giá trị cho cho cấu hình “%s”: %s"
 
-#: builtin/branch.c:608
-msgid "Specific git-branch actions:"
-msgstr "Hành động git-branch:"
+#: transport.c:897
+#, c-format
+msgid "transport '%s' not allowed"
+msgstr "không cho phép phương thức vận chuyển “%s”"
 
-#: builtin/branch.c:609
-msgid "list both remote-tracking and local branches"
-msgstr "liệt kê cả nhánh “remote-tracking” và nội bộ"
+#: transport.c:949
+msgid "git-over-rsync is no longer supported"
+msgstr "git-over-rsync không còn được hỗ trợ nữa"
 
-#: builtin/branch.c:611
-msgid "delete fully merged branch"
-msgstr "xóa một toàn bộ nhánh đã hòa trộn"
+#: transport.c:1044
+#, c-format
+msgid ""
+"The following submodule paths contain changes that can\n"
+"not be found on any remote:\n"
+msgstr ""
+"Các đường dẫn mô-đun-con sau đây có chứa các thay đổi cái mà\n"
+"có thể được tìm thấy trên mọi máy phục vụ:\n"
 
-#: builtin/branch.c:612
-msgid "delete branch (even if not merged)"
-msgstr "xóa nhánh (cho dù là chưa được hòa trộn)"
+#: transport.c:1048
+#, c-format
+msgid ""
+"\n"
+"Please try\n"
+"\n"
+"\tgit push --recurse-submodules=on-demand\n"
+"\n"
+"or cd to the path and use\n"
+"\n"
+"\tgit push\n"
+"\n"
+"to push them to a remote.\n"
+"\n"
+msgstr ""
+"\n"
+"Hãy thử\n"
+"\n"
+"\tgit push --recurse-submodules=on-demand\n"
+"\n"
+"hoặc cd đến đường dẫn và dùng\n"
+"\n"
+"\tgit push\n"
+"\n"
+"để đẩy chúng lên máy phục vụ.\n"
+"\n"
 
-#: builtin/branch.c:613
-msgid "move/rename a branch and its reflog"
-msgstr "di chuyển hay đổi tên một nhánh và reflog của nó"
+#: transport.c:1056
+msgid "Aborting."
+msgstr "Bãi bỏ."
 
-#: builtin/branch.c:614
-msgid "move/rename a branch, even if target exists"
-msgstr "di chuyển hoặc đổi tên một nhánh ngay cả khi đích đã có sẵn"
+#: transport.c:1201
+msgid "failed to push all needed submodules"
+msgstr "gặp lỗi khi đẩy dữ liệu của tất cả các mô-đun-con cần thiết"
 
-#: builtin/branch.c:615
-msgid "copy a branch and its reflog"
-msgstr "sao chép một nhánh và reflog của nó"
+#: transport.c:1345 transport-helper.c:656
+msgid "operation not supported by protocol"
+msgstr "thao tác không được gia thức hỗ trợ"
 
-#: builtin/branch.c:616
-msgid "copy a branch, even if target exists"
-msgstr "sao chép một nhánh ngay cả khi đích đã có sẵn"
+#: transport-helper.c:61 transport-helper.c:90
+msgid "full write to remote helper failed"
+msgstr "ghi đầy đủ lên bộ hỗ trợ máy chủ gặp lỗi"
 
-#: builtin/branch.c:617
-msgid "list branch names"
-msgstr "liệt kê các tên nhánh"
+#: transport-helper.c:144
+#, c-format
+msgid "unable to find remote helper for '%s'"
+msgstr "không thể tìm thấy bộ hỗ trợ máy chủ cho “%s”"
 
-#: builtin/branch.c:618
-msgid "create the branch's reflog"
-msgstr "tạo reflog của nhánh"
+#: transport-helper.c:160 transport-helper.c:570
+msgid "can't dup helper output fd"
+msgstr "không thể nhân đôi fd dầu ra bộ hỗ trợ"
 
-#: builtin/branch.c:620
-msgid "edit the description for the branch"
-msgstr "sửa mô tả cho nhánh"
+#: transport-helper.c:211
+#, c-format
+msgid ""
+"unknown mandatory capability %s; this remote helper probably needs newer "
+"version of Git"
+msgstr ""
+"không hiểu capability bắt buộc %s; bộ hỗ trợ máy chủ này gần như chắc chắn "
+"là cần phiên bản Git mới hơn"
 
-#: builtin/branch.c:621
-msgid "force creation, move/rename, deletion"
-msgstr "buộc tạo, di chuyển/đổi tên, xóa"
+#: transport-helper.c:217
+msgid "this remote helper should implement refspec capability"
+msgstr "bộ hỗ trợ máy chủ này cần phải thực thi capability đặc tả tham chiếu"
 
-#: builtin/branch.c:622
-msgid "print only branches that are merged"
-msgstr "chỉ hiển thị những nhánh mà nó được hòa trộn"
+#: transport-helper.c:284 transport-helper.c:424
+#, c-format
+msgid "%s unexpectedly said: '%s'"
+msgstr "%s said bất ngờ: “%s”"
 
-#: builtin/branch.c:623
-msgid "print only branches that are not merged"
-msgstr "chỉ hiển thị những nhánh mà nó không được hòa trộn"
+#: transport-helper.c:413
+#, c-format
+msgid "%s also locked %s"
+msgstr "%s cũng khóa %s"
 
-#: builtin/branch.c:624
-msgid "list branches in columns"
-msgstr "liệt kê các nhánh trong các cột"
+#: transport-helper.c:492
+msgid "couldn't run fast-import"
+msgstr "không thể chạy fast-import"
 
-#: builtin/branch.c:625 builtin/for-each-ref.c:40 builtin/ls-remote.c:70
-#: builtin/tag.c:412
-msgid "key"
-msgstr "khóa"
+#: transport-helper.c:515
+msgid "error while running fast-import"
+msgstr "gặp lỗi trong khi chạy fast-import"
 
-#: builtin/branch.c:626 builtin/for-each-ref.c:41 builtin/ls-remote.c:71
-#: builtin/tag.c:413
-msgid "field name to sort on"
-msgstr "tên trường cần sắp xếp"
+#: transport-helper.c:544 transport-helper.c:1133
+#, c-format
+msgid "could not read ref %s"
+msgstr "không thể đọc tham chiếu %s"
 
-#: builtin/branch.c:628 builtin/for-each-ref.c:43 builtin/notes.c:408
-#: builtin/notes.c:411 builtin/notes.c:571 builtin/notes.c:574
-#: builtin/tag.c:415
-msgid "object"
-msgstr "đối tượng"
+#: transport-helper.c:589
+#, c-format
+msgid "unknown response to connect: %s"
+msgstr "không hiểu đáp ứng để kết nối: %s"
 
-#: builtin/branch.c:629
-msgid "print only branches of the object"
-msgstr "chỉ hiển thị các nhánh của đối tượng"
+#: transport-helper.c:611
+msgid "setting remote service path not supported by protocol"
+msgstr "giao thức này không hỗ trợ cài đặt đường dẫn dịch vụ máy chủ"
 
-#: builtin/branch.c:631 builtin/for-each-ref.c:49 builtin/tag.c:422
-msgid "sorting and filtering are case insensitive"
-msgstr "sắp xếp và lọc là phân biệt HOA thường"
+#: transport-helper.c:613
+msgid "invalid remote service path"
+msgstr "đường dẫn dịch vụ máy chủ không hợp lệ"
 
-#: builtin/branch.c:632 builtin/for-each-ref.c:38 builtin/tag.c:420
-#: builtin/verify-tag.c:39
-msgid "format to use for the output"
-msgstr "định dạng sẽ dùng cho đầu ra"
+#: transport-helper.c:659
+#, c-format
+msgid "can't connect to subservice %s"
+msgstr "không thể kết nối đến dịch vụ phụ %s"
 
-#: builtin/branch.c:655 builtin/clone.c:737
-msgid "HEAD not found below refs/heads!"
-msgstr "không tìm thấy HEAD ở dưới refs/heads!"
+#: transport-helper.c:735
+#, c-format
+msgid "expected ok/error, helper said '%s'"
+msgstr "cần ok/error, nhưng bộ hỗ trợ lại nói “%s”"
 
-#: builtin/branch.c:678
-msgid "--column and --verbose are incompatible"
-msgstr "tùy chọn --column và --verbose xung khắc nhau"
+#: transport-helper.c:788
+#, c-format
+msgid "helper reported unexpected status of %s"
+msgstr "bộ hỗ trợ báo cáo rằng không cần tình trạng của %s"
 
-#: builtin/branch.c:693 builtin/branch.c:745 builtin/branch.c:754
-msgid "branch name required"
-msgstr "cần chỉ ra tên nhánh"
+#: transport-helper.c:849
+#, c-format
+msgid "helper %s does not support dry-run"
+msgstr "helper %s không hỗ trợ dry-run"
 
-#: builtin/branch.c:721
-msgid "Cannot give description to detached HEAD"
-msgstr "Không thể đưa ra mô tả HEAD đã tách rời"
+#: transport-helper.c:852
+#, c-format
+msgid "helper %s does not support --signed"
+msgstr "helper %s không hỗ trợ --signed"
 
-#: builtin/branch.c:726
-msgid "cannot edit description of more than one branch"
-msgstr "không thể sửa mô tả cho nhiều hơn một nhánh"
+#: transport-helper.c:855
+#, c-format
+msgid "helper %s does not support --signed=if-asked"
+msgstr "helper %s không hỗ trợ --signed=if-asked"
 
-#: builtin/branch.c:733
+#: transport-helper.c:860
 #, c-format
-msgid "No commit on branch '%s' yet."
-msgstr "Vẫn chưa chuyển giao trên nhánh “%s”."
+msgid "helper %s does not support --atomic"
+msgstr "helper %s không hỗ trợ --atomic"
 
-#: builtin/branch.c:736
+#: transport-helper.c:866
 #, c-format
-msgid "No branch named '%s'."
-msgstr "Không có nhánh nào có tên “%s”."
+msgid "helper %s does not support 'push-option'"
+msgstr "helper %s không hỗ trợ “push-option”"
 
-#: builtin/branch.c:751
-msgid "too many branches for a copy operation"
-msgstr "quá nhiều nhánh dành cho thao tác sao chép"
+#: transport-helper.c:964
+msgid "remote-helper doesn't support push; refspec needed"
+msgstr "remote-helper không hỗ trợ push; cần đặc tả tham chiếu"
 
-#: builtin/branch.c:760
-msgid "too many arguments for a rename operation"
-msgstr "quá nhiều tham số cho thao tác đổi tên"
+#: transport-helper.c:969
+#, c-format
+msgid "helper %s does not support 'force'"
+msgstr "helper %s không hỗ trợ “force”"
 
-#: builtin/branch.c:765
-msgid "too many arguments to set new upstream"
-msgstr "quá nhiều tham số để đặt thượng nguồn mới"
+#: transport-helper.c:1016
+msgid "couldn't run fast-export"
+msgstr "không thể chạy fast-export"
+
+#: transport-helper.c:1021
+msgid "error while running fast-export"
+msgstr "gặp lỗi trong khi chạy fast-export"
 
-#: builtin/branch.c:769
+#: transport-helper.c:1046
 #, c-format
 msgid ""
-"could not set upstream of HEAD to %s when it does not point to any branch."
+"No refs in common and none specified; doing nothing.\n"
+"Perhaps you should specify a branch such as 'master'.\n"
 msgstr ""
-"không thể đặt thượng nguồn của HEAD thành %s khi mà nó chẳng chỉ đến nhánh "
-"nào cả."
+"Không có các tham chiếu trong phần chung và chưa chỉ định; nên không làm gì "
+"cả.\n"
+"Tuy nhiên bạn nên chỉ định một nhánh như “master” chẳng hạn.\n"
 
-#: builtin/branch.c:772 builtin/branch.c:794 builtin/branch.c:810
+#: transport-helper.c:1119
 #, c-format
-msgid "no such branch '%s'"
-msgstr "không có nhánh nào như thế “%s”"
+msgid "malformed response in ref list: %s"
+msgstr "đáp ứng sai dạng trong danh sách tham chiếu: %s"
 
-#: builtin/branch.c:776
+#: transport-helper.c:1271
 #, c-format
-msgid "branch '%s' does not exist"
-msgstr "chưa có nhánh “%s”"
+msgid "read(%s) failed"
+msgstr "read(%s) gặp lỗi"
 
-#: builtin/branch.c:788
-msgid "too many arguments to unset upstream"
-msgstr "quá nhiều tham số để bỏ đặt thượng nguồn"
+#: transport-helper.c:1298
+#, c-format
+msgid "write(%s) failed"
+msgstr "write(%s) gặp lỗi"
 
-#: builtin/branch.c:792
-msgid "could not unset upstream of HEAD when it does not point to any branch."
-msgstr "không thể bỏ đặt thượng nguồn của HEAD không chỉ đến một nhánh nào cả."
+#: transport-helper.c:1347
+#, c-format
+msgid "%s thread failed"
+msgstr "tuyến trình %s gặp lỗi"
 
-#: builtin/branch.c:798
+#: transport-helper.c:1351
 #, c-format
-msgid "Branch '%s' has no upstream information"
-msgstr "Nhánh “%s” không có thông tin thượng nguồn"
+msgid "%s thread failed to join: %s"
+msgstr "tuyến trình %s gặp lỗi khi gia nhập: %s"
 
-#: builtin/branch.c:813
-msgid "-a and -r options to 'git branch' do not make sense with a branch name"
-msgstr ""
-"hai tùy chọn -a và -r áp dụng cho lệnh “git branch” không hợp lý đối với tên "
-"nhánh"
+#: transport-helper.c:1370 transport-helper.c:1374
+#, c-format
+msgid "can't start thread for copying data: %s"
+msgstr "không thể khởi chạy tuyến trình để sao chép dữ liệu: %s"
 
-#: builtin/branch.c:816
-msgid ""
-"the '--set-upstream' option is no longer supported. Please use '--track' or "
-"'--set-upstream-to' instead."
-msgstr ""
-"tùy chọn --set-upstream đã không còn được hỗ trợ nữa. Vui lòng dùng “--"
-"track” hoặc “--set-upstream-to” để thay thế."
+#: transport-helper.c:1411
+#, c-format
+msgid "%s process failed to wait"
+msgstr "xử lý %s gặp lỗi khi đợi"
 
-#: builtin/bundle.c:45
+#: transport-helper.c:1415
 #, c-format
-msgid "%s is okay\n"
-msgstr "“%s” tốt\n"
+msgid "%s process failed"
+msgstr "xử lý %s gặp lỗi"
 
-#: builtin/bundle.c:58
-msgid "Need a repository to create a bundle."
-msgstr "Cần một kho chứa để có thể tạo một bundle."
+#: transport-helper.c:1433 transport-helper.c:1442
+msgid "can't start thread for copying data"
+msgstr "không thể khởi chạy tuyến trình cho việc chép dữ liệu"
 
-#: builtin/bundle.c:62
-msgid "Need a repository to unbundle."
-msgstr "Cần một kho chứa để có thể giải nén một bundle."
+#: tree-walk.c:33
+msgid "too-short tree object"
+msgstr "đối tượng cây quá ngắn"
+
+#: tree-walk.c:39
+msgid "malformed mode in tree entry"
+msgstr "chế độ dị hình trong đề mục cây"
 
-#: builtin/cat-file.c:525
+#: tree-walk.c:43
+msgid "empty filename in tree entry"
+msgstr "tên tập tin trống rỗng trong mục tin cây"
+
+#: tree-walk.c:48
+#, c-format
+msgid "filename in tree entry contains backslash: '%s'"
+msgstr "tên tập tin trong mục tin cây có chứa ký tự gạch ngược: '%s'"
+
+#: tree-walk.c:124
+msgid "too-short tree file"
+msgstr "tập tin cây quá ngắn"
+
+#: unpack-trees.c:110
+#, c-format
 msgid ""
-"git cat-file (-t [--allow-unknown-type] | -s [--allow-unknown-type] | -e | -"
-"p | <type> | --textconv | --filters) [--path=<path>] <object>"
+"Your local changes to the following files would be overwritten by checkout:\n"
+"%%sPlease commit your changes or stash them before you switch branches."
 msgstr ""
-"git cat-file (-t [--allow-unknown-type] | -s [--allow-unknown-type] | -e | -"
-"p | <kiểu> | --textconv) | --filters) [--path=<đường/dẫn>] <đối_tượng>"
+"Các thay đổi nội bộ của bạn với các tập tin sau đây sẽ bị ghi đè bởi lệnh "
+"checkout:\n"
+"%%sVui lòng chuyển giao các thay đổi hay tạm cất chúng đi trước khi bạn "
+"chuyển nhánh."
 
-#: builtin/cat-file.c:526
+#: unpack-trees.c:112
+#, c-format
 msgid ""
-"git cat-file (--batch | --batch-check) [--follow-symlinks] [--textconv | --"
-"filters]"
+"Your local changes to the following files would be overwritten by checkout:\n"
+"%%s"
 msgstr ""
-"git cat-file (--batch | --batch-check) [--follow-symlinks] [--textconv | --"
-"filters]"
-
-#: builtin/cat-file.c:563
-msgid "<type> can be one of: blob, tree, commit, tag"
-msgstr "<kiểu> là một trong số: blob, tree, commit hoặc tag"
+"Các thay đổi nội bộ của bạn với các tập tin sau đây sẽ bị ghi đè bởi lệnh "
+"checkout:\n"
+"%%s"
 
-#: builtin/cat-file.c:564
+#: unpack-trees.c:115
+#, c-format
+msgid ""
+"Your local changes to the following files would be overwritten by merge:\n"
+"%%sPlease commit your changes or stash them before you merge."
+msgstr ""
+"Các thay đổi nội bộ của bạn với các tập tin sau đây sẽ bị ghi đè bởi lệnh "
+"hòa trộn:\n"
+"%%sVui lòng chuyển giao các thay đổi hay tạm cất chúng đi trước khi bạn hòa "
+"trộn."
+
+#: unpack-trees.c:117
+#, c-format
+msgid ""
+"Your local changes to the following files would be overwritten by merge:\n"
+"%%s"
+msgstr ""
+"Các thay đổi nội bộ của bạn với các tập tin sau đây sẽ bị ghi đè bởi lệnh "
+"hòa trộn:\n"
+"%%s"
+
+#: unpack-trees.c:120
+#, c-format
+msgid ""
+"Your local changes to the following files would be overwritten by %s:\n"
+"%%sPlease commit your changes or stash them before you %s."
+msgstr ""
+"Các thay đổi nội bộ của bạn với các tập tin sau đây sẽ bị ghi đè bởi lệnh "
+"%s:\n"
+"%%sVui lòng chuyển giao các thay đổi hay tạm cất chúng đi trước khi bạn %s."
+
+#: unpack-trees.c:122
+#, c-format
+msgid ""
+"Your local changes to the following files would be overwritten by %s:\n"
+"%%s"
+msgstr ""
+"Các thay đổi nội bộ của bạn với các tập tin sau đây sẽ bị ghi đè bởi lệnh "
+"%s:\n"
+"%%s"
+
+#: unpack-trees.c:127
+#, c-format
+msgid ""
+"Updating the following directories would lose untracked files in them:\n"
+"%s"
+msgstr ""
+"Việc cập nhật các thư mục sau đây có thể làm mất các tập tin chưa theo dõi "
+"trong nó:\n"
+"%s"
+
+#: unpack-trees.c:131
+#, c-format
+msgid ""
+"The following untracked working tree files would be removed by checkout:\n"
+"%%sPlease move or remove them before you switch branches."
+msgstr ""
+"Các tập tin cây làm việc chưa được theo dõi sau đây sẽ bị gỡ bỏ bởi lệnh "
+"checkout:\n"
+"%%sVui lòng di chuyển hay gỡ bỏ chúng trước khi bạn chuyển nhánh."
+
+#: unpack-trees.c:133
+#, c-format
+msgid ""
+"The following untracked working tree files would be removed by checkout:\n"
+"%%s"
+msgstr ""
+"Các tập tin cây làm việc chưa được theo dõi sau đây sẽ bị gỡ bỏ bởi lệnh "
+"checkout:\n"
+"%%s"
+
+#: unpack-trees.c:136
+#, c-format
+msgid ""
+"The following untracked working tree files would be removed by merge:\n"
+"%%sPlease move or remove them before you merge."
+msgstr ""
+"Các tập tin cây làm việc chưa được theo dõi sau đây sẽ bị gỡ bỏ bởi lệnh hòa "
+"trộn:\n"
+"%%sVui lòng di chuyển hay gỡ bỏ chúng trước khi bạn hòa trộn."
+
+#: unpack-trees.c:138
+#, c-format
+msgid ""
+"The following untracked working tree files would be removed by merge:\n"
+"%%s"
+msgstr ""
+"Các tập tin cây làm việc chưa được theo dõi sau đây sẽ bị gỡ bỏ bởi lệnh hòa "
+"trộn:\n"
+"%%s"
+
+#: unpack-trees.c:141
+#, c-format
+msgid ""
+"The following untracked working tree files would be removed by %s:\n"
+"%%sPlease move or remove them before you %s."
+msgstr ""
+"Các tập tin cây làm việc chưa được theo dõi sau đây sẽ bị gỡ bỏ bởi %s:\n"
+"%%sVui lòng di chuyển hay gỡ bỏ chúng trước khi bạn %s."
+
+#: unpack-trees.c:143
+#, c-format
+msgid ""
+"The following untracked working tree files would be removed by %s:\n"
+"%%s"
+msgstr ""
+"Các tập tin cây làm việc chưa được theo dõi sau đây sẽ bị gỡ bỏ bởi %s:\n"
+"%%s"
+
+#: unpack-trees.c:149
+#, c-format
+msgid ""
+"The following untracked working tree files would be overwritten by "
+"checkout:\n"
+"%%sPlease move or remove them before you switch branches."
+msgstr ""
+"Các tập tin cây làm việc chưa được theo dõi sau đây sẽ bị ghi đè bởi lệnh "
+"checkout:\n"
+"%%sVui lòng di chuyển hay gỡ bỏ chúng trước khi bạn chuyển nhánh."
+
+#: unpack-trees.c:151
+#, c-format
+msgid ""
+"The following untracked working tree files would be overwritten by "
+"checkout:\n"
+"%%s"
+msgstr ""
+"Các tập tin cây làm việc chưa được theo dõi sau đây sẽ bị ghi đè bởi lệnh "
+"checkout:\n"
+"%%s"
+
+#: unpack-trees.c:154
+#, c-format
+msgid ""
+"The following untracked working tree files would be overwritten by merge:\n"
+"%%sPlease move or remove them before you merge."
+msgstr ""
+"Các tập tin cây làm việc chưa được theo dõi sau đây sẽ bị ghi đè bởi lệnh "
+"hòa trộn:\n"
+"%%sVui lòng di chuyển hay gỡ bỏ chúng trước khi bạn hòa trộn."
+
+#: unpack-trees.c:156
+#, c-format
+msgid ""
+"The following untracked working tree files would be overwritten by merge:\n"
+"%%s"
+msgstr ""
+"Các tập tin cây làm việc chưa được theo dõi sau đây sẽ bị ghi đè bởi lệnh "
+"hòa trộn:\n"
+"%%s"
+
+#: unpack-trees.c:159
+#, c-format
+msgid ""
+"The following untracked working tree files would be overwritten by %s:\n"
+"%%sPlease move or remove them before you %s."
+msgstr ""
+"Các tập tin cây làm việc chưa được theo dõi sau đây sẽ bị ghi đè bởi lệnh "
+"%s:\n"
+"%%sVui lòng di chuyển hay gỡ bỏ chúng trước khi bạn %s."
+
+#: unpack-trees.c:161
+#, c-format
+msgid ""
+"The following untracked working tree files would be overwritten by %s:\n"
+"%%s"
+msgstr ""
+"Các tập tin cây làm việc chưa được theo dõi sau đây sẽ bị ghi đè bởi lệnh "
+"%s:\n"
+"%%s"
+
+#: unpack-trees.c:169
+#, c-format
+msgid "Entry '%s' overlaps with '%s'.  Cannot bind."
+msgstr "Mục “%s” đè lên “%s”. Không thể buộc."
+
+#: unpack-trees.c:172
+#, c-format
+msgid ""
+"Cannot update sparse checkout: the following entries are not up to date:\n"
+"%s"
+msgstr ""
+"Không thể cập nhật checkout rải rác: các mục tin sau đây chưa cập nhật:\n"
+"%s"
+
+#: unpack-trees.c:174
+#, c-format
+msgid ""
+"The following working tree files would be overwritten by sparse checkout "
+"update:\n"
+"%s"
+msgstr ""
+"Các tập tin cây làm việc chưa được theo dõi sau đây sẽ bị ghi đè bởi cập "
+"nhật checkout rải rác:\n"
+"%s"
+
+#: unpack-trees.c:176
+#, c-format
+msgid ""
+"The following working tree files would be removed by sparse checkout "
+"update:\n"
+"%s"
+msgstr ""
+"Các tập tin cây làm việc chưa được theo dõi sau đây sẽ bị xóa bỏ bởi cập "
+"nhật checkout rải rác:\n"
+"%s"
+
+#: unpack-trees.c:178
+#, c-format
+msgid ""
+"Cannot update submodule:\n"
+"%s"
+msgstr ""
+"Không thể cập nhật mô-đun-con:\n"
+"%s"
+
+#: unpack-trees.c:255
+#, c-format
+msgid "Aborting\n"
+msgstr "Bãi bỏ\n"
+
+#: unpack-trees.c:317
+msgid "Updating files"
+msgstr "Đang cập nhật các tập tin"
+
+#: unpack-trees.c:349
+msgid ""
+"the following paths have collided (e.g. case-sensitive paths\n"
+"on a case-insensitive filesystem) and only one from the same\n"
+"colliding group is in the working tree:\n"
+msgstr ""
+"các đường dẫn sau đây có xung đột(vd: các đường dẫn phân biệt\n"
+"HOA/thường trên một hệ thống tập tin không phân biệt HOA/thường)\n"
+"và chỉ một từ cùng một nhóm xung đột là trong cây làm việc hiện tại:\n"
+
+#: unpack-trees.c:1441
+msgid "Updating index flags"
+msgstr "Đang cập nhật các cờ mục lục"
+
+#: urlmatch.c:163
+msgid "invalid URL scheme name or missing '://' suffix"
+msgstr "tên lược đồ URL không hợp lệ, hoặc thiếu hậu tố “://”"
+
+#: urlmatch.c:187 urlmatch.c:346 urlmatch.c:405
+#, c-format
+msgid "invalid %XX escape sequence"
+msgstr "thoát chuỗi %XX không hợp lệ"
+
+#: urlmatch.c:215
+msgid "missing host and scheme is not 'file:'"
+msgstr "thiếu máy chủ và lược đồ thì không phải là giao thức “file:”"
+
+#: urlmatch.c:232
+msgid "a 'file:' URL may not have a port number"
+msgstr "một URL kiểu “file:” không được chứa cổng"
+
+#: urlmatch.c:247
+msgid "invalid characters in host name"
+msgstr "có các ký tự không hợp lệ trong tên máy"
+
+#: urlmatch.c:292 urlmatch.c:303
+msgid "invalid port number"
+msgstr "tên cổng không hợp lệ"
+
+#: urlmatch.c:371
+msgid "invalid '..' path segment"
+msgstr "đoạn đường dẫn “..” không hợp lệ"
+
+#: worktree.c:258 builtin/am.c:2084
+#, c-format
+msgid "failed to read '%s'"
+msgstr "gặp lỗi khi đọc “%s”"
+
+#: worktree.c:304
+#, c-format
+msgid "'%s' at main working tree is not the repository directory"
+msgstr "“%s” tại cây làm việc chình không phải là thư mục kho"
+
+#: worktree.c:315
+#, c-format
+msgid "'%s' file does not contain absolute path to the working tree location"
+msgstr ""
+"tập tin “%s” không chứa đường dẫn tuyệt đối đến vị trí cây làm việc hiện"
+
+#: worktree.c:327
+#, c-format
+msgid "'%s' does not exist"
+msgstr "\"%s\" không tồn tại"
+
+#: worktree.c:333
+#, c-format
+msgid "'%s' is not a .git file, error code %d"
+msgstr "“%s” không phải là tập tin .git, mã lỗi %d"
+
+#: worktree.c:341
+#, c-format
+msgid "'%s' does not point back to '%s'"
+msgstr "“%s” không chỉ ngược đến “%s”"
+
+#: wrapper.c:186 wrapper.c:356
+#, c-format
+msgid "could not open '%s' for reading and writing"
+msgstr "không thể mở “%s” để đọc và ghi"
+
+#: wrapper.c:387 wrapper.c:588
+#, c-format
+msgid "unable to access '%s'"
+msgstr "không thể truy cập “%s”"
+
+#: wrapper.c:596
+msgid "unable to get current working directory"
+msgstr "không thể lấy thư mục làm việc hiện hành"
+
+#: wt-status.c:158
+msgid "Unmerged paths:"
+msgstr "Những đường dẫn chưa được hòa trộn:"
+
+#: wt-status.c:187 wt-status.c:219
+msgid "  (use \"git restore --staged <file>...\" to unstage)"
+msgstr "  (dùng \"git restore --staged <tập-tin>…\" để bỏ ra khỏi bệ phóng)"
+
+#: wt-status.c:190 wt-status.c:222
+#, c-format
+msgid "  (use \"git restore --source=%s --staged <file>...\" to unstage)"
+msgstr ""
+"  (dùng \"git restore --source=%s --staged <tập-tin>…\" để bỏ ra khỏi bệ "
+"phóng)"
+
+#: wt-status.c:193 wt-status.c:225
+msgid "  (use \"git rm --cached <file>...\" to unstage)"
+msgstr "  (dùng \"git rm --cached <tập-tin>…\" để bỏ ra khỏi bệ phóng)"
+
+#: wt-status.c:197
+msgid "  (use \"git add <file>...\" to mark resolution)"
+msgstr "  (dùng \"git add <tập-tin>…\" để đánh dấu là cần giải quyết)"
+
+#: wt-status.c:199 wt-status.c:203
+msgid "  (use \"git add/rm <file>...\" as appropriate to mark resolution)"
+msgstr ""
+"  (dùng \"git add/rm <tập-tin>…\" như là một cách thích hợp để đánh dấu là "
+"cần được giải quyết)"
+
+#: wt-status.c:201
+msgid "  (use \"git rm <file>...\" to mark resolution)"
+msgstr "  (dùng \"git rm <tập-tin>…\" để đánh dấu là cần giải quyết)"
+
+#: wt-status.c:211 wt-status.c:1074
+msgid "Changes to be committed:"
+msgstr "Những thay đổi sẽ được chuyển giao:"
+
+#: wt-status.c:234 wt-status.c:1083
+msgid "Changes not staged for commit:"
+msgstr "Các thay đổi chưa được đặt lên bệ phóng để chuyển giao:"
+
+#: wt-status.c:238
+msgid "  (use \"git add <file>...\" to update what will be committed)"
+msgstr "  (dùng \"git add <tập-tin>…\" để cập nhật những gì sẽ chuyển giao)"
+
+#: wt-status.c:240
+msgid "  (use \"git add/rm <file>...\" to update what will be committed)"
+msgstr ""
+"  (dùng \"git add/rm <tập-tin>…\" để cập nhật những gì sẽ được chuyển giao)"
+
+#: wt-status.c:241
+msgid ""
+"  (use \"git restore <file>...\" to discard changes in working directory)"
+msgstr ""
+"  (dùng \"git restore <tập-tin>…\" để loại bỏ các thay đổi trong thư mục làm "
+"việc)"
+
+#: wt-status.c:243
+msgid "  (commit or discard the untracked or modified content in submodules)"
+msgstr ""
+"  (chuyển giao hoặc là loại bỏ các nội dung chưa được theo dõi hay đã sửa "
+"chữa trong mô-đun-con)"
+
+#: wt-status.c:254
+#, c-format
+msgid "  (use \"git %s <file>...\" to include in what will be committed)"
+msgstr ""
+"  (dùng \"git %s <tập-tin>…\" để thêm vào những gì cần được chuyển giao)"
+
+#: wt-status.c:268
+msgid "both deleted:"
+msgstr "bị xóa bởi cả hai:"
+
+#: wt-status.c:270
+msgid "added by us:"
+msgstr "được thêm vào bởi chúng ta:"
+
+#: wt-status.c:272
+msgid "deleted by them:"
+msgstr "bị xóa đi bởi họ:"
+
+#: wt-status.c:274
+msgid "added by them:"
+msgstr "được thêm vào bởi họ:"
+
+#: wt-status.c:276
+msgid "deleted by us:"
+msgstr "bị xóa bởi chúng ta:"
+
+#: wt-status.c:278
+msgid "both added:"
+msgstr "được thêm vào bởi cả hai:"
+
+#: wt-status.c:280
+msgid "both modified:"
+msgstr "bị sửa bởi cả hai:"
+
+#: wt-status.c:290
+msgid "new file:"
+msgstr "tập tin mới:"
+
+#: wt-status.c:292
+msgid "copied:"
+msgstr "đã chép:"
+
+#: wt-status.c:294
+msgid "deleted:"
+msgstr "đã xóa:"
+
+#: wt-status.c:296
+msgid "modified:"
+msgstr "đã sửa:"
+
+#: wt-status.c:298
+msgid "renamed:"
+msgstr "đã đổi tên:"
+
+#: wt-status.c:300
+msgid "typechange:"
+msgstr "đổi-kiểu:"
+
+#: wt-status.c:302
+msgid "unknown:"
+msgstr "không hiểu:"
+
+#: wt-status.c:304
+msgid "unmerged:"
+msgstr "chưa hòa trộn:"
+
+#: wt-status.c:384
+msgid "new commits, "
+msgstr "lần chuyển giao mới, "
+
+#: wt-status.c:386
+msgid "modified content, "
+msgstr "nội dung bị sửa đổi, "
+
+#: wt-status.c:388
+msgid "untracked content, "
+msgstr "nội dung chưa được theo dõi, "
+
+#: wt-status.c:906
+#, c-format
+msgid "Your stash currently has %d entry"
+msgid_plural "Your stash currently has %d entries"
+msgstr[0] "Bạn hiện nay ở trong phần cất đi đang có %d mục"
+
+#: wt-status.c:938
+msgid "Submodules changed but not updated:"
+msgstr "Những mô-đun-con đã bị thay đổi nhưng chưa được cập nhật:"
+
+#: wt-status.c:940
+msgid "Submodule changes to be committed:"
+msgstr "Những mô-đun-con thay đổi đã được chuyển giao:"
+
+#: wt-status.c:1022
+msgid ""
+"Do not modify or remove the line above.\n"
+"Everything below it will be ignored."
+msgstr ""
+"Không sửa hay xóa bỏ đường ở trên.\n"
+"Mọi thứ phía dưới sẽ được xóa bỏ."
+
+#: wt-status.c:1114
+#, c-format
+msgid ""
+"\n"
+"It took %.2f seconds to compute the branch ahead/behind values.\n"
+"You can use '--no-ahead-behind' to avoid this.\n"
+msgstr ""
+"\n"
+"Nó cần %.2f giây để tính toán giá trị của trước/sau của nhánh.\n"
+"Bạn có thể dùng '--no-ahead-behind' tránh phải điều này.\n"
+
+#: wt-status.c:1144
+msgid "You have unmerged paths."
+msgstr "Bạn có những đường dẫn chưa được hòa trộn."
+
+#: wt-status.c:1147
+msgid "  (fix conflicts and run \"git commit\")"
+msgstr "  (sửa các xung đột rồi chạy \"git commit\")"
+
+#: wt-status.c:1149
+msgid "  (use \"git merge --abort\" to abort the merge)"
+msgstr "  (dùng \"git merge --abort\" để bãi bỏ việc hòa trộn)"
+
+#: wt-status.c:1153
+msgid "All conflicts fixed but you are still merging."
+msgstr "Tất cả các xung đột đã được giải quyết nhưng bạn vẫn đang hòa trộn."
+
+#: wt-status.c:1156
+msgid "  (use \"git commit\" to conclude merge)"
+msgstr "  (dùng \"git commit\" để hoàn tất việc hòa trộn)"
+
+#: wt-status.c:1165
+msgid "You are in the middle of an am session."
+msgstr "Bạn đang ở giữa của một phiên “am”."
+
+#: wt-status.c:1168
+msgid "The current patch is empty."
+msgstr "Miếng vá hiện tại bị trống rỗng."
+
+#: wt-status.c:1172
+msgid "  (fix conflicts and then run \"git am --continue\")"
+msgstr "  (sửa các xung đột và sau đó chạy lệnh \"git am --continue\")"
+
+#: wt-status.c:1174
+msgid "  (use \"git am --skip\" to skip this patch)"
+msgstr "  (dùng \"git am --skip\" để bỏ qua miếng vá này)"
+
+#: wt-status.c:1176
+msgid "  (use \"git am --abort\" to restore the original branch)"
+msgstr "  (dùng \"git am --abort\" để phục hồi lại nhánh nguyên thủy)"
+
+#: wt-status.c:1309
+msgid "git-rebase-todo is missing."
+msgstr "thiếu git-rebase-todo."
+
+#: wt-status.c:1311
+msgid "No commands done."
+msgstr "Không thực hiện lệnh nào."
+
+#: wt-status.c:1314
+#, c-format
+msgid "Last command done (%d command done):"
+msgid_plural "Last commands done (%d commands done):"
+msgstr[0] "Lệnh thực hiện cuối (%d lệnh được thực thi):"
+
+#: wt-status.c:1325
+#, c-format
+msgid "  (see more in file %s)"
+msgstr "  (xem thêm trong %s)"
+
+#: wt-status.c:1330
+msgid "No commands remaining."
+msgstr "Không có lệnh nào còn lại."
+
+#: wt-status.c:1333
+#, c-format
+msgid "Next command to do (%d remaining command):"
+msgid_plural "Next commands to do (%d remaining commands):"
+msgstr[0] "Lệnh cần làm kế tiếp (%d lệnh còn lại):"
+
+#: wt-status.c:1341
+msgid "  (use \"git rebase --edit-todo\" to view and edit)"
+msgstr "  (dùng lệnh \"git rebase --edit-todo\" để xem và sửa)"
+
+#: wt-status.c:1353
+#, c-format
+msgid "You are currently rebasing branch '%s' on '%s'."
+msgstr "Bạn hiện nay đang thực hiện việc “rebase” nhánh “%s” trên “%s”."
+
+#: wt-status.c:1358
+msgid "You are currently rebasing."
+msgstr "Bạn hiện nay đang thực hiện việc “rebase” (“cải tổ”)."
+
+#: wt-status.c:1371
+msgid "  (fix conflicts and then run \"git rebase --continue\")"
+msgstr ""
+"  (sửa các xung đột và sau đó chạy lệnh “cải tổ” \"git rebase --continue\")"
+
+#: wt-status.c:1373
+msgid "  (use \"git rebase --skip\" to skip this patch)"
+msgstr "  (dùng lệnh “cải tổ” \"git rebase --skip\" để bỏ qua lần vá này)"
+
+#: wt-status.c:1375
+msgid "  (use \"git rebase --abort\" to check out the original branch)"
+msgstr ""
+"  (dùng lệnh “cải tổ” \"git rebase --abort\" để check-out nhánh nguyên thủy)"
+
+#: wt-status.c:1382
+msgid "  (all conflicts fixed: run \"git rebase --continue\")"
+msgstr ""
+"  (khi tất cả các xung đột đã sửa xong: chạy lệnh “cải tổ” \"git rebase --"
+"continue\")"
+
+#: wt-status.c:1386
+#, c-format
+msgid ""
+"You are currently splitting a commit while rebasing branch '%s' on '%s'."
+msgstr ""
+"Bạn hiện nay đang thực hiện việc chia tách một lần chuyển giao trong khi "
+"đang “rebase” nhánh “%s” trên “%s”."
+
+#: wt-status.c:1391
+msgid "You are currently splitting a commit during a rebase."
+msgstr ""
+"Bạn hiện tại đang cắt đôi một lần chuyển giao trong khi đang thực hiện việc "
+"rebase."
+
+#: wt-status.c:1394
+msgid "  (Once your working directory is clean, run \"git rebase --continue\")"
+msgstr ""
+"  (Một khi thư mục làm việc của bạn đã gọn gàng, chạy lệnh “cải tổ” \"git "
+"rebase --continue\")"
+
+#: wt-status.c:1398
+#, c-format
+msgid "You are currently editing a commit while rebasing branch '%s' on '%s'."
+msgstr ""
+"Bạn hiện nay đang thực hiện việc sửa chữa một lần chuyển giao trong khi đang "
+"rebase nhánh “%s” trên “%s”."
+
+#: wt-status.c:1403
+msgid "You are currently editing a commit during a rebase."
+msgstr "Bạn hiện đang sửa một lần chuyển giao trong khi bạn thực hiện rebase."
+
+#: wt-status.c:1406
+msgid "  (use \"git commit --amend\" to amend the current commit)"
+msgstr "  (dùng \"git commit --amend\" để “tu bổ” lần chuyển giao hiện tại)"
+
+#: wt-status.c:1408
+msgid ""
+"  (use \"git rebase --continue\" once you are satisfied with your changes)"
+msgstr ""
+"  (chạy lệnh “cải tổ” \"git rebase --continue\" một khi bạn cảm thấy hài "
+"lòng về những thay đổi của mình)"
+
+#: wt-status.c:1419
+msgid "Cherry-pick currently in progress."
+msgstr "Cherry-pick hiện tại đang được thực hiện."
+
+#: wt-status.c:1422
+#, c-format
+msgid "You are currently cherry-picking commit %s."
+msgstr "Bạn hiện nay đang thực hiện việc cherry-pick lần chuyển giao %s."
+
+#: wt-status.c:1429
+msgid "  (fix conflicts and run \"git cherry-pick --continue\")"
+msgstr ""
+"  (sửa các xung đột và sau đó chạy lệnh \"git cherry-pick --continue\")"
+
+#: wt-status.c:1432
+msgid "  (run \"git cherry-pick --continue\" to continue)"
+msgstr "  (chạy lệnh \"git cherry-pick --continue\" để tiếp tục)"
+
+#: wt-status.c:1435
+msgid "  (all conflicts fixed: run \"git cherry-pick --continue\")"
+msgstr ""
+"  (khi tất cả các xung đột đã sửa xong: chạy lệnh \"git cherry-pick --"
+"continue\")"
+
+#: wt-status.c:1437
+msgid "  (use \"git cherry-pick --skip\" to skip this patch)"
+msgstr "  (dùng \"git cherry-pick --skip\" để bỏ qua miếng vá này)"
+
+#: wt-status.c:1439
+msgid "  (use \"git cherry-pick --abort\" to cancel the cherry-pick operation)"
+msgstr "  (dùng \"git cherry-pick --abort\" để hủy bỏ thao tác cherry-pick)"
+
+#: wt-status.c:1449
+msgid "Revert currently in progress."
+msgstr "Hoàn nguyên hiện tại đang thực hiện."
+
+#: wt-status.c:1452
+#, c-format
+msgid "You are currently reverting commit %s."
+msgstr "Bạn hiện nay đang thực hiện thao tác hoàn nguyên lần chuyển giao “%s”."
+
+#: wt-status.c:1458
+msgid "  (fix conflicts and run \"git revert --continue\")"
+msgstr "  (sửa các xung đột và sau đó chạy lệnh \"git revert --continue\")"
+
+#: wt-status.c:1461
+msgid "  (run \"git revert --continue\" to continue)"
+msgstr "  (chạy lệnh \"git revert --continue\" để tiếp tục)"
+
+#: wt-status.c:1464
+msgid "  (all conflicts fixed: run \"git revert --continue\")"
+msgstr ""
+"  (khi tất cả các xung đột đã sửa xong: chạy lệnh \"git revert --continue\")"
+
+#: wt-status.c:1466
+msgid "  (use \"git revert --skip\" to skip this patch)"
+msgstr "  (dùng lệnh \"git revert --skip\" để bỏ qua lần vá này)"
+
+#: wt-status.c:1468
+msgid "  (use \"git revert --abort\" to cancel the revert operation)"
+msgstr "  (dùng \"git revert --abort\" để hủy bỏ thao tác hoàn nguyên)"
+
+#: wt-status.c:1478
+#, c-format
+msgid "You are currently bisecting, started from branch '%s'."
+msgstr ""
+"Bạn hiện nay đang thực hiện thao tác di chuyển nửa bước (bisect), bắt đầu từ "
+"nhánh “%s”."
+
+#: wt-status.c:1482
+msgid "You are currently bisecting."
+msgstr "Bạn hiện tại đang thực hiện việc bisect (di chuyển nửa bước)."
+
+#: wt-status.c:1485
+msgid "  (use \"git bisect reset\" to get back to the original branch)"
+msgstr "  (dùng \"git bisect reset\" để quay trở lại nhánh nguyên thủy)"
+
+#: wt-status.c:1694
+msgid "On branch "
+msgstr "Trên nhánh "
+
+#: wt-status.c:1701
+msgid "interactive rebase in progress; onto "
+msgstr "rebase ở chế độ tương tác đang được thực hiện; lên trên "
+
+#: wt-status.c:1703
+msgid "rebase in progress; onto "
+msgstr "rebase đang được thực hiện: lên trên "
+
+#: wt-status.c:1713
+msgid "Not currently on any branch."
+msgstr "Hiện tại chẳng ở nhánh nào cả."
+
+#: wt-status.c:1730
+msgid "Initial commit"
+msgstr "Lần chuyển giao khởi tạo"
+
+#: wt-status.c:1731
+msgid "No commits yet"
+msgstr "Vẫn chưa chuyển giao"
+
+#: wt-status.c:1745
+msgid "Untracked files"
+msgstr "Những tập tin chưa được theo dõi"
+
+#: wt-status.c:1747
+msgid "Ignored files"
+msgstr "Những tập tin bị lờ đi"
+
+#: wt-status.c:1751
+#, c-format
+msgid ""
+"It took %.2f seconds to enumerate untracked files. 'status -uno'\n"
+"may speed it up, but you have to be careful not to forget to add\n"
+"new files yourself (see 'git help status')."
+msgstr ""
+"Cần %.2f giây để liệt kê tất cả các tập tin chưa được theo dõi. “status -"
+"uno”\n"
+"có lẽ làm nó nhanh hơn, nhưng bạn phải cẩn thận đừng quên mình phải\n"
+"tự thêm các tập tin mới (xem “git help status”.."
+
+#: wt-status.c:1757
+#, c-format
+msgid "Untracked files not listed%s"
+msgstr "Những tập tin chưa được theo dõi không được liệt kê ra %s"
+
+#: wt-status.c:1759
+msgid " (use -u option to show untracked files)"
+msgstr " (dùng tùy chọn -u để hiển thị các tập tin chưa được theo dõi)"
+
+#: wt-status.c:1765
+msgid "No changes"
+msgstr "Không có thay đổi nào"
+
+#: wt-status.c:1770
+#, c-format
+msgid "no changes added to commit (use \"git add\" and/or \"git commit -a\")\n"
+msgstr ""
+"không có thay đổi nào được thêm vào để chuyển giao (dùng \"git add\" và/hoặc "
+"\"git commit -a\")\n"
+
+#: wt-status.c:1773
+#, c-format
+msgid "no changes added to commit\n"
+msgstr "không có thay đổi nào được thêm vào để chuyển giao\n"
+
+#: wt-status.c:1776
+#, c-format
+msgid ""
+"nothing added to commit but untracked files present (use \"git add\" to "
+"track)\n"
+msgstr ""
+"không có gì được thêm vào lần chuyển giao nhưng có những tập tin chưa được "
+"theo dõi hiện diện (dùng \"git add\" để đưa vào theo dõi)\n"
+
+#: wt-status.c:1779
+#, c-format
+msgid "nothing added to commit but untracked files present\n"
+msgstr ""
+"không có gì được thêm vào lần chuyển giao nhưng có những tập tin chưa được "
+"theo dõi hiện diện\n"
+
+#: wt-status.c:1782
+#, c-format
+msgid "nothing to commit (create/copy files and use \"git add\" to track)\n"
+msgstr ""
+"không có gì để chuyển giao (tạo/sao-chép các tập tin và dùng \"git add\" để "
+"đưa vào theo dõi)\n"
+
+#: wt-status.c:1785 wt-status.c:1790
+#, c-format
+msgid "nothing to commit\n"
+msgstr "không có gì để chuyển giao\n"
+
+#: wt-status.c:1788
+#, c-format
+msgid "nothing to commit (use -u to show untracked files)\n"
+msgstr ""
+"không có gì để chuyển giao (dùng -u xem các tập tin chưa được theo dõi)\n"
+
+#: wt-status.c:1792
+#, c-format
+msgid "nothing to commit, working tree clean\n"
+msgstr "không có gì để chuyển giao, thư mục làm việc sạch sẽ\n"
+
+#: wt-status.c:1905
+msgid "No commits yet on "
+msgstr "Vẫn không thực hiện lệnh chuyển giao nào "
+
+#: wt-status.c:1909
+msgid "HEAD (no branch)"
+msgstr "HEAD (không nhánh)"
+
+#: wt-status.c:1940
+msgid "different"
+msgstr "khác"
+
+#: wt-status.c:1942 wt-status.c:1950
+msgid "behind "
+msgstr "đằng sau "
+
+#: wt-status.c:1945 wt-status.c:1948
+msgid "ahead "
+msgstr "phía trước "
+
+#. TRANSLATORS: the action is e.g. "pull with rebase"
+#: wt-status.c:2470
+#, c-format
+msgid "cannot %s: You have unstaged changes."
+msgstr "không thể %s: Bạn có các thay đổi chưa được đưa lên bệ phóng."
+
+#: wt-status.c:2476
+msgid "additionally, your index contains uncommitted changes."
+msgstr ""
+"thêm vào đó, bảng mục lục của bạn có chứa các thay đổi chưa được chuyển giao."
+
+#: wt-status.c:2478
+#, c-format
+msgid "cannot %s: Your index contains uncommitted changes."
+msgstr ""
+"không thể %s: Mục lục của bạn có chứa các thay đổi chưa được chuyển giao."
+
+#: compat/precompose_utf8.c:58 builtin/clone.c:455
+#, c-format
+msgid "failed to unlink '%s'"
+msgstr "gặp lỗi khi bỏ liên kết (unlink) “%s”"
+
+#: builtin/add.c:26
+msgid "git add [<options>] [--] <pathspec>..."
+msgstr "git add [<các tùy chọn>] [--]  <pathspec>…"
+
+#: builtin/add.c:87
+#, c-format
+msgid "unexpected diff status %c"
+msgstr "trạng thái lệnh diff không như mong đợi %c"
+
+#: builtin/add.c:92 builtin/commit.c:288
+msgid "updating files failed"
+msgstr "cập nhật tập tin gặp lỗi"
+
+#: builtin/add.c:102
+#, c-format
+msgid "remove '%s'\n"
+msgstr "gỡ bỏ “%s”\n"
+
+#: builtin/add.c:177
+msgid "Unstaged changes after refreshing the index:"
+msgstr ""
+"Đưa ra khỏi bệ phóng các thay đổi sau khi làm tươi mới lại bảng mục lục:"
+
+#: builtin/add.c:252 builtin/rev-parse.c:899
+msgid "Could not read the index"
+msgstr "Không thể đọc bảng mục lục"
+
+#: builtin/add.c:263
+#, c-format
+msgid "Could not open '%s' for writing."
+msgstr "Không thể mở “%s” để ghi."
+
+#: builtin/add.c:267
+msgid "Could not write patch"
+msgstr "Không thể ghi ra miếng vá"
+
+#: builtin/add.c:270
+msgid "editing patch failed"
+msgstr "gặp lỗi khi sửa miếng vá"
+
+#: builtin/add.c:273
+#, c-format
+msgid "Could not stat '%s'"
+msgstr "Không thể lấy thông tin thống kê về “%s”"
+
+#: builtin/add.c:275
+msgid "Empty patch. Aborted."
+msgstr "Miếng vá trống rỗng. Nên bỏ qua."
+
+#: builtin/add.c:280
+#, c-format
+msgid "Could not apply '%s'"
+msgstr "Không thể áp dụng miếng vá “%s”"
+
+#: builtin/add.c:288
+msgid "The following paths are ignored by one of your .gitignore files:\n"
+msgstr ""
+"Các đường dẫn theo sau đây sẽ bị lờ đi bởi một trong các tập tin .gitignore "
+"của bạn:\n"
+
+#: builtin/add.c:308 builtin/clean.c:910 builtin/fetch.c:163 builtin/mv.c:124
+#: builtin/prune-packed.c:56 builtin/pull.c:223 builtin/push.c:548
+#: builtin/remote.c:1344 builtin/rm.c:241 builtin/send-pack.c:165
+msgid "dry run"
+msgstr "chạy thử"
+
+#: builtin/add.c:311
+msgid "interactive picking"
+msgstr "sửa bằng cách tương tác"
+
+#: builtin/add.c:312 builtin/checkout.c:1482 builtin/reset.c:307
+msgid "select hunks interactively"
+msgstr "chọn “hunks” theo kiểu tương tác"
+
+#: builtin/add.c:313
+msgid "edit current diff and apply"
+msgstr "sửa diff hiện nay và áp dụng nó"
+
+#: builtin/add.c:314
+msgid "allow adding otherwise ignored files"
+msgstr "cho phép thêm các tập tin bị bỏ qua khác"
+
+#: builtin/add.c:315
+msgid "update tracked files"
+msgstr "cập nhật các tập tin được theo dõi"
+
+#: builtin/add.c:316
+msgid "renormalize EOL of tracked files (implies -u)"
+msgstr "thường hóa lại EOL của các tập tin được theo dõi (ý là -u)"
+
+#: builtin/add.c:317
+msgid "record only the fact that the path will be added later"
+msgstr "chỉ ghi lại sự việc mà đường dẫn sẽ được thêm vào sau"
+
+#: builtin/add.c:318
+msgid "add changes from all tracked and untracked files"
+msgstr ""
+"thêm các thay đổi từ tất cả các tập tin có cũng như không được theo dõi dấu "
+"vết"
+
+#: builtin/add.c:321
+msgid "ignore paths removed in the working tree (same as --no-all)"
+msgstr ""
+"lờ đi các đường dẫn bị gỡ bỏ trong cây thư mục làm việc (giống với --no-all)"
+
+#: builtin/add.c:323
+msgid "don't add, only refresh the index"
+msgstr "không thêm, chỉ làm tươi mới bảng mục lục"
+
+#: builtin/add.c:324
+msgid "just skip files which cannot be added because of errors"
+msgstr "chie bỏ qua những tập tin mà nó không thể được thêm vào bởi vì gặp lỗi"
+
+#: builtin/add.c:325
+msgid "check if - even missing - files are ignored in dry run"
+msgstr ""
+"kiểm tra xem - thậm chí thiếu - tập tin bị bỏ qua trong quá trình chạy thử"
+
+#: builtin/add.c:327 builtin/update-index.c:1004
+msgid "override the executable bit of the listed files"
+msgstr "ghi đè lên bít thi hành của các tập tin được liệt kê"
+
+#: builtin/add.c:329
+msgid "warn when adding an embedded repository"
+msgstr "cảnh báo khi thêm một kho nhúng"
+
+#: builtin/add.c:347
+#, c-format
+msgid ""
+"You've added another git repository inside your current repository.\n"
+"Clones of the outer repository will not contain the contents of\n"
+"the embedded repository and will not know how to obtain it.\n"
+"If you meant to add a submodule, use:\n"
+"\n"
+"\tgit submodule add <url> %s\n"
+"\n"
+"If you added this path by mistake, you can remove it from the\n"
+"index with:\n"
+"\n"
+"\tgit rm --cached %s\n"
+"\n"
+"See \"git help submodule\" for more information."
+msgstr ""
+"Bạn vừa thêm một kho git vào bên trong kho hiện tại của bạn.\n"
+"Các bản sao của kho ngoài sẽ không chứa các nội dung của\n"
+"kho nhúng và sẽ không biết làm thế nào để lấy nó.\n"
+"Nếu ý bạn là thêm một mô-đun-con, hãy chạy:\n"
+"\n"
+"\tgit submodule add <url> %s\n"
+"\n"
+"Nếu bạn đã thêm miếng vá này chỉ là sai sót, bạn có thể xóa bỏ\n"
+"nó khỏi mục lục bằng:\n"
+"\n"
+"\tgit rm --cached %s\n"
+"\n"
+"Xem \"git help submodule\" để biết thêm chi tiết."
+
+#: builtin/add.c:375
+#, c-format
+msgid "adding embedded git repository: %s"
+msgstr "thêm cần một kho git nhúng: %s"
+
+#: builtin/add.c:393
+#, c-format
+msgid "Use -f if you really want to add them.\n"
+msgstr "Sử dụng tùy chọn -f nếu bạn thực sự muốn thêm chúng vào.\n"
+
+#: builtin/add.c:400
+msgid "adding files failed"
+msgstr "thêm tập tin gặp lỗi"
+
+#: builtin/add.c:428 builtin/commit.c:348
+#| msgid "--first-parent is incompatible with --bisect"
+msgid "--pathspec-from-file is incompatible with --interactive/--patch"
+msgstr "--pathspec-from-file xung khắc với --interactive/--patch"
+
+#: builtin/add.c:434
+#| msgid "--first-parent is incompatible with --bisect"
+msgid "--pathspec-from-file is incompatible with --edit"
+msgstr "--pathspec-from-file xung khắc với --edit"
+
+#: builtin/add.c:446
+msgid "-A and -u are mutually incompatible"
+msgstr "-A và -u xung khắc nhau"
+
+#: builtin/add.c:449
+msgid "Option --ignore-missing can only be used together with --dry-run"
+msgstr "Tùy chọn --ignore-missing chỉ có thể được dùng cùng với --dry-run"
+
+#: builtin/add.c:453
+#, c-format
+msgid "--chmod param '%s' must be either -x or +x"
+msgstr "--chmod tham số “%s” phải hoặc là -x hay +x"
+
+#: builtin/add.c:471 builtin/checkout.c:1648 builtin/commit.c:354
+#: builtin/reset.c:327
+#| msgid "--patch is incompatible with --{hard,mixed,soft}"
+msgid "--pathspec-from-file is incompatible with pathspec arguments"
+msgstr "--pathspec-from-file xung khắc với các tham số đặc tả đường dẫn"
+
+#: builtin/add.c:478 builtin/checkout.c:1660 builtin/commit.c:360
+#: builtin/reset.c:333
+msgid "--pathspec-file-nul requires --pathspec-from-file"
+msgstr "--pathspec-file-nul cần --pathspec-from-file"
+
+#: builtin/add.c:482
+#, c-format
+msgid "Nothing specified, nothing added.\n"
+msgstr "Không có gì được chỉ ra, không có gì được thêm vào.\n"
+
+#: builtin/add.c:483
+#, c-format
+msgid "Maybe you wanted to say 'git add .'?\n"
+msgstr "Có lẽ ý bạn là “git add .” phải không?\n"
+
+#: builtin/am.c:347
+msgid "could not parse author script"
+msgstr "không thể phân tích cú pháp văn lệnh tác giả"
+
+#: builtin/am.c:431
+#, c-format
+msgid "'%s' was deleted by the applypatch-msg hook"
+msgstr "“%s” bị xóa bởi móc applypatch-msg"
+
+#: builtin/am.c:473
+#, c-format
+msgid "Malformed input line: '%s'."
+msgstr "Dòng đầu vào dị hình: “%s”."
+
+#: builtin/am.c:511
+#, c-format
+msgid "Failed to copy notes from '%s' to '%s'"
+msgstr "Gặp lỗi khi sao chép ghi chú (note) từ “%s” tới “%s”"
+
+#: builtin/am.c:537
+msgid "fseek failed"
+msgstr "fseek gặp lỗi"
+
+#: builtin/am.c:725
+#, c-format
+msgid "could not parse patch '%s'"
+msgstr "không thể phân tích cú pháp “%s”"
+
+#: builtin/am.c:790
+msgid "Only one StGIT patch series can be applied at once"
+msgstr "Chỉ có một sê-ri miếng vá StGIT được áp dụng một lúc"
+
+#: builtin/am.c:838
+msgid "invalid timestamp"
+msgstr "dấu thời gian không hợp lệ"
+
+#: builtin/am.c:843 builtin/am.c:855
+msgid "invalid Date line"
+msgstr "dòng Ngày tháng không hợp lệ"
+
+#: builtin/am.c:850
+msgid "invalid timezone offset"
+msgstr "độ lệch múi giờ không hợp lệ"
+
+#: builtin/am.c:943
+msgid "Patch format detection failed."
+msgstr "Dò tìm định dạng miếng vá gặp lỗi."
+
+#: builtin/am.c:948 builtin/clone.c:409
+#, c-format
+msgid "failed to create directory '%s'"
+msgstr "tạo thư mục \"%s\" gặp lỗi"
+
+#: builtin/am.c:953
+msgid "Failed to split patches."
+msgstr "Gặp lỗi khi chia nhỏ các miếng vá."
+
+#: builtin/am.c:1084
+#, c-format
+msgid "When you have resolved this problem, run \"%s --continue\"."
+msgstr "Khi bạn đã phân giải xong trục trặc này, hãy chạy \"%s --continue\"."
+
+#: builtin/am.c:1085
+#, c-format
+msgid "If you prefer to skip this patch, run \"%s --skip\" instead."
+msgstr ""
+"Nếu bạn muốn bỏ qua miếng vá này, hãy chạy lệnh \"%s --skip\" để thay thế."
+
+#: builtin/am.c:1086
+#, c-format
+msgid "To restore the original branch and stop patching, run \"%s --abort\"."
+msgstr "Để phục hồi lại nhánh gốc và dừng vá, hãy chạy \"%s --abort\"."
+
+#: builtin/am.c:1169
+msgid "Patch sent with format=flowed; space at the end of lines might be lost."
+msgstr ""
+"Miếng vá được gửi với format=flowed; khoảng trống ở cuối của các dòng có thể "
+"bị mất."
+
+#: builtin/am.c:1197
+msgid "Patch is empty."
+msgstr "Miếng vá trống rỗng."
+
+#: builtin/am.c:1262
+#, c-format
+msgid "missing author line in commit %s"
+msgstr "thiếu dòng tác giả trong lần chuyển gia %s"
+
+#: builtin/am.c:1265
+#, c-format
+msgid "invalid ident line: %.*s"
+msgstr "dòng thụt lề không hợp lệ: %.*s"
+
+#: builtin/am.c:1484
+msgid "Repository lacks necessary blobs to fall back on 3-way merge."
+msgstr "Kho thiếu đối tượng blob cần thiết để trở về trên “3-way merge”."
+
+#: builtin/am.c:1486
+msgid "Using index info to reconstruct a base tree..."
+msgstr ""
+"Sử dụng thông tin trong bảng mục lục để cấu trúc lại một cây (tree) cơ sở…"
+
+#: builtin/am.c:1505
+msgid ""
+"Did you hand edit your patch?\n"
+"It does not apply to blobs recorded in its index."
+msgstr ""
+"Bạn đã sửa miếng vá của mình bằng cách thủ công à?\n"
+"Nó không thể áp dụng các blob đã được ghi lại trong bảng mục lục của nó."
+
+#: builtin/am.c:1511
+msgid "Falling back to patching base and 3-way merge..."
+msgstr "Đang trở lại để vá cơ sở và “hòa trộn 3-đường”…"
+
+#: builtin/am.c:1537
+msgid "Failed to merge in the changes."
+msgstr "Gặp lỗi khi trộn vào các thay đổi."
+
+#: builtin/am.c:1569
+msgid "applying to an empty history"
+msgstr "áp dụng vào một lịch sử trống rỗng"
+
+#: builtin/am.c:1616 builtin/am.c:1620
+#, c-format
+msgid "cannot resume: %s does not exist."
+msgstr "không thể phục hồi: %s không tồn tại."
+
+#: builtin/am.c:1638
+msgid "Commit Body is:"
+msgstr "Thân của lần chuyển giao là:"
+
+#. TRANSLATORS: Make sure to include [y], [n], [e], [v] and [a]
+#. in your translation. The program will only accept English
+#. input at this point.
+#.
+#: builtin/am.c:1648
+#, c-format
+msgid "Apply? [y]es/[n]o/[e]dit/[v]iew patch/[a]ccept all: "
+msgstr ""
+"Áp dụng? đồng ý [y]/khô[n]g/chỉnh sửa [e]/hiển thị miếng [v]á/chấp nhận tất "
+"cả [a]: "
+
+#: builtin/am.c:1695 builtin/commit.c:394
+msgid "unable to write index file"
+msgstr "không thể ghi tập tin lưu mục lục"
+
+#: builtin/am.c:1699
+#, c-format
+msgid "Dirty index: cannot apply patches (dirty: %s)"
+msgstr "Bảng mục lục bẩn: không thể áp dụng các miếng vá (bẩn: %s)"
+
+#: builtin/am.c:1739 builtin/am.c:1807
+#, c-format
+msgid "Applying: %.*s"
+msgstr "Áp dụng: %.*s"
+
+#: builtin/am.c:1756
+msgid "No changes -- Patch already applied."
+msgstr "Không thay đổi gì cả -- Miếng vá đã được áp dụng rồi."
+
+#: builtin/am.c:1762
+#, c-format
+msgid "Patch failed at %s %.*s"
+msgstr "Gặp lỗi khi vá tại %s %.*s"
+
+#: builtin/am.c:1766
+msgid "Use 'git am --show-current-patch' to see the failed patch"
+msgstr "Dùng “git am --show-current-patch” để xem miếng vá bị lỗi"
+
+#: builtin/am.c:1810
+msgid ""
+"No changes - did you forget to use 'git add'?\n"
+"If there is nothing left to stage, chances are that something else\n"
+"already introduced the same changes; you might want to skip this patch."
+msgstr ""
+"Không có thay đổi nào - bạn đã quên sử dụng lệnh “git add” à?\n"
+"Nếu ở đây không có gì còn lại stage, tình cờ là có một số thứ khác\n"
+"đã sẵn được đưa vào với cùng nội dung thay đổi; bạn có lẽ muốn bỏ qua miếng "
+"vá này."
+
+#: builtin/am.c:1817
+msgid ""
+"You still have unmerged paths in your index.\n"
+"You should 'git add' each file with resolved conflicts to mark them as "
+"such.\n"
+"You might run `git rm` on a file to accept \"deleted by them\" for it."
+msgstr ""
+"Bạn vẫn có những đường dẫn chưa hòa trộn trong chỉ mục của bạn.\n"
+"Bạn nên “git add” từng tập tin với các xung đột đã được giải quyết để đánh "
+"dấu chúng là thế.\n"
+"Bạn có lẽ muốn chạy “git rm“ trên một tập tin để chấp nhận \"được xóa bởi họ"
+"\" cho nó."
+
+#: builtin/am.c:1924 builtin/am.c:1928 builtin/am.c:1940 builtin/reset.c:346
+#: builtin/reset.c:354
+#, c-format
+msgid "Could not parse object '%s'."
+msgstr "Không thể phân tích đối tượng “%s”."
+
+#: builtin/am.c:1976
+msgid "failed to clean index"
+msgstr "gặp lỗi khi dọn bảng mục lục"
+
+#: builtin/am.c:2020
+msgid ""
+"You seem to have moved HEAD since the last 'am' failure.\n"
+"Not rewinding to ORIG_HEAD"
+msgstr ""
+"Bạn có lẽ đã có HEAD đã bị di chuyển đi kể từ lần “am” thất bại cuối cùng.\n"
+"Không thể chuyển tới ORIG_HEAD"
+
+#: builtin/am.c:2117
+#, c-format
+msgid "Invalid value for --patch-format: %s"
+msgstr "Giá trị không hợp lệ cho --patch-format: %s"
+
+#: builtin/am.c:2153
+msgid "git am [<options>] [(<mbox> | <Maildir>)...]"
+msgstr "git am [<các tùy chọn>] [(<mbox>|<Maildir>)…]"
+
+#: builtin/am.c:2154
+msgid "git am [<options>] (--continue | --skip | --abort)"
+msgstr "git am [<các tùy chọn>] (--continue | --skip | --abort)"
+
+#: builtin/am.c:2160
+msgid "run interactively"
+msgstr "chạy kiểu tương tác"
+
+#: builtin/am.c:2162
+msgid "historical option -- no-op"
+msgstr "tùy chọn lịch sử -- không-toán-tử"
+
+#: builtin/am.c:2164
+msgid "allow fall back on 3way merging if needed"
+msgstr "cho phép quay trở lại để hòa trộn kiểu “3way” nếu cần"
+
+#: builtin/am.c:2165 builtin/init-db.c:494 builtin/prune-packed.c:58
+#: builtin/repack.c:304 builtin/stash.c:811
+msgid "be quiet"
+msgstr "im lặng"
+
+#: builtin/am.c:2167
+msgid "add a Signed-off-by line to the commit message"
+msgstr "thêm dòng Signed-off-by cho ghi chú của lần chuyển giao"
+
+#: builtin/am.c:2170
+msgid "recode into utf8 (default)"
+msgstr "chuyển mã thành utf8 (mặc định)"
+
+#: builtin/am.c:2172
+msgid "pass -k flag to git-mailinfo"
+msgstr "chuyển cờ -k cho git-mailinfo"
+
+#: builtin/am.c:2174
+msgid "pass -b flag to git-mailinfo"
+msgstr "chuyển cờ -b cho git-mailinfo"
+
+#: builtin/am.c:2176
+msgid "pass -m flag to git-mailinfo"
+msgstr "chuyển cờ -m cho git-mailinfo"
+
+#: builtin/am.c:2178
+msgid "pass --keep-cr flag to git-mailsplit for mbox format"
+msgstr "chuyển cờ --keep-cr cho git-mailsplit với định dạng mbox"
+
+#: builtin/am.c:2181
+msgid "do not pass --keep-cr flag to git-mailsplit independent of am.keepcr"
+msgstr ""
+"đừng chuyển cờ --keep-cr cho git-mailsplit không phụ thuộc vào am.keepcr"
+
+#: builtin/am.c:2184
+msgid "strip everything before a scissors line"
+msgstr "cắt mọi thứ trước dòng scissors"
+
+#: builtin/am.c:2186 builtin/am.c:2189 builtin/am.c:2192 builtin/am.c:2195
+#: builtin/am.c:2198 builtin/am.c:2201 builtin/am.c:2204 builtin/am.c:2207
+#: builtin/am.c:2213
+msgid "pass it through git-apply"
+msgstr "chuyển nó qua git-apply"
+
+#: builtin/am.c:2203 builtin/commit.c:1386 builtin/fmt-merge-msg.c:673
+#: builtin/fmt-merge-msg.c:676 builtin/grep.c:883 builtin/merge.c:249
+#: builtin/pull.c:160 builtin/pull.c:219 builtin/rebase.c:1469
+#: builtin/repack.c:315 builtin/repack.c:319 builtin/repack.c:321
+#: builtin/show-branch.c:650 builtin/show-ref.c:172 builtin/tag.c:403
+#: parse-options.h:154 parse-options.h:175 parse-options.h:316
+msgid "n"
+msgstr "n"
+
+#: builtin/am.c:2209 builtin/branch.c:661 builtin/for-each-ref.c:38
+#: builtin/replace.c:555 builtin/tag.c:437 builtin/verify-tag.c:38
+msgid "format"
+msgstr "định dạng"
+
+#: builtin/am.c:2210
+msgid "format the patch(es) are in"
+msgstr "định dạng (các) miếng vá theo"
+
+#: builtin/am.c:2216
+msgid "override error message when patch failure occurs"
+msgstr "đè lên các lời nhắn lỗi khi xảy ra lỗi vá nghiêm trọng"
+
+#: builtin/am.c:2218
+msgid "continue applying patches after resolving a conflict"
+msgstr "tiếp tục áp dụng các miếng vá sau khi giải quyết xung đột"
+
+#: builtin/am.c:2221
+msgid "synonyms for --continue"
+msgstr "đồng nghĩa với --continue"
+
+#: builtin/am.c:2224
+msgid "skip the current patch"
+msgstr "bỏ qua miếng vá hiện hành"
+
+#: builtin/am.c:2227
+msgid "restore the original branch and abort the patching operation."
+msgstr "phục hồi lại nhánh gốc và loại bỏ thao tác vá."
+
+#: builtin/am.c:2230
+msgid "abort the patching operation but keep HEAD where it is."
+msgstr "bỏ qua thao tác vá nhưng vẫn giữ HEAD chỉ đến nó."
+
+#: builtin/am.c:2233
+msgid "show the patch being applied."
+msgstr "hiển thị miếng vá đã được áp dụng rồi."
+
+#: builtin/am.c:2237
+msgid "lie about committer date"
+msgstr "nói dối về ngày chuyển giao"
+
+#: builtin/am.c:2239
+msgid "use current timestamp for author date"
+msgstr "dùng dấu thời gian hiện tại cho ngày tác giả"
+
+#: builtin/am.c:2241 builtin/commit-tree.c:120 builtin/commit.c:1507
+#: builtin/merge.c:286 builtin/pull.c:194 builtin/rebase.c:509
+#: builtin/rebase.c:1513 builtin/revert.c:117 builtin/tag.c:418
+msgid "key-id"
+msgstr "mã-số-khóa"
+
+#: builtin/am.c:2242 builtin/rebase.c:510 builtin/rebase.c:1514
+msgid "GPG-sign commits"
+msgstr "Các lần chuyển giao ký-GPG"
+
+#: builtin/am.c:2245
+msgid "(internal use for git-rebase)"
+msgstr "(dùng nội bộ cho git-rebase)"
+
+#: builtin/am.c:2263
+msgid ""
+"The -b/--binary option has been a no-op for long time, and\n"
+"it will be removed. Please do not use it anymore."
+msgstr ""
+"Tùy chọn -b/--binary đã không dùng từ lâu rồi, và\n"
+"nó sẽ được bỏ đi. Xin đừng sử dụng nó thêm nữa."
+
+#: builtin/am.c:2270
+msgid "failed to read the index"
+msgstr "gặp lỗi đọc bảng mục lục"
+
+#: builtin/am.c:2285
+#, c-format
+msgid "previous rebase directory %s still exists but mbox given."
+msgstr "thư mục rebase trước %s không sẵn có nhưng mbox lại đưa ra."
+
+#: builtin/am.c:2309
+#, c-format
+msgid ""
+"Stray %s directory found.\n"
+"Use \"git am --abort\" to remove it."
+msgstr ""
+"Tìm thấy thư mục lạc %s.\n"
+"Dùng \"git am --abort\" để loại bỏ nó đi."
+
+#: builtin/am.c:2315
+msgid "Resolve operation not in progress, we are not resuming."
+msgstr "Thao tác phân giải không được tiến hành, chúng ta không phục hồi lại."
+
+#: builtin/am.c:2325
+msgid "interactive mode requires patches on the command line"
+msgstr "chế độ tương tác yêu cầu có các miếng vá trên dòng lênh"
+
+#: builtin/apply.c:8
+msgid "git apply [<options>] [<patch>...]"
+msgstr "git apply [<các tùy chọn>] [<miếng-vá>…]"
+
+#: builtin/archive.c:17
+#, c-format
+msgid "could not create archive file '%s'"
+msgstr "không thể tạo tập tin kho (lưu trữ, nén) “%s”"
+
+#: builtin/archive.c:20
+msgid "could not redirect output"
+msgstr "không thể chuyển hướng kết xuất"
+
+#: builtin/archive.c:37
+msgid "git archive: Remote with no URL"
+msgstr "git archive: Máy chủ không có địa chỉ URL"
+
+#: builtin/archive.c:61
+msgid "git archive: expected ACK/NAK, got a flush packet"
+msgstr "git archive: cần ACK/NAK, nhưng lại nhận được gói flush"
+
+#: builtin/archive.c:64
+#, c-format
+msgid "git archive: NACK %s"
+msgstr "git archive: NACK %s"
+
+#: builtin/archive.c:65
+msgid "git archive: protocol error"
+msgstr "git archive: lỗi giao thức"
+
+#: builtin/archive.c:69
+msgid "git archive: expected a flush"
+msgstr "git archive: cần một flush (đẩy dữ liệu lên đĩa)"
+
+#: builtin/bisect--helper.c:22
+msgid "git bisect--helper --next-all [--no-checkout]"
+msgstr "git bisect--helper --next-all [--no-checkout]"
+
+#: builtin/bisect--helper.c:23
+msgid "git bisect--helper --write-terms <bad_term> <good_term>"
+msgstr "git bisect--helper --write-terms <bad_term> <good_term>"
+
+#: builtin/bisect--helper.c:24
+msgid "git bisect--helper --bisect-clean-state"
+msgstr "git bisect--helper --bisect-clean-state"
+
+#: builtin/bisect--helper.c:25
+msgid "git bisect--helper --bisect-reset [<commit>]"
+msgstr "git bisect--helper --bisect-reset [<lần_chuyển_giao>]"
+
+#: builtin/bisect--helper.c:26
+msgid ""
+"git bisect--helper --bisect-write [--no-log] <state> <revision> <good_term> "
+"<bad_term>"
+msgstr ""
+"git bisect--helper --bisect-write [--no-log] <state> <revision> <lúc_sai> "
+"<lúc_đúng>"
+
+#: builtin/bisect--helper.c:27
+msgid ""
+"git bisect--helper --bisect-check-and-set-terms <command> <good_term> "
+"<bad_term>"
+msgstr ""
+"git bisect--helper --bisect-check-and-set-terms <command> <lúc_sai> "
+"<lúc_đúng>"
+
+#: builtin/bisect--helper.c:28
+msgid "git bisect--helper --bisect-next-check <good_term> <bad_term> [<term>]"
+msgstr "git bisect--helper --bisect-next-check <lúc_sai> <lúc_đúng> [<term>]"
+
+#: builtin/bisect--helper.c:29
+msgid ""
+"git bisect--helper --bisect-terms [--term-good | --term-old | --term-bad | --"
+"term-new]"
+msgstr ""
+"git bisect--helper --bisect-terms [--term-good | --term-old | --term-bad | --"
+"term-new]"
+
+#: builtin/bisect--helper.c:30
+msgid ""
+"git bisect--helper --bisect-start [--term-{old,good}=<term> --term-{new,bad}"
+"=<term>][--no-checkout] [<bad> [<good>...]] [--] [<paths>...]"
+msgstr ""
+"git bisect--helper --bisect-start [--term-{old,good}=<term> --term-{new,bad}"
+"=<term>][--no-checkout] [<sai> [<đúng>…]] [--] [</các/đường/dẫn>…]"
+
+#: builtin/bisect--helper.c:86
+#, c-format
+msgid "'%s' is not a valid term"
+msgstr "“%s” không phải một thời hạn hợp lệ"
+
+#: builtin/bisect--helper.c:90
+#, c-format
+msgid "can't use the builtin command '%s' as a term"
+msgstr "không thể dùng lệnh tích hợp “%s” như là một thời kỳ"
+
+#: builtin/bisect--helper.c:100
+#, c-format
+msgid "can't change the meaning of the term '%s'"
+msgstr "không thể thay đổi nghĩa của thời kỳ “%s”"
+
+#: builtin/bisect--helper.c:111
+msgid "please use two different terms"
+msgstr "vui lòng dùng hai thời kỳ khác nhau"
+
+#: builtin/bisect--helper.c:118
+msgid "could not open the file BISECT_TERMS"
+msgstr "không thể mở tập tin BISECT_TERMS"
+
+#: builtin/bisect--helper.c:155
+#, c-format
+msgid "We are not bisecting.\n"
+msgstr "Chúng tôi đang không bisect.\n"
+
+#: builtin/bisect--helper.c:163
+#, c-format
+msgid "'%s' is not a valid commit"
+msgstr "“%s” không phải một lần chuyển giao hợp lệ"
+
+#: builtin/bisect--helper.c:172
+#, c-format
+msgid ""
+"could not check out original HEAD '%s'. Try 'git bisect reset <commit>'."
+msgstr ""
+"không thể lấy ra HEAD nguyên thủy của “%s”. Hãy thử “git bisect reset <lần-"
+"chuyển-giao>”."
+
+#: builtin/bisect--helper.c:216
+#, c-format
+msgid "Bad bisect_write argument: %s"
+msgstr "Đối số bisect_write sai: %s"
+
+#: builtin/bisect--helper.c:221
+#, c-format
+msgid "couldn't get the oid of the rev '%s'"
+msgstr "không thể lấy oid của điểm xét duyệt “%s”"
+
+#: builtin/bisect--helper.c:233
+#, c-format
+msgid "couldn't open the file '%s'"
+msgstr "không thể mở tập tin “%s”"
+
+#: builtin/bisect--helper.c:259
+#, c-format
+msgid "Invalid command: you're currently in a %s/%s bisect"
+msgstr "Lệnh không hợp lệ: bạn hiện đang ở một bisect %s/%s"
+
+#: builtin/bisect--helper.c:286
+#, c-format
+msgid ""
+"You need to give me at least one %s and %s revision.\n"
+"You can use \"git bisect %s\" and \"git bisect %s\" for that."
+msgstr ""
+"Bạn phải chỉ cho tôi ít nhất một điểm %s và một %s.\n"
+"Bạn có thể sử dụng \"git bisect %s\" và \"git bisect %s\" cho cái đó."
+
+#: builtin/bisect--helper.c:290
+#, c-format
+msgid ""
+"You need to start by \"git bisect start\".\n"
+"You then need to give me at least one %s and %s revision.\n"
+"You can use \"git bisect %s\" and \"git bisect %s\" for that."
+msgstr ""
+"Bạn cần bắt đầu bằng lệnh \"git bisect start\".\n"
+"Bạn sau đó cần phải chỉ cho tôi ít nhất một điểm xét duyệt %s và một %s.\n"
+"Bạn có thể sử dụng \"git bisect %s\" và \"git bisect %s\" cho chúng."
+
+#: builtin/bisect--helper.c:322
+#, c-format
+msgid "bisecting only with a %s commit"
+msgstr "chỉ thực hiện việc bisect với một lần chuyển giao %s"
+
+#. TRANSLATORS: Make sure to include [Y] and [n] in your
+#. translation. The program will only accept English input
+#. at this point.
+#.
+#: builtin/bisect--helper.c:330
+msgid "Are you sure [Y/n]? "
+msgstr "Bạn có chắc chắn chưa [Y/n]? "
+
+#: builtin/bisect--helper.c:377
+msgid "no terms defined"
+msgstr "chưa định nghĩa thời kỳ nào"
+
+#: builtin/bisect--helper.c:380
+#, c-format
+msgid ""
+"Your current terms are %s for the old state\n"
+"and %s for the new state.\n"
+msgstr ""
+"Bạn hiện tại đang ở thời kỳ %s cho tình trạng cũ\n"
+"và %s cho tình trạng mới.\n"
+
+#: builtin/bisect--helper.c:390
+#, c-format
+msgid ""
+"invalid argument %s for 'git bisect terms'.\n"
+"Supported options are: --term-good|--term-old and --term-bad|--term-new."
+msgstr ""
+"tham số không hợp lệ %s cho “git bisect terms”.\n"
+"Các tùy chọn hỗ trợ là: --term-good|--term-old và --term-bad|--term-new."
+
+#: builtin/bisect--helper.c:476
+#, c-format
+msgid "unrecognized option: '%s'"
+msgstr "tùy chọn không được thừa nhận: “%s”"
+
+#: builtin/bisect--helper.c:480
+#, c-format
+msgid "'%s' does not appear to be a valid revision"
+msgstr "“%s” không có vẻ như là một điểm xét duyệt hợp lệ"
+
+#: builtin/bisect--helper.c:512
+msgid "bad HEAD - I need a HEAD"
+msgstr "sai HEAD - Tôi cần một HEAD"
+
+#: builtin/bisect--helper.c:527
+#, c-format
+msgid "checking out '%s' failed. Try 'git bisect start <valid-branch>'."
+msgstr "lấy ra “%s” ra gặp lỗi. Hãy thử \"git bisect reset <nhánh_hợp_lệ>\"."
+
+#: builtin/bisect--helper.c:548
+msgid "won't bisect on cg-seek'ed tree"
+msgstr "sẽ không di chuyển nửa bước trên cây được cg-seek"
+
+#: builtin/bisect--helper.c:551
+msgid "bad HEAD - strange symbolic ref"
+msgstr "sai HEAD - tham chiếu mềm kỳ lạ"
+
+#: builtin/bisect--helper.c:575
+#, c-format
+msgid "invalid ref: '%s'"
+msgstr "refspec không hợp lệ: “%s”"
+
+#: builtin/bisect--helper.c:631
+msgid "perform 'git bisect next'"
+msgstr "thực hiện “git bisect next”"
+
+#: builtin/bisect--helper.c:633
+msgid "write the terms to .git/BISECT_TERMS"
+msgstr "ghi thời kỳ vào .git/BISECT_TERMS"
+
+#: builtin/bisect--helper.c:635
+msgid "cleanup the bisection state"
+msgstr "dọn dẹp tình trạng di chuyển nửa bước"
+
+#: builtin/bisect--helper.c:637
+msgid "check for expected revs"
+msgstr "kiểm tra cho điểm xem xét cần dùng"
+
+#: builtin/bisect--helper.c:639
+msgid "reset the bisection state"
+msgstr "đặt lại trạng di chuyển nửa bước"
+
+#: builtin/bisect--helper.c:641
+msgid "write out the bisection state in BISECT_LOG"
+msgstr "ghi ra tình trạng di chuyển nửa bước trong BISECT_LOG"
+
+#: builtin/bisect--helper.c:643
+msgid "check and set terms in a bisection state"
+msgstr "kiểm tra và đặt thời điểm trong di chuyển nửa bước"
+
+#: builtin/bisect--helper.c:645
+msgid "check whether bad or good terms exist"
+msgstr "kiểm tra xem các thời điểm xấu/tốt có tồn tại không"
+
+#: builtin/bisect--helper.c:647
+msgid "print out the bisect terms"
+msgstr "in ra các thời điểm di chuyển nửa bước"
+
+#: builtin/bisect--helper.c:649
+msgid "start the bisect session"
+msgstr "bắt đầu phiên di chuyển nửa bước"
+
+#: builtin/bisect--helper.c:651
+msgid "update BISECT_HEAD instead of checking out the current commit"
+msgstr ""
+"cập nhật BISECT_HEAD thay vì lấy ra (checking out) lần chuyển giao hiện hành"
+
+#: builtin/bisect--helper.c:653
+msgid "no log for BISECT_WRITE"
+msgstr "không có nhật ký cho BISECT_WRITE"
+
+#: builtin/bisect--helper.c:670
+msgid "--write-terms requires two arguments"
+msgstr "--write-terms cần hai tham số"
+
+#: builtin/bisect--helper.c:674
+msgid "--bisect-clean-state requires no arguments"
+msgstr "--bisect-clean-state không nhận đối số"
+
+#: builtin/bisect--helper.c:681
+msgid "--bisect-reset requires either no argument or a commit"
+msgstr ""
+"--bisect-reset requires không nhận đối số cũng không nhận lần chuyển giao"
+
+#: builtin/bisect--helper.c:685
+msgid "--bisect-write requires either 4 or 5 arguments"
+msgstr "--bisect-write cần 4 hoặc 5 tham số"
+
+#: builtin/bisect--helper.c:691
+msgid "--check-and-set-terms requires 3 arguments"
+msgstr "--check-and-set-terms cần 3 tham số"
+
+#: builtin/bisect--helper.c:697
+msgid "--bisect-next-check requires 2 or 3 arguments"
+msgstr "--bisect-next-check cần 2 hoặc 3 tham số"
+
+#: builtin/bisect--helper.c:703
+msgid "--bisect-terms requires 0 or 1 argument"
+msgstr "--bisect-terms cần 0 hoặc 1 tham số"
+
+#: builtin/blame.c:31
+msgid "git blame [<options>] [<rev-opts>] [<rev>] [--] <file>"
+msgstr "git blame [<các tùy chọn>] [<rev-opts>] [<rev>] [--] <tập-tin>"
+
+#: builtin/blame.c:36
+msgid "<rev-opts> are documented in git-rev-list(1)"
+msgstr "<rev-opts> được mô tả trong tài liệu git-rev-list(1)"
+
+#: builtin/blame.c:409
+#, c-format
+msgid "expecting a color: %s"
+msgstr "cần một màu: %s"
+
+#: builtin/blame.c:416
+msgid "must end with a color"
+msgstr "phải kết thúc bằng một màu"
+
+#: builtin/blame.c:729
+#, c-format
+msgid "invalid color '%s' in color.blame.repeatedLines"
+msgstr "màu không hợp lệ “%s” trong color.blame.repeatedLines"
+
+#: builtin/blame.c:747
+msgid "invalid value for blame.coloring"
+msgstr "màu không hợp lệ cho blame.coloring"
+
+#: builtin/blame.c:822
+#, c-format
+msgid "cannot find revision %s to ignore"
+msgstr "không thể tìm thấy điểm xét duyệt %s để mà bỏ qua"
+
+#: builtin/blame.c:844
+msgid "Show blame entries as we find them, incrementally"
+msgstr "Hiển thị các mục “blame” như là chúng ta thấy chúng, tăng dần"
+
+#: builtin/blame.c:845
+msgid "Show blank SHA-1 for boundary commits (Default: off)"
+msgstr ""
+"Hiển thị SHA-1 trắng cho những lần chuyển giao biên giới (Mặc định: off)"
+
+#: builtin/blame.c:846
+msgid "Do not treat root commits as boundaries (Default: off)"
+msgstr "Không coi các lần chuyển giao gốc là giới hạn (Mặc định: off)"
+
+#: builtin/blame.c:847
+msgid "Show work cost statistics"
+msgstr "Hiển thị thống kê công sức làm việc"
+
+#: builtin/blame.c:848
+msgid "Force progress reporting"
+msgstr "Ép buộc báo cáo tiến triển công việc"
+
+#: builtin/blame.c:849
+msgid "Show output score for blame entries"
+msgstr "Hiển thị kết xuất điểm số có các mục tin “blame”"
+
+#: builtin/blame.c:850
+msgid "Show original filename (Default: auto)"
+msgstr "Hiển thị tên tập tin gốc (Mặc định: auto)"
+
+#: builtin/blame.c:851
+msgid "Show original linenumber (Default: off)"
+msgstr "Hiển thị số dòng gốc (Mặc định: off)"
+
+#: builtin/blame.c:852
+msgid "Show in a format designed for machine consumption"
+msgstr "Hiển thị ở định dạng đã thiết kế cho sự tiêu dùng bằng máy"
+
+#: builtin/blame.c:853
+msgid "Show porcelain format with per-line commit information"
+msgstr "Hiển thị định dạng “porcelain” với thông tin chuyển giao mỗi dòng"
+
+#: builtin/blame.c:854
+msgid "Use the same output mode as git-annotate (Default: off)"
+msgstr "Dùng cùng chế độ xuất ra với git-annotate (Mặc định: off)"
+
+#: builtin/blame.c:855
+msgid "Show raw timestamp (Default: off)"
+msgstr "Hiển thị dấu vết thời gian dạng thô (Mặc định: off)"
+
+#: builtin/blame.c:856
+msgid "Show long commit SHA1 (Default: off)"
+msgstr "Hiển thị SHA1 của lần chuyển giao dạng dài (Mặc định: off)"
+
+#: builtin/blame.c:857
+msgid "Suppress author name and timestamp (Default: off)"
+msgstr "Không hiển thị tên tác giả và dấu vết thời gian (Mặc định: off)"
+
+#: builtin/blame.c:858
+msgid "Show author email instead of name (Default: off)"
+msgstr "Hiển thị thư điện tử của tác giả thay vì tên (Mặc định: off)"
+
+#: builtin/blame.c:859
+msgid "Ignore whitespace differences"
+msgstr "Bỏ qua các khác biệt do khoảng trắng gây ra"
+
+#: builtin/blame.c:860 builtin/log.c:1702
+msgid "rev"
+msgstr "rev"
+
+#: builtin/blame.c:860
+msgid "Ignore <rev> when blaming"
+msgstr "Bỏ qua <rev> khi blame"
+
+#: builtin/blame.c:861
+msgid "Ignore revisions from <file>"
+msgstr "Bỏ qua các điểm xét duyệt từ <tập tin>"
+
+#: builtin/blame.c:862
+msgid "color redundant metadata from previous line differently"
+msgstr "siêu dữ liệu dư thừa màu từ dòng trước khác hẳn"
+
+#: builtin/blame.c:863
+msgid "color lines by age"
+msgstr "các dòng màu theo tuổi"
+
+#: builtin/blame.c:864
+msgid "Spend extra cycles to find better match"
+msgstr "Tiêu thụ thêm năng tài nguyên máy móc để tìm kiếm tốt hơn nữa"
+
+#: builtin/blame.c:865
+msgid "Use revisions from <file> instead of calling git-rev-list"
+msgstr ""
+"Sử dụng điểm xét duyệt (revision) từ <tập tin> thay vì gọi “git-rev-list”"
+
+#: builtin/blame.c:866
+msgid "Use <file>'s contents as the final image"
+msgstr "Sử dụng nội dung của <tập tin> như là ảnh cuối cùng"
+
+#: builtin/blame.c:867 builtin/blame.c:868
+msgid "score"
+msgstr "điểm số"
+
+#: builtin/blame.c:867
+msgid "Find line copies within and across files"
+msgstr "Tìm các bản sao chép dòng trong và ngang qua tập tin"
+
+#: builtin/blame.c:868
+msgid "Find line movements within and across files"
+msgstr "Tìm các di chuyển dòng trong và ngang qua tập tin"
+
+#: builtin/blame.c:869
+msgid "n,m"
+msgstr "n,m"
+
+#: builtin/blame.c:869
+msgid "Process only line range n,m, counting from 1"
+msgstr "Xử lý chỉ dòng vùng n,m, tính từ 1"
+
+#: builtin/blame.c:921
+msgid "--progress can't be used with --incremental or porcelain formats"
+msgstr ""
+"--progress không được dùng cùng với --incremental hay các định dạng porcelain"
+
+#. TRANSLATORS: This string is used to tell us the
+#. maximum display width for a relative timestamp in
+#. "git blame" output.  For C locale, "4 years, 11
+#. months ago", which takes 22 places, is the longest
+#. among various forms of relative timestamps, but
+#. your language may need more or fewer display
+#. columns.
+#.
+#: builtin/blame.c:972
+msgid "4 years, 11 months ago"
+msgstr "4 năm, 11 tháng trước"
+
+#: builtin/blame.c:1079
+#, c-format
+msgid "file %s has only %lu line"
+msgid_plural "file %s has only %lu lines"
+msgstr[0] "tập tin %s chỉ có %lu dòng"
+
+#: builtin/blame.c:1125
+msgid "Blaming lines"
+msgstr "Các dòng blame"
+
+#: builtin/branch.c:29
+msgid "git branch [<options>] [-r | -a] [--merged | --no-merged]"
+msgstr "git branch [<các tùy chọn>] [-r | -a] [--merged | --no-merged]"
+
+#: builtin/branch.c:30
+msgid "git branch [<options>] [-l] [-f] <branch-name> [<start-point>]"
+msgstr "git branch [<các tùy chọn>] [-l] [-f] <tên-nhánh> [<điểm-đầu>]"
+
+#: builtin/branch.c:31
+msgid "git branch [<options>] [-r] (-d | -D) <branch-name>..."
+msgstr "git branch [<các tùy chọn>] [-r] (-d | -D) <tên-nhánh> …"
+
+#: builtin/branch.c:32
+msgid "git branch [<options>] (-m | -M) [<old-branch>] <new-branch>"
+msgstr "git branch [<các tùy chọn>] (-m | -M) [<nhánh-cũ>] <nhánh-mới>"
+
+#: builtin/branch.c:33
+msgid "git branch [<options>] (-c | -C) [<old-branch>] <new-branch>"
+msgstr "git branch [<các tùy chọn>] (-c | -C) [<nhánh-cũ>] <nhánh-mới>"
+
+#: builtin/branch.c:34
+msgid "git branch [<options>] [-r | -a] [--points-at]"
+msgstr "git branch [<các tùy chọn>] [-r | -a] [--points-at]"
+
+#: builtin/branch.c:35
+msgid "git branch [<options>] [-r | -a] [--format]"
+msgstr "git branch [<các tùy chọn>] [-r | -a] [--format]"
+
+#: builtin/branch.c:154
+#, c-format
+msgid ""
+"deleting branch '%s' that has been merged to\n"
+"         '%s', but not yet merged to HEAD."
+msgstr ""
+"đang xóa nhánh “%s” mà nó lại đã được hòa trộn vào\n"
+"         “%s”, nhưng vẫn chưa được hòa trộn vào HEAD."
+
+#: builtin/branch.c:158
+#, c-format
+msgid ""
+"not deleting branch '%s' that is not yet merged to\n"
+"         '%s', even though it is merged to HEAD."
+msgstr ""
+"không xóa nhánh “%s” cái mà chưa được hòa trộn vào\n"
+"         “%s”, cho dù là nó đã được hòa trộn vào HEAD."
+
+#: builtin/branch.c:172
+#, c-format
+msgid "Couldn't look up commit object for '%s'"
+msgstr "Không thể tìm kiếm đối tượng chuyển giao cho “%s”"
+
+#: builtin/branch.c:176
+#, c-format
+msgid ""
+"The branch '%s' is not fully merged.\n"
+"If you are sure you want to delete it, run 'git branch -D %s'."
+msgstr ""
+"Nhánh “%s” không được trộn một cách đầy đủ.\n"
+"Nếu bạn thực sự muốn xóa nó, thì chạy lệnh “git branch -D %s”."
+
+#: builtin/branch.c:189
+msgid "Update of config-file failed"
+msgstr "Cập nhật tập tin cấu hình gặp lỗi"
+
+#: builtin/branch.c:220
+msgid "cannot use -a with -d"
+msgstr "không thể dùng tùy chọn -a với -d"
+
+#: builtin/branch.c:226
+msgid "Couldn't look up commit object for HEAD"
+msgstr "Không thể tìm kiếm đối tượng chuyển giao cho HEAD"
+
+#: builtin/branch.c:240
+#, c-format
+msgid "Cannot delete branch '%s' checked out at '%s'"
+msgstr "Không thể xóa nhánh “%s” đã được lấy ra tại “%s”"
+
+#: builtin/branch.c:255
+#, c-format
+msgid "remote-tracking branch '%s' not found."
+msgstr "không tìm thấy nhánh theo dõi máy chủ “%s”."
+
+#: builtin/branch.c:256
+#, c-format
+msgid "branch '%s' not found."
+msgstr "không tìm thấy nhánh “%s”."
+
+#: builtin/branch.c:271
+#, c-format
+msgid "Error deleting remote-tracking branch '%s'"
+msgstr "Gặp lỗi khi đang xóa nhánh theo dõi máy chủ “%s”"
+
+#: builtin/branch.c:272
+#, c-format
+msgid "Error deleting branch '%s'"
+msgstr "Gặp lỗi khi xóa bỏ nhánh “%s”"
+
+#: builtin/branch.c:279
+#, c-format
+msgid "Deleted remote-tracking branch %s (was %s).\n"
+msgstr "Đã xóa nhánh theo dõi máy chủ \"%s\" (từng là %s).\n"
+
+#: builtin/branch.c:280
+#, c-format
+msgid "Deleted branch %s (was %s).\n"
+msgstr "Nhánh “%s” đã bị xóa (từng là %s)\n"
+
+#: builtin/branch.c:429 builtin/tag.c:61
+msgid "unable to parse format string"
+msgstr "không thể phân tích chuỗi định dạng"
+
+#: builtin/branch.c:460
+msgid "could not resolve HEAD"
+msgstr "không thể phân giải HEAD"
+
+#: builtin/branch.c:466
+#, c-format
+msgid "HEAD (%s) points outside of refs/heads/"
+msgstr "HEAD (%s) chỉ bên ngoài của refs/heads/"
+
+#: builtin/branch.c:481
+#, c-format
+msgid "Branch %s is being rebased at %s"
+msgstr "Nhánh %s đang được cải tổ lại tại %s"
+
+#: builtin/branch.c:485
+#, c-format
+msgid "Branch %s is being bisected at %s"
+msgstr "Nhánh %s đang được di chuyển phân đôi (bisect) tại %s"
+
+#: builtin/branch.c:502
+msgid "cannot copy the current branch while not on any."
+msgstr "không thể sao chép nhánh hiện hành trong khi nó chẳng ở đâu cả."
+
+#: builtin/branch.c:504
+msgid "cannot rename the current branch while not on any."
+msgstr "không thể đổi tên nhánh hiện hành trong khi nó chẳng ở đâu cả."
+
+#: builtin/branch.c:515
+#, c-format
+msgid "Invalid branch name: '%s'"
+msgstr "Tên nhánh không hợp lệ: “%s”"
+
+#: builtin/branch.c:542
+msgid "Branch rename failed"
+msgstr "Gặp lỗi khi đổi tên nhánh"
+
+#: builtin/branch.c:544
+msgid "Branch copy failed"
+msgstr "Gặp lỗi khi sao chép nhánh"
+
+#: builtin/branch.c:548
+#, c-format
+msgid "Created a copy of a misnamed branch '%s'"
+msgstr "Đã tạo một bản sao của nhánh khuyết danh “%s”"
+
+#: builtin/branch.c:551
+#, c-format
+msgid "Renamed a misnamed branch '%s' away"
+msgstr "Đã đổi tên nhánh khuyết danh “%s” đi"
+
+#: builtin/branch.c:557
+#, c-format
+msgid "Branch renamed to %s, but HEAD is not updated!"
+msgstr "Nhánh bị đổi tên thành %s, nhưng HEAD lại không được cập nhật!"
+
+#: builtin/branch.c:566
+msgid "Branch is renamed, but update of config-file failed"
+msgstr "Nhánh bị đổi tên, nhưng cập nhật tập tin cấu hình gặp lỗi"
+
+#: builtin/branch.c:568
+msgid "Branch is copied, but update of config-file failed"
+msgstr "Nhánh đã được sao chép, nhưng cập nhật tập tin cấu hình gặp lỗi"
+
+#: builtin/branch.c:584
+#, c-format
+msgid ""
+"Please edit the description for the branch\n"
+"  %s\n"
+"Lines starting with '%c' will be stripped.\n"
+msgstr ""
+"Viết các ghi chú cho nhánh:\n"
+"  %s\n"
+"Những dòng được bắt đầu bằng “%c” sẽ được cắt bỏ.\n"
+
+#: builtin/branch.c:618
+msgid "Generic options"
+msgstr "Tùy chọn chung"
+
+#: builtin/branch.c:620
+msgid "show hash and subject, give twice for upstream branch"
+msgstr "hiển thị mã băm và chủ đề, đưa ra hai lần cho nhánh thượng nguồn"
+
+#: builtin/branch.c:621
+msgid "suppress informational messages"
+msgstr "không xuất các thông tin"
+
+#: builtin/branch.c:622
+msgid "set up tracking mode (see git-pull(1))"
+msgstr "cài đặt chế độ theo dõi (xem git-pull(1))"
+
+#: builtin/branch.c:624
+msgid "do not use"
+msgstr "không dùng"
+
+#: builtin/branch.c:626 builtin/rebase.c:505
+msgid "upstream"
+msgstr "thượng nguồn"
+
+#: builtin/branch.c:626
+msgid "change the upstream info"
+msgstr "thay đổi thông tin thượng nguồn"
+
+#: builtin/branch.c:627
+msgid "unset the upstream info"
+msgstr "bỏ đặt thông tin thượng nguồn"
+
+#: builtin/branch.c:628
+msgid "use colored output"
+msgstr "tô màu kết xuất"
+
+#: builtin/branch.c:629
+msgid "act on remote-tracking branches"
+msgstr "thao tác trên nhánh “remote-tracking”"
+
+#: builtin/branch.c:631 builtin/branch.c:633
+msgid "print only branches that contain the commit"
+msgstr "chỉ hiển thị những nhánh mà nó chứa lần chuyển giao"
+
+#: builtin/branch.c:632 builtin/branch.c:634
+msgid "print only branches that don't contain the commit"
+msgstr "chỉ hiển thị những nhánh mà nó không chứa lần chuyển giao"
+
+#: builtin/branch.c:637
+msgid "Specific git-branch actions:"
+msgstr "Hành động git-branch:"
+
+#: builtin/branch.c:638
+msgid "list both remote-tracking and local branches"
+msgstr "liệt kê cả nhánh “remote-tracking” và nội bộ"
+
+#: builtin/branch.c:640
+msgid "delete fully merged branch"
+msgstr "xóa một toàn bộ nhánh đã hòa trộn"
+
+#: builtin/branch.c:641
+msgid "delete branch (even if not merged)"
+msgstr "xóa nhánh (cho dù là chưa được hòa trộn)"
+
+#: builtin/branch.c:642
+msgid "move/rename a branch and its reflog"
+msgstr "di chuyển hay đổi tên một nhánh và reflog của nó"
+
+#: builtin/branch.c:643
+msgid "move/rename a branch, even if target exists"
+msgstr "di chuyển hoặc đổi tên một nhánh ngay cả khi đích đã có sẵn"
+
+#: builtin/branch.c:644
+msgid "copy a branch and its reflog"
+msgstr "sao chép một nhánh và reflog của nó"
+
+#: builtin/branch.c:645
+msgid "copy a branch, even if target exists"
+msgstr "sao chép một nhánh ngay cả khi đích đã có sẵn"
+
+#: builtin/branch.c:646
+msgid "list branch names"
+msgstr "liệt kê các tên nhánh"
+
+#: builtin/branch.c:647
+msgid "show current branch name"
+msgstr "hiển thị nhánh hiện hành"
+
+#: builtin/branch.c:648
+msgid "create the branch's reflog"
+msgstr "tạo reflog của nhánh"
+
+#: builtin/branch.c:650
+msgid "edit the description for the branch"
+msgstr "sửa mô tả cho nhánh"
+
+#: builtin/branch.c:651
+msgid "force creation, move/rename, deletion"
+msgstr "buộc tạo, di chuyển/đổi tên, xóa"
+
+#: builtin/branch.c:652
+msgid "print only branches that are merged"
+msgstr "chỉ hiển thị những nhánh mà nó được hòa trộn"
+
+#: builtin/branch.c:653
+msgid "print only branches that are not merged"
+msgstr "chỉ hiển thị những nhánh mà nó không được hòa trộn"
+
+#: builtin/branch.c:654
+msgid "list branches in columns"
+msgstr "liệt kê các nhánh trong các cột"
+
+#: builtin/branch.c:657 builtin/for-each-ref.c:42 builtin/notes.c:415
+#: builtin/notes.c:418 builtin/notes.c:581 builtin/notes.c:584
+#: builtin/tag.c:433
+msgid "object"
+msgstr "đối tượng"
+
+#: builtin/branch.c:658
+msgid "print only branches of the object"
+msgstr "chỉ hiển thị các nhánh của đối tượng"
+
+#: builtin/branch.c:660 builtin/for-each-ref.c:48 builtin/tag.c:440
+msgid "sorting and filtering are case insensitive"
+msgstr "sắp xếp và lọc là phân biệt HOA thường"
+
+#: builtin/branch.c:661 builtin/for-each-ref.c:38 builtin/tag.c:438
+#: builtin/verify-tag.c:38
+msgid "format to use for the output"
+msgstr "định dạng sẽ dùng cho đầu ra"
+
+#: builtin/branch.c:684 builtin/clone.c:784
+msgid "HEAD not found below refs/heads!"
+msgstr "Không tìm thấy HEAD ở dưới refs/heads!"
+
+#: builtin/branch.c:708
+msgid "--column and --verbose are incompatible"
+msgstr "tùy chọn --column và --verbose xung khắc nhau"
+
+#: builtin/branch.c:723 builtin/branch.c:777 builtin/branch.c:786
+msgid "branch name required"
+msgstr "cần chỉ ra tên nhánh"
+
+#: builtin/branch.c:753
+msgid "Cannot give description to detached HEAD"
+msgstr "Không thể đưa ra mô tả HEAD đã tách rời"
+
+#: builtin/branch.c:758
+msgid "cannot edit description of more than one branch"
+msgstr "không thể sửa mô tả cho nhiều hơn một nhánh"
+
+#: builtin/branch.c:765
+#, c-format
+msgid "No commit on branch '%s' yet."
+msgstr "Vẫn chưa chuyển giao trên nhánh “%s”."
+
+#: builtin/branch.c:768
+#, c-format
+msgid "No branch named '%s'."
+msgstr "Không có nhánh nào có tên “%s”."
+
+#: builtin/branch.c:783
+msgid "too many branches for a copy operation"
+msgstr "quá nhiều nhánh dành cho thao tác sao chép"
+
+#: builtin/branch.c:792
+msgid "too many arguments for a rename operation"
+msgstr "quá nhiều tham số cho thao tác đổi tên"
+
+#: builtin/branch.c:797
+msgid "too many arguments to set new upstream"
+msgstr "quá nhiều tham số để đặt thượng nguồn mới"
+
+#: builtin/branch.c:801
+#, c-format
+msgid ""
+"could not set upstream of HEAD to %s when it does not point to any branch."
+msgstr ""
+"không thể đặt thượng nguồn của HEAD thành %s khi mà nó chẳng chỉ đến nhánh "
+"nào cả."
+
+#: builtin/branch.c:804 builtin/branch.c:827
+#, c-format
+msgid "no such branch '%s'"
+msgstr "không có nhánh nào như thế “%s”"
+
+#: builtin/branch.c:808
+#, c-format
+msgid "branch '%s' does not exist"
+msgstr "chưa có nhánh “%s”"
+
+#: builtin/branch.c:821
+msgid "too many arguments to unset upstream"
+msgstr "quá nhiều tham số để bỏ đặt thượng nguồn"
+
+#: builtin/branch.c:825
+msgid "could not unset upstream of HEAD when it does not point to any branch."
+msgstr "không thể bỏ đặt thượng nguồn của HEAD không chỉ đến một nhánh nào cả."
+
+#: builtin/branch.c:831
+#, c-format
+msgid "Branch '%s' has no upstream information"
+msgstr "Nhánh “%s” không có thông tin thượng nguồn"
+
+#: builtin/branch.c:841
+msgid ""
+"The -a, and -r, options to 'git branch' do not take a branch name.\n"
+"Did you mean to use: -a|-r --list <pattern>?"
+msgstr ""
+"Hai tùy chọn -a và -r áp dụng cho lệnh “git branch” không nhận một tên "
+"nhánh.\n"
+"Có phải ý bạn là dùng: -a|-r --list <mẫu>?"
+
+#: builtin/branch.c:845
+msgid ""
+"the '--set-upstream' option is no longer supported. Please use '--track' or "
+"'--set-upstream-to' instead."
+msgstr ""
+"tùy chọn --set-upstream đã không còn được hỗ trợ nữa. Vui lòng dùng “--"
+"track” hoặc “--set-upstream-to” để thay thế."
+
+#: builtin/bundle.c:15 builtin/bundle.c:23
+#| msgid "git remote add [<options>] <name> <url>"
+msgid "git bundle create [<options>] <file> <git-rev-list args>"
+msgstr "git bundle create [<các tùy chọn>] <tập_tin> <git-rev-list args>"
+
+#: builtin/bundle.c:16 builtin/bundle.c:28
+msgid "git bundle verify [<options>] <file>"
+msgstr "git bundle verify [<các tùy chọn>] <tập-tin>"
+
+#: builtin/bundle.c:17 builtin/bundle.c:33
+msgid "git bundle list-heads <file> [<refname>...]"
+msgstr "git bundle list-heads <tập tin> [<tên tham chiếu>...]"
+
+#: builtin/bundle.c:18 builtin/bundle.c:38
+msgid "git bundle unbundle <file> [<refname>...]"
+msgstr "git bundle unbundle <tập tin> [<tên tham chiếu>...]"
+
+#: builtin/bundle.c:66 builtin/pack-objects.c:3228
+msgid "do not show progress meter"
+msgstr "không hiển thị bộ đo tiến trình"
+
+#: builtin/bundle.c:68 builtin/pack-objects.c:3230
+msgid "show progress meter"
+msgstr "hiển thị bộ đo tiến trình"
+
+#: builtin/bundle.c:70 builtin/pack-objects.c:3232
+msgid "show progress meter during object writing phase"
+msgstr "hiển thị bộ đo tiến triển trong suốt pha ghi đối tượng"
+
+#: builtin/bundle.c:73 builtin/pack-objects.c:3235
+msgid "similar to --all-progress when progress meter is shown"
+msgstr "tương tự --all-progress khi bộ đo tiến trình được xuất hiện"
+
+#: builtin/bundle.c:93
+msgid "Need a repository to create a bundle."
+msgstr "Cần một kho chứa để có thể tạo một bundle."
+
+#: builtin/bundle.c:104
+msgid "do not show bundle details"
+msgstr "không hiển thị chi tiết bundle (bó)"
+
+#: builtin/bundle.c:119
+#, c-format
+msgid "%s is okay\n"
+msgstr "“%s” tốt\n"
+
+#: builtin/bundle.c:160
+msgid "Need a repository to unbundle."
+msgstr "Cần một kho chứa để có thể giải nén một bundle."
+
+#: builtin/bundle.c:168 builtin/remote.c:1609
+msgid "be verbose; must be placed before a subcommand"
+msgstr "chi tiết; phải được đặt trước một lệnh-con"
+
+#: builtin/bundle.c:190 builtin/remote.c:1640
+#, c-format
+msgid "Unknown subcommand: %s"
+msgstr "Không hiểu câu lệnh con: %s"
+
+#: builtin/cat-file.c:595
+msgid ""
+"git cat-file (-t [--allow-unknown-type] | -s [--allow-unknown-type] | -e | -"
+"p | <type> | --textconv | --filters) [--path=<path>] <object>"
+msgstr ""
+"git cat-file (-t [--allow-unknown-type] | -s [--allow-unknown-type] | -e | -"
+"p | <kiểu> | --textconv) | --filters) [--path=<đường/dẫn>] <đối_tượng>"
+
+#: builtin/cat-file.c:596
+msgid ""
+"git cat-file (--batch | --batch-check) [--follow-symlinks] [--textconv | --"
+"filters]"
+msgstr ""
+"git cat-file (--batch | --batch-check) [--follow-symlinks] [--textconv | --"
+"filters]"
+
+#: builtin/cat-file.c:617
+msgid "only one batch option may be specified"
+msgstr "chỉ một tùy chọn batch được chỉ ra"
+
+#: builtin/cat-file.c:635
+msgid "<type> can be one of: blob, tree, commit, tag"
+msgstr "<kiểu> là một trong số: blob, tree, commit hoặc tag"
+
+#: builtin/cat-file.c:636
 msgid "show object type"
 msgstr "hiển thị kiểu đối tượng"
 
-#: builtin/cat-file.c:565
-msgid "show object size"
-msgstr "hiển thị kích thước đối tượng"
+#: builtin/cat-file.c:637
+msgid "show object size"
+msgstr "hiển thị kích thước đối tượng"
+
+#: builtin/cat-file.c:639
+msgid "exit with zero when there's no error"
+msgstr "thoát với 0 khi không có lỗi"
+
+#: builtin/cat-file.c:640
+msgid "pretty-print object's content"
+msgstr "in nội dung đối tượng dạng dễ đọc"
+
+#: builtin/cat-file.c:642
+msgid "for blob objects, run textconv on object's content"
+msgstr "với đối tượng blob, chạy lệnh textconv trên nội dung của đối tượng"
+
+#: builtin/cat-file.c:644
+msgid "for blob objects, run filters on object's content"
+msgstr "với đối tượng blob, chạy lệnh filters trên nội dung của đối tượng"
+
+#: builtin/cat-file.c:645 git-submodule.sh:992
+msgid "blob"
+msgstr "blob"
+
+#: builtin/cat-file.c:646
+msgid "use a specific path for --textconv/--filters"
+msgstr "dùng một đường dẫn rõ ràng cho --textconv/--filters"
+
+#: builtin/cat-file.c:648
+msgid "allow -s and -t to work with broken/corrupt objects"
+msgstr "cho phép -s và -t để làm việc với các đối tượng sai/hỏng"
+
+#: builtin/cat-file.c:649
+msgid "buffer --batch output"
+msgstr "đệm kết xuất --batch"
+
+#: builtin/cat-file.c:651
+msgid "show info and content of objects fed from the standard input"
+msgstr ""
+"hiển thị thông tin và nội dung của các đối tượng lấy từ đầu vào tiêu chuẩn"
+
+#: builtin/cat-file.c:655
+msgid "show info about objects fed from the standard input"
+msgstr "hiển thị các thông tin về đối tượng fed  từ đầu vào tiêu chuẩn"
+
+#: builtin/cat-file.c:659
+msgid "follow in-tree symlinks (used with --batch or --batch-check)"
+msgstr "theo liên kết mềm trong-cây (được dùng với --batch hay --batch-check)"
+
+#: builtin/cat-file.c:661
+msgid "show all objects with --batch or --batch-check"
+msgstr "hiển thị mọi đối tượng với --batch hay --batch-check"
+
+#: builtin/cat-file.c:663
+msgid "do not order --batch-all-objects output"
+msgstr "đừng sắp xếp đầu ra --batch-all-objects"
+
+#: builtin/check-attr.c:13
+msgid "git check-attr [-a | --all | <attr>...] [--] <pathname>..."
+msgstr "git check-attr [-a | --all | <attr>…] [--] tên-đường-dẫn…"
+
+#: builtin/check-attr.c:14
+msgid "git check-attr --stdin [-z] [-a | --all | <attr>...]"
+msgstr "git check-attr --stdin [-z] [-a | --all | <attr>…]"
+
+#: builtin/check-attr.c:21
+msgid "report all attributes set on file"
+msgstr "báo cáo tất cả các thuộc tính đặt trên tập tin"
+
+#: builtin/check-attr.c:22
+msgid "use .gitattributes only from the index"
+msgstr "chỉ dùng .gitattributes từ bảng mục lục"
+
+#: builtin/check-attr.c:23 builtin/check-ignore.c:25 builtin/hash-object.c:102
+msgid "read file names from stdin"
+msgstr "đọc tên tập tin từ đầu vào tiêu chuẩn"
+
+#: builtin/check-attr.c:25 builtin/check-ignore.c:27
+msgid "terminate input and output records by a NUL character"
+msgstr "chấm dứt các bản ghi vào và ra bằng ký tự NULL"
+
+#: builtin/check-ignore.c:21 builtin/checkout.c:1435 builtin/gc.c:537
+#: builtin/worktree.c:506
+msgid "suppress progress reporting"
+msgstr "chặn các báo cáo tiến trình hoạt động"
+
+#: builtin/check-ignore.c:29
+msgid "show non-matching input paths"
+msgstr "hiển thị những đường dẫn đầu vào không khớp với mẫu"
+
+#: builtin/check-ignore.c:31
+msgid "ignore index when checking"
+msgstr "bỏ qua mục lục khi kiểm tra"
+
+#: builtin/check-ignore.c:160
+msgid "cannot specify pathnames with --stdin"
+msgstr "không thể chỉ định các tên đường dẫn với --stdin"
+
+#: builtin/check-ignore.c:163
+msgid "-z only makes sense with --stdin"
+msgstr "-z chỉ hợp lý với --stdin"
+
+#: builtin/check-ignore.c:165
+msgid "no path specified"
+msgstr "chưa chỉ ra đường dẫn"
+
+#: builtin/check-ignore.c:169
+msgid "--quiet is only valid with a single pathname"
+msgstr "--quiet chỉ hợp lệ với tên đường dẫn đơn"
+
+#: builtin/check-ignore.c:171
+msgid "cannot have both --quiet and --verbose"
+msgstr "không thể dùng cả hai tùy chọn --quiet và --verbose"
+
+#: builtin/check-ignore.c:174
+msgid "--non-matching is only valid with --verbose"
+msgstr "tùy-chọn --non-matching chỉ hợp lệ khi dùng với --verbose"
+
+#: builtin/check-mailmap.c:9
+msgid "git check-mailmap [<options>] <contact>..."
+msgstr "git check-mailmap [<các tùy chọn>] <danh-bạ>…"
+
+#: builtin/check-mailmap.c:14
+msgid "also read contacts from stdin"
+msgstr "đồng thời đọc các danh bạ từ đầu vào tiêu chuẩn"
+
+#: builtin/check-mailmap.c:25
+#, c-format
+msgid "unable to parse contact: %s"
+msgstr "không thể phân tích danh bạ: “%s”"
+
+#: builtin/check-mailmap.c:48
+msgid "no contacts specified"
+msgstr "chưa chỉ ra danh bạ"
+
+#: builtin/checkout-index.c:131
+msgid "git checkout-index [<options>] [--] [<file>...]"
+msgstr "git checkout-index [<các tùy chọn>] [--] [<tập-tin>…]"
+
+#: builtin/checkout-index.c:148
+msgid "stage should be between 1 and 3 or all"
+msgstr "stage nên giữa 1 và 3 hay all"
+
+#: builtin/checkout-index.c:164
+msgid "check out all files in the index"
+msgstr "lấy ra toàn bộ các tập tin trong bảng mục lục"
+
+#: builtin/checkout-index.c:165
+msgid "force overwrite of existing files"
+msgstr "ép buộc ghi đè lên tập tin đã sẵn có từ trước"
+
+#: builtin/checkout-index.c:167
+msgid "no warning for existing files and files not in index"
+msgstr ""
+"không cảnh báo cho những tập tin tồn tại và không có trong bảng mục lục"
+
+#: builtin/checkout-index.c:169
+msgid "don't checkout new files"
+msgstr "không checkout các tập tin mới"
+
+#: builtin/checkout-index.c:171
+msgid "update stat information in the index file"
+msgstr "cập nhật thông tin thống kê trong tập tin lưu bảng mục lục mới"
+
+#: builtin/checkout-index.c:175
+msgid "read list of paths from the standard input"
+msgstr "đọc danh sách đường dẫn từ đầu vào tiêu chuẩn"
+
+#: builtin/checkout-index.c:177
+msgid "write the content to temporary files"
+msgstr "ghi nội dung vào tập tin tạm"
+
+#: builtin/checkout-index.c:178 builtin/column.c:31
+#: builtin/submodule--helper.c:1385 builtin/submodule--helper.c:1388
+#: builtin/submodule--helper.c:1396 builtin/submodule--helper.c:1882
+#: builtin/worktree.c:679
+msgid "string"
+msgstr "chuỗi"
+
+#: builtin/checkout-index.c:179
+msgid "when creating files, prepend <string>"
+msgstr "khi tạo các tập tin, nối thêm <chuỗi>"
+
+#: builtin/checkout-index.c:181
+msgid "copy out the files from named stage"
+msgstr "sao chép ra các tập tin từ bệ phóng có tên"
+
+#: builtin/checkout.c:31
+msgid "git checkout [<options>] <branch>"
+msgstr "git checkout [<các tùy chọn>] <nhánh>"
+
+#: builtin/checkout.c:32
+msgid "git checkout [<options>] [<branch>] -- <file>..."
+msgstr "git checkout [<các tùy chọn>] [<nhánh>] -- <tập-tin>…"
+
+#: builtin/checkout.c:37
+msgid "git switch [<options>] [<branch>]"
+msgstr "git switch [<các tùy chọn>] [<nhánh>]"
+
+#: builtin/checkout.c:42
+msgid "git restore [<options>] [--source=<branch>] <file>..."
+msgstr "git restore [<các tùy chọn>] [--source=<nhánh>] <tập tin>..."
+
+#: builtin/checkout.c:175 builtin/checkout.c:214
+#, c-format
+msgid "path '%s' does not have our version"
+msgstr "đường dẫn “%s” không có các phiên bản của chúng ta"
+
+#: builtin/checkout.c:177 builtin/checkout.c:216
+#, c-format
+msgid "path '%s' does not have their version"
+msgstr "đường dẫn “%s” không có các phiên bản của chúng"
+
+#: builtin/checkout.c:193
+#, c-format
+msgid "path '%s' does not have all necessary versions"
+msgstr "đường dẫn “%s” không có tất cả các phiên bản cần thiết"
+
+#: builtin/checkout.c:243
+#, c-format
+msgid "path '%s' does not have necessary versions"
+msgstr "đường dẫn “%s” không có các phiên bản cần thiết"
+
+#: builtin/checkout.c:261
+#, c-format
+msgid "path '%s': cannot merge"
+msgstr "đường dẫn “%s”: không thể hòa trộn"
+
+#: builtin/checkout.c:277
+#, c-format
+msgid "Unable to add merge result for '%s'"
+msgstr "Không thể thêm kết quả hòa trộn cho “%s”"
+
+#: builtin/checkout.c:377
+#, c-format
+msgid "Recreated %d merge conflict"
+msgid_plural "Recreated %d merge conflicts"
+msgstr[0] "Đã tạo lại %d xung đột hòa trộn"
+
+#: builtin/checkout.c:382
+#, c-format
+msgid "Updated %d path from %s"
+msgid_plural "Updated %d paths from %s"
+msgstr[0] "Đã cập nhật đường dẫn %d từ %s"
+
+#: builtin/checkout.c:389
+#, c-format
+msgid "Updated %d path from the index"
+msgid_plural "Updated %d paths from the index"
+msgstr[0] "Đã cập nhật đường dẫn %d từ mục lục"
+
+#: builtin/checkout.c:412 builtin/checkout.c:415 builtin/checkout.c:418
+#: builtin/checkout.c:422
+#, c-format
+msgid "'%s' cannot be used with updating paths"
+msgstr "không được dùng “%s” với các đường dẫn cập nhật"
+
+#: builtin/checkout.c:425 builtin/checkout.c:428
+#, c-format
+msgid "'%s' cannot be used with %s"
+msgstr "không được dùng “%s” với %s"
+
+#: builtin/checkout.c:432
+#, c-format
+msgid "Cannot update paths and switch to branch '%s' at the same time."
+msgstr ""
+"Không thể cập nhật các đường dẫn và chuyển đến nhánh “%s” cùng một lúc."
+
+#: builtin/checkout.c:436
+#, c-format
+msgid "neither '%s' or '%s' is specified"
+msgstr "không chỉ định '%s' không '%s'"
+
+#: builtin/checkout.c:440
+#, c-format
+msgid "'%s' must be used when '%s' is not specified"
+msgstr "phải có “%s” khi không chỉ định “%s”"
+
+#: builtin/checkout.c:445 builtin/checkout.c:450
+#, c-format
+msgid "'%s' or '%s' cannot be used with %s"
+msgstr "'%s' hay '%s' không thể được sử dụng với %s"
+
+#: builtin/checkout.c:509 builtin/checkout.c:516
+#, c-format
+msgid "path '%s' is unmerged"
+msgstr "đường dẫn “%s” không được hòa trộn"
+
+#: builtin/checkout.c:682 builtin/sparse-checkout.c:82
+msgid "you need to resolve your current index first"
+msgstr "bạn cần phải giải quyết bảng mục lục hiện tại của bạn trước đã"
+
+#: builtin/checkout.c:732
+#, c-format
+msgid ""
+"cannot continue with staged changes in the following files:\n"
+"%s"
+msgstr ""
+"không thể tiếp tục với các thay đổi đã được đưa lên bệ phóng trong các dòng "
+"sau:\n"
+"%s"
+
+#: builtin/checkout.c:835
+#, c-format
+msgid "Can not do reflog for '%s': %s\n"
+msgstr "Không thể thực hiện reflog cho “%s”: %s\n"
+
+#: builtin/checkout.c:877
+msgid "HEAD is now at"
+msgstr "HEAD hiện giờ tại"
+
+#: builtin/checkout.c:881 builtin/clone.c:716
+msgid "unable to update HEAD"
+msgstr "không thể cập nhật HEAD"
+
+#: builtin/checkout.c:885
+#, c-format
+msgid "Reset branch '%s'\n"
+msgstr "Đặt lại nhánh “%s”\n"
+
+#: builtin/checkout.c:888
+#, c-format
+msgid "Already on '%s'\n"
+msgstr "Đã sẵn sàng trên “%s”\n"
+
+#: builtin/checkout.c:892
+#, c-format
+msgid "Switched to and reset branch '%s'\n"
+msgstr "Đã chuyển tới và đặt lại nhánh “%s”\n"
+
+#: builtin/checkout.c:894 builtin/checkout.c:1291
+#, c-format
+msgid "Switched to a new branch '%s'\n"
+msgstr "Đã chuyển đến nhánh mới “%s”\n"
+
+#: builtin/checkout.c:896
+#, c-format
+msgid "Switched to branch '%s'\n"
+msgstr "Đã chuyển đến nhánh “%s”\n"
+
+#: builtin/checkout.c:947
+#, c-format
+msgid " ... and %d more.\n"
+msgstr " … và nhiều hơn %d.\n"
+
+#: builtin/checkout.c:953
+#, c-format
+msgid ""
+"Warning: you are leaving %d commit behind, not connected to\n"
+"any of your branches:\n"
+"\n"
+"%s\n"
+msgid_plural ""
+"Warning: you are leaving %d commits behind, not connected to\n"
+"any of your branches:\n"
+"\n"
+"%s\n"
+msgstr[0] ""
+"Cảnh báo: bạn đã rời bỏ %d lần chuyển giao lại đằng sau, không được kết nối "
+"đến\n"
+"bất kỳ nhánh nào của bạn:\n"
+"\n"
+"%s\n"
+
+#: builtin/checkout.c:972
+#, c-format
+msgid ""
+"If you want to keep it by creating a new branch, this may be a good time\n"
+"to do so with:\n"
+"\n"
+" git branch <new-branch-name> %s\n"
+"\n"
+msgid_plural ""
+"If you want to keep them by creating a new branch, this may be a good time\n"
+"to do so with:\n"
+"\n"
+" git branch <new-branch-name> %s\n"
+"\n"
+msgstr[0] ""
+"Nếu bạn muốn giữ (chúng) nó bằng cách tạo ra một nhánh mới, đây có lẽ là\n"
+"một thời điểm thích hợp để làm thế bằng lệnh:\n"
+"\n"
+" git branch <tên_nhánh_mới> %s\n"
+"\n"
+
+#: builtin/checkout.c:1007
+msgid "internal error in revision walk"
+msgstr "lỗi nội bộ trong khi di chuyển qua các điểm xét duyệt"
+
+#: builtin/checkout.c:1011
+msgid "Previous HEAD position was"
+msgstr "Vị trí trước kia của HEAD là"
+
+#: builtin/checkout.c:1051 builtin/checkout.c:1286
+msgid "You are on a branch yet to be born"
+msgstr "Bạn tại nhánh mà nó chưa hề được sinh ra"
+
+#: builtin/checkout.c:1178
+msgid "only one reference expected"
+msgstr "chỉ cần một tham chiếu"
+
+#: builtin/checkout.c:1195
+#, c-format
+msgid "only one reference expected, %d given."
+msgstr "chỉ cần một tham chiếu, nhưng lại đưa ra %d."
+
+#: builtin/checkout.c:1232
+#, c-format
+msgid ""
+"'%s' could be both a local file and a tracking branch.\n"
+"Please use -- (and optionally --no-guess) to disambiguate"
+msgstr ""
+"“%s” không thể là cả tập tin nội bộ và một nhánh theo dõi.\n"
+"Vui long dùng -- (và tùy chọn thêm --no-guess) để tránh lẫn lộn"
+
+#: builtin/checkout.c:1245 builtin/worktree.c:290 builtin/worktree.c:455
+#, c-format
+msgid "invalid reference: %s"
+msgstr "tham chiếu không hợp lệ: %s"
+
+#: builtin/checkout.c:1258 builtin/checkout.c:1622
+#, c-format
+msgid "reference is not a tree: %s"
+msgstr "tham chiếu không phải là một cây:%s"
+
+#: builtin/checkout.c:1305
+#, c-format
+msgid "a branch is expected, got tag '%s'"
+msgstr "cần một nhánh, nhưng lại nhận được thẻ “%s”"
+
+#: builtin/checkout.c:1307
+#, c-format
+msgid "a branch is expected, got remote branch '%s'"
+msgstr "cần một nhánh, nhưng lại nhận được nhánh máy phục vụ “%s”"
+
+#: builtin/checkout.c:1308 builtin/checkout.c:1316
+#, c-format
+msgid "a branch is expected, got '%s'"
+msgstr "cần một nhánh, nhưng lại nhận được “%s”"
+
+#: builtin/checkout.c:1311
+#, c-format
+msgid "a branch is expected, got commit '%s'"
+msgstr "cần một nhánh, nhưng lại nhận được “%s”"
+
+#: builtin/checkout.c:1327
+msgid ""
+"cannot switch branch while merging\n"
+"Consider \"git merge --quit\" or \"git worktree add\"."
+msgstr ""
+"không thể chuyển nhánh trong khi đang hòa trộn\n"
+"Cân nhắc dung \"git merge --quit\" hoặc \"git worktree add\"."
+
+#: builtin/checkout.c:1331
+msgid ""
+"cannot switch branch in the middle of an am session\n"
+"Consider \"git am --quit\" or \"git worktree add\"."
+msgstr ""
+"không thể chuyển nhanh ở giữa một phiên am\n"
+"Cân nhắc dùng \"git am --quit\" hoặc \"git worktree add\"."
+
+#: builtin/checkout.c:1335
+msgid ""
+"cannot switch branch while rebasing\n"
+"Consider \"git rebase --quit\" or \"git worktree add\"."
+msgstr ""
+"không thể chuyển nhánh trong khi cải tổ\n"
+"Cân nhắc dùng \"git rebase --quit\" hay \"git worktree add\"."
+
+#: builtin/checkout.c:1339
+msgid ""
+"cannot switch branch while cherry-picking\n"
+"Consider \"git cherry-pick --quit\" or \"git worktree add\"."
+msgstr ""
+"không thể chuyển nhánh trong khi  cherry-picking\n"
+"Cân nhắc dùng \"git cherry-pick --quit\" hay \"git worktree add\"."
+
+#: builtin/checkout.c:1343
+msgid ""
+"cannot switch branch while reverting\n"
+"Consider \"git revert --quit\" or \"git worktree add\"."
+msgstr ""
+"không thể chuyển nhánh trong khi hoàn nguyên\n"
+"Cân nhắc dùng \"git revert --quit\" hoặc \"git worktree add\"."
+
+#: builtin/checkout.c:1347
+msgid "you are switching branch while bisecting"
+msgstr ""
+"bạn hiện tại đang thực hiện việc chuyển nhánh trong khi đang di chuyển nửa "
+"bước"
+
+#: builtin/checkout.c:1354
+msgid "paths cannot be used with switching branches"
+msgstr "các đường dẫn không thể dùng cùng với các nhánh chuyển"
+
+#: builtin/checkout.c:1357 builtin/checkout.c:1361 builtin/checkout.c:1365
+#, c-format
+msgid "'%s' cannot be used with switching branches"
+msgstr "“%s” không thể được sử dụng với các nhánh chuyển"
+
+#: builtin/checkout.c:1369 builtin/checkout.c:1372 builtin/checkout.c:1375
+#: builtin/checkout.c:1380 builtin/checkout.c:1385
+#, c-format
+msgid "'%s' cannot be used with '%s'"
+msgstr "“%s” không thể được dùng với “%s”"
+
+#: builtin/checkout.c:1382
+#, c-format
+msgid "'%s' cannot take <start-point>"
+msgstr "“%s” không thể nhận <điểm-đầu>"
+
+#: builtin/checkout.c:1390
+#, c-format
+msgid "Cannot switch branch to a non-commit '%s'"
+msgstr "Không thể chuyển nhánh đến một thứ không phải là lần chuyển giao “%s”"
+
+#: builtin/checkout.c:1397
+msgid "missing branch or commit argument"
+msgstr "thiếu tham số là nhánh hoặc lần chuyển giao"
+
+#: builtin/checkout.c:1439 builtin/clone.c:91 builtin/commit-graph.c:52
+#: builtin/commit-graph.c:113 builtin/fetch.c:167 builtin/merge.c:285
+#: builtin/multi-pack-index.c:27 builtin/pull.c:138 builtin/push.c:563
+#: builtin/send-pack.c:174
+msgid "force progress reporting"
+msgstr "ép buộc báo cáo tiến triển công việc"
+
+#: builtin/checkout.c:1440
+msgid "perform a 3-way merge with the new branch"
+msgstr "thực hiện hòa trộn kiểu 3-way với nhánh mới"
+
+#: builtin/checkout.c:1441 builtin/log.c:1690 parse-options.h:322
+msgid "style"
+msgstr "kiểu"
+
+#: builtin/checkout.c:1442
+msgid "conflict style (merge or diff3)"
+msgstr "xung đột kiểu (hòa trộn hoặc diff3)"
+
+#: builtin/checkout.c:1454 builtin/worktree.c:503
+msgid "detach HEAD at named commit"
+msgstr "rời bỏ HEAD tại lần chuyển giao theo tên"
+
+#: builtin/checkout.c:1455
+msgid "set upstream info for new branch"
+msgstr "đặt thông tin thượng nguồn cho nhánh mới"
+
+#: builtin/checkout.c:1457
+msgid "force checkout (throw away local modifications)"
+msgstr "ép buộc lấy ra (bỏ đi những thay đổi nội bộ)"
+
+#: builtin/checkout.c:1459
+msgid "new-branch"
+msgstr "nhánh-mới"
+
+#: builtin/checkout.c:1459
+msgid "new unparented branch"
+msgstr "nhánh không cha mới"
+
+#: builtin/checkout.c:1461 builtin/merge.c:288
+msgid "update ignored files (default)"
+msgstr "cập nhật các tập tin bị bỏ qua (mặc định)"
+
+#: builtin/checkout.c:1464
+msgid "do not check if another worktree is holding the given ref"
+msgstr "không kiểm tra nếu cây làm việc khác đang giữ tham chiếu đã cho"
+
+#: builtin/checkout.c:1477
+msgid "checkout our version for unmerged files"
+msgstr ""
+"lấy ra (checkout) phiên bản của chúng ta cho các tập tin chưa được hòa trộn"
+
+#: builtin/checkout.c:1480
+msgid "checkout their version for unmerged files"
+msgstr ""
+"lấy ra (checkout) phiên bản của chúng họ cho các tập tin chưa được hòa trộn"
+
+#: builtin/checkout.c:1484
+msgid "do not limit pathspecs to sparse entries only"
+msgstr "không giới hạn đặc tả đường dẫn thành chỉ các mục rải rác"
+
+#: builtin/checkout.c:1537
+msgid "-b, -B and --orphan are mutually exclusive"
+msgstr "Các tùy chọn -b, -B và --orphan loại từ lẫn nhau"
+
+#: builtin/checkout.c:1540
+msgid "-p and --overlay are mutually exclusive"
+msgstr "-p và --overlay loại từ lẫn nhau"
+
+#: builtin/checkout.c:1577
+msgid "--track needs a branch name"
+msgstr "--track cần tên một nhánh"
+
+#: builtin/checkout.c:1582
+msgid "missing branch name; try -b"
+msgstr "thiếu tên nhánh; hãy thử -b"
+
+#: builtin/checkout.c:1615
+#, c-format
+msgid "could not resolve %s"
+msgstr "không thể phân giải “%s”"
+
+#: builtin/checkout.c:1631
+msgid "invalid path specification"
+msgstr "đường dẫn đã cho không hợp lệ"
+
+#: builtin/checkout.c:1638
+#, c-format
+msgid "'%s' is not a commit and a branch '%s' cannot be created from it"
+msgstr ""
+"“%s” không phải là một lần chuyển giao và một nhánh'%s” không thể được tạo "
+"từ đó"
+
+#: builtin/checkout.c:1642
+#, c-format
+msgid "git checkout: --detach does not take a path argument '%s'"
+msgstr "git checkout: --detach không nhận một đối số đường dẫn “%s”"
+
+#: builtin/checkout.c:1651
+#| msgid "--first-parent is incompatible with --bisect"
+msgid "--pathspec-from-file is incompatible with --detach"
+msgstr "--pathspec-from-file xung khắc với --detach"
+
+#: builtin/checkout.c:1654 builtin/reset.c:324
+#| msgid "--first-parent is incompatible with --bisect"
+msgid "--pathspec-from-file is incompatible with --patch"
+msgstr "--pathspec-from-file xung khắc với --patch"
+
+#: builtin/checkout.c:1665
+msgid ""
+"git checkout: --ours/--theirs, --force and --merge are incompatible when\n"
+"checking out of the index."
+msgstr ""
+"git checkout: --ours/--theirs, --force và --merge là xung khắc với nhau khi\n"
+"checkout bảng mục lục (index)."
+
+#: builtin/checkout.c:1670
+msgid "you must specify path(s) to restore"
+msgstr "bạn phải chỉ định các thư mục muốn hồi phục"
+
+#: builtin/checkout.c:1689
+#, c-format
+msgid ""
+"'%s' matched more than one remote tracking branch.\n"
+"We found %d remotes with a reference that matched. So we fell back\n"
+"on trying to resolve the argument as a path, but failed there too!\n"
+"\n"
+"If you meant to check out a remote tracking branch on, e.g. 'origin',\n"
+"you can do so by fully qualifying the name with the --track option:\n"
+"\n"
+"    git checkout --track origin/<name>\n"
+"\n"
+"If you'd like to always have checkouts of an ambiguous <name> prefer\n"
+"one remote, e.g. the 'origin' remote, consider setting\n"
+"checkout.defaultRemote=origin in your config."
+msgstr ""
+"“%s” khớp hơn một nhánh máy chủ được theo dõi.\n"
+"Chúng tôi tìm thấy %d máy chủ với một tham chiếu khớp. Do đó chúng tôi cố "
+"để\n"
+"phân giải tham số như là một đường dẫn, nhưng cũng gặp lỗi!\n"
+"\n"
+"Nếu ý bạn là lấy ra nhánh máy chủ được theo dõi, ví dụ “origin”,\n"
+"bạn có thể làm như vậy bằng cách chỉ định đầy đủ tên với tùy chọn --track:\n"
+"\n"
+"    git checkout --track origin/<tên>\n"
+"\n"
+"Nếu bạn muốn luôn lấy ra từ một <tên> một náy chủ ưa thích\n"
+"chưa rõ ràng, ví dụ máy chủ “origin”, cân nhắc cài đặt\n"
+"checkout.defaultRemote=origin trong cấu hình của bạn."
+
+#: builtin/checkout.c:1714 builtin/checkout.c:1716 builtin/checkout.c:1765
+#: builtin/checkout.c:1767 builtin/clone.c:121 builtin/remote.c:169
+#: builtin/remote.c:171 builtin/worktree.c:499 builtin/worktree.c:501
+msgid "branch"
+msgstr "nhánh"
+
+#: builtin/checkout.c:1715
+msgid "create and checkout a new branch"
+msgstr "tạo và checkout một nhánh mới"
+
+#: builtin/checkout.c:1717
+msgid "create/reset and checkout a branch"
+msgstr "tạo/đặt_lại và checkout một nhánh"
+
+#: builtin/checkout.c:1718
+msgid "create reflog for new branch"
+msgstr "tạo reflog cho nhánh mới"
+
+#: builtin/checkout.c:1720
+msgid "second guess 'git checkout <no-such-branch>' (default)"
+msgstr "đoán thứ hai 'git checkout <không-nhánh-nào-như-vậy>' (mặc định)"
+
+#: builtin/checkout.c:1721
+msgid "use overlay mode (default)"
+msgstr "dùng chế độ che phủ (mặc định)"
+
+#: builtin/checkout.c:1766
+msgid "create and switch to a new branch"
+msgstr "tạo và chuyển đến một nhánh mới"
+
+#: builtin/checkout.c:1768
+msgid "create/reset and switch to a branch"
+msgstr "tạo/đặt_lại và chuyển đến một nhánh"
+
+#: builtin/checkout.c:1770
+msgid "second guess 'git switch <no-such-branch>'"
+msgstr "gợi ý thứ hai \"git checkout <không-nhánh-nào-như-vậy>\""
+
+#: builtin/checkout.c:1772
+msgid "throw away local modifications"
+msgstr "vứt bỏ các sửa đổi địa phương"
+
+#: builtin/checkout.c:1804
+msgid "which tree-ish to checkout from"
+msgstr "lấy ra từ tree-ish nào"
+
+#: builtin/checkout.c:1806
+msgid "restore the index"
+msgstr "phục hồi bảng mục lục"
+
+#: builtin/checkout.c:1808
+msgid "restore the working tree (default)"
+msgstr "phục hồi cây làm việc (mặc định)"
+
+#: builtin/checkout.c:1810
+msgid "ignore unmerged entries"
+msgstr "bỏ qua những thứ chưa hòa trộn: %s"
+
+#: builtin/checkout.c:1811
+msgid "use overlay mode"
+msgstr "dùng chế độ che phủ"
+
+#: builtin/clean.c:28
+msgid ""
+"git clean [-d] [-f] [-i] [-n] [-q] [-e <pattern>] [-x | -X] [--] <paths>..."
+msgstr ""
+"git clean [-d] [-f] [-i] [-n] [-q] [-e <mẫu>] [-x | -X] [--] </các/đường/"
+"dẫn>…"
+
+#: builtin/clean.c:32
+#, c-format
+msgid "Removing %s\n"
+msgstr "Đang gỡ bỏ %s\n"
+
+#: builtin/clean.c:33
+#, c-format
+msgid "Would remove %s\n"
+msgstr "Có thể gỡ bỏ %s\n"
+
+#: builtin/clean.c:34
+#, c-format
+msgid "Skipping repository %s\n"
+msgstr "Đang bỏ qua kho chứa %s\n"
+
+#: builtin/clean.c:35
+#, c-format
+msgid "Would skip repository %s\n"
+msgstr "Nên bỏ qua kho chứa %s\n"
+
+#: builtin/clean.c:36
+#, c-format
+msgid "failed to remove %s"
+msgstr "gặp lỗi khi gỡ bỏ %s"
+
+#: builtin/clean.c:37
+#, c-format
+msgid "could not lstat %s\n"
+msgstr "không thể lấy thông tin thống kê đầy đủ của %s\n"
+
+#: builtin/clean.c:301 git-add--interactive.perl:595
+#, c-format
+msgid ""
+"Prompt help:\n"
+"1          - select a numbered item\n"
+"foo        - select item based on unique prefix\n"
+"           - (empty) select nothing\n"
+msgstr ""
+"Trợ giúp về nhắc:\n"
+"1          - chọn một mục được đánh số\n"
+"foo        - chọn mục trên cơ sở tiền tố duy nhất\n"
+"           - (để trống) không chọn gì cả\n"
+
+#: builtin/clean.c:305 git-add--interactive.perl:604
+#, c-format
+msgid ""
+"Prompt help:\n"
+"1          - select a single item\n"
+"3-5        - select a range of items\n"
+"2-3,6-9    - select multiple ranges\n"
+"foo        - select item based on unique prefix\n"
+"-...       - unselect specified items\n"
+"*          - choose all items\n"
+"           - (empty) finish selecting\n"
+msgstr ""
+"Trợ giúp về nhắc:\n"
+"1          - chọn một mục đơn\n"
+"3-5        - chọn một vùng\n"
+"2-3,6-9    - chọn nhiều vùng\n"
+"foo        - chọn mục dựa trên tiền tố duy nhất\n"
+"-…         - không chọn các mục đã chỉ ra\n"
+"*          - chọn tất\n"
+"           - (để trống) kết thúc việc chọn\n"
+
+#: builtin/clean.c:521 git-add--interactive.perl:570
+#: git-add--interactive.perl:575
+#, c-format, perl-format
+msgid "Huh (%s)?\n"
+msgstr "Hả (%s)?\n"
+
+#: builtin/clean.c:663
+#, c-format
+msgid "Input ignore patterns>> "
+msgstr "Mẫu để lọc các tập tin đầu vào cần lờ đi>> "
+
+#: builtin/clean.c:700
+#, c-format
+msgid "WARNING: Cannot find items matched by: %s"
+msgstr "CẢNH BÁO: Không tìm thấy các mục được khớp bởi: %s"
+
+#: builtin/clean.c:721
+msgid "Select items to delete"
+msgstr "Chọn mục muốn xóa"
+
+#. TRANSLATORS: Make sure to keep [y/N] as is
+#: builtin/clean.c:762
+#, c-format
+msgid "Remove %s [y/N]? "
+msgstr "Xóa bỏ “%s” [y/N]? "
+
+#: builtin/clean.c:795
+msgid ""
+"clean               - start cleaning\n"
+"filter by pattern   - exclude items from deletion\n"
+"select by numbers   - select items to be deleted by numbers\n"
+"ask each            - confirm each deletion (like \"rm -i\")\n"
+"quit                - stop cleaning\n"
+"help                - this screen\n"
+"?                   - help for prompt selection"
+msgstr ""
+"clean               - bắt đầu dọn dẹp\n"
+"filter by pattern   - loại trừ các mục khỏi việc xóa\n"
+"select by numbers   - chọn các mục cần xóa bằng số\n"
+"ask each            - xác nhận trước mỗi lần xóa (giống như \"rm -i\")\n"
+"quit                - dừng việc dọn dẹp lại\n"
+"help                - hiển thị chính trợ giúp này\n"
+"?                   - trợ giúp dành cho chọn bằng cách nhắc"
+
+#: builtin/clean.c:831
+msgid "Would remove the following item:"
+msgid_plural "Would remove the following items:"
+msgstr[0] "Có muốn gỡ bỏ (các) mục sau đây không:"
+
+#: builtin/clean.c:847
+msgid "No more files to clean, exiting."
+msgstr "Không còn tập-tin nào để dọn dẹp, đang thoát ra."
+
+#: builtin/clean.c:909
+msgid "do not print names of files removed"
+msgstr "không hiển thị tên của các tập tin đã gỡ bỏ"
+
+#: builtin/clean.c:911
+msgid "force"
+msgstr "ép buộc"
+
+#: builtin/clean.c:912
+msgid "interactive cleaning"
+msgstr "dọn bằng kiểu tương tác"
+
+#: builtin/clean.c:914
+msgid "remove whole directories"
+msgstr "gỡ bỏ toàn bộ thư mục"
+
+#: builtin/clean.c:915 builtin/describe.c:548 builtin/describe.c:550
+#: builtin/grep.c:901 builtin/log.c:177 builtin/log.c:179
+#: builtin/ls-files.c:557 builtin/name-rev.c:464 builtin/name-rev.c:466
+#: builtin/show-ref.c:179
+msgid "pattern"
+msgstr "mẫu"
+
+#: builtin/clean.c:916
+msgid "add <pattern> to ignore rules"
+msgstr "thêm <mẫu> vào trong qui tắc bỏ qua"
+
+#: builtin/clean.c:917
+msgid "remove ignored files, too"
+msgstr "đồng thời gỡ bỏ cả các tập tin bị bỏ qua"
+
+#: builtin/clean.c:919
+msgid "remove only ignored files"
+msgstr "chỉ gỡ bỏ những tập tin bị bỏ qua"
+
+#: builtin/clean.c:937
+msgid "-x and -X cannot be used together"
+msgstr "-x và -X không thể dùng cùng nhau"
+
+#: builtin/clean.c:941
+msgid ""
+"clean.requireForce set to true and neither -i, -n, nor -f given; refusing to "
+"clean"
+msgstr ""
+"clean.requireForce được đặt thành true và không đưa ra tùy chọn -i, -n mà "
+"cũng không -f; từ chối lệnh dọn dẹp (clean)"
+
+#: builtin/clean.c:944
+msgid ""
+"clean.requireForce defaults to true and neither -i, -n, nor -f given; "
+"refusing to clean"
+msgstr ""
+"clean.requireForce mặc định được đặt là true và không đưa ra tùy chọn -i, -n "
+"mà cũng không -f; từ chối lệnh dọn dẹp (clean)"
+
+#: builtin/clone.c:45
+msgid "git clone [<options>] [--] <repo> [<dir>]"
+msgstr "git clone [<các tùy chọn>] [--] <kho> [<t.mục>]"
+
+#: builtin/clone.c:93
+msgid "don't create a checkout"
+msgstr "không tạo một checkout"
+
+#: builtin/clone.c:94 builtin/clone.c:96 builtin/init-db.c:489
+msgid "create a bare repository"
+msgstr "tạo kho thuần"
+
+#: builtin/clone.c:98
+msgid "create a mirror repository (implies bare)"
+msgstr "tạo kho bản sao (ý là kho thuần)"
+
+#: builtin/clone.c:100
+msgid "to clone from a local repository"
+msgstr "để nhân bản từ kho nội bộ"
+
+#: builtin/clone.c:102
+msgid "don't use local hardlinks, always copy"
+msgstr "không sử dụng liên kết cứng nội bộ, luôn sao chép"
+
+#: builtin/clone.c:104
+msgid "setup as shared repository"
+msgstr "cài đặt đây là kho chia sẻ"
+
+#: builtin/clone.c:107
+msgid "pathspec"
+msgstr "đặc-tả-đường-dẫn"
+
+#: builtin/clone.c:107
+msgid "initialize submodules in the clone"
+msgstr "khởi tạo mô-đun-con trong bản sao"
+
+#: builtin/clone.c:110
+msgid "number of submodules cloned in parallel"
+msgstr "số lượng mô-đun-con được nhân bản đồng thời"
+
+#: builtin/clone.c:111 builtin/init-db.c:486
+msgid "template-directory"
+msgstr "thư-mục-mẫu"
+
+#: builtin/clone.c:112 builtin/init-db.c:487
+msgid "directory from which templates will be used"
+msgstr "thư mục mà tại đó các mẫu sẽ được dùng"
+
+#: builtin/clone.c:114 builtin/clone.c:116 builtin/submodule--helper.c:1392
+#: builtin/submodule--helper.c:1885
+msgid "reference repository"
+msgstr "kho tham chiếu"
+
+#: builtin/clone.c:118 builtin/submodule--helper.c:1394
+#: builtin/submodule--helper.c:1887
+msgid "use --reference only while cloning"
+msgstr "chỉ dùng --reference khi nhân bản"
+
+#: builtin/clone.c:119 builtin/column.c:27 builtin/merge-file.c:46
+#: builtin/pack-objects.c:3294 builtin/repack.c:327
+msgid "name"
+msgstr "tên"
+
+#: builtin/clone.c:120
+msgid "use <name> instead of 'origin' to track upstream"
+msgstr "dùng <tên> thay cho “origin” để theo dõi thượng nguồn"
+
+#: builtin/clone.c:122
+msgid "checkout <branch> instead of the remote's HEAD"
+msgstr "lấy ra <nhánh> thay cho HEAD của máy chủ"
+
+#: builtin/clone.c:124
+msgid "path to git-upload-pack on the remote"
+msgstr "đường dẫn đến git-upload-pack trên máy chủ"
+
+#: builtin/clone.c:125 builtin/fetch.c:168 builtin/grep.c:840
+#: builtin/pull.c:227
+msgid "depth"
+msgstr "độ-sâu"
+
+#: builtin/clone.c:126
+msgid "create a shallow clone of that depth"
+msgstr "tạo bản sao không đầy đủ cho mức sâu đã cho"
+
+#: builtin/clone.c:127 builtin/fetch.c:170 builtin/pack-objects.c:3283
+msgid "time"
+msgstr "thời-gian"
+
+#: builtin/clone.c:128
+msgid "create a shallow clone since a specific time"
+msgstr "tạo bản sao không đầy đủ từ thời điểm đã cho"
+
+#: builtin/clone.c:129 builtin/fetch.c:172 builtin/fetch.c:195
+#: builtin/rebase.c:1445
+msgid "revision"
+msgstr "điểm xét duyệt"
+
+#: builtin/clone.c:130 builtin/fetch.c:173
+msgid "deepen history of shallow clone, excluding rev"
+msgstr "làm sâu hơn lịch sử của bản sao shallow, bằng điểm xét duyệt loại trừ"
+
+#: builtin/clone.c:132
+msgid "clone only one branch, HEAD or --branch"
+msgstr "chỉ nhân bản một nhánh, HEAD hoặc --branch"
+
+#: builtin/clone.c:134
+msgid "don't clone any tags, and make later fetches not to follow them"
+msgstr ""
+"đứng có nhân bản bất kỳ nhánh nào, và làm cho những lần lấy về sau không "
+"theo chúng nữa"
+
+#: builtin/clone.c:136
+msgid "any cloned submodules will be shallow"
+msgstr "mọi mô-đun-con nhân bản sẽ là shallow (nông)"
+
+#: builtin/clone.c:137 builtin/init-db.c:495
+msgid "gitdir"
+msgstr "gitdir"
+
+#: builtin/clone.c:138 builtin/init-db.c:496
+msgid "separate git dir from working tree"
+msgstr "không dùng chung thư mục dành riêng cho git và thư mục làm việc"
+
+#: builtin/clone.c:139
+msgid "key=value"
+msgstr "khóa=giá_trị"
+
+#: builtin/clone.c:140
+msgid "set config inside the new repository"
+msgstr "đặt cấu hình bên trong một kho chứa mới"
+
+#: builtin/clone.c:142 builtin/fetch.c:190 builtin/ls-remote.c:76
+#: builtin/push.c:573 builtin/send-pack.c:172
+msgid "server-specific"
+msgstr "đặc-tả-máy-phục-vụ"
+
+#: builtin/clone.c:142 builtin/fetch.c:190 builtin/ls-remote.c:76
+#: builtin/push.c:573 builtin/send-pack.c:173
+msgid "option to transmit"
+msgstr "tùy chọn để chuyển giao"
+
+#: builtin/clone.c:143 builtin/fetch.c:191 builtin/pull.c:240
+#: builtin/push.c:574
+msgid "use IPv4 addresses only"
+msgstr "chỉ dùng địa chỉ IPv4"
+
+#: builtin/clone.c:145 builtin/fetch.c:193 builtin/pull.c:243
+#: builtin/push.c:576
+msgid "use IPv6 addresses only"
+msgstr "chỉ dùng địa chỉ IPv6"
+
+#: builtin/clone.c:149
+msgid "any cloned submodules will use their remote-tracking branch"
+msgstr "mọi mô-đun-con nhân bản sẽ dung nhánh theo dõi máy chủ của chúng"
+
+#: builtin/clone.c:151
+msgid "initialize sparse-checkout file to include only files at root"
+msgstr "khởi tạo tập tin sparse-checkout để bao gồm chỉ các tập tin ở gốc"
+
+#: builtin/clone.c:287
+msgid ""
+"No directory name could be guessed.\n"
+"Please specify a directory on the command line"
+msgstr ""
+"Không đoán được thư mục tên là gì.\n"
+"Vui lòng chỉ định tên một thư mục trên dòng lệnh"
+
+#: builtin/clone.c:340
+#, c-format
+msgid "info: Could not add alternate for '%s': %s\n"
+msgstr "thông tin: không thể thêm thay thế cho “%s”: %s\n"
+
+#: builtin/clone.c:413
+#, c-format
+msgid "%s exists and is not a directory"
+msgstr "%s có tồn tại nhưng lại không phải là một thư mục"
+
+#: builtin/clone.c:430
+#, c-format
+msgid "failed to start iterator over '%s'"
+msgstr "gặp lỗi khi bắt đầu lặp qua “%s”"
+
+#: builtin/clone.c:460
+#, c-format
+msgid "failed to create link '%s'"
+msgstr "gặp lỗi khi tạo được liên kết mềm %s"
+
+#: builtin/clone.c:464
+#, c-format
+msgid "failed to copy file to '%s'"
+msgstr "gặp lỗi khi sao chép tập tin và “%s”"
+
+#: builtin/clone.c:469
+#, c-format
+msgid "failed to iterate over '%s'"
+msgstr "gặp lỗi khi lặp qua “%s”"
+
+#: builtin/clone.c:494
+#, c-format
+msgid "done.\n"
+msgstr "hoàn tất.\n"
+
+#: builtin/clone.c:508
+msgid ""
+"Clone succeeded, but checkout failed.\n"
+"You can inspect what was checked out with 'git status'\n"
+"and retry with 'git restore --source=HEAD :/'\n"
+msgstr ""
+"Việc nhân bản thành công, nhưng checkout gặp lỗi.\n"
+"Bạn kiểm tra kỹ xem cái gì được lấy ra bằng lệnh “git status”\n"
+"và thử lấy ra với lệnh 'git restore --source=HEAD :/'\n"
+
+#: builtin/clone.c:585
+#, c-format
+msgid "Could not find remote branch %s to clone."
+msgstr "Không tìm thấy nhánh máy chủ %s để nhân bản (clone)."
+
+#: builtin/clone.c:704
+#, c-format
+msgid "unable to update %s"
+msgstr "không thể cập nhật %s"
+
+#: builtin/clone.c:752
+msgid "failed to initialize sparse-checkout"
+msgstr "gặp lỗi khi khởi tạo sparse-checkout"
+
+#: builtin/clone.c:775
+msgid "remote HEAD refers to nonexistent ref, unable to checkout.\n"
+msgstr "refers HEAD máy chủ  chỉ đến ref không tồn tại, không thể lấy ra.\n"
+
+#: builtin/clone.c:806
+msgid "unable to checkout working tree"
+msgstr "không thể lấy ra (checkout) cây làm việc"
+
+#: builtin/clone.c:856
+msgid "unable to write parameters to config file"
+msgstr "không thể ghi các tham số vào tập tin cấu hình"
+
+#: builtin/clone.c:919
+msgid "cannot repack to clean up"
+msgstr "không thể đóng gói để dọn dẹp"
+
+#: builtin/clone.c:921
+msgid "cannot unlink temporary alternates file"
+msgstr "không thể bỏ liên kết tập tin thay thế tạm thời"
+
+#: builtin/clone.c:959 builtin/receive-pack.c:1948
+msgid "Too many arguments."
+msgstr "Có quá nhiều đối số."
+
+#: builtin/clone.c:963
+msgid "You must specify a repository to clone."
+msgstr "Bạn phải chỉ định một kho để mà nhân bản (clone)."
+
+#: builtin/clone.c:976
+#, c-format
+msgid "--bare and --origin %s options are incompatible."
+msgstr "tùy chọn --bare và --origin %s xung khắc nhau."
+
+#: builtin/clone.c:979
+msgid "--bare and --separate-git-dir are incompatible."
+msgstr "tùy chọn --bare và --separate-git-dir xung khắc nhau."
+
+#: builtin/clone.c:992
+#, c-format
+msgid "repository '%s' does not exist"
+msgstr "kho chứa “%s” chưa tồn tại"
+
+#: builtin/clone.c:998 builtin/fetch.c:1787
+#, c-format
+msgid "depth %s is not a positive number"
+msgstr "độ sâu %s không phải là một số nguyên dương"
+
+#: builtin/clone.c:1008
+#, c-format
+msgid "destination path '%s' already exists and is not an empty directory."
+msgstr "đường dẫn đích “%s” đã có từ trước và không phải là một thư mục rỗng."
+
+#: builtin/clone.c:1018
+#, c-format
+msgid "working tree '%s' already exists."
+msgstr "cây làm việc “%s” đã sẵn tồn tại rồi."
+
+#: builtin/clone.c:1033 builtin/clone.c:1054 builtin/difftool.c:271
+#: builtin/log.c:1866 builtin/worktree.c:302 builtin/worktree.c:334
+#, c-format
+msgid "could not create leading directories of '%s'"
+msgstr "không thể tạo các thư mục dẫn đầu của “%s”"
+
+#: builtin/clone.c:1038
+#, c-format
+msgid "could not create work tree dir '%s'"
+msgstr "không thể tạo cây thư mục làm việc dir “%s”"
+
+#: builtin/clone.c:1058
+#, c-format
+msgid "Cloning into bare repository '%s'...\n"
+msgstr "Đang nhân bản thành kho chứa bare “%s”…\n"
+
+#: builtin/clone.c:1060
+#, c-format
+msgid "Cloning into '%s'...\n"
+msgstr "Đang nhân bản thành “%s”…\n"
+
+#: builtin/clone.c:1084
+msgid ""
+"clone --recursive is not compatible with both --reference and --reference-if-"
+"able"
+msgstr ""
+"nhân bản --recursive không tương thích với cả hai --reference và --reference-"
+"if-able"
+
+#: builtin/clone.c:1148
+msgid "--depth is ignored in local clones; use file:// instead."
+msgstr "--depth bị lờ đi khi nhân bản nội bộ; hãy sử dụng file:// để thay thế."
+
+#: builtin/clone.c:1150
+msgid "--shallow-since is ignored in local clones; use file:// instead."
+msgstr ""
+"--shallow-since bị lờ đi khi nhân bản nội bộ; hãy sử dụng file:// để thay "
+"thế."
+
+#: builtin/clone.c:1152
+msgid "--shallow-exclude is ignored in local clones; use file:// instead."
+msgstr ""
+"--shallow-exclude bị lờ đi khi nhân bản nội bộ; hãy sử dụng file:// để thay "
+"thế."
+
+#: builtin/clone.c:1154
+msgid "--filter is ignored in local clones; use file:// instead."
+msgstr ""
+"--filter bị lờ đi khi nhân bản nội bộ; hãy sử dụng file:// để thay thế."
+
+#: builtin/clone.c:1157
+msgid "source repository is shallow, ignoring --local"
+msgstr "kho nguồn là nông, nên bỏ qua --local"
+
+#: builtin/clone.c:1162
+msgid "--local is ignored"
+msgstr "--local bị lờ đi"
+
+#: builtin/clone.c:1237 builtin/clone.c:1245
+#, c-format
+msgid "Remote branch %s not found in upstream %s"
+msgstr "Nhánh máy chủ %s không tìm thấy trong thượng nguồn %s"
+
+#: builtin/clone.c:1248
+msgid "You appear to have cloned an empty repository."
+msgstr "Bạn hình như là đã nhân bản một kho trống rỗng."
+
+#: builtin/column.c:10
+msgid "git column [<options>]"
+msgstr "git column [<các tùy chọn>]"
+
+#: builtin/column.c:27
+msgid "lookup config vars"
+msgstr "tìm kiếm biến cấu hình"
+
+#: builtin/column.c:28 builtin/column.c:29
+msgid "layout to use"
+msgstr "bố cục để dùng"
+
+#: builtin/column.c:30
+msgid "Maximum width"
+msgstr "Độ rộng tối đa"
+
+#: builtin/column.c:31
+msgid "Padding space on left border"
+msgstr "Chèn thêm khoảng trống vào bên trái"
+
+#: builtin/column.c:32
+msgid "Padding space on right border"
+msgstr "Chèn thêm khoảng trắng vào bên phải"
+
+#: builtin/column.c:33
+msgid "Padding space between columns"
+msgstr "Chèn thêm khoảng trắng giữa các cột"
 
-#: builtin/cat-file.c:567
-msgid "exit with zero when there's no error"
-msgstr "thoát với 0 khi không có lỗi"
+#: builtin/column.c:51
+msgid "--command must be the first argument"
+msgstr "--command phải là đối số đầu tiên"
 
-#: builtin/cat-file.c:568
-msgid "pretty-print object's content"
-msgstr "in nội dung đối tượng dạng dễ đọc"
+#: builtin/commit-tree.c:18
+msgid ""
+"git commit-tree [(-p <parent>)...] [-S[<keyid>]] [(-m <message>)...] [(-F "
+"<file>)...] <tree>"
+msgstr ""
+"git commit-tree [(-p <cha>)…] [-S[<keyid>]] [(-m <ghi chú>)…] [(-F <tập tin>)"
+"…] <cây>"
 
-#: builtin/cat-file.c:570
-msgid "for blob objects, run textconv on object's content"
-msgstr "với đối tượng blob, chạy lệnh textconv trên nội dung của đối tượng"
+#: builtin/commit-tree.c:31
+#, c-format
+msgid "duplicate parent %s ignored"
+msgstr "cha mẹ bị trùng lặp %s đã bị bỏ qua"
 
-#: builtin/cat-file.c:572
-msgid "for blob objects, run filters on object's content"
-msgstr "với đối tượng blob, chạy lệnh filters trên nội dung của đối tượng"
+#: builtin/commit-tree.c:56 builtin/commit-tree.c:136 builtin/log.c:526
+#, c-format
+msgid "not a valid object name %s"
+msgstr "không phải là tên đối tượng hợp lệ “%s”"
 
-#: builtin/cat-file.c:573 git-submodule.sh:894
-msgid "blob"
-msgstr "blob"
+#: builtin/commit-tree.c:93
+#, c-format
+msgid "git commit-tree: failed to open '%s'"
+msgstr "git commit-tree: gặp lỗi khi mở “%s”"
 
-#: builtin/cat-file.c:574
-msgid "use a specific path for --textconv/--filters"
-msgstr "dùng một đường dẫn rõ ràng cho --textconv/--filters"
+#: builtin/commit-tree.c:96
+#, c-format
+msgid "git commit-tree: failed to read '%s'"
+msgstr "git commit-tree: gặp lỗi khi đọc “%s”"
 
-#: builtin/cat-file.c:576
-msgid "allow -s and -t to work with broken/corrupt objects"
-msgstr "cho phép -s và -t để làm việc với các đối tượng sai/hỏng"
+#: builtin/commit-tree.c:98
+#, c-format
+msgid "git commit-tree: failed to close '%s'"
+msgstr "git commit-tree: gặp lỗi khi đóng “%s”"
 
-#: builtin/cat-file.c:577
-msgid "buffer --batch output"
-msgstr "đệm kết xuất --batch"
+#: builtin/commit-tree.c:111
+msgid "parent"
+msgstr "cha-mẹ"
 
-#: builtin/cat-file.c:579
-msgid "show info and content of objects fed from the standard input"
-msgstr ""
-"hiển thị thông tin và nội dung của các đối tượng lấy từ đầu vào tiêu chuẩn"
+#: builtin/commit-tree.c:112
+msgid "id of a parent commit object"
+msgstr "mã số của đối tượng chuyển giao cha mẹ"
 
-#: builtin/cat-file.c:582
-msgid "show info about objects fed from the standard input"
-msgstr "hiển thị các thông tin về đối tượng fed  từ đầu vào tiêu chuẩn"
+#: builtin/commit-tree.c:114 builtin/commit.c:1496 builtin/merge.c:270
+#: builtin/notes.c:409 builtin/notes.c:575 builtin/stash.c:1469
+#: builtin/tag.c:412
+msgid "message"
+msgstr "chú thích"
 
-#: builtin/cat-file.c:585
-msgid "follow in-tree symlinks (used with --batch or --batch-check)"
-msgstr "theo liên kết mềm trong-cây (được dùng với --batch hay --batch-check)"
+#: builtin/commit-tree.c:115 builtin/commit.c:1496
+msgid "commit message"
+msgstr "chú thích của lần chuyển giao"
 
-#: builtin/cat-file.c:587
-msgid "show all objects with --batch or --batch-check"
-msgstr "hiển thị mọi đối tượng với --batch hay --batch-check"
+#: builtin/commit-tree.c:118
+msgid "read commit log message from file"
+msgstr "đọc chú thích nhật ký lần chuyển giao từ tập tin"
 
-#: builtin/check-attr.c:12
-msgid "git check-attr [-a | --all | <attr>...] [--] <pathname>..."
-msgstr "git check-attr [-a | --all | <attr>…] [--] tên-đường-dẫn…"
+#: builtin/commit-tree.c:121 builtin/commit.c:1508 builtin/merge.c:287
+#: builtin/pull.c:195 builtin/revert.c:118
+msgid "GPG sign commit"
+msgstr "Ký lần chuyển giao dùng GPG"
 
-#: builtin/check-attr.c:13
-msgid "git check-attr --stdin [-z] [-a | --all | <attr>...]"
-msgstr "git check-attr --stdin [-z] [-a | --all | <attr>…]"
+#: builtin/commit-tree.c:133
+msgid "must give exactly one tree"
+msgstr "phải đưa ra chính xác một cây"
 
-#: builtin/check-attr.c:20
-msgid "report all attributes set on file"
-msgstr "báo cáo tất cả các thuộc tính đặt trên tập tin"
+#: builtin/commit-tree.c:140
+msgid "git commit-tree: failed to read"
+msgstr "git commit-tree: gặp lỗi khi đọc"
 
-#: builtin/check-attr.c:21
-msgid "use .gitattributes only from the index"
-msgstr "chỉ dùng .gitattributes từ bảng mục lục"
+#: builtin/commit.c:41
+msgid "git commit [<options>] [--] <pathspec>..."
+msgstr "git commit [<các tùy chọn>] [--] <pathspec>…"
 
-#: builtin/check-attr.c:22 builtin/check-ignore.c:24 builtin/hash-object.c:100
-msgid "read file names from stdin"
-msgstr "đọc tên tập tin từ đầu vào tiêu chuẩn"
+#: builtin/commit.c:46
+msgid "git status [<options>] [--] <pathspec>..."
+msgstr "git status [<các tùy chọn>] [--] <pathspec>…"
 
-#: builtin/check-attr.c:24 builtin/check-ignore.c:26
-msgid "terminate input and output records by a NUL character"
-msgstr "chấm dứt các bản ghi vào và ra bằng ký tự NULL"
+#: builtin/commit.c:51
+msgid ""
+"You asked to amend the most recent commit, but doing so would make\n"
+"it empty. You can repeat your command with --allow-empty, or you can\n"
+"remove the commit entirely with \"git reset HEAD^\".\n"
+msgstr ""
+"Bạn đã yêu cầu amend (“tu bổ”) phần lớn các lần chuyển giao gần đây, nhưng "
+"làm như thế\n"
+"có thể làm cho nó trở nên trống rỗng. Bạn có thể lặp lại lệnh của mình bằng "
+"--allow-empty,\n"
+"hoặc là bạn gỡ bỏ các lần chuyển giao một cách hoàn toàn bằng lệnh:\n"
+"\"git reset HEAD^\".\n"
 
-#: builtin/check-ignore.c:20 builtin/checkout.c:1113 builtin/gc.c:500
-msgid "suppress progress reporting"
-msgstr "chặn các báo cáo tiến trình hoạt động"
+#: builtin/commit.c:56
+msgid ""
+"The previous cherry-pick is now empty, possibly due to conflict resolution.\n"
+"If you wish to commit it anyway, use:\n"
+"\n"
+"    git commit --allow-empty\n"
+"\n"
+msgstr ""
+"Lần cherry-pick trước hiện nay trống rỗng, có lẽ là bởi vì sự phân giải xung "
+"đột.\n"
+"Nếu bạn vẫn muốn chuyển giao nó cho dù thế nào đi nữa, hãy dùng:\n"
+"\n"
+"    git commit --allow-empty\n"
+"\n"
 
-#: builtin/check-ignore.c:28
-msgid "show non-matching input paths"
-msgstr "hiển thị những đường dẫn đầu vào không khớp với mẫu"
+#: builtin/commit.c:63
+msgid "Otherwise, please use 'git cherry-pick --skip'\n"
+msgstr "Nếu không được thì dùng lệnh \"git cherry-pick --skip\"\n"
 
-#: builtin/check-ignore.c:30
-msgid "ignore index when checking"
-msgstr "bỏ qua mục lục khi kiểm tra"
+#: builtin/commit.c:66
+msgid ""
+"and then use:\n"
+"\n"
+"    git cherry-pick --continue\n"
+"\n"
+"to resume cherry-picking the remaining commits.\n"
+"If you wish to skip this commit, use:\n"
+"\n"
+"    git cherry-pick --skip\n"
+"\n"
+msgstr ""
+"và sau đó dùng:\n"
+"\n"
+"    git cherry-pick --continue\n"
+"\n"
+"để lại tiếp tục cherry-picking các lần chuyển giao còn lại.\n"
+"Nếu bạn muốn bỏ qua lần chuyển giao này thì dùng:\n"
+"\n"
+"    git cherry-pick --skip\n"
+"\n"
 
-#: builtin/check-ignore.c:159
-msgid "cannot specify pathnames with --stdin"
-msgstr "không thể chỉ định các tên đường dẫn với --stdin"
+#: builtin/commit.c:315
+msgid "failed to unpack HEAD tree object"
+msgstr "gặp lỗi khi tháo dỡ HEAD đối tượng cây"
 
-#: builtin/check-ignore.c:162
-msgid "-z only makes sense with --stdin"
-msgstr "-z chỉ hợp lý với --stdin"
+#: builtin/commit.c:351
+#| msgid "paths '%s ...' with -a does not make sense"
+msgid "--pathspec-from-file with -a does not make sense"
+msgstr "--pathspec-from-file với -a là không có ý nghĩa gì"
 
-#: builtin/check-ignore.c:164
-msgid "no path specified"
-msgstr "chưa chỉ ra đường dẫn"
+#: builtin/commit.c:364
+msgid "No paths with --include/--only does not make sense."
+msgstr "Không đường dẫn với các tùy chọn --include/--only không hợp lý."
 
-#: builtin/check-ignore.c:168
-msgid "--quiet is only valid with a single pathname"
-msgstr "--quiet chỉ hợp lệ với tên đường dẫn đơn"
+#: builtin/commit.c:376
+msgid "unable to create temporary index"
+msgstr "không thể tạo bảng mục lục tạm thời"
 
-#: builtin/check-ignore.c:170
-msgid "cannot have both --quiet and --verbose"
-msgstr "không thể dùng cả hai tùy chọn --quiet và --verbose"
+#: builtin/commit.c:382
+msgid "interactive add failed"
+msgstr "gặp lỗi khi thêm bằng cách tương"
 
-#: builtin/check-ignore.c:173
-msgid "--non-matching is only valid with --verbose"
-msgstr "tùy-chọn --non-matching chỉ hợp lệ khi dùng với --verbose"
+#: builtin/commit.c:396
+msgid "unable to update temporary index"
+msgstr "không thể cập nhật bảng mục lục tạm thời"
 
-#: builtin/check-mailmap.c:9
-msgid "git check-mailmap [<options>] <contact>..."
-msgstr "git check-mailmap [<các-tùy-chọn>] <danh-bạ>…"
+#: builtin/commit.c:398
+msgid "Failed to update main cache tree"
+msgstr "Gặp lỗi khi cập nhật cây bộ nhớ đệm"
 
-#: builtin/check-mailmap.c:14
-msgid "also read contacts from stdin"
-msgstr "đồng thời đọc các danh bạ từ đầu vào tiêu chuẩn"
+#: builtin/commit.c:423 builtin/commit.c:446 builtin/commit.c:492
+msgid "unable to write new_index file"
+msgstr "không thể ghi tập tin lưu bảng mục lục mới (new_index)"
 
-#: builtin/check-mailmap.c:25
-#, c-format
-msgid "unable to parse contact: %s"
-msgstr "không thể phân tích danh bạ: “%s”"
+#: builtin/commit.c:475
+msgid "cannot do a partial commit during a merge."
+msgstr ""
+"không thể thực hiện việc chuyển giao cục bộ trong khi đang được hòa trộn."
 
-#: builtin/check-mailmap.c:48
-msgid "no contacts specified"
-msgstr "chưa chỉ ra danh bạ"
+#: builtin/commit.c:477
+msgid "cannot do a partial commit during a cherry-pick."
+msgstr ""
+"không thể thực hiện việc chuyển giao bộ phận trong khi đang cherry-pick."
 
-#: builtin/checkout-index.c:128
-msgid "git checkout-index [<options>] [--] [<file>...]"
-msgstr "git checkout-index [<các-tùy-chọn>] [--] [<tập-tin>…]"
+#: builtin/commit.c:485
+msgid "cannot read the index"
+msgstr "không đọc được bảng mục lục"
 
-#: builtin/checkout-index.c:143
-msgid "stage should be between 1 and 3 or all"
-msgstr "stage nên giữa 1 và 3 hay all"
+#: builtin/commit.c:504
+msgid "unable to write temporary index file"
+msgstr "không thể ghi tập tin lưu bảng mục lục tạm thời"
 
-#: builtin/checkout-index.c:159
-msgid "check out all files in the index"
-msgstr "lấy ra toàn bộ các tập tin trong bảng mục lục"
+#: builtin/commit.c:602
+#, c-format
+msgid "commit '%s' lacks author header"
+msgstr "lần chuyển giao “%s” thiếu phần tác giả ở đầu"
 
-#: builtin/checkout-index.c:160
-msgid "force overwrite of existing files"
-msgstr "ép buộc ghi đè lên tập tin đã sẵn có từ trước"
+#: builtin/commit.c:604
+#, c-format
+msgid "commit '%s' has malformed author line"
+msgstr "lần chuyển giao “%s” có phần tác giả ở đầu dị dạng"
 
-#: builtin/checkout-index.c:162
-msgid "no warning for existing files and files not in index"
+#: builtin/commit.c:623
+msgid "malformed --author parameter"
+msgstr "đối số cho --author bị dị hình"
+
+#: builtin/commit.c:676
+msgid ""
+"unable to select a comment character that is not used\n"
+"in the current commit message"
 msgstr ""
-"không cảnh báo cho những tập tin tồn tại và không có trong bảng mục lục"
+"không thể chọn một ký tự ghi chú cái mà không được dùng\n"
+"trong phần ghi chú hiện tại"
 
-#: builtin/checkout-index.c:164
-msgid "don't checkout new files"
-msgstr "không checkout các tập tin mới"
+#: builtin/commit.c:714 builtin/commit.c:747 builtin/commit.c:1092
+#, c-format
+msgid "could not lookup commit %s"
+msgstr "không thể tìm kiếm commit (lần chuyển giao) %s"
 
-#: builtin/checkout-index.c:166
-msgid "update stat information in the index file"
-msgstr "cập nhật thông tin thống kê trong tập tin lưu bảng mục lục mới"
+#: builtin/commit.c:726 builtin/shortlog.c:319
+#, c-format
+msgid "(reading log message from standard input)\n"
+msgstr "(đang đọc thông điệp nhật ký từ đầu vào tiêu chuẩn)\n"
 
-#: builtin/checkout-index.c:170
-msgid "read list of paths from the standard input"
-msgstr "đọc danh sách đường dẫn từ đầu vào tiêu chuẩn"
+#: builtin/commit.c:728
+msgid "could not read log from standard input"
+msgstr "không thể đọc nhật ký từ đầu vào tiêu chuẩn"
 
-#: builtin/checkout-index.c:172
-msgid "write the content to temporary files"
-msgstr "ghi nội dung vào tập tin tạm"
+#: builtin/commit.c:732
+#, c-format
+msgid "could not read log file '%s'"
+msgstr "không đọc được tệp nhật ký “%s”"
 
-#: builtin/checkout-index.c:173 builtin/column.c:31
-#: builtin/submodule--helper.c:1216 builtin/submodule--helper.c:1219
-#: builtin/submodule--helper.c:1227 builtin/submodule--helper.c:1591
-#: builtin/worktree.c:610
-msgid "string"
-msgstr "chuỗi"
+#: builtin/commit.c:763 builtin/commit.c:779
+msgid "could not read SQUASH_MSG"
+msgstr "không thể đọc SQUASH_MSG"
 
-#: builtin/checkout-index.c:174
-msgid "when creating files, prepend <string>"
-msgstr "khi tạo các tập tin, nối thêm <chuỗi>"
+#: builtin/commit.c:770
+msgid "could not read MERGE_MSG"
+msgstr "không thể đọc MERGE_MSG"
 
-#: builtin/checkout-index.c:176
-msgid "copy out the files from named stage"
-msgstr "sao chép ra các tập tin từ bệ phóng có tên"
+#: builtin/commit.c:830
+msgid "could not write commit template"
+msgstr "không thể ghi mẫu chuyển giao"
 
-#: builtin/checkout.c:27
-msgid "git checkout [<options>] <branch>"
-msgstr "git checkout [<các-tùy-chọn>] <nhánh>"
+#: builtin/commit.c:849
+#, c-format
+msgid ""
+"\n"
+"It looks like you may be committing a merge.\n"
+"If this is not correct, please remove the file\n"
+"\t%s\n"
+"and try again.\n"
+msgstr ""
+"\n"
+"Nó trông giống với việc bạn đang chuyển giao một lần hòa trộn.\n"
+"Nếu không phải vậy, xin hãy gỡ bỏ tập tin\n"
+"\t%s\n"
+"và thử lại.\n"
 
-#: builtin/checkout.c:28
-msgid "git checkout [<options>] [<branch>] -- <file>..."
-msgstr "git checkout [<các-tùy-chọn>] [<nhánh>] -- <tập-tin>…"
+#: builtin/commit.c:854
+#, c-format
+msgid ""
+"\n"
+"It looks like you may be committing a cherry-pick.\n"
+"If this is not correct, please remove the file\n"
+"\t%s\n"
+"and try again.\n"
+msgstr ""
+"\n"
+"Nó trông giống với việc bạn đang chuyển giao một lần cherry-pick.\n"
+"Nếu không phải vậy, xin hãy gỡ bỏ tập tin\n"
+"\t%s\n"
+"và thử lại.\n"
+
+#: builtin/commit.c:867
+#, c-format
+msgid ""
+"Please enter the commit message for your changes. Lines starting\n"
+"with '%c' will be ignored, and an empty message aborts the commit.\n"
+msgstr ""
+"Hãy nhập vào các thông tin để giải thích các thay đổi của bạn. Những dòng "
+"được\n"
+"bắt đầu bằng “%c” sẽ được bỏ qua, nếu phần chú thích rỗng sẽ hủy bỏ lần "
+"chuyển giao.\n"
+
+#: builtin/commit.c:875
+#, c-format
+msgid ""
+"Please enter the commit message for your changes. Lines starting\n"
+"with '%c' will be kept; you may remove them yourself if you want to.\n"
+"An empty message aborts the commit.\n"
+msgstr ""
+"Hãy nhập vào các thông tin để giải thích các thay đổi của bạn. Những dòng "
+"được\n"
+"bắt đầu bằng “%c” sẽ được bỏ qua; bạn có thể xóa chúng đi nếu muốn thế.\n"
+"Phần chú thích này nếu trống rỗng sẽ hủy bỏ lần chuyển giao.\n"
 
-#: builtin/checkout.c:136 builtin/checkout.c:169
+#: builtin/commit.c:892
 #, c-format
-msgid "path '%s' does not have our version"
-msgstr "đường dẫn “%s” không có các phiên bản của chúng ta"
+msgid "%sAuthor:    %.*s <%.*s>"
+msgstr "%sTác giả:           %.*s <%.*s>"
 
-#: builtin/checkout.c:138 builtin/checkout.c:171
+#: builtin/commit.c:900
 #, c-format
-msgid "path '%s' does not have their version"
-msgstr "đường dẫn “%s” không có các phiên bản của chúng"
+msgid "%sDate:      %s"
+msgstr "%sNgày tháng:        %s"
 
-#: builtin/checkout.c:154
+#: builtin/commit.c:907
 #, c-format
-msgid "path '%s' does not have all necessary versions"
-msgstr "đường dẫn “%s” không có tất cả các phiên bản cần thiết"
+msgid "%sCommitter: %.*s <%.*s>"
+msgstr "%sNgười chuyển giao: %.*s <%.*s>"
 
-#: builtin/checkout.c:198
-#, c-format
-msgid "path '%s' does not have necessary versions"
-msgstr "đường dẫn “%s” không có các phiên bản cần thiết"
+#: builtin/commit.c:925
+msgid "Cannot read index"
+msgstr "Không đọc được bảng mục lục"
 
-#: builtin/checkout.c:215
-#, c-format
-msgid "path '%s': cannot merge"
-msgstr "đường dẫn “%s”: không thể hòa trộn"
+#: builtin/commit.c:992
+msgid "Error building trees"
+msgstr "Gặp lỗi khi xây dựng cây"
 
-#: builtin/checkout.c:231
+#: builtin/commit.c:1006 builtin/tag.c:275
 #, c-format
-msgid "Unable to add merge result for '%s'"
-msgstr "Không thể thêm kết quả hòa trộn cho “%s”"
+msgid "Please supply the message using either -m or -F option.\n"
+msgstr "Xin hãy cung cấp lời chú giải hoặc là dùng tùy chọn -m hoặc là -F.\n"
 
-#: builtin/checkout.c:253 builtin/checkout.c:256 builtin/checkout.c:259
-#: builtin/checkout.c:262
+#: builtin/commit.c:1050
 #, c-format
-msgid "'%s' cannot be used with updating paths"
-msgstr "không được dùng “%s” với các đường dẫn cập nhật"
+msgid "--author '%s' is not 'Name <email>' and matches no existing author"
+msgstr ""
+"--author “%s” không phải là “Họ và tên <thư điện tửl>” và không khớp bất kỳ "
+"tác giả nào sẵn có"
 
-#: builtin/checkout.c:265 builtin/checkout.c:268
+#: builtin/commit.c:1064
 #, c-format
-msgid "'%s' cannot be used with %s"
-msgstr "không được dùng “%s” với %s"
+msgid "Invalid ignored mode '%s'"
+msgstr "Chế độ bỏ qua không hợp lệ “%s”"
 
-#: builtin/checkout.c:271
+#: builtin/commit.c:1082 builtin/commit.c:1322
 #, c-format
-msgid "Cannot update paths and switch to branch '%s' at the same time."
+msgid "Invalid untracked files mode '%s'"
+msgstr "Chế độ cho các tập tin chưa được theo dõi không hợp lệ “%s”"
+
+#: builtin/commit.c:1122
+msgid "--long and -z are incompatible"
+msgstr "hai tùy chọn -long và -z không tương thích với nhau"
+
+#: builtin/commit.c:1166
+msgid "Using both --reset-author and --author does not make sense"
+msgstr "Sử dụng cả hai tùy chọn --reset-author và --author không hợp lý"
+
+#: builtin/commit.c:1175
+msgid "You have nothing to amend."
+msgstr "Không có gì để mà “tu bổ” cả."
+
+#: builtin/commit.c:1178
+msgid "You are in the middle of a merge -- cannot amend."
 msgstr ""
-"Không thể cập nhật các đường dẫn và chuyển đến nhánh “%s” cùng một lúc."
+"Bạn đang ở giữa của quá trình hòa trộn -- không thể thực hiện việc “tu bổ”."
 
-#: builtin/checkout.c:340 builtin/checkout.c:347
-#, c-format
-msgid "path '%s' is unmerged"
-msgstr "đường dẫn “%s” không được hòa trộn"
+#: builtin/commit.c:1180
+msgid "You are in the middle of a cherry-pick -- cannot amend."
+msgstr ""
+"Bạn đang ở giữa của quá trình cherry-pick -- không thể thực hiện việc “tu "
+"bổ”."
 
-#: builtin/checkout.c:506
-msgid "you need to resolve your current index first"
-msgstr "bạn cần phải giải quyết bảng mục lục hiện tại của bạn trước đã"
+#: builtin/commit.c:1183
+msgid "Options --squash and --fixup cannot be used together"
+msgstr "Các tùy chọn --squash và --fixup không thể sử dụng cùng với nhau"
 
-#: builtin/checkout.c:643
-#, c-format
-msgid "Can not do reflog for '%s': %s\n"
-msgstr "Không thể thực hiện reflog cho “%s”: %s\n"
+#: builtin/commit.c:1193
+msgid "Only one of -c/-C/-F/--fixup can be used."
+msgstr "Chỉ được dùng một trong số tùy chọn trong số -c/-C/-F/--fixup."
 
-#: builtin/checkout.c:684
-msgid "HEAD is now at"
-msgstr "HEAD hiện giờ tại"
+#: builtin/commit.c:1195
+msgid "Option -m cannot be combined with -c/-C/-F."
+msgstr "Tùy chọn -m không thể được tổ hợp cùng với -c/-C/-F."
 
-#: builtin/checkout.c:688 builtin/clone.c:691
-msgid "unable to update HEAD"
-msgstr "không thể cập nhật HEAD"
+#: builtin/commit.c:1203
+msgid "--reset-author can be used only with -C, -c or --amend."
+msgstr ""
+"--reset-author chỉ có thể được sử dụng với tùy chọn -C, -c hay --amend."
 
-#: builtin/checkout.c:692
-#, c-format
-msgid "Reset branch '%s'\n"
-msgstr "Đặt lại nhánh “%s”\n"
+#: builtin/commit.c:1220
+msgid "Only one of --include/--only/--all/--interactive/--patch can be used."
+msgstr ""
+"Chỉ một trong các tùy chọn --include/--only/--all/--interactive/--patch được "
+"sử dụng."
 
-#: builtin/checkout.c:695
+#: builtin/commit.c:1226
 #, c-format
-msgid "Already on '%s'\n"
-msgstr "Đã sẵn sàng trên “%s”\n"
+msgid "paths '%s ...' with -a does not make sense"
+msgstr "các đường dẫn “%s …” với tùy chọn -a không hợp lý"
 
-#: builtin/checkout.c:699
-#, c-format
-msgid "Switched to and reset branch '%s'\n"
-msgstr "Đã chuyển tới và đặt lại nhánh “%s”\n"
+#: builtin/commit.c:1357 builtin/commit.c:1519
+msgid "show status concisely"
+msgstr "hiển thị trạng thái ở dạng súc tích"
 
-#: builtin/checkout.c:701 builtin/checkout.c:1046
-#, c-format
-msgid "Switched to a new branch '%s'\n"
-msgstr "Đã chuyển đến nhánh mới “%s”\n"
+#: builtin/commit.c:1359 builtin/commit.c:1521
+msgid "show branch information"
+msgstr "hiển thị thông tin nhánh"
 
-#: builtin/checkout.c:703
-#, c-format
-msgid "Switched to branch '%s'\n"
-msgstr "Đã chuyển đến nhánh “%s”\n"
+#: builtin/commit.c:1361
+msgid "show stash information"
+msgstr "hiển thị thông tin về tạm cất"
 
-#: builtin/checkout.c:754
-#, c-format
-msgid " ... and %d more.\n"
-msgstr " … và nhiều hơn %d.\n"
+#: builtin/commit.c:1363 builtin/commit.c:1523
+msgid "compute full ahead/behind values"
+msgstr "tính đầy đủ giá trị trước/sau"
 
-#: builtin/checkout.c:760
-#, c-format
+#: builtin/commit.c:1365
+msgid "version"
+msgstr "phiên bản"
+
+#: builtin/commit.c:1365 builtin/commit.c:1525 builtin/push.c:549
+#: builtin/worktree.c:650
+msgid "machine-readable output"
+msgstr "kết xuất dạng máy-có-thể-đọc"
+
+#: builtin/commit.c:1368 builtin/commit.c:1527
+msgid "show status in long format (default)"
+msgstr "hiển thị trạng thái ở định dạng dài (mặc định)"
+
+#: builtin/commit.c:1371 builtin/commit.c:1530
+msgid "terminate entries with NUL"
+msgstr "chấm dứt các mục bằng NUL"
+
+#: builtin/commit.c:1373 builtin/commit.c:1377 builtin/commit.c:1533
+#: builtin/fast-export.c:1153 builtin/fast-export.c:1156
+#: builtin/fast-export.c:1159 builtin/rebase.c:1525 parse-options.h:336
+msgid "mode"
+msgstr "chế độ"
+
+#: builtin/commit.c:1374 builtin/commit.c:1533
+msgid "show untracked files, optional modes: all, normal, no. (Default: all)"
+msgstr ""
+"hiển thị các tập tin chưa được theo dõi  dấu vết, các chế độ tùy chọn:  all, "
+"normal, no. (Mặc định: all)"
+
+#: builtin/commit.c:1378
 msgid ""
-"Warning: you are leaving %d commit behind, not connected to\n"
-"any of your branches:\n"
-"\n"
-"%s\n"
-msgid_plural ""
-"Warning: you are leaving %d commits behind, not connected to\n"
-"any of your branches:\n"
-"\n"
-"%s\n"
-msgstr[0] ""
-"Cảnh báo: bạn đã rời bỏ %d lần chuyển giao lại đằng sau, không được kết nối "
-"đến\n"
-"bất kỳ nhánh nào của bạn:\n"
-"\n"
-"%s\n"
+"show ignored files, optional modes: traditional, matching, no. (Default: "
+"traditional)"
+msgstr ""
+"hiển thị các tập tin bị bỏ qua, các chế độ tùy chọn: traditional, matching, "
+"no. (Mặc định: traditional)"
 
-#: builtin/checkout.c:779
-#, c-format
+#: builtin/commit.c:1380 parse-options.h:192
+msgid "when"
+msgstr "khi"
+
+#: builtin/commit.c:1381
 msgid ""
-"If you want to keep it by creating a new branch, this may be a good time\n"
-"to do so with:\n"
-"\n"
-" git branch <new-branch-name> %s\n"
-"\n"
-msgid_plural ""
-"If you want to keep them by creating a new branch, this may be a good time\n"
-"to do so with:\n"
-"\n"
-" git branch <new-branch-name> %s\n"
-"\n"
-msgstr[0] ""
-"Nếu bạn muốn giữ (chúng) nó bằng cách tạo ra một nhánh mới, đây có lẽ là\n"
-"một thời điểm thích hợp để làm thế bằng lệnh:\n"
-"\n"
-" git branch <tên_nhánh_mới> %s\n"
-"\n"
+"ignore changes to submodules, optional when: all, dirty, untracked. "
+"(Default: all)"
+msgstr ""
+"bỏ qua các thay đổi trong mô-đun-con, tùy chọn khi: all, dirty, untracked. "
+"(Mặc định: all)"
 
-#: builtin/checkout.c:811
-msgid "internal error in revision walk"
-msgstr "lỗi nội bộ trong khi di chuyển qua các điểm xét duyệt"
+#: builtin/commit.c:1383
+msgid "list untracked files in columns"
+msgstr "hiển thị danh sách các tập-tin chưa được theo dõi trong các cột"
 
-#: builtin/checkout.c:815
-msgid "Previous HEAD position was"
-msgstr "Vị trí trước kia của HEAD là"
+#: builtin/commit.c:1384
+msgid "do not detect renames"
+msgstr "không dò tìm các tên thay đổi"
 
-#: builtin/checkout.c:843 builtin/checkout.c:1041
-msgid "You are on a branch yet to be born"
-msgstr "Bạn tại nhánh mà nó chưa hề được sinh ra"
+#: builtin/commit.c:1386
+msgid "detect renames, optionally set similarity index"
+msgstr "dò các tên thay đổi, tùy ý đặt mục lục tương tự"
 
-#: builtin/checkout.c:947
-#, c-format
-msgid "only one reference expected, %d given."
-msgstr "chỉ cần một tham chiếu, nhưng lại đưa ra %d."
+#: builtin/commit.c:1406
+msgid "Unsupported combination of ignored and untracked-files arguments"
+msgstr ""
+"Không hỗ trỡ tổ hợp các tham số các tập tin bị bỏ qua và không được theo dõi"
 
-#: builtin/checkout.c:987 builtin/worktree.c:240 builtin/worktree.c:389
-#, c-format
-msgid "invalid reference: %s"
-msgstr "tham chiếu không hợp lệ: %s"
+#: builtin/commit.c:1489
+msgid "suppress summary after successful commit"
+msgstr "không hiển thị tổng kết sau khi chuyển giao thành công"
 
-#: builtin/checkout.c:1016
-#, c-format
-msgid "reference is not a tree: %s"
-msgstr "tham chiếu không phải là một cây:%s"
+#: builtin/commit.c:1490
+msgid "show diff in commit message template"
+msgstr "hiển thị sự khác biệt trong mẫu tin nhắn chuyển giao"
 
-#: builtin/checkout.c:1055
-msgid "paths cannot be used with switching branches"
-msgstr "các đường dẫn không thể dùng cùng với các nhánh chuyển"
+#: builtin/commit.c:1492
+msgid "Commit message options"
+msgstr "Các tùy chọn ghi chú commit"
 
-#: builtin/checkout.c:1058 builtin/checkout.c:1062
-#, c-format
-msgid "'%s' cannot be used with switching branches"
-msgstr "“%s” không thể được sử dụng với các nhánh chuyển"
+#: builtin/commit.c:1493 builtin/merge.c:274 builtin/tag.c:414
+msgid "read message from file"
+msgstr "đọc chú thích từ tập tin"
 
-#: builtin/checkout.c:1066 builtin/checkout.c:1069 builtin/checkout.c:1074
-#: builtin/checkout.c:1077
-#, c-format
-msgid "'%s' cannot be used with '%s'"
-msgstr "“%s” không thể được dùng với “%s”"
+#: builtin/commit.c:1494
+msgid "author"
+msgstr "tác giả"
 
-#: builtin/checkout.c:1082
-#, c-format
-msgid "Cannot switch branch to a non-commit '%s'"
-msgstr "Không thể chuyển nhánh đến một thứ không phải là lần chuyển giao “%s”"
+#: builtin/commit.c:1494
+msgid "override author for commit"
+msgstr "ghi đè tác giả cho commit"
 
-#: builtin/checkout.c:1114 builtin/checkout.c:1116 builtin/clone.c:118
-#: builtin/remote.c:167 builtin/remote.c:169 builtin/worktree.c:433
-#: builtin/worktree.c:435
-msgid "branch"
-msgstr "nhánh"
+#: builtin/commit.c:1495 builtin/gc.c:538
+msgid "date"
+msgstr "ngày tháng"
 
-#: builtin/checkout.c:1115
-msgid "create and checkout a new branch"
-msgstr "tạo và checkout một nhánh mới"
+#: builtin/commit.c:1495
+msgid "override date for commit"
+msgstr "ghi đè ngày tháng cho lần chuyển giao"
 
-#: builtin/checkout.c:1117
-msgid "create/reset and checkout a branch"
-msgstr "tạo/đặt_lại và checkout một nhánh"
+#: builtin/commit.c:1497 builtin/commit.c:1498 builtin/commit.c:1499
+#: builtin/commit.c:1500 parse-options.h:328 ref-filter.h:92
+msgid "commit"
+msgstr "lần_chuyển_giao"
+
+#: builtin/commit.c:1497
+msgid "reuse and edit message from specified commit"
+msgstr "dùng lại các ghi chú từ lần chuyển giao đã cho nhưng có cho sửa chữa"
+
+#: builtin/commit.c:1498
+msgid "reuse message from specified commit"
+msgstr "dùng lại các ghi chú từ lần chuyển giao đã cho"
+
+#: builtin/commit.c:1499
+msgid "use autosquash formatted message to fixup specified commit"
+msgstr ""
+"dùng ghi chú có định dạng autosquash để sửa chữa lần chuyển giao đã chỉ ra"
+
+#: builtin/commit.c:1500
+msgid "use autosquash formatted message to squash specified commit"
+msgstr ""
+"dùng lời nhắn có định dạng tự động nén để nén lại các lần chuyển giao đã chỉ "
+"ra"
+
+#: builtin/commit.c:1501
+msgid "the commit is authored by me now (used with -C/-c/--amend)"
+msgstr ""
+"lần chuyển giao nhận tôi là tác giả (được dùng với tùy chọn -C/-c/--amend)"
 
-#: builtin/checkout.c:1118
-msgid "create reflog for new branch"
-msgstr "tạo reflog cho nhánh mới"
+#: builtin/commit.c:1502 builtin/log.c:1634 builtin/merge.c:289
+#: builtin/pull.c:164 builtin/revert.c:110
+msgid "add Signed-off-by:"
+msgstr "(nên dùng) thêm dòng Signed-off-by:"
 
-#: builtin/checkout.c:1119 builtin/worktree.c:437
-msgid "detach HEAD at named commit"
-msgstr "rời bỏ HEAD tại lần chuyển giao theo tên"
+#: builtin/commit.c:1503
+msgid "use specified template file"
+msgstr "sử dụng tập tin mẫu đã cho"
 
-#: builtin/checkout.c:1120
-msgid "set upstream info for new branch"
-msgstr "đặt thông tin thượng nguồn cho nhánh mới"
+#: builtin/commit.c:1504
+msgid "force edit of commit"
+msgstr "ép buộc sửa lần commit"
 
-#: builtin/checkout.c:1122
-msgid "new-branch"
-msgstr "nhánh-mới"
+#: builtin/commit.c:1506
+msgid "include status in commit message template"
+msgstr "bao gồm các trạng thái trong mẫu ghi chú chuyển giao"
 
-#: builtin/checkout.c:1122
-msgid "new unparented branch"
-msgstr "nhánh không cha mới"
+#: builtin/commit.c:1511
+msgid "Commit contents options"
+msgstr "Các tùy nội dung ghi chú commit"
 
-#: builtin/checkout.c:1123
-msgid "checkout our version for unmerged files"
-msgstr ""
-"lấy ra (checkout) phiên bản của chúng ta cho các tập tin chưa được hòa trộn"
+#: builtin/commit.c:1512
+msgid "commit all changed files"
+msgstr "chuyển giao tất cả các tập tin có thay đổi"
 
-#: builtin/checkout.c:1125
-msgid "checkout their version for unmerged files"
-msgstr ""
-"lấy ra (checkout) phiên bản của chúng họ cho các tập tin chưa được hòa trộn"
+#: builtin/commit.c:1513
+msgid "add specified files to index for commit"
+msgstr "thêm các tập tin đã chỉ ra vào bảng mục lục để chuyển giao"
 
-#: builtin/checkout.c:1127
-msgid "force checkout (throw away local modifications)"
-msgstr "ép buộc lấy ra (bỏ đi những thay đổi nội bộ)"
+#: builtin/commit.c:1514
+msgid "interactively add files"
+msgstr "thêm các tập-tin bằng tương tác"
 
-#: builtin/checkout.c:1129
-msgid "perform a 3-way merge with the new branch"
-msgstr "thực hiện hòa trộn kiểu 3-way với nhánh mới"
+#: builtin/commit.c:1515
+msgid "interactively add changes"
+msgstr "thêm các thay đổi bằng tương tác"
 
-#: builtin/checkout.c:1131 builtin/merge.c:241
-msgid "update ignored files (default)"
-msgstr "cập nhật các tập tin bị bỏ qua (mặc định)"
+#: builtin/commit.c:1516
+msgid "commit only specified files"
+msgstr "chỉ chuyển giao các tập tin đã chỉ ra"
 
-#: builtin/checkout.c:1133 builtin/log.c:1499 parse-options.h:264
-msgid "style"
-msgstr "kiểu"
+#: builtin/commit.c:1517
+msgid "bypass pre-commit and commit-msg hooks"
+msgstr "vòng qua móc (hook) pre-commit và commit-msg"
 
-#: builtin/checkout.c:1134
-msgid "conflict style (merge or diff3)"
-msgstr "xung đột kiểu (hòa trộn hoặc diff3)"
+#: builtin/commit.c:1518
+msgid "show what would be committed"
+msgstr "hiển thị xem cái gì có thể được chuyển giao"
 
-#: builtin/checkout.c:1137
-msgid "do not limit pathspecs to sparse entries only"
-msgstr "không giới hạn đặc tả đường dẫn thành chỉ các mục thưa thớt"
+#: builtin/commit.c:1531
+msgid "amend previous commit"
+msgstr "“tu bổ” (amend) lần commit trước"
 
-#: builtin/checkout.c:1139
-msgid "second guess 'git checkout <no-such-branch>'"
-msgstr "gợi ý thứ hai \"git checkout <không-nhánh-nào-như-vậy>\""
+#: builtin/commit.c:1532
+msgid "bypass post-rewrite hook"
+msgstr "vòng qua móc (hook) post-rewrite"
 
-#: builtin/checkout.c:1141
-msgid "do not check if another worktree is holding the given ref"
-msgstr "không kiểm tra nếu cây làm việc khác đang giữ tham chiếu đã cho"
+#: builtin/commit.c:1539
+msgid "ok to record an empty change"
+msgstr "ok để ghi lại một thay đổi trống rỗng"
 
-#: builtin/checkout.c:1145 builtin/clone.c:85 builtin/fetch.c:149
-#: builtin/merge.c:238 builtin/pull.c:128 builtin/push.c:572
-#: builtin/send-pack.c:174
-msgid "force progress reporting"
-msgstr "ép buộc báo cáo tiến triển công việc"
+#: builtin/commit.c:1541
+msgid "ok to record a change with an empty message"
+msgstr "ok để ghi các thay đổi với lời nhắn trống rỗng"
 
-#: builtin/checkout.c:1175
-msgid "-b, -B and --orphan are mutually exclusive"
-msgstr "Các tùy chọn -b, -B và --orphan loại từ lẫn nhau"
+#: builtin/commit.c:1614
+#, c-format
+msgid "Corrupt MERGE_HEAD file (%s)"
+msgstr "Tập tin MERGE_HEAD sai hỏng (%s)"
 
-#: builtin/checkout.c:1192
-msgid "--track needs a branch name"
-msgstr "--track cần tên một nhánh"
+#: builtin/commit.c:1621
+msgid "could not read MERGE_MODE"
+msgstr "không thể đọc MERGE_MODE"
 
-#: builtin/checkout.c:1197
-msgid "Missing branch name; try -b"
-msgstr "Thiếu tên nhánh; hãy thử -b"
+#: builtin/commit.c:1640
+#, c-format
+msgid "could not read commit message: %s"
+msgstr "không thể đọc phần chú thích (message) của lần chuyển giao: %s"
 
-#: builtin/checkout.c:1233
-msgid "invalid path specification"
-msgstr "đường dẫn đã cho không hợp lệ"
+#: builtin/commit.c:1647
+#, c-format
+msgid "Aborting commit due to empty commit message.\n"
+msgstr "Bãi bỏ việc chuyển giao bởi vì phần chú thích của nó trống rỗng.\n"
 
-#: builtin/checkout.c:1240
+#: builtin/commit.c:1652
 #, c-format
-msgid "'%s' is not a commit and a branch '%s' cannot be created from it"
+msgid "Aborting commit; you did not edit the message.\n"
 msgstr ""
-"“%s” không phải là một lần chuyển giao và một nhánh'%s” không thể được tạo "
-"từ đó"
+"Đang bỏ qua việc chuyển giao; bạn đã không biên soạn phần chú thích "
+"(message).\n"
 
-#: builtin/checkout.c:1244
-#, c-format
-msgid "git checkout: --detach does not take a path argument '%s'"
-msgstr "git checkout: --detach không nhận một đối số đường dẫn “%s”"
+#: builtin/commit.c:1686
+msgid ""
+"repository has been updated, but unable to write\n"
+"new_index file. Check that disk is not full and quota is\n"
+"not exceeded, and then \"git restore --staged :/\" to recover."
+msgstr ""
+"kho chứa đã được cập nhật, nhưng không thể ghi vào\n"
+"tập tin new_index (bảng mục lục mới). Hãy kiểm tra xem đĩa\n"
+"có bị đầy quá hay quota (hạn nghạch đĩa cứng) bị vượt quá,\n"
+"và sau đó \"git restore --staged :/\" để khắc phục."
 
-#: builtin/checkout.c:1248
+#: builtin/commit-graph.c:11 builtin/commit-graph.c:17
 msgid ""
-"git checkout: --ours/--theirs, --force and --merge are incompatible when\n"
-"checking out of the index."
+"git commit-graph verify [--object-dir <objdir>] [--shallow] [--[no-]progress]"
 msgstr ""
-"git checkout: --ours/--theirs, --force và --merge là xung khắc với nhau khi\n"
-"checkout bảng mục lục (index)."
+"git commit-graph verify [--object-dir </thư/mục/đối/tượng>] [--shallow] [--"
+"[no-]progress]"
 
-#: builtin/clean.c:26
+#: builtin/commit-graph.c:12 builtin/commit-graph.c:22
 msgid ""
-"git clean [-d] [-f] [-i] [-n] [-q] [-e <pattern>] [-x | -X] [--] <paths>..."
+"git commit-graph write [--object-dir <objdir>] [--append|--split] [--"
+"reachable|--stdin-packs|--stdin-commits] [--[no-]progress] <split options>"
 msgstr ""
-"git clean [-d] [-f] [-i] [-n] [-q] [-e <mẫu>] [-x | -X] [--] <đường-dẫn>…"
+"git commit-graph write [--object-dir </thư/mục/đối/tượng>] [--append|--"
+"split] [--reachable|--stdin-packs|--stdin-commits] [--[no-]progress] <các "
+"tùy chọn chia tách>"
 
-#: builtin/clean.c:30
-#, c-format
-msgid "Removing %s\n"
-msgstr "Đang gỡ bỏ %s\n"
+#: builtin/commit-graph.c:48 builtin/commit-graph.c:103
+#: builtin/commit-graph.c:187 builtin/fetch.c:179 builtin/log.c:1657
+msgid "dir"
+msgstr "tmục"
 
-#: builtin/clean.c:31
-#, c-format
-msgid "Would remove %s\n"
-msgstr "Có thể gỡ bỏ %s\n"
+#: builtin/commit-graph.c:49 builtin/commit-graph.c:104
+#: builtin/commit-graph.c:188
+msgid "The object directory to store the graph"
+msgstr "Thư mục đối tượng để lưu đồ thị"
 
-#: builtin/clean.c:32
-#, c-format
-msgid "Skipping repository %s\n"
-msgstr "Đang bỏ qua kho chứa %s\n"
+#: builtin/commit-graph.c:51
+msgid "if the commit-graph is split, only verify the tip file"
+msgstr ""
+"nếu đồ-thị-các-lần-chuyển-giao bị chia cắt, thì chỉ thẩm tra tập tin đỉnh"
 
-#: builtin/clean.c:33
+#: builtin/commit-graph.c:73 t/helper/test-read-graph.c:23
 #, c-format
-msgid "Would skip repository %s\n"
-msgstr "Nên bỏ qua kho chứa %s\n"
+msgid "Could not open commit-graph '%s'"
+msgstr "Không thể mở đồ thị chuyển giao “%s”"
 
-#: builtin/clean.c:34
-#, c-format
-msgid "failed to remove %s"
-msgstr "gặp lỗi khi gỡ bỏ %s"
+#: builtin/commit-graph.c:106
+msgid "start walk at all refs"
+msgstr "bắt đầu di chuyển tại mọi tham chiếu"
 
-#: builtin/clean.c:302 git-add--interactive.perl:579
-#, c-format
-msgid ""
-"Prompt help:\n"
-"1          - select a numbered item\n"
-"foo        - select item based on unique prefix\n"
-"           - (empty) select nothing\n"
+#: builtin/commit-graph.c:108
+msgid "scan pack-indexes listed by stdin for commits"
 msgstr ""
-"Trợ giúp về nhắc:\n"
-"1          - chọn một mục được đánh số\n"
-"foo        - chọn mục trên cơ sở tiền tố duy nhất\n"
-"           - (để trống) không chọn gì cả\n"
+"quét dó các mục lục gói được liệt kê bởi đầu vào tiêu chuẩn cho các lần "
+"chuyển giao"
 
-#: builtin/clean.c:306 git-add--interactive.perl:588
-#, c-format
-msgid ""
-"Prompt help:\n"
-"1          - select a single item\n"
-"3-5        - select a range of items\n"
-"2-3,6-9    - select multiple ranges\n"
-"foo        - select item based on unique prefix\n"
-"-...       - unselect specified items\n"
-"*          - choose all items\n"
-"           - (empty) finish selecting\n"
+#: builtin/commit-graph.c:110
+msgid "start walk at commits listed by stdin"
 msgstr ""
-"Trợ giúp về nhắc:\n"
-"1          - chọn một mục đơn\n"
-"3-5        - chọn một vùng\n"
-"2-3,6-9    - chọn nhiều vùng\n"
-"foo        - chọn mục dựa trên tiền tố duy nhất\n"
-"-…         - không chọn các mục đã chỉ ra\n"
-"*          - chọn tất\n"
-"           - (để trống) kết thúc việc chọn\n"
+"bắt đầu di chuyển tại các lần chuyển giao được liệt kê bởi đầu vào tiêu chuẩn"
 
-#: builtin/clean.c:522 git-add--interactive.perl:554
-#: git-add--interactive.perl:559
-#, c-format, perl-format
-msgid "Huh (%s)?\n"
-msgstr "Hả (%s)?\n"
+#: builtin/commit-graph.c:112
+msgid "include all commits already in the commit-graph file"
+msgstr ""
+"bao gồm mọi lần chuyển giao đã sẵn có trongười tập tin đồ-thị-các-lần-chuyển-"
+"giao"
 
-#: builtin/clean.c:664
-#, c-format
-msgid "Input ignore patterns>> "
-msgstr "Mẫu để lọc các tập tin đầu vào cần lờ đi>> "
+#: builtin/commit-graph.c:115
+msgid "allow writing an incremental commit-graph file"
+msgstr "cho phép ghi một tập tin đồ họa các lần chuyển giao lớn lên"
 
-#: builtin/clean.c:701
-#, c-format
-msgid "WARNING: Cannot find items matched by: %s"
-msgstr "CẢNH BÁO: Không tìm thấy các mục được khớp bởi: %s"
+#: builtin/commit-graph.c:117 builtin/commit-graph.c:121
+msgid "maximum number of commits in a non-base split commit-graph"
+msgstr ""
+"số lượng tối đa của các lần chuyển giao trong một đồ-thị-các-lần-chuyển-giao "
+"chia cắt không-cơ-sở"
 
-#: builtin/clean.c:722
-msgid "Select items to delete"
-msgstr "Chọn mục muốn xóa"
+#: builtin/commit-graph.c:119
+msgid "maximum ratio between two levels of a split commit-graph"
+msgstr "tỷ lệ tối đa giữa hai mức của một đồ-thị-các-lần-chuyển-giao chia cắt"
 
-#. TRANSLATORS: Make sure to keep [y/N] as is
-#: builtin/clean.c:763
-#, c-format
-msgid "Remove %s [y/N]? "
-msgstr "Xóa bỏ “%s” [y/N]? "
+#: builtin/commit-graph.c:137
+msgid "use at most one of --reachable, --stdin-commits, or --stdin-packs"
+msgstr ""
+"không thể sử dụng hơn một --reachable, --stdin-commits, hay --stdin-packs"
+
+#: builtin/config.c:11
+msgid "git config [<options>]"
+msgstr "git config [<các tùy chọn>]"
 
-#: builtin/clean.c:788 git-add--interactive.perl:1717
+#: builtin/config.c:103 builtin/env--helper.c:23
 #, c-format
-msgid "Bye.\n"
-msgstr "Tạm biệt.\n"
+msgid "unrecognized --type argument, %s"
+msgstr "đối số không được thừa nhận --type, %s"
 
-#: builtin/clean.c:796
-msgid ""
-"clean               - start cleaning\n"
-"filter by pattern   - exclude items from deletion\n"
-"select by numbers   - select items to be deleted by numbers\n"
-"ask each            - confirm each deletion (like \"rm -i\")\n"
-"quit                - stop cleaning\n"
-"help                - this screen\n"
-"?                   - help for prompt selection"
-msgstr ""
-"clean               - bắt đầu dọn dẹp\n"
-"filter by pattern   - loại trừ các mục khỏi việc xóa\n"
-"select by numbers   - chọn các mục cần xóa bằng số\n"
-"ask each            - xác nhận trước mỗi lần xóa (giống như \"rm -i\")\n"
-"quit                - dừng việc dọn dẹp lại\n"
-"help                - hiển thị chính trợ giúp này\n"
-"?                   - trợ giúp dành cho chọn bằng cách nhắc"
+#: builtin/config.c:115
+msgid "only one type at a time"
+msgstr "chỉ một kiểu một lần"
 
-#: builtin/clean.c:823 git-add--interactive.perl:1793
-msgid "*** Commands ***"
-msgstr "*** Lệnh ***"
+#: builtin/config.c:124
+msgid "Config file location"
+msgstr "Vị trí tập tin cấu hình"
 
-#: builtin/clean.c:824 git-add--interactive.perl:1790
-msgid "What now"
-msgstr "Giờ thì sao"
+#: builtin/config.c:125
+msgid "use global config file"
+msgstr "dùng tập tin cấu hình toàn cục"
 
-#: builtin/clean.c:832
-msgid "Would remove the following item:"
-msgid_plural "Would remove the following items:"
-msgstr[0] "Có muốn gỡ bỏ (các) mục sau đây không:"
+#: builtin/config.c:126
+msgid "use system config file"
+msgstr "sử dụng tập tin cấu hình hệ thống"
 
-#: builtin/clean.c:848
-msgid "No more files to clean, exiting."
-msgstr "Không còn tập-tin nào để dọn dẹp, đang thoát ra."
+#: builtin/config.c:127
+msgid "use repository config file"
+msgstr "dùng tập tin cấu hình của kho"
 
-#: builtin/clean.c:910
-msgid "do not print names of files removed"
-msgstr "không hiển thị tên của các tập tin đã gỡ bỏ"
+#: builtin/config.c:128
+msgid "use per-worktree config file"
+msgstr "dùng tập tin cấu hình per-worktree"
 
-#: builtin/clean.c:912
-msgid "force"
-msgstr "ép buộc"
+#: builtin/config.c:129
+msgid "use given config file"
+msgstr "sử dụng tập tin cấu hình đã cho"
 
-#: builtin/clean.c:913
-msgid "interactive cleaning"
-msgstr "dọn bằng kiểu tương tác"
+#: builtin/config.c:130
+msgid "blob-id"
+msgstr "blob-id"
 
-#: builtin/clean.c:915
-msgid "remove whole directories"
-msgstr "gỡ bỏ toàn bộ thư mục"
+#: builtin/config.c:130
+msgid "read config from given blob object"
+msgstr "đọc cấu hình từ đối tượng blob đã cho"
 
-#: builtin/clean.c:916 builtin/describe.c:533 builtin/describe.c:535
-#: builtin/grep.c:871 builtin/log.c:157 builtin/log.c:159
-#: builtin/ls-files.c:548 builtin/name-rev.c:397 builtin/name-rev.c:399
-#: builtin/show-ref.c:176
-msgid "pattern"
-msgstr "mẫu"
+#: builtin/config.c:131
+msgid "Action"
+msgstr "Hành động"
+
+#: builtin/config.c:132
+msgid "get value: name [value-regex]"
+msgstr "lấy giá-trị: tên [value-regex]"
+
+#: builtin/config.c:133
+msgid "get all values: key [value-regex]"
+msgstr "lấy tất cả giá-trị: khóa [value-regex]"
+
+#: builtin/config.c:134
+msgid "get values for regexp: name-regex [value-regex]"
+msgstr "lấy giá trị cho regexp: name-regex [value-regex]"
 
-#: builtin/clean.c:917
-msgid "add <pattern> to ignore rules"
-msgstr "thêm <mẫu> vào trong qui tắc bỏ qua"
+#: builtin/config.c:135
+msgid "get value specific for the URL: section[.var] URL"
+msgstr "lấy đặc tả giá trị cho URL: phần[.biến] URL"
 
-#: builtin/clean.c:918
-msgid "remove ignored files, too"
-msgstr "đồng thời gỡ bỏ cả các tập tin bị bỏ qua"
+#: builtin/config.c:136
+msgid "replace all matching variables: name value [value_regex]"
+msgstr "thay thế tất cả các biến khớp mẫu: tên giá-trị [value_regex]"
 
-#: builtin/clean.c:920
-msgid "remove only ignored files"
-msgstr "chỉ gỡ bỏ những tập tin bị bỏ qua"
+#: builtin/config.c:137
+msgid "add a new variable: name value"
+msgstr "thêm biến mới: tên giá-trị"
 
-#: builtin/clean.c:938
-msgid "-x and -X cannot be used together"
-msgstr "-x và -X không thể dùng cùng nhau"
+#: builtin/config.c:138
+msgid "remove a variable: name [value-regex]"
+msgstr "gỡ bỏ biến: tên [value-regex]"
 
-#: builtin/clean.c:942
-msgid ""
-"clean.requireForce set to true and neither -i, -n, nor -f given; refusing to "
-"clean"
-msgstr ""
-"clean.requireForce được đặt thành true và không đưa ra tùy chọn -i, -n mà "
-"cũng không -f; từ chối lệnh dọn dẹp (clean)"
+#: builtin/config.c:139
+msgid "remove all matches: name [value-regex]"
+msgstr "gỡ bỏ mọi cái khớp: tên [value-regex]"
 
-#: builtin/clean.c:945
-msgid ""
-"clean.requireForce defaults to true and neither -i, -n, nor -f given; "
-"refusing to clean"
-msgstr ""
-"clean.requireForce mặc định được đặt là true và không đưa ra tùy chọn -i, -n "
-"mà cũng không -f; từ chối lệnh dọn dẹp (clean)"
+#: builtin/config.c:140
+msgid "rename section: old-name new-name"
+msgstr "đổi tên phần: tên-cũ tên-mới"
 
-#: builtin/clone.c:42
-msgid "git clone [<options>] [--] <repo> [<dir>]"
-msgstr "git clone [<các-tùy-chọn>] [--] <kho> [<t.mục>]"
+#: builtin/config.c:141
+msgid "remove a section: name"
+msgstr "gỡ bỏ phần: tên"
 
-#: builtin/clone.c:87
-msgid "don't create a checkout"
-msgstr "không tạo một checkout"
+#: builtin/config.c:142
+msgid "list all"
+msgstr "liệt kê tất"
 
-#: builtin/clone.c:88 builtin/clone.c:90 builtin/init-db.c:479
-msgid "create a bare repository"
-msgstr "tạo kho thuần"
+#: builtin/config.c:143
+msgid "open an editor"
+msgstr "mở một trình biên soạn"
 
-#: builtin/clone.c:92
-msgid "create a mirror repository (implies bare)"
-msgstr "tạo kho bản sao (ý là kho thuần)"
+#: builtin/config.c:144
+msgid "find the color configured: slot [default]"
+msgstr "tìm cấu hình màu sắc: slot [mặc định]"
 
-#: builtin/clone.c:94
-msgid "to clone from a local repository"
-msgstr "để nhân bản từ kho nội bộ"
+#: builtin/config.c:145
+msgid "find the color setting: slot [stdout-is-tty]"
+msgstr "tìm các cài đặt về màu sắc: slot [stdout-là-tty]"
 
-#: builtin/clone.c:96
-msgid "don't use local hardlinks, always copy"
-msgstr "không sử dụng liên kết cứng nội bộ, luôn sao chép"
+#: builtin/config.c:146
+msgid "Type"
+msgstr "Kiểu"
 
-#: builtin/clone.c:98
-msgid "setup as shared repository"
-msgstr "cài đặt đây là kho chia sẻ"
+#: builtin/config.c:147 builtin/env--helper.c:38
+msgid "value is given this type"
+msgstr "giá trị được đưa kiểu này"
 
-#: builtin/clone.c:100 builtin/clone.c:104
-msgid "pathspec"
-msgstr "đặc-tả-đường-dẫn"
+#: builtin/config.c:148
+msgid "value is \"true\" or \"false\""
+msgstr "giá trị là \"true\" hoặc \"false\""
 
-#: builtin/clone.c:100 builtin/clone.c:104
-msgid "initialize submodules in the clone"
-msgstr "khởi tạo mô-đun-con trong bản sao"
+#: builtin/config.c:149
+msgid "value is decimal number"
+msgstr "giá trị ở dạng số thập phân"
 
-#: builtin/clone.c:107
-msgid "number of submodules cloned in parallel"
-msgstr "số lượng mô-đun-con được nhân bản đồng thời"
+#: builtin/config.c:150
+msgid "value is --bool or --int"
+msgstr "giá trị là --bool hoặc --int"
 
-#: builtin/clone.c:108 builtin/init-db.c:476
-msgid "template-directory"
-msgstr "thư-mục-mẫu"
+#: builtin/config.c:151
+msgid "value is a path (file or directory name)"
+msgstr "giá trị là đường dẫn (tên tập tin hay thư mục)"
 
-#: builtin/clone.c:109 builtin/init-db.c:477
-msgid "directory from which templates will be used"
-msgstr "thư mục mà tại đó các mẫu sẽ được dùng"
+#: builtin/config.c:152
+msgid "value is an expiry date"
+msgstr "giá trị là một ngày hết hạn"
 
-#: builtin/clone.c:111 builtin/clone.c:113 builtin/submodule--helper.c:1223
-#: builtin/submodule--helper.c:1594
-msgid "reference repository"
-msgstr "kho tham chiếu"
+#: builtin/config.c:153
+msgid "Other"
+msgstr "Khác"
 
-#: builtin/clone.c:115 builtin/submodule--helper.c:1225
-#: builtin/submodule--helper.c:1596
-msgid "use --reference only while cloning"
-msgstr "chỉ dùng --reference khi nhân bản"
+#: builtin/config.c:154
+msgid "terminate values with NUL byte"
+msgstr "chấm dứt giá trị với byte NUL"
 
-#: builtin/clone.c:116 builtin/column.c:27 builtin/merge-file.c:44
-#: builtin/pack-objects.c:3166 builtin/repack.c:213
-msgid "name"
-msgstr "tên"
+#: builtin/config.c:155
+msgid "show variable names only"
+msgstr "chỉ hiển thị các tên biến"
 
-#: builtin/clone.c:117
-msgid "use <name> instead of 'origin' to track upstream"
-msgstr "dùng <tên> thay cho “origin” để theo dõi thượng nguồn"
+#: builtin/config.c:156
+msgid "respect include directives on lookup"
+msgstr "tôn trọng kể cà các hướng trong tìm kiếm"
 
-#: builtin/clone.c:119
-msgid "checkout <branch> instead of the remote's HEAD"
-msgstr "lấy ra <nhánh> thay cho HEAD của máy chủ"
+#: builtin/config.c:157
+msgid "show origin of config (file, standard input, blob, command line)"
+msgstr ""
+"hiển thị nguyên gốc của cấu hình (tập tin, đầu vào tiêu chuẩn, blob, dòng "
+"lệnh)"
 
-#: builtin/clone.c:121
-msgid "path to git-upload-pack on the remote"
-msgstr "đường dẫn đến git-upload-pack trên máy chủ"
+#: builtin/config.c:158 builtin/env--helper.c:40
+msgid "value"
+msgstr "giá trị"
 
-#: builtin/clone.c:122 builtin/fetch.c:150 builtin/grep.c:813
-#: builtin/pull.c:216
-msgid "depth"
-msgstr "độ-sâu"
+#: builtin/config.c:158
+msgid "with --get, use default value when missing entry"
+msgstr "với --get, dùng giá trị mặc định khi thiếu mục tin"
 
-#: builtin/clone.c:123
-msgid "create a shallow clone of that depth"
-msgstr "tạo bản sao không đầy đủ cho mức sâu đã cho"
+#: builtin/config.c:172
+#, c-format
+msgid "wrong number of arguments, should be %d"
+msgstr "sai số lượng tham số, phải là %d"
 
-#: builtin/clone.c:124 builtin/fetch.c:152 builtin/pack-objects.c:3157
-#: parse-options.h:154
-msgid "time"
-msgstr "thời-gian"
+#: builtin/config.c:174
+#, c-format
+msgid "wrong number of arguments, should be from %d to %d"
+msgstr "sai số lượng tham số, phải từ %d đến %d"
 
-#: builtin/clone.c:125
-msgid "create a shallow clone since a specific time"
-msgstr "tạo bản sao không đầy đủ từ thời điểm đã cho"
+#: builtin/config.c:308
+#, c-format
+msgid "invalid key pattern: %s"
+msgstr "mẫu khóa không hợp lệ: %s"
 
-#: builtin/clone.c:126 builtin/fetch.c:154
-msgid "revision"
-msgstr "điểm xét duyệt"
+#: builtin/config.c:344
+#, c-format
+msgid "failed to format default config value: %s"
+msgstr "gặp lỗi khi định dạng giá trị cấu hình mặc định: %s"
 
-#: builtin/clone.c:127 builtin/fetch.c:155
-msgid "deepen history of shallow clone, excluding rev"
-msgstr "làm sâu hơn lịch sử của bản sao shallow, bằng điểm xét duyệt loại trừ"
+#: builtin/config.c:401
+#, c-format
+msgid "cannot parse color '%s'"
+msgstr "không thể phân tích màu “%s”"
 
-#: builtin/clone.c:129
-msgid "clone only one branch, HEAD or --branch"
-msgstr "chỉ nhân bản một nhánh, HEAD hoặc --branch"
+#: builtin/config.c:443
+msgid "unable to parse default color value"
+msgstr "không thể phân tích giá trị màu mặc định"
 
-#: builtin/clone.c:131
-msgid "don't clone any tags, and make later fetches not to follow them"
+#: builtin/config.c:496 builtin/config.c:742
+msgid "not in a git directory"
+msgstr "không trong thư mục git"
+
+#: builtin/config.c:499
+msgid "writing to stdin is not supported"
+msgstr "việc ghi ra đầu ra tiêu chuẩn là không được hỗ trợ"
+
+#: builtin/config.c:502
+msgid "writing config blobs is not supported"
+msgstr "không hỗ trợ ghi cấu hình các blob"
+
+#: builtin/config.c:587
+#, c-format
+msgid ""
+"# This is Git's per-user configuration file.\n"
+"[user]\n"
+"# Please adapt and uncomment the following lines:\n"
+"#\tname = %s\n"
+"#\temail = %s\n"
 msgstr ""
-"đứng có nhân bản bất kỳ nhánh nào, và làm cho những lần lấy về sau không "
-"theo chúng nữa"
+"# Đây là tập tin cấu hình cho từng người dùng Git.\n"
+"[user]\n"
+"# Vui lòng sửa lại cho thích hợp và bỏ dấu ghi chú các dòng sau:\n"
+"#\tname = %s\n"
+"#\temail = %s\n"
 
-#: builtin/clone.c:133
-msgid "any cloned submodules will be shallow"
-msgstr "mọi mô-đun-con nhân bản sẽ là shallow (nông)"
+#: builtin/config.c:611
+msgid "only one config file at a time"
+msgstr "chỉ một tập tin cấu hình một lần"
 
-#: builtin/clone.c:134 builtin/init-db.c:485
-msgid "gitdir"
-msgstr "gitdir"
+#: builtin/config.c:616
+msgid "--local can only be used inside a git repository"
+msgstr "--local chỉ có thể được dùng bên trong một kho git"
 
-#: builtin/clone.c:135 builtin/init-db.c:486
-msgid "separate git dir from working tree"
-msgstr "không dùng chung thư mục dành riêng cho git và thư mục làm việc"
+#: builtin/config.c:619
+msgid "--blob can only be used inside a git repository"
+msgstr "--blob chỉ có thể được dùng bên trong một kho git"
 
-#: builtin/clone.c:136
-msgid "key=value"
-msgstr "khóa=giá_trị"
+#: builtin/config.c:638
+msgid "$HOME not set"
+msgstr "Chưa đặt biến môi trường HOME"
 
-#: builtin/clone.c:137
-msgid "set config inside the new repository"
-msgstr "đặt cấu hình bên trong một kho chứa mới"
+#: builtin/config.c:658
+msgid ""
+"--worktree cannot be used with multiple working trees unless the config\n"
+"extension worktreeConfig is enabled. Please read \"CONFIGURATION FILE\"\n"
+"section in \"git help worktree\" for details"
+msgstr ""
+"--worktree không thể dùng với nhiều cây làm việc trừ khi cấu hình mở rộng\n"
+"worktreeConfig được bật. Vui lòng đọc phần \"CONFIGURATION FILE\"\n"
+"trong \"git help worktree\" để biết thêm chi tiết"
 
-#: builtin/clone.c:138 builtin/fetch.c:173 builtin/pull.c:229
-#: builtin/push.c:583
-msgid "use IPv4 addresses only"
-msgstr "chỉ dùng địa chỉ IPv4"
+#: builtin/config.c:688
+msgid "--get-color and variable type are incoherent"
+msgstr "--get-color và kiểu biến là không mạch lạc"
 
-#: builtin/clone.c:140 builtin/fetch.c:175 builtin/pull.c:232
-#: builtin/push.c:585
-msgid "use IPv6 addresses only"
-msgstr "chỉ dùng địa chỉ IPv6"
+#: builtin/config.c:693
+msgid "only one action at a time"
+msgstr "chỉ một thao tác mỗi lần"
 
-#: builtin/clone.c:278
+#: builtin/config.c:706
+msgid "--name-only is only applicable to --list or --get-regexp"
+msgstr "--name-only chỉ được áp dụng cho --list hoặc --get-regexp"
+
+#: builtin/config.c:712
 msgid ""
-"No directory name could be guessed.\n"
-"Please specify a directory on the command line"
+"--show-origin is only applicable to --get, --get-all, --get-regexp, and --"
+"list"
 msgstr ""
-"Không đoán được thư mục tên là gì.\n"
-"Vui lòng chỉ định tên một thư mục trên dòng lệnh"
+"--show-origin chỉ được áp dụng cho --get, --get-all, --get-regexp, hoặc --"
+"list"
 
-#: builtin/clone.c:331
-#, c-format
-msgid "info: Could not add alternate for '%s': %s\n"
-msgstr "thông tin: không thể thêm thay thế cho “%s”: %s\n"
+#: builtin/config.c:718
+msgid "--default is only applicable to --get"
+msgstr "--default chỉ được áp dụng cho --get"
 
-#: builtin/clone.c:403
+#: builtin/config.c:731
 #, c-format
-msgid "failed to open '%s'"
-msgstr "gặp lỗi khi mở “%s”"
+msgid "unable to read config file '%s'"
+msgstr "không thể đọc tập tin cấu hình “%s”"
 
-#: builtin/clone.c:411
-#, c-format
-msgid "%s exists and is not a directory"
-msgstr "%s có tồn tại nhưng lại không phải là một thư mục"
+#: builtin/config.c:734
+msgid "error processing config file(s)"
+msgstr "gặp lỗi khi xử lý các tập tin cấu hình"
 
-#: builtin/clone.c:425
-#, c-format
-msgid "failed to stat %s\n"
-msgstr "gặp lỗi khi lấy thông tin thống kê về %s\n"
+#: builtin/config.c:744
+msgid "editing stdin is not supported"
+msgstr "sửa chữa đầu ra tiêu chuẩn là không được hỗ trợ"
 
-#: builtin/clone.c:447
-#, c-format
-msgid "failed to create link '%s'"
-msgstr "gặp lỗi khi tạo được liên kết mềm %s"
+#: builtin/config.c:746
+msgid "editing blobs is not supported"
+msgstr "việc sửa chữa các blob là không được hỗ trợ"
 
-#: builtin/clone.c:451
+#: builtin/config.c:760
 #, c-format
-msgid "failed to copy file to '%s'"
-msgstr "gặp lỗi khi sao chép tập tin và “%s”"
+msgid "cannot create configuration file %s"
+msgstr "không thể tạo tập tin cấu hình “%s”"
 
-#: builtin/clone.c:477
+#: builtin/config.c:773
 #, c-format
-msgid "done.\n"
-msgstr "hoàn tất.\n"
-
-#: builtin/clone.c:491
 msgid ""
-"Clone succeeded, but checkout failed.\n"
-"You can inspect what was checked out with 'git status'\n"
-"and retry the checkout with 'git checkout -f HEAD'\n"
+"cannot overwrite multiple values with a single value\n"
+"       Use a regexp, --add or --replace-all to change %s."
 msgstr ""
-"Việc nhân bản thành công, nhưng checkout gặp lỗi.\n"
-"Bạn kiểm tra kỹ xem cái gì được lấy ra bằng lệnh “git status”\n"
-"và thử lấy ra với lệnh “git checkout -f HEAD”\n"
+"không thể ghi đè nhiều giá trị với một giá trị đơn\n"
+"      Dùng một biểu thức chính quy, --add hay --replace-all để thay đổi %s."
 
-#: builtin/clone.c:568
+#: builtin/config.c:847 builtin/config.c:858
 #, c-format
-msgid "Could not find remote branch %s to clone."
-msgstr "Không tìm thấy nhánh máy chủ %s để nhân bản (clone)."
+msgid "no such section: %s"
+msgstr "không có đoạn: %s"
 
-#: builtin/clone.c:663
-msgid "remote did not send all necessary objects"
-msgstr "máy chủ đã không gửi tất cả các đối tượng cần thiết"
+#: builtin/count-objects.c:90
+msgid "git count-objects [-v] [-H | --human-readable]"
+msgstr "git count-objects [-v] [-H | --human-readable]"
 
-#: builtin/clone.c:679
-#, c-format
-msgid "unable to update %s"
-msgstr "không thể cập nhật %s"
+#: builtin/count-objects.c:100
+msgid "print sizes in human readable format"
+msgstr "hiển thị kích cỡ theo định dạng dành cho người đọc"
 
-#: builtin/clone.c:728
-msgid "remote HEAD refers to nonexistent ref, unable to checkout.\n"
-msgstr "refers HEAD máy chủ  chỉ đến ref không tồn tại, không thể lấy ra.\n"
+#: builtin/describe.c:26
+msgid "git describe [<options>] [<commit-ish>...]"
+msgstr "git describe [<các tùy chọn>] <commit-ish>*"
 
-#: builtin/clone.c:758
-msgid "unable to checkout working tree"
-msgstr "không thể lấy ra (checkout) cây làm việc"
+#: builtin/describe.c:27
+msgid "git describe [<options>] --dirty"
+msgstr "git describe [<các tùy chọn>] --dirty"
 
-#: builtin/clone.c:803
-msgid "unable to write parameters to config file"
-msgstr "không thể ghi các tham số vào tập tin cấu hình"
+#: builtin/describe.c:62
+msgid "head"
+msgstr "phía trước"
 
-#: builtin/clone.c:866
-msgid "cannot repack to clean up"
-msgstr "không thể đóng gói để dọn dẹp"
+#: builtin/describe.c:62
+msgid "lightweight"
+msgstr "hạng nhẹ"
 
-#: builtin/clone.c:868
-msgid "cannot unlink temporary alternates file"
-msgstr "không thể bỏ liên kết tập tin thay thế tạm thời"
+#: builtin/describe.c:62
+msgid "annotated"
+msgstr "có diễn giải"
+
+#: builtin/describe.c:275
+#, c-format
+msgid "annotated tag %s not available"
+msgstr "thẻ đã được ghi chú %s không sẵn để dùng"
 
-#: builtin/clone.c:907 builtin/receive-pack.c:1947
-msgid "Too many arguments."
-msgstr "Có quá nhiều đối số."
+#: builtin/describe.c:279
+#, c-format
+msgid "annotated tag %s has no embedded name"
+msgstr "thẻ được chú giải %s không có tên nhúng"
 
-#: builtin/clone.c:911
-msgid "You must specify a repository to clone."
-msgstr "Bạn phải chỉ định một kho để mà nhân bản (clone)."
+#: builtin/describe.c:281
+#, c-format
+msgid "tag '%s' is really '%s' here"
+msgstr "thẻ “%s” đã thực sự ở đây “%s” rồi"
 
-#: builtin/clone.c:924
+#: builtin/describe.c:325
 #, c-format
-msgid "--bare and --origin %s options are incompatible."
-msgstr "tùy chọn --bare và --origin %s xung khắc nhau."
+msgid "no tag exactly matches '%s'"
+msgstr "không có thẻ nào khớp chính xác với “%s”"
 
-#: builtin/clone.c:927
-msgid "--bare and --separate-git-dir are incompatible."
-msgstr "tùy chọn --bare và --separate-git-dir xung khắc nhau."
+#: builtin/describe.c:327
+#, c-format
+msgid "No exact match on refs or tags, searching to describe\n"
+msgstr "Không có tham chiếu hay thẻ khớp đúng, đang tìm kiếm mô tả\n"
 
-#: builtin/clone.c:940
+#: builtin/describe.c:381
 #, c-format
-msgid "repository '%s' does not exist"
-msgstr "kho chứa “%s” chưa tồn tại"
+msgid "finished search at %s\n"
+msgstr "việc tìm kiếm đã kết thúc tại %s\n"
 
-#: builtin/clone.c:946 builtin/fetch.c:1460
+#: builtin/describe.c:407
 #, c-format
-msgid "depth %s is not a positive number"
-msgstr "độ sâu %s không phải là một số nguyên dương"
+msgid ""
+"No annotated tags can describe '%s'.\n"
+"However, there were unannotated tags: try --tags."
+msgstr ""
+"Không có thẻ được chú giải nào được mô tả là “%s”.\n"
+"Tuy nhiên, ở đây có những thẻ không được chú giải: hãy thử --tags."
 
-#: builtin/clone.c:956
+#: builtin/describe.c:411
 #, c-format
-msgid "destination path '%s' already exists and is not an empty directory."
-msgstr "đường dẫn đích “%s” đã có từ trước và không phải là một thư mục rỗng."
+msgid ""
+"No tags can describe '%s'.\n"
+"Try --always, or create some tags."
+msgstr ""
+"Không có thẻ có thể mô tả “%s”.\n"
+"Hãy thử --always, hoặc tạo một số thẻ."
 
-#: builtin/clone.c:966
+#: builtin/describe.c:441
 #, c-format
-msgid "working tree '%s' already exists."
-msgstr "cây làm việc “%s” đã sẵn tồn tại rồi."
+msgid "traversed %lu commits\n"
+msgstr "đã xuyên %lu qua lần chuyển giao\n"
 
-#: builtin/clone.c:981 builtin/clone.c:1002 builtin/difftool.c:270
-#: builtin/worktree.c:246 builtin/worktree.c:276
+#: builtin/describe.c:444
 #, c-format
-msgid "could not create leading directories of '%s'"
-msgstr "không thể tạo các thư mục dẫn đầu của “%s”"
+msgid ""
+"more than %i tags found; listed %i most recent\n"
+"gave up search at %s\n"
+msgstr ""
+"tìm thấy nhiều hơn %i thẻ; đã liệt kê %i cái gần\n"
+"đây nhất bỏ đi tìm kiếm tại %s\n"
 
-#: builtin/clone.c:986
+#: builtin/describe.c:512
 #, c-format
-msgid "could not create work tree dir '%s'"
-msgstr "không thể tạo cây thư mục làm việc dir “%s”"
+msgid "describe %s\n"
+msgstr "mô tả %s\n"
 
-#: builtin/clone.c:1006
+#: builtin/describe.c:515
 #, c-format
-msgid "Cloning into bare repository '%s'...\n"
-msgstr "Đang nhân bản thành kho chứa bare “%s”…\n"
+msgid "Not a valid object name %s"
+msgstr "Không phải tên đối tượng %s hợp lệ"
 
-#: builtin/clone.c:1008
+#: builtin/describe.c:523
 #, c-format
-msgid "Cloning into '%s'...\n"
-msgstr "Đang nhân bản thành “%s”…\n"
+msgid "%s is neither a commit nor blob"
+msgstr "%s không phải là một lần commit cũng không phải blob"
 
-#: builtin/clone.c:1032
-msgid ""
-"clone --recursive is not compatible with both --reference and --reference-if-"
-"able"
-msgstr ""
-"nhân bản --recursive không tương thích với cả hai --reference và --reference-"
-"if-able"
+#: builtin/describe.c:537
+msgid "find the tag that comes after the commit"
+msgstr "tìm các thẻ mà nó đến trước lần chuyển giao"
 
-#: builtin/clone.c:1093
-msgid "--depth is ignored in local clones; use file:// instead."
-msgstr "--depth bị lờ đi khi nhân bản nội bộ; hãy sử dụng file:// để thay thế."
+#: builtin/describe.c:538
+msgid "debug search strategy on stderr"
+msgstr "chiến lược tìm kiếm gỡ lỗi trên đầu ra lỗi chuẩn stderr"
 
-#: builtin/clone.c:1095
-msgid "--shallow-since is ignored in local clones; use file:// instead."
-msgstr ""
-"--shallow-since bị lờ đi khi nhân bản nội bộ; hãy sử dụng file:// để thay "
-"thế."
+#: builtin/describe.c:539
+msgid "use any ref"
+msgstr "dùng ref bất kỳ"
 
-#: builtin/clone.c:1097
-msgid "--shallow-exclude is ignored in local clones; use file:// instead."
-msgstr ""
-"--shallow-exclude bị lờ đi khi nhân bản nội bộ; hãy sử dụng file:// để thay "
-"thế."
+#: builtin/describe.c:540
+msgid "use any tag, even unannotated"
+msgstr "dùng thẻ bất kỳ, cả khi “unannotated”"
 
-#: builtin/clone.c:1099
-msgid "--filter is ignored in local clones; use file:// instead."
-msgstr ""
-"--filter bị lờ đi khi nhân bản nội bộ; hãy sử dụng file:// để thay thế."
+#: builtin/describe.c:541
+msgid "always use long format"
+msgstr "luôn dùng định dạng dài"
 
-#: builtin/clone.c:1102
-msgid "source repository is shallow, ignoring --local"
-msgstr "kho nguồn là nông, nên bỏ qua --local"
+#: builtin/describe.c:542
+msgid "only follow first parent"
+msgstr "chỉ theo cha mẹ đầu tiên"
 
-#: builtin/clone.c:1107
-msgid "--local is ignored"
-msgstr "--local bị lờ đi"
+#: builtin/describe.c:545
+msgid "only output exact matches"
+msgstr "chỉ xuất những gì khớp chính xác"
 
-#: builtin/clone.c:1169 builtin/clone.c:1177
-#, c-format
-msgid "Remote branch %s not found in upstream %s"
-msgstr "Nhánh máy chủ %s không tìm thấy trong thượng nguồn %s"
+#: builtin/describe.c:547
+msgid "consider <n> most recent tags (default: 10)"
+msgstr "coi như <n> thẻ gần đây nhất (mặc định: 10)"
 
-#: builtin/clone.c:1180
-msgid "You appear to have cloned an empty repository."
-msgstr "Bạn hình như là đã nhân bản một kho trống rỗng."
+#: builtin/describe.c:549
+msgid "only consider tags matching <pattern>"
+msgstr "chỉ cân nhắc đến những thẻ khớp với <mẫu>"
 
-#: builtin/column.c:10
-msgid "git column [<options>]"
-msgstr "git column [<các-tùy-chọn>]"
+#: builtin/describe.c:551
+msgid "do not consider tags matching <pattern>"
+msgstr "không coi rằng các thẻ khớp với <mẫu>"
 
-#: builtin/column.c:27
-msgid "lookup config vars"
-msgstr "tìm kiếm biến cấu hình"
+#: builtin/describe.c:553 builtin/name-rev.c:473
+msgid "show abbreviated commit object as fallback"
+msgstr "hiển thị đối tượng chuyển giao vắn tắt như là fallback"
 
-#: builtin/column.c:28 builtin/column.c:29
-msgid "layout to use"
-msgstr "bố cục để dùng"
+#: builtin/describe.c:554 builtin/describe.c:557
+msgid "mark"
+msgstr "dấu"
 
-#: builtin/column.c:30
-msgid "Maximum width"
-msgstr "Độ rộng tối đa"
+#: builtin/describe.c:555
+msgid "append <mark> on dirty working tree (default: \"-dirty\")"
+msgstr "thêm <dấu> trên cây thư mục làm việc bẩn (mặc định \"-dirty\")"
 
-#: builtin/column.c:31
-msgid "Padding space on left border"
-msgstr "Chèn thêm khoảng trống vào bên trái"
+#: builtin/describe.c:558
+msgid "append <mark> on broken working tree (default: \"-broken\")"
+msgstr "thêm <dấu> trên cây thư mục làm việc bị hỏng (mặc định \"-broken\")"
 
-#: builtin/column.c:32
-msgid "Padding space on right border"
-msgstr "Chèn thêm khoảng trắng vào bên phải"
+#: builtin/describe.c:576
+msgid "--long is incompatible with --abbrev=0"
+msgstr "--long là xung khắc với tùy chọn --abbrev=0"
 
-#: builtin/column.c:33
-msgid "Padding space between columns"
-msgstr "Chèn thêm khoảng trắng giữa các cột"
+#: builtin/describe.c:605
+msgid "No names found, cannot describe anything."
+msgstr "Không tìm thấy các tên, không thể mô tả gì cả."
 
-#: builtin/column.c:51
-msgid "--command must be the first argument"
-msgstr "--command phải là đối số đầu tiên"
+#: builtin/describe.c:656
+msgid "--dirty is incompatible with commit-ishes"
+msgstr "--dirty là xung khắc với các tùy chọn commit-ish"
 
-#: builtin/commit.c:37
-msgid "git commit [<options>] [--] <pathspec>..."
-msgstr "git commit [<các-tùy-chọn>] [--] <pathspec>…"
+#: builtin/describe.c:658
+msgid "--broken is incompatible with commit-ishes"
+msgstr "--broken là xung khắc với commit-ishes"
 
-#: builtin/commit.c:42
-msgid "git status [<options>] [--] <pathspec>..."
-msgstr "git status [<các-tùy-chọn>] [--] <pathspec>…"
+#: builtin/diff.c:84
+#, c-format
+msgid "'%s': not a regular file or symlink"
+msgstr "“%s”: không phải tập tin bình thường hay liên kết mềm"
 
-#: builtin/commit.c:47
-msgid ""
-"You asked to amend the most recent commit, but doing so would make\n"
-"it empty. You can repeat your command with --allow-empty, or you can\n"
-"remove the commit entirely with \"git reset HEAD^\".\n"
-msgstr ""
-"Bạn đã yêu cầu amend (“tu bổ”) phần lớn các lần chuyển giao gần đây, nhưng "
-"làm như thế\n"
-"có thể làm cho nó trở nên trống rỗng. Bạn có thể lặp lại lệnh của mình bằng "
-"--allow-empty,\n"
-"hoặc là bạn gỡ bỏ các lần chuyển giao một cách hoàn toàn bằng lệnh:\n"
-"\"git reset HEAD^\".\n"
+#: builtin/diff.c:235
+#, c-format
+msgid "invalid option: %s"
+msgstr "tùy chọn không hợp lệ: %s"
 
-#: builtin/commit.c:52
-msgid ""
-"The previous cherry-pick is now empty, possibly due to conflict resolution.\n"
-"If you wish to commit it anyway, use:\n"
-"\n"
-"    git commit --allow-empty\n"
-"\n"
-msgstr ""
-"Lần cherry-pick trước hiện nay trống rỗng, có lẽ là bởi vì sự phân giải xung "
-"đột.\n"
-"Nếu bạn vẫn muốn chuyển giao nó cho dù thế nào đi nữa, hãy dùng:\n"
-"\n"
-"    git commit --allow-empty\n"
-"\n"
+#: builtin/diff.c:350
+msgid "Not a git repository"
+msgstr "Không phải là kho git"
+
+#: builtin/diff.c:394
+#, c-format
+msgid "invalid object '%s' given."
+msgstr "đối tượng đã cho “%s” không hợp lệ."
 
-#: builtin/commit.c:59
-msgid "Otherwise, please use 'git reset'\n"
-msgstr "Nếu không được thì dùng lệnh \"git reset\"\n"
+#: builtin/diff.c:403
+#, c-format
+msgid "more than two blobs given: '%s'"
+msgstr "đã cho nhiều hơn hai đối tượng blob: “%s”"
 
-#: builtin/commit.c:62
-msgid ""
-"If you wish to skip this commit, use:\n"
-"\n"
-"    git reset\n"
-"\n"
-"Then \"git cherry-pick --continue\" will resume cherry-picking\n"
-"the remaining commits.\n"
+#: builtin/diff.c:408
+#, c-format
+msgid "unhandled object '%s' given."
+msgstr "đã cho đối tượng không thể nắm giữ “%s”."
+
+#: builtin/difftool.c:30
+msgid "git difftool [<options>] [<commit> [<commit>]] [--] [<path>...]"
 msgstr ""
-"Nếu bạn muốn bỏ qua lần chuyển giao này thì dùng:\n"
-"\n"
-"    git reset\n"
-"\n"
-"Thế thì \"git cherry-pick --continue\" sẽ phục hồi lại việc cherry-pick\n"
-"những lần chuyển giao còn lại.\n"
+"git difftool [<các tùy chọn>] [<lần_chuyển_giao> [<lần_chuyển_giao>]] [--] </"
+"đường/dẫn>…]"
 
-#: builtin/commit.c:293
-msgid "failed to unpack HEAD tree object"
-msgstr "gặp lỗi khi tháo dỡ HEAD đối tượng cây"
+#: builtin/difftool.c:260
+#, c-format
+msgid "failed: %d"
+msgstr "gặp lỗi: %d"
 
-#: builtin/commit.c:334
-msgid "unable to create temporary index"
-msgstr "không thể tạo bảng mục lục tạm thời"
+#: builtin/difftool.c:302
+#, c-format
+msgid "could not read symlink %s"
+msgstr "không thể đọc liên kết mềm %s"
 
-#: builtin/commit.c:340
-msgid "interactive add failed"
-msgstr "gặp lỗi khi thêm bằng cách tương"
+#: builtin/difftool.c:304
+#, c-format
+msgid "could not read symlink file %s"
+msgstr "không đọc được tập tin liên kết mềm %s"
 
-#: builtin/commit.c:353
-msgid "unable to update temporary index"
-msgstr "không thể cập nhật bảng mục lục tạm thời"
+#: builtin/difftool.c:312
+#, c-format
+msgid "could not read object %s for symlink %s"
+msgstr "không thể đọc đối tượng %s cho liên kết mềm %s"
 
-#: builtin/commit.c:355
-msgid "Failed to update main cache tree"
-msgstr "Gặp lỗi khi cập nhật cây bộ nhớ đệm"
+#: builtin/difftool.c:413
+msgid ""
+"combined diff formats('-c' and '--cc') are not supported in\n"
+"directory diff mode('-d' and '--dir-diff')."
+msgstr ""
+"các định dạng diff tổ hợp(“-c” và “--cc”) chưa được hỗ trợ trong\n"
+"chế độ diff thư mục(“-d” và “--dir-diff”)."
 
-#: builtin/commit.c:380 builtin/commit.c:403 builtin/commit.c:449
-msgid "unable to write new_index file"
-msgstr "không thể ghi tập tin lưu bảng mục lục mới (new_index)"
+#: builtin/difftool.c:634
+#, c-format
+msgid "both files modified: '%s' and '%s'."
+msgstr "cả hai tập tin đã bị sửa: “%s” và “%s”."
 
-#: builtin/commit.c:432
-msgid "cannot do a partial commit during a merge."
-msgstr ""
-"không thể thực hiện việc chuyển giao cục bộ trong khi đang được hòa trộn."
+#: builtin/difftool.c:636
+msgid "working tree file has been left."
+msgstr "cây làm việc ở bên trái."
+
+#: builtin/difftool.c:647
+#, c-format
+msgid "temporary files exist in '%s'."
+msgstr "các tập tin tạm đã sẵn có trong “%s”."
+
+#: builtin/difftool.c:648
+msgid "you may want to cleanup or recover these."
+msgstr "bạn có lẽ muốn dọn dẹp hay phục hồi ở đây."
+
+#: builtin/difftool.c:697
+msgid "use `diff.guitool` instead of `diff.tool`"
+msgstr "dùng “diff.guitool“ thay vì dùng “diff.tool“"
 
-#: builtin/commit.c:434
-msgid "cannot do a partial commit during a cherry-pick."
-msgstr ""
-"không thể thực hiện việc chuyển giao bộ phận trong khi đang cherry-pick."
+#: builtin/difftool.c:699
+msgid "perform a full-directory diff"
+msgstr "thực hiện một diff toàn thư mục"
 
-#: builtin/commit.c:442
-msgid "cannot read the index"
-msgstr "không đọc được bảng mục lục"
+#: builtin/difftool.c:701
+msgid "do not prompt before launching a diff tool"
+msgstr "đừng nhắc khi khởi chạy công cụ diff"
 
-#: builtin/commit.c:461
-msgid "unable to write temporary index file"
-msgstr "không thể ghi tập tin lưu bảng mục lục tạm thời"
+#: builtin/difftool.c:706
+msgid "use symlinks in dir-diff mode"
+msgstr "dùng liên kết mềm trong diff-thư-mục"
 
-#: builtin/commit.c:558
-#, c-format
-msgid "commit '%s' lacks author header"
-msgstr "lần chuyển giao “%s” thiếu phần tác giả ở đầu"
+#: builtin/difftool.c:707
+msgid "tool"
+msgstr "công cụ"
 
-#: builtin/commit.c:560
-#, c-format
-msgid "commit '%s' has malformed author line"
-msgstr "lần chuyển giao “%s” có phần tác giả ở đầu dị dạng"
+#: builtin/difftool.c:708
+msgid "use the specified diff tool"
+msgstr "dùng công cụ diff đã cho"
 
-#: builtin/commit.c:579
-msgid "malformed --author parameter"
-msgstr "đối số cho --author bị dị hình"
+#: builtin/difftool.c:710
+msgid "print a list of diff tools that may be used with `--tool`"
+msgstr "in ra danh sách các công cụ dif cái mà có thẻ dùng với “--tool“"
 
-#: builtin/commit.c:631
+#: builtin/difftool.c:713
 msgid ""
-"unable to select a comment character that is not used\n"
-"in the current commit message"
+"make 'git-difftool' exit when an invoked diff tool returns a non - zero exit "
+"code"
 msgstr ""
-"không thể chọn một ký tự ghi chú cái mà không được dùng\n"
-"trong phần ghi chú hiện tại"
-
-#: builtin/commit.c:668 builtin/commit.c:701 builtin/commit.c:1029
-#, c-format
-msgid "could not lookup commit %s"
-msgstr "không thể tìm kiếm commit (lần chuyển giao) %s"
+"làm cho “git-difftool” thoát khi gọi công cụ diff trả về mã không phải số "
+"không"
 
-#: builtin/commit.c:680 builtin/shortlog.c:316
-#, c-format
-msgid "(reading log message from standard input)\n"
-msgstr "(đang đọc thông điệp nhật ký từ đầu vào tiêu chuẩn)\n"
+#: builtin/difftool.c:716
+msgid "specify a custom command for viewing diffs"
+msgstr "chỉ định một lệnh tùy ý để xem diff"
 
-#: builtin/commit.c:682
-msgid "could not read log from standard input"
-msgstr "không thể đọc nhật ký từ đầu vào tiêu chuẩn"
+#: builtin/difftool.c:717
+msgid "passed to `diff`"
+msgstr "chuyển cho “diff”"
+
+#: builtin/difftool.c:732
+msgid "difftool requires worktree or --no-index"
+msgstr "difftool cần cây làm việc hoặc --no-index"
+
+#: builtin/difftool.c:739
+msgid "--dir-diff is incompatible with --no-index"
+msgstr "--dir-diff xung khắc với --no-index"
+
+#: builtin/difftool.c:742
+msgid "--gui, --tool and --extcmd are mutually exclusive"
+msgstr "--gui, --tool và --extcmd loại từ lẫn nhau"
 
-#: builtin/commit.c:686
-#, c-format
-msgid "could not read log file '%s'"
-msgstr "không đọc được tệp nhật ký “%s”"
+#: builtin/difftool.c:750
+msgid "no <tool> given for --tool=<tool>"
+msgstr "chưa đưa ra <công_cụ> cho --tool=<công_cụ>"
 
-#: builtin/commit.c:715 builtin/commit.c:723
-msgid "could not read SQUASH_MSG"
-msgstr "không thể đọc SQUASH_MSG"
+#: builtin/difftool.c:757
+msgid "no <cmd> given for --extcmd=<cmd>"
+msgstr "chưa đưa ra <lệnh> cho --extcmd=<lệnh>"
 
-#: builtin/commit.c:720
-msgid "could not read MERGE_MSG"
-msgstr "không thể đọc MERGE_MSG"
+#: builtin/env--helper.c:6
+msgid "git env--helper --type=[bool|ulong] <options> <env-var>"
+msgstr "git env--helper --type=[bool|ulong] <các tùy chọn> <env-var>"
 
-#: builtin/commit.c:774
-msgid "could not write commit template"
-msgstr "không thể ghi mẫu chuyển giao"
+#: builtin/env--helper.c:37 builtin/hash-object.c:98
+msgid "type"
+msgstr "kiểu"
 
-#: builtin/commit.c:792
-#, c-format
-msgid ""
-"\n"
-"It looks like you may be committing a merge.\n"
-"If this is not correct, please remove the file\n"
-"\t%s\n"
-"and try again.\n"
-msgstr ""
-"\n"
-"Nó trông giống với việc bạn đang chuyển giao một lần hòa trộn.\n"
-"Nếu không phải vậy, xin hãy gỡ bỏ tập tin\n"
-"\t%s\n"
-"và thử lại.\n"
+#: builtin/env--helper.c:41
+msgid "default for git_env_*(...) to fall back on"
+msgstr "mặc định cho git_env_*(...) để quay về"
 
-#: builtin/commit.c:797
-#, c-format
-msgid ""
-"\n"
-"It looks like you may be committing a cherry-pick.\n"
-"If this is not correct, please remove the file\n"
-"\t%s\n"
-"and try again.\n"
-msgstr ""
-"\n"
-"Nó trông giống với việc bạn đang chuyển giao một lần cherry-pick.\n"
-"Nếu không phải vậy, xin hãy gỡ bỏ tập tin\n"
-"\t%s\n"
-"và thử lại.\n"
+#: builtin/env--helper.c:43
+msgid "be quiet only use git_env_*() value as exit code"
+msgstr "im lặng chỉ khi dung giá trị git_env_*() làm mã thoát"
 
-#: builtin/commit.c:810
+#: builtin/env--helper.c:62
 #, c-format
-msgid ""
-"Please enter the commit message for your changes. Lines starting\n"
-"with '%c' will be ignored, and an empty message aborts the commit.\n"
+msgid "option `--default' expects a boolean value with `--type=bool`, not `%s`"
 msgstr ""
-"Hãy nhập vào các thông tin để giải thích các thay đổi của bạn. Những dòng "
-"được\n"
-"bắt đầu bằng “%c” sẽ được bỏ qua, nếu phần chú thích rỗng sẽ hủy bỏ lần "
-"chuyển giao.\n"
+"tùy chọn `--default' cần một giá trị logic với `--type=bool`, không phải `%s`"
 
-#: builtin/commit.c:818
+#: builtin/env--helper.c:77
 #, c-format
 msgid ""
-"Please enter the commit message for your changes. Lines starting\n"
-"with '%c' will be kept; you may remove them yourself if you want to.\n"
-"An empty message aborts the commit.\n"
+"option `--default' expects an unsigned long value with `--type=ulong`, not `"
+"%s`"
 msgstr ""
-"Hãy nhập vào các thông tin để giải thích các thay đổi của bạn. Những dòng "
-"được\n"
-"bắt đầu bằng “%c” sẽ được bỏ qua; bạn có thể xóa chúng đi nếu muốn thế.\n"
-"Phần chú thích này nếu trống rỗng sẽ hủy bỏ lần chuyển giao.\n"
+"tùy chọn `--default' cần một giá trị số nguyên dài không dấu với `--"
+"type=ulong`, không phải `%s`"
 
-#: builtin/commit.c:835
-#, c-format
-msgid "%sAuthor:    %.*s <%.*s>"
-msgstr "%sTác giả:           %.*s <%.*s>"
-
-#: builtin/commit.c:843
-#, c-format
-msgid "%sDate:      %s"
-msgstr "%sNgày tháng:        %s"
+#: builtin/fast-export.c:29
+msgid "git fast-export [rev-list-opts]"
+msgstr "git fast-export [rev-list-opts]"
 
-#: builtin/commit.c:850
-#, c-format
-msgid "%sCommitter: %.*s <%.*s>"
-msgstr "%sNgười chuyển giao: %.*s <%.*s>"
+#: builtin/fast-export.c:852
+msgid "Error: Cannot export nested tags unless --mark-tags is specified."
+msgstr "Lỗi: không thể xuất thẻ lồng nhau trừ khi --mark-tags được chỉ định."
 
-#: builtin/commit.c:867
-msgid "Cannot read index"
-msgstr "Không đọc được bảng mục lục"
+#: builtin/fast-export.c:1152
+msgid "show progress after <n> objects"
+msgstr "hiển thị tiến triển sau <n> đối tượng"
 
-#: builtin/commit.c:933
-msgid "Error building trees"
-msgstr "Gặp lỗi khi xây dựng cây"
+#: builtin/fast-export.c:1154
+msgid "select handling of signed tags"
+msgstr "chọn điều khiển của thẻ đã ký"
 
-#: builtin/commit.c:947 builtin/tag.c:257
-#, c-format
-msgid "Please supply the message using either -m or -F option.\n"
-msgstr "Xin hãy cung cấp lời chú giải hoặc là dùng tùy chọn -m hoặc là -F.\n"
+#: builtin/fast-export.c:1157
+msgid "select handling of tags that tag filtered objects"
+msgstr "chọn sự xử lý của các thẻ, cái mà đánh thẻ các đối tượng được lọc ra"
 
-#: builtin/commit.c:991
-#, c-format
-msgid "--author '%s' is not 'Name <email>' and matches no existing author"
+#: builtin/fast-export.c:1160
+msgid "select handling of commit messages in an alternate encoding"
 msgstr ""
-"--author “%s” không phải là “Họ và tên <thư điện tửl>” và không khớp bất kỳ "
-"tác giả nào sẵn có"
-
-#: builtin/commit.c:1005
-#, c-format
-msgid "Invalid ignored mode '%s'"
-msgstr "Chế độ bỏ qua không hợp lệ “%s”"
+"chọn bộ xử lý cho các ghi chú của lần chuyển giao theo một bộ mã thay thế"
 
-#: builtin/commit.c:1019 builtin/commit.c:1269
-#, c-format
-msgid "Invalid untracked files mode '%s'"
-msgstr "Chế độ cho các tập tin chưa được theo dõi không hợp lệ “%s”"
+#: builtin/fast-export.c:1163
+msgid "Dump marks to this file"
+msgstr "Đổ các đánh dấu này vào tập-tin"
 
-#: builtin/commit.c:1057
-msgid "--long and -z are incompatible"
-msgstr "hai tùy chọn -long và -z không tương thích với nhau"
+#: builtin/fast-export.c:1165
+msgid "Import marks from this file"
+msgstr "Nhập vào đánh dấu từ tập tin này"
 
-#: builtin/commit.c:1090
-msgid "Using both --reset-author and --author does not make sense"
-msgstr "Sử dụng cả hai tùy chọn --reset-author và --author không hợp lý"
+#: builtin/fast-export.c:1169
+msgid "Import marks from this file if it exists"
+msgstr "Nhập vào đánh dấu từ tập tin sẵn có"
 
-#: builtin/commit.c:1099
-msgid "You have nothing to amend."
-msgstr "Không có gì để mà “tu bổ” cả."
+#: builtin/fast-export.c:1171
+msgid "Fake a tagger when tags lack one"
+msgstr "Làm giả một cái thẻ khi thẻ bị thiếu một cái"
 
-#: builtin/commit.c:1102
-msgid "You are in the middle of a merge -- cannot amend."
-msgstr ""
-"Bạn đang ở giữa của quá trình hòa trộn -- không thể thực hiện việc “tu bổ”."
+#: builtin/fast-export.c:1173
+msgid "Output full tree for each commit"
+msgstr "Xuất ra toàn bộ cây cho mỗi lần chuyển giao"
 
-#: builtin/commit.c:1104
-msgid "You are in the middle of a cherry-pick -- cannot amend."
-msgstr ""
-"Bạn đang ở giữa của quá trình cherry-pick -- không thể thực hiện việc “tu "
-"bổ”."
+#: builtin/fast-export.c:1175
+msgid "Use the done feature to terminate the stream"
+msgstr "Sử dụng tính năng done để chấm dứt luồng dữ liệu"
 
-#: builtin/commit.c:1107
-msgid "Options --squash and --fixup cannot be used together"
-msgstr "Các tùy chọn --squash và --fixup không thể sử dụng cùng với nhau"
+#: builtin/fast-export.c:1176
+msgid "Skip output of blob data"
+msgstr "Bỏ qua kết xuất của dữ liệu blob"
 
-#: builtin/commit.c:1117
-msgid "Only one of -c/-C/-F/--fixup can be used."
-msgstr ""
-"Chỉ được dùng một trong số tùy chọn trong số các tùy chọn -c/-C/-F/--fixup"
+#: builtin/fast-export.c:1177 builtin/log.c:1705
+msgid "refspec"
+msgstr "refspec"
 
-#: builtin/commit.c:1119
-msgid "Option -m cannot be combined with -c/-C/-F."
-msgstr "Tùy chọn -m không thể được tổ hợp cùng với -c/-C/-F."
+#: builtin/fast-export.c:1178
+msgid "Apply refspec to exported refs"
+msgstr "Áp dụng refspec cho refs đã xuất"
 
-#: builtin/commit.c:1127
-msgid "--reset-author can be used only with -C, -c or --amend."
-msgstr ""
-"--reset-author chỉ có thể được sử dụng với tùy chọn -C, -c hay --amend."
+#: builtin/fast-export.c:1179
+msgid "anonymize output"
+msgstr "kết xuất anonymize"
 
-#: builtin/commit.c:1144
-msgid "Only one of --include/--only/--all/--interactive/--patch can be used."
+#: builtin/fast-export.c:1181
+msgid "Reference parents which are not in fast-export stream by object id"
 msgstr ""
-"Chỉ một trong các tùy chọn --include/--only/--all/--interactive/--patch được "
-"sử dụng."
-
-#: builtin/commit.c:1146
-msgid "No paths with --include/--only does not make sense."
-msgstr "Không đường dẫn với các tùy chọn --include/--only không hợp lý."
-
-#: builtin/commit.c:1160 builtin/tag.c:543
-#, c-format
-msgid "Invalid cleanup mode %s"
-msgstr "Chế độ dọn dẹp không hợp lệ %s"
+"Các cha mẹ tham chiếu cái mà k trong luồng dữ liệu fast-export bởi mã id đối "
+"tượng"
 
-#: builtin/commit.c:1165
-msgid "Paths with -a does not make sense."
-msgstr "Các đường dẫn với tùy chọn -a không hợp lý."
+#: builtin/fast-export.c:1183
+msgid "Show original object ids of blobs/commits"
+msgstr "Hiển thị các mã id nguyên gốc của blobs/commits"
 
-#: builtin/commit.c:1303 builtin/commit.c:1480
-msgid "show status concisely"
-msgstr "hiển thị trạng thái ở dạng súc tích"
+#: builtin/fast-export.c:1185
+msgid "Label tags with mark ids"
+msgstr "Gắn nhãn thẻ ID dấu"
 
-#: builtin/commit.c:1305 builtin/commit.c:1482
-msgid "show branch information"
-msgstr "hiển thị thông tin nhánh"
+#: builtin/fast-export.c:1220
+msgid "Cannot pass both --import-marks and --import-marks-if-exists"
+msgstr "Không thể chuyển qua cả hai --import-marks và --import-marks-if-exists"
 
-#: builtin/commit.c:1307
-msgid "show stash information"
-msgstr "hiển thị thông tin về tạm cất"
+#: builtin/fetch.c:34
+msgid "git fetch [<options>] [<repository> [<refspec>...]]"
+msgstr "git fetch [<các tùy chọn>] [<kho-chứa> [<refspec>…]]"
 
-#: builtin/commit.c:1309 builtin/commit.c:1484
-msgid "compute full ahead/behind values"
-msgstr "tính đầy đủ giá trị trước/sau"
+#: builtin/fetch.c:35
+msgid "git fetch [<options>] <group>"
+msgstr "git fetch [<các tùy chọn>] [<nhóm>"
 
-#: builtin/commit.c:1311
-msgid "version"
-msgstr "phiên bản"
+#: builtin/fetch.c:36
+msgid "git fetch --multiple [<options>] [(<repository> | <group>)...]"
+msgstr "git fetch --multiple [<các tùy chọn>] [(<kho> | <nhóm>)…]"
 
-#: builtin/commit.c:1311 builtin/commit.c:1486 builtin/push.c:558
-#: builtin/worktree.c:581
-msgid "machine-readable output"
-msgstr "kết xuất dạng máy-có-thể-đọc"
+#: builtin/fetch.c:37
+msgid "git fetch --all [<options>]"
+msgstr "git fetch --all [<các tùy chọn>]"
 
-#: builtin/commit.c:1314 builtin/commit.c:1488
-msgid "show status in long format (default)"
-msgstr "hiển thị trạng thái ở định dạng dài (mặc định)"
+#: builtin/fetch.c:116
+msgid "fetch.parallel cannot be negative"
+msgstr "fetch.parallel không thể âm"
 
-#: builtin/commit.c:1317 builtin/commit.c:1491
-msgid "terminate entries with NUL"
-msgstr "chấm dứt các mục bằng NUL"
+#: builtin/fetch.c:139 builtin/pull.c:204
+msgid "fetch from all remotes"
+msgstr "lấy về từ tất cả các máy chủ"
 
-#: builtin/commit.c:1319 builtin/commit.c:1323 builtin/commit.c:1494
-#: builtin/fast-export.c:1001 builtin/fast-export.c:1004 builtin/tag.c:397
-msgid "mode"
-msgstr "chế độ"
+#: builtin/fetch.c:141 builtin/pull.c:248
+msgid "set upstream for git pull/fetch"
+msgstr "đặt thượng nguồn cho git pull/fetch"
 
-#: builtin/commit.c:1320 builtin/commit.c:1494
-msgid "show untracked files, optional modes: all, normal, no. (Default: all)"
-msgstr ""
-"hiển thị các tập tin chưa được theo dõi  dấu vết, các chế độ tùy chọn:  all, "
-"normal, no. (Mặc định: all)"
+#: builtin/fetch.c:143 builtin/pull.c:207
+msgid "append to .git/FETCH_HEAD instead of overwriting"
+msgstr "nối thêm vào .git/FETCH_HEAD thay vì ghi đè lên nó"
 
-#: builtin/commit.c:1324
-msgid ""
-"show ignored files, optional modes: traditional, matching, no. (Default: "
-"traditional)"
-msgstr ""
-"hiển thị các tập tin bị bỏ qua, các chế độ tùy chọn: traditional, matching, "
-"no. (Mặc định: traditional)"
+#: builtin/fetch.c:145 builtin/pull.c:210
+msgid "path to upload pack on remote end"
+msgstr "đường dẫn đến gói tải lên trên máy chủ cuối"
 
-#: builtin/commit.c:1326 parse-options.h:167
-msgid "when"
-msgstr "khi"
+#: builtin/fetch.c:146
+msgid "force overwrite of local reference"
+msgstr "ép buộc ghi đè lên tham chiếu nội bộ"
 
-#: builtin/commit.c:1327
-msgid ""
-"ignore changes to submodules, optional when: all, dirty, untracked. "
-"(Default: all)"
-msgstr ""
-"bỏ qua các thay đổi trong mô-đun-con, tùy chọn khi: all, dirty, untracked. "
-"(Mặc định: all)"
+#: builtin/fetch.c:148
+msgid "fetch from multiple remotes"
+msgstr "lấy từ nhiều máy chủ cùng lúc"
 
-#: builtin/commit.c:1329
-msgid "list untracked files in columns"
-msgstr "hiển thị danh sách các tập-tin chưa được theo dõi trong các cột"
+#: builtin/fetch.c:150 builtin/pull.c:214
+msgid "fetch all tags and associated objects"
+msgstr "lấy tất cả các thẻ cùng với các đối tượng liên quan đến nó"
 
-#: builtin/commit.c:1330
-msgid "do not detect renames"
-msgstr "không dò tìm các tên thay đổi"
+#: builtin/fetch.c:152
+msgid "do not fetch all tags (--no-tags)"
+msgstr "không lấy tất cả các thẻ (--no-tags)"
 
-#: builtin/commit.c:1332
-msgid "detect renames, optionally set similarity index"
-msgstr "dò các tên thay đổi, tùy ý đặt mục lục tương tự"
+#: builtin/fetch.c:154
+msgid "number of submodules fetched in parallel"
+msgstr "số lượng mô-đun-con được lấy đồng thời"
 
-#: builtin/commit.c:1352
-msgid "Unsupported combination of ignored and untracked-files arguments"
+#: builtin/fetch.c:156 builtin/pull.c:217
+msgid "prune remote-tracking branches no longer on remote"
 msgstr ""
-"Không hỗ trỡ tổ hợp các tham số các tập tin bị bỏ qua và không được theo dõi"
+"cắt cụt (prune) các nhánh “remote-tracking” không còn tồn tại trên máy chủ "
+"nữa"
 
-#: builtin/commit.c:1450
-msgid "suppress summary after successful commit"
-msgstr "không hiển thị tổng kết sau khi chuyển giao thành công"
+#: builtin/fetch.c:158
+msgid "prune local tags no longer on remote and clobber changed tags"
+msgstr "cắt xém các thẻ nội bộ không còn ở máy chủ và xóa các thẻ đã thay đổi"
 
-#: builtin/commit.c:1451
-msgid "show diff in commit message template"
-msgstr "hiển thị sự khác biệt trong mẫu tin nhắn chuyển giao"
+#: builtin/fetch.c:159 builtin/fetch.c:182 builtin/pull.c:141
+msgid "on-demand"
+msgstr "khi-cần"
 
-#: builtin/commit.c:1453
-msgid "Commit message options"
-msgstr "Các tùy chọn ghi chú commit"
+#: builtin/fetch.c:160
+msgid "control recursive fetching of submodules"
+msgstr "điều khiển việc lấy về đệ quy trong các mô-đun-con"
 
-#: builtin/commit.c:1454 builtin/tag.c:394
-msgid "read message from file"
-msgstr "đọc chú thích từ tập tin"
+#: builtin/fetch.c:164 builtin/pull.c:225
+msgid "keep downloaded pack"
+msgstr "giữ lại gói đã tải về"
 
-#: builtin/commit.c:1455
-msgid "author"
-msgstr "tác giả"
+#: builtin/fetch.c:166
+msgid "allow updating of HEAD ref"
+msgstr "cho phép cập nhật th.chiếu HEAD"
 
-#: builtin/commit.c:1455
-msgid "override author for commit"
-msgstr "ghi đè tác giả cho commit"
+#: builtin/fetch.c:169 builtin/fetch.c:175 builtin/pull.c:228
+msgid "deepen history of shallow clone"
+msgstr "làm sâu hơn lịch sử của bản sao"
 
-#: builtin/commit.c:1456 builtin/gc.c:501
-msgid "date"
-msgstr "ngày tháng"
+#: builtin/fetch.c:171
+msgid "deepen history of shallow repository based on time"
+msgstr "làm sâu hơn lịch sử của kho bản sao shallow dựa trên thời gian"
 
-#: builtin/commit.c:1456
-msgid "override date for commit"
-msgstr "ghi đè ngày tháng cho lần chuyển giao"
+#: builtin/fetch.c:177 builtin/pull.c:231
+msgid "convert to a complete repository"
+msgstr "chuyển đổi hoàn toàn sang kho git"
 
-#: builtin/commit.c:1457 builtin/merge.c:228 builtin/notes.c:402
-#: builtin/notes.c:565 builtin/tag.c:392
-msgid "message"
-msgstr "chú thích"
+#: builtin/fetch.c:180
+msgid "prepend this to submodule path output"
+msgstr "soạn sẵn cái này cho kết xuất đường dẫn mô-đun-con"
 
-#: builtin/commit.c:1457
-msgid "commit message"
-msgstr "chú thích của lần chuyển giao"
+#: builtin/fetch.c:183
+msgid ""
+"default for recursive fetching of submodules (lower priority than config "
+"files)"
+msgstr ""
+"mặc định cho việc lấy đệ quy các mô-đun-con (có mức ưu tiên thấp hơn các tập "
+"tin cấu hình config)"
 
-#: builtin/commit.c:1458 builtin/commit.c:1459 builtin/commit.c:1460
-#: builtin/commit.c:1461 parse-options.h:270 ref-filter.h:92
-msgid "commit"
-msgstr "lần_chuyển_giao"
+#: builtin/fetch.c:187 builtin/pull.c:234
+msgid "accept refs that update .git/shallow"
+msgstr "chấp nhận tham chiếu cập nhật .git/shallow"
 
-#: builtin/commit.c:1458
-msgid "reuse and edit message from specified commit"
-msgstr "dùng lại các ghi chú từ lần chuyển giao đã cho nhưng có cho sửa chữa"
+#: builtin/fetch.c:188 builtin/pull.c:236
+msgid "refmap"
+msgstr "refmap"
 
-#: builtin/commit.c:1459
-msgid "reuse message from specified commit"
-msgstr "dùng lại các ghi chú từ lần chuyển giao đã cho"
+#: builtin/fetch.c:189 builtin/pull.c:237
+msgid "specify fetch refmap"
+msgstr "chỉ ra refmap cần lấy về"
 
-#: builtin/commit.c:1460
-msgid "use autosquash formatted message to fixup specified commit"
+#: builtin/fetch.c:196
+msgid "report that we have only objects reachable from this object"
 msgstr ""
-"dùng ghi chú có định dạng autosquash để sửa chữa lần chuyển giao đã chỉ ra"
+"báo cáo rằng chúng ta chỉ có các đối tượng tiếp cận được từ đối tượng này"
 
-#: builtin/commit.c:1461
-msgid "use autosquash formatted message to squash specified commit"
-msgstr ""
-"dùng lời nhắn có định dạng tự động nén để nén lại các lần chuyển giao đã chỉ "
-"ra"
+#: builtin/fetch.c:199
+msgid "run 'gc --auto' after fetching"
+msgstr "chạy 'gc --auto' sau khi lấy về"
 
-#: builtin/commit.c:1462
-msgid "the commit is authored by me now (used with -C/-c/--amend)"
-msgstr ""
-"lần chuyển giao nhận tôi là tác giả (được dùng với tùy chọn -C/-c/--amend)"
+#: builtin/fetch.c:201 builtin/pull.c:246
+msgid "check for forced-updates on all updated branches"
+msgstr "kiểm cho các-cập-nhật-bắt-buộc trên mọi nhánh đã cập nhật"
 
-#: builtin/commit.c:1463 builtin/log.c:1446 builtin/merge.c:242
-#: builtin/pull.c:154 builtin/revert.c:105
-msgid "add Signed-off-by:"
-msgstr "(nên dùng) thêm dòng Signed-off-by:"
+#: builtin/fetch.c:203
+msgid "write the commit-graph after fetching"
+msgstr "ghi ra đồ thị các lần chuyển giao sau khi lấy về"
 
-#: builtin/commit.c:1464
-msgid "use specified template file"
-msgstr "sử dụng tập tin mẫu đã cho"
+#: builtin/fetch.c:513
+msgid "Couldn't find remote ref HEAD"
+msgstr "Không thể tìm thấy máy chủ cho tham chiếu HEAD"
 
-#: builtin/commit.c:1465
-msgid "force edit of commit"
-msgstr "ép buộc sửa lần commit"
+#: builtin/fetch.c:653
+#, c-format
+msgid "configuration fetch.output contains invalid value %s"
+msgstr "phần cấu hình fetch.output có chứa giá-trị không hợp lệ %s"
 
-#: builtin/commit.c:1466
-msgid "default"
-msgstr "mặc định"
+#: builtin/fetch.c:751
+#, c-format
+msgid "object %s not found"
+msgstr "không tìm thấy đối tượng %s"
 
-#: builtin/commit.c:1466 builtin/tag.c:398
-msgid "how to strip spaces and #comments from message"
-msgstr "làm thế nào để cắt bỏ khoảng trắng và #ghichú từ mẩu tin nhắn"
+#: builtin/fetch.c:755
+msgid "[up to date]"
+msgstr "[đã cập nhật]"
 
-#: builtin/commit.c:1467
-msgid "include status in commit message template"
-msgstr "bao gồm các trạng thái trong mẫu ghi chú chuyển giao"
+#: builtin/fetch.c:768 builtin/fetch.c:784 builtin/fetch.c:856
+msgid "[rejected]"
+msgstr "[Bị từ chối]"
 
-#: builtin/commit.c:1469 builtin/merge.c:240 builtin/pull.c:184
-#: builtin/revert.c:113
-msgid "GPG sign commit"
-msgstr "ký lần chuyển giao dùng GPG"
+#: builtin/fetch.c:769
+msgid "can't fetch in current branch"
+msgstr "không thể fetch (lấy) về nhánh hiện hành"
 
-#: builtin/commit.c:1472
-msgid "Commit contents options"
-msgstr "Các tùy nội dung ghi chú commit"
+#: builtin/fetch.c:779
+msgid "[tag update]"
+msgstr "[cập nhật thẻ]"
 
-#: builtin/commit.c:1473
-msgid "commit all changed files"
-msgstr "chuyển giao tất cả các tập tin có thay đổi"
+#: builtin/fetch.c:780 builtin/fetch.c:817 builtin/fetch.c:839
+#: builtin/fetch.c:851
+msgid "unable to update local ref"
+msgstr "không thể cập nhật tham chiếu nội bộ"
 
-#: builtin/commit.c:1474
-msgid "add specified files to index for commit"
-msgstr "thêm các tập tin đã chỉ ra vào bảng mục lục để chuyển giao"
+#: builtin/fetch.c:784
+msgid "would clobber existing tag"
+msgstr "nên xóa chồng các thẻ có sẵn"
 
-#: builtin/commit.c:1475
-msgid "interactively add files"
-msgstr "thêm các tập-tin bằng tương tác"
+#: builtin/fetch.c:806
+msgid "[new tag]"
+msgstr "[thẻ mới]"
 
-#: builtin/commit.c:1476
-msgid "interactively add changes"
-msgstr "thêm các thay đổi bằng tương tác"
+#: builtin/fetch.c:809
+msgid "[new branch]"
+msgstr "[nhánh mới]"
 
-#: builtin/commit.c:1477
-msgid "commit only specified files"
-msgstr "chỉ chuyển giao các tập tin đã chỉ ra"
+#: builtin/fetch.c:812
+msgid "[new ref]"
+msgstr "[ref (tham chiếu) mới]"
 
-#: builtin/commit.c:1478
-msgid "bypass pre-commit and commit-msg hooks"
-msgstr "vòng qua móc (hook) pre-commit và commit-msg"
+#: builtin/fetch.c:851
+msgid "forced update"
+msgstr "cưỡng bức cập nhật"
 
-#: builtin/commit.c:1479
-msgid "show what would be committed"
-msgstr "hiển thị xem cái gì có thể được chuyển giao"
+#: builtin/fetch.c:856
+msgid "non-fast-forward"
+msgstr "không-phải-chuyển-tiếp-nhanh"
 
-#: builtin/commit.c:1492
-msgid "amend previous commit"
-msgstr "“tu bổ” (amend) lần commit trước"
+#: builtin/fetch.c:877
+msgid ""
+"Fetch normally indicates which branches had a forced update,\n"
+"but that check has been disabled. To re-enable, use '--show-forced-updates'\n"
+"flag or run 'git config fetch.showForcedUpdates true'."
+msgstr ""
+"Việc lấy về thường chỉ ra các nhánh buộc phải cập nhật,\n"
+"nhưng lựa chọn bị tắt. Để kích hoạt lại, sử dụng cờ\n"
+"'--show-forced-updates' hoặc chạy 'git config fetch.showForcedUpdates true'."
 
-#: builtin/commit.c:1493
-msgid "bypass post-rewrite hook"
-msgstr "vòng qua móc (hook) post-rewrite"
+#: builtin/fetch.c:881
+#, c-format
+msgid ""
+"It took %.2f seconds to check forced updates. You can use\n"
+"'--no-show-forced-updates' or run 'git config fetch.showForcedUpdates "
+"false'\n"
+" to avoid this check.\n"
+msgstr ""
+"Việc này cần %.2f giây để kiểm tra các cập nhật ép buộc. Bạn có thể dùng\n"
+"'--no-show-forced-updates' hoặc chạy 'git config fetch.showForcedUpdates "
+"false'\n"
+"để tránh kiểm tra này.\n"
 
-#: builtin/commit.c:1498
-msgid "ok to record an empty change"
-msgstr "ok để ghi lại một thay đổi trống rỗng"
+#: builtin/fetch.c:911
+#, c-format
+msgid "%s did not send all necessary objects\n"
+msgstr "%s đã không gửi tất cả các đối tượng cần thiết\n"
 
-#: builtin/commit.c:1500
-msgid "ok to record a change with an empty message"
-msgstr "ok để ghi các thay đổi với lời nhắn trống rỗng"
+#: builtin/fetch.c:932
+#, c-format
+msgid "reject %s because shallow roots are not allowed to be updated"
+msgstr "từ chối %s bởi vì các gốc nông thì không được phép cập nhật"
 
-#: builtin/commit.c:1573
+#: builtin/fetch.c:1017 builtin/fetch.c:1155
 #, c-format
-msgid "Corrupt MERGE_HEAD file (%s)"
-msgstr "Tập tin MERGE_HEAD sai hỏng (%s)"
+msgid "From %.*s\n"
+msgstr "Từ %.*s\n"
 
-#: builtin/commit.c:1580
-msgid "could not read MERGE_MODE"
-msgstr "không thể đọc MERGE_MODE"
+#: builtin/fetch.c:1028
+#, c-format
+msgid ""
+"some local refs could not be updated; try running\n"
+" 'git remote prune %s' to remove any old, conflicting branches"
+msgstr ""
+"một số tham chiếu nội bộ không thể được cập nhật; hãy thử chạy\n"
+" “git remote prune %s” để bỏ đi những nhánh cũ, hay bị xung đột"
 
-#: builtin/commit.c:1599
+#: builtin/fetch.c:1125
 #, c-format
-msgid "could not read commit message: %s"
-msgstr "không thể đọc phần chú thích (message) của lần chuyển giao: %s"
+msgid "   (%s will become dangling)"
+msgstr "   (%s sẽ trở thành không đầu (không được quản lý))"
 
-#: builtin/commit.c:1610
+#: builtin/fetch.c:1126
 #, c-format
-msgid "Aborting commit due to empty commit message.\n"
-msgstr "Bãi bỏ việc chuyển giao bởi vì phần chú thích của nó trống rỗng.\n"
+msgid "   (%s has become dangling)"
+msgstr "   (%s đã trở thành không đầu (không được quản lý))"
+
+#: builtin/fetch.c:1158
+msgid "[deleted]"
+msgstr "[đã xóa]"
+
+#: builtin/fetch.c:1159 builtin/remote.c:1035
+msgid "(none)"
+msgstr "(không)"
 
-#: builtin/commit.c:1615
+#: builtin/fetch.c:1182
 #, c-format
-msgid "Aborting commit; you did not edit the message.\n"
+msgid "Refusing to fetch into current branch %s of non-bare repository"
 msgstr ""
-"Đang bỏ qua việc chuyển giao; bạn đã không biên soạn phần chú thích "
-"(message).\n"
+"Từ chối việc lấy vào trong nhánh hiện tại %s của một kho chứa không phải kho "
+"trần (bare)"
 
-#: builtin/commit.c:1650
-msgid ""
-"Repository has been updated, but unable to write\n"
-"new_index file. Check that disk is not full and quota is\n"
-"not exceeded, and then \"git reset HEAD\" to recover."
-msgstr ""
-"Kho chứa đã được cập nhật, nhưng không thể ghi vào\n"
-"tập tin new_index (bảng mục lục mới). Hãy kiểm tra xem đĩa\n"
-"có bị đầy quá hay quota (hạn nghạch đĩa cứng) bị vượt quá,\n"
-"và sau đó \"git reset HEAD\" để khắc phục."
+#: builtin/fetch.c:1201
+#, c-format
+msgid "Option \"%s\" value \"%s\" is not valid for %s"
+msgstr "Tùy chọn \"%s\" có giá trị \"%s\" là không hợp lệ cho %s"
 
-#: builtin/commit-graph.c:9
-msgid "git commit-graph [--object-dir <objdir>]"
-msgstr "git commit-graph [--object-dir <objdir>]"
+#: builtin/fetch.c:1204
+#, c-format
+msgid "Option \"%s\" is ignored for %s\n"
+msgstr "Tùy chọn \"%s\" bị bỏ qua với %s\n"
 
-#: builtin/commit-graph.c:10 builtin/commit-graph.c:16
-msgid "git commit-graph read [--object-dir <objdir>]"
-msgstr "git commit-graph read [--object-dir <objdir>]"
+#: builtin/fetch.c:1412
+msgid "multiple branches detected, incompatible with --set-upstream"
+msgstr "phát hiện nhiều nhánh, không tương thích với --set-upstream"
 
-#: builtin/commit-graph.c:11 builtin/commit-graph.c:21
-msgid ""
-"git commit-graph write [--object-dir <objdir>] [--append] [--stdin-packs|--"
-"stdin-commits]"
-msgstr ""
-"git commit-graph write [--object-dir <objdir>] [--append] [--stdin-packs|--"
-"stdin-commits]"
+#: builtin/fetch.c:1427
+msgid "not setting upstream for a remote remote-tracking branch"
+msgstr "không cài đặt thượng nguồn cho một nhánh được theo dõi trên máy chủ"
 
-#: builtin/commit-graph.c:39 builtin/commit-graph.c:92
-#: builtin/commit-graph.c:147 builtin/fetch.c:161 builtin/log.c:1466
-msgid "dir"
-msgstr "tmục"
+#: builtin/fetch.c:1429
+msgid "not setting upstream for a remote tag"
+msgstr "không cài đặt thượng nguồn cho một thẻ nhánh trên máy chủ"
 
-#: builtin/commit-graph.c:40 builtin/commit-graph.c:93
-#: builtin/commit-graph.c:148
-msgid "The object directory to store the graph"
-msgstr "Thư mục đối tượng để lưu đồ thị"
+#: builtin/fetch.c:1431
+msgid "unknown branch type"
+msgstr "không hiểu kiểu nhánh"
 
-#: builtin/commit-graph.c:95
-msgid "scan pack-indexes listed by stdin for commits"
+#: builtin/fetch.c:1433
+msgid ""
+"no source branch found.\n"
+"you need to specify exactly one branch with the --set-upstream option."
 msgstr ""
-"quét dó các mục lục gói được liệt kê bởi đầu vào tiêu chuẩn cho các lần "
-"chuyển giao"
+"không tìm thấy nhánh nguồn.\n"
+"bạn cần phải chỉ định chính xác một nhánh với tùy chọn --set-upstream."
 
-#: builtin/commit-graph.c:97
-msgid "start walk at commits listed by stdin"
-msgstr ""
-"bắt đầu di chuyển tại các lần chuyển giao được liệt kê bởi đầu vào tiêu chuẩn"
+#: builtin/fetch.c:1559 builtin/fetch.c:1622
+#, c-format
+msgid "Fetching %s\n"
+msgstr "Đang lấy “%s” về\n"
 
-#: builtin/commit-graph.c:99
-msgid "include all commits already in the commit-graph file"
+#: builtin/fetch.c:1569 builtin/fetch.c:1624 builtin/remote.c:100
+#, c-format
+msgid "Could not fetch %s"
+msgstr "Không thể lấy“%s” về"
+
+#: builtin/fetch.c:1581
+#, c-format
+msgid "could not fetch '%s' (exit code: %d)\n"
+msgstr "không thể lấy “%s” (mã thoát: %d)\n"
+
+#: builtin/fetch.c:1684
+msgid ""
+"No remote repository specified.  Please, specify either a URL or a\n"
+"remote name from which new revisions should be fetched."
 msgstr ""
-"bao gồm mọi lần chuyển giao đã sẵn có trongười tập tin đồ thị lần chuyển giao"
+"Chưa chỉ ra kho chứa máy chủ.  Xin hãy chỉ định hoặc là URL hoặc\n"
+"tên máy chủ từ cái mà những điểm xét duyệt mới có thể được fetch (lấy về)."
 
-#: builtin/commit-graph.c:108
-msgid "cannot use both --stdin-commits and --stdin-packs"
-msgstr "không thể sử dụng cả hai --stdin-commits và --stdin-packs"
+#: builtin/fetch.c:1721
+msgid "You need to specify a tag name."
+msgstr "Bạn phải định rõ tên thẻ."
 
-#: builtin/config.c:10
-msgid "git config [<options>]"
-msgstr "git config [<các-tùy-chọn>]"
+#: builtin/fetch.c:1771
+msgid "Negative depth in --deepen is not supported"
+msgstr "Mức sâu là số âm trong --deepen là không được hỗ trợ"
 
-#: builtin/config.c:101
-#, c-format
-msgid "unrecognized --type argument, %s"
-msgstr "đối số không được thừa nhận --type, %s"
+#: builtin/fetch.c:1773
+msgid "--deepen and --depth are mutually exclusive"
+msgstr "Các tùy chọn--deepen và --depth loại từ lẫn nhau"
 
-#: builtin/config.c:123
-msgid "Config file location"
-msgstr "Vị trí tập tin cấu hình"
+#: builtin/fetch.c:1778
+msgid "--depth and --unshallow cannot be used together"
+msgstr "tùy chọn --depth và --unshallow không thể sử dụng cùng với nhau"
 
-#: builtin/config.c:124
-msgid "use global config file"
-msgstr "dùng tập tin cấu hình toàn cục"
+#: builtin/fetch.c:1780
+msgid "--unshallow on a complete repository does not make sense"
+msgstr "--unshallow trên kho hoàn chỉnh là không hợp lý"
 
-#: builtin/config.c:125
-msgid "use system config file"
-msgstr "sử dụng tập tin cấu hình hệ thống"
+#: builtin/fetch.c:1796
+msgid "fetch --all does not take a repository argument"
+msgstr "lệnh lấy về \"fetch --all\" không lấy đối số kho chứa"
 
-#: builtin/config.c:126
-msgid "use repository config file"
-msgstr "dùng tập tin cấu hình của kho"
+#: builtin/fetch.c:1798
+msgid "fetch --all does not make sense with refspecs"
+msgstr "lệnh lấy về \"fetch --all\" không hợp lý với refspecs"
 
-#: builtin/config.c:127
-msgid "use given config file"
-msgstr "sử dụng tập tin cấu hình đã cho"
+#: builtin/fetch.c:1807
+#, c-format
+msgid "No such remote or remote group: %s"
+msgstr "Không có nhóm máy chủ hay máy chủ như thế: %s"
 
-#: builtin/config.c:128
-msgid "blob-id"
-msgstr "blob-id"
+#: builtin/fetch.c:1814
+msgid "Fetching a group and specifying refspecs does not make sense"
+msgstr "Việc lấy về cả một nhóm và chỉ định refspecs không hợp lý"
 
-#: builtin/config.c:128
-msgid "read config from given blob object"
-msgstr "đọc cấu hình từ đối tượng blob đã cho"
+#: builtin/fetch.c:1832
+msgid ""
+"--filter can only be used with the remote configured in extensions."
+"partialclone"
+msgstr ""
+"--filter chỉ có thể được dùng với máy chủ được cấu hình bằng extensions."
+"partialclone"
 
-#: builtin/config.c:129
-msgid "Action"
-msgstr "Hành động"
+#: builtin/fmt-merge-msg.c:18
+msgid ""
+"git fmt-merge-msg [-m <message>] [--log[=<n>] | --no-log] [--file <file>]"
+msgstr ""
+"git fmt-merge-msg [-m <chú_thích>] [--log[=<n>] | --no-log] [--file <tập-"
+"tin>]"
 
-#: builtin/config.c:130
-msgid "get value: name [value-regex]"
-msgstr "lấy giá-trị: tên [value-regex]"
+#: builtin/fmt-merge-msg.c:674
+msgid "populate log with at most <n> entries from shortlog"
+msgstr "gắn nhật ký với ít nhất <n> mục từ lệnh “shortlog”"
 
-#: builtin/config.c:131
-msgid "get all values: key [value-regex]"
-msgstr "lấy tất cả giá-trị: khóa [value-regex]"
+#: builtin/fmt-merge-msg.c:677
+msgid "alias for --log (deprecated)"
+msgstr "bí danh cho --log (không được dùng)"
 
-#: builtin/config.c:132
-msgid "get values for regexp: name-regex [value-regex]"
-msgstr "lấy giá trị cho regexp: name-regex [value-regex]"
+#: builtin/fmt-merge-msg.c:680
+msgid "text"
+msgstr "văn bản"
 
-#: builtin/config.c:133
-msgid "get value specific for the URL: section[.var] URL"
-msgstr "lấy đặc tả giá trị cho URL: phần[.biến] URL"
+#: builtin/fmt-merge-msg.c:681
+msgid "use <text> as start of message"
+msgstr "dùng <văn bản thường> để bắt đầu ghi chú"
 
-#: builtin/config.c:134
-msgid "replace all matching variables: name value [value_regex]"
-msgstr "thay thế tất cả các biến khớp mẫu: tên giá-trị [value_regex]"
+#: builtin/fmt-merge-msg.c:682
+msgid "file to read from"
+msgstr "tập tin để đọc dữ liệu từ đó"
 
-#: builtin/config.c:135
-msgid "add a new variable: name value"
-msgstr "thêm biến mới: tên giá-trị"
+#: builtin/for-each-ref.c:10
+msgid "git for-each-ref [<options>] [<pattern>]"
+msgstr "git for-each-ref [<các tùy chọn>] [<mẫu>]"
 
-#: builtin/config.c:136
-msgid "remove a variable: name [value-regex]"
-msgstr "gỡ bỏ biến: tên [value-regex]"
+#: builtin/for-each-ref.c:11
+msgid "git for-each-ref [--points-at <object>]"
+msgstr "git for-each-ref [--points-at <đối tượng>]"
 
-#: builtin/config.c:137
-msgid "remove all matches: name [value-regex]"
-msgstr "gỡ bỏ mọi cái khớp: tên [value-regex]"
+#: builtin/for-each-ref.c:12
+msgid "git for-each-ref [(--merged | --no-merged) [<commit>]]"
+msgstr "git for-each-ref [(--merged | --no-merged) [<lần-chuyển-giao>]]"
 
-#: builtin/config.c:138
-msgid "rename section: old-name new-name"
-msgstr "đổi tên phần: tên-cũ tên-mới"
+#: builtin/for-each-ref.c:13
+msgid "git for-each-ref [--contains [<commit>]] [--no-contains [<commit>]]"
+msgstr ""
+"git for-each-ref [--contains [<lần-chuyển-giao>]] [--no-contains [<lần-"
+"chuyển-giao>]]"
 
-#: builtin/config.c:139
-msgid "remove a section: name"
-msgstr "gỡ bỏ phần: tên"
+#: builtin/for-each-ref.c:28
+msgid "quote placeholders suitably for shells"
+msgstr "trích dẫn để phù hợp cho hệ vỏ (shell)"
 
-#: builtin/config.c:140
-msgid "list all"
-msgstr "liệt kê tất"
+#: builtin/for-each-ref.c:30
+msgid "quote placeholders suitably for perl"
+msgstr "trích dẫn để phù hợp cho perl"
 
-#: builtin/config.c:141
-msgid "open an editor"
-msgstr "mở một trình biên soạn"
+#: builtin/for-each-ref.c:32
+msgid "quote placeholders suitably for python"
+msgstr "trích dẫn để phù hợp cho python"
 
-#: builtin/config.c:142
-msgid "find the color configured: slot [default]"
-msgstr "tìm cấu hình màu sắc: slot [mặc định]"
+#: builtin/for-each-ref.c:34
+msgid "quote placeholders suitably for Tcl"
+msgstr "trích dẫn để phù hợp cho Tcl"
 
-#: builtin/config.c:143
-msgid "find the color setting: slot [stdout-is-tty]"
-msgstr "tìm các cài đặt về màu sắc: slot [stdout-là-tty]"
+#: builtin/for-each-ref.c:37
+msgid "show only <n> matched refs"
+msgstr "hiển thị chỉ <n> tham chiếu khớp"
 
-#: builtin/config.c:144
-msgid "Type"
-msgstr "Kiểu"
+#: builtin/for-each-ref.c:39 builtin/tag.c:439
+msgid "respect format colors"
+msgstr "các màu định dạng lưu tâm"
 
-#: builtin/config.c:145
-msgid "value is given this type"
-msgstr "giá trị được đưa kiểu này"
+#: builtin/for-each-ref.c:42
+msgid "print only refs which points at the given object"
+msgstr "chỉ hiển thị các tham chiếu mà nó chỉ đến đối tượng đã cho"
 
-#: builtin/config.c:146
-msgid "value is \"true\" or \"false\""
-msgstr "giá trị là \"true\" hoặc \"false\""
+#: builtin/for-each-ref.c:44
+msgid "print only refs that are merged"
+msgstr "chỉ hiển thị những tham chiếu mà nó được hòa trộn"
 
-#: builtin/config.c:147
-msgid "value is decimal number"
-msgstr "giá trị ở dạng số thập phân"
+#: builtin/for-each-ref.c:45
+msgid "print only refs that are not merged"
+msgstr "chỉ hiển thị những tham chiếu mà nó không được hòa trộn"
 
-#: builtin/config.c:148
-msgid "value is --bool or --int"
-msgstr "giá trị là --bool hoặc --int"
+#: builtin/for-each-ref.c:46
+msgid "print only refs which contain the commit"
+msgstr "chỉ hiển thị những tham chiếu mà nó chứa lần chuyển giao"
 
-#: builtin/config.c:149
-msgid "value is a path (file or directory name)"
-msgstr "giá trị là đường dẫn (tên tập tin hay thư mục)"
+#: builtin/for-each-ref.c:47
+msgid "print only refs which don't contain the commit"
+msgstr "chỉ hiển thị những tham chiếu mà nó không chứa lần chuyển giao"
 
-#: builtin/config.c:150
-msgid "value is an expiry date"
-msgstr "giá trị là một ngày hết hạn"
+#: builtin/fsck.c:68 builtin/fsck.c:147 builtin/fsck.c:148
+msgid "unknown"
+msgstr "không hiểu"
 
-#: builtin/config.c:151
-msgid "Other"
-msgstr "Khác"
+#. TRANSLATORS: e.g. error in tree 01bfda: <more explanation>
+#: builtin/fsck.c:100 builtin/fsck.c:120
+#, c-format
+msgid "error in %s %s: %s"
+msgstr "lỗi trong %s %s: %s"
 
-#: builtin/config.c:152
-msgid "terminate values with NUL byte"
-msgstr "chấm dứt giá trị với byte NUL"
+#. TRANSLATORS: e.g. warning in tree 01bfda: <more explanation>
+#: builtin/fsck.c:114
+#, c-format
+msgid "warning in %s %s: %s"
+msgstr "có cảnh báo trong %s %s: %s"
 
-#: builtin/config.c:153
-msgid "show variable names only"
-msgstr "chỉ hiển thị các tên biến"
+#: builtin/fsck.c:143 builtin/fsck.c:146
+#, c-format
+msgid "broken link from %7s %s"
+msgstr "liên kết gãy từ %7s %s"
 
-#: builtin/config.c:154
-msgid "respect include directives on lookup"
-msgstr "tôn trọng kể cà các hướng trong tìm kiếm"
+#: builtin/fsck.c:155
+msgid "wrong object type in link"
+msgstr "kiểu đối tượng sai trong liên kết"
 
-#: builtin/config.c:155
-msgid "show origin of config (file, standard input, blob, command line)"
+#: builtin/fsck.c:171
+#, c-format
+msgid ""
+"broken link from %7s %s\n"
+"              to %7s %s"
 msgstr ""
-"hiển thị nguyên gốc của cấu hình (tập tin, đầu vào tiêu chuẩn, blob, dòng "
-"lệnh)"
+"liên kết gãy từ %7s %s \n"
+"              tới %7s %s"
 
-#: builtin/config.c:156
-msgid "value"
-msgstr "giá trị"
+#: builtin/fsck.c:282
+#, c-format
+msgid "missing %s %s"
+msgstr "thiếu %s %s"
 
-#: builtin/config.c:156
-msgid "with --get, use default value when missing entry"
-msgstr "với --get, dùng giá trị mặc định khi thiếu mục tin"
+#: builtin/fsck.c:309
+#, c-format
+msgid "unreachable %s %s"
+msgstr "không tiếp cận được %s %s"
 
-#: builtin/config.c:332
+#: builtin/fsck.c:329
 #, c-format
-msgid "failed to format default config value: %s"
-msgstr "gặp lỗi khi định dạng giá trị cấu hình mặc định: %s"
+msgid "dangling %s %s"
+msgstr "dangling %s %s"
 
-#: builtin/config.c:431
-msgid "unable to parse default color value"
-msgstr "không thể phân tích giá trị màu mặc định"
+#: builtin/fsck.c:339
+msgid "could not create lost-found"
+msgstr "không thể tạo lost-found"
 
-#: builtin/config.c:575
+#: builtin/fsck.c:350
 #, c-format
-msgid ""
-"# This is Git's per-user configuration file.\n"
-"[user]\n"
-"# Please adapt and uncomment the following lines:\n"
-"#\tname = %s\n"
-"#\temail = %s\n"
-msgstr ""
-"# Đây là tập tin cấu hình cho từng người dùng Git.\n"
-"[user]\n"
-"# Vui lòng sửa lại cho thích hợp và bỏ dấu ghi chú các dòng sau:\n"
-"#\tname = %s\n"
-"#\temail = %s\n"
+msgid "could not finish '%s'"
+msgstr "không thể hoàn thành “%s”"
 
-#: builtin/config.c:603
-msgid "--local can only be used inside a git repository"
-msgstr "--local chỉ có thể được dùng bên trong một kho git"
+#: builtin/fsck.c:367
+#, c-format
+msgid "Checking %s"
+msgstr "Đang kiểm tra %s"
 
-#: builtin/config.c:606
-msgid "--blob can only be used inside a git repository"
-msgstr "--blob chỉ có thể được dùng bên trong một kho git"
+#: builtin/fsck.c:405
+#, c-format
+msgid "Checking connectivity (%d objects)"
+msgstr "Đang kiểm tra kết nối (%d đối tượng)"
 
-#: builtin/config.c:735
+#: builtin/fsck.c:424
 #, c-format
-msgid "cannot create configuration file %s"
-msgstr "không thể tạo tập tin cấu hình “%s”"
+msgid "Checking %s %s"
+msgstr "Đang kiểm tra %s %s"
+
+#: builtin/fsck.c:429
+msgid "broken links"
+msgstr "các liên kết bị gẫy"
 
-#: builtin/config.c:748
+#: builtin/fsck.c:438
 #, c-format
-msgid ""
-"cannot overwrite multiple values with a single value\n"
-"       Use a regexp, --add or --replace-all to change %s."
-msgstr ""
-"không thể ghi đè nhiều giá trị với một giá trị đơn\n"
-"      Dùng một biểu thức chính quy, --add hay --replace-all để thay đổi %s."
+msgid "root %s"
+msgstr "gốc %s"
 
-#: builtin/count-objects.c:90
-msgid "git count-objects [-v] [-H | --human-readable]"
-msgstr "git count-objects [-v] [-H | --human-readable]"
+#: builtin/fsck.c:446
+#, c-format
+msgid "tagged %s %s (%s) in %s"
+msgstr "đã đánh thẻ %s %s (%s) trong %s"
 
-#: builtin/count-objects.c:100
-msgid "print sizes in human readable format"
-msgstr "hiển thị kích cỡ theo định dạng dành cho người đọc"
+#: builtin/fsck.c:475
+#, c-format
+msgid "%s: object corrupt or missing"
+msgstr "%s: đối tượng thiếu hay hỏng"
 
-#: builtin/describe.c:22
-msgid "git describe [<options>] [<commit-ish>...]"
-msgstr "git describe [<các-tùy-chọn>] <commit-ish>*"
+#: builtin/fsck.c:500
+#, c-format
+msgid "%s: invalid reflog entry %s"
+msgstr "%s: mục reflog không hợp lệ %s"
 
-#: builtin/describe.c:23
-msgid "git describe [<options>] --dirty"
-msgstr "git describe [<các-tùy-chọn>] --dirty"
+#: builtin/fsck.c:514
+#, c-format
+msgid "Checking reflog %s->%s"
+msgstr "Đang kiểm tra việc đổi tên của “%s” thành “%s”"
 
-#: builtin/describe.c:57
-msgid "head"
-msgstr "phía trước "
+#: builtin/fsck.c:548
+#, c-format
+msgid "%s: invalid sha1 pointer %s"
+msgstr "%s: con trỏ sha1 không hợp lệ %s"
 
-#: builtin/describe.c:57
-msgid "lightweight"
-msgstr "hạng nhẹ"
+#: builtin/fsck.c:555
+#, c-format
+msgid "%s: not a commit"
+msgstr "%s: không phải là một lần chuyển giao"
 
-#: builtin/describe.c:57
-msgid "annotated"
-msgstr "có diễn giải"
+#: builtin/fsck.c:609
+msgid "notice: No default references"
+msgstr "cảnh báo: Không có các tham chiếu mặc định"
 
-#: builtin/describe.c:267
+#: builtin/fsck.c:624
 #, c-format
-msgid "annotated tag %s not available"
-msgstr "thẻ đã được ghi chú %s không sẵn để dùng"
+msgid "%s: object corrupt or missing: %s"
+msgstr "%s: thiếu đối tượng hoặc hỏng: %s"
 
-#: builtin/describe.c:271
+#: builtin/fsck.c:637
 #, c-format
-msgid "annotated tag %s has no embedded name"
-msgstr "thẻ được chú giải %s không có tên nhúng"
+msgid "%s: object could not be parsed: %s"
+msgstr "%s: không thể phân tích cú đối tượng: %s"
 
-#: builtin/describe.c:273
+#: builtin/fsck.c:657
 #, c-format
-msgid "tag '%s' is really '%s' here"
-msgstr "thẻ “%s” đã thực sự ở đây “%s” rồi"
+msgid "bad sha1 file: %s"
+msgstr "tập tin sha1 sai: %s"
+
+#: builtin/fsck.c:672
+msgid "Checking object directory"
+msgstr "Đang kiểm tra thư mục đối tượng"
+
+#: builtin/fsck.c:675
+msgid "Checking object directories"
+msgstr "Đang kiểm tra các thư mục đối tượng"
 
-#: builtin/describe.c:317
+#: builtin/fsck.c:690
 #, c-format
-msgid "no tag exactly matches '%s'"
-msgstr "không có thẻ nào khớp chính xác với “%s”"
+msgid "Checking %s link"
+msgstr "Đang lấy liên kết %s"
 
-#: builtin/describe.c:319
+#: builtin/fsck.c:695 builtin/index-pack.c:842
 #, c-format
-msgid "No exact match on refs or tags, searching to describe\n"
-msgstr "Không có tham chiếu hay thẻ khớp đúng, đang tìm kiếm mô tả\n"
+msgid "invalid %s"
+msgstr "%s không hợp lệ"
 
-#: builtin/describe.c:366
+#: builtin/fsck.c:702
 #, c-format
-msgid "finished search at %s\n"
-msgstr "việc tìm kiếm đã kết thúc tại %s\n"
+msgid "%s points to something strange (%s)"
+msgstr "%s chỉ đến thứ gì đó xa lạ (%s)"
 
-#: builtin/describe.c:392
+#: builtin/fsck.c:708
 #, c-format
-msgid ""
-"No annotated tags can describe '%s'.\n"
-"However, there were unannotated tags: try --tags."
-msgstr ""
-"Không có thẻ được chú giải nào được mô tả là “%s”.\n"
-"Tuy nhiên, ở đây có những thẻ không được chú giải: hãy thử --tags."
+msgid "%s: detached HEAD points at nothing"
+msgstr "%s: HEAD đã tách rời không chỉ vào đâu cả"
 
-#: builtin/describe.c:396
+#: builtin/fsck.c:712
 #, c-format
-msgid ""
-"No tags can describe '%s'.\n"
-"Try --always, or create some tags."
-msgstr ""
-"Không có thẻ có thể mô tả “%s”.\n"
-"Hãy thử --always, hoặc tạo một số thẻ."
+msgid "notice: %s points to an unborn branch (%s)"
+msgstr "chú ý: %s chỉ đến một nhánh chưa sinh (%s)"
 
-#: builtin/describe.c:426
+#: builtin/fsck.c:724
+msgid "Checking cache tree"
+msgstr "Đang kiểm tra cây nhớ tạm"
+
+#: builtin/fsck.c:729
 #, c-format
-msgid "traversed %lu commits\n"
-msgstr "đã xuyên %lu qua lần chuyển giao\n"
+msgid "%s: invalid sha1 pointer in cache-tree"
+msgstr "%s: con trỏ sha1 không hợp lệ trong cache-tree"
+
+#: builtin/fsck.c:738
+msgid "non-tree in cache-tree"
+msgstr "non-tree trong cache-tree"
+
+#: builtin/fsck.c:769
+msgid "git fsck [<options>] [<object>...]"
+msgstr "git fsck [<các tùy chọn>] [<đối-tượng>…]"
+
+#: builtin/fsck.c:775
+msgid "show unreachable objects"
+msgstr "hiển thị các đối tượng không thể đọc được"
+
+#: builtin/fsck.c:776
+msgid "show dangling objects"
+msgstr "hiển thị các đối tượng không được quản lý"
+
+#: builtin/fsck.c:777
+msgid "report tags"
+msgstr "báo cáo các thẻ"
+
+#: builtin/fsck.c:778
+msgid "report root nodes"
+msgstr "báo cáo node gốc"
 
-#: builtin/describe.c:429
-#, c-format
-msgid ""
-"more than %i tags found; listed %i most recent\n"
-"gave up search at %s\n"
-msgstr ""
-"tìm thấy nhiều hơn %i thẻ; đã liệt kê %i cái gần\n"
-"đây nhất bỏ đi tìm kiếm tại %s\n"
+#: builtin/fsck.c:779
+msgid "make index objects head nodes"
+msgstr "tạo “index objects head nodes”"
 
-#: builtin/describe.c:497
-#, c-format
-msgid "describe %s\n"
-msgstr "mô tả %s\n"
+#: builtin/fsck.c:780
+msgid "make reflogs head nodes (default)"
+msgstr "tạo “reflogs head nodes” (mặc định)"
 
-#: builtin/describe.c:500 builtin/log.c:502
-#, c-format
-msgid "Not a valid object name %s"
-msgstr "Không phải tên đối tượng %s hợp lệ"
+#: builtin/fsck.c:781
+msgid "also consider packs and alternate objects"
+msgstr "cũng cân nhắc đến các đối tượng gói và thay thế"
 
-#: builtin/describe.c:508
-#, c-format
-msgid "%s is neither a commit nor blob"
-msgstr "%s không phải là một lần commit cũng không phải blob"
+#: builtin/fsck.c:782
+msgid "check only connectivity"
+msgstr "chỉ kiểm tra kết nối"
 
-#: builtin/describe.c:522
-msgid "find the tag that comes after the commit"
-msgstr "tìm các thẻ mà nó đến trước lần chuyển giao"
+#: builtin/fsck.c:783
+msgid "enable more strict checking"
+msgstr "cho phép kiểm tra hạn chế hơn"
 
-#: builtin/describe.c:523
-msgid "debug search strategy on stderr"
-msgstr "chiến lược tìm kiếm gỡ lỗi trên đầu ra lỗi chuẩn stderr"
+#: builtin/fsck.c:785
+msgid "write dangling objects in .git/lost-found"
+msgstr "ghi các đối tượng không được quản lý trong .git/lost-found"
 
-#: builtin/describe.c:524
-msgid "use any ref"
-msgstr "dùng ref bất kỳ"
+#: builtin/fsck.c:786 builtin/prune.c:132
+msgid "show progress"
+msgstr "hiển thị quá trình"
 
-#: builtin/describe.c:525
-msgid "use any tag, even unannotated"
-msgstr "dùng thẻ bất kỳ, cả khi “unannotated”"
+#: builtin/fsck.c:787
+msgid "show verbose names for reachable objects"
+msgstr "hiển thị tên chi tiết cho các đối tượng đọc được"
 
-#: builtin/describe.c:526
-msgid "always use long format"
-msgstr "luôn dùng định dạng dài"
+#: builtin/fsck.c:846 builtin/index-pack.c:225
+msgid "Checking objects"
+msgstr "Đang kiểm tra các đối tượng"
 
-#: builtin/describe.c:527
-msgid "only follow first parent"
-msgstr "chỉ theo cha mẹ đầu tiên"
+#: builtin/fsck.c:874
+#, c-format
+msgid "%s: object missing"
+msgstr "%s: thiếu đối tượng"
 
-#: builtin/describe.c:530
-msgid "only output exact matches"
-msgstr "chỉ xuất những gì khớp chính xác"
+#: builtin/fsck.c:885
+#, c-format
+msgid "invalid parameter: expected sha1, got '%s'"
+msgstr "tham số không hợp lệ: cần sha1, nhưng lại nhận được “%s”"
 
-#: builtin/describe.c:532
-msgid "consider <n> most recent tags (default: 10)"
-msgstr "coi như <n> thẻ gần đây nhất (mặc định: 10)"
+#: builtin/gc.c:35
+msgid "git gc [<options>]"
+msgstr "git gc [<các tùy chọn>]"
 
-#: builtin/describe.c:534
-msgid "only consider tags matching <pattern>"
-msgstr "chỉ cân nhắc đến những thẻ khớp với <mẫu>"
+#: builtin/gc.c:90
+#, c-format
+msgid "Failed to fstat %s: %s"
+msgstr "Gặp lỗi khi lấy thông tin thống kê về tập tin %s: %s"
 
-#: builtin/describe.c:536
-msgid "do not consider tags matching <pattern>"
-msgstr "không coi rằng các thẻ khớp với <mẫu>"
+#: builtin/gc.c:126
+#, c-format
+msgid "failed to parse '%s' value '%s'"
+msgstr "gặp lỗi khi phân tích “%s” giá trị “%s”"
 
-#: builtin/describe.c:538 builtin/name-rev.c:406
-msgid "show abbreviated commit object as fallback"
-msgstr "hiển thị đối tượng chuyển giao vắn tắt như là fallback"
+#: builtin/gc.c:475 builtin/init-db.c:55
+#, c-format
+msgid "cannot stat '%s'"
+msgstr "không thể lấy thông tin thống kê về “%s”"
 
-#: builtin/describe.c:539 builtin/describe.c:542
-msgid "mark"
-msgstr "dấu"
+#: builtin/gc.c:484 builtin/notes.c:240 builtin/tag.c:529
+#, c-format
+msgid "cannot read '%s'"
+msgstr "không thể đọc “%s”"
 
-#: builtin/describe.c:540
-msgid "append <mark> on dirty working tree (default: \"-dirty\")"
-msgstr "thêm <dấu> trên cây thư mục làm việc bẩn (mặc định \"-dirty\")"
+#: builtin/gc.c:491
+#, c-format
+msgid ""
+"The last gc run reported the following. Please correct the root cause\n"
+"and remove %s.\n"
+"Automatic cleanup will not be performed until the file is removed.\n"
+"\n"
+"%s"
+msgstr ""
+"Lần chạy gc cuối đã báo cáo các vấn đề sau đây. Vui lòng sửa nguyên nhân\n"
+"tận gốc và xóa bỏ %s.\n"
+"Việc tự động dọn dẹp sẽ không thực thi cho đến khi tập tin được xóa bỏ.\n"
+"\n"
+"%s"
 
-#: builtin/describe.c:543
-msgid "append <mark> on broken working tree (default: \"-broken\")"
-msgstr "thêm <dấu> trên cây thư mục làm việc bị hỏng (mặc định \"-broken\")"
+#: builtin/gc.c:539
+msgid "prune unreferenced objects"
+msgstr "xóa bỏ các đối tượng không được tham chiếu"
 
-#: builtin/describe.c:561
-msgid "--long is incompatible with --abbrev=0"
-msgstr "--long là xung khắc với tùy chọn --abbrev=0"
+#: builtin/gc.c:541
+msgid "be more thorough (increased runtime)"
+msgstr "cẩn thận hơn nữa (tăng thời gian chạy)"
 
-#: builtin/describe.c:590
-msgid "No names found, cannot describe anything."
-msgstr "Không tìm thấy các tên, không thể mô tả gì cả."
+#: builtin/gc.c:542
+msgid "enable auto-gc mode"
+msgstr "bật chế độ auto-gc"
 
-#: builtin/describe.c:640
-msgid "--dirty is incompatible with commit-ishes"
-msgstr "--dirty là xung khắc với các tùy chọn commit-ish"
+#: builtin/gc.c:545
+msgid "force running gc even if there may be another gc running"
+msgstr "buộc gc chạy ngay cả khi có tiến trình gc khác đang chạy"
 
-#: builtin/describe.c:642
-msgid "--broken is incompatible with commit-ishes"
-msgstr "--broken là xung khắc với commit-ishes"
+#: builtin/gc.c:548
+msgid "repack all other packs except the largest pack"
+msgstr "đóng gói lại tất cả các gói khác ngoại trừ gói lớn nhất"
 
-#: builtin/diff.c:83
+#: builtin/gc.c:565
 #, c-format
-msgid "'%s': not a regular file or symlink"
-msgstr "“%s”: không phải tập tin bình thường hay liên kết mềm"
+msgid "failed to parse gc.logexpiry value %s"
+msgstr "gặp lỗi khi phân tích giá trị gc.logexpiry %s"
 
-#: builtin/diff.c:234
+#: builtin/gc.c:576
 #, c-format
-msgid "invalid option: %s"
-msgstr "tùy chọn không hợp lệ: %s"
+msgid "failed to parse prune expiry value %s"
+msgstr "gặp lỗi khi phân tích giá trị prune %s"
 
-#: builtin/diff.c:356
-msgid "Not a git repository"
-msgstr "Không phải là kho git"
+#: builtin/gc.c:596
+#, c-format
+msgid "Auto packing the repository in background for optimum performance.\n"
+msgstr ""
+"Tự động đóng gói kho chứa trên nền hệ thống để tối ưu hóa hiệu suất làm "
+"việc.\n"
 
-#: builtin/diff.c:399
+#: builtin/gc.c:598
 #, c-format
-msgid "invalid object '%s' given."
-msgstr "đối tượng đã cho “%s” không hợp lệ."
+msgid "Auto packing the repository for optimum performance.\n"
+msgstr "Tự động đóng gói kho chứa để tối ưu hóa hiệu suất làm việc.\n"
 
-#: builtin/diff.c:408
+#: builtin/gc.c:599
 #, c-format
-msgid "more than two blobs given: '%s'"
-msgstr "đã cho nhiều hơn hai đối tượng blob: “%s”"
+msgid "See \"git help gc\" for manual housekeeping.\n"
+msgstr "Xem \"git help gc\" để có hướng dẫn cụ thể về cách dọn dẹp kho git.\n"
 
-#: builtin/diff.c:413
+#: builtin/gc.c:639
 #, c-format
-msgid "unhandled object '%s' given."
-msgstr "đã cho đối tượng không thể nắm giữ “%s”."
+msgid ""
+"gc is already running on machine '%s' pid %<PRIuMAX> (use --force if not)"
+msgstr ""
+"gc đang được thực hiện trên máy “%s” pid %<PRIuMAX> (dùng --force nếu không "
+"phải thế)"
 
-#: builtin/difftool.c:29
-msgid "git difftool [<options>] [<commit> [<commit>]] [--] [<path>...]"
+#: builtin/gc.c:694
+msgid ""
+"There are too many unreachable loose objects; run 'git prune' to remove them."
 msgstr ""
-"git difftool [<các-tùy-chọn>] [<lần_chuyển_giao> [<lần_chuyển_giao>]] [--] "
-"<đường-dẫn>…]"
+"Có quá nhiều đối tượng tự do không được dùng đến; hãy chạy lệnh “git prune” "
+"để xóa bỏ chúng đi."
+
+#: builtin/grep.c:29
+msgid "git grep [<options>] [-e] <pattern> [<rev>...] [[--] <path>...]"
+msgstr "git grep [<các tùy chọn>] [-e] <mẫu> [<rev>…] [[--] </đường/dẫn>…]"
 
-#: builtin/difftool.c:259
+#: builtin/grep.c:225
 #, c-format
-msgid "failed: %d"
-msgstr "gặp lỗi: %d"
+msgid "grep: failed to create thread: %s"
+msgstr "grep: gặp lỗi tạo tuyến (thread): %s"
 
-#: builtin/difftool.c:301
+#: builtin/grep.c:279
 #, c-format
-msgid "could not read symlink %s"
-msgstr "không thể đọc liên kết mềm %s"
+msgid "invalid number of threads specified (%d) for %s"
+msgstr "số tuyến đã cho không hợp lệ (%d) cho %s"
 
-#: builtin/difftool.c:303
+#. TRANSLATORS: %s is the configuration
+#. variable for tweaking threads, currently
+#. grep.threads
+#.
+#: builtin/grep.c:287 builtin/index-pack.c:1534 builtin/index-pack.c:1727
+#: builtin/pack-objects.c:2708
 #, c-format
-msgid "could not read symlink file %s"
-msgstr "không đọc được tập tin liên kết mềm %s"
+msgid "no threads support, ignoring %s"
+msgstr "không hỗ trợ đa tuyến, bỏ qua %s"
 
-#: builtin/difftool.c:311
+#: builtin/grep.c:467 builtin/grep.c:592 builtin/grep.c:635
 #, c-format
-msgid "could not read object %s for symlink %s"
-msgstr "Không thể đọc đối tượng %s cho liên kết mềm %s"
+msgid "unable to read tree (%s)"
+msgstr "không thể đọc cây (%s)"
 
-#: builtin/difftool.c:412
-msgid ""
-"combined diff formats('-c' and '--cc') are not supported in\n"
-"directory diff mode('-d' and '--dir-diff')."
-msgstr ""
-"các định dạng diff tổ hợp(“-c” và “--cc”) chưa được hỗ trợ trong\n"
-"chế độ diff thư mục(“-d” và “--dir-diff”)."
+#: builtin/grep.c:650
+#, c-format
+msgid "unable to grep from object of type %s"
+msgstr "không thể thực hiện lệnh grep (lọc tìm) từ đối tượng thuộc kiểu %s"
 
-#: builtin/difftool.c:632
+#: builtin/grep.c:716
 #, c-format
-msgid "both files modified: '%s' and '%s'."
-msgstr "cả hai tập tin đã bị sửa: “%s” và “%s”."
+msgid "switch `%c' expects a numerical value"
+msgstr "chuyển đến “%c” cần một giá trị bằng số"
 
-#: builtin/difftool.c:634
-msgid "working tree file has been left."
-msgstr "cây làm việc ở bên trái."
+#: builtin/grep.c:815
+msgid "search in index instead of in the work tree"
+msgstr "tìm trong bảng mục lục thay vì trong cây làm việc"
 
-#: builtin/difftool.c:645
-#, c-format
-msgid "temporary files exist in '%s'."
-msgstr "các tập tin tạm đã sẵn có trong “%s”."
+#: builtin/grep.c:817
+msgid "find in contents not managed by git"
+msgstr "tìm trong nội dung không được quản lý bởi git"
 
-#: builtin/difftool.c:646
-msgid "you may want to cleanup or recover these."
-msgstr "bạn có lẽ muốn dọn dẹp hay "
+#: builtin/grep.c:819
+msgid "search in both tracked and untracked files"
+msgstr "tìm kiếm các tập tin được và chưa được theo dõi dấu vết"
 
-#: builtin/difftool.c:695
-msgid "use `diff.guitool` instead of `diff.tool`"
-msgstr "dùng “diff.guitool“ thay vì dùng “diff.tool“"
+#: builtin/grep.c:821
+msgid "ignore files specified via '.gitignore'"
+msgstr "các tập tin bị bỏ qua được chỉ định thông qua “.gitignore”"
 
-#: builtin/difftool.c:697
-msgid "perform a full-directory diff"
-msgstr "thực hiện một diff toàn thư mục"
+#: builtin/grep.c:823
+msgid "recursively search in each submodule"
+msgstr "tìm kiếm đệ quy trong từng mô-đun-con"
 
-#: builtin/difftool.c:699
-msgid "do not prompt before launching a diff tool"
-msgstr "đừng nhắc khi khởi chạy công cụ diff"
+#: builtin/grep.c:826
+msgid "show non-matching lines"
+msgstr "hiển thị những dòng không khớp với mẫu"
 
-#: builtin/difftool.c:704
-msgid "use symlinks in dir-diff mode"
-msgstr "dùng liên kết mềm trong diff-thư-mục"
+#: builtin/grep.c:828
+msgid "case insensitive matching"
+msgstr "phân biệt HOA/thường"
 
-#: builtin/difftool.c:705
-msgid "<tool>"
-msgstr "<công_cụ>"
+#: builtin/grep.c:830
+msgid "match patterns only at word boundaries"
+msgstr "chỉ khớp mẫu tại đường ranh giới từ"
 
-#: builtin/difftool.c:706
-msgid "use the specified diff tool"
-msgstr "dùng công cụ diff đã cho"
+#: builtin/grep.c:832
+msgid "process binary files as text"
+msgstr "xử lý tập tin nhị phân như là dạng văn bản thường"
 
-#: builtin/difftool.c:708
-msgid "print a list of diff tools that may be used with `--tool`"
-msgstr "in ra danh sách các công cụ dif cái mà có thẻ dùng với “--tool“"
+#: builtin/grep.c:834
+msgid "don't match patterns in binary files"
+msgstr "không khớp mẫu trong các tập tin nhị phân"
 
-#: builtin/difftool.c:711
-msgid ""
-"make 'git-difftool' exit when an invoked diff tool returns a non - zero exit "
-"code"
-msgstr ""
-"làm cho “git-difftool” thoát khi gọi công cụ diff trả về mã không phải số "
-"không"
+#: builtin/grep.c:837
+msgid "process binary files with textconv filters"
+msgstr "xử lý tập tin nhị phân với các bộ lọc “textconv”"
 
-#: builtin/difftool.c:713
-msgid "<command>"
-msgstr "<lệnh>"
+#: builtin/grep.c:839
+msgid "search in subdirectories (default)"
+msgstr "tìm kiếm trong thư mục con (mặc định)"
 
-#: builtin/difftool.c:714
-msgid "specify a custom command for viewing diffs"
-msgstr "chỉ định một lệnh tùy ý để xem diff"
+#: builtin/grep.c:841
+msgid "descend at most <depth> levels"
+msgstr "hạ xuống ít nhất là mức <sâu>"
+
+#: builtin/grep.c:845
+msgid "use extended POSIX regular expressions"
+msgstr "dùng biểu thức chính qui POSIX có mở rộng"
+
+#: builtin/grep.c:848
+msgid "use basic POSIX regular expressions (default)"
+msgstr "sử dụng biểu thức chính quy kiểu POSIX (mặc định)"
+
+#: builtin/grep.c:851
+msgid "interpret patterns as fixed strings"
+msgstr "diễn dịch các mẫu như là chuỗi cố định"
+
+#: builtin/grep.c:854
+msgid "use Perl-compatible regular expressions"
+msgstr "sử dụng biểu thức chính quy tương thích Perl"
+
+#: builtin/grep.c:857
+msgid "show line numbers"
+msgstr "hiển thị số của dòng"
 
-#: builtin/difftool.c:738
-msgid "no <tool> given for --tool=<tool>"
-msgstr "chưa đưa ra <công_cụ> cho --tool=<công_cụ>"
+#: builtin/grep.c:858
+msgid "show column number of first match"
+msgstr "hiển thị số cột của khớp với mẫu đầu tiên"
 
-#: builtin/difftool.c:745
-msgid "no <cmd> given for --extcmd=<cmd>"
-msgstr "chưa đưa ra <lệnh> cho --extcmd=<lệnh>"
+#: builtin/grep.c:859
+msgid "don't show filenames"
+msgstr "không hiển thị tên tập tin"
 
-#: builtin/fast-export.c:27
-msgid "git fast-export [rev-list-opts]"
-msgstr "git fast-export [rev-list-opts]"
+#: builtin/grep.c:860
+msgid "show filenames"
+msgstr "hiển thị các tên tập tin"
 
-#: builtin/fast-export.c:1000
-msgid "show progress after <n> objects"
-msgstr "hiển thị tiến triển sau <n> đối tượng"
+#: builtin/grep.c:862
+msgid "show filenames relative to top directory"
+msgstr "hiển thị tên tập tin tương đối với thư mục đỉnh (top)"
 
-#: builtin/fast-export.c:1002
-msgid "select handling of signed tags"
-msgstr "chọn điều khiển của thẻ đã ký"
+#: builtin/grep.c:864
+msgid "show only filenames instead of matching lines"
+msgstr "chỉ hiển thị tên tập tin thay vì những dòng khớp với mẫu"
 
-#: builtin/fast-export.c:1005
-msgid "select handling of tags that tag filtered objects"
-msgstr "chọn sự xử lý của các thẻ, cái mà đánh thẻ các đối tượng được lọc ra"
+#: builtin/grep.c:866
+msgid "synonym for --files-with-matches"
+msgstr "đồng nghĩa với --files-with-matches"
 
-#: builtin/fast-export.c:1008
-msgid "Dump marks to this file"
-msgstr "Đổ các đánh dấu này vào tập-tin"
+#: builtin/grep.c:869
+msgid "show only the names of files without match"
+msgstr "chỉ hiển thị tên cho những tập tin không khớp với mẫu"
 
-#: builtin/fast-export.c:1010
-msgid "Import marks from this file"
-msgstr "nhập vào đánh dấu từ tập tin này"
+#: builtin/grep.c:871
+msgid "print NUL after filenames"
+msgstr "thêm NUL vào sau tên tập tin"
 
-#: builtin/fast-export.c:1012
-msgid "Fake a tagger when tags lack one"
-msgstr "Làm giả một cái thẻ khi thẻ bị thiếu một cái"
+#: builtin/grep.c:874
+msgid "show only matching parts of a line"
+msgstr "chỉ hiển thị những phần khớp với mẫu của một dòng"
 
-#: builtin/fast-export.c:1014
-msgid "Output full tree for each commit"
-msgstr "Xuất ra toàn bộ cây cho mỗi lần chuyển giao"
+#: builtin/grep.c:876
+msgid "show the number of matches instead of matching lines"
+msgstr "hiển thị số lượng khớp thay vì những dòng khớp với mẫu"
 
-#: builtin/fast-export.c:1016
-msgid "Use the done feature to terminate the stream"
-msgstr "Sử dụng tính năng done để chấm dứt luồng dữ liệu"
+#: builtin/grep.c:877
+msgid "highlight matches"
+msgstr "tô sáng phần khớp mẫu"
 
-#: builtin/fast-export.c:1017
-msgid "Skip output of blob data"
-msgstr "Bỏ qua kết xuất của dữ liệu blob"
+#: builtin/grep.c:879
+msgid "print empty line between matches from different files"
+msgstr "hiển thị dòng trống giữa các lần khớp từ các tập tin khác biệt"
 
-#: builtin/fast-export.c:1018
-msgid "refspec"
-msgstr "refspec"
+#: builtin/grep.c:881
+msgid "show filename only once above matches from same file"
+msgstr ""
+"hiển thị tên tập tin một lần phía trên các lần khớp từ cùng một tập tin"
 
-#: builtin/fast-export.c:1019
-msgid "Apply refspec to exported refs"
-msgstr "Áp dụng refspec cho refs đã xuất"
+#: builtin/grep.c:884
+msgid "show <n> context lines before and after matches"
+msgstr "hiển thị <n> dòng nội dung phía trước và sau các lần khớp"
 
-#: builtin/fast-export.c:1020
-msgid "anonymize output"
-msgstr "kết xuất anonymize"
+#: builtin/grep.c:887
+msgid "show <n> context lines before matches"
+msgstr "hiển thị <n> dòng nội dung trước khớp"
 
-#: builtin/fetch.c:26
-msgid "git fetch [<options>] [<repository> [<refspec>...]]"
-msgstr "git fetch [<các-tùy-chọn>] [<kho-chứa> [<refspec>…]]"
+#: builtin/grep.c:889
+msgid "show <n> context lines after matches"
+msgstr "hiển thị <n> dòng nội dung sau khớp"
 
-#: builtin/fetch.c:27
-msgid "git fetch [<options>] <group>"
-msgstr "git fetch [<các-tùy-chọn>] [<nhóm>"
+#: builtin/grep.c:891
+msgid "use <n> worker threads"
+msgstr "dùng <n> tuyến trình làm việc"
 
-#: builtin/fetch.c:28
-msgid "git fetch --multiple [<options>] [(<repository> | <group>)...]"
-msgstr "git fetch --multiple [<các-tùy-chọn>] [(<kho> | <nhóm>)…]"
+#: builtin/grep.c:892
+msgid "shortcut for -C NUM"
+msgstr "dạng viết tắt của -C SỐ"
 
-#: builtin/fetch.c:29
-msgid "git fetch --all [<options>]"
-msgstr "git fetch --all [<các-tùy-chọn>]"
+#: builtin/grep.c:895
+msgid "show a line with the function name before matches"
+msgstr "hiển thị dòng vói tên hàm trước các lần khớp"
 
-#: builtin/fetch.c:123 builtin/pull.c:193
-msgid "fetch from all remotes"
-msgstr "lấy về từ tất cả các máy chủ"
+#: builtin/grep.c:897
+msgid "show the surrounding function"
+msgstr "hiển thị hàm bao quanh"
 
-#: builtin/fetch.c:125 builtin/pull.c:196
-msgid "append to .git/FETCH_HEAD instead of overwriting"
-msgstr "nối thêm vào .git/FETCH_HEAD thay vì ghi đè lên nó"
+#: builtin/grep.c:900
+msgid "read patterns from file"
+msgstr "đọc mẫu từ tập-tin"
 
-#: builtin/fetch.c:127 builtin/pull.c:199
-msgid "path to upload pack on remote end"
-msgstr "đường dẫn đến gói tải lên trên máy chủ cuối"
+#: builtin/grep.c:902
+msgid "match <pattern>"
+msgstr "match <mẫu>"
 
-#: builtin/fetch.c:128 builtin/pull.c:201
-msgid "force overwrite of local branch"
-msgstr "ép buộc ghi đè lên nhánh nội bộ"
+#: builtin/grep.c:904
+msgid "combine patterns specified with -e"
+msgstr "tổ hợp mẫu được chỉ ra với tùy chọn -e"
 
-#: builtin/fetch.c:130
-msgid "fetch from multiple remotes"
-msgstr "lấy từ nhiều máy chủ cùng lúc"
+#: builtin/grep.c:916
+msgid "indicate hit with exit status without output"
+msgstr "đưa ra gợi ý với trạng thái thoát mà không có kết xuất"
 
-#: builtin/fetch.c:132 builtin/pull.c:203
-msgid "fetch all tags and associated objects"
-msgstr "lấy tất cả các thẻ cùng với các đối tượng liên quan đến nó"
+#: builtin/grep.c:918
+msgid "show only matches from files that match all patterns"
+msgstr "chỉ hiển thị những cái khớp từ tập tin mà nó khớp toàn bộ các mẫu"
 
-#: builtin/fetch.c:134
-msgid "do not fetch all tags (--no-tags)"
-msgstr "không lấy tất cả các thẻ (--no-tags)"
+#: builtin/grep.c:920
+msgid "show parse tree for grep expression"
+msgstr "hiển thị cây phân tích cú pháp cho biểu thức “grep” (tìm kiếm)"
 
-#: builtin/fetch.c:136
-msgid "number of submodules fetched in parallel"
-msgstr "số lượng mô-đun-con được lấy đồng thời"
+#: builtin/grep.c:924
+msgid "pager"
+msgstr "dàn trang"
 
-#: builtin/fetch.c:138 builtin/pull.c:206
-msgid "prune remote-tracking branches no longer on remote"
-msgstr ""
-"cắt cụt (prune) các nhánh “remote-tracking” không còn tồn tại trên máy chủ "
-"nữa"
+#: builtin/grep.c:924
+msgid "show matching files in the pager"
+msgstr "hiển thị các tập tin khớp trong trang giấy"
 
-#: builtin/fetch.c:140
-msgid "prune local tags no longer on remote and clobber changed tags"
-msgstr "cắt xém các thẻ nội bộ không còn ở máy chủ và xóa các thẻ đã thay đổi"
+#: builtin/grep.c:928
+msgid "allow calling of grep(1) (ignored by this build)"
+msgstr "cho phép gọi grep(1) (bị bỏ qua bởi lần dịch này)"
 
-#: builtin/fetch.c:141 builtin/fetch.c:164 builtin/pull.c:131
-msgid "on-demand"
-msgstr "khi-cần"
+#: builtin/grep.c:992
+msgid "no pattern given"
+msgstr "chưa chỉ ra mẫu"
 
-#: builtin/fetch.c:142
-msgid "control recursive fetching of submodules"
-msgstr "điều khiển việc lấy về đệ quy trong các mô-đun-con"
+#: builtin/grep.c:1028
+msgid "--no-index or --untracked cannot be used with revs"
+msgstr "--no-index hay --untracked không được sử dụng cùng với revs"
 
-#: builtin/fetch.c:146 builtin/pull.c:214
-msgid "keep downloaded pack"
-msgstr "giữ lại gói đã tải về"
+#: builtin/grep.c:1036
+#, c-format
+msgid "unable to resolve revision: %s"
+msgstr "không thể phân giải điểm xét duyệt: %s"
 
-#: builtin/fetch.c:148
-msgid "allow updating of HEAD ref"
-msgstr "cho phép cập nhật th.chiếu HEAD"
+#: builtin/grep.c:1067
+msgid "invalid option combination, ignoring --threads"
+msgstr "tổ hợp tùy chọn không hợp lệ, bỏ qua --threads"
 
-#: builtin/fetch.c:151 builtin/fetch.c:157 builtin/pull.c:217
-msgid "deepen history of shallow clone"
-msgstr "làm sâu hơn lịch sử của bản sao"
+#: builtin/grep.c:1070 builtin/pack-objects.c:3400
+msgid "no threads support, ignoring --threads"
+msgstr "không hỗ trợ đa tuyến, bỏ qua --threads"
 
-#: builtin/fetch.c:153
-msgid "deepen history of shallow repository based on time"
-msgstr "làm sâu hơn lịch sử của kho bản sao shallow dựa trên thời gian"
+#: builtin/grep.c:1073 builtin/index-pack.c:1531 builtin/pack-objects.c:2705
+#, c-format
+msgid "invalid number of threads specified (%d)"
+msgstr "số tuyến chỉ ra không hợp lệ (%d)"
 
-#: builtin/fetch.c:159 builtin/pull.c:220
-msgid "convert to a complete repository"
-msgstr "chuyển đổi hoàn toàn sang kho git"
+#: builtin/grep.c:1096
+msgid "--open-files-in-pager only works on the worktree"
+msgstr "--open-files-in-pager chỉ làm việc trên cây-làm-việc"
 
-#: builtin/fetch.c:162
-msgid "prepend this to submodule path output"
-msgstr "soạn sẵn cái này cho kết xuất đường dẫn mô-đun-con"
+#: builtin/grep.c:1119
+msgid "option not supported with --recurse-submodules"
+msgstr "tùy chọn không được hỗ trợ với --recurse-submodules"
+
+#: builtin/grep.c:1125
+msgid "--cached or --untracked cannot be used with --no-index"
+msgstr "--cached hay --untracked không được sử dụng với --no-index"
+
+#: builtin/grep.c:1131
+msgid "--[no-]exclude-standard cannot be used for tracked contents"
+msgstr "--[no-]exclude-standard không thể sử dụng cho nội dung lưu dấu vết"
+
+#: builtin/grep.c:1139
+msgid "both --cached and trees are given"
+msgstr "cả hai --cached và các cây phải được chỉ ra"
 
-#: builtin/fetch.c:165
+#: builtin/hash-object.c:85
 msgid ""
-"default for recursive fetching of submodules (lower priority than config "
-"files)"
+"git hash-object [-t <type>] [-w] [--path=<file> | --no-filters] [--stdin] "
+"[--] <file>..."
 msgstr ""
-"mặc định cho việc lấy đệ quy các mô-đun-con (có mức ưu tiên thấp hơn các tập "
-"tin cấu hình config)"
+"git hash-object [-t <kiểu>] [-w] [--path=<tập-tin> | --no-filters] [--stdin] "
+"[--] <tập-tin>…"
 
-#: builtin/fetch.c:169 builtin/pull.c:223
-msgid "accept refs that update .git/shallow"
-msgstr "chấp nhận tham chiếu cập nhật .git/shallow"
+#: builtin/hash-object.c:86
+msgid "git hash-object  --stdin-paths"
+msgstr "git hash-object  --stdin-paths"
 
-#: builtin/fetch.c:170 builtin/pull.c:225
-msgid "refmap"
-msgstr "refmap"
+#: builtin/hash-object.c:98
+msgid "object type"
+msgstr "kiểu đối tượng"
 
-#: builtin/fetch.c:171 builtin/pull.c:226
-msgid "specify fetch refmap"
-msgstr "chỉ ra refmap cần lấy về"
+#: builtin/hash-object.c:99
+msgid "write the object into the object database"
+msgstr "ghi đối tượng vào dữ liệu đối tượng"
 
-#: builtin/fetch.c:172 builtin/ls-remote.c:77 builtin/push.c:582
-#: builtin/send-pack.c:172
-msgid "server-specific"
-msgstr "đặc-tả-máy-phục-vụ"
+#: builtin/hash-object.c:101
+msgid "read the object from stdin"
+msgstr "đọc đối tượng từ đầu vào tiêu chuẩn stdin"
 
-#: builtin/fetch.c:172 builtin/ls-remote.c:77 builtin/push.c:582
-#: builtin/send-pack.c:173
-msgid "option to transmit"
-msgstr "tùy chọn để chuyển giao"
+#: builtin/hash-object.c:103
+msgid "store file as is without filters"
+msgstr "lưu các tập tin mà nó không có các bộ lọc"
 
-#: builtin/fetch.c:442
-msgid "Couldn't find remote ref HEAD"
-msgstr "Không thể tìm thấy máy chủ cho tham chiếu HEAD"
+#: builtin/hash-object.c:104
+msgid ""
+"just hash any random garbage to create corrupt objects for debugging Git"
+msgstr "chỉ cần băm rác ngẫu nhiên để tạo một đối tượng hỏng để mà gỡ lỗi Git"
 
-#: builtin/fetch.c:560
-#, c-format
-msgid "configuration fetch.output contains invalid value %s"
-msgstr "phần cấu hình fetch.output có chứa giá-trị không hợp lệ %s"
+#: builtin/hash-object.c:105
+msgid "process file as it were from this path"
+msgstr "xử lý tập tin như là nó đang ở thư mục này"
 
-#: builtin/fetch.c:653
-#, c-format
-msgid "object %s not found"
-msgstr "Không tìm thấy đối tượng %s"
+#: builtin/help.c:46
+msgid "print all available commands"
+msgstr "hiển thị danh sách các câu lệnh người dùng có thể sử dụng"
 
-#: builtin/fetch.c:657
-msgid "[up to date]"
-msgstr "[đã cập nhật]"
+#: builtin/help.c:47
+msgid "exclude guides"
+msgstr "hướng dẫn loại trừ"
 
-#: builtin/fetch.c:670 builtin/fetch.c:750
-msgid "[rejected]"
-msgstr "[Bị từ chối]"
+#: builtin/help.c:48
+msgid "print list of useful guides"
+msgstr "hiển thị danh sách các hướng dẫn hữu dụng"
 
-#: builtin/fetch.c:671
-msgid "can't fetch in current branch"
-msgstr "không thể fetch (lấy) về nhánh hiện hành"
+#: builtin/help.c:49
+msgid "print all configuration variable names"
+msgstr "in ra tất cả các tên biến cấu hình"
 
-#: builtin/fetch.c:680
-msgid "[tag update]"
-msgstr "[cập nhật thẻ]"
+#: builtin/help.c:51
+msgid "show man page"
+msgstr "hiển thị trang man"
 
-#: builtin/fetch.c:681 builtin/fetch.c:714 builtin/fetch.c:730
-#: builtin/fetch.c:745
-msgid "unable to update local ref"
-msgstr "không thể cập nhật tham chiếu nội bộ"
+#: builtin/help.c:52
+msgid "show manual in web browser"
+msgstr "hiển thị hướng dẫn sử dụng trong trình duyệt web"
 
-#: builtin/fetch.c:700
-msgid "[new tag]"
-msgstr "[thẻ mới]"
+#: builtin/help.c:54
+msgid "show info page"
+msgstr "hiện trang info"
 
-#: builtin/fetch.c:703
-msgid "[new branch]"
-msgstr "[nhánh mới]"
+#: builtin/help.c:56
+msgid "print command description"
+msgstr "hiển thị mô tả lệnh"
 
-#: builtin/fetch.c:706
-msgid "[new ref]"
-msgstr "[ref (tham chiếu) mới]"
+#: builtin/help.c:61
+msgid "git help [--all] [--guides] [--man | --web | --info] [<command>]"
+msgstr "git help [--all] [--guides] [--man | --web | --info] [<lệnh>]"
 
-#: builtin/fetch.c:745
-msgid "forced update"
-msgstr "cưỡng bức cập nhật"
+#: builtin/help.c:77
+#, c-format
+msgid "unrecognized help format '%s'"
+msgstr "không nhận ra định dạng trợ giúp “%s”"
 
-#: builtin/fetch.c:750
-msgid "non-fast-forward"
-msgstr "không-phải-chuyển-tiếp-nhanh"
+#: builtin/help.c:104
+msgid "Failed to start emacsclient."
+msgstr "Gặp lỗi khi khởi chạy emacsclient."
 
-#: builtin/fetch.c:795
-#, c-format
-msgid "%s did not send all necessary objects\n"
-msgstr "%s đã không gửi tất cả các đối tượng cần thiết\n"
+#: builtin/help.c:117
+msgid "Failed to parse emacsclient version."
+msgstr "Gặp lỗi khi phân tích phiên bản emacsclient."
 
-#: builtin/fetch.c:815
+#: builtin/help.c:125
 #, c-format
-msgid "reject %s because shallow roots are not allowed to be updated"
-msgstr "từ chối %s bởi vì các gốc nông thì không được phép cập nhật"
+msgid "emacsclient version '%d' too old (< 22)."
+msgstr "phiên bản của emacsclient “%d” quá cũ (< 22)."
 
-#: builtin/fetch.c:903 builtin/fetch.c:999
+#: builtin/help.c:143 builtin/help.c:165 builtin/help.c:175 builtin/help.c:183
 #, c-format
-msgid "From %.*s\n"
-msgstr "Từ %.*s\n"
+msgid "failed to exec '%s'"
+msgstr "gặp lỗi khi thực thi “%s”"
 
-#: builtin/fetch.c:914
+#: builtin/help.c:221
 #, c-format
 msgid ""
-"some local refs could not be updated; try running\n"
-" 'git remote prune %s' to remove any old, conflicting branches"
+"'%s': path for unsupported man viewer.\n"
+"Please consider using 'man.<tool>.cmd' instead."
 msgstr ""
-"một số tham chiếu nội bộ không thể được cập nhật; hãy thử chạy\n"
-" “git remote prune %s” để bỏ đi những nhánh cũ, hay bị xung đột"
+"“%s”: đường dẫn không hỗ trợ bộ trình chiếu man.\n"
+"Hãy cân nhắc đến việc sử dụng “man.<tool>.cmd” để thay thế."
 
-#: builtin/fetch.c:969
+#: builtin/help.c:233
 #, c-format
-msgid "   (%s will become dangling)"
-msgstr "   (%s sẽ trở thành không đầu (không được quản lý))"
+msgid ""
+"'%s': cmd for supported man viewer.\n"
+"Please consider using 'man.<tool>.path' instead."
+msgstr ""
+"“%s”: cmd (lệnh) hỗ trợ bộ trình chiếu man.\n"
+"Hãy cân nhắc đến việc sử dụng “man.<tool>.path” để thay thế."
 
-#: builtin/fetch.c:970
+#: builtin/help.c:350
 #, c-format
-msgid "   (%s has become dangling)"
-msgstr "   (%s đã trở thành không đầu (không được quản lý))"
+msgid "'%s': unknown man viewer."
+msgstr "“%s”: không rõ chương trình xem man."
 
-#: builtin/fetch.c:1002
-msgid "[deleted]"
-msgstr "[đã xóa]"
+#: builtin/help.c:367
+msgid "no man viewer handled the request"
+msgstr "không có trình xem trợ giúp dạng manpage tiếp hợp với yêu cầu"
 
-#: builtin/fetch.c:1003 builtin/remote.c:1033
-msgid "(none)"
-msgstr "(không)"
+#: builtin/help.c:375
+msgid "no info viewer handled the request"
+msgstr "không có trình xem trợ giúp dạng info tiếp hợp với yêu cầu"
 
-#: builtin/fetch.c:1026
+#: builtin/help.c:434 builtin/help.c:445 git.c:336
 #, c-format
-msgid "Refusing to fetch into current branch %s of non-bare repository"
-msgstr ""
-"Từ chối việc lấy vào trong nhánh hiện tại %s của một kho chứa không phải kho "
-"trần (bare)"
+msgid "'%s' is aliased to '%s'"
+msgstr "“%s” được đặt bí danh thành “%s”"
 
-#: builtin/fetch.c:1045
+#: builtin/help.c:448 git.c:365
 #, c-format
-msgid "Option \"%s\" value \"%s\" is not valid for %s"
-msgstr "Tùy chọn \"%s\" có giá trị \"%s\" là không hợp lệ cho %s"
+msgid "bad alias.%s string: %s"
+msgstr "chuỗi alias.%s sai: %s"
 
-#: builtin/fetch.c:1048
+#: builtin/help.c:477 builtin/help.c:507
 #, c-format
-msgid "Option \"%s\" is ignored for %s\n"
-msgstr "Tùy chọn \"%s\" bị bỏ qua với %s\n"
+msgid "usage: %s%s"
+msgstr "cách dùng: %s%s"
 
-#: builtin/fetch.c:1287
+#: builtin/help.c:491
+msgid "'git help config' for more information"
+msgstr "Chạy lệnh “git help config” để có thêm thông tin"
+
+#: builtin/index-pack.c:185
 #, c-format
-msgid "Fetching %s\n"
-msgstr "Đang lấy “%s” về\n"
+msgid "object type mismatch at %s"
+msgstr "kiểu đối tượng không khớp tại %s"
 
-#: builtin/fetch.c:1289 builtin/remote.c:98
+#: builtin/index-pack.c:205
 #, c-format
-msgid "Could not fetch %s"
-msgstr "không thể “%s” về"
+msgid "did not receive expected object %s"
+msgstr "không thể lấy về đối tượng cần %s"
 
-#: builtin/fetch.c:1335 builtin/fetch.c:1503
-msgid ""
-"--filter can only be used with the remote configured in core.partialClone"
-msgstr ""
-"--filter chỉ có thể được dùng với máy chủ được cấu hình bằng core."
-"partialClone"
+#: builtin/index-pack.c:208
+#, c-format
+msgid "object %s: expected type %s, found %s"
+msgstr "đối tượng %s: cần kiểu %s nhưng lại nhận được %s"
 
-#: builtin/fetch.c:1358
-msgid ""
-"No remote repository specified.  Please, specify either a URL or a\n"
-"remote name from which new revisions should be fetched."
-msgstr ""
-"Chưa chỉ ra kho chứa máy chủ.  Xin hãy chỉ định hoặc là URL hoặc\n"
-"tên máy chủ từ cái mà những điểm xét duyệt mới có thể được fetch (lấy về)."
+#: builtin/index-pack.c:258
+#, c-format
+msgid "cannot fill %d byte"
+msgid_plural "cannot fill %d bytes"
+msgstr[0] "không thể điền thêm vào %d byte"
 
-#: builtin/fetch.c:1395
-msgid "You need to specify a tag name."
-msgstr "Bạn phải định rõ tên thẻ."
+#: builtin/index-pack.c:268
+msgid "early EOF"
+msgstr "gặp kết thúc tập tin EOF quá sớm"
 
-#: builtin/fetch.c:1444
-msgid "Negative depth in --deepen is not supported"
-msgstr "Mức sâu là số âm trong --deepen là không được hỗ trợ"
+#: builtin/index-pack.c:269
+msgid "read error on input"
+msgstr "lỗi đọc ở đầu vào"
 
-#: builtin/fetch.c:1446
-msgid "--deepen and --depth are mutually exclusive"
-msgstr "Các tùy chọn--deepen và --depth loại từ lẫn nhau"
+#: builtin/index-pack.c:281
+msgid "used more bytes than were available"
+msgstr "sử dụng nhiều hơn số lượng byte mà nó sẵn có"
 
-#: builtin/fetch.c:1451
-msgid "--depth and --unshallow cannot be used together"
-msgstr "tùy chọn --depth và --unshallow không thể sử dụng cùng với nhau"
+#: builtin/index-pack.c:288 builtin/pack-objects.c:604
+msgid "pack too large for current definition of off_t"
+msgstr "gói quá lớn so với định nghĩa hiện tại của kiểu off_t"
 
-#: builtin/fetch.c:1453
-msgid "--unshallow on a complete repository does not make sense"
-msgstr "--unshallow trên kho hoàn chỉnh là không hợp lý"
+#: builtin/index-pack.c:291 builtin/unpack-objects.c:95
+msgid "pack exceeds maximum allowed size"
+msgstr "gói đã vượt quá cỡ tối đa được phép"
 
-#: builtin/fetch.c:1469
-msgid "fetch --all does not take a repository argument"
-msgstr "lệnh lấy về \"fetch --all\" không lấy đối số kho chứa"
+#: builtin/index-pack.c:312
+#, c-format
+msgid "cannot open packfile '%s'"
+msgstr "không thể mở packfile “%s”"
 
-#: builtin/fetch.c:1471
-msgid "fetch --all does not make sense with refspecs"
-msgstr "lệnh lấy về \"fetch --all\" không hợp lý với refspecs"
+#: builtin/index-pack.c:326
+msgid "pack signature mismatch"
+msgstr "chữ ký cho gói không khớp"
 
-#: builtin/fetch.c:1480
+#: builtin/index-pack.c:328
 #, c-format
-msgid "No such remote or remote group: %s"
-msgstr "không có nhóm máy chủ hay máy chủ như thế: %s"
+msgid "pack version %<PRIu32> unsupported"
+msgstr "không hỗ trợ phiên bản gói %<PRIu32>"
 
-#: builtin/fetch.c:1487
-msgid "Fetching a group and specifying refspecs does not make sense"
-msgstr "Việc lấy về cả một nhóm và chỉ định refspecs không hợp lý"
+#: builtin/index-pack.c:346
+#, c-format
+msgid "pack has bad object at offset %<PRIuMAX>: %s"
+msgstr "gói có đối tượng sai tại khoảng bù %<PRIuMAX>: %s"
 
-#: builtin/fmt-merge-msg.c:15
-msgid ""
-"git fmt-merge-msg [-m <message>] [--log[=<n>] | --no-log] [--file <file>]"
-msgstr ""
-"git fmt-merge-msg [-m <chú_thích>] [--log[=<n>] | --no-log] [--file <tập-"
-"tin>]"
+#: builtin/index-pack.c:466
+#, c-format
+msgid "inflate returned %d"
+msgstr "xả nén trả về %d"
 
-#: builtin/fmt-merge-msg.c:666
-msgid "populate log with at most <n> entries from shortlog"
-msgstr "gắn nhật ký với ít nhất <n> mục từ lệnh “shortlog”"
+#: builtin/index-pack.c:515
+msgid "offset value overflow for delta base object"
+msgstr "tràn giá trị khoảng bù cho đối tượng delta cơ sở"
 
-#: builtin/fmt-merge-msg.c:669
-msgid "alias for --log (deprecated)"
-msgstr "bí danh cho --log (không được dùng)"
+#: builtin/index-pack.c:523
+msgid "delta base offset is out of bound"
+msgstr "khoảng bù cơ sở cho delta nằm ngoài phạm vi"
 
-#: builtin/fmt-merge-msg.c:672
-msgid "text"
-msgstr "văn bản"
+#: builtin/index-pack.c:531
+#, c-format
+msgid "unknown object type %d"
+msgstr "không hiểu kiểu đối tượng %d"
 
-#: builtin/fmt-merge-msg.c:673
-msgid "use <text> as start of message"
-msgstr "dùng <văn bản thường> để bắt đầu ghi chú"
+#: builtin/index-pack.c:562
+msgid "cannot pread pack file"
+msgstr "không thể chạy hàm pread cho tập tin gói"
 
-#: builtin/fmt-merge-msg.c:674
-msgid "file to read from"
-msgstr "tập tin để đọc dữ liệu từ đó"
+#: builtin/index-pack.c:564
+#, c-format
+msgid "premature end of pack file, %<PRIuMAX> byte missing"
+msgid_plural "premature end of pack file, %<PRIuMAX> bytes missing"
+msgstr[0] "tập tin gói bị kết thúc sớm, thiếu %<PRIuMAX> byte"
 
-#: builtin/for-each-ref.c:10
-msgid "git for-each-ref [<options>] [<pattern>]"
-msgstr "git for-each-ref [<các-tùy-chọn>] [<mẫu>]"
+#: builtin/index-pack.c:590
+msgid "serious inflate inconsistency"
+msgstr "sự mâu thuẫn xả nén nghiêm trọng"
 
-#: builtin/for-each-ref.c:11
-msgid "git for-each-ref [--points-at <object>]"
-msgstr "git for-each-ref [--points-at <đối tượng>]"
+#: builtin/index-pack.c:735 builtin/index-pack.c:741 builtin/index-pack.c:764
+#: builtin/index-pack.c:803 builtin/index-pack.c:812
+#, c-format
+msgid "SHA1 COLLISION FOUND WITH %s !"
+msgstr "SỰ VA CHẠM SHA1 ĐÃ XẢY RA VỚI %s!"
 
-#: builtin/for-each-ref.c:12
-msgid "git for-each-ref [(--merged | --no-merged) [<commit>]]"
-msgstr "git for-each-ref [(--merged | --no-merged) [<lần-chuyển-giao>]]"
+#: builtin/index-pack.c:738 builtin/pack-objects.c:157
+#: builtin/pack-objects.c:217 builtin/pack-objects.c:311
+#, c-format
+msgid "unable to read %s"
+msgstr "không thể đọc %s"
 
-#: builtin/for-each-ref.c:13
-msgid "git for-each-ref [--contains [<commit>]] [--no-contains [<commit>]]"
-msgstr ""
-"git for-each-ref [--contains [<lần-chuyển-giao>]] [--no-contains [<lần-"
-"chuyển-giao>]]"
+#: builtin/index-pack.c:801
+#, c-format
+msgid "cannot read existing object info %s"
+msgstr "không thể đọc thông tin đối tượng sẵn có %s"
 
-#: builtin/for-each-ref.c:28
-msgid "quote placeholders suitably for shells"
-msgstr "trích dẫn để phù hợp cho hệ vỏ (shell)"
+#: builtin/index-pack.c:809
+#, c-format
+msgid "cannot read existing object %s"
+msgstr "không thể đọc đối tượng đã tồn tại %s"
 
-#: builtin/for-each-ref.c:30
-msgid "quote placeholders suitably for perl"
-msgstr "trích dẫn để phù hợp cho perl"
+#: builtin/index-pack.c:823
+#, c-format
+msgid "invalid blob object %s"
+msgstr "đối tượng blob không hợp lệ %s"
 
-#: builtin/for-each-ref.c:32
-msgid "quote placeholders suitably for python"
-msgstr "trích dẫn để phù hợp cho python"
+#: builtin/index-pack.c:826 builtin/index-pack.c:845
+msgid "fsck error in packed object"
+msgstr "lỗi fsck trong đối tượng đóng gói"
 
-#: builtin/for-each-ref.c:34
-msgid "quote placeholders suitably for Tcl"
-msgstr "trích dẫn để phù hợp cho Tcl"
+#: builtin/index-pack.c:847
+#, c-format
+msgid "Not all child objects of %s are reachable"
+msgstr "Không phải tất cả các đối tượng con của %s là có thể với tới được"
 
-#: builtin/for-each-ref.c:37
-msgid "show only <n> matched refs"
-msgstr "hiển thị chỉ <n> tham chiếu khớp"
+#: builtin/index-pack.c:919 builtin/index-pack.c:950
+msgid "failed to apply delta"
+msgstr "gặp lỗi khi áp dụng delta"
 
-#: builtin/for-each-ref.c:39 builtin/tag.c:421
-msgid "respect format colors"
-msgstr "các màu định dạng lưu tâm"
+#: builtin/index-pack.c:1118
+msgid "Receiving objects"
+msgstr "Đang nhận về các đối tượng"
 
-#: builtin/for-each-ref.c:43
-msgid "print only refs which points at the given object"
-msgstr "chỉ hiển thị các tham chiếu mà nó chỉ đến đối tượng đã cho"
+#: builtin/index-pack.c:1118
+msgid "Indexing objects"
+msgstr "Các đối tượng bảng mục lục"
 
-#: builtin/for-each-ref.c:45
-msgid "print only refs that are merged"
-msgstr "chỉ hiển thị những tham chiếu mà nó được hòa trộn"
+#: builtin/index-pack.c:1152
+msgid "pack is corrupted (SHA1 mismatch)"
+msgstr "gói bị sai hỏng (SHA1 không khớp)"
 
-#: builtin/for-each-ref.c:46
-msgid "print only refs that are not merged"
-msgstr "chỉ hiển thị những tham chiếu mà nó không được hòa trộn"
+#: builtin/index-pack.c:1157
+msgid "cannot fstat packfile"
+msgstr "không thể lấy thông tin thống kê packfile"
 
-#: builtin/for-each-ref.c:47
-msgid "print only refs which contain the commit"
-msgstr "chỉ hiển thị những tham chiếu mà nó chứa lần chuyển giao"
+#: builtin/index-pack.c:1160
+msgid "pack has junk at the end"
+msgstr "pack có phần thừa ở cuối"
 
-#: builtin/for-each-ref.c:48
-msgid "print only refs which don't contain the commit"
-msgstr "chỉ hiển thị những tham chiếu mà nó không chứa lần chuyển giao"
+#: builtin/index-pack.c:1172
+msgid "confusion beyond insanity in parse_pack_objects()"
+msgstr "lộn xộn hơn cả điên rồ khi chạy hàm parse_pack_objects()"
 
-#: builtin/fsck.c:569
-msgid "Checking object directories"
-msgstr "Đang kiểm tra các thư mục đối tượng"
+#: builtin/index-pack.c:1195
+msgid "Resolving deltas"
+msgstr "Đang phân giải các delta"
 
-#: builtin/fsck.c:661
-msgid "git fsck [<options>] [<object>...]"
-msgstr "git fsck [<các-tùy-chọn>] [<đối-tượng>…]"
+#: builtin/index-pack.c:1205 builtin/pack-objects.c:2481
+#, c-format
+msgid "unable to create thread: %s"
+msgstr "không thể tạo tuyến: %s"
 
-#: builtin/fsck.c:667
-msgid "show unreachable objects"
-msgstr "hiển thị các đối tượng không thể đọc được"
+#: builtin/index-pack.c:1246
+msgid "confusion beyond insanity"
+msgstr "lộn xộn hơn cả điên rồ"
 
-#: builtin/fsck.c:668
-msgid "show dangling objects"
-msgstr "hiển thị các đối tượng không được quản lý"
+#: builtin/index-pack.c:1252
+#, c-format
+msgid "completed with %d local object"
+msgid_plural "completed with %d local objects"
+msgstr[0] "đầy đủ với %d đối tượng nội bộ"
 
-#: builtin/fsck.c:669
-msgid "report tags"
-msgstr "báo cáo các thẻ"
+#: builtin/index-pack.c:1264
+#, c-format
+msgid "Unexpected tail checksum for %s (disk corruption?)"
+msgstr "Gặp tổng kiểm tra tail không cần cho %s (đĩa hỏng?)"
 
-#: builtin/fsck.c:670
-msgid "report root nodes"
-msgstr "báo cáo node gốc"
+#: builtin/index-pack.c:1268
+#, c-format
+msgid "pack has %d unresolved delta"
+msgid_plural "pack has %d unresolved deltas"
+msgstr[0] "gói có %d delta chưa được giải quyết"
 
-#: builtin/fsck.c:671
-msgid "make index objects head nodes"
-msgstr "tạo “index objects head nodes”"
+#: builtin/index-pack.c:1292
+#, c-format
+msgid "unable to deflate appended object (%d)"
+msgstr "không thể xả nén đối tượng nối thêm (%d)"
 
-#: builtin/fsck.c:672
-msgid "make reflogs head nodes (default)"
-msgstr "tạo “reflogs head nodes” (mặc định)"
+#: builtin/index-pack.c:1388
+#, c-format
+msgid "local object %s is corrupt"
+msgstr "đối tượng nội bộ %s bị hỏng"
 
-#: builtin/fsck.c:673
-msgid "also consider packs and alternate objects"
-msgstr "cũng cân nhắc đến các đối tượng gói và thay thế"
+#: builtin/index-pack.c:1402
+#, c-format
+msgid "packfile name '%s' does not end with '.pack'"
+msgstr "tên tập tin tập tin gói “%s” không được kết thúc bằng đuôi “.pack”"
+
+#: builtin/index-pack.c:1427
+#, c-format
+msgid "cannot write %s file '%s'"
+msgstr "không thể ghi %s tập tin “%s”"
 
-#: builtin/fsck.c:674
-msgid "check only connectivity"
-msgstr "chỉ kiểm tra kết nối"
+#: builtin/index-pack.c:1435
+#, c-format
+msgid "cannot close written %s file '%s'"
+msgstr "không thể đóng tập tin được ghi %s “%s”"
 
-#: builtin/fsck.c:675
-msgid "enable more strict checking"
-msgstr "cho phép kiểm tra hạn chế hơn"
+#: builtin/index-pack.c:1459
+msgid "error while closing pack file"
+msgstr "gặp lỗi trong khi đóng tập tin gói"
 
-#: builtin/fsck.c:677
-msgid "write dangling objects in .git/lost-found"
-msgstr "ghi các đối tượng không được quản lý trong .git/lost-found"
+#: builtin/index-pack.c:1473
+msgid "cannot store pack file"
+msgstr "không thể lưu tập tin gói"
 
-#: builtin/fsck.c:678 builtin/prune.c:109
-msgid "show progress"
-msgstr "hiển thị quá trình"
+#: builtin/index-pack.c:1481
+msgid "cannot store index file"
+msgstr "không thể lưu trữ tập tin ghi mục lục"
 
-#: builtin/fsck.c:679
-msgid "show verbose names for reachable objects"
-msgstr "hiển thị tên chi tiết cho các đối tượng đọc được"
+#: builtin/index-pack.c:1525 builtin/pack-objects.c:2716
+#, c-format
+msgid "bad pack.indexversion=%<PRIu32>"
+msgstr "sai pack.indexversion=%<PRIu32>"
 
-#: builtin/fsck.c:745
-msgid "Checking objects"
-msgstr "Đang kiểm tra các đối tượng"
+#: builtin/index-pack.c:1593
+#, c-format
+msgid "Cannot open existing pack file '%s'"
+msgstr "Không thể mở tập tin gói đã sẵn có “%s”"
 
-#: builtin/gc.c:33
-msgid "git gc [<options>]"
-msgstr "git gc [<các-tùy-chọn>]"
+#: builtin/index-pack.c:1595
+#, c-format
+msgid "Cannot open existing pack idx file for '%s'"
+msgstr "Không thể mở tập tin idx của gói cho “%s”"
 
-#: builtin/gc.c:88
+#: builtin/index-pack.c:1643
 #, c-format
-msgid "Failed to fstat %s: %s"
-msgstr "Gặp lỗi khi lấy thông tin thống kê về tập tin %s: %s"
+msgid "non delta: %d object"
+msgid_plural "non delta: %d objects"
+msgstr[0] "không delta: %d đối tượng"
 
-#: builtin/gc.c:452
+#: builtin/index-pack.c:1650
 #, c-format
-msgid "Can't stat %s"
-msgstr "không thể lấy thông tin thống kê về “%s”"
+msgid "chain length = %d: %lu object"
+msgid_plural "chain length = %d: %lu objects"
+msgstr[0] "chiều dài xích = %d: %lu đối tượng"
+
+#: builtin/index-pack.c:1689
+msgid "Cannot come back to cwd"
+msgstr "Không thể quay lại cwd"
 
-#: builtin/gc.c:461
+#: builtin/index-pack.c:1738 builtin/index-pack.c:1741
+#: builtin/index-pack.c:1757 builtin/index-pack.c:1761
 #, c-format
-msgid ""
-"The last gc run reported the following. Please correct the root cause\n"
-"and remove %s.\n"
-"Automatic cleanup will not be performed until the file is removed.\n"
-"\n"
-"%s"
-msgstr ""
-"Lần chạy gc cuối đã báo cáo các vấn đề sau đây. Vui lòng sửa nguyên nhân\n"
-"tận gốc và xóa bỏ %s.\n"
-"Việc tự động dọn dẹp sẽ không thực thi cho đến khi tập tin được xóa bỏ.\n"
-"\n"
-"%s"
+msgid "bad %s"
+msgstr "%s sai"
 
-#: builtin/gc.c:502
-msgid "prune unreferenced objects"
-msgstr "xóa bỏ các đối tượng không được tham chiếu"
+#: builtin/index-pack.c:1777
+msgid "--fix-thin cannot be used without --stdin"
+msgstr "--fix-thin không thể được dùng mà không có --stdin"
 
-#: builtin/gc.c:504
-msgid "be more thorough (increased runtime)"
-msgstr "cẩn thận hơn nữa (tăng thời gian chạy)"
+#: builtin/index-pack.c:1779
+msgid "--stdin requires a git repository"
+msgstr "--stdin cần một kho git"
 
-#: builtin/gc.c:505
-msgid "enable auto-gc mode"
-msgstr "bật chế độ auto-gc"
+#: builtin/index-pack.c:1785
+msgid "--verify with no packfile name given"
+msgstr "dùng tùy chọn --verify mà không đưa ra tên packfile"
 
-#: builtin/gc.c:508
-msgid "force running gc even if there may be another gc running"
-msgstr "buộc gc chạy ngay cả khi có tiến trình gc khác đang chạy"
+#: builtin/index-pack.c:1833 builtin/unpack-objects.c:581
+msgid "fsck error in pack objects"
+msgstr "lỗi fsck trong các đối tượng gói"
 
-#: builtin/gc.c:511
-msgid "repack all other packs except the largest pack"
-msgstr "đóng gói lại tất cả các gói khác ngoại trừ gói lớn nhất"
+#: builtin/init-db.c:61
+#, c-format
+msgid "cannot stat template '%s'"
+msgstr "không thể lấy thông tin thống kê về mẫu “%s”"
 
-#: builtin/gc.c:528
+#: builtin/init-db.c:66
 #, c-format
-msgid "failed to parse gc.logexpiry value %s"
-msgstr "gặp lỗi khi phân tích giá trị gc.logexpiry %s"
+msgid "cannot opendir '%s'"
+msgstr "không thể opendir() “%s”"
 
-#: builtin/gc.c:539
+#: builtin/init-db.c:78
 #, c-format
-msgid "failed to parse prune expiry value %s"
-msgstr "gặp lỗi khi phân tích giá trị prune %s"
+msgid "cannot readlink '%s'"
+msgstr "không thể readlink “%s”"
 
-#: builtin/gc.c:559
+#: builtin/init-db.c:80
 #, c-format
-msgid "Auto packing the repository in background for optimum performance.\n"
-msgstr ""
-"Tự động đóng gói kho chứa trên nền hệ thống để tối ưu hóa hiệu suất làm "
-"việc.\n"
+msgid "cannot symlink '%s' '%s'"
+msgstr "không thể tạo liên kết mềm (symlink) “%s” “%s”"
 
-#: builtin/gc.c:561
+#: builtin/init-db.c:86
 #, c-format
-msgid "Auto packing the repository for optimum performance.\n"
-msgstr "Tự động đóng gói kho chứa để tối ưu hóa hiệu suất làm việc.\n"
+msgid "cannot copy '%s' to '%s'"
+msgstr "không thể sao chép “%s” sang “%s”"
 
-#: builtin/gc.c:562
+#: builtin/init-db.c:90
 #, c-format
-msgid "See \"git help gc\" for manual housekeeping.\n"
-msgstr "Xem \"git help gc\" để có hướng dẫn cụ thể về cách dọn dẹp kho git.\n"
+msgid "ignoring template %s"
+msgstr "đang lờ đi mẫu “%s”"
 
-#: builtin/gc.c:598
+#: builtin/init-db.c:121
 #, c-format
-msgid ""
-"gc is already running on machine '%s' pid %<PRIuMAX> (use --force if not)"
-msgstr ""
-"gc đang được thực hiện trên máy “%s” pid %<PRIuMAX> (dùng --force nếu không "
-"phải thế)"
+msgid "templates not found in %s"
+msgstr "các mẫu không được tìm thấy trong %s"
 
-#: builtin/gc.c:645
-msgid ""
-"There are too many unreachable loose objects; run 'git prune' to remove them."
-msgstr ""
-"Có quá nhiều đối tượng tự do không được dùng đến; hãy chạy lệnh “git prune” "
-"để xóa bỏ chúng đi."
+#: builtin/init-db.c:136
+#, c-format
+msgid "not copying templates from '%s': %s"
+msgstr "không sao chép các mẫu từ “%s”: %s"
 
-#: builtin/grep.c:28
-msgid "git grep [<options>] [-e] <pattern> [<rev>...] [[--] <path>...]"
-msgstr "git grep [<các-tùy-chọn>] [-e] <mẫu> [<rev>…] [[--] <đường-dẫn>…]"
+#: builtin/init-db.c:334
+#, c-format
+msgid "unable to handle file type %d"
+msgstr "không thể xử lý (handle) tập tin kiểu %d"
 
-#: builtin/grep.c:226
+#: builtin/init-db.c:337
 #, c-format
-msgid "grep: failed to create thread: %s"
-msgstr "grep: gặp lỗi tạo tuyến (thread): %s"
+msgid "unable to move %s to %s"
+msgstr "không di chuyển được %s vào %s"
 
-#: builtin/grep.c:284
+#: builtin/init-db.c:354 builtin/init-db.c:357
 #, c-format
-msgid "invalid number of threads specified (%d) for %s"
-msgstr "số tuyến đã cho không hợp lệ (%d) cho %s"
+msgid "%s already exists"
+msgstr "%s đã có từ trước rồi"
 
-#. TRANSLATORS: %s is the configuration
-#. variable for tweaking threads, currently
-#. grep.threads
-#.
-#: builtin/grep.c:293 builtin/index-pack.c:1535 builtin/index-pack.c:1727
+#: builtin/init-db.c:413
 #, c-format
-msgid "no threads support, ignoring %s"
-msgstr "không hỗ trợ đa tuyến, bỏ qua %s"
+msgid "Reinitialized existing shared Git repository in %s%s\n"
+msgstr "Đã khởi tạo lại kho Git chia sẻ sẵn có trong %s%s\n"
 
-#: builtin/grep.c:461 builtin/grep.c:582 builtin/grep.c:623
+#: builtin/init-db.c:414
 #, c-format
-msgid "unable to read tree (%s)"
-msgstr "không thể đọc cây (%s)"
+msgid "Reinitialized existing Git repository in %s%s\n"
+msgstr "Đã khởi tạo lại kho Git sẵn có trong %s%s\n"
 
-#: builtin/grep.c:638
+#: builtin/init-db.c:418
 #, c-format
-msgid "unable to grep from object of type %s"
-msgstr "không thể thực hiện lệnh grep (lọc tìm) từ đối tượng thuộc kiểu %s"
+msgid "Initialized empty shared Git repository in %s%s\n"
+msgstr "Đã khởi tạo lại kho Git chia sẻ trống rỗng sẵn có trong %s%s\n"
 
-#: builtin/grep.c:703
+#: builtin/init-db.c:419
 #, c-format
-msgid "switch `%c' expects a numerical value"
-msgstr "chuyển đến “%c” cần một giá trị bằng số"
+msgid "Initialized empty Git repository in %s%s\n"
+msgstr "Đã khởi tạo lại kho Git trống rỗng sẵn có trong %s%s\n"
 
-#: builtin/grep.c:790
-msgid "search in index instead of in the work tree"
-msgstr "tìm trong bảng mục lục thay vì trong cây làm việc"
+#: builtin/init-db.c:468
+msgid ""
+"git init [-q | --quiet] [--bare] [--template=<template-directory>] [--"
+"shared[=<permissions>]] [<directory>]"
+msgstr ""
+"git init [-q | --quiet] [--bare] [--template=<thư-mục-tạm>] [--shared[=<các-"
+"quyền>]] [thư-mục]"
 
-#: builtin/grep.c:792
-msgid "find in contents not managed by git"
-msgstr "tìm trong nội dung không được quản lý bởi git"
+#: builtin/init-db.c:491
+msgid "permissions"
+msgstr "các quyền"
 
-#: builtin/grep.c:794
-msgid "search in both tracked and untracked files"
-msgstr "tìm kiếm các tập tin được và chưa được theo dõi dấu vết"
+#: builtin/init-db.c:492
+msgid "specify that the git repository is to be shared amongst several users"
+msgstr "chỉ ra cái mà kho git được chia sẻ giữa nhiều người dùng"
 
-#: builtin/grep.c:796
-msgid "ignore files specified via '.gitignore'"
-msgstr "các tập tin bị bỏ qua được chỉ định thông qua “.gitignore”"
+#: builtin/init-db.c:529 builtin/init-db.c:534
+#, c-format
+msgid "cannot mkdir %s"
+msgstr "không thể mkdir (tạo thư mục): %s"
 
-#: builtin/grep.c:798
-msgid "recursively search in each submodule"
-msgstr "tìm kiếm đệ quy trong từng mô-đun-con"
+#: builtin/init-db.c:538
+#, c-format
+msgid "cannot chdir to %s"
+msgstr "không thể chdir (chuyển đổi thư mục) sang %s"
 
-#: builtin/grep.c:801
-msgid "show non-matching lines"
-msgstr "hiển thị những dòng không khớp với mẫu"
+#: builtin/init-db.c:559
+#, c-format
+msgid ""
+"%s (or --work-tree=<directory>) not allowed without specifying %s (or --git-"
+"dir=<directory>)"
+msgstr ""
+"%s (hoặc --work-tree=<thư-mục>) không cho phép không chỉ định %s (hoặc --git-"
+"dir=<thư-mục>)"
 
-#: builtin/grep.c:803
-msgid "case insensitive matching"
-msgstr "phân biệt HOA/thường"
+#: builtin/init-db.c:587
+#, c-format
+msgid "Cannot access work tree '%s'"
+msgstr "Không thể truy cập cây (tree) làm việc “%s”"
 
-#: builtin/grep.c:805
-msgid "match patterns only at word boundaries"
-msgstr "chỉ khớp mẫu tại đường ranh giới từ"
+#: builtin/interpret-trailers.c:16
+msgid ""
+"git interpret-trailers [--in-place] [--trim-empty] [(--trailer "
+"<token>[(=|:)<value>])...] [<file>...]"
+msgstr ""
+"git interpret-trailers [--in-place] [--trim-empty] [(--trailer "
+"<thẻ>[(=|:)<giá-trị>])…] [<tập-tin>…]"
 
-#: builtin/grep.c:807
-msgid "process binary files as text"
-msgstr "xử lý tập tin nhị phân như là dạng văn bản thường"
+#: builtin/interpret-trailers.c:95
+msgid "edit files in place"
+msgstr "sửa các tập tin tại chỗ"
 
-#: builtin/grep.c:809
-msgid "don't match patterns in binary files"
-msgstr "không khớp mẫu trong các tập tin nhị phân"
+#: builtin/interpret-trailers.c:96
+msgid "trim empty trailers"
+msgstr "bộ dò vết cắt bỏ phần trống rỗng"
 
-#: builtin/grep.c:812
-msgid "process binary files with textconv filters"
-msgstr "xử lý tập tin nhị phân với các bộ lọc “textconv”"
+#: builtin/interpret-trailers.c:99
+msgid "where to place the new trailer"
+msgstr "đặt phần đuôi mới ở đâu"
 
-#: builtin/grep.c:814
-msgid "descend at most <depth> levels"
-msgstr "hạ xuống ít nhất là mức <sâu>"
+#: builtin/interpret-trailers.c:101
+msgid "action if trailer already exists"
+msgstr "thao tác khi đã có phần đuôi"
 
-#: builtin/grep.c:818
-msgid "use extended POSIX regular expressions"
-msgstr "dùng biểu thức chính qui POSIX có mở rộng"
+#: builtin/interpret-trailers.c:103
+msgid "action if trailer is missing"
+msgstr "thao tác khi thiếu phần đuôi"
 
-#: builtin/grep.c:821
-msgid "use basic POSIX regular expressions (default)"
-msgstr "sử dụng biểu thức chính quy kiểu POSIX (mặc định)"
+#: builtin/interpret-trailers.c:105
+msgid "output only the trailers"
+msgstr "chỉ xuất phần đuôi"
 
-#: builtin/grep.c:824
-msgid "interpret patterns as fixed strings"
-msgstr "diễn dịch các mẫu như là chuỗi cố định"
+#: builtin/interpret-trailers.c:106
+msgid "do not apply config rules"
+msgstr "đừng áp dụng các quy tắc cấu hình"
 
-#: builtin/grep.c:827
-msgid "use Perl-compatible regular expressions"
-msgstr "sử dụng biểu thức chính quy tương thích Perl"
+#: builtin/interpret-trailers.c:107
+msgid "join whitespace-continued values"
+msgstr "nối các giá trị khoảng-trắng-liên-tiếp"
 
-#: builtin/grep.c:830
-msgid "show line numbers"
-msgstr "hiển thị số của dòng"
+#: builtin/interpret-trailers.c:108
+msgid "set parsing options"
+msgstr "đặt các tùy chọn phân tích cú pháp"
 
-#: builtin/grep.c:831
-msgid "don't show filenames"
-msgstr "không hiển thị tên tập tin"
+#: builtin/interpret-trailers.c:110
+msgid "do not treat --- specially"
+msgstr "không coi --- là đặc biệt"
 
-#: builtin/grep.c:832
-msgid "show filenames"
-msgstr "hiển thị các tên tập tin"
+#: builtin/interpret-trailers.c:111
+msgid "trailer"
+msgstr "bộ dò vết"
 
-#: builtin/grep.c:834
-msgid "show filenames relative to top directory"
-msgstr "hiển thị tên tập tin tương đối với thư mục đỉnh (top)"
+#: builtin/interpret-trailers.c:112
+msgid "trailer(s) to add"
+msgstr "bộ dò vết cần thêm"
 
-#: builtin/grep.c:836
-msgid "show only filenames instead of matching lines"
-msgstr "chỉ hiển thị tên tập tin thay vì những dòng khớp với mẫu"
+#: builtin/interpret-trailers.c:123
+msgid "--trailer with --only-input does not make sense"
+msgstr "--trailer cùng với --only-input không hợp lý"
 
-#: builtin/grep.c:838
-msgid "synonym for --files-with-matches"
-msgstr "đồng nghĩa với --files-with-matches"
+#: builtin/interpret-trailers.c:133
+msgid "no input file given for in-place editing"
+msgstr "không đưa ra tập tin đầu vào để sửa tại-chỗ"
 
-#: builtin/grep.c:841
-msgid "show only the names of files without match"
-msgstr "chỉ hiển thị tên cho những tập tin không khớp với mẫu"
+#: builtin/log.c:56
+msgid "git log [<options>] [<revision-range>] [[--] <path>...]"
+msgstr "git log [<các tùy chọn>] [<vùng-xem-xét>] [[--] </đường/dẫn>…]"
 
-#: builtin/grep.c:843
-msgid "print NUL after filenames"
-msgstr "thêm NUL vào sau tên tập tin"
+#: builtin/log.c:57
+msgid "git show [<options>] <object>..."
+msgstr "git show [<các tùy chọn>] <đối-tượng>…"
 
-#: builtin/grep.c:846
-msgid "show the number of matches instead of matching lines"
-msgstr "hiển thị số lượng khớp thay vì những dòng khớp với mẫu"
+#: builtin/log.c:110
+#, c-format
+msgid "invalid --decorate option: %s"
+msgstr "tùy chọn--decorate không hợp lệ: %s"
 
-#: builtin/grep.c:847
-msgid "highlight matches"
-msgstr "tô sáng phần khớp mẫu"
+#: builtin/log.c:174
+msgid "show source"
+msgstr "hiển thị mã nguồn"
 
-#: builtin/grep.c:849
-msgid "print empty line between matches from different files"
-msgstr "hiển thị dòng trống giữa các lần khớp từ các tập tin khác biệt"
+#: builtin/log.c:175
+msgid "Use mail map file"
+msgstr "Sử dụng tập tin ánh xạ thư"
 
-#: builtin/grep.c:851
-msgid "show filename only once above matches from same file"
-msgstr ""
-"hiển thị tên tập tin một lần phía trên các lần khớp từ cùng một tập tin"
+#: builtin/log.c:177
+msgid "only decorate refs that match <pattern>"
+msgstr "chỉ tô sáng các tham chiếu khớp với <mẫu>"
 
-#: builtin/grep.c:854
-msgid "show <n> context lines before and after matches"
-msgstr "hiển thị <n> dòng nội dung phía trước và sau các lần khớp"
+#: builtin/log.c:179
+msgid "do not decorate refs that match <pattern>"
+msgstr "không tô sáng các tham chiếu khớp với <mẫu>"
 
-#: builtin/grep.c:857
-msgid "show <n> context lines before matches"
-msgstr "hiển thị <n> dòng nội dung trước khớp"
+#: builtin/log.c:180
+msgid "decorate options"
+msgstr "các tùy chọn trang trí"
 
-#: builtin/grep.c:859
-msgid "show <n> context lines after matches"
-msgstr "hiển thị <n> dòng nội dung sau khớp"
+#: builtin/log.c:183
+msgid "Process line range n,m in file, counting from 1"
+msgstr "Xử lý chỉ dòng vùng n,m trong tập tin, tính từ 1"
 
-#: builtin/grep.c:861
-msgid "use <n> worker threads"
-msgstr "dùng <n> tuyến trình làm việc"
+#: builtin/log.c:281
+#, c-format
+msgid "Final output: %d %s\n"
+msgstr "Kết xuất cuối cùng: %d %s\n"
 
-#: builtin/grep.c:862
-msgid "shortcut for -C NUM"
-msgstr "dạng viết tắt của -C SỐ"
+#: builtin/log.c:535
+#, c-format
+msgid "git show %s: bad file"
+msgstr "git show %s: sai tập tin"
 
-#: builtin/grep.c:865
-msgid "show a line with the function name before matches"
-msgstr "hiển thị dòng vói tên hàm trước các lần khớp"
+#: builtin/log.c:550 builtin/log.c:645
+#, c-format
+msgid "could not read object %s"
+msgstr "không thể đọc đối tượng %s"
 
-#: builtin/grep.c:867
-msgid "show the surrounding function"
-msgstr "hiển thị hàm bao quanh"
+#: builtin/log.c:670
+#, c-format
+msgid "unknown type: %d"
+msgstr "không nhận ra kiểu: %d"
 
-#: builtin/grep.c:870
-msgid "read patterns from file"
-msgstr "đọc mẫu từ tập-tin"
+#: builtin/log.c:814
+#, c-format
+msgid "%s: invalid cover from description mode"
+msgstr "%s: bao bọc không hợp lệ từ chế độ mô tả"
 
-#: builtin/grep.c:872
-msgid "match <pattern>"
-msgstr "match <mẫu>"
+#: builtin/log.c:821
+msgid "format.headers without value"
+msgstr "format.headers không có giá trị cụ thể"
 
-#: builtin/grep.c:874
-msgid "combine patterns specified with -e"
-msgstr "tổ hợp mẫu được chỉ ra với tùy chọn -e"
+#: builtin/log.c:936
+msgid "name of output directory is too long"
+msgstr "tên của thư mục kết xuất quá dài"
 
-#: builtin/grep.c:886
-msgid "indicate hit with exit status without output"
-msgstr "đưa ra gợi ý với trạng thái thoát mà không có kết xuất"
+#: builtin/log.c:952
+#, c-format
+msgid "cannot open patch file %s"
+msgstr "không thể mở tập tin miếng vá: %s"
 
-#: builtin/grep.c:888
-msgid "show only matches from files that match all patterns"
-msgstr "chỉ hiển thị những cái khớp từ tập tin mà nó khớp toàn bộ các mẫu"
+#: builtin/log.c:969
+msgid "need exactly one range"
+msgstr "cần chính xác một vùng"
 
-#: builtin/grep.c:890
-msgid "show parse tree for grep expression"
-msgstr "hiển thị cây phân tích cú pháp cho biểu thức “grep” (tìm kiếm)"
+#: builtin/log.c:979
+msgid "not a range"
+msgstr "không phải là một vùng"
 
-#: builtin/grep.c:894
-msgid "pager"
-msgstr "dàn trang"
+#: builtin/log.c:1143
+msgid "cover letter needs email format"
+msgstr "“cover letter” cần cho định dạng thư"
 
-#: builtin/grep.c:894
-msgid "show matching files in the pager"
-msgstr "hiển thị các tập tin khớp trong trang giấy"
+#: builtin/log.c:1149
+msgid "failed to create cover-letter file"
+msgstr "gặp lỗi khi tạo các tập tin cover-letter"
 
-#: builtin/grep.c:898
-msgid "allow calling of grep(1) (ignored by this build)"
-msgstr "cho phép gọi grep(1) (bị bỏ qua bởi lần dịch này)"
+#: builtin/log.c:1228
+#, c-format
+msgid "insane in-reply-to: %s"
+msgstr "in-reply-to điên rồ: %s"
 
-#: builtin/grep.c:962
-msgid "no pattern given."
-msgstr "chưa chỉ ra mẫu."
+#: builtin/log.c:1255
+msgid "git format-patch [<options>] [<since> | <revision-range>]"
+msgstr "git format-patch [<các tùy chọn>] [<kể-từ> | <vùng-xem-xét>]"
 
-#: builtin/grep.c:994
-msgid "--no-index or --untracked cannot be used with revs"
-msgstr "--no-index hay --untracked không được sử dụng cùng với revs"
+#: builtin/log.c:1313
+msgid "two output directories?"
+msgstr "hai thư mục kết xuất?"
 
-#: builtin/grep.c:1001
+#: builtin/log.c:1424 builtin/log.c:2197 builtin/log.c:2199 builtin/log.c:2211
 #, c-format
-msgid "unable to resolve revision: %s"
-msgstr "không thể phân giải điểm xét duyệt: %s"
+msgid "unknown commit %s"
+msgstr "không hiểu lần chuyển giao %s"
 
-#: builtin/grep.c:1036 builtin/index-pack.c:1531
+#: builtin/log.c:1434 builtin/replace.c:58 builtin/replace.c:207
+#: builtin/replace.c:210
 #, c-format
-msgid "invalid number of threads specified (%d)"
-msgstr "số tuyến chỉ ra không hợp lệ (%d)"
+msgid "failed to resolve '%s' as a valid ref"
+msgstr "gặp lỗi khi phân giải “%s” như là một tham chiếu hợp lệ"
 
-#: builtin/grep.c:1041
-msgid "no threads support, ignoring --threads"
-msgstr "không hỗ trợ đa tuyến, bỏ qua --threads"
-
-#: builtin/grep.c:1065
-msgid "--open-files-in-pager only works on the worktree"
-msgstr "--open-files-in-pager chỉ làm việc trên cây-làm-việc"
-
-#: builtin/grep.c:1088
-msgid "option not supported with --recurse-submodules."
-msgstr "tùy chọn không được hỗ trợ với --recurse-submodules."
-
-#: builtin/grep.c:1094
-msgid "--cached or --untracked cannot be used with --no-index."
-msgstr "--cached hay --untracked không được sử dụng với --no-index."
-
-#: builtin/grep.c:1100
-msgid "--[no-]exclude-standard cannot be used for tracked contents."
-msgstr "--[no-]exclude-standard không thể sử dụng cho nội dung lưu dấu vết."
-
-#: builtin/grep.c:1108
-msgid "both --cached and trees are given."
-msgstr "cả hai --cached và các cây phải được chỉ ra."
+#: builtin/log.c:1439
+msgid "could not find exact merge base"
+msgstr "không tìm thấy nền hòa trộn chính xác"
 
-#: builtin/hash-object.c:83
+#: builtin/log.c:1443
 msgid ""
-"git hash-object [-t <type>] [-w] [--path=<file> | --no-filters] [--stdin] "
-"[--] <file>..."
+"failed to get upstream, if you want to record base commit automatically,\n"
+"please use git branch --set-upstream-to to track a remote branch.\n"
+"Or you could specify base commit by --base=<base-commit-id> manually"
 msgstr ""
-"git hash-object [-t <kiểu>] [-w] [--path=<tập-tin> | --no-filters] [--stdin] "
-"[--] <tập-tin>…"
+"gặp lỗi khi lấy thượng nguồn, nếu bạn muốn ghi lại lần chuyển giao nền một\n"
+"cách tự động, vui lòng dùng \"git branch --set-upstream-to\" để theo dõi\n"
+"nhánh máy chủ. Hoặc là bạn có thể chỉ định lần chuyển giao nền bằng\n"
+"\"--base=<base-commit-id>\" một cách thủ công"
 
-#: builtin/hash-object.c:84
-msgid "git hash-object  --stdin-paths"
-msgstr "git hash-object  --stdin-paths"
+#: builtin/log.c:1463
+msgid "failed to find exact merge base"
+msgstr "gặp lỗi khi tìm nền hòa trộn chính xác"
 
-#: builtin/hash-object.c:96
-msgid "type"
-msgstr "kiểu"
+#: builtin/log.c:1474
+msgid "base commit should be the ancestor of revision list"
+msgstr "lần chuyển giao nền không là tổ tiên của danh sách điểm xét duyệt"
 
-#: builtin/hash-object.c:96
-msgid "object type"
-msgstr "kiểu đối tượng"
+#: builtin/log.c:1478
+msgid "base commit shouldn't be in revision list"
+msgstr "lần chuyển giao nền không được trong danh sách điểm xét duyệt"
 
-#: builtin/hash-object.c:97
-msgid "write the object into the object database"
-msgstr "ghi đối tượng vào dữ liệu đối tượng"
+#: builtin/log.c:1531
+msgid "cannot get patch id"
+msgstr "không thể lấy mã miếng vá"
 
-#: builtin/hash-object.c:99
-msgid "read the object from stdin"
-msgstr "đọc đối tượng từ đầu vào tiêu chuẩn stdin"
+#: builtin/log.c:1583
+msgid "failed to infer range-diff ranges"
+msgstr "gặp lỗi khi suy luận range-diff (vùng khác biệt)"
 
-#: builtin/hash-object.c:101
-msgid "store file as is without filters"
-msgstr "lưu các tập tin mà nó không có các bộ lọc"
+#: builtin/log.c:1629
+msgid "use [PATCH n/m] even with a single patch"
+msgstr "dùng [PATCH n/m] ngay cả với miếng vá đơn"
 
-#: builtin/hash-object.c:102
-msgid ""
-"just hash any random garbage to create corrupt objects for debugging Git"
-msgstr "chỉ cần băm rác ngẫu nhiên để tạo một đối tượng hỏng để mà gỡ lỗi Git"
+#: builtin/log.c:1632
+msgid "use [PATCH] even with multiple patches"
+msgstr "dùng [VÁ] ngay cả với các miếng vá phức tạp"
 
-#: builtin/hash-object.c:103
-msgid "process file as it were from this path"
-msgstr "xử lý tập tin như là nó đang ở thư mục này"
+#: builtin/log.c:1636
+msgid "print patches to standard out"
+msgstr "hiển thị miếng vá ra đầu ra chuẩn"
 
-#: builtin/help.c:45
-msgid "print all available commands"
-msgstr "hiển thị danh sách các câu lệnh người dùng có thể sử dụng"
+#: builtin/log.c:1638
+msgid "generate a cover letter"
+msgstr "tạo bì thư"
 
-#: builtin/help.c:46
-msgid "exclude guides"
-msgstr "hướng dẫn loại trừ"
+#: builtin/log.c:1640
+msgid "use simple number sequence for output file names"
+msgstr "sử dụng chỗi dãy số dạng đơn giản cho tên tập-tin xuất ra"
 
-#: builtin/help.c:47
-msgid "print list of useful guides"
-msgstr "hiển thị danh sách các hướng dẫn hữu dụng"
+#: builtin/log.c:1641
+msgid "sfx"
+msgstr "sfx"
 
-#: builtin/help.c:48
-msgid "show man page"
-msgstr "hiển thị trang man"
+#: builtin/log.c:1642
+msgid "use <sfx> instead of '.patch'"
+msgstr "sử dụng <sfx> thay cho “.patch”"
 
-#: builtin/help.c:49
-msgid "show manual in web browser"
-msgstr "hiển thị hướng dẫn sử dụng trong trình duyệt web"
+#: builtin/log.c:1644
+msgid "start numbering patches at <n> instead of 1"
+msgstr "bắt đầu đánh số miếng vá từ <n> thay vì 1"
 
-#: builtin/help.c:51
-msgid "show info page"
-msgstr "hiện trang info"
+#: builtin/log.c:1646
+msgid "mark the series as Nth re-roll"
+msgstr "đánh dấu chuỗi nối tiếp dạng thứ-N re-roll"
 
-#: builtin/help.c:53
-msgid "print command description"
-msgstr "hiển thị mô tả lệnh"
+#: builtin/log.c:1648
+msgid "Use [RFC PATCH] instead of [PATCH]"
+msgstr "Dùng [RFC VÁ] thay cho [VÁ]"
 
-#: builtin/help.c:58
-msgid "git help [--all] [--guides] [--man | --web | --info] [<command>]"
-msgstr "git help [--all] [--guides] [--man | --web | --info] [<lệnh>]"
+#: builtin/log.c:1651
+msgid "cover-from-description-mode"
+msgstr "cover-from-description-mode"
+
+#: builtin/log.c:1652
+msgid "generate parts of a cover letter based on a branch's description"
+msgstr "tạo ra các phần của một lá thư bao gồm dựa trên mô tả của nhánh"
 
-#: builtin/help.c:70
-#, c-format
-msgid "unrecognized help format '%s'"
-msgstr "không nhận ra định dạng trợ giúp “%s”"
+#: builtin/log.c:1654
+msgid "Use [<prefix>] instead of [PATCH]"
+msgstr "Dùng [<tiền-tố>] thay cho [VÁ]"
 
-#: builtin/help.c:97
-msgid "Failed to start emacsclient."
-msgstr "Gặp lỗi khi khởi chạy emacsclient."
+#: builtin/log.c:1657
+msgid "store resulting files in <dir>"
+msgstr "lưu các tập tin kết quả trong <t.mục>"
 
-#: builtin/help.c:110
-msgid "Failed to parse emacsclient version."
-msgstr "Gặp lỗi khi phân tích phiên bản emacsclient."
+#: builtin/log.c:1660
+msgid "don't strip/add [PATCH]"
+msgstr "không strip/add [VÁ]"
 
-#: builtin/help.c:118
-#, c-format
-msgid "emacsclient version '%d' too old (< 22)."
-msgstr "phiên bản của emacsclient “%d” quá cũ (< 22)."
+#: builtin/log.c:1663
+msgid "don't output binary diffs"
+msgstr "không kết xuất diff (những khác biệt) nhị phân"
 
-#: builtin/help.c:136 builtin/help.c:158 builtin/help.c:168 builtin/help.c:176
-#, c-format
-msgid "failed to exec '%s'"
-msgstr "gặp lỗi khi thực thi “%s”"
+#: builtin/log.c:1665
+msgid "output all-zero hash in From header"
+msgstr "xuất mọi mã băm all-zero trong phần đầu From"
 
-#: builtin/help.c:214
-#, c-format
-msgid ""
-"'%s': path for unsupported man viewer.\n"
-"Please consider using 'man.<tool>.cmd' instead."
-msgstr ""
-"“%s”: đường dẫn không hỗ trợ bộ trình chiếu man.\n"
-"Hãy cân nhắc đến việc sử dụng “man.<tool>.cmd” để thay thế."
+#: builtin/log.c:1667
+msgid "don't include a patch matching a commit upstream"
+msgstr "không bao gồm miếng vá khớp với một lần chuyển giao thượng nguồn"
 
-#: builtin/help.c:226
-#, c-format
-msgid ""
-"'%s': cmd for supported man viewer.\n"
-"Please consider using 'man.<tool>.path' instead."
-msgstr ""
-"“%s”: cmd (lệnh) hỗ trợ bộ trình chiếu man.\n"
-"Hãy cân nhắc đến việc sử dụng “man.<tool>.path” để thay thế."
+#: builtin/log.c:1669
+msgid "show patch format instead of default (patch + stat)"
+msgstr "hiển thị định dạng miếng vá thay vì mặc định (miếng vá + thống kê)"
 
-#: builtin/help.c:343
-#, c-format
-msgid "'%s': unknown man viewer."
-msgstr "“%s”: không rõ chương trình xem man."
+#: builtin/log.c:1671
+msgid "Messaging"
+msgstr "Lời nhắn"
 
-#: builtin/help.c:360
-msgid "no man viewer handled the request"
-msgstr "không có trình xem trợ giúp dạng manpage tiếp hợp với yêu cầu"
+#: builtin/log.c:1672
+msgid "header"
+msgstr "đầu đề thư"
+
+#: builtin/log.c:1673
+msgid "add email header"
+msgstr "thêm đầu đề thư"
+
+#: builtin/log.c:1674 builtin/log.c:1676
+msgid "email"
+msgstr "thư điện tử"
+
+#: builtin/log.c:1674
+msgid "add To: header"
+msgstr "thêm To: đầu đề thư"
+
+#: builtin/log.c:1676
+msgid "add Cc: header"
+msgstr "thêm Cc: đầu đề thư"
+
+#: builtin/log.c:1678
+msgid "ident"
+msgstr "thụt lề"
+
+#: builtin/log.c:1679
+msgid "set From address to <ident> (or committer ident if absent)"
+msgstr ""
+"đặt “Địa chỉ gửi” thành <thụ lề> (hoặc thụt lề người commit nếu bỏ quên)"
 
-#: builtin/help.c:368
-msgid "no info viewer handled the request"
-msgstr "không có trình xem trợ giúp dạng info tiếp hợp với yêu cầu"
+#: builtin/log.c:1681
+msgid "message-id"
+msgstr "message-id"
 
-#: builtin/help.c:415
-#, c-format
-msgid "'%s' is aliased to '%s'"
-msgstr "“%s” được đặt bí danh thành “%s”"
+#: builtin/log.c:1682
+msgid "make first mail a reply to <message-id>"
+msgstr "dùng thư đầu tiên để trả lời <message-id>"
 
-#: builtin/help.c:442 builtin/help.c:459
-#, c-format
-msgid "usage: %s%s"
-msgstr "cách dùng: %s%s"
+#: builtin/log.c:1683 builtin/log.c:1686
+msgid "boundary"
+msgstr "ranh giới"
 
-#: builtin/index-pack.c:158
-#, c-format
-msgid "unable to open %s"
-msgstr "không thể mở %s"
+#: builtin/log.c:1684
+msgid "attach the patch"
+msgstr "đính kèm miếng vá"
 
-#: builtin/index-pack.c:208
-#, c-format
-msgid "object type mismatch at %s"
-msgstr "kiểu đối tượng không khớp tại %s"
+#: builtin/log.c:1687
+msgid "inline the patch"
+msgstr "dùng miếng vá làm nội dung"
 
-#: builtin/index-pack.c:228
-#, c-format
-msgid "did not receive expected object %s"
-msgstr "Không thể lấy về đối tượng cần %s"
+#: builtin/log.c:1691
+msgid "enable message threading, styles: shallow, deep"
+msgstr "cho phép luồng lời nhắn, kiểu: “shallow”, “deep”"
 
-#: builtin/index-pack.c:231
-#, c-format
-msgid "object %s: expected type %s, found %s"
-msgstr "đối tượng %s: cần kiểu %s nhưng lại nhận được %s"
+#: builtin/log.c:1693
+msgid "signature"
+msgstr "chữ ký"
 
-#: builtin/index-pack.c:273
-#, c-format
-msgid "cannot fill %d byte"
-msgid_plural "cannot fill %d bytes"
-msgstr[0] "không thể điền thêm vào %d byte"
+#: builtin/log.c:1694
+msgid "add a signature"
+msgstr "thêm chữ ký"
 
-#: builtin/index-pack.c:283
-msgid "early EOF"
-msgstr "gặp kết thúc tập tin EOF quá sớm"
+#: builtin/log.c:1695
+msgid "base-commit"
+msgstr "lần_chuyển_giao_nền"
 
-#: builtin/index-pack.c:284
-msgid "read error on input"
-msgstr "lỗi đọc ở đầu vào"
+#: builtin/log.c:1696
+msgid "add prerequisite tree info to the patch series"
+msgstr "add trước hết đòi hỏi thông tin cây tới sê-ri miếng vá"
 
-#: builtin/index-pack.c:296
-msgid "used more bytes than were available"
-msgstr "sử dụng nhiều hơn số lượng byte mà nó sẵn có"
+#: builtin/log.c:1698
+msgid "add a signature from a file"
+msgstr "thêm chữ ký từ một tập tin"
 
-#: builtin/index-pack.c:303
-msgid "pack too large for current definition of off_t"
-msgstr "gói quá lớn so với định nghĩa hiện tại của kiểu off_t"
+#: builtin/log.c:1699
+msgid "don't print the patch filenames"
+msgstr "không hiển thị các tên tập tin của miếng vá"
 
-#: builtin/index-pack.c:306 builtin/unpack-objects.c:93
-msgid "pack exceeds maximum allowed size"
-msgstr "gói đã vượt quá cỡ tối đa được phép"
+#: builtin/log.c:1701
+msgid "show progress while generating patches"
+msgstr "hiển thị bộ đo tiến triển trong khi tạo các miếng vá"
 
-#: builtin/index-pack.c:321
-#, c-format
-msgid "unable to create '%s'"
-msgstr "không thể tạo “%s”"
+#: builtin/log.c:1703
+msgid "show changes against <rev> in cover letter or single patch"
+msgstr ""
+"hiển thị các thay đổi dựa trên <rev> trong các chữ bao bọc hoặc miếng vá đơn"
 
-#: builtin/index-pack.c:327
-#, c-format
-msgid "cannot open packfile '%s'"
-msgstr "không thể mở packfile “%s”"
+#: builtin/log.c:1706
+msgid "show changes against <refspec> in cover letter or single patch"
+msgstr ""
+"hiển thị các thay đổi dựa trên <refspec> trong các chữ bao bọc hoặc miếng vá "
+"đơn"
 
-#: builtin/index-pack.c:341
-msgid "pack signature mismatch"
-msgstr "chữ ký cho gói không khớp"
+#: builtin/log.c:1708
+msgid "percentage by which creation is weighted"
+msgstr "tỷ lệ phần trăm theo cái tạo là weighted"
 
-#: builtin/index-pack.c:343
+#: builtin/log.c:1792
 #, c-format
-msgid "pack version %<PRIu32> unsupported"
-msgstr "không hỗ trợ phiên bản gói %<PRIu32>"
+msgid "invalid ident line: %s"
+msgstr "dòng thụt lề không hợp lệ: %s"
 
-#: builtin/index-pack.c:361
-#, c-format
-msgid "pack has bad object at offset %<PRIuMAX>: %s"
-msgstr "gói có đối tượng sai tại khoảng bù %<PRIuMAX>: %s"
+#: builtin/log.c:1807
+msgid "-n and -k are mutually exclusive"
+msgstr "-n và  -k loại từ lẫn nhau"
+
+#: builtin/log.c:1809
+msgid "--subject-prefix/--rfc and -k are mutually exclusive"
+msgstr "--subject-prefix/--rfc và -k xung khắc nhau"
 
-#: builtin/index-pack.c:482
-#, c-format
-msgid "inflate returned %d"
-msgstr "xả nén trả về %d"
+#: builtin/log.c:1817
+msgid "--name-only does not make sense"
+msgstr "--name-only không hợp lý"
 
-#: builtin/index-pack.c:531
-msgid "offset value overflow for delta base object"
-msgstr "tràn giá trị khoảng bù cho đối tượng delta cơ sở"
+#: builtin/log.c:1819
+msgid "--name-status does not make sense"
+msgstr "--name-status không hợp lý"
 
-#: builtin/index-pack.c:539
-msgid "delta base offset is out of bound"
-msgstr "khoảng bù cơ sở cho delta nằm ngoài phạm vi"
+#: builtin/log.c:1821
+msgid "--check does not make sense"
+msgstr "--check không hợp lý"
 
-#: builtin/index-pack.c:547
-#, c-format
-msgid "unknown object type %d"
-msgstr "không hiểu kiểu đối tượng %d"
+#: builtin/log.c:1854
+msgid "standard output, or directory, which one?"
+msgstr "đầu ra chuẩn, hay thư mục, chọn cái nào?"
 
-#: builtin/index-pack.c:578
-msgid "cannot pread pack file"
-msgstr "không thể chạy hàm pread cho tập tin gói"
+#: builtin/log.c:1958
+msgid "--interdiff requires --cover-letter or single patch"
+msgstr "--interdiff cần --cover-letter hoặc vá đơn"
+
+#: builtin/log.c:1962
+msgid "Interdiff:"
+msgstr "Interdiff:"
 
-#: builtin/index-pack.c:580
+#: builtin/log.c:1963
 #, c-format
-msgid "premature end of pack file, %<PRIuMAX> byte missing"
-msgid_plural "premature end of pack file, %<PRIuMAX> bytes missing"
-msgstr[0] "tập tin gói bị kết thúc sớm, thiếu %<PRIuMAX> byte"
+msgid "Interdiff against v%d:"
+msgstr "Interdiff dựa trên v%d:"
 
-#: builtin/index-pack.c:606
-msgid "serious inflate inconsistency"
-msgstr "sự mâu thuẫn xả nén nghiêm trọng"
+#: builtin/log.c:1969
+msgid "--creation-factor requires --range-diff"
+msgstr "--creation-factor yêu cầu --range-diff"
 
-#: builtin/index-pack.c:751 builtin/index-pack.c:757 builtin/index-pack.c:780
-#: builtin/index-pack.c:819 builtin/index-pack.c:828
-#, c-format
-msgid "SHA1 COLLISION FOUND WITH %s !"
-msgstr "SỰ VA CHẠM SHA1 ĐÃ XẢY RA VỚI %s!"
+#: builtin/log.c:1973
+msgid "--range-diff requires --cover-letter or single patch"
+msgstr "--range-diff yêu cầu --cover-letter hoặc miếng vá đơn"
 
-#: builtin/index-pack.c:754 builtin/pack-objects.c:198
-#: builtin/pack-objects.c:292
-#, c-format
-msgid "unable to read %s"
-msgstr "không thể đọc %s"
+#: builtin/log.c:1981
+msgid "Range-diff:"
+msgstr "Range-diff:"
 
-#: builtin/index-pack.c:817
+#: builtin/log.c:1982
 #, c-format
-msgid "cannot read existing object info %s"
-msgstr "không thể đọc thông tin đối tượng sẵn có %s"
+msgid "Range-diff against v%d:"
+msgstr "Range-diff dựa trên v%d:"
 
-#: builtin/index-pack.c:825
+#: builtin/log.c:1993
 #, c-format
-msgid "cannot read existing object %s"
-msgstr "không thể đọc đối tượng đã tồn tại %s"
+msgid "unable to read signature file '%s'"
+msgstr "không thể đọc tập tin chữ ký “%s”"
 
-#: builtin/index-pack.c:839
-#, c-format
-msgid "invalid blob object %s"
-msgstr "đối tượng blob không hợp lệ %s"
+#: builtin/log.c:2029
+msgid "Generating patches"
+msgstr "Đang tạo các miếng vá"
 
-#: builtin/index-pack.c:842 builtin/index-pack.c:860
-msgid "fsck error in packed object"
-msgstr "lỗi fsck trong đối tượng đóng gói"
+#: builtin/log.c:2073
+msgid "failed to create output files"
+msgstr "gặp lỗi khi tạo các tập tin kết xuất"
 
-#: builtin/index-pack.c:857
-#, c-format
-msgid "invalid %s"
-msgstr "%s không hợp lệ"
+#: builtin/log.c:2132
+msgid "git cherry [-v] [<upstream> [<head> [<limit>]]]"
+msgstr "git cherry [-v] [<thượng-nguồn> [<đầu> [<giới-hạn>]]]"
 
-#: builtin/index-pack.c:862
+#: builtin/log.c:2186
 #, c-format
-msgid "Not all child objects of %s are reachable"
-msgstr "Không phải tất cả các đối tượng con của %s là có thể với tới được"
-
-#: builtin/index-pack.c:934 builtin/index-pack.c:965
-msgid "failed to apply delta"
-msgstr "gặp lỗi khi áp dụng delta"
+msgid ""
+"Could not find a tracked remote branch, please specify <upstream> manually.\n"
+msgstr ""
+"Không tìm thấy nhánh mạng được theo dõi, hãy chỉ định <thượng-nguồn> một "
+"cách thủ công.\n"
 
-#: builtin/index-pack.c:1135
-msgid "Receiving objects"
-msgstr "Đang nhận về các đối tượng"
+#: builtin/ls-files.c:470
+msgid "git ls-files [<options>] [<file>...]"
+msgstr "git ls-files [<các tùy chọn>] [<tập-tin>…]"
 
-#: builtin/index-pack.c:1135
-msgid "Indexing objects"
-msgstr "Các đối tượng bảng mục lục"
+#: builtin/ls-files.c:526
+msgid "identify the file status with tags"
+msgstr "nhận dạng các trạng thái tập tin với thẻ"
 
-#: builtin/index-pack.c:1169
-msgid "pack is corrupted (SHA1 mismatch)"
-msgstr "gói bị sai hỏng (SHA1 không khớp)"
+#: builtin/ls-files.c:528
+msgid "use lowercase letters for 'assume unchanged' files"
+msgstr ""
+"dùng chữ cái viết thường cho các tập tin “assume unchanged” (giả định không "
+"thay đổi)"
 
-#: builtin/index-pack.c:1174
-msgid "cannot fstat packfile"
-msgstr "không thể lấy thông tin thống kê packfile"
+#: builtin/ls-files.c:530
+msgid "use lowercase letters for 'fsmonitor clean' files"
+msgstr "dùng chữ cái viết thường cho các tập tin “fsmonitor clean”"
 
-#: builtin/index-pack.c:1177
-msgid "pack has junk at the end"
-msgstr "pack có phần thừa ở cuối"
+#: builtin/ls-files.c:532
+msgid "show cached files in the output (default)"
+msgstr "hiển thị các tập tin được nhớ tạm vào đầu ra (mặc định)"
 
-#: builtin/index-pack.c:1189
-msgid "confusion beyond insanity in parse_pack_objects()"
-msgstr "lộn xộn hơn cả điên rồ khi chạy hàm parse_pack_objects()"
+#: builtin/ls-files.c:534
+msgid "show deleted files in the output"
+msgstr "hiển thị các tập tin đã xóa trong kết xuất"
 
-#: builtin/index-pack.c:1212
-msgid "Resolving deltas"
-msgstr "Đang phân giải các delta"
+#: builtin/ls-files.c:536
+msgid "show modified files in the output"
+msgstr "hiển thị các tập tin đã bị sửa đổi ra kết xuất"
 
-#: builtin/index-pack.c:1223
-#, c-format
-msgid "unable to create thread: %s"
-msgstr "không thể tạo tuyến: %s"
+#: builtin/ls-files.c:538
+msgid "show other files in the output"
+msgstr "hiển thị các tập tin khác trong kết xuất"
 
-#: builtin/index-pack.c:1265
-msgid "confusion beyond insanity"
-msgstr "lộn xộn hơn cả điên rồ"
+#: builtin/ls-files.c:540
+msgid "show ignored files in the output"
+msgstr "hiển thị các tập tin bị bỏ qua trong kết xuất"
 
-#: builtin/index-pack.c:1271
-#, c-format
-msgid "completed with %d local object"
-msgid_plural "completed with %d local objects"
-msgstr[0] "đầy đủ với %d đối tượng nội bộ"
+#: builtin/ls-files.c:543
+msgid "show staged contents' object name in the output"
+msgstr "hiển thị tên đối tượng của nội dung được đặt lên bệ phóng ra kết xuất"
 
-#: builtin/index-pack.c:1283
-#, c-format
-msgid "Unexpected tail checksum for %s (disk corruption?)"
-msgstr "Gặp tổng kiểm tra tail không cần cho %s (đĩa hỏng?)"
+#: builtin/ls-files.c:545
+msgid "show files on the filesystem that need to be removed"
+msgstr "hiển thị các tập tin trên hệ thống tập tin mà nó cần được gỡ bỏ"
 
-#: builtin/index-pack.c:1287
-#, c-format
-msgid "pack has %d unresolved delta"
-msgid_plural "pack has %d unresolved deltas"
-msgstr[0] "gói có %d delta chưa được giải quyết"
+#: builtin/ls-files.c:547
+msgid "show 'other' directories' names only"
+msgstr "chỉ hiển thị tên của các thư mục “khác”"
 
-#: builtin/index-pack.c:1311
-#, c-format
-msgid "unable to deflate appended object (%d)"
-msgstr "không thể xả nén đối tượng nối thêm (%d)"
+#: builtin/ls-files.c:549
+msgid "show line endings of files"
+msgstr "hiển thị kết thúc dòng của các tập tin"
 
-#: builtin/index-pack.c:1388
-#, c-format
-msgid "local object %s is corrupt"
-msgstr "đối tượng nội bộ %s bị hỏng"
+#: builtin/ls-files.c:551
+msgid "don't show empty directories"
+msgstr "không hiển thị thư mục rỗng"
 
-#: builtin/index-pack.c:1402
-#, c-format
-msgid "packfile name '%s' does not end with '.pack'"
-msgstr "tên tập tin tập tin gói “%s” không được kết thúc bằng đuôi “.pack”"
+#: builtin/ls-files.c:554
+msgid "show unmerged files in the output"
+msgstr "hiển thị các tập tin chưa hòa trộn trong kết xuất"
 
-#: builtin/index-pack.c:1427
-#, c-format
-msgid "cannot write %s file '%s'"
-msgstr "không thể ghi %s tập tin “%s”"
+#: builtin/ls-files.c:556
+msgid "show resolve-undo information"
+msgstr "hiển thị thông tin resolve-undo"
 
-#: builtin/index-pack.c:1435
-#, c-format
-msgid "cannot close written %s file '%s'"
-msgstr "không thể đóng tập tin được ghi %s “%s”"
+#: builtin/ls-files.c:558
+msgid "skip files matching pattern"
+msgstr "bỏ qua những tập tin khớp với một mẫu"
 
-#: builtin/index-pack.c:1459
-msgid "error while closing pack file"
-msgstr "gặp lỗi trong khi đóng tập tin gói"
+#: builtin/ls-files.c:561
+msgid "exclude patterns are read from <file>"
+msgstr "mẫu loại trừ được đọc từ <tập tin>"
 
-#: builtin/index-pack.c:1473
-msgid "cannot store pack file"
-msgstr "không thể lưu tập tin gói"
+#: builtin/ls-files.c:564
+msgid "read additional per-directory exclude patterns in <file>"
+msgstr "đọc thêm các mẫu ngoại trừ mỗi thư mục trong <tập tin>"
 
-#: builtin/index-pack.c:1481
-msgid "cannot store index file"
-msgstr "không thể lưu trữ tập tin ghi mục lục"
+#: builtin/ls-files.c:566
+msgid "add the standard git exclusions"
+msgstr "thêm loại trừ tiêu chuẩn kiểu git"
 
-#: builtin/index-pack.c:1525
-#, c-format
-msgid "bad pack.indexversion=%<PRIu32>"
-msgstr "sai pack.indexversion=%<PRIu32>"
+#: builtin/ls-files.c:570
+msgid "make the output relative to the project top directory"
+msgstr "làm cho kết xuất liên quan đến thư mục ở mức cao nhất (gốc) của dự án"
 
-#: builtin/index-pack.c:1594
-#, c-format
-msgid "Cannot open existing pack file '%s'"
-msgstr "Không thể mở tập tin gói đã sẵn có “%s”"
+#: builtin/ls-files.c:573
+msgid "recurse through submodules"
+msgstr "đệ quy xuyên qua mô-đun con"
 
-#: builtin/index-pack.c:1596
-#, c-format
-msgid "Cannot open existing pack idx file for '%s'"
-msgstr "Không thể mở tập tin idx của gói cho “%s”"
+#: builtin/ls-files.c:575
+msgid "if any <file> is not in the index, treat this as an error"
+msgstr "nếu <tập tin> bất kỳ không ở trong bảng mục lục, xử lý nó như một lỗi"
 
-#: builtin/index-pack.c:1644
-#, c-format
-msgid "non delta: %d object"
-msgid_plural "non delta: %d objects"
-msgstr[0] "không delta: %d đối tượng"
+#: builtin/ls-files.c:576
+msgid "tree-ish"
+msgstr "tree-ish"
 
-#: builtin/index-pack.c:1651
-#, c-format
-msgid "chain length = %d: %lu object"
-msgid_plural "chain length = %d: %lu objects"
-msgstr[0] "chiều dài xích = %d: %lu đối tượng"
+#: builtin/ls-files.c:577
+msgid "pretend that paths removed since <tree-ish> are still present"
+msgstr ""
+"giả định rằng các đường dẫn đã bị gỡ bỏ kể từ <tree-ish> nay vẫn hiện diện"
 
-#: builtin/index-pack.c:1688
-msgid "Cannot come back to cwd"
-msgstr "Không thể quay lại cwd"
+#: builtin/ls-files.c:579
+msgid "show debugging data"
+msgstr "hiển thị dữ liệu gỡ lỗi"
 
-#: builtin/index-pack.c:1739 builtin/index-pack.c:1742
-#: builtin/index-pack.c:1758 builtin/index-pack.c:1762
-#, c-format
-msgid "bad %s"
-msgstr "%s sai"
+#: builtin/ls-remote.c:9
+msgid ""
+"git ls-remote [--heads] [--tags] [--refs] [--upload-pack=<exec>]\n"
+"                     [-q | --quiet] [--exit-code] [--get-url]\n"
+"                     [--symref] [<repository> [<refs>...]]"
+msgstr ""
+"git ls-remote [--heads] [--tags] [--refs] [--upload-pack=<exec>]\n"
+"                     [-q | --quiet] [--exit-code] [--get-url]\n"
+"                     [--symref] [<kho> [<các tham chiếu>…]]"
 
-#: builtin/index-pack.c:1778
-msgid "--fix-thin cannot be used without --stdin"
-msgstr "--fix-thin không thể được dùng mà không có --stdin"
+#: builtin/ls-remote.c:59
+msgid "do not print remote URL"
+msgstr "không hiển thị URL máy chủ"
 
-#: builtin/index-pack.c:1780
-msgid "--stdin requires a git repository"
-msgstr "--stdin cần một kho git"
+#: builtin/ls-remote.c:60 builtin/ls-remote.c:62 builtin/rebase.c:1518
+msgid "exec"
+msgstr "thực thi"
 
-#: builtin/index-pack.c:1786
-msgid "--verify with no packfile name given"
-msgstr "dùng tùy chọn --verify mà không đưa ra tên packfile"
+#: builtin/ls-remote.c:61 builtin/ls-remote.c:63
+msgid "path of git-upload-pack on the remote host"
+msgstr "đường dẫn của git-upload-pack trên máy chủ"
 
-#: builtin/index-pack.c:1836 builtin/unpack-objects.c:578
-msgid "fsck error in pack objects"
-msgstr "lỗi fsck trong các đối tượng gói"
+#: builtin/ls-remote.c:65
+msgid "limit to tags"
+msgstr "giới hạn tới các thẻ"
 
-#: builtin/init-db.c:55
-#, c-format
-msgid "cannot stat '%s'"
-msgstr "không thể lấy thông tin thống kê về “%s”"
+#: builtin/ls-remote.c:66
+msgid "limit to heads"
+msgstr "giới hạn cho các đầu"
 
-#: builtin/init-db.c:61
-#, c-format
-msgid "cannot stat template '%s'"
-msgstr "không thể lấy thông tin thống kê về mẫu “%s”"
+#: builtin/ls-remote.c:67
+msgid "do not show peeled tags"
+msgstr "không hiển thị thẻ bị peel (gọt bỏ)"
 
-#: builtin/init-db.c:66
-#, c-format
-msgid "cannot opendir '%s'"
-msgstr "không thể opendir() “%s”"
+#: builtin/ls-remote.c:69
+msgid "take url.<base>.insteadOf into account"
+msgstr "lấy url.<base>.insteadOf vào trong tài khoản"
 
-#: builtin/init-db.c:77
-#, c-format
-msgid "cannot readlink '%s'"
-msgstr "không thể readlink “%s”"
+#: builtin/ls-remote.c:72
+msgid "exit with exit code 2 if no matching refs are found"
+msgstr "thoát với mã là 2 nếu không tìm thấy tham chiếu nào khớp"
 
-#: builtin/init-db.c:79
-#, c-format
-msgid "cannot symlink '%s' '%s'"
-msgstr "không thể tạo liên kết mềm (symlink) “%s” “%s”"
+#: builtin/ls-remote.c:75
+msgid "show underlying ref in addition to the object pointed by it"
+msgstr "hiển thị tham chiếu nằm dưới để thêm vào đối tượng được chỉ bởi nó"
 
-#: builtin/init-db.c:85
-#, c-format
-msgid "cannot copy '%s' to '%s'"
-msgstr "không thể sao chép “%s” sang “%s”"
+#: builtin/ls-tree.c:30
+msgid "git ls-tree [<options>] <tree-ish> [<path>...]"
+msgstr "git ls-tree [<các tùy chọn>] <tree-ish> [</đường/dẫn>…]"
 
-#: builtin/init-db.c:89
-#, c-format
-msgid "ignoring template %s"
-msgstr "đang lờ đi mẫu “%s”"
+#: builtin/ls-tree.c:128
+msgid "only show trees"
+msgstr "chỉ hiển thị các tree"
 
-#: builtin/init-db.c:120
-#, c-format
-msgid "templates not found in %s"
-msgstr "các mẫu không được tìm thấy trong %s"
+#: builtin/ls-tree.c:130
+msgid "recurse into subtrees"
+msgstr "đệ quy vào các thư mục con"
 
-#: builtin/init-db.c:135
-#, c-format
-msgid "not copying templates from '%s': %s"
-msgstr "không sao chép các mẫu từ “%s”: %s"
+#: builtin/ls-tree.c:132
+msgid "show trees when recursing"
+msgstr "hiển thị cây khi đệ quy"
 
-#: builtin/init-db.c:328
-#, c-format
-msgid "unable to handle file type %d"
-msgstr "không thể xử lý (handle) tập tin kiểu %d"
+#: builtin/ls-tree.c:135
+msgid "terminate entries with NUL byte"
+msgstr "chấm dứt mục tin với byte NUL"
 
-#: builtin/init-db.c:331
-#, c-format
-msgid "unable to move %s to %s"
-msgstr "không di chuyển được %s vào %s"
+#: builtin/ls-tree.c:136
+msgid "include object size"
+msgstr "gồm cả kích thước đối tượng"
 
-#: builtin/init-db.c:348 builtin/init-db.c:351
-#, c-format
-msgid "%s already exists"
-msgstr "%s đã có từ trước rồi"
+#: builtin/ls-tree.c:138 builtin/ls-tree.c:140
+msgid "list only filenames"
+msgstr "chỉ liệt kê tên tập tin"
 
-#: builtin/init-db.c:404
-#, c-format
-msgid "Reinitialized existing shared Git repository in %s%s\n"
-msgstr "Đã khởi tạo lại kho Git chia sẻ sẵn có trong %s%s\n"
+#: builtin/ls-tree.c:143
+msgid "use full path names"
+msgstr "dùng tên đường dẫn đầy đủ"
 
-#: builtin/init-db.c:405
-#, c-format
-msgid "Reinitialized existing Git repository in %s%s\n"
-msgstr "Đã khởi tạo lại kho Git sẵn có trong %s%s\n"
+#: builtin/ls-tree.c:145
+msgid "list entire tree; not just current directory (implies --full-name)"
+msgstr "liệt kê cây mục tin; không chỉ thư mục hiện hành (ngụ ý --full-name)"
 
-#: builtin/init-db.c:409
+#: builtin/mailsplit.c:241
 #, c-format
-msgid "Initialized empty shared Git repository in %s%s\n"
-msgstr "Đã khởi tạo lại kho Git chia sẻ trống rỗng sẵn có trong %s%s\n"
+msgid "empty mbox: '%s'"
+msgstr "mbox trống rỗng: “%s”"
 
-#: builtin/init-db.c:410
-#, c-format
-msgid "Initialized empty Git repository in %s%s\n"
-msgstr "Đã khởi tạo lại kho Git trống rỗng sẵn có trong %s%s\n"
+#: builtin/merge.c:55
+msgid "git merge [<options>] [<commit>...]"
+msgstr "git merge [<các tùy chọn>] [<commit>…]"
 
-#: builtin/init-db.c:458
-msgid ""
-"git init [-q | --quiet] [--bare] [--template=<template-directory>] [--"
-"shared[=<permissions>]] [<directory>]"
-msgstr ""
-"git init [-q | --quiet] [--bare] [--template=<thư-mục-tạm>] [--shared[=<các-"
-"quyền>]] [thư-mục]"
+#: builtin/merge.c:56
+msgid "git merge --abort"
+msgstr "git merge --abort"
 
-#: builtin/init-db.c:481
-msgid "permissions"
-msgstr "các quyền"
+#: builtin/merge.c:57
+msgid "git merge --continue"
+msgstr "git merge --continue"
 
-#: builtin/init-db.c:482
-msgid "specify that the git repository is to be shared amongst several users"
-msgstr "chỉ ra cái mà kho git được chia sẻ giữa nhiều người dùng"
+#: builtin/merge.c:118
+msgid "switch `m' requires a value"
+msgstr "switch “m” yêu cầu một giá trị"
 
-#: builtin/init-db.c:525
+#: builtin/merge.c:141
 #, c-format
-msgid "cannot chdir to %s"
-msgstr "không thể chdir (chuyển đổi thư mục) sang %s"
+msgid "option `%s' requires a value"
+msgstr "tùy chọn “%s” yêu cầu một giá trị"
 
-#: builtin/init-db.c:546
+#: builtin/merge.c:187
 #, c-format
-msgid ""
-"%s (or --work-tree=<directory>) not allowed without specifying %s (or --git-"
-"dir=<directory>)"
-msgstr ""
-"%s (hoặc --work-tree=<thư-mục>) không cho phép không chỉ định %s (hoặc --git-"
-"dir=<thư-mục>)"
+msgid "Could not find merge strategy '%s'.\n"
+msgstr "Không tìm thấy chiến lược hòa trộn “%s”.\n"
 
-#: builtin/init-db.c:574
+#: builtin/merge.c:188
 #, c-format
-msgid "Cannot access work tree '%s'"
-msgstr "không thể truy cập cây (tree) làm việc “%s”"
-
-#: builtin/interpret-trailers.c:15
-msgid ""
-"git interpret-trailers [--in-place] [--trim-empty] [(--trailer "
-"<token>[(=|:)<value>])...] [<file>...]"
-msgstr ""
-"git interpret-trailers [--in-place] [--trim-empty] [(--trailer "
-"<thẻ>[(=|:)<giá-trị>])…] [<tập-tin>…]"
-
-#: builtin/interpret-trailers.c:92
-msgid "edit files in place"
-msgstr "sửa các tập tin tại chỗ"
-
-#: builtin/interpret-trailers.c:93
-msgid "trim empty trailers"
-msgstr "bộ dò vết cắt bỏ phần trống rỗng"
-
-#: builtin/interpret-trailers.c:96
-msgid "where to place the new trailer"
-msgstr "đặt phần đuôi mới ở đâu"
+msgid "Available strategies are:"
+msgstr "Các chiến lược sẵn sàng là:"
 
-#: builtin/interpret-trailers.c:98
-msgid "action if trailer already exists"
-msgstr "thao tác khi đã có phần đuôi"
+#: builtin/merge.c:193
+#, c-format
+msgid "Available custom strategies are:"
+msgstr "Các chiến lược tùy chỉnh sẵn sàng là:"
 
-#: builtin/interpret-trailers.c:100
-msgid "action if trailer is missing"
-msgstr "thao tác khi thiếu phần đuôi"
+#: builtin/merge.c:244 builtin/pull.c:152
+msgid "do not show a diffstat at the end of the merge"
+msgstr "không hiển thị thống kê khác biệt tại cuối của lần hòa trộn"
 
-#: builtin/interpret-trailers.c:102
-msgid "output only the trailers"
-msgstr "chỉ xuất phần đuôi"
+#: builtin/merge.c:247 builtin/pull.c:155
+msgid "show a diffstat at the end of the merge"
+msgstr "hiển thị thống kê khác biệt tại cuối của hòa trộn"
 
-#: builtin/interpret-trailers.c:103
-msgid "do not apply config rules"
-msgstr "đừng áp dụng các quy tắc cấu hình"
+#: builtin/merge.c:248 builtin/pull.c:158
+msgid "(synonym to --stat)"
+msgstr "(đồng nghĩa với --stat)"
 
-#: builtin/interpret-trailers.c:104
-msgid "join whitespace-continued values"
-msgstr "nối các giá trị khoảng-trắng-liên-tiếp"
+#: builtin/merge.c:250 builtin/pull.c:161
+msgid "add (at most <n>) entries from shortlog to merge commit message"
+msgstr "thêm (ít nhất <n>) mục từ shortlog cho ghi chú chuyển giao hòa trộn"
 
-#: builtin/interpret-trailers.c:105
-msgid "set parsing options"
-msgstr "đặt các tùy chọn phân tích cú pháp"
+#: builtin/merge.c:253 builtin/pull.c:167
+msgid "create a single commit instead of doing a merge"
+msgstr "tạo một lần chuyển giao đưon thay vì thực hiện việc hòa trộn"
 
-#: builtin/interpret-trailers.c:107
-msgid "trailer"
-msgstr "bộ dò vết"
+#: builtin/merge.c:255 builtin/pull.c:170
+msgid "perform a commit if the merge succeeds (default)"
+msgstr "thực hiện chuyển giao nếu hòa trộn thành công (mặc định)"
 
-#: builtin/interpret-trailers.c:108
-msgid "trailer(s) to add"
-msgstr "bộ dò vết cần thêm"
+#: builtin/merge.c:257 builtin/pull.c:173
+msgid "edit message before committing"
+msgstr "sửa chú thích trước khi chuyển giao"
 
-#: builtin/interpret-trailers.c:117
-msgid "--trailer with --only-input does not make sense"
-msgstr "--trailer cùng với --only-input không hợp lý"
+#: builtin/merge.c:259
+msgid "allow fast-forward (default)"
+msgstr "cho phép chuyển-tiếp-nhanh (mặc định)"
 
-#: builtin/interpret-trailers.c:127
-msgid "no input file given for in-place editing"
-msgstr "không đưa ra tập tin đầu vào để sửa tại-chỗ"
+#: builtin/merge.c:261 builtin/pull.c:180
+msgid "abort if fast-forward is not possible"
+msgstr "bỏ qua nếu chuyển-tiếp-nhanh không thể được"
 
-#: builtin/log.c:48
-msgid "git log [<options>] [<revision-range>] [[--] <path>...]"
-msgstr "git log [<các-tùy-chọn>] [<vùng-xem-xét>] [[--] <đường-dẫn>…]"
+#: builtin/merge.c:265 builtin/pull.c:183
+msgid "verify that the named commit has a valid GPG signature"
+msgstr "thẩm tra xem lần chuyển giao có tên đó có chữ ký GPG hợp lệ hay không"
 
-#: builtin/log.c:49
-msgid "git show [<options>] <object>..."
-msgstr "git show [<các-tùy-chọn>] <đối-tượng>…"
+#: builtin/merge.c:266 builtin/notes.c:787 builtin/pull.c:187
+#: builtin/rebase.c:512 builtin/rebase.c:1531 builtin/revert.c:114
+msgid "strategy"
+msgstr "chiến lược"
 
-#: builtin/log.c:93
-#, c-format
-msgid "invalid --decorate option: %s"
-msgstr "tùy chọn--decorate không hợp lệ: %s"
+#: builtin/merge.c:267 builtin/pull.c:188
+msgid "merge strategy to use"
+msgstr "chiến lược hòa trộn sẽ dùng"
 
-#: builtin/log.c:153
-msgid "suppress diff output"
-msgstr "chặn mọi kết xuất từ diff"
+#: builtin/merge.c:268 builtin/pull.c:191
+msgid "option=value"
+msgstr "tùy_chọn=giá_trị"
 
-#: builtin/log.c:154
-msgid "show source"
-msgstr "hiển thị mã nguồn"
+#: builtin/merge.c:269 builtin/pull.c:192
+msgid "option for selected merge strategy"
+msgstr "tùy chọn cho chiến lược hòa trộn đã chọn"
 
-#: builtin/log.c:155
-msgid "Use mail map file"
-msgstr "Sử dụng tập tin ánh xạ thư"
+#: builtin/merge.c:271
+msgid "merge commit message (for a non-fast-forward merge)"
+msgstr ""
+"hòa trộn ghi chú của lần chuyển giao (dành cho hòa trộn không-chuyển-tiếp-"
+"nhanh)"
 
-#: builtin/log.c:157
-msgid "only decorate refs that match <pattern>"
-msgstr "chỉ tô sáng các tham chiếu khớp với <mẫu>"
+#: builtin/merge.c:278
+msgid "abort the current in-progress merge"
+msgstr "bãi bỏ quá trình hòa trộn hiện tại đang thực hiện"
 
-#: builtin/log.c:159
-msgid "do not decorate refs that match <pattern>"
-msgstr "không tô sáng các tham chiếu khớp với <mẫu>"
+#: builtin/merge.c:280
+msgid "--abort but leave index and working tree alone"
+msgstr "--abort nhưng để lại bảng mục lục và cây làm việc"
 
-#: builtin/log.c:160
-msgid "decorate options"
-msgstr "các tùy chọn trang trí"
+#: builtin/merge.c:282
+msgid "continue the current in-progress merge"
+msgstr "tiếp tục quá trình hòa trộn hiện tại đang thực hiện"
 
-#: builtin/log.c:163
-msgid "Process line range n,m in file, counting from 1"
-msgstr "Xử lý chỉ dòng vùng n,m trong tập tin, tính từ 1"
+#: builtin/merge.c:284 builtin/pull.c:199
+msgid "allow merging unrelated histories"
+msgstr "cho phép hòa trộn lịch sử không liên quan"
 
-#: builtin/log.c:259
-#, c-format
-msgid "Final output: %d %s\n"
-msgstr "Kết xuất cuối cùng: %d %s\n"
+#: builtin/merge.c:290
+msgid "bypass pre-merge-commit and commit-msg hooks"
+msgstr "vòng qua móc (hook) pre-merge-commit và commit-msg"
 
-#: builtin/log.c:510
-#, c-format
-msgid "git show %s: bad file"
-msgstr "git show %s: sai tập tin"
+#: builtin/merge.c:307
+msgid "could not run stash."
+msgstr "không thể chạy stash."
 
-#: builtin/log.c:525 builtin/log.c:619
-#, c-format
-msgid "Could not read object %s"
-msgstr "Không thể đọc đối tượng %s"
+#: builtin/merge.c:312
+msgid "stash failed"
+msgstr "lệnh tạm cất gặp lỗi"
 
-#: builtin/log.c:643
+#: builtin/merge.c:317
 #, c-format
-msgid "Unknown type: %d"
-msgstr "Không nhận ra kiểu: %d"
+msgid "not a valid object: %s"
+msgstr "không phải là một đối tượng hợp lệ: %s"
 
-#: builtin/log.c:764
-msgid "format.headers without value"
-msgstr "format.headers không có giá trị cụ thể"
+#: builtin/merge.c:339 builtin/merge.c:356
+msgid "read-tree failed"
+msgstr "read-tree gặp lỗi"
 
-#: builtin/log.c:865
-msgid "name of output directory is too long"
-msgstr "tên của thư mục kết xuất quá dài"
+#: builtin/merge.c:386
+msgid " (nothing to squash)"
+msgstr " (không có gì để squash)"
 
-#: builtin/log.c:881
+#: builtin/merge.c:397
 #, c-format
-msgid "Cannot open patch file %s"
-msgstr "Không thể mở tập tin miếng vá: %s"
-
-#: builtin/log.c:898
-msgid "Need exactly one range."
-msgstr "Cần chính xác một vùng."
+msgid "Squash commit -- not updating HEAD\n"
+msgstr "Squash commit -- không cập nhật HEAD\n"
 
-#: builtin/log.c:908
-msgid "Not a range."
-msgstr "Không phải là một vùng."
+#: builtin/merge.c:447
+#, c-format
+msgid "No merge message -- not updating HEAD\n"
+msgstr "Không có lời chú thích hòa trộn -- nên không cập nhật HEAD\n"
 
-#: builtin/log.c:1014
-msgid "Cover letter needs email format"
-msgstr "“Cover letter” cần cho định dạng thư"
+#: builtin/merge.c:498
+#, c-format
+msgid "'%s' does not point to a commit"
+msgstr "“%s” không chỉ đến một lần chuyển giao nào cả"
 
-#: builtin/log.c:1095
+#: builtin/merge.c:585
 #, c-format
-msgid "insane in-reply-to: %s"
-msgstr "in-reply-to điên rồ: %s"
+msgid "Bad branch.%s.mergeoptions string: %s"
+msgstr "Chuỗi branch.%s.mergeoptions sai: %s"
 
-#: builtin/log.c:1122
-msgid "git format-patch [<options>] [<since> | <revision-range>]"
-msgstr "git format-patch [<các-tùy-chọn>] [<kể-từ> | <vùng-xem-xét>]"
+#: builtin/merge.c:705
+msgid "Not handling anything other than two heads merge."
+msgstr "Không cầm nắm gì ngoài hai head hòa trộn."
 
-#: builtin/log.c:1172
-msgid "Two output directories?"
-msgstr "Hai thư mục kết xuất?"
+#: builtin/merge.c:719
+#, c-format
+msgid "Unknown option for merge-recursive: -X%s"
+msgstr "Không hiểu tùy chọn cho merge-recursive: -X%s"
 
-#: builtin/log.c:1279 builtin/log.c:1932 builtin/log.c:1934 builtin/log.c:1946
+#: builtin/merge.c:734
 #, c-format
-msgid "Unknown commit %s"
-msgstr "Không hiểu lần chuyển giao %s"
+msgid "unable to write %s"
+msgstr "không thể ghi %s"
 
-#: builtin/log.c:1289 builtin/notes.c:887 builtin/tag.c:523
+#: builtin/merge.c:786
 #, c-format
-msgid "Failed to resolve '%s' as a valid ref."
-msgstr "Gặp lỗi khi phân giải “%s” như là một tham chiếu hợp lệ."
+msgid "Could not read from '%s'"
+msgstr "Không thể đọc từ “%s”"
 
-#: builtin/log.c:1294
-msgid "Could not find exact merge base."
-msgstr "Không tìm thấy nền hòa trộn chính xác."
+#: builtin/merge.c:795
+#, c-format
+msgid "Not committing merge; use 'git commit' to complete the merge.\n"
+msgstr ""
+"Vẫn chưa hòa trộn các lần chuyển giao; sử dụng lệnh “git commit” để hoàn tất "
+"việc hòa trộn.\n"
 
-#: builtin/log.c:1298
+#: builtin/merge.c:801
 msgid ""
-"Failed to get upstream, if you want to record base commit automatically,\n"
-"please use git branch --set-upstream-to to track a remote branch.\n"
-"Or you could specify base commit by --base=<base-commit-id> manually."
+"Please enter a commit message to explain why this merge is necessary,\n"
+"especially if it merges an updated upstream into a topic branch.\n"
+"\n"
 msgstr ""
-"Gặp lỗi khi lấy thượng nguồn, nếu bạn muốn ghi lại lần chuyển giao nền một\n"
-"cách tự động, vui lòng dùng \"git branch --set-upstream-to\" để theo dõi\n"
-"nhánh máy chủ. Hoặc là bạn có thể chỉ định lần chuyển giao nền bằng\n"
-"\"--base=<base-commit-id>\" một cách thủ công."
-
-#: builtin/log.c:1318
-msgid "Failed to find exact merge base"
-msgstr "Gặp lỗi khi tìm nền hòa trộn chính xác."
-
-#: builtin/log.c:1329
-msgid "base commit should be the ancestor of revision list"
-msgstr "lần chuyển giao nền không là tổ tiên của danh sách điểm xét duyệt"
+"Hãy nhập vào các thông tin để giải thích tại sao sự hòa trộn này là cần "
+"thiết,\n"
+"đặc biệt là khi nó hòa trộn thượng nguồn đã cập nhật vào trong một nhánh "
+"topic.\n"
+"\n"
 
-#: builtin/log.c:1333
-msgid "base commit shouldn't be in revision list"
-msgstr "lần chuyển giao nền không được trong danh sách điểm xét duyệt"
+#: builtin/merge.c:806
+msgid "An empty message aborts the commit.\n"
+msgstr "Nếu phần chú thích rỗng sẽ hủy bỏ lần chuyển giao.\n"
 
-#: builtin/log.c:1382
-msgid "cannot get patch id"
-msgstr "không thể lấy mã miếng vá"
+#: builtin/merge.c:809
+#, c-format
+msgid ""
+"Lines starting with '%c' will be ignored, and an empty message aborts\n"
+"the commit.\n"
+msgstr ""
+"Những dòng được bắt đầu bằng “%c” sẽ được bỏ qua, và nếu phần chú\n"
+"thích rỗng sẽ hủy bỏ lần chuyển giao.\n"
 
-#: builtin/log.c:1441
-msgid "use [PATCH n/m] even with a single patch"
-msgstr "dùng [PATCH n/m] ngay cả với miếng vá đơn"
+#: builtin/merge.c:862
+msgid "Empty commit message."
+msgstr "Chú thích của lần commit (chuyển giao) bị trống rỗng."
 
-#: builtin/log.c:1444
-msgid "use [PATCH] even with multiple patches"
-msgstr "dùng [VÁ] ngay cả với các miếng vá phức tạp"
+#: builtin/merge.c:877
+#, c-format
+msgid "Wonderful.\n"
+msgstr "Tuyệt vời.\n"
 
-#: builtin/log.c:1448
-msgid "print patches to standard out"
-msgstr "hiển thị miếng vá ra đầu ra chuẩn"
+#: builtin/merge.c:938
+#, c-format
+msgid "Automatic merge failed; fix conflicts and then commit the result.\n"
+msgstr ""
+"Việc tự động hòa trộn gặp lỗi; hãy sửa các xung đột sau đó chuyển giao kết "
+"quả.\n"
 
-#: builtin/log.c:1450
-msgid "generate a cover letter"
-msgstr "tạo bì thư"
+#: builtin/merge.c:977
+msgid "No current branch."
+msgstr "Không phải nhánh hiện hành."
 
-#: builtin/log.c:1452
-msgid "use simple number sequence for output file names"
-msgstr "sử dụng chỗi dãy số dạng đơn giản cho tên tập-tin xuất ra"
+#: builtin/merge.c:979
+msgid "No remote for the current branch."
+msgstr "Không có máy chủ cho nhánh hiện hành."
 
-#: builtin/log.c:1453
-msgid "sfx"
-msgstr "sfx"
+#: builtin/merge.c:981
+msgid "No default upstream defined for the current branch."
+msgstr "Không có thượng nguồn mặc định được định nghĩa cho nhánh hiện hành."
 
-#: builtin/log.c:1454
-msgid "use <sfx> instead of '.patch'"
-msgstr "sử dụng <sfx> thay cho “.patch”"
+#: builtin/merge.c:986
+#, c-format
+msgid "No remote-tracking branch for %s from %s"
+msgstr "Không nhánh mạng theo dõi cho %s từ %s"
 
-#: builtin/log.c:1456
-msgid "start numbering patches at <n> instead of 1"
-msgstr "bắt đầu đánh số miếng vá từ <n> thay vì 1"
+#: builtin/merge.c:1043
+#, c-format
+msgid "Bad value '%s' in environment '%s'"
+msgstr "Giá trị sai “%s” trong biến môi trường “%s”"
 
-#: builtin/log.c:1458
-msgid "mark the series as Nth re-roll"
-msgstr "đánh dấu chuỗi nối tiếp dạng thứ-N re-roll"
+#: builtin/merge.c:1146
+#, c-format
+msgid "not something we can merge in %s: %s"
+msgstr "không phải là một thứ gì đó mà chúng tôi có thể hòa trộn trong %s: %s"
 
-#: builtin/log.c:1460
-msgid "Use [RFC PATCH] instead of [PATCH]"
-msgstr "Dùng [RFC VÁ] thay cho [VÁ]"
+#: builtin/merge.c:1180
+msgid "not something we can merge"
+msgstr "không phải là thứ gì đó mà chúng tôi có thể hòa trộn"
 
-#: builtin/log.c:1463
-msgid "Use [<prefix>] instead of [PATCH]"
-msgstr "Dùng [<tiền-tố>] thay cho [VÁ]"
+#: builtin/merge.c:1283
+msgid "--abort expects no arguments"
+msgstr "--abort không nhận các đối số"
 
-#: builtin/log.c:1466
-msgid "store resulting files in <dir>"
-msgstr "lưu các tập tin kết quả trong <t.mục>"
+#: builtin/merge.c:1287
+msgid "There is no merge to abort (MERGE_HEAD missing)."
+msgstr ""
+"Ở đây không có lần hòa trộn nào được hủy bỏ giữa chừng cả (thiếu MERGE_HEAD)."
 
-#: builtin/log.c:1469
-msgid "don't strip/add [PATCH]"
-msgstr "không strip/add [VÁ]"
+#: builtin/merge.c:1296
+msgid "--quit expects no arguments"
+msgstr "--quit không nhận các đối số"
 
-#: builtin/log.c:1472
-msgid "don't output binary diffs"
-msgstr "không kết xuất diff (những khác biệt) nhị phân"
+#: builtin/merge.c:1309
+msgid "--continue expects no arguments"
+msgstr "--continue không nhận đối số"
 
-#: builtin/log.c:1474
-msgid "output all-zero hash in From header"
-msgstr "xuất mọi mã băm all-zero trong phần đầu From"
+#: builtin/merge.c:1313
+msgid "There is no merge in progress (MERGE_HEAD missing)."
+msgstr "Ở đây không có lần hòa trộn nào đang được xử lý cả (thiếu MERGE_HEAD)."
 
-#: builtin/log.c:1476
-msgid "don't include a patch matching a commit upstream"
-msgstr "không bao gồm miếng vá khớp với một lần chuyển giao thượng nguồn"
+#: builtin/merge.c:1329
+msgid ""
+"You have not concluded your merge (MERGE_HEAD exists).\n"
+"Please, commit your changes before you merge."
+msgstr ""
+"Bạn chưa kết thúc việc hòa trộn (MERGE_HEAD vẫn tồn tại).\n"
+"Hãy chuyển giao các thay đổi trước khi bạn có thể hòa trộn."
 
-#: builtin/log.c:1478
-msgid "show patch format instead of default (patch + stat)"
-msgstr "hiển thị định dạng miếng vá thay vì mặc định (miếng vá + thống kê)"
+#: builtin/merge.c:1336
+msgid ""
+"You have not concluded your cherry-pick (CHERRY_PICK_HEAD exists).\n"
+"Please, commit your changes before you merge."
+msgstr ""
+"Bạn chưa kết thúc việc cherry-pick (CHERRY_PICK_HEAD vẫn tồn tại).\n"
+"Hãy chuyển giao các thay đổi trước khi bạn có thể hòa trộn."
 
-#: builtin/log.c:1480
-msgid "Messaging"
-msgstr "Lời nhắn"
+#: builtin/merge.c:1339
+msgid "You have not concluded your cherry-pick (CHERRY_PICK_HEAD exists)."
+msgstr "Bạn chưa kết thúc việc cherry-pick (CHERRY_PICK_HEAD vẫn tồn tại)."
 
-#: builtin/log.c:1481
-msgid "header"
-msgstr "đầu đề thư"
+#: builtin/merge.c:1353
+msgid "You cannot combine --squash with --no-ff."
+msgstr "Bạn không thể kết hợp --squash với --no-ff."
 
-#: builtin/log.c:1482
-msgid "add email header"
-msgstr "thêm đầu đề thư"
+#: builtin/merge.c:1355
+msgid "You cannot combine --squash with --commit."
+msgstr "Bạn không thể kết hợp --squash với --commit."
 
-#: builtin/log.c:1483 builtin/log.c:1485
-msgid "email"
-msgstr "thư điện tử"
+#: builtin/merge.c:1371
+msgid "No commit specified and merge.defaultToUpstream not set."
+msgstr "Không chỉ ra lần chuyển giao và merge.defaultToUpstream chưa được đặt."
 
-#: builtin/log.c:1483
-msgid "add To: header"
-msgstr "thêm To: đầu đề thư"
+#: builtin/merge.c:1388
+msgid "Squash commit into empty head not supported yet"
+msgstr "Squash commit vào một head trống rỗng vẫn chưa được hỗ trợ"
 
-#: builtin/log.c:1485
-msgid "add Cc: header"
-msgstr "thêm Cc: đầu đề thư"
+#: builtin/merge.c:1390
+msgid "Non-fast-forward commit does not make sense into an empty head"
+msgstr ""
+"Chuyển giao không-chuyển-tiếp-nhanh không hợp lý ở trong một head trống rỗng"
 
-#: builtin/log.c:1487
-msgid "ident"
-msgstr "thụt lề"
+#: builtin/merge.c:1395
+#, c-format
+msgid "%s - not something we can merge"
+msgstr "%s - không phải là thứ gì đó mà chúng tôi có thể hòa trộn"
 
-#: builtin/log.c:1488
-msgid "set From address to <ident> (or committer ident if absent)"
+#: builtin/merge.c:1397
+msgid "Can merge only exactly one commit into empty head"
 msgstr ""
-"đặt “Địa chỉ gửi” thành <thụ lề> (hoặc thụt lề người commit nếu bỏ quên)"
-
-#: builtin/log.c:1490
-msgid "message-id"
-msgstr "message-id"
+"Không thể hòa trộn một cách đúng đắn một lần chuyển giao vào một head rỗng"
 
-#: builtin/log.c:1491
-msgid "make first mail a reply to <message-id>"
-msgstr "dùng thư đầu tiên để trả lời <message-id>"
+#: builtin/merge.c:1476
+msgid "refusing to merge unrelated histories"
+msgstr "từ chối hòa trộn lịch sử không liên quan"
 
-#: builtin/log.c:1492 builtin/log.c:1495
-msgid "boundary"
-msgstr "ranh giới"
+#: builtin/merge.c:1485
+msgid "Already up to date."
+msgstr "Đã cập nhật rồi."
 
-#: builtin/log.c:1493
-msgid "attach the patch"
-msgstr "đính kèm miếng vá"
+#: builtin/merge.c:1495
+#, c-format
+msgid "Updating %s..%s\n"
+msgstr "Đang cập nhật %s..%s\n"
 
-#: builtin/log.c:1496
-msgid "inline the patch"
-msgstr "dùng miếng vá làm nội dung"
+#: builtin/merge.c:1537
+#, c-format
+msgid "Trying really trivial in-index merge...\n"
+msgstr "Đang thử hòa trộn kiểu “trivial in-index”…\n"
 
-#: builtin/log.c:1500
-msgid "enable message threading, styles: shallow, deep"
-msgstr "cho phép luồng lời nhắn, kiểu: “shallow”, “deep”"
+#: builtin/merge.c:1544
+#, c-format
+msgid "Nope.\n"
+msgstr "Không.\n"
 
-#: builtin/log.c:1502
-msgid "signature"
-msgstr "chữ ký"
+#: builtin/merge.c:1569
+msgid "Already up to date. Yeeah!"
+msgstr "Đã cập nhật rồi. Yeeah!"
 
-#: builtin/log.c:1503
-msgid "add a signature"
-msgstr "thêm chữ ký"
+#: builtin/merge.c:1575
+msgid "Not possible to fast-forward, aborting."
+msgstr "Thực hiện lệnh chuyển-tiếp-nhanh là không thể được, đang bỏ qua."
 
-#: builtin/log.c:1504
-msgid "base-commit"
-msgstr "lần_chuyển_giao_nền"
+#: builtin/merge.c:1598 builtin/merge.c:1663
+#, c-format
+msgid "Rewinding the tree to pristine...\n"
+msgstr "Đang tua lại cây thành thời xa xưa…\n"
 
-#: builtin/log.c:1505
-msgid "add prerequisite tree info to the patch series"
-msgstr "add trước hết đòi hỏi thông tin cây tới sê-ri miếng vá"
+#: builtin/merge.c:1602
+#, c-format
+msgid "Trying merge strategy %s...\n"
+msgstr "Đang thử chiến lược hòa trộn %s…\n"
 
-#: builtin/log.c:1507
-msgid "add a signature from a file"
-msgstr "thêm chữ ký từ một tập tin"
+#: builtin/merge.c:1654
+#, c-format
+msgid "No merge strategy handled the merge.\n"
+msgstr "Không có chiến lược hòa trộn nào được nắm giữ (handle) sự hòa trộn.\n"
 
-#: builtin/log.c:1508
-msgid "don't print the patch filenames"
-msgstr "không hiển thị các tên tập tin của miếng vá"
+#: builtin/merge.c:1656
+#, c-format
+msgid "Merge with strategy %s failed.\n"
+msgstr "Hòa trộn với chiến lược %s gặp lỗi.\n"
 
-#: builtin/log.c:1510
-msgid "show progress while generating patches"
-msgstr "hiển thị bộ đo tiến triển trong khi tạo các miếng vá"
+#: builtin/merge.c:1665
+#, c-format
+msgid "Using the %s to prepare resolving by hand.\n"
+msgstr "Sử dụng %s để chuẩn bị giải quyết bằng tay.\n"
 
-#: builtin/log.c:1585
+#: builtin/merge.c:1677
 #, c-format
-msgid "invalid ident line: %s"
-msgstr "dòng thụt lề không hợp lệ: %s"
+msgid "Automatic merge went well; stopped before committing as requested\n"
+msgstr ""
+"Hòa trộn tự động đã trở nên tốt; bị dừng trước khi việc chuyển giao được yêu "
+"cầu\n"
 
-#: builtin/log.c:1600
-msgid "-n and -k are mutually exclusive."
-msgstr "-n và  -k loại từ lẫn nhau."
-
-#: builtin/log.c:1602
-msgid "--subject-prefix/--rfc and -k are mutually exclusive."
-msgstr "--subject-prefix/--rfc và -k xung khắc nhau."
+#: builtin/merge-base.c:32
+msgid "git merge-base [-a | --all] <commit> <commit>..."
+msgstr "git merge-base [-a | --all] <lần_chuyển_giao> <lần_chuyển_giao>…"
 
-#: builtin/log.c:1610
-msgid "--name-only does not make sense"
-msgstr "--name-only không hợp lý"
+#: builtin/merge-base.c:33
+msgid "git merge-base [-a | --all] --octopus <commit>..."
+msgstr "git merge-base [-a | --all] --octopus <lần_chuyển_giao>…"
 
-#: builtin/log.c:1612
-msgid "--name-status does not make sense"
-msgstr "--name-status không hợp lý"
+#: builtin/merge-base.c:34
+msgid "git merge-base --independent <commit>..."
+msgstr "git merge-base --independent <lần_chuyển_giao>…"
 
-#: builtin/log.c:1614
-msgid "--check does not make sense"
-msgstr "--check không hợp lý"
+#: builtin/merge-base.c:35
+msgid "git merge-base --is-ancestor <commit> <commit>"
+msgstr "git merge-base --is-ancestor <commit> <lần_chuyển_giao>"
 
-#: builtin/log.c:1646
-msgid "standard output, or directory, which one?"
-msgstr "đầu ra chuẩn, hay thư mục, chọn cái nào?"
+#: builtin/merge-base.c:36
+msgid "git merge-base --fork-point <ref> [<commit>]"
+msgstr "git merge-base --fork-point <tham-chiếu> [<lần_chuyển_giao>]"
 
-#: builtin/log.c:1648
-#, c-format
-msgid "Could not create directory '%s'"
-msgstr "Không thể tạo thư mục “%s”"
+#: builtin/merge-base.c:153
+msgid "output all common ancestors"
+msgstr "xuất ra tất cả các ông bà, tổ tiên chung"
 
-#: builtin/log.c:1741
-#, c-format
-msgid "unable to read signature file '%s'"
-msgstr "không thể đọc tập tin chữ ký “%s”"
+#: builtin/merge-base.c:155
+msgid "find ancestors for a single n-way merge"
+msgstr "tìm tổ tiên của hòa trộn n-way đơn"
 
-#: builtin/log.c:1773
-msgid "Generating patches"
-msgstr "Đang tạo các miếng vá"
+#: builtin/merge-base.c:157
+msgid "list revs not reachable from others"
+msgstr "liệt kê các “rev” mà nó không thể đọc được từ cái khác"
 
-#: builtin/log.c:1817
-msgid "Failed to create output files"
-msgstr "Gặp lỗi khi tạo các tập tin kết xuất"
+#: builtin/merge-base.c:159
+msgid "is the first one ancestor of the other?"
+msgstr "là cha mẹ đầu tiên của cái khác?"
 
-#: builtin/log.c:1867
-msgid "git cherry [-v] [<upstream> [<head> [<limit>]]]"
-msgstr "git cherry [-v] [<thượng-nguồn> [<đầu> [<giới-hạn>]]]"
+#: builtin/merge-base.c:161
+msgid "find where <commit> forked from reflog of <ref>"
+msgstr "tìm xem <commit> được rẽ nhánh ở đâu từ reflog của <th.chiếu>"
 
-#: builtin/log.c:1921
-#, c-format
+#: builtin/merge-file.c:9
 msgid ""
-"Could not find a tracked remote branch, please specify <upstream> manually.\n"
+"git merge-file [<options>] [-L <name1> [-L <orig> [-L <name2>]]] <file1> "
+"<orig-file> <file2>"
 msgstr ""
-"Không tìm thấy nhánh mạng được theo dõi, hãy chỉ định <thượng-nguồn> một "
-"cách thủ công.\n"
+"git merge-file [<các tùy chọn>] [-L <tên1> [-L <gốc> [-L <tên2>]]] <tập-"
+"tin1> <tập-tin-gốc> <tập-tin2>"
 
-#: builtin/ls-files.c:468
-msgid "git ls-files [<options>] [<file>...]"
-msgstr "git ls-files [<các-tùy-chọn>] [<tập-tin>…]"
+#: builtin/merge-file.c:35
+msgid "send results to standard output"
+msgstr "gửi kết quả vào đầu ra tiêu chuẩn"
 
-#: builtin/ls-files.c:517
-msgid "identify the file status with tags"
-msgstr "nhận dạng các trạng thái tập tin với thẻ"
+#: builtin/merge-file.c:36
+msgid "use a diff3 based merge"
+msgstr "dùng kiểu hòa dựa trên diff3"
 
-#: builtin/ls-files.c:519
-msgid "use lowercase letters for 'assume unchanged' files"
-msgstr ""
-"dùng chữ cái viết thường cho các tập tin “assume unchanged” (giả định không "
-"thay đổi)"
+#: builtin/merge-file.c:37
+msgid "for conflicts, use our version"
+msgstr "để tránh xung đột, sử dụng phiên bản của chúng ta"
 
-#: builtin/ls-files.c:521
-msgid "use lowercase letters for 'fsmonitor clean' files"
-msgstr "dùng chữ cái viết thường cho các tập tin “fsmonitor clean”"
+#: builtin/merge-file.c:39
+msgid "for conflicts, use their version"
+msgstr "để tránh xung đột, sử dụng phiên bản của họ"
 
-#: builtin/ls-files.c:523
-msgid "show cached files in the output (default)"
-msgstr "hiển thị các tập tin được nhớ tạm vào đầu ra (mặc định)"
+#: builtin/merge-file.c:41
+msgid "for conflicts, use a union version"
+msgstr "để tránh xung đột, sử dụng phiên bản kết hợp"
 
-#: builtin/ls-files.c:525
-msgid "show deleted files in the output"
-msgstr "hiển thị các tập tin đã xóa trong kết xuất"
+#: builtin/merge-file.c:44
+msgid "for conflicts, use this marker size"
+msgstr "để tránh xung đột, hãy sử dụng kích thước bộ tạo này"
 
-#: builtin/ls-files.c:527
-msgid "show modified files in the output"
-msgstr "hiển thị các tập tin đã bị sửa đổi ra kết xuất"
+#: builtin/merge-file.c:45
+msgid "do not warn about conflicts"
+msgstr "không cảnh báo về các xung đột xảy ra"
 
-#: builtin/ls-files.c:529
-msgid "show other files in the output"
-msgstr "hiển thị các tập tin khác trong kết xuất"
+#: builtin/merge-file.c:47
+msgid "set labels for file1/orig-file/file2"
+msgstr "đặt nhãn cho tập-tin-1/tập-tin-gốc/tập-tin-2"
 
-#: builtin/ls-files.c:531
-msgid "show ignored files in the output"
-msgstr "hiển thị các tập tin bị bỏ qua trong kết xuất"
+#: builtin/merge-recursive.c:47
+#, c-format
+msgid "unknown option %s"
+msgstr "không hiểu tùy chọn %s"
 
-#: builtin/ls-files.c:534
-msgid "show staged contents' object name in the output"
-msgstr "hiển thị tên đối tượng của nội dung được đặt lên bệ phóng ra kết xuất"
+#: builtin/merge-recursive.c:53
+#, c-format
+msgid "could not parse object '%s'"
+msgstr "không thể phân tích đối tượng “%s”"
 
-#: builtin/ls-files.c:536
-msgid "show files on the filesystem that need to be removed"
-msgstr "hiển thị các tập tin trên hệ thống tập tin mà nó cần được gỡ bỏ"
+#: builtin/merge-recursive.c:57
+#, c-format
+msgid "cannot handle more than %d base. Ignoring %s."
+msgid_plural "cannot handle more than %d bases. Ignoring %s."
+msgstr[0] "không thể xử lý nhiều hơn %d nền. Bỏ qua %s."
 
-#: builtin/ls-files.c:538
-msgid "show 'other' directories' names only"
-msgstr "chỉ hiển thị tên của các thư mục “khác”"
+#: builtin/merge-recursive.c:65
+msgid "not handling anything other than two heads merge."
+msgstr "không xử lý gì ngoài hai head hòa trộn."
 
-#: builtin/ls-files.c:540
-msgid "show line endings of files"
-msgstr "hiển thị kết thúc dòng của các tập tin"
+#: builtin/merge-recursive.c:74 builtin/merge-recursive.c:76
+#, c-format
+msgid "could not resolve ref '%s'"
+msgstr "không thể phân giải tham chiếu %s"
 
-#: builtin/ls-files.c:542
-msgid "don't show empty directories"
-msgstr "không hiển thị thư mục rỗng"
+#: builtin/merge-recursive.c:82
+#, c-format
+msgid "Merging %s with %s\n"
+msgstr "Đang hòa trộn %s với %s\n"
 
-#: builtin/ls-files.c:545
-msgid "show unmerged files in the output"
-msgstr "hiển thị các tập tin chưa hòa trộn trong kết xuất"
+#: builtin/mktree.c:66
+msgid "git mktree [-z] [--missing] [--batch]"
+msgstr "git mktree [-z] [--missing] [--batch]"
 
-#: builtin/ls-files.c:547
-msgid "show resolve-undo information"
-msgstr "hiển thị thông tin resolve-undo"
+#: builtin/mktree.c:154
+msgid "input is NUL terminated"
+msgstr "đầu vào được chấm dứt bởi NUL"
 
-#: builtin/ls-files.c:549
-msgid "skip files matching pattern"
-msgstr "bỏ qua những tập tin khớp với một mẫu"
+#: builtin/mktree.c:155 builtin/write-tree.c:26
+msgid "allow missing objects"
+msgstr "cho phép thiếu đối tượng"
 
-#: builtin/ls-files.c:552
-msgid "exclude patterns are read from <file>"
-msgstr "mẫu loại trừ được đọc từ <tập tin>"
+#: builtin/mktree.c:156
+msgid "allow creation of more than one tree"
+msgstr "cho phép tạo nhiều hơn một cây"
 
-#: builtin/ls-files.c:555
-msgid "read additional per-directory exclude patterns in <file>"
-msgstr "đọc thêm các mẫu ngoại trừ mỗi thư mục trong <tập tin>"
+#: builtin/multi-pack-index.c:9
+msgid ""
+"git multi-pack-index [<options>] (write|verify|expire|repack --batch-"
+"size=<size>)"
+msgstr ""
+"git multi-pack-index [<các-tùy-chọn>] (write|verify|expire|repack --batch-"
+"size=<cỡ>)"
 
-#: builtin/ls-files.c:557
-msgid "add the standard git exclusions"
-msgstr "thêm loại trừ tiêu chuẩn kiểu git"
+#: builtin/multi-pack-index.c:26
+msgid "object directory containing set of packfile and pack-index pairs"
+msgstr "thư mục đối tượng có chứa một bộ các tập tin gói và cặp pack-index"
 
-#: builtin/ls-files.c:560
-msgid "make the output relative to the project top directory"
-msgstr "làm cho kết xuất liên quan đến thư mục ở mức cao nhất (gốc) của dự án"
+#: builtin/multi-pack-index.c:29
+msgid ""
+"during repack, collect pack-files of smaller size into a batch that is "
+"larger than this size"
+msgstr ""
+"trong suốt quá trình đóng gói lại, gom các tập tin gói có kích cỡ nhỏ hơn "
+"vào một bó cái mà lớn hơn kích thước này"
 
-#: builtin/ls-files.c:563
-msgid "recurse through submodules"
-msgstr "đệ quy xuyên qua mô-đun con"
+#: builtin/multi-pack-index.c:50 builtin/prune-packed.c:67
+msgid "too many arguments"
+msgstr "có quá nhiều đối số"
 
-#: builtin/ls-files.c:565
-msgid "if any <file> is not in the index, treat this as an error"
-msgstr "nếu <tập tin> bất kỳ không ở trong bảng mục lục, xử lý nó như một lỗi"
+#: builtin/multi-pack-index.c:60
+msgid "--batch-size option is only for 'repack' subcommand"
+msgstr "tùy chọn --batch-size chỉ cho lệnh con 'repack'"
 
-#: builtin/ls-files.c:566
-msgid "tree-ish"
-msgstr "tree-ish"
+#: builtin/multi-pack-index.c:69
+#, c-format
+msgid "unrecognized subcommand: %s"
+msgstr "không hiểu câu lệnh con: %s"
 
-#: builtin/ls-files.c:567
-msgid "pretend that paths removed since <tree-ish> are still present"
-msgstr ""
-"giả định rằng các đường dẫn đã bị gỡ bỏ kể từ <tree-ish> nay vẫn hiện diện"
+#: builtin/mv.c:18
+msgid "git mv [<options>] <source>... <destination>"
+msgstr "git mv [<các tùy chọn>] <nguồn>… <đích>"
 
-#: builtin/ls-files.c:569
-msgid "show debugging data"
-msgstr "hiển thị dữ liệu gỡ lỗi"
+#: builtin/mv.c:83
+#, c-format
+msgid "Directory %s is in index and no submodule?"
+msgstr "Thư mục “%s” có ở trong chỉ mục mà không có mô-đun con?"
 
-#: builtin/ls-remote.c:9
-msgid ""
-"git ls-remote [--heads] [--tags] [--refs] [--upload-pack=<exec>]\n"
-"                     [-q | --quiet] [--exit-code] [--get-url]\n"
-"                     [--symref] [<repository> [<refs>...]]"
+#: builtin/mv.c:85
+msgid "Please stage your changes to .gitmodules or stash them to proceed"
 msgstr ""
-"git ls-remote [--heads] [--tags] [--refs] [--upload-pack=<exec>]\n"
-"                     [-q | --quiet] [--exit-code] [--get-url]\n"
-"                     [--symref] [<kho> [<các tham chiếu>…]]"
+"Hãy đưa các thay đổi của bạn vào .gitmodules hay tạm cất chúng đi để xử lý"
 
-#: builtin/ls-remote.c:59
-msgid "do not print remote URL"
-msgstr "không hiển thị URL máy chủ"
+#: builtin/mv.c:103
+#, c-format
+msgid "%.*s is in index"
+msgstr "%.*s trong bảng mục lục"
 
-#: builtin/ls-remote.c:60 builtin/ls-remote.c:62
-msgid "exec"
-msgstr "thực thi"
+#: builtin/mv.c:125
+msgid "force move/rename even if target exists"
+msgstr "ép buộc di chuyển hay đổi tên thậm chí cả khi đích đã tồn tại"
 
-#: builtin/ls-remote.c:61 builtin/ls-remote.c:63
-msgid "path of git-upload-pack on the remote host"
-msgstr "đường dẫn của git-upload-pack trên máy chủ"
+#: builtin/mv.c:127
+msgid "skip move/rename errors"
+msgstr "bỏ qua các lỗi liên quan đến di chuyển, đổi tên"
 
-#: builtin/ls-remote.c:65
-msgid "limit to tags"
-msgstr "giới hạn tới các thẻ"
+#: builtin/mv.c:169
+#, c-format
+msgid "destination '%s' is not a directory"
+msgstr "có đích “%s” nhưng đây không phải là một thư mục"
 
-#: builtin/ls-remote.c:66
-msgid "limit to heads"
-msgstr "giới hạn cho các đầu"
+#: builtin/mv.c:180
+#, c-format
+msgid "Checking rename of '%s' to '%s'\n"
+msgstr "Đang kiểm tra việc đổi tên của “%s” thành “%s”\n"
 
-#: builtin/ls-remote.c:67
-msgid "do not show peeled tags"
-msgstr "không hiển thị thẻ bị peel (gọt bỏ)"
+#: builtin/mv.c:184
+msgid "bad source"
+msgstr "nguồn sai"
 
-#: builtin/ls-remote.c:69
-msgid "take url.<base>.insteadOf into account"
-msgstr "lấy url.<base>.insteadOf vào trong tài khoản"
+#: builtin/mv.c:187
+msgid "can not move directory into itself"
+msgstr "không thể di chuyển một thư mục vào trong chính nó được"
 
-#: builtin/ls-remote.c:73
-msgid "exit with exit code 2 if no matching refs are found"
-msgstr "thoát với mã là 2 nếu không tìm thấy tham chiếu nào khớp"
+#: builtin/mv.c:190
+msgid "cannot move directory over file"
+msgstr "không di chuyển được thư mục thông qua tập tin"
 
-#: builtin/ls-remote.c:76
-msgid "show underlying ref in addition to the object pointed by it"
-msgstr "hiển thị tham chiếu nằm dưới để thêm vào đối tượng được chỉ bởi nó"
+#: builtin/mv.c:199
+msgid "source directory is empty"
+msgstr "thư mục nguồn là trống rỗng"
 
-#: builtin/ls-tree.c:29
-msgid "git ls-tree [<options>] <tree-ish> [<path>...]"
-msgstr "git ls-tree [<các-tùy-chọn>] <tree-ish> [<đường-dẫn>…]"
+#: builtin/mv.c:224
+msgid "not under version control"
+msgstr "không nằm dưới sự quản lý mã nguồn"
 
-#: builtin/ls-tree.c:127
-msgid "only show trees"
-msgstr "chỉ hiển thị các tree"
+#: builtin/mv.c:227
+msgid "destination exists"
+msgstr "đích đã tồn tại sẵn rồi"
+
+#: builtin/mv.c:235
+#, c-format
+msgid "overwriting '%s'"
+msgstr "đang ghi đè lên “%s”"
+
+#: builtin/mv.c:238
+msgid "Cannot overwrite"
+msgstr "Không thể ghi đè"
+
+#: builtin/mv.c:241
+msgid "multiple sources for the same target"
+msgstr "nhiều nguồn cho cùng một đích"
+
+#: builtin/mv.c:243
+msgid "destination directory does not exist"
+msgstr "thư mục đích không tồn tại"
+
+#: builtin/mv.c:250
+#, c-format
+msgid "%s, source=%s, destination=%s"
+msgstr "%s, nguồn=%s, đích=%s"
 
-#: builtin/ls-tree.c:129
-msgid "recurse into subtrees"
-msgstr "đệ quy vào các thư mục con"
+#: builtin/mv.c:271
+#, c-format
+msgid "Renaming %s to %s\n"
+msgstr "Đổi tên %s thành %s\n"
 
-#: builtin/ls-tree.c:131
-msgid "show trees when recursing"
-msgstr "hiển thị cây khi đệ quy"
+#: builtin/mv.c:277 builtin/remote.c:716 builtin/repack.c:518
+#, c-format
+msgid "renaming '%s' failed"
+msgstr "gặp lỗi khi đổi tên “%s”"
 
-#: builtin/ls-tree.c:134
-msgid "terminate entries with NUL byte"
-msgstr "chấm dứt mục tin với byte NUL"
+#: builtin/name-rev.c:403
+msgid "git name-rev [<options>] <commit>..."
+msgstr "git name-rev [<các tùy chọn>] <commit>…"
 
-#: builtin/ls-tree.c:135
-msgid "include object size"
-msgstr "gồm cả kích thước đối tượng"
+#: builtin/name-rev.c:404
+msgid "git name-rev [<options>] --all"
+msgstr "git name-rev [<các tùy chọn>] --all"
 
-#: builtin/ls-tree.c:137 builtin/ls-tree.c:139
-msgid "list only filenames"
-msgstr "chỉ liệt kê tên tập tin"
+#: builtin/name-rev.c:405
+msgid "git name-rev [<options>] --stdin"
+msgstr "git name-rev [<các tùy chọn>] --stdin"
 
-#: builtin/ls-tree.c:142
-msgid "use full path names"
-msgstr "dùng tên đường dẫn đầy đủ"
+#: builtin/name-rev.c:462
+msgid "print only names (no SHA-1)"
+msgstr "chỉ hiển thị tên (không SHA-1)"
 
-#: builtin/ls-tree.c:144
-msgid "list entire tree; not just current directory (implies --full-name)"
-msgstr "liệt kê cây mục tin; không chỉ thư mục hiện hành (ngụ ý --full-name)"
+#: builtin/name-rev.c:463
+msgid "only use tags to name the commits"
+msgstr "chỉ dùng các thẻ để đặt tên cho các lần chuyển giao"
 
-#: builtin/mailsplit.c:241
-#, c-format
-msgid "empty mbox: '%s'"
-msgstr "mbox trống rỗng: “%s”"
+#: builtin/name-rev.c:465
+msgid "only use refs matching <pattern>"
+msgstr "chỉ sử dụng các tham chiếu khớp với <mẫu>"
 
-#: builtin/merge.c:51
-msgid "git merge [<options>] [<commit>...]"
-msgstr "git merge [<các-tùy-chọn>] [<commit>…]"
+#: builtin/name-rev.c:467
+msgid "ignore refs matching <pattern>"
+msgstr "bỏ qua các tham chiếu khớp với <mẫu>"
 
-#: builtin/merge.c:52
-msgid "git merge --abort"
-msgstr "git merge --abort"
+#: builtin/name-rev.c:469
+msgid "list all commits reachable from all refs"
+msgstr ""
+"liệt kê tất cả các lần chuyển giao có thể đọc được từ tất cả các tham chiếu"
 
-#: builtin/merge.c:53
-msgid "git merge --continue"
-msgstr "git merge --continue"
+#: builtin/name-rev.c:470
+msgid "read from stdin"
+msgstr "đọc từ đầu vào tiêu chuẩn"
 
-#: builtin/merge.c:110
-msgid "switch `m' requires a value"
-msgstr "switch “m” yêu cầu một giá trị"
+#: builtin/name-rev.c:471
+msgid "allow to print `undefined` names (default)"
+msgstr "cho phép in các tên “chưa định nghĩa” (mặc định)"
 
-#: builtin/merge.c:147
-#, c-format
-msgid "Could not find merge strategy '%s'.\n"
-msgstr "Không tìm thấy chiến lược hòa trộn “%s”.\n"
+#: builtin/name-rev.c:477
+msgid "dereference tags in the input (internal use)"
+msgstr "bãi bỏ tham chiếu các thẻ trong đầu vào (dùng nội bộ)"
 
-#: builtin/merge.c:148
-#, c-format
-msgid "Available strategies are:"
-msgstr "Các chiến lược sẵn sàng là:"
+#: builtin/notes.c:28
+msgid "git notes [--ref <notes-ref>] [list [<object>]]"
+msgstr "git notes [--ref <notes-ref>] [list [<đối-tượng>]]"
 
-#: builtin/merge.c:153
-#, c-format
-msgid "Available custom strategies are:"
-msgstr "Các chiến lược tùy chỉnh sẵn sàng là:"
+#: builtin/notes.c:29
+msgid ""
+"git notes [--ref <notes-ref>] add [-f] [--allow-empty] [-m <msg> | -F <file> "
+"| (-c | -C) <object>] [<object>]"
+msgstr ""
+"git notes [--ref <notes-ref>] add [-f] [--allow-empty] [-m <lời-nhắn> | -F "
+"<tập-tin> | (-c | -C) <đối-tượng>] [<đối-tượng>]"
 
-#: builtin/merge.c:203 builtin/pull.c:142
-msgid "do not show a diffstat at the end of the merge"
-msgstr "không hiển thị thống kê khác biệt tại cuối của lần hòa trộn"
+#: builtin/notes.c:30
+msgid "git notes [--ref <notes-ref>] copy [-f] <from-object> <to-object>"
+msgstr "git notes [--ref <notes-ref>] copy [-f] <từ-đối-tượng> <đến-đối-tượng>"
 
-#: builtin/merge.c:206 builtin/pull.c:145
-msgid "show a diffstat at the end of the merge"
-msgstr "hiển thị thống kê khác biệt tại cuối của hòa trộn"
+#: builtin/notes.c:31
+msgid ""
+"git notes [--ref <notes-ref>] append [--allow-empty] [-m <msg> | -F <file> | "
+"(-c | -C) <object>] [<object>]"
+msgstr ""
+"git notes [--ref <notes-ref>] append [--allow-empty] [-m <lời-nhắn> | -F "
+"<tập-tin> | (-c | -C) <đối-tượng>] [<đối-tượng>]"
 
-#: builtin/merge.c:207 builtin/pull.c:148
-msgid "(synonym to --stat)"
-msgstr "(đồng nghĩa với --stat)"
+#: builtin/notes.c:32
+msgid "git notes [--ref <notes-ref>] edit [--allow-empty] [<object>]"
+msgstr "git notes [--ref <notes-ref>] edit [--allow-empty] [<đối-tượng>]"
 
-#: builtin/merge.c:209 builtin/pull.c:151
-msgid "add (at most <n>) entries from shortlog to merge commit message"
-msgstr "thêm (ít nhất <n>) mục từ shortlog cho ghi chú chuyển giao hòa trộn"
+#: builtin/notes.c:33
+msgid "git notes [--ref <notes-ref>] show [<object>]"
+msgstr "git notes [--ref <notes-ref>] show [<đối-tượng>]"
 
-#: builtin/merge.c:212 builtin/pull.c:157
-msgid "create a single commit instead of doing a merge"
-msgstr "tạo một lần chuyển giao đưon thay vì thực hiện việc hòa trộn"
+#: builtin/notes.c:34
+msgid ""
+"git notes [--ref <notes-ref>] merge [-v | -q] [-s <strategy>] <notes-ref>"
+msgstr ""
+"git notes [--ref <notes-ref>] merge [-v | -q] [-s <chiến-lược> ] <notes-ref>"
 
-#: builtin/merge.c:214 builtin/pull.c:160
-msgid "perform a commit if the merge succeeds (default)"
-msgstr "thực hiện chuyển giao nếu hòa trộn thành công (mặc định)"
+#: builtin/notes.c:35
+msgid "git notes merge --commit [-v | -q]"
+msgstr "git notes merge --commit [-v | -q]"
 
-#: builtin/merge.c:216 builtin/pull.c:163
-msgid "edit message before committing"
-msgstr "sửa chú thích trước khi chuyển giao"
+#: builtin/notes.c:36
+msgid "git notes merge --abort [-v | -q]"
+msgstr "git notes merge --abort [-v | -q]"
 
-#: builtin/merge.c:217
-msgid "allow fast-forward (default)"
-msgstr "cho phép chuyển-tiếp-nhanh (mặc định)"
+#: builtin/notes.c:37
+msgid "git notes [--ref <notes-ref>] remove [<object>...]"
+msgstr "git notes [--ref <notes-ref>] remove [<đối-tượng>…]"
 
-#: builtin/merge.c:219 builtin/pull.c:169
-msgid "abort if fast-forward is not possible"
-msgstr "bỏ qua nếu chuyển-tiếp-nhanh không thể được"
+#: builtin/notes.c:38
+msgid "git notes [--ref <notes-ref>] prune [-n] [-v]"
+msgstr "git notes [--ref <notes-ref>] prune [-n] [-v]"
 
-#: builtin/merge.c:223 builtin/pull.c:172
-msgid "verify that the named commit has a valid GPG signature"
-msgstr "thẩm tra xem lần chuyển giao có tên đó có chữ ký GPG hợp lệ hay không"
+#: builtin/notes.c:39
+msgid "git notes [--ref <notes-ref>] get-ref"
+msgstr "git notes [--ref <notes-ref>] get-ref"
 
-#: builtin/merge.c:224 builtin/notes.c:777 builtin/pull.c:176
-#: builtin/revert.c:109
-msgid "strategy"
-msgstr "chiến lược"
+#: builtin/notes.c:44
+msgid "git notes [list [<object>]]"
+msgstr "git notes [list [<đối tượng>]]"
 
-#: builtin/merge.c:225 builtin/pull.c:177
-msgid "merge strategy to use"
-msgstr "chiến lược hòa trộn sẽ dùng"
+#: builtin/notes.c:49
+msgid "git notes add [<options>] [<object>]"
+msgstr "git notes add [<các tùy chọn>] [<đối-tượng>]"
 
-#: builtin/merge.c:226 builtin/pull.c:180
-msgid "option=value"
-msgstr "tùy_chọn=giá_trị"
+#: builtin/notes.c:54
+msgid "git notes copy [<options>] <from-object> <to-object>"
+msgstr "git notes copy [<các tùy chọn>] <từ-đối-tượng> <đến-đối-tượng>"
 
-#: builtin/merge.c:227 builtin/pull.c:181
-msgid "option for selected merge strategy"
-msgstr "tùy chọn cho chiến lược hòa trộn đã chọn"
+#: builtin/notes.c:55
+msgid "git notes copy --stdin [<from-object> <to-object>]..."
+msgstr "git notes copy --stdin [<từ-đối-tượng> <đến-đối-tượng>]…"
 
-#: builtin/merge.c:229
-msgid "merge commit message (for a non-fast-forward merge)"
-msgstr ""
-"hòa trộn ghi chú của lần chuyển giao (dành cho hòa trộn không-chuyển-tiếp-"
-"nhanh)"
+#: builtin/notes.c:60
+msgid "git notes append [<options>] [<object>]"
+msgstr "git notes append [<các tùy chọn>] [<đối-tượng>]"
 
-#: builtin/merge.c:233
-msgid "abort the current in-progress merge"
-msgstr "bãi bỏ quá trình hòa trộn hiện tại đang thực hiện"
+#: builtin/notes.c:65
+msgid "git notes edit [<object>]"
+msgstr "git notes edit [<đối tượng>]"
 
-#: builtin/merge.c:235
-msgid "continue the current in-progress merge"
-msgstr "tiếp tục quá trình hòa trộn hiện tại đang thực hiện"
+#: builtin/notes.c:70
+msgid "git notes show [<object>]"
+msgstr "git notes show [<đối tượng>]"
 
-#: builtin/merge.c:237 builtin/pull.c:188
-msgid "allow merging unrelated histories"
-msgstr "cho phép hòa trộn lịch sử không liên quan"
+#: builtin/notes.c:75
+msgid "git notes merge [<options>] <notes-ref>"
+msgstr "git notes merge [<các tùy chọn>] <notes-ref>"
 
-#: builtin/merge.c:243
-msgid "verify commit-msg hook"
-msgstr "thẩm tra móc (hook) commit-msg"
+#: builtin/notes.c:76
+msgid "git notes merge --commit [<options>]"
+msgstr "git notes merge --commit [<các tùy chọn>]"
 
-#: builtin/merge.c:268
-msgid "could not run stash."
-msgstr "không thể chạy stash."
+#: builtin/notes.c:77
+msgid "git notes merge --abort [<options>]"
+msgstr "git notes merge --abort [<các tùy chọn>]"
 
-#: builtin/merge.c:273
-msgid "stash failed"
-msgstr "lệnh tạm cất gặp lỗi"
+#: builtin/notes.c:82
+msgid "git notes remove [<object>]"
+msgstr "git notes remove [<đối tượng>]"
 
-#: builtin/merge.c:278
-#, c-format
-msgid "not a valid object: %s"
-msgstr "không phải là một đối tượng hợp lệ: %s"
+#: builtin/notes.c:87
+msgid "git notes prune [<options>]"
+msgstr "git notes prune [<các tùy chọn>]"
 
-#: builtin/merge.c:300 builtin/merge.c:317
-msgid "read-tree failed"
-msgstr "read-tree gặp lỗi"
+#: builtin/notes.c:92
+msgid "git notes get-ref"
+msgstr "git notes get-ref"
 
-#: builtin/merge.c:347
-msgid " (nothing to squash)"
-msgstr " (không có gì để squash)"
+#: builtin/notes.c:97
+msgid "Write/edit the notes for the following object:"
+msgstr "Ghi hay sửa ghi chú cho đối tượng sau đây:"
 
-#: builtin/merge.c:358
+#: builtin/notes.c:150
 #, c-format
-msgid "Squash commit -- not updating HEAD\n"
-msgstr "Squash commit -- không cập nhật HEAD\n"
+msgid "unable to start 'show' for object '%s'"
+msgstr "không thể khởi chạy “show” cho đối tượng “%s”"
 
-#: builtin/merge.c:408
-#, c-format
-msgid "No merge message -- not updating HEAD\n"
-msgstr "Không có lời chú thích hòa trộn -- nên không cập nhật HEAD\n"
+#: builtin/notes.c:154
+msgid "could not read 'show' output"
+msgstr "không thể đọc kết xuất “show”"
 
-#: builtin/merge.c:458
+#: builtin/notes.c:162
 #, c-format
-msgid "'%s' does not point to a commit"
-msgstr "“%s” không chỉ đến một lần chuyển giao nào cả"
+msgid "failed to finish 'show' for object '%s'"
+msgstr "gặp lỗi khi hoàn thành “show” cho đối tượng “%s”"
 
-#: builtin/merge.c:548
-#, c-format
-msgid "Bad branch.%s.mergeoptions string: %s"
-msgstr "Chuỗi branch.%s.mergeoptions sai: %s"
+#: builtin/notes.c:197
+msgid "please supply the note contents using either -m or -F option"
+msgstr ""
+"xin hãy áp dụng nội dung của ghi chú sử dụng hoặc là tùy chọn -m hoặc là -F"
 
-#: builtin/merge.c:669
-msgid "Not handling anything other than two heads merge."
-msgstr "Không cầm nắm gì ngoài hai head hòa trộn"
+#: builtin/notes.c:206
+msgid "unable to write note object"
+msgstr "không thể ghi đối tượng ghi chú (note)"
 
-#: builtin/merge.c:683
+#: builtin/notes.c:208
 #, c-format
-msgid "Unknown option for merge-recursive: -X%s"
-msgstr "Không hiểu tùy chọn cho merge-recursive: -X%s"
+msgid "the note contents have been left in %s"
+msgstr "nội dung ghi chú còn lại %s"
 
-#: builtin/merge.c:698
+#: builtin/notes.c:242 builtin/tag.c:532
 #, c-format
-msgid "unable to write %s"
-msgstr "không thể ghi %s"
+msgid "could not open or read '%s'"
+msgstr "không thể mở hay đọc “%s”"
 
-#: builtin/merge.c:749
+#: builtin/notes.c:263 builtin/notes.c:313 builtin/notes.c:315
+#: builtin/notes.c:383 builtin/notes.c:438 builtin/notes.c:526
+#: builtin/notes.c:531 builtin/notes.c:610 builtin/notes.c:672
 #, c-format
-msgid "Could not read from '%s'"
-msgstr "Không thể đọc từ “%s”"
+msgid "failed to resolve '%s' as a valid ref."
+msgstr "gặp lỗi khi phân giải “%s” như là một tham chiếu hợp lệ."
 
-#: builtin/merge.c:758
+#: builtin/notes.c:265
 #, c-format
-msgid "Not committing merge; use 'git commit' to complete the merge.\n"
-msgstr ""
-"Vẫn chưa hòa trộn các lần chuyển giao; sử dụng lệnh “git commit” để hoàn tất "
-"việc hòa trộn.\n"
+msgid "failed to read object '%s'."
+msgstr "gặp lỗi khi đọc đối tượng “%s”."
 
-#: builtin/merge.c:764
+#: builtin/notes.c:268
 #, c-format
-msgid ""
-"Please enter a commit message to explain why this merge is necessary,\n"
-"especially if it merges an updated upstream into a topic branch.\n"
-"\n"
-"Lines starting with '%c' will be ignored, and an empty message aborts\n"
-"the commit.\n"
-msgstr ""
-"Hãy nhập vào các thông tin để giải thích tại sao sự hòa trộn này là cần "
-"thiết,\n"
-"đặc biệt là khi nó hòa trộn thượng nguồn đã cập nhật vào trong một nhánh "
-"topic.\n"
-"\n"
-"Những dòng được bắt đầu bằng “%c” sẽ được bỏ qua, và phần chú thích này nếu "
-"rỗng\n"
-"sẽ hủy bỏ lần chuyển giao.\n"
-
-#: builtin/merge.c:800
-msgid "Empty commit message."
-msgstr "Chú thích của lần commit (chuyển giao) bị trống rỗng."
+msgid "cannot read note data from non-blob object '%s'."
+msgstr "không thể đọc dữ liệu ghi chú từ đối tượng không-blob “%s”."
 
-#: builtin/merge.c:819
+#: builtin/notes.c:309
 #, c-format
-msgid "Wonderful.\n"
-msgstr "Tuyệt vời.\n"
+msgid "malformed input line: '%s'."
+msgstr "dòng đầu vào dị hình: “%s”."
 
-#: builtin/merge.c:872
+#: builtin/notes.c:324
 #, c-format
-msgid "Automatic merge failed; fix conflicts and then commit the result.\n"
-msgstr ""
-"Việc tự động hòa trộn gặp lỗi; hãy sửa các xung đột sau đó chuyển giao kết "
-"quả.\n"
-
-#: builtin/merge.c:911
-msgid "No current branch."
-msgstr "không phải nhánh hiện hành"
-
-#: builtin/merge.c:913
-msgid "No remote for the current branch."
-msgstr "Không có máy chủ cho nhánh hiện hành."
-
-#: builtin/merge.c:915
-msgid "No default upstream defined for the current branch."
-msgstr "Không có thượng nguồn mặc định được định nghĩa cho nhánh hiện hành."
+msgid "failed to copy notes from '%s' to '%s'"
+msgstr "gặp lỗi khi sao chép ghi chú (note) từ “%s” sang “%s”"
 
-#: builtin/merge.c:920
+#. TRANSLATORS: the first %s will be replaced by a git
+#. notes command: 'add', 'merge', 'remove', etc.
+#.
+#: builtin/notes.c:356
 #, c-format
-msgid "No remote-tracking branch for %s from %s"
-msgstr "Không nhánh mạng theo dõi cho %s từ %s"
+msgid "refusing to %s notes in %s (outside of refs/notes/)"
+msgstr "từ chối %s ghi chú trong %s (nằm ngoài refs/notes/)"
 
-#: builtin/merge.c:973
-#, c-format
-msgid "Bad value '%s' in environment '%s'"
-msgstr "Giá trị sai “%s” trong biến môi trường “%s”"
+#: builtin/notes.c:376 builtin/notes.c:431 builtin/notes.c:509
+#: builtin/notes.c:521 builtin/notes.c:598 builtin/notes.c:665
+#: builtin/notes.c:815 builtin/notes.c:963 builtin/notes.c:985
+msgid "too many parameters"
+msgstr "quá nhiều đối số"
 
-#: builtin/merge.c:1075
+#: builtin/notes.c:389 builtin/notes.c:678
 #, c-format
-msgid "not something we can merge in %s: %s"
-msgstr "không phải là một thứ gì đó mà chúng tôi có thể hòa trộn trong %s: %s"
+msgid "no note found for object %s."
+msgstr "không tìm thấy ghi chú cho đối tượng %s."
 
-#: builtin/merge.c:1109
-msgid "not something we can merge"
-msgstr "không phải là thứ gì đó mà chúng tôi có thể hòa trộn"
+#: builtin/notes.c:410 builtin/notes.c:576
+msgid "note contents as a string"
+msgstr "nội dung ghi chú (note) nằm trong một chuỗi"
 
-#: builtin/merge.c:1211
-msgid "--abort expects no arguments"
-msgstr "--abort không nhận các đối số"
+#: builtin/notes.c:413 builtin/notes.c:579
+msgid "note contents in a file"
+msgstr "nội dung ghi chú (note) nằm trong một tập tin"
 
-#: builtin/merge.c:1215
-msgid "There is no merge to abort (MERGE_HEAD missing)."
-msgstr ""
-"Ở đây không có lần hòa trộn nào được hủy bỏ giữa chừng cả (thiếu MERGE_HEAD)."
+#: builtin/notes.c:416 builtin/notes.c:582
+msgid "reuse and edit specified note object"
+msgstr "dùng lại nhưng có sửa chữa đối tượng note đã chỉ ra"
 
-#: builtin/merge.c:1227
-msgid "--continue expects no arguments"
-msgstr "--continue không nhận đối số"
+#: builtin/notes.c:419 builtin/notes.c:585
+msgid "reuse specified note object"
+msgstr "dùng lại đối tượng ghi chú (note) đã chỉ ra"
 
-#: builtin/merge.c:1231
-msgid "There is no merge in progress (MERGE_HEAD missing)."
-msgstr "Ở đây không có lần hòa trộn nào đang được xử lý cả (thiếu MERGE_HEAD)."
+#: builtin/notes.c:422 builtin/notes.c:588
+msgid "allow storing empty note"
+msgstr "cho lưu trữ ghi chú trống rỗng"
 
-#: builtin/merge.c:1247
-msgid ""
-"You have not concluded your merge (MERGE_HEAD exists).\n"
-"Please, commit your changes before you merge."
-msgstr ""
-"Bạn chưa kết thúc việc hòa trộn (MERGE_HEAD vẫn tồn tại).\n"
-"Hãy chuyển giao các thay đổi trước khi bạn có thể hòa trộn."
+#: builtin/notes.c:423 builtin/notes.c:496
+msgid "replace existing notes"
+msgstr "thay thế ghi chú trước"
 
-#: builtin/merge.c:1254
+#: builtin/notes.c:448
+#, c-format
 msgid ""
-"You have not concluded your cherry-pick (CHERRY_PICK_HEAD exists).\n"
-"Please, commit your changes before you merge."
+"Cannot add notes. Found existing notes for object %s. Use '-f' to overwrite "
+"existing notes"
 msgstr ""
-"Bạn chưa kết thúc việc cherry-pick (CHERRY_PICK_HEAD vẫn tồn tại).\n"
-"Hãy chuyển giao các thay đổi trước khi bạn có thể hòa trộn."
-
-#: builtin/merge.c:1257
-msgid "You have not concluded your cherry-pick (CHERRY_PICK_HEAD exists)."
-msgstr "Bạn chưa kết thúc việc cherry-pick (CHERRY_PICK_HEAD vẫn tồn tại)."
-
-#: builtin/merge.c:1266
-msgid "You cannot combine --squash with --no-ff."
-msgstr "Bạn không thể kết hợp --squash với --no-ff."
+"Không thể thêm các ghi chú. Đã tìm thấy các ghi chú đã có sẵn cho đối tượng "
+"%s. Sử dụng tùy chọn “-f” để ghi đè lên các ghi chú cũ"
 
-#: builtin/merge.c:1274
-msgid "No commit specified and merge.defaultToUpstream not set."
-msgstr "Không chỉ ra lần chuyển giao và merge.defaultToUpstream chưa được đặt."
+#: builtin/notes.c:463 builtin/notes.c:544
+#, c-format
+msgid "Overwriting existing notes for object %s\n"
+msgstr "Đang ghi đè lên ghi chú cũ cho đối tượng %s\n"
 
-#: builtin/merge.c:1291
-msgid "Squash commit into empty head not supported yet"
-msgstr "Squash commit vào một head trống rỗng vẫn chưa được hỗ trợ"
+#: builtin/notes.c:475 builtin/notes.c:637 builtin/notes.c:902
+#, c-format
+msgid "Removing note for object %s\n"
+msgstr "Đang gỡ bỏ ghi chú (note) cho đối tượng %s\n"
 
-#: builtin/merge.c:1293
-msgid "Non-fast-forward commit does not make sense into an empty head"
-msgstr ""
-"Chuyển giao không-chuyển-tiếp-nhanh không hợp lý ở trong một head trống rỗng"
+#: builtin/notes.c:497
+msgid "read objects from stdin"
+msgstr "đọc các đối tượng từ đầu vào tiêu chuẩn"
 
-#: builtin/merge.c:1298
-#, c-format
-msgid "%s - not something we can merge"
-msgstr "%s - không phải là thứ gì đó mà chúng tôi có thể hòa trộn"
+#: builtin/notes.c:499
+msgid "load rewriting config for <command> (implies --stdin)"
+msgstr "tải cấu hình chép lại cho <lệnh> (ngầm định là --stdin)"
 
-#: builtin/merge.c:1300
-msgid "Can merge only exactly one commit into empty head"
-msgstr ""
-"Không thể hòa trộn một cách đúng đắn một lần chuyển giao vào một head rỗng"
+#: builtin/notes.c:517
+msgid "too few parameters"
+msgstr "quá ít đối số"
 
-#: builtin/merge.c:1334
+#: builtin/notes.c:538
 #, c-format
-msgid "Commit %s has an untrusted GPG signature, allegedly by %s."
+msgid ""
+"Cannot copy notes. Found existing notes for object %s. Use '-f' to overwrite "
+"existing notes"
 msgstr ""
-"Lần chuyển giao %s có một chữ ký GPG không đáng tin, được cho là bởi %s."
-
-#: builtin/merge.c:1337
-#, c-format
-msgid "Commit %s has a bad GPG signature allegedly by %s."
-msgstr "Lần chuyển giao %s có một chữ ký GPG sai, được cho là bởi %s."
+"Không thể sao chép các ghi chú. Đã tìm thấy các ghi chú đã có sẵn cho đối "
+"tượng %s. Sử dụng tùy chọn “-f” để ghi đè lên các ghi chú cũ"
 
-#: builtin/merge.c:1340
+#: builtin/notes.c:550
 #, c-format
-msgid "Commit %s does not have a GPG signature."
-msgstr "Lần chuyển giao %s không có chữ ký GPG."
+msgid "missing notes on source object %s. Cannot copy."
+msgstr "thiếu ghi chú trên đối tượng nguồn %s. Không thể sao chép."
 
-#: builtin/merge.c:1343
+#: builtin/notes.c:603
 #, c-format
-msgid "Commit %s has a good GPG signature by %s\n"
-msgstr "Lần chuyển giao %s có một chữ ký GPG tốt bởi %s\n"
-
-#: builtin/merge.c:1402
-msgid "refusing to merge unrelated histories"
-msgstr "từ chối hòa trộn lịch sử không liên quan"
+msgid ""
+"The -m/-F/-c/-C options have been deprecated for the 'edit' subcommand.\n"
+"Please use 'git notes add -f -m/-F/-c/-C' instead.\n"
+msgstr ""
+"Các tùy chọn -m/-F/-c/-C đã cổ không còn dùng nữa cho lệnh con “edit”.\n"
+"Xin hãy sử dụng lệnh sau để thay thế: “git notes add -f -m/-F/-c/-C”.\n"
 
-#: builtin/merge.c:1411
-msgid "Already up to date."
-msgstr "Đã cập nhật rồi."
+#: builtin/notes.c:698
+msgid "failed to delete ref NOTES_MERGE_PARTIAL"
+msgstr "gặp lỗi khi xóa tham chiếu NOTES_MERGE_PARTIAL"
 
-#: builtin/merge.c:1421
-#, c-format
-msgid "Updating %s..%s\n"
-msgstr "Đang cập nhật %s..%s\n"
+#: builtin/notes.c:700
+msgid "failed to delete ref NOTES_MERGE_REF"
+msgstr "gặp lỗi khi xóa tham chiếu NOTES_MERGE_REF"
 
-#: builtin/merge.c:1462
-#, c-format
-msgid "Trying really trivial in-index merge...\n"
-msgstr "Đang thử hòa trộn kiểu “trivial in-index”…\n"
+#: builtin/notes.c:702
+msgid "failed to remove 'git notes merge' worktree"
+msgstr "gặp lỗi khi gỡ bỏ cây làm việc “git notes merge”"
 
-#: builtin/merge.c:1469
-#, c-format
-msgid "Nope.\n"
-msgstr "Không.\n"
+#: builtin/notes.c:722
+msgid "failed to read ref NOTES_MERGE_PARTIAL"
+msgstr "gặp lỗi khi đọc tham chiếu NOTES_MERGE_PARTIAL"
 
-#: builtin/merge.c:1494
-msgid "Already up to date. Yeeah!"
-msgstr "Đã cập nhật rồi. Yeeah!"
+#: builtin/notes.c:724
+msgid "could not find commit from NOTES_MERGE_PARTIAL."
+msgstr "không thể tìm thấy lần chuyển giao từ NOTES_MERGE_PARTIAL."
 
-#: builtin/merge.c:1500
-msgid "Not possible to fast-forward, aborting."
-msgstr "Thực hiện lệnh chuyển-tiếp-nhanh là không thể được, đang bỏ qua."
+#: builtin/notes.c:726
+msgid "could not parse commit from NOTES_MERGE_PARTIAL."
+msgstr "không thể phân tích cú pháp lần chuyển giao từ NOTES_MERGE_PARTIAL."
 
-#: builtin/merge.c:1523 builtin/merge.c:1602
-#, c-format
-msgid "Rewinding the tree to pristine...\n"
-msgstr "Đang tua lại cây thành thời xa xưa…\n"
+#: builtin/notes.c:739
+msgid "failed to resolve NOTES_MERGE_REF"
+msgstr "gặp lỗi khi phân giải NOTES_MERGE_REF"
 
-#: builtin/merge.c:1527
-#, c-format
-msgid "Trying merge strategy %s...\n"
-msgstr "Đang thử chiến lược hòa trộn %s…\n"
+#: builtin/notes.c:742
+msgid "failed to finalize notes merge"
+msgstr "gặp lỗi khi hoàn thành hòa trộn ghi chú"
 
-#: builtin/merge.c:1593
+#: builtin/notes.c:768
 #, c-format
-msgid "No merge strategy handled the merge.\n"
-msgstr "Không có chiến lược hòa trộn nào được nắm giữ (handle) sự hòa trộn.\n"
+msgid "unknown notes merge strategy %s"
+msgstr "không hiểu chiến lược hòa trộn ghi chú %s"
 
-#: builtin/merge.c:1595
-#, c-format
-msgid "Merge with strategy %s failed.\n"
-msgstr "Hòa trộn với chiến lược %s gặp lỗi.\n"
+#: builtin/notes.c:784
+msgid "General options"
+msgstr "Tùy chọn chung"
 
-#: builtin/merge.c:1604
-#, c-format
-msgid "Using the %s to prepare resolving by hand.\n"
-msgstr "Sử dụng %s để chuẩn bị giải quyết bằng tay.\n"
+#: builtin/notes.c:786
+msgid "Merge options"
+msgstr "Tùy chọn về hòa trộn"
 
-#: builtin/merge.c:1616
-#, c-format
-msgid "Automatic merge went well; stopped before committing as requested\n"
+#: builtin/notes.c:788
+msgid ""
+"resolve notes conflicts using the given strategy (manual/ours/theirs/union/"
+"cat_sort_uniq)"
 msgstr ""
-"Hòa trộn tự động đã trở nên tốt; bị dừng trước khi việc chuyển giao được yêu "
-"cầu\n"
-
-#: builtin/merge-base.c:30
-msgid "git merge-base [-a | --all] <commit> <commit>..."
-msgstr "git merge-base [-a | --all] <lần_chuyển_giao> <lần_chuyển_giao>…"
+"phân giải các xung đột “notes” sử dụng chiến lược đã đưa ra (manual/ours/"
+"theirs/union/cat_sort_uniq)"
 
-#: builtin/merge-base.c:31
-msgid "git merge-base [-a | --all] --octopus <commit>..."
-msgstr "git merge-base [-a | --all] --octopus <lần_chuyển_giao>…"
+#: builtin/notes.c:790
+msgid "Committing unmerged notes"
+msgstr "Chuyển giao các note chưa được hòa trộn"
 
-#: builtin/merge-base.c:32
-msgid "git merge-base --independent <commit>..."
-msgstr "git merge-base --independent <lần_chuyển_giao>…"
+#: builtin/notes.c:792
+msgid "finalize notes merge by committing unmerged notes"
+msgstr ""
+"các note cuối cùng được hòa trộn bởi các note chưa hòa trộn của lần chuyển "
+"giao"
 
-#: builtin/merge-base.c:33
-msgid "git merge-base --is-ancestor <commit> <commit>"
-msgstr "git merge-base --is-ancestor <commit> <lần_chuyển_giao>"
+#: builtin/notes.c:794
+msgid "Aborting notes merge resolution"
+msgstr "Hủy bỏ phân giải ghi chú (note) hòa trộn"
 
-#: builtin/merge-base.c:34
-msgid "git merge-base --fork-point <ref> [<commit>]"
-msgstr "git merge-base --fork-point <tham-chiếu> [<lần_chuyển_giao>]"
+#: builtin/notes.c:796
+msgid "abort notes merge"
+msgstr "bỏ qua hòa trộn các ghi chú (note)"
 
-#: builtin/merge-base.c:220
-msgid "output all common ancestors"
-msgstr "xuất ra tất cả các ông bà, tổ tiên chung"
+#: builtin/notes.c:807
+msgid "cannot mix --commit, --abort or -s/--strategy"
+msgstr "không thể trộn lẫn --commit, --abort hay -s/--strategy"
 
-#: builtin/merge-base.c:222
-msgid "find ancestors for a single n-way merge"
-msgstr "tìm tổ tiên của hòa trộn n-way đơn"
+#: builtin/notes.c:812
+msgid "must specify a notes ref to merge"
+msgstr "bạn phải chỉ định tham chiếu ghi chú để hòa trộn"
 
-#: builtin/merge-base.c:224
-msgid "list revs not reachable from others"
-msgstr "liệt kê các “rev” mà nó không thể đọc được từ cái khác"
+#: builtin/notes.c:836
+#, c-format
+msgid "unknown -s/--strategy: %s"
+msgstr "không hiểu -s/--strategy: %s"
 
-#: builtin/merge-base.c:226
-msgid "is the first one ancestor of the other?"
-msgstr "là cha mẹ đầu tiên của cái khác?"
+#: builtin/notes.c:873
+#, c-format
+msgid "a notes merge into %s is already in-progress at %s"
+msgstr "một ghi chú hòa trộn vào %s đã sẵn trong quá trình xử lý tại %s"
 
-#: builtin/merge-base.c:228
-msgid "find where <commit> forked from reflog of <ref>"
-msgstr "tìm xem <commit> được rẽ nhánh ở đâu từ reflog của <th.chiếu>"
+#: builtin/notes.c:876
+#, c-format
+msgid "failed to store link to current notes ref (%s)"
+msgstr "gặp lỗi khi lưu liên kết đến tham chiếu ghi chú hiện tại (%s)"
 
-#: builtin/merge-file.c:9
+#: builtin/notes.c:878
+#, c-format
 msgid ""
-"git merge-file [<options>] [-L <name1> [-L <orig> [-L <name2>]]] <file1> "
-"<orig-file> <file2>"
+"Automatic notes merge failed. Fix conflicts in %s and commit the result with "
+"'git notes merge --commit', or abort the merge with 'git notes merge --"
+"abort'.\n"
 msgstr ""
-"git merge-file [<các-tùy-chọn>] [-L <tên1> [-L <gốc> [-L <tên2>]]] <tập-"
-"tin1> <tập-tin-gốc> <tập-tin2>"
+"Gặp lỗi khi hòa trộn các ghi chú tự động. Sửa các xung đột này trong %s và "
+"chuyển giao kết quả bằng “git notes merge --commit”, hoặc bãi bỏ việc hòa "
+"trộn bằng “git notes merge --abort”.\n"
 
-#: builtin/merge-file.c:33
-msgid "send results to standard output"
-msgstr "gửi kết quả vào đầu ra tiêu chuẩn"
+#: builtin/notes.c:897 builtin/tag.c:545
+#, c-format
+msgid "Failed to resolve '%s' as a valid ref."
+msgstr "Gặp lỗi khi phân giải “%s” như là một tham chiếu hợp lệ."
 
-#: builtin/merge-file.c:34
-msgid "use a diff3 based merge"
-msgstr "dùng kiểu hòa dựa trên diff3"
+#: builtin/notes.c:900
+#, c-format
+msgid "Object %s has no note\n"
+msgstr "Đối tượng %s không có ghi chú (note)\n"
 
-#: builtin/merge-file.c:35
-msgid "for conflicts, use our version"
-msgstr "để tránh xung đột, sử dụng phiên bản của chúng ta"
+#: builtin/notes.c:912
+msgid "attempt to remove non-existent note is not an error"
+msgstr "cố gắng gỡ bỏ một note chưa từng tồn tại không phải là một lỗi"
 
-#: builtin/merge-file.c:37
-msgid "for conflicts, use their version"
-msgstr "để tránh xung đột, sử dụng phiên bản của họ"
+#: builtin/notes.c:915
+msgid "read object names from the standard input"
+msgstr "đọc tên đối tượng từ thiết bị nhập chuẩn"
 
-#: builtin/merge-file.c:39
-msgid "for conflicts, use a union version"
-msgstr "để tránh xung đột, sử dụng phiên bản kết hợp"
+#: builtin/notes.c:954 builtin/prune.c:130 builtin/worktree.c:164
+msgid "do not remove, show only"
+msgstr "không gỡ bỏ, chỉ hiển thị"
 
-#: builtin/merge-file.c:42
-msgid "for conflicts, use this marker size"
-msgstr "để tránh xung đột, hãy sử dụng kích thước bộ tạo này"
+#: builtin/notes.c:955
+msgid "report pruned notes"
+msgstr "báo cáo các đối tượng đã prune"
 
-#: builtin/merge-file.c:43
-msgid "do not warn about conflicts"
-msgstr "không cảnh báo về các xung đột xảy ra"
+#: builtin/notes.c:998
+msgid "notes-ref"
+msgstr "notes-ref"
 
-#: builtin/merge-file.c:45
-msgid "set labels for file1/orig-file/file2"
-msgstr "đặt nhãn cho tập-tin-1/tập-tin-gốc/tập-tin-2"
+#: builtin/notes.c:999
+msgid "use notes from <notes-ref>"
+msgstr "dùng “notes” từ <notes-ref>"
 
-#: builtin/merge-recursive.c:45
+#: builtin/notes.c:1034 builtin/stash.c:1607
 #, c-format
-msgid "unknown option %s"
-msgstr "không hiểu tùy chọn %s"
+msgid "unknown subcommand: %s"
+msgstr "không hiểu câu lệnh con: %s"
+
+#: builtin/pack-objects.c:52
+msgid ""
+"git pack-objects --stdout [<options>...] [< <ref-list> | < <object-list>]"
+msgstr ""
+"git pack-objects --stdout [các tùy chọn…] [< <danh-sách-tham-chiếu> | < "
+"<danh-sách-đối-tượng>]"
+
+#: builtin/pack-objects.c:53
+msgid ""
+"git pack-objects [<options>...] <base-name> [< <ref-list> | < <object-list>]"
+msgstr ""
+"git pack-objects [các tùy chọn…] <base-name> [< <danh-sách-ref> | < <danh-"
+"sách-đối-tượng>]"
 
-#: builtin/merge-recursive.c:51
+#: builtin/pack-objects.c:428
 #, c-format
-msgid "could not parse object '%s'"
-msgstr "không thể phân tích đối tượng “%s”"
+msgid "bad packed object CRC for %s"
+msgstr "CRC của đối tượng gói sai với %s"
 
-#: builtin/merge-recursive.c:55
+#: builtin/pack-objects.c:439
 #, c-format
-msgid "cannot handle more than %d base. Ignoring %s."
-msgid_plural "cannot handle more than %d bases. Ignoring %s."
-msgstr[0] "không thể xử lý nhiều hơn %d nền. Bỏ qua %s"
+msgid "corrupt packed object for %s"
+msgstr "đối tượng đã đóng gói sai hỏng cho %s"
 
-#: builtin/merge-recursive.c:63
-msgid "not handling anything other than two heads merge."
-msgstr "không cầm nắm gì ngoài hai head hòa trộn"
+#: builtin/pack-objects.c:570
+#, c-format
+msgid "recursive delta detected for object %s"
+msgstr "dò thấy delta đệ quy cho đối tượng %s"
 
-#: builtin/merge-recursive.c:69 builtin/merge-recursive.c:71
+#: builtin/pack-objects.c:781
 #, c-format
-msgid "could not resolve ref '%s'"
-msgstr "không thể phân giải tham chiếu %s"
+msgid "ordered %u objects, expected %<PRIu32>"
+msgstr "đã sắp xếp %u đối tượng, cần %<PRIu32>"
 
-#: builtin/merge-recursive.c:77
+#: builtin/pack-objects.c:794
 #, c-format
-msgid "Merging %s with %s\n"
-msgstr "Đang hòa trộn %s với %s\n"
+msgid "packfile is invalid: %s"
+msgstr "tập tin gói không hợp lệ: %s"
 
-#: builtin/mktree.c:65
-msgid "git mktree [-z] [--missing] [--batch]"
-msgstr "git mktree [-z] [--missing] [--batch]"
+#: builtin/pack-objects.c:798
+#, c-format
+msgid "unable to open packfile for reuse: %s"
+msgstr "không thể mở tập tin gói để dùng lại: %s"
 
-#: builtin/mktree.c:153
-msgid "input is NUL terminated"
-msgstr "đầu vào được chấm dứt bởi NUL"
+#: builtin/pack-objects.c:802
+msgid "unable to seek in reused packfile"
+msgstr "không thể di chuyển vị trí đọc trong tập tin gói dùng lại"
 
-#: builtin/mktree.c:154 builtin/write-tree.c:25
-msgid "allow missing objects"
-msgstr "cho phép thiếu đối tượng"
+#: builtin/pack-objects.c:813
+msgid "unable to read from reused packfile"
+msgstr "không thể đọc từ tập tin gói dùng lại"
 
-#: builtin/mktree.c:155
-msgid "allow creation of more than one tree"
-msgstr "cho phép tạo nhiều hơn một cây"
+#: builtin/pack-objects.c:841
+msgid "disabling bitmap writing, packs are split due to pack.packSizeLimit"
+msgstr "tắt ghi bitmap, các gói bị chia nhỏ bởi vì pack.packSizeLimit"
 
-#: builtin/mv.c:17
-msgid "git mv [<options>] <source>... <destination>"
-msgstr "git mv [<các-tùy-chọn>] <nguồn>… <đích>"
+#: builtin/pack-objects.c:854
+msgid "Writing objects"
+msgstr "Đang ghi lại các đối tượng"
 
-#: builtin/mv.c:82
+#: builtin/pack-objects.c:917 builtin/update-index.c:90
 #, c-format
-msgid "Directory %s is in index and no submodule?"
-msgstr "Thư mục “%s” có ở trong chỉ mục mà không có mô-đun con?"
-
-#: builtin/mv.c:84 builtin/rm.c:288
-msgid "Please stage your changes to .gitmodules or stash them to proceed"
-msgstr ""
-"Hãy đưa các thay đổi của bạn vào .gitmodules hay tạm cất chúng đi để xử lý"
+msgid "failed to stat %s"
+msgstr "gặp lỗi khi lấy thông tin thống kê về %s"
 
-#: builtin/mv.c:102
+#: builtin/pack-objects.c:970
 #, c-format
-msgid "%.*s is in index"
-msgstr "%.*s trong bảng mục lục"
-
-#: builtin/mv.c:124
-msgid "force move/rename even if target exists"
-msgstr "ép buộc di chuyển hay đổi tên thậm chí cả khi đích đã tồn tại"
+msgid "wrote %<PRIu32> objects while expecting %<PRIu32>"
+msgstr "đã ghi %<PRIu32> đối tượng trong khi cần %<PRIu32>"
 
-#: builtin/mv.c:126
-msgid "skip move/rename errors"
-msgstr "bỏ qua các lỗi liên quan đến di chuyển, đổi tên"
+#: builtin/pack-objects.c:1164
+msgid "disabling bitmap writing, as some objects are not being packed"
+msgstr "tắt ghi bitmap, như vậy một số đối tượng sẽ không được đóng gói"
 
-#: builtin/mv.c:168
+#: builtin/pack-objects.c:1592
 #, c-format
-msgid "destination '%s' is not a directory"
-msgstr "có đích “%s” nhưng đây không phải là một thư mục"
+msgid "delta base offset overflow in pack for %s"
+msgstr "khoảng bù cơ sở cho delta bị tràn trong gói cho %s"
 
-#: builtin/mv.c:179
+#: builtin/pack-objects.c:1601
 #, c-format
-msgid "Checking rename of '%s' to '%s'\n"
-msgstr "Đang kiểm tra việc đổi tên của “%s” thành “%s”\n"
+msgid "delta base offset out of bound for %s"
+msgstr "khoảng bù cơ sở cho delta nằm ngoài phạm cho %s"
 
-#: builtin/mv.c:183
-msgid "bad source"
-msgstr "nguồn sai"
+#: builtin/pack-objects.c:1870
+msgid "Counting objects"
+msgstr "Đang đếm các đối tượng"
 
-#: builtin/mv.c:186
-msgid "can not move directory into itself"
-msgstr "không thể di chuyển một thư mục vào trong chính nó được"
+#: builtin/pack-objects.c:2000
+#, c-format
+msgid "unable to get size of %s"
+msgstr "không thể lấy kích cỡ của %s"
 
-#: builtin/mv.c:189
-msgid "cannot move directory over file"
-msgstr "không di chuyển được thư mục thông qua tập tin"
+#: builtin/pack-objects.c:2015
+#, c-format
+msgid "unable to parse object header of %s"
+msgstr "không thể phân tích phần đầu đối tượng của “%s”"
 
-#: builtin/mv.c:198
-msgid "source directory is empty"
-msgstr "thư mục nguồn là trống rỗng"
+#: builtin/pack-objects.c:2085 builtin/pack-objects.c:2101
+#: builtin/pack-objects.c:2111
+#, c-format
+msgid "object %s cannot be read"
+msgstr "không thể đọc đối tượng %s"
 
-#: builtin/mv.c:223
-msgid "not under version control"
-msgstr "không nằm dưới sự quản lý mã nguồn"
+#: builtin/pack-objects.c:2088 builtin/pack-objects.c:2115
+#, c-format
+msgid "object %s inconsistent object length (%<PRIuMAX> vs %<PRIuMAX>)"
+msgstr ""
+"đối tượng %s không nhất quán về chiều dài đối tượng (%<PRIuMAX> so với "
+"%<PRIuMAX>)"
 
-#: builtin/mv.c:226
-msgid "destination exists"
-msgstr "đích đã tồn tại sẵn rồi"
+#: builtin/pack-objects.c:2125
+msgid "suboptimal pack - out of memory"
+msgstr "suboptimal pack - hết bộ nhớ"
 
-#: builtin/mv.c:234
+#: builtin/pack-objects.c:2440
 #, c-format
-msgid "overwriting '%s'"
-msgstr "đang ghi đè lên “%s”"
+msgid "Delta compression using up to %d threads"
+msgstr "Nén delta dùng tới %d tuyến trình"
 
-#: builtin/mv.c:237
-msgid "Cannot overwrite"
-msgstr "Không thể ghi đè"
-
-#: builtin/mv.c:240
-msgid "multiple sources for the same target"
-msgstr "Nhiều nguồn cho cùng một đích"
+#: builtin/pack-objects.c:2572
+#, c-format
+msgid "unable to pack objects reachable from tag %s"
+msgstr "không thể đóng gói các đối tượng tiếp cận được từ thẻ “%s”"
 
-#: builtin/mv.c:242
-msgid "destination directory does not exist"
-msgstr "thư mục đích không tồn tại"
+#: builtin/pack-objects.c:2659
+msgid "Compressing objects"
+msgstr "Đang nén các đối tượng"
 
-#: builtin/mv.c:249
-#, c-format
-msgid "%s, source=%s, destination=%s"
-msgstr "%s, nguồn=%s, đích=%s"
+#: builtin/pack-objects.c:2665
+msgid "inconsistency with delta count"
+msgstr "mâu thuẫn với số lượng delta"
 
-#: builtin/mv.c:270
+#: builtin/pack-objects.c:2742
 #, c-format
-msgid "Renaming %s to %s\n"
-msgstr "Đổi tên %s thành %s\n"
+msgid ""
+"expected edge object ID, got garbage:\n"
+" %s"
+msgstr ""
+"cần ID đối tượng cạnh, nhận được rác:\n"
+" %s"
 
-#: builtin/mv.c:276 builtin/remote.c:715 builtin/repack.c:409
+#: builtin/pack-objects.c:2748
 #, c-format
-msgid "renaming '%s' failed"
-msgstr "gặp lỗi khi đổi tên “%s”"
-
-#: builtin/name-rev.c:338
-msgid "git name-rev [<options>] <commit>..."
-msgstr "git name-rev [<các-tùy-chọn>] <commit>…"
-
-#: builtin/name-rev.c:339
-msgid "git name-rev [<options>] --all"
-msgstr "git name-rev [<các-tùy-chọn>] --all"
+msgid ""
+"expected object ID, got garbage:\n"
+" %s"
+msgstr ""
+"cần ID đối tượng, nhận được rác:\n"
+" %s"
 
-#: builtin/name-rev.c:340
-msgid "git name-rev [<options>] --stdin"
-msgstr "git name-rev [<các-tùy-chọn>] --stdin"
+#: builtin/pack-objects.c:2846
+msgid "invalid value for --missing"
+msgstr "giá trị cho --missing không hợp lệ"
 
-#: builtin/name-rev.c:395
-msgid "print only names (no SHA-1)"
-msgstr "chỉ hiển thị tên (không SHA-1)"
+#: builtin/pack-objects.c:2905 builtin/pack-objects.c:3013
+msgid "cannot open pack index"
+msgstr "không thể mở mục lục của gói"
 
-#: builtin/name-rev.c:396
-msgid "only use tags to name the commits"
-msgstr "chỉ dùng các thẻ để đặt tên cho các lần chuyển giao"
+#: builtin/pack-objects.c:2936
+#, c-format
+msgid "loose object at %s could not be examined"
+msgstr "đối tượng mất tại %s không thể đã kiểm tra"
 
-#: builtin/name-rev.c:398
-msgid "only use refs matching <pattern>"
-msgstr "chỉ sử dụng các tham chiếu khớp với <mẫu>"
+#: builtin/pack-objects.c:3021
+msgid "unable to force loose object"
+msgstr "không thể buộc mất đối tượng"
 
-#: builtin/name-rev.c:400
-msgid "ignore refs matching <pattern>"
-msgstr "bỏ qua các tham chiếu khớp với <mẫu>"
+#: builtin/pack-objects.c:3113
+#, c-format
+msgid "not a rev '%s'"
+msgstr "không phải một rev “%s”"
 
-#: builtin/name-rev.c:402
-msgid "list all commits reachable from all refs"
-msgstr ""
-"liệt kê tất cả các lần chuyển giao có thể đọc được từ tất cả các tham chiếu"
+#: builtin/pack-objects.c:3116
+#, c-format
+msgid "bad revision '%s'"
+msgstr "điểm xem xét sai “%s”"
 
-#: builtin/name-rev.c:403
-msgid "read from stdin"
-msgstr "đọc từ đầu vào tiêu chuẩn"
+#: builtin/pack-objects.c:3141
+msgid "unable to add recent objects"
+msgstr "không thể thêm các đối tượng mới dùng"
 
-#: builtin/name-rev.c:404
-msgid "allow to print `undefined` names (default)"
-msgstr "cho phép in các tên “chưa định nghĩa” (mặc định)"
+#: builtin/pack-objects.c:3194
+#, c-format
+msgid "unsupported index version %s"
+msgstr "phiên bản mục lục không được hỗ trợ %s"
 
-#: builtin/name-rev.c:410
-msgid "dereference tags in the input (internal use)"
-msgstr "bãi bỏ tham chiếu các thẻ trong đầu vào (dùng nội bộ)"
+#: builtin/pack-objects.c:3198
+#, c-format
+msgid "bad index version '%s'"
+msgstr "phiên bản mục lục sai “%s”"
 
-#: builtin/notes.c:26
-msgid "git notes [--ref <notes-ref>] [list [<object>]]"
-msgstr "git notes [--ref <notes-ref>] [list [<đối-tượng>]]"
+#: builtin/pack-objects.c:3236
+msgid "<version>[,<offset>]"
+msgstr "<phiên bản>[,offset]"
 
-#: builtin/notes.c:27
-msgid ""
-"git notes [--ref <notes-ref>] add [-f] [--allow-empty] [-m <msg> | -F <file> "
-"| (-c | -C) <object>] [<object>]"
-msgstr ""
-"git notes [--ref <notes-ref>] add [-f] [--allow-empty] [-m <lời-nhắn> | -F "
-"<tập-tin> | (-c | -C) <đối-tượng>] [<đối-tượng>]"
+#: builtin/pack-objects.c:3237
+msgid "write the pack index file in the specified idx format version"
+msgstr "ghi tập tin bảng mục lục gói (pack) ở phiên bản định dạng idx đã cho"
 
-#: builtin/notes.c:28
-msgid "git notes [--ref <notes-ref>] copy [-f] <from-object> <to-object>"
-msgstr "git notes [--ref <notes-ref>] copy [-f] <từ-đối-tượng> <đến-đối-tượng>"
+#: builtin/pack-objects.c:3240
+msgid "maximum size of each output pack file"
+msgstr "kcíh thước tối đa cho tập tin gói được tạo"
 
-#: builtin/notes.c:29
-msgid ""
-"git notes [--ref <notes-ref>] append [--allow-empty] [-m <msg> | -F <file> | "
-"(-c | -C) <object>] [<object>]"
-msgstr ""
-"git notes [--ref <notes-ref>] append [--allow-empty] [-m <lời-nhắn> | -F "
-"<tập-tin> | (-c | -C) <đối-tượng>] [<đối-tượng>]"
+#: builtin/pack-objects.c:3242
+msgid "ignore borrowed objects from alternate object store"
+msgstr "bỏ qua các đối tượng vay mượn từ kho đối tượng thay thế"
 
-#: builtin/notes.c:30
-msgid "git notes [--ref <notes-ref>] edit [--allow-empty] [<object>]"
-msgstr "git notes [--ref <notes-ref>] edit [--allow-empty] [<đối-tượng>]"
+#: builtin/pack-objects.c:3244
+msgid "ignore packed objects"
+msgstr "bỏ qua các đối tượng đóng gói"
 
-#: builtin/notes.c:31
-msgid "git notes [--ref <notes-ref>] show [<object>]"
-msgstr "git notes [--ref <notes-ref>] show [<đối-tượng>]"
+#: builtin/pack-objects.c:3246
+msgid "limit pack window by objects"
+msgstr "giới hạn cửa sổ đóng gói theo đối tượng"
 
-#: builtin/notes.c:32
-msgid ""
-"git notes [--ref <notes-ref>] merge [-v | -q] [-s <strategy>] <notes-ref>"
-msgstr ""
-"git notes [--ref <notes-ref>] merge [-v | -q] [-s <chiến-lược> ] <notes-ref>"
+#: builtin/pack-objects.c:3248
+msgid "limit pack window by memory in addition to object limit"
+msgstr "giới hạn cửa sổ đóng gói theo bộ nhớ cộng thêm với giới hạn đối tượng"
 
-#: builtin/notes.c:33
-msgid "git notes merge --commit [-v | -q]"
-msgstr "git notes merge --commit [-v | -q]"
+#: builtin/pack-objects.c:3250
+msgid "maximum length of delta chain allowed in the resulting pack"
+msgstr "độ dài tối đa của chuỗi móc xích “delta” được phép trong gói kết quả"
 
-#: builtin/notes.c:34
-msgid "git notes merge --abort [-v | -q]"
-msgstr "git notes merge --abort [-v | -q]"
+#: builtin/pack-objects.c:3252
+msgid "reuse existing deltas"
+msgstr "dùng lại các delta sẵn có"
 
-#: builtin/notes.c:35
-msgid "git notes [--ref <notes-ref>] remove [<object>...]"
-msgstr "git notes [--ref <notes-ref>] remove [<đối-tượng>…]"
+#: builtin/pack-objects.c:3254
+msgid "reuse existing objects"
+msgstr "dùng lại các đối tượng sẵn có"
 
-#: builtin/notes.c:36
-msgid "git notes [--ref <notes-ref>] prune [-n] [-v]"
-msgstr "git notes [--ref <notes-ref>] prune [-n] [-v]"
+#: builtin/pack-objects.c:3256
+msgid "use OFS_DELTA objects"
+msgstr "dùng các đối tượng OFS_DELTA"
 
-#: builtin/notes.c:37
-msgid "git notes [--ref <notes-ref>] get-ref"
-msgstr "git notes [--ref <notes-ref>] get-ref"
+#: builtin/pack-objects.c:3258
+msgid "use threads when searching for best delta matches"
+msgstr "sử dụng các tuyến trình khi tìm kiếm cho các mẫu khớp delta tốt nhất"
 
-#: builtin/notes.c:42
-msgid "git notes [list [<object>]]"
-msgstr "git notes [list [<đối tượng>]]"
+#: builtin/pack-objects.c:3260
+msgid "do not create an empty pack output"
+msgstr "không thể tạo kết xuất gói trống rỗng"
 
-#: builtin/notes.c:47
-msgid "git notes add [<options>] [<object>]"
-msgstr "git notes add [<các-tùy-chọn>] [<đối-tượng>]"
+#: builtin/pack-objects.c:3262
+msgid "read revision arguments from standard input"
+msgstr "đọc tham số “revision” từ thiết bị nhập chuẩn"
 
-#: builtin/notes.c:52
-msgid "git notes copy [<options>] <from-object> <to-object>"
-msgstr "git notes copy [<các-tùy-chọn>] <từ-đối-tượng> <đến-đối-tượng>"
+#: builtin/pack-objects.c:3264
+msgid "limit the objects to those that are not yet packed"
+msgstr "giới hạn các đối tượng thành những cái mà chúng vẫn chưa được đóng gói"
 
-#: builtin/notes.c:53
-msgid "git notes copy --stdin [<from-object> <to-object>]..."
-msgstr "git notes copy --stdin [<từ-đối-tượng> <đến-đối-tượng>]…"
+#: builtin/pack-objects.c:3267
+msgid "include objects reachable from any reference"
+msgstr "bao gồm các đối tượng có thể đọc được từ bất kỳ tham chiếu nào"
 
-#: builtin/notes.c:58
-msgid "git notes append [<options>] [<object>]"
-msgstr "git notes append [<các-tùy-chọn>] [<đối-tượng>]"
+#: builtin/pack-objects.c:3270
+msgid "include objects referred by reflog entries"
+msgstr "bao gồm các đối tượng được tham chiếu bởi các mục reflog"
 
-#: builtin/notes.c:63
-msgid "git notes edit [<object>]"
-msgstr "git notes edit [<đối tượng>]"
+#: builtin/pack-objects.c:3273
+msgid "include objects referred to by the index"
+msgstr "bao gồm các đối tượng được tham chiếu bởi mục lục"
 
-#: builtin/notes.c:68
-msgid "git notes show [<object>]"
-msgstr "git notes show [<đối tượng>]"
+#: builtin/pack-objects.c:3276
+msgid "output pack to stdout"
+msgstr "xuất gói ra đầu ra tiêu chuẩn"
 
-#: builtin/notes.c:73
-msgid "git notes merge [<options>] <notes-ref>"
-msgstr "git notes merge [<các-tùy-chọn>] <notes-ref>"
+#: builtin/pack-objects.c:3278
+msgid "include tag objects that refer to objects to be packed"
+msgstr "bao gồm các đối tượng tham chiếu đến các đối tượng được đóng gói"
 
-#: builtin/notes.c:74
-msgid "git notes merge --commit [<options>]"
-msgstr "git notes merge --commit [<các-tùy-chọn>]"
+#: builtin/pack-objects.c:3280
+msgid "keep unreachable objects"
+msgstr "giữ lại các đối tượng không thể đọc được"
 
-#: builtin/notes.c:75
-msgid "git notes merge --abort [<options>]"
-msgstr "git notes merge --abort [<các-tùy-chọn>]"
+#: builtin/pack-objects.c:3282
+msgid "pack loose unreachable objects"
+msgstr "pack mất các đối tượng không thể đọc được"
 
-#: builtin/notes.c:80
-msgid "git notes remove [<object>]"
-msgstr "git notes remove [<đối tượng>]"
+#: builtin/pack-objects.c:3284
+msgid "unpack unreachable objects newer than <time>"
+msgstr ""
+"xả nén (gỡ khỏi gói) các đối tượng không thể đọc được mới hơn <thời-gian>"
 
-#: builtin/notes.c:85
-msgid "git notes prune [<options>]"
-msgstr "git notes prune [<các-tùy-chọn>]"
+#: builtin/pack-objects.c:3287
+msgid "use the sparse reachability algorithm"
+msgstr "sử dụng thuật toán “sparse reachability”"
 
-#: builtin/notes.c:90
-msgid "git notes get-ref"
-msgstr "git notes get-ref"
+#: builtin/pack-objects.c:3289
+msgid "create thin packs"
+msgstr "tạo gói nhẹ"
 
-#: builtin/notes.c:95
-msgid "Write/edit the notes for the following object:"
-msgstr "Ghi hay sửa ghi chú cho đối tượng sau đây:"
+#: builtin/pack-objects.c:3291
+msgid "create packs suitable for shallow fetches"
+msgstr "tạo gói để phù hợp cho lấy về nông (shallow)"
 
-#: builtin/notes.c:148
-#, c-format
-msgid "unable to start 'show' for object '%s'"
-msgstr "không thể khởi chạy “show” cho đối tượng “%s”"
+#: builtin/pack-objects.c:3293
+msgid "ignore packs that have companion .keep file"
+msgstr "bỏ qua các gói mà nó có tập tin .keep đi kèm"
 
-#: builtin/notes.c:152
-msgid "could not read 'show' output"
-msgstr "không thể đọc kết xuất “show”"
+#: builtin/pack-objects.c:3295
+msgid "ignore this pack"
+msgstr "bỏ qua gói này"
 
-#: builtin/notes.c:160
-#, c-format
-msgid "failed to finish 'show' for object '%s'"
-msgstr "gặp lỗi khi hoàn thành “show” cho đối tượng “%s”"
+#: builtin/pack-objects.c:3297
+msgid "pack compression level"
+msgstr "mức nén gói"
 
-#: builtin/notes.c:195
-msgid "please supply the note contents using either -m or -F option"
-msgstr ""
-"xin hãy áp dụng nội dung của ghi chú sử dụng hoặc là tùy chọn -m hoặc là -F"
+#: builtin/pack-objects.c:3299
+msgid "do not hide commits by grafts"
+msgstr "không ẩn các lần chuyển giao bởi “grafts”"
 
-#: builtin/notes.c:204
-msgid "unable to write note object"
-msgstr "không thể ghi đối tượng ghi chú (note)"
+#: builtin/pack-objects.c:3301
+msgid "use a bitmap index if available to speed up counting objects"
+msgstr "dùng mục lục ánh xạ nếu có thể được để nâng cao tốc độ đếm đối tượng"
 
-#: builtin/notes.c:206
-#, c-format
-msgid "the note contents have been left in %s"
-msgstr "nội dung ghi chú còn lại %s"
+#: builtin/pack-objects.c:3303
+msgid "write a bitmap index together with the pack index"
+msgstr "ghi một mục lục ánh xạ cùng với mục lục gói"
 
-#: builtin/notes.c:234 builtin/tag.c:507
-#, c-format
-msgid "cannot read '%s'"
-msgstr "không thể đọc “%s”"
+#: builtin/pack-objects.c:3307
+msgid "write a bitmap index if possible"
+msgstr "ghi mục lục ánh xạ nếu được"
 
-#: builtin/notes.c:236 builtin/tag.c:510
-#, c-format
-msgid "could not open or read '%s'"
-msgstr "không thể mở hay đọc “%s”"
+#: builtin/pack-objects.c:3311
+msgid "handling for missing objects"
+msgstr "xử lý cho thiếu đối tượng"
 
-#: builtin/notes.c:255 builtin/notes.c:306 builtin/notes.c:308
-#: builtin/notes.c:376 builtin/notes.c:431 builtin/notes.c:517
-#: builtin/notes.c:522 builtin/notes.c:600 builtin/notes.c:662
-#, c-format
-msgid "failed to resolve '%s' as a valid ref."
-msgstr "gặp lỗi khi phân giải “%s” như là một tham chiếu hợp lệ."
+#: builtin/pack-objects.c:3314
+msgid "do not pack objects in promisor packfiles"
+msgstr "không thể đóng gói các đối tượng trong các tập tin gói hứa hẹn"
 
-#: builtin/notes.c:258
-#, c-format
-msgid "failed to read object '%s'."
-msgstr "gặp lỗi khi đọc đối tượng “%s”."
+#: builtin/pack-objects.c:3316
+msgid "respect islands during delta compression"
+msgstr "tôn trọng island trong suốt quá trình nén “delta”"
 
-#: builtin/notes.c:262
+#: builtin/pack-objects.c:3345
 #, c-format
-msgid "cannot read note data from non-blob object '%s'."
-msgstr "không thể đọc dữ liệu ghi chú từ đối tượng không-blob “%s”."
+msgid "delta chain depth %d is too deep, forcing %d"
+msgstr "mức sau xích delta %d là quá sâu, buộc dùng %d"
 
-#: builtin/notes.c:302
+#: builtin/pack-objects.c:3350
 #, c-format
-msgid "malformed input line: '%s'."
-msgstr "dòng đầu vào dị hình: “%s”."
+msgid "pack.deltaCacheLimit is too high, forcing %d"
+msgstr "pack.deltaCacheLimit là quá cao, ép dùng %d"
 
-#: builtin/notes.c:317
-#, c-format
-msgid "failed to copy notes from '%s' to '%s'"
-msgstr "gặp lỗi khi sao chép ghi chú (note) từ “%s” sang “%s”"
+#: builtin/pack-objects.c:3404
+msgid "--max-pack-size cannot be used to build a pack for transfer"
+msgstr ""
+"--max-pack-size không thể được sử dụng để xây dựng một gói để vận chuyển"
 
-#. TRANSLATORS: the first %s will be replaced by a git
-#. notes command: 'add', 'merge', 'remove', etc.
-#.
-#: builtin/notes.c:349
-#, c-format
-msgid "refusing to %s notes in %s (outside of refs/notes/)"
-msgstr "từ chối %s ghi chú trong %s (nằm ngoài refs/notes/)"
+#: builtin/pack-objects.c:3406
+msgid "minimum pack size limit is 1 MiB"
+msgstr "giới hạn kích thước tối thiểu của gói là 1 MiB"
 
-#: builtin/notes.c:369 builtin/notes.c:424 builtin/notes.c:500
-#: builtin/notes.c:512 builtin/notes.c:588 builtin/notes.c:655
-#: builtin/notes.c:805 builtin/notes.c:952 builtin/notes.c:973
-msgid "too many parameters"
-msgstr "quá nhiều đối số"
+#: builtin/pack-objects.c:3411
+msgid "--thin cannot be used to build an indexable pack"
+msgstr "--thin không thể được dùng để xây dựng gói đánh mục lục được"
 
-#: builtin/notes.c:382 builtin/notes.c:668
-#, c-format
-msgid "no note found for object %s."
-msgstr "không tìm thấy ghi chú cho đối tượng %s."
+#: builtin/pack-objects.c:3414
+msgid "--keep-unreachable and --unpack-unreachable are incompatible"
+msgstr "--keep-unreachable và --unpack-unreachable xung khắc nhau"
 
-#: builtin/notes.c:403 builtin/notes.c:566
-msgid "note contents as a string"
-msgstr "nội dung ghi chú (note) nằm trong một chuỗi"
+#: builtin/pack-objects.c:3420
+msgid "cannot use --filter without --stdout"
+msgstr "không thể dùng tùy chọn --filter mà không có --stdout"
 
-#: builtin/notes.c:406 builtin/notes.c:569
-msgid "note contents in a file"
-msgstr "nội dung ghi chú (note) nằm trong một tập tin"
+#: builtin/pack-objects.c:3481
+msgid "Enumerating objects"
+msgstr "Đánh số các đối tượng"
 
-#: builtin/notes.c:409 builtin/notes.c:572
-msgid "reuse and edit specified note object"
-msgstr "dùng lại nhưng có sửa chữa đối tượng note đã chỉ ra"
+#: builtin/pack-objects.c:3511
+#, c-format
+msgid "Total %<PRIu32> (delta %<PRIu32>), reused %<PRIu32> (delta %<PRIu32>)"
+msgstr "Tổng %<PRIu32> (delta %<PRIu32>), dùng lại %<PRIu32> (delta %<PRIu32>)"
 
-#: builtin/notes.c:412 builtin/notes.c:575
-msgid "reuse specified note object"
-msgstr "dùng lại đối tượng ghi chú (note) đã chỉ ra"
+#: builtin/pack-refs.c:8
+msgid "git pack-refs [<options>]"
+msgstr "git pack-refs [<các tùy chọn>]"
 
-#: builtin/notes.c:415 builtin/notes.c:578
-msgid "allow storing empty note"
-msgstr "cho lưu trữ ghi chú trống rỗng"
+#: builtin/pack-refs.c:16
+msgid "pack everything"
+msgstr "đóng gói mọi thứ"
 
-#: builtin/notes.c:416 builtin/notes.c:487
-msgid "replace existing notes"
-msgstr "thay thế ghi chú trước"
+#: builtin/pack-refs.c:17
+msgid "prune loose refs (default)"
+msgstr "prune (cắt cụt) những tham chiếu bị mất (mặc định)"
 
-#: builtin/notes.c:441
-#, c-format
-msgid ""
-"Cannot add notes. Found existing notes for object %s. Use '-f' to overwrite "
-"existing notes"
-msgstr ""
-"Không thể thêm các ghi chú. Đã tìm thấy các ghi chú đã có sẵn cho đối tượng "
-"%s. Sử dụng tùy chọn “-f” để ghi đè lên các ghi chú cũ"
+#: builtin/prune-packed.c:9
+msgid "git prune-packed [-n | --dry-run] [-q | --quiet]"
+msgstr "git prune-packed [-n | --dry-run] [-q | --quiet]"
 
-#: builtin/notes.c:456 builtin/notes.c:535
-#, c-format
-msgid "Overwriting existing notes for object %s\n"
-msgstr "Đang ghi đè lên ghi chú cũ cho đối tượng %s\n"
+#: builtin/prune-packed.c:42
+msgid "Removing duplicate objects"
+msgstr "Đang gỡ các đối tượng trùng lặp"
 
-#: builtin/notes.c:467 builtin/notes.c:627 builtin/notes.c:892
-#, c-format
-msgid "Removing note for object %s\n"
-msgstr "Đang gỡ bỏ ghi chú (note) cho đối tượng %s\n"
+#: builtin/prune.c:12
+msgid "git prune [-n] [-v] [--progress] [--expire <time>] [--] [<head>...]"
+msgstr "git prune [-n] [-v] [--progress] [--expire <thời-gian>] [--] [<head>…]"
 
-#: builtin/notes.c:488
-msgid "read objects from stdin"
-msgstr "đọc các đối tượng từ đầu vào tiêu chuẩn"
+#: builtin/prune.c:131
+msgid "report pruned objects"
+msgstr "báo cáo các đối tượng đã prune"
 
-#: builtin/notes.c:490
-msgid "load rewriting config for <command> (implies --stdin)"
-msgstr "tải cấu hình chép lại cho <lệnh> (ngầm định là --stdin)"
+#: builtin/prune.c:134
+msgid "expire objects older than <time>"
+msgstr "các đối tượng hết hạn cũ hơn khoảng <thời gian>"
 
-#: builtin/notes.c:508
-msgid "too few parameters"
-msgstr "quá ít đối số"
+#: builtin/prune.c:136
+msgid "limit traversal to objects outside promisor packfiles"
+msgstr "giới hạn giao đến các đối tượng nằm ngoài các tập tin gói hứa hẹn"
 
-#: builtin/notes.c:529
-#, c-format
-msgid ""
-"Cannot copy notes. Found existing notes for object %s. Use '-f' to overwrite "
-"existing notes"
-msgstr ""
-"Không thể sao chép các ghi chú. Đã tìm thấy các ghi chú đã có sẵn cho đối "
-"tượng %s. Sử dụng tùy chọn “-f” để ghi đè lên các ghi chú cũ"
+#: builtin/prune.c:150
+msgid "cannot prune in a precious-objects repo"
+msgstr "không thể tỉa bớt trong một kho đối_tượng_vĩ_đại"
 
-#: builtin/notes.c:541
+#: builtin/pull.c:66 builtin/pull.c:68
 #, c-format
-msgid "missing notes on source object %s. Cannot copy."
-msgstr "thiếu ghi chú trên đối tượng nguồn %s. Không thể sao chép."
+msgid "Invalid value for %s: %s"
+msgstr "Giá trị không hợp lệ %s: %s"
 
-#: builtin/notes.c:593
-#, c-format
-msgid ""
-"The -m/-F/-c/-C options have been deprecated for the 'edit' subcommand.\n"
-"Please use 'git notes add -f -m/-F/-c/-C' instead.\n"
-msgstr ""
-"Các tùy chọn -m/-F/-c/-C đã cổ không còn dùng nữa cho lệnh con “edit”.\n"
-"Xin hãy sử dụng lệnh sau để thay thế: “git notes add -f -m/-F/-c/-C”.\n"
+#: builtin/pull.c:88
+msgid "git pull [<options>] [<repository> [<refspec>...]]"
+msgstr "git pull [<các tùy chọn>] [<kho-chứa> [<refspec>…]]"
 
-#: builtin/notes.c:688
-msgid "failed to delete ref NOTES_MERGE_PARTIAL"
-msgstr "gặp lỗi khi xóa tham chiếu NOTES_MERGE_PARTIAL"
+#: builtin/pull.c:142
+msgid "control for recursive fetching of submodules"
+msgstr "điều khiển việc lấy về đệ quy của các mô-đun-con"
 
-#: builtin/notes.c:690
-msgid "failed to delete ref NOTES_MERGE_REF"
-msgstr "gặp lỗi khi xóa tham chiếu NOTES_MERGE_REF"
+#: builtin/pull.c:146
+msgid "Options related to merging"
+msgstr "Các tùy chọn liên quan đến hòa trộn"
 
-#: builtin/notes.c:692
-msgid "failed to remove 'git notes merge' worktree"
-msgstr "gặp lỗi khi gỡ bỏ cây làm việc “git notes merge”"
+#: builtin/pull.c:149
+msgid "incorporate changes by rebasing rather than merging"
+msgstr "các thay đổi hợp nhất bằng cải tổ thay vì hòa trộn"
 
-#: builtin/notes.c:712
-msgid "failed to read ref NOTES_MERGE_PARTIAL"
-msgstr "gặp lỗi khi đọc tham chiếu NOTES_MERGE_PARTIAL"
+#: builtin/pull.c:177 builtin/rebase.c:467 builtin/revert.c:126
+msgid "allow fast-forward"
+msgstr "cho phép chuyển-tiếp-nhanh"
 
-#: builtin/notes.c:714
-msgid "could not find commit from NOTES_MERGE_PARTIAL."
-msgstr "không thể tìm thấy lần chuyển giao từ NOTES_MERGE_PARTIAL."
+#: builtin/pull.c:186
+msgid "automatically stash/stash pop before and after rebase"
+msgstr "tự động stash/stash pop tước và sau tu bổ (rebase)"
 
-#: builtin/notes.c:716
-msgid "could not parse commit from NOTES_MERGE_PARTIAL."
-msgstr "không thể phân tích cú pháp lần chuyển giao từ NOTES_MERGE_PARTIAL."
+#: builtin/pull.c:202
+msgid "Options related to fetching"
+msgstr "Các tùy chọn liên quan đến lệnh lấy về"
 
-#: builtin/notes.c:729
-msgid "failed to resolve NOTES_MERGE_REF"
-msgstr "gặp lỗi khi phân giải NOTES_MERGE_REF"
+#: builtin/pull.c:212
+msgid "force overwrite of local branch"
+msgstr "ép buộc ghi đè lên nhánh nội bộ"
 
-#: builtin/notes.c:732
-msgid "failed to finalize notes merge"
-msgstr "gặp lỗi khi hoàn thành hòa trộn ghi chú"
+#: builtin/pull.c:220
+msgid "number of submodules pulled in parallel"
+msgstr "số lượng mô-đun-con được đẩy lên đồng thời"
 
-#: builtin/notes.c:758
+#: builtin/pull.c:320
 #, c-format
-msgid "unknown notes merge strategy %s"
-msgstr "không hiểu chiến lược hòa trộn ghi chú %s"
-
-#: builtin/notes.c:774
-msgid "General options"
-msgstr "Tùy chọn chung"
+msgid "Invalid value for pull.ff: %s"
+msgstr "Giá trị không hợp lệ cho pull.ff: %s"
 
-#: builtin/notes.c:776
-msgid "Merge options"
-msgstr "Tùy chọn về hòa trộn"
+#: builtin/pull.c:437
+msgid ""
+"There is no candidate for rebasing against among the refs that you just "
+"fetched."
+msgstr ""
+"Ở đây không có ứng cử nào để cải tổ lại trong số các tham chiếu mà bạn vừa "
+"lấy về."
 
-#: builtin/notes.c:778
+#: builtin/pull.c:439
 msgid ""
-"resolve notes conflicts using the given strategy (manual/ours/theirs/union/"
-"cat_sort_uniq)"
+"There are no candidates for merging among the refs that you just fetched."
 msgstr ""
-"phân giải các xung đột “notes” sử dụng chiến lược đã đưa ra (manual/ours/"
-"theirs/union/cat_sort_uniq)"
+"Ở đây không có ứng cử nào để hòa trộn trong số các tham chiếu mà bạn vừa lấy "
+"về."
 
-#: builtin/notes.c:780
-msgid "Committing unmerged notes"
-msgstr "Chuyển giao các note chưa được hòa trộn"
+#: builtin/pull.c:440
+msgid ""
+"Generally this means that you provided a wildcard refspec which had no\n"
+"matches on the remote end."
+msgstr ""
+"Đại thể điều này có nghĩa là bạn đã cung cấp đặc tả đường dẫn dạng dùng ký "
+"tự\n"
+"đại diện mà nó lại không khớp trên điểm cuối máy phục vụ."
 
-#: builtin/notes.c:782
-msgid "finalize notes merge by committing unmerged notes"
+#: builtin/pull.c:443
+#, c-format
+msgid ""
+"You asked to pull from the remote '%s', but did not specify\n"
+"a branch. Because this is not the default configured remote\n"
+"for your current branch, you must specify a branch on the command line."
 msgstr ""
-"các note cuối cùng được hòa trộn bởi các note chưa hòa trộn của lần chuyển "
-"giao"
+"Bạn yêu cầu pull từ máy dịch vụ “%s”, nhưng lại chưa chỉ định\n"
+"nhánh nào. Bởi vì đây không phải là máy dịch vụ được cấu hình\n"
+"theo mặc định cho nhánh hiện tại của bạn, bạn phải chỉ định\n"
+"một nhánh trên dòng lệnh."
 
-#: builtin/notes.c:784
-msgid "Aborting notes merge resolution"
-msgstr "Hủy bỏ phân giải ghi chú (note) hòa trộn"
+#: builtin/pull.c:448 builtin/rebase.c:1375 git-parse-remote.sh:73
+msgid "You are not currently on a branch."
+msgstr "Hiện tại bạn chẳng ở nhánh nào cả."
 
-#: builtin/notes.c:786
-msgid "abort notes merge"
-msgstr "bỏ qua hòa trộn các ghi chú (note)"
+#: builtin/pull.c:450 builtin/pull.c:465 git-parse-remote.sh:79
+msgid "Please specify which branch you want to rebase against."
+msgstr "Vui lòng chỉ định nhánh nào bạn muốn cải tổ lại."
 
-#: builtin/notes.c:797
-msgid "cannot mix --commit, --abort or -s/--strategy"
-msgstr "không thể trộn lẫn --commit, --abort hay -s/--strategy"
+#: builtin/pull.c:452 builtin/pull.c:467 git-parse-remote.sh:82
+msgid "Please specify which branch you want to merge with."
+msgstr "Vui lòng chỉ định nhánh nào bạn muốn hòa trộn vào."
 
-#: builtin/notes.c:802
-msgid "must specify a notes ref to merge"
-msgstr "bạn phải chỉ định tham chiếu ghi chú để hòa trộn"
+#: builtin/pull.c:453 builtin/pull.c:468
+msgid "See git-pull(1) for details."
+msgstr "Xem git-pull(1) để biết thêm chi tiết."
 
-#: builtin/notes.c:826
-#, c-format
-msgid "unknown -s/--strategy: %s"
-msgstr "không hiểu -s/--strategy: %s"
+#: builtin/pull.c:455 builtin/pull.c:461 builtin/pull.c:470
+#: builtin/rebase.c:1381 git-parse-remote.sh:64
+msgid "<remote>"
+msgstr "<máy chủ>"
+
+#: builtin/pull.c:455 builtin/pull.c:470 builtin/pull.c:475
+#: git-parse-remote.sh:65
+msgid "<branch>"
+msgstr "<nhánh>"
 
-#: builtin/notes.c:863
-#, c-format
-msgid "a notes merge into %s is already in-progress at %s"
-msgstr "một ghi chú hòa trộn vào %s đã sẵn trong quá trình xử lý tại %s"
+#: builtin/pull.c:463 builtin/rebase.c:1373 git-parse-remote.sh:75
+msgid "There is no tracking information for the current branch."
+msgstr "Ở đây không có thông tin theo dõi cho nhánh hiện hành."
 
-#: builtin/notes.c:866
-#, c-format
-msgid "failed to store link to current notes ref (%s)"
-msgstr "gặp lỗi khi lưu liên kết đến tham chiếu ghi chú hiện tại (%s)"
+#: builtin/pull.c:472 git-parse-remote.sh:95
+msgid ""
+"If you wish to set tracking information for this branch you can do so with:"
+msgstr ""
+"Nếu bạn muốn theo dõi thông tin cho nhánh này bạn có thể thực hiện bằng lệnh:"
 
-#: builtin/notes.c:868
+#: builtin/pull.c:477
 #, c-format
 msgid ""
-"Automatic notes merge failed. Fix conflicts in %s and commit the result with "
-"'git notes merge --commit', or abort the merge with 'git notes merge --"
-"abort'.\n"
+"Your configuration specifies to merge with the ref '%s'\n"
+"from the remote, but no such ref was fetched."
 msgstr ""
-"Gặp lỗi khi hòa trộn các ghi chú tự động. Sửa các xung đột này trong %s và "
-"chuyển giao kết quả bằng “git notes merge --commit”, hoặc bãi bỏ việc hòa "
-"trộn bằng “git notes merge --abort”.\n"
+"Các đặc tả cấu hình của bạn để hòa trộn với tham chiếu “%s”\n"
+"từ máy dịch vụ, nhưng không có nhánh nào như thế được lấy về."
 
-#: builtin/notes.c:890
+#: builtin/pull.c:587
 #, c-format
-msgid "Object %s has no note\n"
-msgstr "Đối tượng %s không có ghi chú (note)\n"
-
-#: builtin/notes.c:902
-msgid "attempt to remove non-existent note is not an error"
-msgstr "cố gắng gỡ bỏ một note chưa từng tồn tại không phải là một lỗi"
+msgid "unable to access commit %s"
+msgstr "không thể truy cập lần chuyển giao “%s”"
 
-#: builtin/notes.c:905
-msgid "read object names from the standard input"
-msgstr "đọc tên đối tượng từ thiết bị nhập chuẩn"
+#: builtin/pull.c:867
+msgid "ignoring --verify-signatures for rebase"
+msgstr "bỏ qua --verify-signatures khi rebase"
 
-#: builtin/notes.c:943 builtin/prune.c:107 builtin/worktree.c:151
-msgid "do not remove, show only"
-msgstr "không gỡ bỏ, chỉ hiển thị"
+#: builtin/pull.c:922
+msgid "--[no-]autostash option is only valid with --rebase."
+msgstr "tùy chọn --[no-]autostash chỉ hợp lệ khi dùng với --rebase."
 
-#: builtin/notes.c:944
-msgid "report pruned notes"
-msgstr "báo cáo các đối tượng đã prune"
+#: builtin/pull.c:930
+msgid "Updating an unborn branch with changes added to the index."
+msgstr ""
+"Đang cập nhật một nhánh chưa được sinh ra với các thay đổi được thêm vào "
+"bảng mục lục."
 
-#: builtin/notes.c:986
-msgid "notes-ref"
-msgstr "notes-ref"
+#: builtin/pull.c:934
+msgid "pull with rebase"
+msgstr "pull với rebase"
 
-#: builtin/notes.c:987
-msgid "use notes from <notes-ref>"
-msgstr "dùng “notes” từ <notes-ref>"
+#: builtin/pull.c:935
+msgid "please commit or stash them."
+msgstr "xin hãy chuyển giao hoặc tạm cất (stash) chúng."
 
-#: builtin/notes.c:1022
+#: builtin/pull.c:960
 #, c-format
-msgid "unknown subcommand: %s"
-msgstr "không hiểu câu lệnh con: %s"
-
-#: builtin/pack-objects.c:48
 msgid ""
-"git pack-objects --stdout [<options>...] [< <ref-list> | < <object-list>]"
+"fetch updated the current branch head.\n"
+"fast-forwarding your working tree from\n"
+"commit %s."
 msgstr ""
-"git pack-objects --stdout [các-tùy-chọn…] [< <danh-sách-tham-chiếu> | < "
-"<danh-sách-đối-tượng>]"
+"fetch đã cập nhật head nhánh hiện tại.\n"
+"đang chuyển-tiếp-nhanh cây làm việc của bạn từ\n"
+"lần chuyển giaot %s."
 
-#: builtin/pack-objects.c:49
+#: builtin/pull.c:966
+#, c-format
 msgid ""
-"git pack-objects [<options>...] <base-name> [< <ref-list> | < <object-list>]"
+"Cannot fast-forward your working tree.\n"
+"After making sure that you saved anything precious from\n"
+"$ git diff %s\n"
+"output, run\n"
+"$ git reset --hard\n"
+"to recover."
 msgstr ""
-"git pack-objects [các-tùy-chọn…] <base-name> [< <danh-sách-ref> | < <danh-"
-"sách-đối-tượng>]"
+"Không thể chuyển tiếp nhanh cây làm việc của bạn.\n"
+"Sau khi chắc chắn rằng mình đã ghi lại mọi thứ\n"
+"quý báu từ kết xuất của lệnh\n"
+"$ git diff %s\n"
+"chạy\n"
+"$ git reset --hard\n"
+"để khôi phục lại."
 
-#: builtin/pack-objects.c:211 builtin/pack-objects.c:214
-#, c-format
-msgid "deflate error (%d)"
-msgstr "lỗi giải nén (%d)"
+#: builtin/pull.c:981
+msgid "Cannot merge multiple branches into empty head."
+msgstr "Không thể hòa trộn nhiều nhánh vào trong một head trống rỗng."
 
-#: builtin/pack-objects.c:810
-msgid "disabling bitmap writing, packs are split due to pack.packSizeLimit"
-msgstr "tắt ghi bitmap, các gói bị chia nhỏ bởi vì pack.packSizeLimit"
+#: builtin/pull.c:985
+msgid "Cannot rebase onto multiple branches."
+msgstr "Không thể thực hiện lệnh rebase (cải tổ) trên nhiều nhánh."
 
-#: builtin/pack-objects.c:823
-msgid "Writing objects"
-msgstr "Đang ghi lại các đối tượng"
+#: builtin/pull.c:992
+msgid "cannot rebase with locally recorded submodule modifications"
+msgstr ""
+"không thể cải tổ với các thay đổi mô-đun-con được ghi lại một cách cục bộ"
 
-#: builtin/pack-objects.c:1106
-msgid "disabling bitmap writing, as some objects are not being packed"
-msgstr "tắt ghi bitmap, như vậy một số đối tượng sẽ không được đóng gói"
+#: builtin/push.c:19
+msgid "git push [<options>] [<repository> [<refspec>...]]"
+msgstr "git push [<các tùy chọn>] [<kho-chứa> [<refspec>…]]"
 
-#: builtin/pack-objects.c:1765
-msgid "Counting objects"
-msgstr "Đang đếm các đối tượng"
+#: builtin/push.c:112
+msgid "tag shorthand without <tag>"
+msgstr "dùng tốc ký thẻ không có <thẻ>"
 
-#: builtin/pack-objects.c:1895
-#, c-format
-msgid "unable to get size of %s"
-msgstr "không thể lấy kích cỡ của %s"
+#: builtin/push.c:122
+msgid "--delete only accepts plain target ref names"
+msgstr "--delete chỉ chấp nhận các tên tham chiếu dạng thường"
+
+#: builtin/push.c:168
+msgid ""
+"\n"
+"To choose either option permanently, see push.default in 'git help config'."
+msgstr ""
+"\n"
+"Để chọn mỗi tùy chọn một cách cố định, xem push.default trong “git help "
+"config”."
 
-#: builtin/pack-objects.c:1910
+#: builtin/push.c:171
 #, c-format
-msgid "unable to parse object header of %s"
-msgstr "không thể phân tích phần đầu đối tượng của “%s”"
+msgid ""
+"The upstream branch of your current branch does not match\n"
+"the name of your current branch.  To push to the upstream branch\n"
+"on the remote, use\n"
+"\n"
+"    git push %s HEAD:%s\n"
+"\n"
+"To push to the branch of the same name on the remote, use\n"
+"\n"
+"    git push %s HEAD\n"
+"%s"
+msgstr ""
+"Nhánh thượng nguồn của nhánh hiện tại của bạn không khớp\n"
+"với tên của nhánh hiện tại của bạn.  Để đẩy lên đến nhánh\n"
+"thượng nguồn trên máy chủ, sử dụng\n"
+"\n"
+"    git push %s HEAD:%s\n"
+"\n"
+"Để đẩy tới nhánh cùng tên trên máy chủ, sử dụng\n"
+"\n"
+"    git push %s HEAD\n"
+"%s"
 
-#: builtin/pack-objects.c:2564
-msgid "Compressing objects"
-msgstr "Đang nén các đối tượng"
+#: builtin/push.c:186
+#, c-format
+msgid ""
+"You are not currently on a branch.\n"
+"To push the history leading to the current (detached HEAD)\n"
+"state now, use\n"
+"\n"
+"    git push %s HEAD:<name-of-remote-branch>\n"
+msgstr ""
+"Bạn hiện nay không ở một nhánh.\n"
+"Để đẩy lịch sử lên trên trạng thái hiện hành (HEAD đã bị tách rời)\n"
+"ngay bây giờ, sử dụng\n"
+"\n"
+"    git push %s HEAD:<tên-của-nhánh-máy-chủ>\n"
 
-#: builtin/pack-objects.c:2735
-msgid "invalid value for --missing"
-msgstr "giá trị cho --missing không hợp lệ"
+#: builtin/push.c:200
+#, c-format
+msgid ""
+"The current branch %s has no upstream branch.\n"
+"To push the current branch and set the remote as upstream, use\n"
+"\n"
+"    git push --set-upstream %s %s\n"
+msgstr ""
+"Nhánh hiện tại %s không có nhánh thượng nguồn nào.\n"
+"Để push (đẩy lên) nhánh hiện tại và đặt máy chủ này làm thượng nguồn "
+"(upstream), sử dụng\n"
+"\n"
+"    git push --set-upstream %s %s\n"
 
-#: builtin/pack-objects.c:3067
+#: builtin/push.c:208
 #, c-format
-msgid "unsupported index version %s"
-msgstr "phiên bản mục lục không được hỗ trợ %s"
+msgid "The current branch %s has multiple upstream branches, refusing to push."
+msgstr "Nhánh hiện tại %s có nhiều nhánh thượng nguồn, từ chối push."
 
-#: builtin/pack-objects.c:3071
+#: builtin/push.c:211
 #, c-format
-msgid "bad index version '%s'"
-msgstr "phiên bản mục lục sai “%s”"
+msgid ""
+"You are pushing to remote '%s', which is not the upstream of\n"
+"your current branch '%s', without telling me what to push\n"
+"to update which remote branch."
+msgstr ""
+"Bạn đang push (đẩy lên) máy chủ “%s”, mà nó không phải là thượng nguồn "
+"(upstream) của\n"
+"nhánh hiện tại “%s” của bạn, mà không báo cho tôi biết là cái gì được push\n"
+"để cập nhật nhánh máy chủ nào."
 
-#: builtin/pack-objects.c:3102
-msgid "do not show progress meter"
-msgstr "không hiển thị bộ đo tiến trình"
+#: builtin/push.c:270
+msgid ""
+"You didn't specify any refspecs to push, and push.default is \"nothing\"."
+msgstr ""
+"Bạn đã không chỉ ra một refspecs nào để đẩy lên, và push.default là \"không "
+"là gì cả\"."
 
-#: builtin/pack-objects.c:3104
-msgid "show progress meter"
-msgstr "hiển thị bộ đo tiến trình"
+#: builtin/push.c:277
+msgid ""
+"Updates were rejected because the tip of your current branch is behind\n"
+"its remote counterpart. Integrate the remote changes (e.g.\n"
+"'git pull ...') before pushing again.\n"
+"See the 'Note about fast-forwards' in 'git push --help' for details."
+msgstr ""
+"Việc cập nhật bị từ chối bởi vì đầu mút của nhánh hiện tại của bạn nằm đằng\n"
+"sau bộ phận tương ứng của máy chủ. Hòa trộn với các thay đổi từ máy chủ\n"
+"(v.d. \"git pull …\") trước khi đẩy lên lần nữa.\n"
+"Xem “Note about fast-forwards” trong “git push --help” để có thông tin chi "
+"tiết."
 
-#: builtin/pack-objects.c:3106
-msgid "show progress meter during object writing phase"
-msgstr "hiển thị bộ đo tiến triển trong suốt pha ghi đối tượng"
+#: builtin/push.c:283
+msgid ""
+"Updates were rejected because a pushed branch tip is behind its remote\n"
+"counterpart. Check out this branch and integrate the remote changes\n"
+"(e.g. 'git pull ...') before pushing again.\n"
+"See the 'Note about fast-forwards' in 'git push --help' for details."
+msgstr ""
+"Việc cập nhật bị từ chối bởi vì đầu mút của nhánh đã đẩy lên nằm đằng sau "
+"bộ\n"
+"phận tương ứng của máy chủ. Checkou nhánh này và hòa trộn với các thay đổi\n"
+"từ máy chủ (v.d. “git pull …”) trước khi lại push lần nữa.\n"
+"Xem “Note about fast-forwards” trong “git push --help” để có thông tin chi "
+"tiết."
 
-#: builtin/pack-objects.c:3109
-msgid "similar to --all-progress when progress meter is shown"
-msgstr "tương tự --all-progress khi bộ đo tiến trình được xuất hiện"
+#: builtin/push.c:289
+msgid ""
+"Updates were rejected because the remote contains work that you do\n"
+"not have locally. This is usually caused by another repository pushing\n"
+"to the same ref. You may want to first integrate the remote changes\n"
+"(e.g., 'git pull ...') before pushing again.\n"
+"See the 'Note about fast-forwards' in 'git push --help' for details."
+msgstr ""
+"Việc cập nhật bị từ chối bởi vì máy chủ có chứa công việc mà bạn không\n"
+"có ở máy nội bộ của mình. Lỗi này thường có nguyên nhân bởi kho khác đẩy\n"
+"dữ liệu lên cùng một tham chiếu. Bạn có lẽ muốn hòa trộn với các thay đổi\n"
+"từ máy chủ (v.d. “git pull…”) trước khi lại push lần nữa.\n"
+"Xem “Note about fast-forwards” trong “git push --help” để có thông tin chi "
+"tiết."
 
-#: builtin/pack-objects.c:3110
-msgid "version[,offset]"
-msgstr "phiên bản[,offset]"
+#: builtin/push.c:296
+msgid "Updates were rejected because the tag already exists in the remote."
+msgstr "Việc cập nhật bị từ chối bởi vì thẻ đã sẵn có từ trước trên máy chủ."
 
-#: builtin/pack-objects.c:3111
-msgid "write the pack index file in the specified idx format version"
-msgstr "ghi tập tin bảng mục lục gói (pack) ở phiên bản định dạng idx đã cho"
+#: builtin/push.c:299
+msgid ""
+"You cannot update a remote ref that points at a non-commit object,\n"
+"or update a remote ref to make it point at a non-commit object,\n"
+"without using the '--force' option.\n"
+msgstr ""
+"Không thể cập nhật một tham chiếu trên máy chủ mà nó chỉ đến đối tượng "
+"không\n"
+"phải là lần chuyển giao, hoặc cập nhật một tham chiếu máy chủ để nó chỉ đến "
+"đối tượng\n"
+"không phải chuyển giao, mà không sử dụng tùy chọn “--force”.\n"
 
-#: builtin/pack-objects.c:3114
-msgid "maximum size of each output pack file"
-msgstr "kcíh thước tối đa cho tập tin gói được tạo"
+#: builtin/push.c:360
+#, c-format
+msgid "Pushing to %s\n"
+msgstr "Đang đẩy lên %s\n"
 
-#: builtin/pack-objects.c:3116
-msgid "ignore borrowed objects from alternate object store"
-msgstr "bỏ qua các đối tượng vay mượn từ kho đối tượng thay thế"
+#: builtin/push.c:367
+#, c-format
+msgid "failed to push some refs to '%s'"
+msgstr "gặp lỗi khi đẩy tới một số tham chiếu đến “%s”"
+
+#: builtin/push.c:542
+msgid "repository"
+msgstr "kho"
 
-#: builtin/pack-objects.c:3118
-msgid "ignore packed objects"
-msgstr "bỏ qua các đối tượng đóng gói"
+#: builtin/push.c:543 builtin/send-pack.c:164
+msgid "push all refs"
+msgstr "đẩy tất cả các tham chiếu"
 
-#: builtin/pack-objects.c:3120
-msgid "limit pack window by objects"
-msgstr "giới hạn cửa sổ đóng gói theo đối tượng"
+#: builtin/push.c:544 builtin/send-pack.c:166
+msgid "mirror all refs"
+msgstr "mirror tất cả các tham chiếu"
 
-#: builtin/pack-objects.c:3122
-msgid "limit pack window by memory in addition to object limit"
-msgstr "giới hạn cửa sổ đóng gói theo bộ nhớ cộng thêm với giới hạn đối tượng"
+#: builtin/push.c:546
+msgid "delete refs"
+msgstr "xóa các tham chiếu"
 
-#: builtin/pack-objects.c:3124
-msgid "maximum length of delta chain allowed in the resulting pack"
-msgstr "độ dài tối đa của chuỗi móc xích “delta” được phép trong gói kết quả"
+#: builtin/push.c:547
+msgid "push tags (can't be used with --all or --mirror)"
+msgstr "đẩy các thẻ (không dùng cùng với --all hay --mirror)"
 
-#: builtin/pack-objects.c:3126
-msgid "reuse existing deltas"
-msgstr "dùng lại các delta sẵn có"
+#: builtin/push.c:550 builtin/send-pack.c:167
+msgid "force updates"
+msgstr "ép buộc cập nhật"
 
-#: builtin/pack-objects.c:3128
-msgid "reuse existing objects"
-msgstr "dùng lại các đối tượng sẵn có"
+#: builtin/push.c:552 builtin/send-pack.c:181
+msgid "<refname>:<expect>"
+msgstr "<tên-tham-chiếu>:<cần>"
 
-#: builtin/pack-objects.c:3130
-msgid "use OFS_DELTA objects"
-msgstr "dùng các đối tượng OFS_DELTA"
+#: builtin/push.c:553 builtin/send-pack.c:182
+msgid "require old value of ref to be at this value"
+msgstr "yêu cầu giá-trị cũ của tham chiếu thì là giá-trị này"
 
-#: builtin/pack-objects.c:3132
-msgid "use threads when searching for best delta matches"
-msgstr "sử dụng các tuyến trình khi tìm kiếm cho các mẫu khớp delta tốt nhất"
+#: builtin/push.c:556
+msgid "control recursive pushing of submodules"
+msgstr "điều khiển việc đẩy lên (push) đệ qui của mô-đun-con"
 
-#: builtin/pack-objects.c:3134
-msgid "do not create an empty pack output"
-msgstr "không thể tạo kết xuất gói trống rỗng"
+#: builtin/push.c:558 builtin/send-pack.c:175
+msgid "use thin pack"
+msgstr "tạo gói nhẹ"
 
-#: builtin/pack-objects.c:3136
-msgid "read revision arguments from standard input"
-msgstr " đọc tham số “revision” từ thiết bị nhập chuẩn"
+#: builtin/push.c:559 builtin/push.c:560 builtin/send-pack.c:161
+#: builtin/send-pack.c:162
+msgid "receive pack program"
+msgstr "chương trình nhận gói"
 
-#: builtin/pack-objects.c:3138
-msgid "limit the objects to those that are not yet packed"
-msgstr "giới hạn các đối tượng thành những cái mà chúng vẫn chưa được đóng gói"
+#: builtin/push.c:561
+msgid "set upstream for git pull/status"
+msgstr "đặt thượng nguồn cho git pull/status"
 
-#: builtin/pack-objects.c:3141
-msgid "include objects reachable from any reference"
-msgstr "bao gồm các đối tượng có thể đọc được từ bất kỳ tham chiếu nào"
+#: builtin/push.c:564
+msgid "prune locally removed refs"
+msgstr "xén tỉa những tham chiếu bị gỡ bỏ"
 
-#: builtin/pack-objects.c:3144
-msgid "include objects referred by reflog entries"
-msgstr "bao gồm các đối tượng được tham chiếu bởi các mục reflog"
+#: builtin/push.c:566
+msgid "bypass pre-push hook"
+msgstr "vòng qua móc tiền-đẩy (pre-push)"
 
-#: builtin/pack-objects.c:3147
-msgid "include objects referred to by the index"
-msgstr "bao gồm các đối tượng được tham chiếu bởi mục lục"
+#: builtin/push.c:567
+msgid "push missing but relevant tags"
+msgstr "push phần bị thiếu nhưng các thẻ lại thích hợp"
 
-#: builtin/pack-objects.c:3150
-msgid "output pack to stdout"
-msgstr "xuất gói ra đầu ra tiêu chuẩn"
+#: builtin/push.c:570 builtin/send-pack.c:169
+msgid "GPG sign the push"
+msgstr "ký lần đẩy dùng GPG"
 
-#: builtin/pack-objects.c:3152
-msgid "include tag objects that refer to objects to be packed"
-msgstr "bao gồm các đối tượng tham chiếu đến các đối tượng được đóng gói"
+#: builtin/push.c:572 builtin/send-pack.c:176
+msgid "request atomic transaction on remote side"
+msgstr "yêu cầu giao dịch hạt nhân bên phía máy chủ"
 
-#: builtin/pack-objects.c:3154
-msgid "keep unreachable objects"
-msgstr "giữ lại các đối tượng không thể đọc được"
+#: builtin/push.c:590
+msgid "--delete is incompatible with --all, --mirror and --tags"
+msgstr "--delete là xung khắc với các tùy chọn --all, --mirror và --tags"
 
-#: builtin/pack-objects.c:3156
-msgid "pack loose unreachable objects"
-msgstr "pack mất các đối tượng không thể đọc được"
+#: builtin/push.c:592
+msgid "--delete doesn't make sense without any refs"
+msgstr "--delete không hợp lý nếu không có bất kỳ tham chiếu nào"
 
-#: builtin/pack-objects.c:3158
-msgid "unpack unreachable objects newer than <time>"
+#: builtin/push.c:612
+#, c-format
+msgid "bad repository '%s'"
+msgstr "repository (kho) sai “%s”"
+
+#: builtin/push.c:613
+msgid ""
+"No configured push destination.\n"
+"Either specify the URL from the command-line or configure a remote "
+"repository using\n"
+"\n"
+"    git remote add <name> <url>\n"
+"\n"
+"and then push using the remote name\n"
+"\n"
+"    git push <name>\n"
 msgstr ""
-"xả nén (gỡ khỏi gói) các đối tượng không thể đọc được mới hơn <thời-gian>"
+"Chưa cấu hình đích để đẩy lên.\n"
+"Hoặc là chỉ ra URL từ dòng lệnh hoặc là cấu hình một kho máy chủ sử dụng\n"
+"\n"
+"    git remote add <tên> <url>\n"
+"\n"
+"và sau đó đẩy lên sử dụng tên máy chủ\n"
+"\n"
+"    git push <tên>\n"
 
-#: builtin/pack-objects.c:3161
-msgid "create thin packs"
-msgstr "tạo gói nhẹ"
+#: builtin/push.c:628
+msgid "--all and --tags are incompatible"
+msgstr "--all và --tags xung khắc nhau"
 
-#: builtin/pack-objects.c:3163
-msgid "create packs suitable for shallow fetches"
-msgstr "tạo gói để phù hợp cho lấy về nông (shallow)"
+#: builtin/push.c:630
+msgid "--all can't be combined with refspecs"
+msgstr "--all không thể được tổ hợp cùng với đặc tả đường dẫn"
 
-#: builtin/pack-objects.c:3165
-msgid "ignore packs that have companion .keep file"
-msgstr "bỏ qua các gói mà nó có tập tin .keep đi kèm"
+#: builtin/push.c:634
+msgid "--mirror and --tags are incompatible"
+msgstr "--mirror và --tags xung khắc nhau"
 
-#: builtin/pack-objects.c:3167
-msgid "ignore this pack"
-msgstr "bỏ qua gói này"
+#: builtin/push.c:636
+msgid "--mirror can't be combined with refspecs"
+msgstr "--mirror không thể được tổ hợp cùng với đặc tả đường dẫn"
 
-#: builtin/pack-objects.c:3169
-msgid "pack compression level"
-msgstr "mức nén gói"
+#: builtin/push.c:639
+msgid "--all and --mirror are incompatible"
+msgstr "--all và --mirror xung khắc nhau"
 
-#: builtin/pack-objects.c:3171
-msgid "do not hide commits by grafts"
-msgstr "không ẩn các lần chuyển giao bởi “grafts”"
+#: builtin/push.c:643
+msgid "push options must not have new line characters"
+msgstr "các tùy chọn push phải không có ký tự dòng mới"
 
-#: builtin/pack-objects.c:3173
-msgid "use a bitmap index if available to speed up counting objects"
-msgstr "dùng mục lục ánh xạ nếu có thể được để nâng cao tốc độ đếm đối tượng"
+#: builtin/range-diff.c:8
+msgid "git range-diff [<options>] <old-base>..<old-tip> <new-base>..<new-tip>"
+msgstr ""
+"git range-diff [<các tùy chọn>] <old-base>..<old-tip> <new-base>..<new-tip>"
 
-#: builtin/pack-objects.c:3175
-msgid "write a bitmap index together with the pack index"
-msgstr "ghi một mục lục ánh xạ cùng với mục lục gói"
+#: builtin/range-diff.c:9
+msgid "git range-diff [<options>] <old-tip>...<new-tip>"
+msgstr "git range-diff [<các tùy chọn>] <old-tip>…<new-tip>"
 
-#: builtin/pack-objects.c:3178
-msgid "handling for missing objects"
-msgstr "xử lý cho thiếu đối tượng"
+#: builtin/range-diff.c:10
+msgid "git range-diff [<options>] <base> <old-tip> <new-tip>"
+msgstr "git range-diff [<các tùy chọn>] <base> <old-tip> <new-tip>"
 
-#: builtin/pack-objects.c:3181
-msgid "do not pack objects in promisor packfiles"
-msgstr "không thể đóng gói các đối tượng trong các tập tin gói hứa hẹn"
+#: builtin/range-diff.c:22
+msgid "Percentage by which creation is weighted"
+msgstr "Tỷ lệ phần trăm cái tạo là weighted"
 
-#: builtin/pack-objects.c:3205
-#, c-format
-msgid "delta chain depth %d is too deep, forcing %d"
-msgstr "mức sau xích delta %d là quá sâu, buộc dùng %d"
+#: builtin/range-diff.c:24
+msgid "use simple diff colors"
+msgstr "dùng màu diff đơn giản"
+
+#: builtin/range-diff.c:26
+msgid "notes"
+msgstr "ghi chú"
 
-#: builtin/pack-objects.c:3210
+#: builtin/range-diff.c:26
+msgid "passed to 'git log'"
+msgstr "chuyển cho “git log”"
+
+#: builtin/range-diff.c:50 builtin/range-diff.c:54
 #, c-format
-msgid "pack.deltaCacheLimit is too high, forcing %d"
-msgstr "pack.deltaCacheLimit là quá cao, ép dùng %d"
+msgid "no .. in range: '%s'"
+msgstr "không có .. trong vùng: “%s”"
 
-#: builtin/pack-objects.c:3338
-msgid "Enumerating objects"
-msgstr "Đánh số các đối tượng"
+#: builtin/range-diff.c:64
+msgid "single arg format must be symmetric range"
+msgstr "định dạng đối số đơn phải là một vùng đối xứng"
 
-#: builtin/pack-refs.c:7
-msgid "git pack-refs [<options>]"
-msgstr "git pack-refs [<các-tùy-chọn>]"
+#: builtin/range-diff.c:79
+msgid "need two commit ranges"
+msgstr "cần hai vùng lần chuyển giao"
 
-#: builtin/pack-refs.c:15
-msgid "pack everything"
-msgstr "đóng gói mọi thứ"
+#: builtin/read-tree.c:41
+msgid ""
+"git read-tree [(-m [--trivial] [--aggressive] | --reset | --prefix=<prefix>) "
+"[-u [--exclude-per-directory=<gitignore>] | -i]] [--no-sparse-checkout] [--"
+"index-output=<file>] (--empty | <tree-ish1> [<tree-ish2> [<tree-ish3>]])"
+msgstr ""
+"git read-tree [(-m [--trivial] [--aggressive] | --reset | --prefix=<tiền-"
+"tố>) [-u [--exclude-per-directory=<gitignore>] | -i]] [--no-sparse-checkout] "
+"[--index-output=<tập-tin>] (--empty | <tree-ish1> [<tree-ish2> [<tree-"
+"ish3>]])"
 
-#: builtin/pack-refs.c:16
-msgid "prune loose refs (default)"
-msgstr "prune (cắt cụt) những tham chiếu bị mất (mặc định)"
+#: builtin/read-tree.c:124
+msgid "write resulting index to <file>"
+msgstr "ghi mục lục kết quả vào <tập-tin>"
 
-#: builtin/prune-packed.c:8
-msgid "git prune-packed [-n | --dry-run] [-q | --quiet]"
-msgstr "git prune-packed [-n | --dry-run] [-q | --quiet]"
+#: builtin/read-tree.c:127
+msgid "only empty the index"
+msgstr "chỉ với bảng mục lục trống rỗng"
 
-#: builtin/prune-packed.c:41
-msgid "Removing duplicate objects"
-msgstr "Đang gỡ các đối tượng trùng lặp"
+#: builtin/read-tree.c:129
+msgid "Merging"
+msgstr "Hòa trộn"
 
-#: builtin/prune.c:11
-msgid "git prune [-n] [-v] [--progress] [--expire <time>] [--] [<head>...]"
-msgstr "git prune [-n] [-v] [--progress] [--expire <thời-gian>] [--] [<head>…]"
+#: builtin/read-tree.c:131
+msgid "perform a merge in addition to a read"
+msgstr "thực hiện một hòa trộn thêm vào việc đọc"
 
-#: builtin/prune.c:108
-msgid "report pruned objects"
-msgstr "báo cáo các đối tượng đã prune"
+#: builtin/read-tree.c:133
+msgid "3-way merge if no file level merging required"
+msgstr ""
+"hòa trộn kiểu “3-way” nếu không có tập tin mức hòa trộn nào được yêu cầu"
 
-#: builtin/prune.c:111
-msgid "expire objects older than <time>"
-msgstr "các đối tượng hết hạn cũ hơn khoảng <thời gian>"
+#: builtin/read-tree.c:135
+msgid "3-way merge in presence of adds and removes"
+msgstr "hòa trộn 3-way trong sự hiện diện của “adds” và “removes”"
 
-#: builtin/prune.c:113
-msgid "limit traversal to objects outside promisor packfiles"
-msgstr "giới hạn giao đến các đối tượng nằm ngoài các tập tin gói hứa hẹn"
+#: builtin/read-tree.c:137
+msgid "same as -m, but discard unmerged entries"
+msgstr "giống với -m, nhưng bỏ qua các mục chưa được hòa trộn"
 
-#: builtin/prune.c:127
-msgid "cannot prune in a precious-objects repo"
-msgstr "không thể tỉa bớt trong một kho đối_tượng_vĩ_đại"
+#: builtin/read-tree.c:138
+msgid "<subdirectory>/"
+msgstr "<thư-mục-con>/"
 
-#: builtin/pull.c:59 builtin/pull.c:61
-#, c-format
-msgid "Invalid value for %s: %s"
-msgstr "Giá trị không hợp lệ %s: %s"
+#: builtin/read-tree.c:139
+msgid "read the tree into the index under <subdirectory>/"
+msgstr "đọc cây vào trong bảng mục lục dưới <thư_mục_con>/"
 
-#: builtin/pull.c:81
-msgid "git pull [<options>] [<repository> [<refspec>...]]"
-msgstr "git pull [<các-tùy-chọn>] [<kho-chứa> [<refspec>…]]"
+#: builtin/read-tree.c:142
+msgid "update working tree with merge result"
+msgstr "cập nhật cây làm việc với kết quả hòa trộn"
 
-#: builtin/pull.c:132
-msgid "control for recursive fetching of submodules"
-msgstr "điều khiển việc lấy về đệ quy của các mô-đun-con"
+#: builtin/read-tree.c:144
+msgid "gitignore"
+msgstr "gitignore"
 
-#: builtin/pull.c:136
-msgid "Options related to merging"
-msgstr "Các tùy chọn liên quan đến hòa trộn"
+#: builtin/read-tree.c:145
+msgid "allow explicitly ignored files to be overwritten"
+msgstr "cho phép các tập tin rõ ràng bị lờ đi được ghi đè"
 
-#: builtin/pull.c:139
-msgid "incorporate changes by rebasing rather than merging"
-msgstr "các thay đổi hợp nhất bằng cải tổ thay vì hòa trộn"
+#: builtin/read-tree.c:148
+msgid "don't check the working tree after merging"
+msgstr "không kiểm tra cây làm việc sau hòa trộn"
 
-#: builtin/pull.c:166 builtin/rebase--helper.c:23 builtin/revert.c:121
-msgid "allow fast-forward"
-msgstr "cho phép chuyển-tiếp-nhanh"
+#: builtin/read-tree.c:149
+msgid "don't update the index or the work tree"
+msgstr "không cập nhật bảng mục lục hay cây làm việc"
 
-#: builtin/pull.c:175
-msgid "automatically stash/stash pop before and after rebase"
-msgstr "tự động stash/stash pop tước và sau tu bổ (rebase)"
+#: builtin/read-tree.c:151
+msgid "skip applying sparse checkout filter"
+msgstr "bỏ qua áp dụng bộ lọc lấy ra (checkout) thưa thớt"
 
-#: builtin/pull.c:191
-msgid "Options related to fetching"
-msgstr "Các tùy chọn liên quan đến lệnh lấy về"
+#: builtin/read-tree.c:153
+msgid "debug unpack-trees"
+msgstr "gỡ lỗi “unpack-trees”"
 
-#: builtin/pull.c:209
-msgid "number of submodules pulled in parallel"
-msgstr "số lượng mô-đun-con được đẩy lên đồng thời"
+#: builtin/read-tree.c:157
+msgid "suppress feedback messages"
+msgstr "không xuất các thông tin phản hồi"
 
-#: builtin/pull.c:304
-#, c-format
-msgid "Invalid value for pull.ff: %s"
-msgstr "Giá trị không hợp lệ cho pull.ff: %s"
+#: builtin/read-tree.c:188
+msgid "You need to resolve your current index first"
+msgstr "Bạn cần phải giải quyết bảng mục lục hiện tại của bạn trước đã"
 
-#: builtin/pull.c:420
+#: builtin/rebase.c:32
 msgid ""
-"There is no candidate for rebasing against among the refs that you just "
-"fetched."
+"git rebase [-i] [options] [--exec <cmd>] [--onto <newbase> | --keep-base] "
+"[<upstream> [<branch>]]"
 msgstr ""
-"Ở đây không có ứng cử nào để cải tổ lại trong số các tham chiếu mà bạn vừa "
-"lấy về."
+"git rebase [-i] [các tùy chọn] [--exec <lệnh>] [--onto <newbase> | --keep-"
+"base] [<upstream>] [<nhánh>]]"
 
-#: builtin/pull.c:422
+#: builtin/rebase.c:34
 msgid ""
-"There are no candidates for merging among the refs that you just fetched."
+"git rebase [-i] [options] [--exec <cmd>] [--onto <newbase>] --root [<branch>]"
 msgstr ""
-"Ở đây không có ứng cử nào để hòa trộn trong số các tham chiếu mà bạn vừa lấy "
-"về."
+"git rebase [-i] [các tùy chọn] [--exec <lệnh>] [--onto <newbase>] --root "
+"[<nhánh>]"
 
-#: builtin/pull.c:423
-msgid ""
-"Generally this means that you provided a wildcard refspec which had no\n"
-"matches on the remote end."
-msgstr ""
-"Đại thể điều này có nghĩa là bạn đã cung cấp đặc tả đường dẫn dạng dùng ký "
-"tự\n"
-"đại diện mà nó lại không khớp trên điểm cuối máy phục vụ."
+#: builtin/rebase.c:36
+msgid "git rebase --continue | --abort | --skip | --edit-todo"
+msgstr "git rebase --continue | --abort | --skip | --edit-todo"
 
-#: builtin/pull.c:426
+#: builtin/rebase.c:177 builtin/rebase.c:201 builtin/rebase.c:228
 #, c-format
-msgid ""
-"You asked to pull from the remote '%s', but did not specify\n"
-"a branch. Because this is not the default configured remote\n"
-"for your current branch, you must specify a branch on the command line."
-msgstr ""
-"Bạn yêu cầu pull từ máy dịch vụ “%s”, nhưng lại chưa chỉ định\n"
-"nhánh nào. Bởi vì đây không phải là máy dịch vụ được cấu hình\n"
-"theo mặc định cho nhánh hiện tại của bạn, bạn phải chỉ định\n"
-"một nhánh trên dòng lệnh."
+msgid "unusable todo list: '%s'"
+msgstr "danh sách cần làm không dùng được: “%s”"
 
-#: builtin/pull.c:431 git-parse-remote.sh:73
-msgid "You are not currently on a branch."
-msgstr "Hiện tại bạn chẳng ở nhánh nào cả."
+#: builtin/rebase.c:186 builtin/rebase.c:212 builtin/rebase.c:236
+#, c-format
+msgid "could not write '%s'."
+msgstr "không thể ghi “%s”."
 
-#: builtin/pull.c:433 builtin/pull.c:448 git-parse-remote.sh:79
-msgid "Please specify which branch you want to rebase against."
-msgstr "Vui lòng chỉ định nhánh nào bạn muốn cải tổ lại."
+#: builtin/rebase.c:271
+msgid "no HEAD?"
+msgstr "không HEAD?"
 
-#: builtin/pull.c:435 builtin/pull.c:450 git-parse-remote.sh:82
-msgid "Please specify which branch you want to merge with."
-msgstr "Vui lòng chỉ định nhánh nào bạn muốn hòa trộn vào."
+#: builtin/rebase.c:298
+#, c-format
+msgid "could not create temporary %s"
+msgstr "không thể tạo %s tạm thời"
 
-#: builtin/pull.c:436 builtin/pull.c:451
-msgid "See git-pull(1) for details."
-msgstr "Xem git-pull(1) để biết thêm chi tiết."
+#: builtin/rebase.c:304
+msgid "could not mark as interactive"
+msgstr "không thể đánh dấu là tương tác"
 
-#: builtin/pull.c:438 builtin/pull.c:444 builtin/pull.c:453
-#: git-parse-remote.sh:64
-msgid "<remote>"
-msgstr "<máy chủ>"
+#: builtin/rebase.c:362
+msgid "could not generate todo list"
+msgstr "không thể tạo danh sách cần làm"
 
-#: builtin/pull.c:438 builtin/pull.c:453 builtin/pull.c:458 git-rebase.sh:523
-#: git-parse-remote.sh:65
-msgid "<branch>"
-msgstr "<nhánh>"
+#: builtin/rebase.c:402
+msgid "a base commit must be provided with --upstream or --onto"
+msgstr "lần chuyển giao cơ sỏ phải được chỉ định với --upstream hoặc --onto"
 
-#: builtin/pull.c:446 git-parse-remote.sh:75
-msgid "There is no tracking information for the current branch."
-msgstr "Ở đây không có thông tin theo dõi cho nhánh hiện hành."
+#: builtin/rebase.c:457
+msgid "git rebase--interactive [<options>]"
+msgstr "git rebase--interactive [<các tùy chọn>]"
 
-#: builtin/pull.c:455 git-parse-remote.sh:95
-msgid ""
-"If you wish to set tracking information for this branch you can do so with:"
-msgstr ""
-"Nếu bạn muốn theo dõi thông tin cho nhánh này bạn có thể thực hiện bằng lệnh:"
+#: builtin/rebase.c:469
+msgid "keep empty commits"
+msgstr "giữ lại các lần chuyển giao rỗng"
 
-#: builtin/pull.c:460
-#, c-format
-msgid ""
-"Your configuration specifies to merge with the ref '%s'\n"
-"from the remote, but no such ref was fetched."
-msgstr ""
-"Các đặc tả cấu hình của bạn để hòa trộn với tham chiếu “%s”\n"
-"từ máy dịch vụ, nhưng không có nhánh nào như thế được lấy về."
+#: builtin/rebase.c:471 builtin/revert.c:128
+msgid "allow commits with empty messages"
+msgstr "chấp nhận chuyển giao mà không ghi chú gì"
 
-#: builtin/pull.c:826
-msgid "ignoring --verify-signatures for rebase"
-msgstr "bỏ qua --verify-signatures khi rebase"
+#: builtin/rebase.c:472
+msgid "rebase merge commits"
+msgstr "cải tổ các lần chuyển giao hòa trộn"
 
-#: builtin/pull.c:874
-msgid "--[no-]autostash option is only valid with --rebase."
-msgstr "tùy chọn --[no-]autostash chỉ hợp lệ khi dùng với --rebase."
+#: builtin/rebase.c:474
+msgid "keep original branch points of cousins"
+msgstr "giữ các điểm nhánh nguyên bản của các anh em họ"
 
-#: builtin/pull.c:882
-msgid "Updating an unborn branch with changes added to the index."
-msgstr ""
-"Đang cập nhật một nhánh chưa được sinh ra với các thay đổi được thêm vào "
-"bảng mục lục."
+#: builtin/rebase.c:476
+msgid "move commits that begin with squash!/fixup!"
+msgstr "di chuyển các lần chuyển giao bắt đầu bằng squash!/fixup!"
+
+#: builtin/rebase.c:477
+msgid "sign commits"
+msgstr "ký các lần chuyển giao"
+
+#: builtin/rebase.c:479 builtin/rebase.c:1455
+msgid "display a diffstat of what changed upstream"
+msgstr "hiển thị một diffstat của những thay đổi thượng nguồn"
 
-#: builtin/pull.c:885
-msgid "pull with rebase"
-msgstr "pull với rebase"
+#: builtin/rebase.c:481
+msgid "continue rebase"
+msgstr "tiếp tục cải tổ"
 
-#: builtin/pull.c:886
-msgid "please commit or stash them."
-msgstr "xin hãy chuyển giao hoặc tạm cất (stash) chúng."
+#: builtin/rebase.c:483
+msgid "skip commit"
+msgstr "bỏ qua lần chuyển giao"
+
+#: builtin/rebase.c:484
+msgid "edit the todo list"
+msgstr "sửa danh sách cần làm"
+
+#: builtin/rebase.c:486
+msgid "show the current patch"
+msgstr "hiển thị miếng vá hiện hành"
 
-#: builtin/pull.c:911
-#, c-format
-msgid ""
-"fetch updated the current branch head.\n"
-"fast-forwarding your working tree from\n"
-"commit %s."
-msgstr ""
-"fetch đã cập nhật head nhánh hiện tại.\n"
-"đang chuyển-tiếp-nhanh cây làm việc của bạn từ\n"
-"lần chuyển giaot %s."
+#: builtin/rebase.c:489
+msgid "shorten commit ids in the todo list"
+msgstr "rút ngắn mã chuyển giao trong danh sách cần làm"
 
-#: builtin/pull.c:916
-#, c-format
-msgid ""
-"Cannot fast-forward your working tree.\n"
-"After making sure that you saved anything precious from\n"
-"$ git diff %s\n"
-"output, run\n"
-"$ git reset --hard\n"
-"to recover."
-msgstr ""
-"Không thể chuyển tiếp nhanh cây làm việc của bạn.\n"
-"Sau khi chắc chắn rằng mình đã ghi lại mọi thứ\n"
-"quý báu từ kết xuất của lệnh\n"
-"$ git diff %s\n"
-"chạy\n"
-"$ git reset --hard\n"
-"để khôi phục lại."
+#: builtin/rebase.c:491
+msgid "expand commit ids in the todo list"
+msgstr "khai triển mã chuyển giao trong danh sách cần làm"
 
-#: builtin/pull.c:931
-msgid "Cannot merge multiple branches into empty head."
-msgstr "Không thể hòa trộn nhiều nhánh vào trong một head trống rỗng."
+#: builtin/rebase.c:493
+msgid "check the todo list"
+msgstr "kiểm tra danh sách cần làm"
 
-#: builtin/pull.c:935
-msgid "Cannot rebase onto multiple branches."
-msgstr "Không thể thực hiện lệnh rebase (cải tổ) trên nhiều nhánh."
+#: builtin/rebase.c:495
+msgid "rearrange fixup/squash lines"
+msgstr "sắp xếp lại các dòng fixup/squash"
 
-#: builtin/pull.c:942
-msgid "cannot rebase with locally recorded submodule modifications"
-msgstr ""
-"không thể cải tổ với các thay đổi mô-đun-con được ghi lại một cách cục bộ"
+#: builtin/rebase.c:497
+msgid "insert exec commands in todo list"
+msgstr "chèn các lệnh thực thi trong danh sách cần làm"
 
-#: builtin/push.c:19
-msgid "git push [<options>] [<repository> [<refspec>...]]"
-msgstr "git push [<các-tùy-chọn>] [<kho-chứa> [<refspec>…]]"
+#: builtin/rebase.c:498
+msgid "onto"
+msgstr "lên trên"
+
+#: builtin/rebase.c:501
+msgid "restrict-revision"
+msgstr "điểm-xét-duyệt-hạn-chế"
+
+#: builtin/rebase.c:501
+msgid "restrict revision"
+msgstr "điểm xét duyệt hạn chế"
+
+#: builtin/rebase.c:503
+msgid "squash-onto"
+msgstr "squash-lên-trên"
+
+#: builtin/rebase.c:504
+msgid "squash onto"
+msgstr "squash lên trên"
+
+#: builtin/rebase.c:506
+msgid "the upstream commit"
+msgstr "lần chuyển giao thượng nguồn"
+
+#: builtin/rebase.c:508
+msgid "head-name"
+msgstr "tên-đầu"
+
+#: builtin/rebase.c:508
+msgid "head name"
+msgstr "tên đầu"
+
+#: builtin/rebase.c:513
+msgid "rebase strategy"
+msgstr "chiến lược cải tổ"
+
+#: builtin/rebase.c:514
+msgid "strategy-opts"
+msgstr "tùy-chọn-chiến-lược"
+
+#: builtin/rebase.c:515
+msgid "strategy options"
+msgstr "các tùy chọn chiến lược"
+
+#: builtin/rebase.c:516
+msgid "switch-to"
+msgstr "chuyển-đến"
+
+#: builtin/rebase.c:517
+msgid "the branch or commit to checkout"
+msgstr "nhánh hay lần chuyển giao lần lấy ra"
+
+#: builtin/rebase.c:518
+msgid "onto-name"
+msgstr "onto-name"
+
+#: builtin/rebase.c:518
+msgid "onto name"
+msgstr "tên lên trên"
 
-#: builtin/push.c:111
-msgid "tag shorthand without <tag>"
-msgstr "dùng tốc ký thẻ không có <thẻ>"
+#: builtin/rebase.c:519
+msgid "cmd"
+msgstr "lệnh"
 
-#: builtin/push.c:121
-msgid "--delete only accepts plain target ref names"
-msgstr "--delete chỉ chấp nhận các tên tham chiếu dạng thường"
+#: builtin/rebase.c:519
+msgid "the command to run"
+msgstr "lệnh muốn chạy"
+
+#: builtin/rebase.c:522 builtin/rebase.c:1540
+msgid "automatically re-schedule any `exec` that fails"
+msgstr "lập lịch lại một cách tự động bất kỳ “exec“ bị lỗi"
 
-#: builtin/push.c:165
-msgid ""
-"\n"
-"To choose either option permanently, see push.default in 'git help config'."
-msgstr ""
-"\n"
-"Để chọn mỗi tùy chọn một cách cố định, xem push.default trong “git help "
-"config”."
+#: builtin/rebase.c:540
+msgid "--[no-]rebase-cousins has no effect without --rebase-merges"
+msgstr "--[no-]rebase-cousins không có tác dụng khi không có --rebase-merges"
 
-#: builtin/push.c:168
+#: builtin/rebase.c:556
 #, c-format
-msgid ""
-"The upstream branch of your current branch does not match\n"
-"the name of your current branch.  To push to the upstream branch\n"
-"on the remote, use\n"
-"\n"
-"    git push %s HEAD:%s\n"
-"\n"
-"To push to the branch of the same name on the remote, use\n"
-"\n"
-"    git push %s %s\n"
-"%s"
-msgstr ""
-"Nhánh thượng nguồn của nhánh hiện tại của bạn không khớp\n"
-"với tên của nhánh hiện tại của bạn.  Để đẩy lên đến nhánh thượng nguồn\n"
-"trên máy chủ, sử dụng\n"
-"\n"
-"    git push %s HEAD:%s\n"
-"\n"
-"Để push tới nhánh cùng tên trên máy chủ, sử dụng\n"
-"\n"
-"    git push %s %s\n"
-"%s"
+msgid "%s requires an interactive rebase"
+msgstr "%s cần một cải tổ kiểu tương tác"
 
-#: builtin/push.c:183
+#: builtin/rebase.c:608
 #, c-format
-msgid ""
-"You are not currently on a branch.\n"
-"To push the history leading to the current (detached HEAD)\n"
-"state now, use\n"
-"\n"
-"    git push %s HEAD:<name-of-remote-branch>\n"
-msgstr ""
-"Bạn hiện nay không ở một nhánh.\n"
-"Để đẩy lịch sử lên trên trạng thái hiện hành (HEAD đã bị tách rời)\n"
-"ngay bây giờ, sử dụng\n"
-"\n"
-"    git push %s HEAD:<tên-của-nhánh-máy-chủ>\n"
+msgid "could not get 'onto': '%s'"
+msgstr "không thể đặt lấy “onto”: “%s”"
 
-#: builtin/push.c:197
+#: builtin/rebase.c:623
 #, c-format
-msgid ""
-"The current branch %s has no upstream branch.\n"
-"To push the current branch and set the remote as upstream, use\n"
-"\n"
-"    git push --set-upstream %s %s\n"
-msgstr ""
-"Nhánh hiện tại %s không có nhánh thượng nguồn nào.\n"
-"Để push (đẩy lên) nhánh hiện tại và đặt máy chủ này làm thượng nguồn "
-"(upstream), sử dụng\n"
-"\n"
-"    git push --set-upstream %s %s\n"
+msgid "invalid orig-head: '%s'"
+msgstr "orig-head không hợp lệ: “%s”"
 
-#: builtin/push.c:205
+#: builtin/rebase.c:648
 #, c-format
-msgid "The current branch %s has multiple upstream branches, refusing to push."
-msgstr "Nhánh hiện tại %s có nhiều nhánh thượng nguồn, từ chối push."
+msgid "ignoring invalid allow_rerere_autoupdate: '%s'"
+msgstr "đang bỏ qua allow_rerere_autoupdate không hợp lệ: “%s”"
 
-#: builtin/push.c:208
+#: builtin/rebase.c:724
 #, c-format
-msgid ""
-"You are pushing to remote '%s', which is not the upstream of\n"
-"your current branch '%s', without telling me what to push\n"
-"to update which remote branch."
-msgstr ""
-"Bạn đang push (đẩy lên) máy chủ “%s”, mà nó không phải là thượng nguồn "
-"(upstream) của\n"
-"nhánh hiện tại “%s” của bạn, mà không báo cho tôi biết là cái gì được push\n"
-"để cập nhật nhánh máy chủ nào."
-
-#: builtin/push.c:267
-msgid ""
-"You didn't specify any refspecs to push, and push.default is \"nothing\"."
-msgstr ""
-"Bạn đã không chỉ ra một refspecs nào để đẩy lên, và push.default là \"không "
-"là gì cả\"."
+msgid "Could not read '%s'"
+msgstr "Không thể đọc “%s”"
 
-#: builtin/push.c:274
-msgid ""
-"Updates were rejected because the tip of your current branch is behind\n"
-"its remote counterpart. Integrate the remote changes (e.g.\n"
-"'git pull ...') before pushing again.\n"
-"See the 'Note about fast-forwards' in 'git push --help' for details."
-msgstr ""
-"Việc cập nhật bị từ chối bởi vì đầu mút của nhánh hiện tại của bạn nằm đằng\n"
-"sau bộ phận tương ứng của máy chủ. Hòa trộn với các thay đổi từ máy chủ\n"
-"(v.d. \"git pull …\") trước khi đẩy lên lần nữa.\n"
-"Xem “Note about fast-forwards” trong “git push --help” để có thông tin chi "
-"tiết."
+#: builtin/rebase.c:742
+#, c-format
+msgid "Cannot store %s"
+msgstr "Không thể lưu “%s”"
 
-#: builtin/push.c:280
-msgid ""
-"Updates were rejected because a pushed branch tip is behind its remote\n"
-"counterpart. Check out this branch and integrate the remote changes\n"
-"(e.g. 'git pull ...') before pushing again.\n"
-"See the 'Note about fast-forwards' in 'git push --help' for details."
-msgstr ""
-"Việc cập nhật bị từ chối bởi vì đầu mút của nhánh đã đẩy lên nằm đằng sau "
-"bộ\n"
-"phận tương ứng của máy chủ. Checkou nhánh này và hòa trộn với các thay đổi\n"
-"từ máy chủ (v.d. “git pull …”) trước khi lại push lần nữa.\n"
-"Xem “Note about fast-forwards” trong “git push --help” để có thông tin chi "
-"tiết."
+#: builtin/rebase.c:849
+msgid "could not determine HEAD revision"
+msgstr "không thể dò tìm điểm xét duyệt HEAD"
 
-#: builtin/push.c:286
+#: builtin/rebase.c:972 git-rebase--preserve-merges.sh:81
 msgid ""
-"Updates were rejected because the remote contains work that you do\n"
-"not have locally. This is usually caused by another repository pushing\n"
-"to the same ref. You may want to first integrate the remote changes\n"
-"(e.g., 'git pull ...') before pushing again.\n"
-"See the 'Note about fast-forwards' in 'git push --help' for details."
+"Resolve all conflicts manually, mark them as resolved with\n"
+"\"git add/rm <conflicted_files>\", then run \"git rebase --continue\".\n"
+"You can instead skip this commit: run \"git rebase --skip\".\n"
+"To abort and get back to the state before \"git rebase\", run \"git rebase --"
+"abort\"."
 msgstr ""
-"Việc cập nhật bị từ chối bởi vì máy chủ có chứa công việc mà bạn không\n"
-"có ở máy nội bộ của mình. Lỗi này thường có nguyên nhân bởi kho khác đẩy\n"
-"dữ liệu lên cùng một tham chiếu. Bạn có lẽ muốn hòa trộn với các thay đổi\n"
-"từ máy chủ (v.d. “git pull…”) trước khi lại push lần nữa.\n"
-"Xem “Note about fast-forwards” trong “git push --help” để có thông tin chi "
-"tiết."
-
-#: builtin/push.c:293
-msgid "Updates were rejected because the tag already exists in the remote."
-msgstr "Việc cập nhật bị từ chối bởi vì thẻ đã sẵn có từ trước trên máy chủ."
+"Giải quyết vấn đề này thủ công, hãy đanh dấu chúng đã được giải quyết bằng\n"
+"hãy chạy lệnh \"git add/rm <các_tập_tin_xung_đột>\", sau đó chạy \"git "
+"rebase --continue\".\n"
+"Bạn có thể bỏ qua miếng vá, chạy \"git rebase --skip\".\n"
+"Để bãi bỏ và quay trở lại trạng thái trước \"git rebase\", chạy \"git rebase "
+"--abort\"."
 
-#: builtin/push.c:296
+#: builtin/rebase.c:1060
+#, c-format
 msgid ""
-"You cannot update a remote ref that points at a non-commit object,\n"
-"or update a remote ref to make it point at a non-commit object,\n"
-"without using the '--force' option.\n"
+"\n"
+"git encountered an error while preparing the patches to replay\n"
+"these revisions:\n"
+"\n"
+"    %s\n"
+"\n"
+"As a result, git cannot rebase them."
 msgstr ""
-"Không thể cập nhật một tham chiếu trên máy chủ mà nó chỉ đến đối tượng "
-"không\n"
-"phải là lần chuyển giao, hoặc cập nhật một tham chiếu máy chủ để nó chỉ đến "
-"đối tượng\n"
-"không phải chuyển giao, mà không sử dụng tùy chọn “--force”.\n"
-
-#: builtin/push.c:357
-#, c-format
-msgid "Pushing to %s\n"
-msgstr "Đang đẩy lên %s\n"
-
-#: builtin/push.c:361
-#, c-format
-msgid "failed to push some refs to '%s'"
-msgstr "gặp lỗi khi đẩy tới một số tham chiếu đến “%s”"
+"\n"
+"git chạm trán một lỗi trong khi đang chuẩn bị các miếng vá để diễn lại\n"
+"những điểm xét duyệt này:\n"
+"\n"
+"    %s\n"
+"\n"
+"Kết quả là git không thể cải tổ lại chúng."
 
-#: builtin/push.c:395
+#: builtin/rebase.c:1367
 #, c-format
-msgid "bad repository '%s'"
-msgstr "repository (kho) sai “%s”"
-
-#: builtin/push.c:396
 msgid ""
-"No configured push destination.\n"
-"Either specify the URL from the command-line or configure a remote "
-"repository using\n"
+"%s\n"
+"Please specify which branch you want to rebase against.\n"
+"See git-rebase(1) for details.\n"
 "\n"
-"    git remote add <name> <url>\n"
+"    git rebase '<branch>'\n"
+"\n"
+msgstr ""
+"%s\n"
+"Vui lòng chỉ định nhánh nào bạn muốn cải tổ dựa vào.\n"
+"Xem git-rebase(1) để biết thêm chi tiết.\n"
+"\n"
+"    git rebase “<nhánh>”\n"
+"\n"
+
+#: builtin/rebase.c:1383
+#, c-format
+msgid ""
+"If you wish to set tracking information for this branch you can do so with:\n"
 "\n"
-"and then push using the remote name\n"
+"    git branch --set-upstream-to=%s/<branch> %s\n"
 "\n"
-"    git push <name>\n"
 msgstr ""
-"Chưa cấu hình đích để đẩy lên.\n"
-"Hoặc là chỉ ra URL từ dòng lệnh hoặc là cấu hình một kho máy chủ sử dụng\n"
-"\n"
-"    git remote add <tên> <url>\n"
+"Nếu bạn muốn theo dõi thông tin cho nhánh này bạn có thể thực hiện bằng "
+"lệnh:\n"
 "\n"
-"và sau đó đẩy lên sử dụng tên máy chủ\n"
+"    git branch --set-upstream-to=%s/<nhánh> %s\n"
 "\n"
-"    git push <tên>\n"
 
-#: builtin/push.c:551
-msgid "repository"
-msgstr "kho"
+#: builtin/rebase.c:1413
+msgid "exec commands cannot contain newlines"
+msgstr "các lệnh thực thi không thể chứa các ký tự dòng mới"
 
-#: builtin/push.c:552 builtin/send-pack.c:164
-msgid "push all refs"
-msgstr "đẩy tất cả các tham chiếu"
+#: builtin/rebase.c:1417
+msgid "empty exec command"
+msgstr "lệnh thực thi trống rỗng"
 
-#: builtin/push.c:553 builtin/send-pack.c:166
-msgid "mirror all refs"
-msgstr "mirror tất cả các tham chiếu"
+#: builtin/rebase.c:1446
+msgid "rebase onto given branch instead of upstream"
+msgstr "cải tổ vào nhánh đã cho thay cho thượng nguồn"
 
-#: builtin/push.c:555
-msgid "delete refs"
-msgstr "xóa các tham chiếu"
+#: builtin/rebase.c:1448
+msgid "use the merge-base of upstream and branch as the current base"
+msgstr ""
+"sử dụng các cơ sở hòa trộn của thượng nguồn và nhánh như là cơ sở hiện tại"
 
-#: builtin/push.c:556
-msgid "push tags (can't be used with --all or --mirror)"
-msgstr "đẩy các thẻ (không dùng cùng với --all hay --mirror)"
+#: builtin/rebase.c:1450
+msgid "allow pre-rebase hook to run"
+msgstr "cho phép móc (hook) pre-rebase được chạy"
 
-#: builtin/push.c:559 builtin/send-pack.c:167
-msgid "force updates"
-msgstr "ép buộc cập nhật"
+#: builtin/rebase.c:1452
+msgid "be quiet. implies --no-stat"
+msgstr "hãy im lặng. ý là --no-stat"
 
-#: builtin/push.c:561 builtin/send-pack.c:181
-msgid "refname>:<expect"
-msgstr "tên-tham-chiếu>:<cần"
+#: builtin/rebase.c:1458
+msgid "do not show diffstat of what changed upstream"
+msgstr "đừng hiển thị diffstat của những thay đổi thượng nguồn"
 
-#: builtin/push.c:562 builtin/send-pack.c:182
-msgid "require old value of ref to be at this value"
-msgstr "yêu cầu giá-trị cũ của tham chiếu thì là giá-trị này"
+#: builtin/rebase.c:1461
+msgid "add a Signed-off-by: line to each commit"
+msgstr "thêm dòng Signed-off-by: cho từng lần chuyển giao"
 
-#: builtin/push.c:565
-msgid "control recursive pushing of submodules"
-msgstr "điều khiển việc đẩy lên (push) đệ qui của mô-đun-con"
+#: builtin/rebase.c:1464
+msgid "make committer date match author date"
+msgstr "làm ngày tháng chuyển giao khớp với ngày của tác giả"
 
-#: builtin/push.c:567 builtin/send-pack.c:175
-msgid "use thin pack"
-msgstr "tạo gói nhẹ"
+#: builtin/rebase.c:1466
+msgid "ignore author date and use current date"
+msgstr "bỏ qua ngày tác giả và sử dụng ngày tháng hiện tại"
 
-#: builtin/push.c:568 builtin/push.c:569 builtin/send-pack.c:161
-#: builtin/send-pack.c:162
-msgid "receive pack program"
-msgstr "chương trình nhận gói"
+#: builtin/rebase.c:1468
+msgid "synonym of --reset-author-date"
+msgstr "đồng nghĩa với --reset-author-date"
 
-#: builtin/push.c:570
-msgid "set upstream for git pull/status"
-msgstr "đặt thượng nguồn cho git pull/status"
+#: builtin/rebase.c:1470 builtin/rebase.c:1474
+msgid "passed to 'git apply'"
+msgstr "chuyển cho “git apply”"
 
-#: builtin/push.c:573
-msgid "prune locally removed refs"
-msgstr "xén tỉa những tham chiếu bị gỡ bỏ"
+#: builtin/rebase.c:1472
+msgid "ignore changes in whitespace"
+msgstr "lờ đi sự thay đổi do khoảng trắng gây ra"
 
-#: builtin/push.c:575
-msgid "bypass pre-push hook"
-msgstr "vòng qua móc tiền-đẩy (pre-push)"
+#: builtin/rebase.c:1476 builtin/rebase.c:1479
+msgid "cherry-pick all commits, even if unchanged"
+msgstr ""
+"cherry-pick tất cả các lần chuyển giao, ngay cả khi không có thay đổi gì"
 
-#: builtin/push.c:576
-msgid "push missing but relevant tags"
-msgstr "push phần bị thiếu nhưng các thẻ lại thích hợp"
+#: builtin/rebase.c:1481
+msgid "continue"
+msgstr "tiếp tục"
 
-#: builtin/push.c:579 builtin/send-pack.c:169
-msgid "GPG sign the push"
-msgstr "ký lần đẩy dùng GPG"
+#: builtin/rebase.c:1484
+msgid "skip current patch and continue"
+msgstr "bỏ qua miếng vá hiện hành và tiếp tục"
 
-#: builtin/push.c:581 builtin/send-pack.c:176
-msgid "request atomic transaction on remote side"
-msgstr "yêu cầu giao dịch hạt nhân bên phía máy chủ"
+#: builtin/rebase.c:1486
+msgid "abort and check out the original branch"
+msgstr "bãi bỏ và lấy ra nhánh nguyên thủy"
 
-#: builtin/push.c:599
-msgid "--delete is incompatible with --all, --mirror and --tags"
-msgstr "--delete là xung khắc với các tùy chọn --all, --mirror và --tags"
+#: builtin/rebase.c:1489
+msgid "abort but keep HEAD where it is"
+msgstr "bãi bỏ nhưng vẫn vẫn giữ HEAD chỉ đến nó"
 
-#: builtin/push.c:601
-msgid "--delete doesn't make sense without any refs"
-msgstr "--delete không hợp lý nếu không có bất kỳ tham chiếu nào"
+#: builtin/rebase.c:1490
+msgid "edit the todo list during an interactive rebase"
+msgstr "sửa danh sách cần làm trong quá trình “rebase” (cải tổ) tương tác"
 
-#: builtin/push.c:604
-msgid "--all and --tags are incompatible"
-msgstr "--all và --tags xung khắc nhau"
+#: builtin/rebase.c:1493
+msgid "show the patch file being applied or merged"
+msgstr "hiển thị miếng vá đã được áp dụng hay hòa trộn"
 
-#: builtin/push.c:606
-msgid "--all can't be combined with refspecs"
-msgstr "--all không thể được tổ hợp cùng với đặc tả đường dẫn"
+#: builtin/rebase.c:1496
+msgid "use merging strategies to rebase"
+msgstr "dùng chiến lược hòa trộn để cải tổ"
 
-#: builtin/push.c:610
-msgid "--mirror and --tags are incompatible"
-msgstr "--mirror và --tags xung khắc nhau"
+#: builtin/rebase.c:1500
+msgid "let the user edit the list of commits to rebase"
+msgstr "để người dùng sửa danh sách các lần chuyển giao muốn cải tổ"
 
-#: builtin/push.c:612
-msgid "--mirror can't be combined with refspecs"
-msgstr "--mirror không thể được tổ hợp cùng với đặc tả đường dẫn"
+#: builtin/rebase.c:1504
+msgid "(DEPRECATED) try to recreate merges instead of ignoring them"
+msgstr "(ĐÃ LẠC HẬU) hay thử tạo lại các hòa trộn thay vì bỏ qua chúng"
 
-#: builtin/push.c:615
-msgid "--all and --mirror are incompatible"
-msgstr "--all và --mirror xung khắc nhau"
+#: builtin/rebase.c:1509
+msgid "preserve empty commits during rebase"
+msgstr "ngăn cấm các lần chuyển giao trống rỗng trong suốt quá trình cải tổ"
 
-#: builtin/push.c:634
-msgid "push options must not have new line characters"
-msgstr "các tùy chọn push phải không có ký tự dòng mới"
+#: builtin/rebase.c:1511
+msgid "move commits that begin with squash!/fixup! under -i"
+msgstr "di chuyển các lần chuyển giao mà bắt đầu bằng squash!/fixup! dưới -i"
+
+#: builtin/rebase.c:1517
+msgid "automatically stash/stash pop before and after"
+msgstr "tự động stash/stash pop trước và sau"
+
+#: builtin/rebase.c:1519
+msgid "add exec lines after each commit of the editable list"
+msgstr "thêm các dòng thực thi sau từng lần chuyển giao của danh sách sửa được"
+
+#: builtin/rebase.c:1523
+msgid "allow rebasing commits with empty messages"
+msgstr "chấp nhận cải tổ các chuyển giao mà không ghi chú gì"
+
+#: builtin/rebase.c:1526
+msgid "try to rebase merges instead of skipping them"
+msgstr "cố thử cải tổ các hòa trộn thay vì bỏ qua chúng"
+
+#: builtin/rebase.c:1529
+msgid "use 'merge-base --fork-point' to refine upstream"
+msgstr "dùng “merge-base --fork-point” để định nghĩa lại thượng nguồn"
+
+#: builtin/rebase.c:1531
+msgid "use the given merge strategy"
+msgstr "dùng chiến lược hòa trộn đã cho"
+
+#: builtin/rebase.c:1533 builtin/revert.c:115
+msgid "option"
+msgstr "tùy chọn"
+
+#: builtin/rebase.c:1534
+msgid "pass the argument through to the merge strategy"
+msgstr "chuyển thao số đến chiến lược hòa trộn"
+
+#: builtin/rebase.c:1537
+msgid "rebase all reachable commits up to the root(s)"
+msgstr "cải tổ tất các các lần chuyển giao cho đến root"
 
-#: builtin/read-tree.c:40
+#: builtin/rebase.c:1554
 msgid ""
-"git read-tree [(-m [--trivial] [--aggressive] | --reset | --prefix=<prefix>) "
-"[-u [--exclude-per-directory=<gitignore>] | -i]] [--no-sparse-checkout] [--"
-"index-output=<file>] (--empty | <tree-ish1> [<tree-ish2> [<tree-ish3>]])"
+"the rebase.useBuiltin support has been removed!\n"
+"See its entry in 'git help config' for details."
 msgstr ""
-"git read-tree [(-m [--trivial] [--aggressive] | --reset | --prefix=<tiền-"
-"tố>) [-u [--exclude-per-directory=<gitignore>] | -i]] [--no-sparse-checkout] "
-"[--index-output=<tập-tin>] (--empty | <tree-ish1> [<tree-ish2> [<tree-"
-"ish3>]])"
+"việc hỗ trợ rebase.useBuiltin đã bị xóa!\n"
+"Xem mục tin của nó trong “ git help config” để biết chi tiết."
 
-#: builtin/read-tree.c:120
-msgid "write resulting index to <file>"
-msgstr "ghi mục lục kết quả vào <tập-tin>"
+#: builtin/rebase.c:1560
+msgid "It looks like 'git am' is in progress. Cannot rebase."
+msgstr ""
+"Hình như đang trong quá trình thực hiện lệnh “git-am”. Không thể rebase."
 
-#: builtin/read-tree.c:123
-msgid "only empty the index"
-msgstr "chỉ với bảng mục lục trống rỗng"
+#: builtin/rebase.c:1601
+msgid ""
+"git rebase --preserve-merges is deprecated. Use --rebase-merges instead."
+msgstr ""
+"git rebase --preserve-merges đã lạc hậu. Hãy dùng --rebase-merges để thay "
+"thế."
 
-#: builtin/read-tree.c:125
-msgid "Merging"
-msgstr "Hòa trộn"
+#: builtin/rebase.c:1606
+msgid "cannot combine '--keep-base' with '--onto'"
+msgstr "không thể kết hợp “--keep-base” với “--onto”"
+
+#: builtin/rebase.c:1608
+msgid "cannot combine '--keep-base' with '--root'"
+msgstr "không thể kết hợp “--keep-base” với “--root”"
 
-#: builtin/read-tree.c:127
-msgid "perform a merge in addition to a read"
-msgstr "thực hiện một hòa trộn thêm vào việc đọc"
+#: builtin/rebase.c:1612
+msgid "No rebase in progress?"
+msgstr "Không có tiến trình rebase nào phải không?"
 
-#: builtin/read-tree.c:129
-msgid "3-way merge if no file level merging required"
+#: builtin/rebase.c:1616
+msgid "The --edit-todo action can only be used during interactive rebase."
 msgstr ""
-"hòa trộn kiểu “3-way” nếu không có tập tin mức hòa trộn nào được yêu cầu "
+"Hành động “--edit-todo” chỉ có thể dùng trong quá trình “rebase” (sửa lịch "
+"sử) tương tác."
 
-#: builtin/read-tree.c:131
-msgid "3-way merge in presence of adds and removes"
-msgstr "hòa trộn 3-way trong sự hiện diện của “adds” và “removes”"
+#: builtin/rebase.c:1639
+msgid "Cannot read HEAD"
+msgstr "Không thể đọc HEAD"
 
-#: builtin/read-tree.c:133
-msgid "same as -m, but discard unmerged entries"
-msgstr "giống với -m, nhưng bỏ qua các mục chưa được hòa trộn"
+#: builtin/rebase.c:1651
+msgid ""
+"You must edit all merge conflicts and then\n"
+"mark them as resolved using git add"
+msgstr ""
+"Bạn phải sửa tất cả các lần hòa trộn xung đột và sau\n"
+"đó đánh dấu chúng là cần xử lý sử dụng lệnh git add"
 
-#: builtin/read-tree.c:134
-msgid "<subdirectory>/"
-msgstr "<thư-mục-con>/"
+#: builtin/rebase.c:1670
+msgid "could not discard worktree changes"
+msgstr "không thể loại bỏ các thay đổi cây-làm-việc"
 
-#: builtin/read-tree.c:135
-msgid "read the tree into the index under <subdirectory>/"
-msgstr "đọc cây vào trong bảng mục lục dưới <thư_mục_con>/"
+#: builtin/rebase.c:1689
+#, c-format
+msgid "could not move back to %s"
+msgstr "không thể quay trở lại %s"
 
-#: builtin/read-tree.c:138
-msgid "update working tree with merge result"
-msgstr "cập nhật cây làm việc với kết quả hòa trộn"
+#: builtin/rebase.c:1734
+#, c-format
+msgid ""
+"It seems that there is already a %s directory, and\n"
+"I wonder if you are in the middle of another rebase.  If that is the\n"
+"case, please try\n"
+"\t%s\n"
+"If that is not the case, please\n"
+"\t%s\n"
+"and run me again.  I am stopping in case you still have something\n"
+"valuable there.\n"
+msgstr ""
+"Hình như là ở đây sẵn có một thư mục %s, và\n"
+"Tôi tự hỏi có phải bạn đang ở giữa một lệnh rebase khác. Nếu đúng là\n"
+"như vậy, xin hãy thử\n"
+"\t%s\n"
+"Nếu không phải thế, hãy thử\n"
+"\t%s\n"
+"và chạy TÔI lần nữa. TÔI dừng lại trong trường hợp bạn vẫn\n"
+"có một số thứ quý giá ở đây.\n"
 
-#: builtin/read-tree.c:140
-msgid "gitignore"
-msgstr "gitignore"
+#: builtin/rebase.c:1757
+msgid "switch `C' expects a numerical value"
+msgstr "tùy chọn “%c” cần một giá trị bằng số"
 
-#: builtin/read-tree.c:141
-msgid "allow explicitly ignored files to be overwritten"
-msgstr "cho phép các tập tin rõ ràng bị lờ đi được ghi đè"
+#: builtin/rebase.c:1798
+#, c-format
+msgid "Unknown mode: %s"
+msgstr "Không hiểu chế độ: %s"
 
-#: builtin/read-tree.c:144
-msgid "don't check the working tree after merging"
-msgstr "không kiểm tra cây làm việc sau hòa trộn"
+#: builtin/rebase.c:1820
+msgid "--strategy requires --merge or --interactive"
+msgstr "--strategy cần --merge hay --interactive"
 
-#: builtin/read-tree.c:145
-msgid "don't update the index or the work tree"
-msgstr "không cập nhật bảng mục lục hay cây làm việc"
+#: builtin/rebase.c:1860
+msgid "--reschedule-failed-exec requires --exec or --interactive"
+msgstr "--reschedule-failed-exec cần --exec hay --interactive"
 
-#: builtin/read-tree.c:147
-msgid "skip applying sparse checkout filter"
-msgstr "bỏ qua áp dụng bộ lọc lấy ra (checkout) thưa thớt"
+#: builtin/rebase.c:1872
+msgid "cannot combine am options with either interactive or merge options"
+msgstr ""
+"không thể tổ hợp các tùy chọn am với các tùy chọn tương tác hay hòa trộn"
 
-#: builtin/read-tree.c:149
-msgid "debug unpack-trees"
-msgstr "gỡ lỗi “unpack-trees”"
+#: builtin/rebase.c:1891
+msgid "cannot combine '--preserve-merges' with '--rebase-merges'"
+msgstr "không thể kết hợp “--preserve-merges” với “--rebase-merges”"
 
-#: builtin/rebase--helper.c:8
-msgid "git rebase--helper [<options>]"
-msgstr "git rebase--helper [<các-tùy-chọn>]"
+#: builtin/rebase.c:1895
+msgid ""
+"error: cannot combine '--preserve-merges' with '--reschedule-failed-exec'"
+msgstr "không thể kết hợp “--preserve-merges” với “--reschedule-failed-exec”"
 
-#: builtin/rebase--helper.c:24
-msgid "keep empty commits"
-msgstr "giữ lại các lần chuyển giao rỗng"
+#: builtin/rebase.c:1919
+#, c-format
+msgid "invalid upstream '%s'"
+msgstr "thượng nguồn không hợp lệ “%s”"
 
-#: builtin/rebase--helper.c:26 builtin/revert.c:123
-msgid "allow commits with empty messages"
-msgstr "chấp nhận chuyển giao mà không ghi chú gì"
+#: builtin/rebase.c:1925
+msgid "Could not create new root commit"
+msgstr "Không thể tạo lần chuyển giao gốc mới"
 
-#: builtin/rebase--helper.c:27
-msgid "rebase merge commits"
-msgstr "cải tổ các lần chuyển giao hòa trộn"
+#: builtin/rebase.c:1951
+#, c-format
+msgid "'%s': need exactly one merge base with branch"
+msgstr "“%s”: cần chính xác một cơ sở hòa trộn với nhánh"
 
-#: builtin/rebase--helper.c:29
-msgid "keep original branch points of cousins"
-msgstr "giữ các điểm nhánh nguyên bản của các anh em họ"
+#: builtin/rebase.c:1954
+#, c-format
+msgid "'%s': need exactly one merge base"
+msgstr "“%s”: cần chính xác một cơ sở hòa trộn"
 
-#: builtin/rebase--helper.c:30
-msgid "continue rebase"
-msgstr "tiếp tục cải tổ"
+#: builtin/rebase.c:1962
+#, c-format
+msgid "Does not point to a valid commit '%s'"
+msgstr "Không chỉ đến một lần chuyển giao không hợp lệ “%s”"
 
-#: builtin/rebase--helper.c:32
-msgid "abort rebase"
-msgstr "bãi bỏ việc cải tổ"
-
-#: builtin/rebase--helper.c:35
-msgid "make rebase script"
-msgstr "tạo văn lệnh rebase"
+#: builtin/rebase.c:1987
+#, c-format
+msgid "fatal: no such branch/commit '%s'"
+msgstr "nghiêm trọng: không có nhánh/lần chuyển giao “%s” như thế"
 
-#: builtin/rebase--helper.c:37
-msgid "shorten commit ids in the todo list"
-msgstr "rút ngắn mã chuyển giao trong danh sách cần làm"
+#: builtin/rebase.c:1995 builtin/submodule--helper.c:40
+#: builtin/submodule--helper.c:1961
+#, c-format
+msgid "No such ref: %s"
+msgstr "Không có tham chiếu nào như thế: %s"
 
-#: builtin/rebase--helper.c:39
-msgid "expand commit ids in the todo list"
-msgstr "khai triển mã chuyển giao trong danh sách cần làm"
+#: builtin/rebase.c:2006
+msgid "Could not resolve HEAD to a revision"
+msgstr "Không thể phân giải lần chuyển giao HEAD đến một điểm xét duyệt"
 
-#: builtin/rebase--helper.c:41
-msgid "check the todo list"
-msgstr "kiểm tra danh sách cần làm"
+#: builtin/rebase.c:2044
+msgid "Cannot autostash"
+msgstr "Không thể autostash"
 
-#: builtin/rebase--helper.c:43
-msgid "skip unnecessary picks"
-msgstr "bỏ qua các lệnh cậy (pick) không cần thiết"
+#: builtin/rebase.c:2047
+#, c-format
+msgid "Unexpected stash response: '%s'"
+msgstr "Gặp đáp ứng stash không cần: “%s”"
 
-#: builtin/rebase--helper.c:45
-msgid "rearrange fixup/squash lines"
-msgstr "sắp xếp lại các dòng fixup/squash"
+#: builtin/rebase.c:2053
+#, c-format
+msgid "Could not create directory for '%s'"
+msgstr "Không thể tạo thư mục cho “%s”"
 
-#: builtin/rebase--helper.c:47
-msgid "insert exec commands in todo list"
-msgstr "chèn các lệnh thực thi trong danh sách cần làm"
+#: builtin/rebase.c:2056
+#, c-format
+msgid "Created autostash: %s\n"
+msgstr "Đã tạo autostash: %s\n"
 
-#: builtin/rebase--helper.c:68
-msgid "--[no-]rebase-cousins has no effect without --rebase-merges"
-msgstr "--[no-]rebase-cousins không có tác dụng khi không có --rebase-merges"
+#: builtin/rebase.c:2059
+msgid "could not reset --hard"
+msgstr "không thể reset --hard"
+
+#: builtin/rebase.c:2068
+msgid "Please commit or stash them."
+msgstr "Xin hãy chuyển giao hoặc tạm cất (stash) chúng."
+
+#: builtin/rebase.c:2095
+#, c-format
+msgid "could not parse '%s'"
+msgstr "không thể phân tích cú pháp “%s”"
+
+#: builtin/rebase.c:2108
+#, c-format
+msgid "could not switch to %s"
+msgstr "không thể chuyển đến %s"
+
+#: builtin/rebase.c:2119
+msgid "HEAD is up to date."
+msgstr "HEAD đã cập nhật."
+
+#: builtin/rebase.c:2121
+#, c-format
+msgid "Current branch %s is up to date.\n"
+msgstr "Nhánh hiện tại %s đã được cập nhật rồi.\n"
+
+#: builtin/rebase.c:2129
+msgid "HEAD is up to date, rebase forced."
+msgstr "HEAD hiện đã được cập nhật rồi, bị ép buộc rebase."
+
+#: builtin/rebase.c:2131
+#, c-format
+msgid "Current branch %s is up to date, rebase forced.\n"
+msgstr "Nhánh hiện tại %s đã được cập nhật rồi, lệnh rebase ép buộc.\n"
+
+#: builtin/rebase.c:2139
+msgid "The pre-rebase hook refused to rebase."
+msgstr "Móc (hook) pre-rebase từ chối rebase."
+
+#: builtin/rebase.c:2146
+#, c-format
+msgid "Changes to %s:\n"
+msgstr "Thay đổi thành %s:\n"
+
+#: builtin/rebase.c:2149
+#, c-format
+msgid "Changes from %s to %s:\n"
+msgstr "Thay đổi từ %s thành %s:\n"
+
+#: builtin/rebase.c:2174
+#, c-format
+msgid "First, rewinding head to replay your work on top of it...\n"
+msgstr ""
+"Trước tiên, di chuyển head để xem lại các công việc trên đỉnh của nó…\n"
+
+#: builtin/rebase.c:2183
+msgid "Could not detach HEAD"
+msgstr "Không thể tách rời HEAD"
 
-#: builtin/receive-pack.c:31
+#: builtin/rebase.c:2192
+#, c-format
+msgid "Fast-forwarded %s to %s.\n"
+msgstr "Chuyển-tiếp-nhanh %s đến %s.\n"
+
+#: builtin/receive-pack.c:32
 msgid "git receive-pack <git-dir>"
 msgstr "git receive-pack <thư-mục-git>"
 
-#: builtin/receive-pack.c:842
+#: builtin/receive-pack.c:830
 msgid ""
 "By default, updating the current branch in a non-bare repository\n"
 "is denied, because it will make the index and work tree inconsistent\n"
@@ -12821,7 +18411,7 @@ msgstr ""
 "Để chấm dứt lời nhắn này và vẫn giữ cách ứng xử mặc định, hãy đặt\n"
 "biến cấu hình “receive.denyCurrentBranch” thành “refuse”."
 
-#: builtin/receive-pack.c:862
+#: builtin/receive-pack.c:850
 msgid ""
 "By default, deleting the current branch is denied, because the next\n"
 "'git clone' won't result in any file checked out, causing confusion.\n"
@@ -12842,24 +18432,79 @@ msgstr ""
 "\n"
 "Để chấm dứt lời nhắn này, bạn hãy đặt nó thành “refuse”."
 
-#: builtin/receive-pack.c:1935
+#: builtin/receive-pack.c:1936
 msgid "quiet"
 msgstr "im lặng"
 
-#: builtin/receive-pack.c:1949
+#: builtin/receive-pack.c:1950
 msgid "You must specify a directory."
 msgstr "Bạn phải chỉ định thư mục."
 
-#: builtin/reflog.c:532 builtin/reflog.c:537
+#: builtin/reflog.c:17
+msgid ""
+"git reflog expire [--expire=<time>] [--expire-unreachable=<time>] [--"
+"rewrite] [--updateref] [--stale-fix] [--dry-run | -n] [--verbose] [--all] "
+"<refs>..."
+msgstr ""
+"git reflog expire [--expire=<time>] [--expire-unreachable=<time>] [--"
+"rewrite] [--updateref] [--stale-fix] [--dry-run | -n] [--verbose] [--all] "
+"<các tham chiếu>…"
+
+#: builtin/reflog.c:22
+msgid ""
+"git reflog delete [--rewrite] [--updateref] [--dry-run | -n] [--verbose] "
+"<refs>..."
+msgstr ""
+"git reflog delete [--rewrite] [--updateref] [--dry-run | -n] [--verbose] "
+"<các tham chiếu>…"
+
+#: builtin/reflog.c:25
+msgid "git reflog exists <ref>"
+msgstr "git reflog exists <tham_chiếu>"
+
+#: builtin/reflog.c:567 builtin/reflog.c:572
 #, c-format
 msgid "'%s' is not a valid timestamp"
 msgstr "“%s” không phải là dấu thời gian hợp lệ"
 
-#: builtin/remote.c:14
+#: builtin/reflog.c:605
+#, c-format
+msgid "Marking reachable objects..."
+msgstr "Đánh dấu các đối tượng tiếp cận được…"
+
+#: builtin/reflog.c:643
+#, c-format
+msgid "%s points nowhere!"
+msgstr "%s chẳng chỉ đến đâu cả!"
+
+#: builtin/reflog.c:695
+msgid "no reflog specified to delete"
+msgstr "chưa chỉ ra reflog để xóa"
+
+#: builtin/reflog.c:704
+#, c-format
+msgid "not a reflog: %s"
+msgstr "không phải một reflog: %s"
+
+#: builtin/reflog.c:709
+#, c-format
+msgid "no reflog for '%s'"
+msgstr "không reflog cho “%s”"
+
+#: builtin/reflog.c:755
+#, c-format
+msgid "invalid ref format: %s"
+msgstr "định dạng tham chiếu không hợp lệ: %s"
+
+#: builtin/reflog.c:764
+msgid "git reflog [ show | expire | delete | exists ]"
+msgstr "git reflog [ show | expire | delete | exists ]"
+
+#: builtin/remote.c:16
 msgid "git remote [-v | --verbose]"
 msgstr "git remote [-v | --verbose]"
 
-#: builtin/remote.c:15
+#: builtin/remote.c:17
 msgid ""
 "git remote add [-t <branch>] [-m <master>] [-f] [--tags | --no-tags] [--"
 "mirror=<fetch|push>] <name> <url>"
@@ -12867,82 +18512,82 @@ msgstr ""
 "git remote add [-t <nhánh>] [-m <master>] [-f] [--tags|--no-tags] [--"
 "mirror=<fetch|push>] <tên> <url>"
 
-#: builtin/remote.c:16 builtin/remote.c:36
+#: builtin/remote.c:18 builtin/remote.c:38
 msgid "git remote rename <old> <new>"
 msgstr "git remote rename <tên-cũ> <tên-mới>"
 
-#: builtin/remote.c:17 builtin/remote.c:41
+#: builtin/remote.c:19 builtin/remote.c:43
 msgid "git remote remove <name>"
 msgstr "git remote remove <tên>"
 
-#: builtin/remote.c:18 builtin/remote.c:46
+#: builtin/remote.c:20 builtin/remote.c:48
 msgid "git remote set-head <name> (-a | --auto | -d | --delete | <branch>)"
 msgstr "git remote set-head <tên> (-a | --auto | -d | --delete | <nhánh>)"
 
-#: builtin/remote.c:19
+#: builtin/remote.c:21
 msgid "git remote [-v | --verbose] show [-n] <name>"
 msgstr "git remote [-v | --verbose] show [-n] <tên>"
 
-#: builtin/remote.c:20
+#: builtin/remote.c:22
 msgid "git remote prune [-n | --dry-run] <name>"
 msgstr "git remote prune [-n | --dry-run] <tên>"
 
-#: builtin/remote.c:21
+#: builtin/remote.c:23
 msgid ""
 "git remote [-v | --verbose] update [-p | --prune] [(<group> | <remote>)...]"
 msgstr ""
 "git remote [-v | --verbose] update [-p | --prune] [(<nhóm> | <máy-chủ>)…]"
 
-#: builtin/remote.c:22
+#: builtin/remote.c:24
 msgid "git remote set-branches [--add] <name> <branch>..."
 msgstr "git remote set-branches [--add] <tên> <nhánh>…"
 
-#: builtin/remote.c:23 builtin/remote.c:72
+#: builtin/remote.c:25 builtin/remote.c:74
 msgid "git remote get-url [--push] [--all] <name>"
 msgstr "git remote set-url [--push] [--all] <tên>"
 
-#: builtin/remote.c:24 builtin/remote.c:77
+#: builtin/remote.c:26 builtin/remote.c:79
 msgid "git remote set-url [--push] <name> <newurl> [<oldurl>]"
 msgstr "git remote set-url [--push] <tên> <url-mới> [<url-cũ>]"
 
-#: builtin/remote.c:25 builtin/remote.c:78
+#: builtin/remote.c:27 builtin/remote.c:80
 msgid "git remote set-url --add <name> <newurl>"
 msgstr "git remote set-url --add <tên> <url-mới>"
 
-#: builtin/remote.c:26 builtin/remote.c:79
+#: builtin/remote.c:28 builtin/remote.c:81
 msgid "git remote set-url --delete <name> <url>"
 msgstr "git remote set-url --delete <tên> <url>"
 
-#: builtin/remote.c:31
+#: builtin/remote.c:33
 msgid "git remote add [<options>] <name> <url>"
-msgstr "git remote add [<các-tùy-chọn>] <tên> <url>"
+msgstr "git remote add [<các tùy chọn>] <tên> <url>"
 
-#: builtin/remote.c:51
+#: builtin/remote.c:53
 msgid "git remote set-branches <name> <branch>..."
 msgstr "git remote set-branches <tên> <nhánh>…"
 
-#: builtin/remote.c:52
+#: builtin/remote.c:54
 msgid "git remote set-branches --add <name> <branch>..."
 msgstr "git remote set-branches --add <tên> <nhánh>…"
 
-#: builtin/remote.c:57
+#: builtin/remote.c:59
 msgid "git remote show [<options>] <name>"
-msgstr "git remote show [<các-tùy-chọn>] <tên>"
+msgstr "git remote show [<các tùy chọn>] <tên>"
 
-#: builtin/remote.c:62
+#: builtin/remote.c:64
 msgid "git remote prune [<options>] <name>"
-msgstr "git remote prune [<các-tùy-chọn>] <tên>"
+msgstr "git remote prune [<các tùy chọn>] <tên>"
 
-#: builtin/remote.c:67
+#: builtin/remote.c:69
 msgid "git remote update [<options>] [<group> | <remote>]..."
-msgstr "git remote update [<các-tùy-chọn>] [<nhóm> | <máy-chủ>]…"
+msgstr "git remote update [<các tùy chọn>] [<nhóm> | <máy-chủ>]…"
 
-#: builtin/remote.c:96
+#: builtin/remote.c:98
 #, c-format
 msgid "Updating %s"
 msgstr "Đang cập nhật %s"
 
-#: builtin/remote.c:128
+#: builtin/remote.c:130
 msgid ""
 "--mirror is dangerous and deprecated; please\n"
 "\t use --mirror=fetch or --mirror=push instead"
@@ -12950,86 +18595,82 @@ msgstr ""
 "--mirror nguy hiểm và không dùng nữa; xin hãy\n"
 "\t sử dụng tùy chọn --mirror=fetch hoặc --mirror=push để thay thế"
 
-#: builtin/remote.c:145
+#: builtin/remote.c:147
 #, c-format
 msgid "unknown mirror argument: %s"
 msgstr "không hiểu tham số máy bản sao (mirror): %s"
 
-#: builtin/remote.c:161
+#: builtin/remote.c:163
 msgid "fetch the remote branches"
 msgstr "lấy về các nhánh từ máy chủ"
 
-#: builtin/remote.c:163
+#: builtin/remote.c:165
 msgid "import all tags and associated objects when fetching"
 msgstr "nhập vào tất cả các đối tượng thẻ và thành phần liên quan khi lấy về"
 
-#: builtin/remote.c:166
+#: builtin/remote.c:168
 msgid "or do not fetch any tag at all (--no-tags)"
 msgstr "hoặc không lấy về bất kỳ thẻ nào (--no-tags)"
 
-#: builtin/remote.c:168
+#: builtin/remote.c:170
 msgid "branch(es) to track"
 msgstr "các nhánh để theo dõi"
 
-#: builtin/remote.c:169
+#: builtin/remote.c:171
 msgid "master branch"
 msgstr "nhánh master"
 
-#: builtin/remote.c:170
-msgid "push|fetch"
-msgstr "push|fetch"
-
-#: builtin/remote.c:171
+#: builtin/remote.c:173
 msgid "set up remote as a mirror to push to or fetch from"
 msgstr "đặt máy chủ (remote) như là một máy bản sao để push hay fetch từ đó"
 
-#: builtin/remote.c:183
+#: builtin/remote.c:185
 msgid "specifying a master branch makes no sense with --mirror"
 msgstr "đang chỉ định một nhánh master không hợp lý với tùy chọn --mirror"
 
-#: builtin/remote.c:185
+#: builtin/remote.c:187
 msgid "specifying branches to track makes sense only with fetch mirrors"
 msgstr "chỉ định những nhánh để theo dõi chỉ hợp lý với các “fetch mirror”"
 
-#: builtin/remote.c:192 builtin/remote.c:634
+#: builtin/remote.c:194 builtin/remote.c:636
 #, c-format
 msgid "remote %s already exists."
 msgstr "máy chủ %s đã tồn tại rồi."
 
-#: builtin/remote.c:196 builtin/remote.c:638
+#: builtin/remote.c:198 builtin/remote.c:640
 #, c-format
 msgid "'%s' is not a valid remote name"
 msgstr "“%s” không phải tên máy chủ hợp lệ"
 
-#: builtin/remote.c:236
+#: builtin/remote.c:238
 #, c-format
 msgid "Could not setup master '%s'"
 msgstr "Không thể cài đặt nhánh master “%s”"
 
-#: builtin/remote.c:342
+#: builtin/remote.c:344
 #, c-format
 msgid "Could not get fetch map for refspec %s"
 msgstr "Không thể lấy ánh xạ (map) fetch cho đặc tả tham chiếu %s"
 
-#: builtin/remote.c:441 builtin/remote.c:449
+#: builtin/remote.c:443 builtin/remote.c:451
 msgid "(matching)"
 msgstr "(khớp)"
 
-#: builtin/remote.c:453
+#: builtin/remote.c:455
 msgid "(delete)"
 msgstr "(xóa)"
 
-#: builtin/remote.c:627 builtin/remote.c:762 builtin/remote.c:861
+#: builtin/remote.c:629 builtin/remote.c:764 builtin/remote.c:863
 #, c-format
-msgid "No such remote: %s"
-msgstr "Không có máy chủ nào như thế: %s"
+msgid "No such remote: '%s'"
+msgstr "Không có máy chủ nào như vậy: “%s”"
 
-#: builtin/remote.c:644
+#: builtin/remote.c:646
 #, c-format
 msgid "Could not rename config section '%s' to '%s'"
 msgstr "Không thể đổi tên phần của cấu hình từ “%s” thành “%s”"
 
-#: builtin/remote.c:664
+#: builtin/remote.c:666
 #, c-format
 msgid ""
 "Not updating non-default fetch refspec\n"
@@ -13040,17 +18681,17 @@ msgstr ""
 "\t%s\n"
 "\tXin hãy cập nhật phần cấu hình một cách thủ công nếu thấy cần thiết."
 
-#: builtin/remote.c:700
+#: builtin/remote.c:701
 #, c-format
 msgid "deleting '%s' failed"
 msgstr "gặp lỗi khi xóa “%s”"
 
-#: builtin/remote.c:734
+#: builtin/remote.c:735
 #, c-format
 msgid "creating '%s' failed"
 msgstr "gặp lỗi khi tạo “%s”"
 
-#: builtin/remote.c:799
+#: builtin/remote.c:801
 msgid ""
 "Note: A branch outside the refs/remotes/ hierarchy was not removed;\n"
 "to delete it, use:"
@@ -13062,119 +18703,119 @@ msgstr[0] ""
 "đi;\n"
 "để xóa đi, sử dụng:"
 
-#: builtin/remote.c:813
+#: builtin/remote.c:815
 #, c-format
 msgid "Could not remove config section '%s'"
 msgstr "Không thể gỡ bỏ phần cấu hình “%s”"
 
-#: builtin/remote.c:914
+#: builtin/remote.c:916
 #, c-format
 msgid " new (next fetch will store in remotes/%s)"
 msgstr " mới (lần lấy về tiếp theo sẽ lưu trong remotes/%s)"
 
-#: builtin/remote.c:917
+#: builtin/remote.c:919
 msgid " tracked"
 msgstr " được theo dõi"
 
-#: builtin/remote.c:919
+#: builtin/remote.c:921
 msgid " stale (use 'git remote prune' to remove)"
 msgstr " cũ rích (dùng “git remote prune” để gỡ bỏ)"
 
-#: builtin/remote.c:921
+#: builtin/remote.c:923
 msgid " ???"
 msgstr " ???"
 
-#: builtin/remote.c:962
+#: builtin/remote.c:964
 #, c-format
 msgid "invalid branch.%s.merge; cannot rebase onto > 1 branch"
 msgstr "branch.%s.merge không hợp lệ; không thể cải tổ về phía > 1 nhánh"
 
-#: builtin/remote.c:971
+#: builtin/remote.c:973
 #, c-format
 msgid "rebases interactively onto remote %s"
 msgstr "thực hiện rebase một cách tương tác trên máy chủ %s"
 
-#: builtin/remote.c:973
+#: builtin/remote.c:975
 #, c-format
 msgid "rebases interactively (with merges) onto remote %s"
 msgstr ""
 "thực hiện cải tổ (với các hòa trộn) một cách tương tác lên trên máy chủ %s"
 
-#: builtin/remote.c:976
+#: builtin/remote.c:978
 #, c-format
 msgid "rebases onto remote %s"
 msgstr "thực hiện rebase trên máy chủ %s"
 
-#: builtin/remote.c:980
+#: builtin/remote.c:982
 #, c-format
 msgid " merges with remote %s"
 msgstr " hòa trộn với máy chủ %s"
 
-#: builtin/remote.c:983
+#: builtin/remote.c:985
 #, c-format
 msgid "merges with remote %s"
 msgstr "hòa trộn với máy chủ %s"
 
-#: builtin/remote.c:986
+#: builtin/remote.c:988
 #, c-format
 msgid "%-*s    and with remote %s\n"
 msgstr "%-*s    và với máy chủ %s\n"
 
-#: builtin/remote.c:1029
+#: builtin/remote.c:1031
 msgid "create"
 msgstr "tạo"
 
-#: builtin/remote.c:1032
+#: builtin/remote.c:1034
 msgid "delete"
 msgstr "xóa"
 
-#: builtin/remote.c:1036
+#: builtin/remote.c:1038
 msgid "up to date"
 msgstr "đã cập nhật"
 
-#: builtin/remote.c:1039
+#: builtin/remote.c:1041
 msgid "fast-forwardable"
 msgstr "có-thể-chuyển-tiếp-nhanh"
 
-#: builtin/remote.c:1042
+#: builtin/remote.c:1044
 msgid "local out of date"
 msgstr "dữ liệu nội bộ đã cũ"
 
-#: builtin/remote.c:1049
+#: builtin/remote.c:1051
 #, c-format
 msgid "    %-*s forces to %-*s (%s)"
 msgstr "    %-*s ép buộc thành %-*s (%s)"
 
-#: builtin/remote.c:1052
+#: builtin/remote.c:1054
 #, c-format
 msgid "    %-*s pushes to %-*s (%s)"
 msgstr "    %-*s đẩy lên thành %-*s (%s)"
 
-#: builtin/remote.c:1056
+#: builtin/remote.c:1058
 #, c-format
 msgid "    %-*s forces to %s"
 msgstr "    %-*s ép buộc thành %s"
 
-#: builtin/remote.c:1059
+#: builtin/remote.c:1061
 #, c-format
 msgid "    %-*s pushes to %s"
 msgstr "    %-*s đẩy lên thành %s"
 
-#: builtin/remote.c:1127
+#: builtin/remote.c:1129
 msgid "do not query remotes"
 msgstr "không truy vấn các máy chủ"
 
-#: builtin/remote.c:1154
+#: builtin/remote.c:1156
 #, c-format
 msgid "* remote %s"
 msgstr "* máy chủ %s"
 
-#: builtin/remote.c:1155
+#: builtin/remote.c:1157
 #, c-format
 msgid "  Fetch URL: %s"
 msgstr "  URL để lấy về: %s"
 
-#: builtin/remote.c:1156 builtin/remote.c:1172 builtin/remote.c:1311
+#: builtin/remote.c:1158 builtin/remote.c:1174 builtin/remote.c:1313
 msgid "(no URL)"
 msgstr "(không có URL)"
 
@@ -13182,190 +18823,181 @@ msgstr "(không có URL)"
 #. with the one in " Fetch URL: %s"
 #. translation.
 #.
-#: builtin/remote.c:1170 builtin/remote.c:1172
+#: builtin/remote.c:1172 builtin/remote.c:1174
 #, c-format
 msgid "  Push  URL: %s"
 msgstr "  URL để đẩy lên: %s"
 
-#: builtin/remote.c:1174 builtin/remote.c:1176 builtin/remote.c:1178
+#: builtin/remote.c:1176 builtin/remote.c:1178 builtin/remote.c:1180
 #, c-format
 msgid "  HEAD branch: %s"
 msgstr "  Nhánh HEAD: %s"
 
-#: builtin/remote.c:1174
+#: builtin/remote.c:1176
 msgid "(not queried)"
 msgstr "(không yêu cầu)"
 
-#: builtin/remote.c:1176
+#: builtin/remote.c:1178
 msgid "(unknown)"
 msgstr "(không hiểu)"
 
-#: builtin/remote.c:1180
+#: builtin/remote.c:1182
 #, c-format
 msgid ""
 "  HEAD branch (remote HEAD is ambiguous, may be one of the following):\n"
 msgstr "  nhánh HEAD (HEAD máy chủ chưa rõ ràng, có lẽ là một trong số sau):\n"
 
-#: builtin/remote.c:1192
+#: builtin/remote.c:1194
 #, c-format
 msgid "  Remote branch:%s"
 msgid_plural "  Remote branches:%s"
 msgstr[0] "  Những nhánh trên máy chủ:%s"
 
-#: builtin/remote.c:1195 builtin/remote.c:1221
+#: builtin/remote.c:1197 builtin/remote.c:1223
 msgid " (status not queried)"
 msgstr " (trạng thái không được yêu cầu)"
 
-#: builtin/remote.c:1204
+#: builtin/remote.c:1206
 msgid "  Local branch configured for 'git pull':"
 msgid_plural "  Local branches configured for 'git pull':"
 msgstr[0] "  Những nhánh nội bộ đã được cấu hình cho lệnh “git pull”:"
 
-#: builtin/remote.c:1212
+#: builtin/remote.c:1214
 msgid "  Local refs will be mirrored by 'git push'"
 msgstr "  refs nội bộ sẽ được phản chiếu bởi lệnh “git push”"
 
-#: builtin/remote.c:1218
+#: builtin/remote.c:1220
 #, c-format
 msgid "  Local ref configured for 'git push'%s:"
 msgid_plural "  Local refs configured for 'git push'%s:"
 msgstr[0] "  Những tham chiếu nội bộ được cấu hình cho lệnh “git push”%s:"
 
-#: builtin/remote.c:1239
+#: builtin/remote.c:1241
 msgid "set refs/remotes/<name>/HEAD according to remote"
 msgstr "đặt refs/remotes/<tên>/HEAD cho phù hợp với máy chủ"
 
-#: builtin/remote.c:1241
+#: builtin/remote.c:1243
 msgid "delete refs/remotes/<name>/HEAD"
 msgstr "xóa refs/remotes/<tên>/HEAD"
 
-#: builtin/remote.c:1256
+#: builtin/remote.c:1258
 msgid "Cannot determine remote HEAD"
 msgstr "Không thể xác định được HEAD máy chủ"
 
-#: builtin/remote.c:1258
+#: builtin/remote.c:1260
 msgid "Multiple remote HEAD branches. Please choose one explicitly with:"
 msgstr "Nhiều nhánh HEAD máy chủ. Hãy chọn rõ ràng một:"
 
-#: builtin/remote.c:1268
+#: builtin/remote.c:1270
 #, c-format
 msgid "Could not delete %s"
 msgstr "Không thể xóa bỏ %s"
 
-#: builtin/remote.c:1276
+#: builtin/remote.c:1278
 #, c-format
 msgid "Not a valid ref: %s"
 msgstr "Không phải là tham chiếu hợp lệ: %s"
 
-#: builtin/remote.c:1278
+#: builtin/remote.c:1280
 #, c-format
 msgid "Could not setup %s"
 msgstr "Không thể cài đặt %s"
 
-#: builtin/remote.c:1296
+#: builtin/remote.c:1298
 #, c-format
 msgid " %s will become dangling!"
 msgstr " %s sẽ trở thành không đầu (không được quản lý)!"
 
-#: builtin/remote.c:1297
+#: builtin/remote.c:1299
 #, c-format
 msgid " %s has become dangling!"
 msgstr " %s đã trở thành không đầu (không được quản lý)!"
 
-#: builtin/remote.c:1307
+#: builtin/remote.c:1309
 #, c-format
 msgid "Pruning %s"
 msgstr "Đang xén bớt %s"
 
-#: builtin/remote.c:1308
+#: builtin/remote.c:1310
 #, c-format
 msgid "URL: %s"
 msgstr "URL: %s"
 
-#: builtin/remote.c:1324
+#: builtin/remote.c:1326
 #, c-format
 msgid " * [would prune] %s"
 msgstr " * [nên xén bớt] %s"
 
-#: builtin/remote.c:1327
+#: builtin/remote.c:1329
 #, c-format
 msgid " * [pruned] %s"
 msgstr " * [đã bị xén] %s"
 
-#: builtin/remote.c:1372
+#: builtin/remote.c:1374
 msgid "prune remotes after fetching"
 msgstr "cắt máy chủ sau khi lấy về"
 
-#: builtin/remote.c:1435 builtin/remote.c:1489 builtin/remote.c:1557
+#: builtin/remote.c:1437 builtin/remote.c:1491 builtin/remote.c:1559
 #, c-format
 msgid "No such remote '%s'"
 msgstr "Không có máy chủ nào có tên “%s”"
 
-#: builtin/remote.c:1451
+#: builtin/remote.c:1453
 msgid "add branch"
 msgstr "thêm nhánh"
 
-#: builtin/remote.c:1458
+#: builtin/remote.c:1460
 msgid "no remote specified"
 msgstr "chưa chỉ ra máy chủ nào"
 
-#: builtin/remote.c:1475
+#: builtin/remote.c:1477
 msgid "query push URLs rather than fetch URLs"
 msgstr "truy vấn đẩy URL thay vì lấy"
 
-#: builtin/remote.c:1477
+#: builtin/remote.c:1479
 msgid "return all URLs"
 msgstr "trả về mọi URL"
 
-#: builtin/remote.c:1505
+#: builtin/remote.c:1507
 #, c-format
 msgid "no URLs configured for remote '%s'"
 msgstr "không có URL nào được cấu hình cho nhánh “%s”"
 
-#: builtin/remote.c:1531
+#: builtin/remote.c:1533
 msgid "manipulate push URLs"
 msgstr "đẩy các “URL” bằng tay"
 
-#: builtin/remote.c:1533
+#: builtin/remote.c:1535
 msgid "add URL"
 msgstr "thêm URL"
 
-#: builtin/remote.c:1535
+#: builtin/remote.c:1537
 msgid "delete URLs"
 msgstr "xóa URLs"
 
-#: builtin/remote.c:1542
+#: builtin/remote.c:1544
 msgid "--add --delete doesn't make sense"
 msgstr "--add --delete không hợp lý"
 
-#: builtin/remote.c:1581
+#: builtin/remote.c:1583
 #, c-format
 msgid "Invalid old URL pattern: %s"
 msgstr "Kiểu mẫu URL cũ không hợp lệ: %s"
 
-#: builtin/remote.c:1589
+#: builtin/remote.c:1591
 #, c-format
 msgid "No such URL found: %s"
 msgstr "Không tìm thấy URL như vậy: %s"
 
-#: builtin/remote.c:1591
+#: builtin/remote.c:1593
 msgid "Will not delete all non-push URLs"
 msgstr "Sẽ không xóa những địa chỉ URL không-push"
 
-#: builtin/remote.c:1607
-msgid "be verbose; must be placed before a subcommand"
-msgstr "chi tiết; phải được đặt trước một lệnh-con"
-
-#: builtin/remote.c:1638
-#, c-format
-msgid "Unknown subcommand: %s"
-msgstr "Không hiểu câu lệnh con: %s"
-
-#: builtin/repack.c:18
+#: builtin/repack.c:23
 msgid "git repack [<options>]"
-msgstr "git repack [<các-tùy-chọn>]"
+msgstr "git repack [<các tùy chọn>]"
 
-#: builtin/repack.c:23
+#: builtin/repack.c:28
 msgid ""
 "Incremental repacks are incompatible with bitmap indexes.  Use\n"
 "--no-write-bitmap-index or disable the pack.writebitmaps configuration."
@@ -13373,91 +19005,134 @@ msgstr ""
 "Gia tăng repack là không tương thích với chỉ mục bitmap. Dùng\n"
 "--no-write-bitmap-index hay tắt cấu hình pack.writebitmaps."
 
-#: builtin/repack.c:180
+#: builtin/repack.c:191
+msgid "could not start pack-objects to repack promisor objects"
+msgstr ""
+"không thể lấy thông tin thống kê pack-objects để mà đóng gói lại các đối "
+"tượng hứa hẹn"
+
+#: builtin/repack.c:230 builtin/repack.c:416
+msgid "repack: Expecting full hex object ID lines only from pack-objects."
+msgstr ""
+"repack: Đang chỉ cần các dòng ID đối tượng dạng thập lục phân đầy dủ từ pack-"
+"objects."
+
+#: builtin/repack.c:254
+msgid "could not finish pack-objects to repack promisor objects"
+msgstr "không thể hoàn tất pack-objects để đóng gói các đối tượng hứa hẹn"
+
+#: builtin/repack.c:292
 msgid "pack everything in a single pack"
 msgstr "đóng gói mọi thứ trong một gói đơn"
 
-#: builtin/repack.c:182
+#: builtin/repack.c:294
 msgid "same as -a, and turn unreachable objects loose"
 msgstr "giống với -a, và chỉnh sửa các đối tượng không đọc được thiếu sót"
 
-#: builtin/repack.c:185
+#: builtin/repack.c:297
 msgid "remove redundant packs, and run git-prune-packed"
 msgstr "xóa bỏ các gói dư thừa, và chạy git-prune-packed"
 
-#: builtin/repack.c:187
+#: builtin/repack.c:299
 msgid "pass --no-reuse-delta to git-pack-objects"
 msgstr "chuyển --no-reuse-delta cho git-pack-objects"
 
-#: builtin/repack.c:189
+#: builtin/repack.c:301
 msgid "pass --no-reuse-object to git-pack-objects"
 msgstr "chuyển --no-reuse-object cho git-pack-objects"
 
-#: builtin/repack.c:191
+#: builtin/repack.c:303
 msgid "do not run git-update-server-info"
 msgstr "không chạy git-update-server-info"
 
-#: builtin/repack.c:194
+#: builtin/repack.c:306
 msgid "pass --local to git-pack-objects"
 msgstr "chuyển --local cho git-pack-objects"
 
-#: builtin/repack.c:196
+#: builtin/repack.c:308
 msgid "write bitmap index"
 msgstr "ghi mục lục ánh xạ"
 
-#: builtin/repack.c:197
+#: builtin/repack.c:310
+msgid "pass --delta-islands to git-pack-objects"
+msgstr "chuyển --delta-islands cho git-pack-objects"
+
+#: builtin/repack.c:311
 msgid "approxidate"
 msgstr "ngày ước tính"
 
-#: builtin/repack.c:198
+#: builtin/repack.c:312
 msgid "with -A, do not loosen objects older than this"
 msgstr "với -A, các đối tượng cũ hơn khoảng thời gian này thì không bị mất"
 
-#: builtin/repack.c:200
+#: builtin/repack.c:314
 msgid "with -a, repack unreachable objects"
 msgstr "với -a, đóng gói lại các đối tượng không thể đọc được"
 
-#: builtin/repack.c:202
+#: builtin/repack.c:316
 msgid "size of the window used for delta compression"
 msgstr "kích thước cửa sổ được dùng cho nén “delta”"
 
-#: builtin/repack.c:203 builtin/repack.c:209
+#: builtin/repack.c:317 builtin/repack.c:323
 msgid "bytes"
 msgstr "byte"
 
-#: builtin/repack.c:204
+#: builtin/repack.c:318
 msgid "same as the above, but limit memory size instead of entries count"
 msgstr "giống như trên, nhưng giới hạn kích thước bộ nhớ hay vì số lượng"
 
-#: builtin/repack.c:206
+#: builtin/repack.c:320
 msgid "limits the maximum delta depth"
 msgstr "giới hạn độ sâu tối đa của “delta”"
 
-#: builtin/repack.c:208
+#: builtin/repack.c:322
 msgid "limits the maximum number of threads"
 msgstr "giới hạn số lượng tối đa tuyến trình"
 
-#: builtin/repack.c:210
+#: builtin/repack.c:324
 msgid "maximum size of each packfile"
 msgstr "kích thước tối đa cho từng tập tin gói"
 
-#: builtin/repack.c:212
+#: builtin/repack.c:326
 msgid "repack objects in packs marked with .keep"
 msgstr "đóng gói lại các đối tượng trong các gói đã đánh dấu bằng .keep"
 
-#: builtin/repack.c:214
+#: builtin/repack.c:328
 msgid "do not repack this pack"
 msgstr "đừng đóng gói lại gói này"
 
-#: builtin/repack.c:224
+#: builtin/repack.c:338
 msgid "cannot delete packs in a precious-objects repo"
 msgstr "không thể xóa các gói trong một kho đối_tượng_vĩ_đại"
 
-#: builtin/repack.c:228
+#: builtin/repack.c:342
 msgid "--keep-unreachable and -A are incompatible"
 msgstr "--keep-unreachable và -A xung khắc nhau"
 
-#: builtin/repack.c:425 builtin/worktree.c:139
+#: builtin/repack.c:425
+msgid "Nothing new to pack."
+msgstr "Không có gì mới để mà đóng gói."
+
+#: builtin/repack.c:486
+#, c-format
+msgid ""
+"WARNING: Some packs in use have been renamed by\n"
+"WARNING: prefixing old- to their name, in order to\n"
+"WARNING: replace them with the new version of the\n"
+"WARNING: file.  But the operation failed, and the\n"
+"WARNING: attempt to rename them back to their\n"
+"WARNING: original names also failed.\n"
+"WARNING: Please rename them in %s manually:\n"
+msgstr ""
+"CẢNH BÁO: Một số gói đang dùng vừa được đổi tên bằng cách\n"
+"CẢNH BÁO: đánh tiền tố old- vào tên của chúng, mục đích là\n"
+"CẢNH BÁO: thay chúng bằng phiên bản mới của tập\n"
+"CẢNH BÁO: tin. Nhưng thao tác lại gặp lỗi, và nỗ\n"
+"CẢNH BÁO: lực để đổi ngược lại tên chúng cho đúng với tên\n"
+"CẢNH BÁO: nguyên gốc của nó cũng gặp lỗi.\n"
+"CẢNH BÁO: Vui lòng đổi tên chúng trong %s bằng tay:\n"
+
+#: builtin/repack.c:534
 #, c-format
 msgid "failed to remove '%s'"
 msgstr "gặp lỗi khi gỡ bỏ “%s”"
@@ -13486,22 +19161,121 @@ msgstr "git replace -d <đối tượng>
 msgid "git replace [--format=<format>] [-l [<pattern>]]"
 msgstr "git replace [--format=<định_dạng>] [-l [<mẫu>]]"
 
-#: builtin/replace.c:371 builtin/replace.c:415 builtin/replace.c:445
+#: builtin/replace.c:90
+#, c-format
+msgid ""
+"invalid replace format '%s'\n"
+"valid formats are 'short', 'medium' and 'long'"
+msgstr ""
+"định dạng thay thế không hợp lệ “%s”\n"
+"định dạng hợp lệ là “short”, “medium” và “long”"
+
+#: builtin/replace.c:125
+#, c-format
+msgid "replace ref '%s' not found"
+msgstr "không tìm thấy tham chiếu thay thế “%s”"
+
+#: builtin/replace.c:141
+#, c-format
+msgid "Deleted replace ref '%s'"
+msgstr "Đã xóa tham chiếu thay thế “%s”"
+
+#: builtin/replace.c:153
+#, c-format
+msgid "'%s' is not a valid ref name"
+msgstr "“%s” không phải tên tham chiếu hợp lệ"
+
+#: builtin/replace.c:158
+#, c-format
+msgid "replace ref '%s' already exists"
+msgstr "tham chiếu thay thế “%s” đã tồn tại rồi"
+
+#: builtin/replace.c:178
+#, c-format
+msgid ""
+"Objects must be of the same type.\n"
+"'%s' points to a replaced object of type '%s'\n"
+"while '%s' points to a replacement object of type '%s'."
+msgstr ""
+"Các đối tượng phải cùng kiểu.\n"
+"“%s” chỉ đến đối tượng thay thế của kiểu “%s”\n"
+"trong khi “%s” chỉ đến đối tượng tham chiếu của kiểu “%s”."
+
+#: builtin/replace.c:229
+#, c-format
+msgid "unable to open %s for writing"
+msgstr "không thể mở “%s” để ghi"
+
+#: builtin/replace.c:242
+msgid "cat-file reported failure"
+msgstr "cat-file đã báo cáo gặp lỗi nghiêm trọng"
+
+#: builtin/replace.c:258
+#, c-format
+msgid "unable to open %s for reading"
+msgstr "không thể mở “%s” để đọc"
+
+#: builtin/replace.c:272
+msgid "unable to spawn mktree"
+msgstr "không thể sinh tiến trình con mktree"
+
+#: builtin/replace.c:276
+msgid "unable to read from mktree"
+msgstr "không thể đọc từ mktree"
+
+#: builtin/replace.c:285
+msgid "mktree reported failure"
+msgstr "mktree đã báo cáo gặp lỗi nghiêm trọng"
+
+#: builtin/replace.c:289
+msgid "mktree did not return an object name"
+msgstr "mktree đã không trả về một tên đối tượng"
+
+#: builtin/replace.c:298
+#, c-format
+msgid "unable to fstat %s"
+msgstr "không thể fstat %s"
+
+#: builtin/replace.c:303
+msgid "unable to write object to database"
+msgstr "không thể ghi đối tượng vào cơ sở dữ liệu"
+
+#: builtin/replace.c:322 builtin/replace.c:378 builtin/replace.c:423
+#: builtin/replace.c:453
+#, c-format
+msgid "not a valid object name: '%s'"
+msgstr "không phải là tên đối tượng hợp lệ: “%s”"
+
+#: builtin/replace.c:326
+#, c-format
+msgid "unable to get object type for %s"
+msgstr "không thể lấy kiểu đối tượng cho %s"
+
+#: builtin/replace.c:342
+msgid "editing object file failed"
+msgstr "việc sửa tập tin đối tượng gặp lỗi"
+
+#: builtin/replace.c:351
+#, c-format
+msgid "new object is the same as the old one: '%s'"
+msgstr "đối tượng mới là giống với cái cũ: “%s”"
+
+#: builtin/replace.c:384
 #, c-format
-msgid "Not a valid object name: '%s'"
-msgstr "Không phải là tên đối tượng hợp lệ: “%s”"
+msgid "could not parse %s as a commit"
+msgstr "không thể phân tích %s như là một lần chuyển giao"
 
-#: builtin/replace.c:407
+#: builtin/replace.c:415
 #, c-format
 msgid "bad mergetag in commit '%s'"
 msgstr "thẻ hòa trộn sai trong lần chuyển giao “%s”"
 
-#: builtin/replace.c:409
+#: builtin/replace.c:417
 #, c-format
 msgid "malformed mergetag in commit '%s'"
 msgstr "thẻ hòa trộn không đúng dạng ở lần chuyển giao “%s”"
 
-#: builtin/replace.c:421
+#: builtin/replace.c:429
 #, c-format
 msgid ""
 "original commit '%s' contains mergetag '%s' that is discarded; use --edit "
@@ -13510,236 +19284,309 @@ msgstr ""
 "lần chuyển giao gốc “%s” có chứa thẻ hòa trộn “%s” cái mà bị loại bỏ; dùng "
 "tùy chọn --edit thay cho --graft"
 
-#: builtin/replace.c:460
+#: builtin/replace.c:468
 #, c-format
-msgid "the original commit '%s' has a gpg signature."
-msgstr "lần chuyển giao gốc “%s” có chữ ký GPG."
+msgid "the original commit '%s' has a gpg signature"
+msgstr "lần chuyển giao gốc “%s” có chữ ký GPG"
 
-#: builtin/replace.c:461
+#: builtin/replace.c:469
 msgid "the signature will be removed in the replacement commit!"
 msgstr "chữ ký sẽ được bỏ đi trong lần chuyển giao thay thế!"
 
-#: builtin/replace.c:471
+#: builtin/replace.c:479
 #, c-format
 msgid "could not write replacement commit for: '%s'"
 msgstr "không thể ghi lần chuyển giao thay thế cho: “%s”"
 
-#: builtin/replace.c:514
+#: builtin/replace.c:487
+#, c-format
+msgid "graft for '%s' unnecessary"
+msgstr "graft cho “%s” không cần thiết"
+
+#: builtin/replace.c:491
+#, c-format
+msgid "new commit is the same as the old one: '%s'"
+msgstr "lần chuyển giao mới là giống với cái cũ: “%s”"
+
+#: builtin/replace.c:526
 #, c-format
 msgid ""
 "could not convert the following graft(s):\n"
 "%s"
 msgstr ""
-"Không thể chuyển đổi các graft sau đây:\n"
+"không thể chuyển đổi các graft sau đây:\n"
 "%s"
 
-#: builtin/replace.c:535
+#: builtin/replace.c:547
 msgid "list replace refs"
 msgstr "liệt kê các refs thay thế"
 
-#: builtin/replace.c:536
+#: builtin/replace.c:548
 msgid "delete replace refs"
 msgstr "xóa tham chiếu thay thế"
 
-#: builtin/replace.c:537
+#: builtin/replace.c:549
 msgid "edit existing object"
 msgstr "sửa đối tượng sẵn có"
 
-#: builtin/replace.c:538
+#: builtin/replace.c:550
 msgid "change a commit's parents"
 msgstr "thay đổi cha mẹ của lần chuyển giao"
 
-#: builtin/replace.c:539
+#: builtin/replace.c:551
 msgid "convert existing graft file"
 msgstr "chuyển đổi các tập tin graft sẵn có"
 
-#: builtin/replace.c:540
+#: builtin/replace.c:552
 msgid "replace the ref if it exists"
 msgstr "thay thế tham chiếu nếu nó đã sẵn có"
 
-#: builtin/replace.c:542
+#: builtin/replace.c:554
 msgid "do not pretty-print contents for --edit"
 msgstr "đừng in đẹp các nội dung cho --edit"
 
-#: builtin/replace.c:543
+#: builtin/replace.c:555
 msgid "use this format"
 msgstr "dùng định dạng này"
 
+#: builtin/replace.c:568
+msgid "--format cannot be used when not listing"
+msgstr "--format không thể được dùng khi không liệt kê gì"
+
+#: builtin/replace.c:576
+msgid "-f only makes sense when writing a replacement"
+msgstr "-f chỉ hợp lý khi ghi một cái thay thế"
+
+#: builtin/replace.c:580
+msgid "--raw only makes sense with --edit"
+msgstr "--raw chỉ hợp lý với --edit"
+
+#: builtin/replace.c:586
+msgid "-d needs at least one argument"
+msgstr "-d cần ít nhất một tham số"
+
+#: builtin/replace.c:592
+msgid "bad number of arguments"
+msgstr "số đối số không đúng"
+
+#: builtin/replace.c:598
+msgid "-e needs exactly one argument"
+msgstr "-e cần chính các là một đối số"
+
+#: builtin/replace.c:604
+msgid "-g needs at least one argument"
+msgstr "-q cần ít nhất một tham số"
+
+#: builtin/replace.c:610
+msgid "--convert-graft-file takes no argument"
+msgstr "--convert-graft-file không nhận đối số"
+
+#: builtin/replace.c:616
+msgid "only one pattern can be given with -l"
+msgstr "chỉ một mẫu được chỉ ra với tùy chọn -l"
+
 #: builtin/rerere.c:13
 msgid "git rerere [clear | forget <path>... | status | remaining | diff | gc]"
 msgstr ""
 "git rerere [clear | forget <đường dẫn>… | status | remaining | diff | gc]"
 
-#: builtin/rerere.c:59
+#: builtin/rerere.c:60
 msgid "register clean resolutions in index"
 msgstr "sổ ghi dọn sạch các phân giải trong bản mục lục"
 
-#: builtin/reset.c:29
+#: builtin/rerere.c:79
+msgid "'git rerere forget' without paths is deprecated"
+msgstr "“git rerere forget” mà không có các đường dẫn là đã lạc hậu"
+
+#: builtin/rerere.c:113
+#, c-format
+msgid "unable to generate diff for '%s'"
+msgstr "không thể tạo khác biệt cho “%s”"
+
+#: builtin/reset.c:32
 msgid ""
 "git reset [--mixed | --soft | --hard | --merge | --keep] [-q] [<commit>]"
 msgstr ""
 "git reset [--mixed | --soft | --hard | --merge | --keep] [-q] [<commit>]"
 
-#: builtin/reset.c:30
-msgid "git reset [-q] [<tree-ish>] [--] <paths>..."
-msgstr "git reset [-q] [<tree-ish>] [--] <đường-dẫn>…"
-
-#: builtin/reset.c:31
-msgid "git reset --patch [<tree-ish>] [--] [<paths>...]"
-msgstr "git reset --patch [<tree-ish>] [--] [<các-đường-dẫn>…]"
+#: builtin/reset.c:33
+#| msgid "git reset [-q] [<tree-ish>] [--] <paths>..."
+msgid "git reset [-q] [<tree-ish>] [--] <pathspec>..."
+msgstr "git reset [-q] [<tree-ish>] [--] <đặc/tả/đường/dẫn>..."
+
+#: builtin/reset.c:34
+msgid ""
+"git reset [-q] [--pathspec-from-file [--pathspec-file-nul]] [<tree-ish>]"
+msgstr ""
+"git reset [-q] [--pathspec-from-file [--pathspec-file-nul]] [<tree-ish>]"
 
-#: builtin/reset.c:37
+#: builtin/reset.c:35
+#| msgid "git reset --patch [<tree-ish>] [--] [<paths>...]"
+msgid "git reset --patch [<tree-ish>] [--] [<pathspec>...]"
+msgstr "git reset --patch [<tree-ish>] [--] [<đặc/tả/đường/dẫn>...]"
+
+#: builtin/reset.c:41
 msgid "mixed"
 msgstr "pha trộn"
 
-#: builtin/reset.c:37
+#: builtin/reset.c:41
 msgid "soft"
 msgstr "mềm"
 
-#: builtin/reset.c:37
+#: builtin/reset.c:41
 msgid "hard"
 msgstr "cứng"
 
-#: builtin/reset.c:37
+#: builtin/reset.c:41
 msgid "merge"
 msgstr "hòa trộn"
 
-#: builtin/reset.c:37
+#: builtin/reset.c:41
 msgid "keep"
 msgstr "giữ lại"
 
-#: builtin/reset.c:78
+#: builtin/reset.c:82
 msgid "You do not have a valid HEAD."
 msgstr "Bạn không có HEAD nào hợp lệ."
 
-#: builtin/reset.c:80
+#: builtin/reset.c:84
 msgid "Failed to find tree of HEAD."
 msgstr "Gặp lỗi khi tìm cây của HEAD."
 
-#: builtin/reset.c:86
+#: builtin/reset.c:90
 #, c-format
 msgid "Failed to find tree of %s."
 msgstr "Gặp lỗi khi tìm cây của %s."
 
-#: builtin/reset.c:111
+#: builtin/reset.c:115
 #, c-format
 msgid "HEAD is now at %s"
 msgstr "HEAD hiện giờ tại %s"
 
-#: builtin/reset.c:189
+#: builtin/reset.c:194
 #, c-format
 msgid "Cannot do a %s reset in the middle of a merge."
 msgstr "Không thể thực hiện một %s reset ở giữa của quá trình hòa trộn."
 
-#: builtin/reset.c:289
+#: builtin/reset.c:294 builtin/stash.c:519 builtin/stash.c:594
+#: builtin/stash.c:618
 msgid "be quiet, only report errors"
 msgstr "làm việc ở chế độ im lặng, chỉ hiển thị khi có lỗi"
 
-#: builtin/reset.c:291
+#: builtin/reset.c:296
 msgid "reset HEAD and index"
 msgstr "đặt lại (reset) HEAD và bảng mục lục"
 
-#: builtin/reset.c:292
+#: builtin/reset.c:297
 msgid "reset only HEAD"
 msgstr "chỉ đặt lại (reset) HEAD"
 
-#: builtin/reset.c:294 builtin/reset.c:296
+#: builtin/reset.c:299 builtin/reset.c:301
 msgid "reset HEAD, index and working tree"
 msgstr "đặt lại HEAD, bảng mục lục và cây làm việc"
 
-#: builtin/reset.c:298
+#: builtin/reset.c:303
 msgid "reset HEAD but keep local changes"
 msgstr "đặt lại HEAD nhưng giữ lại các thay đổi nội bộ"
 
-#: builtin/reset.c:304
+#: builtin/reset.c:309
 msgid "record only the fact that removed paths will be added later"
 msgstr "chỉ ghi lại những đường dẫn thực sự sẽ được thêm vào sau này"
 
-#: builtin/reset.c:321
+#: builtin/reset.c:343
 #, c-format
 msgid "Failed to resolve '%s' as a valid revision."
 msgstr "Gặp lỗi khi phân giải “%s” như là điểm xét duyệt hợp lệ."
 
-#: builtin/reset.c:329
+#: builtin/reset.c:351
 #, c-format
 msgid "Failed to resolve '%s' as a valid tree."
 msgstr "Gặp lỗi khi phân giải “%s” như là một cây (tree) hợp lệ."
 
-#: builtin/reset.c:338
+#: builtin/reset.c:360
 msgid "--patch is incompatible with --{hard,mixed,soft}"
 msgstr "--patch xung khắc với --{hard,mixed,soft}"
 
-#: builtin/reset.c:347
+#: builtin/reset.c:370
 msgid "--mixed with paths is deprecated; use 'git reset -- <paths>' instead."
 msgstr ""
 "--mixed với các đường dẫn không còn dùng nữa; hãy thay thế bằng lệnh “git "
-"reset -- <đường_dẫn>”."
+"reset -- </các/đường/dẫn>”."
 
-#: builtin/reset.c:349
+#: builtin/reset.c:372
 #, c-format
 msgid "Cannot do %s reset with paths."
 msgstr "Không thể thực hiện lệnh %s reset với các đường dẫn."
 
-#: builtin/reset.c:359
+#: builtin/reset.c:387
 #, c-format
 msgid "%s reset is not allowed in a bare repository"
 msgstr "%s reset không được phép trên kho thuần"
 
-#: builtin/reset.c:363
+#: builtin/reset.c:391
 msgid "-N can only be used with --mixed"
 msgstr "-N chỉ được dùng khi có --mixed"
 
-#: builtin/reset.c:380
+#: builtin/reset.c:412
 msgid "Unstaged changes after reset:"
 msgstr "Những thay đổi được đưa ra khỏi bệ phóng sau khi reset:"
 
-#: builtin/reset.c:386
+#: builtin/reset.c:415
+#, c-format
+msgid ""
+"\n"
+"It took %.2f seconds to enumerate unstaged changes after reset.  You can\n"
+"use '--quiet' to avoid this.  Set the config setting reset.quiet to true\n"
+"to make this the default.\n"
+msgstr ""
+"\n"
+"Cần %.2f giây để kiểm đếm các thay đổi chưa đưa lên bệ phóng sau khi đặt "
+"lại.\n"
+"Bạn có thể sử dụng để tránh việc này. Đặt reset.quiet thành true trong\n"
+"cài đặt config nếu bạn muốn thực hiện nó như là mặc định.\n"
+
+#: builtin/reset.c:425
 #, c-format
 msgid "Could not reset index file to revision '%s'."
 msgstr "Không thể đặt lại (reset) bảng mục lục thành điểm xét duyệt “%s”."
 
-#: builtin/reset.c:390
+#: builtin/reset.c:429
 msgid "Could not write new index file."
 msgstr "Không thể ghi tập tin lưu bảng mục lục mới."
 
-#: builtin/rev-list.c:397
+#: builtin/rev-list.c:411
 msgid "cannot combine --exclude-promisor-objects and --missing"
 msgstr "không thể tổ hợp --exclude-promisor-objects và --missing"
 
-#: builtin/rev-list.c:455
+#: builtin/rev-list.c:472
 msgid "object filtering requires --objects"
 msgstr "lọc đối tượng yêu cầu --objects"
 
-#: builtin/rev-list.c:458
-#, c-format
-msgid "invalid sparse value '%s'"
-msgstr "giá trị sparse không hợp lệ “%s”"
-
-#: builtin/rev-list.c:499
+#: builtin/rev-list.c:522
 msgid "rev-list does not support display of notes"
 msgstr "rev-list không hỗ trợ hiển thị các ghi chú"
 
-#: builtin/rev-list.c:502
+#: builtin/rev-list.c:525
 msgid "cannot combine --use-bitmap-index with object filtering"
 msgstr "không thể tổ hợp --use-bitmap-index với lọc đối tượng"
 
-#: builtin/rev-parse.c:406
+#: builtin/rev-parse.c:408
 msgid "git rev-parse --parseopt [<options>] -- [<args>...]"
-msgstr "git rev-parse --parseopt [<các-tùy-chọn>] -- [<các tham số>…]"
+msgstr "git rev-parse --parseopt [<các tùy chọn>] -- [<các tham số>…]"
 
-#: builtin/rev-parse.c:411
+#: builtin/rev-parse.c:413
 msgid "keep the `--` passed as an arg"
 msgstr "giữ lại “--” chuyển sang làm tham số"
 
-#: builtin/rev-parse.c:413
+#: builtin/rev-parse.c:415
 msgid "stop parsing after the first non-option argument"
 msgstr "dừng phân tích sau đối số đầu tiên không có tùy chọn"
 
-#: builtin/rev-parse.c:416
+#: builtin/rev-parse.c:418
 msgid "output in stuck long form"
 msgstr "kết xuất trong định dạng gậy dài"
 
-#: builtin/rev-parse.c:549
+#: builtin/rev-parse.c:551
 msgid ""
 "git rev-parse --parseopt [<options>] -- [<args>...]\n"
 "   or: git rev-parse --sq-quote [<arg>...]\n"
@@ -13747,98 +19594,103 @@ msgid ""
 "\n"
 "Run \"git rev-parse --parseopt -h\" for more information on the first usage."
 msgstr ""
-"git rev-parse --parseopt [<các-tùy-chọn>] -- [<các đối số>…]\n"
+"git rev-parse --parseopt [<các tùy chọn>] -- [<các đối số>…]\n"
 "   hoặc: git rev-parse --sq-quote [<đ.số>…]\n"
-"   hoặc: git rev-parse [<các-tùy-chọn>] [<đ.số>…]\n"
+"   hoặc: git rev-parse [<các tùy chọn>] [<đ.số>…]\n"
 "\n"
 "Chạy lệnh \"git rev-parse --parseopt -h\" để có thêm thông tin về cách dùng."
 
-#: builtin/revert.c:23
+#: builtin/revert.c:24
 msgid "git revert [<options>] <commit-ish>..."
-msgstr "git revert [<các-tùy-chọn>] <commit-ish>…"
+msgstr "git revert [<các tùy chọn>] <commit-ish>…"
 
-#: builtin/revert.c:24
+#: builtin/revert.c:25
 msgid "git revert <subcommand>"
 msgstr "git revert <lệnh-con>"
 
-#: builtin/revert.c:29
+#: builtin/revert.c:30
 msgid "git cherry-pick [<options>] <commit-ish>..."
-msgstr "git cherry-pick [<các-tùy-chọn>] <commit-ish>…"
+msgstr "git cherry-pick [<các tùy chọn>] <commit-ish>…"
 
-#: builtin/revert.c:30
+#: builtin/revert.c:31
 msgid "git cherry-pick <subcommand>"
 msgstr "git cherry-pick <lệnh-con>"
 
-#: builtin/revert.c:90
+#: builtin/revert.c:72
+#, c-format
+msgid "option `%s' expects a number greater than zero"
+msgstr "tùy chọn “%s” cần một giá trị bằng số lớn hơn không"
+
+#: builtin/revert.c:92
 #, c-format
 msgid "%s: %s cannot be used with %s"
 msgstr "%s: %s không thể được sử dụng với %s"
 
-#: builtin/revert.c:99
+#: builtin/revert.c:102
 msgid "end revert or cherry-pick sequence"
 msgstr "kết thúc cherry-pick hay hoàn nguyên liên tiếp nhau"
 
-#: builtin/revert.c:100
+#: builtin/revert.c:103
 msgid "resume revert or cherry-pick sequence"
 msgstr "phục hồi lại cherry-pick hay hoàn nguyên liên tiếp nhau"
 
-#: builtin/revert.c:101
+#: builtin/revert.c:104
 msgid "cancel revert or cherry-pick sequence"
 msgstr "không cherry-pick hay hoàn nguyên liên tiếp nhau"
 
-#: builtin/revert.c:102
+#: builtin/revert.c:105
+msgid "skip current commit and continue"
+msgstr "bỏ qua lần chuyển giao hiện tại và tiếp tục"
+
+#: builtin/revert.c:107
 msgid "don't automatically commit"
-msgstr "không chuyển giao một cách tự động."
+msgstr "đừng chuyển giao một cách tự động"
 
-#: builtin/revert.c:103
+#: builtin/revert.c:108
 msgid "edit the commit message"
 msgstr "sửa lại chú thích cho lần chuyển giao"
 
-#: builtin/revert.c:106
+#: builtin/revert.c:111
 msgid "parent-number"
 msgstr "số-cha-mẹ"
 
-#: builtin/revert.c:107
+#: builtin/revert.c:112
 msgid "select mainline parent"
 msgstr "chọn cha mẹ luồng chính"
 
-#: builtin/revert.c:109
+#: builtin/revert.c:114
 msgid "merge strategy"
 msgstr "chiến lược hòa trộn"
 
-#: builtin/revert.c:110
-msgid "option"
-msgstr "tùy chọn"
-
-#: builtin/revert.c:111
+#: builtin/revert.c:116
 msgid "option for merge strategy"
 msgstr "tùy chọn cho chiến lược hòa trộn"
 
-#: builtin/revert.c:120
+#: builtin/revert.c:125
 msgid "append commit name"
 msgstr "nối thêm tên lần chuyển giao"
 
-#: builtin/revert.c:122
+#: builtin/revert.c:127
 msgid "preserve initially empty commits"
 msgstr "cấm khởi tạo lần chuyển giao trống rỗng"
 
-#: builtin/revert.c:124
+#: builtin/revert.c:129
 msgid "keep redundant, empty commits"
 msgstr "giữ lại các lần chuyển giao dư thừa, rỗng"
 
-#: builtin/revert.c:214
+#: builtin/revert.c:232
 msgid "revert failed"
 msgstr "hoàn nguyên gặp lỗi"
 
-#: builtin/revert.c:227
+#: builtin/revert.c:245
 msgid "cherry-pick failed"
 msgstr "cherry-pick gặp lỗi"
 
-#: builtin/rm.c:18
+#: builtin/rm.c:19
 msgid "git rm [<options>] [--] <file>..."
-msgstr "git rm [<các-tùy-chọn>] [--] <tập-tin>…"
+msgstr "git rm [<các tùy chọn>] [--] <tập-tin>…"
 
-#: builtin/rm.c:206
+#: builtin/rm.c:207
 msgid ""
 "the following file has staged content different from both the\n"
 "file and the HEAD:"
@@ -13849,7 +19701,7 @@ msgstr[0] ""
 "các tập tin sau đây có khác biệt nội dung đã đưa lên bệ phóng\n"
 "từ cả tập tin và cả HEAD:"
 
-#: builtin/rm.c:211
+#: builtin/rm.c:212
 msgid ""
 "\n"
 "(use -f to force removal)"
@@ -13857,12 +19709,12 @@ msgstr ""
 "\n"
 "(dùng -f để buộc gỡ bỏ)"
 
-#: builtin/rm.c:215
+#: builtin/rm.c:216
 msgid "the following file has changes staged in the index:"
 msgid_plural "the following files have changes staged in the index:"
 msgstr[0] "các tập tin sau đây có thay đổi trạng thái trong bảng mục lục:"
 
-#: builtin/rm.c:219 builtin/rm.c:228
+#: builtin/rm.c:220 builtin/rm.c:229
 msgid ""
 "\n"
 "(use --cached to keep the file, or -f to force removal)"
@@ -13870,46 +19722,46 @@ msgstr ""
 "\n"
 "(dùng tùy chọn --cached để giữ tập tin, hoặc -f để ép buộc gỡ bỏ)"
 
-#: builtin/rm.c:225
+#: builtin/rm.c:226
 msgid "the following file has local modifications:"
 msgid_plural "the following files have local modifications:"
 msgstr[0] "những tập tin sau đây có những thay đổi nội bộ:"
 
-#: builtin/rm.c:241
+#: builtin/rm.c:242
 msgid "do not list removed files"
 msgstr "không liệt kê các tập tin đã gỡ bỏ"
 
-#: builtin/rm.c:242
+#: builtin/rm.c:243
 msgid "only remove from the index"
 msgstr "chỉ gỡ bỏ từ mục lục"
 
-#: builtin/rm.c:243
+#: builtin/rm.c:244
 msgid "override the up-to-date check"
 msgstr "ghi đè lên kiểm tra cập nhật"
 
-#: builtin/rm.c:244
+#: builtin/rm.c:245
 msgid "allow recursive removal"
 msgstr "cho phép gỡ bỏ đệ qui"
 
-#: builtin/rm.c:246
+#: builtin/rm.c:247
 msgid "exit with a zero status even if nothing matched"
 msgstr "thoát ra với trạng thái khác không thậm chí nếu không có gì khớp"
 
-#: builtin/rm.c:306
+#: builtin/rm.c:289
+msgid "please stage your changes to .gitmodules or stash them to proceed"
+msgstr ""
+"hãy đưa các thay đổi của bạn vào .gitmodules hay tạm cất chúng đi để xử lý"
+
+#: builtin/rm.c:307
 #, c-format
 msgid "not removing '%s' recursively without -r"
 msgstr "không thể gỡ bỏ “%s” một cách đệ qui mà không có tùy chọn -r"
 
-#: builtin/rm.c:345
+#: builtin/rm.c:346
 #, c-format
 msgid "git rm: unable to remove %s"
 msgstr "git rm: không thể gỡ bỏ %s"
 
-#: builtin/rm.c:368
-#, c-format
-msgid "could not remove '%s'"
-msgstr "không thể gỡ bỏ “%s”"
-
 #: builtin/send-pack.c:20
 msgid ""
 "git send-pack [--all | --mirror] [--dry-run] [--force] [--receive-pack=<git-"
@@ -13938,25 +19790,13 @@ msgstr "đọc tham chiếu từ đầu
 msgid "print status from remote helper"
 msgstr "in các trạng thái từ phần hướng dẫn trên máy dịch vụ"
 
-#: builtin/serve.c:7
-msgid "git serve [<options>]"
-msgstr "git serve [<các-tùy-chọn>]"
-
-#: builtin/serve.c:17 builtin/upload-pack.c:23
-msgid "quit after a single request/response exchange"
-msgstr "thoát sau khi một trao đổi yêu cầu hay trả lời đơn"
-
-#: builtin/serve.c:19
-msgid "exit immediately after advertising capabilities"
-msgstr "thoát ngay sau khi khởi tạo quảng cáo capabilities"
-
 #: builtin/shortlog.c:14
 msgid "git shortlog [<options>] [<revision-range>] [[--] <path>...]"
-msgstr "git shortlog [<các-tùy-chọn>] [<vùng-xét-duyệt>] [[--] [<đường/dẫn>…]]"
+msgstr "git shortlog [<các tùy chọn>] [<vùng-xét-duyệt>] [[--] [<đường/dẫn>…]]"
 
 #: builtin/shortlog.c:15
 msgid "git log --pretty=short | git shortlog [<options>]"
-msgstr "git log --pretty=short | git shortlog [<các-tùy-chọn>]"
+msgstr "git log --pretty=short | git shortlog [<các tùy chọn>]"
 
 #: builtin/shortlog.c:264
 msgid "Group by committer rather than author"
@@ -13975,18 +19815,18 @@ msgid "Show the email address of each au
 msgstr "Hiển thị thư điện tử cho từng tác giả"
 
 #: builtin/shortlog.c:271
-msgid "w[,i1[,i2]]"
-msgstr "w[,i1[,i2]]"
+msgid "<w>[,<i1>[,<i2>]]"
+msgstr "<w>[,<i1>[,<i2>]]"
 
 #: builtin/shortlog.c:272
 msgid "Linewrap output"
 msgstr "Ngắt dòng khi quá dài"
 
-#: builtin/shortlog.c:298
+#: builtin/shortlog.c:301
 msgid "too many arguments given outside repository"
 msgstr "quá nhiều tham số đưa ra ngoài kho chứa"
 
-#: builtin/show-branch.c:12
+#: builtin/show-branch.c:13
 msgid ""
 "git show-branch [-a | --all] [-r | --remotes] [--topo-order | --date-order]\n"
 "\t\t[--current] [--color[=<when>] | --no-color] [--sparse]\n"
@@ -13998,174 +19838,454 @@ msgstr ""
 "\t\t[--more=<n> | --list | --independent | --merge-base]\n"
 "\t\t[--no-name | --sha1-name] [--topics] [(<rev> | <glob>)…]"
 
-#: builtin/show-branch.c:16
+#: builtin/show-branch.c:17
 msgid "git show-branch (-g | --reflog)[=<n>[,<base>]] [--list] [<ref>]"
 msgstr "git show-branch (-g | --reflog)[=<n>[,<nền>]] [--list] [<ref>]"
 
-#: builtin/show-branch.c:376
+#: builtin/show-branch.c:395
 #, c-format
 msgid "ignoring %s; cannot handle more than %d ref"
 msgid_plural "ignoring %s; cannot handle more than %d refs"
 msgstr[0] "đang bỏ qua %s; không thể xử lý nhiều hơn %d tham chiếu"
 
-#: builtin/show-branch.c:530
+#: builtin/show-branch.c:548
 #, c-format
 msgid "no matching refs with %s"
 msgstr "không tham chiếu nào khớp với %s"
 
-#: builtin/show-branch.c:626
+#: builtin/show-branch.c:645
 msgid "show remote-tracking and local branches"
 msgstr "hiển thị các nhánh remote-tracking và nội bộ"
 
-#: builtin/show-branch.c:628
+#: builtin/show-branch.c:647
 msgid "show remote-tracking branches"
 msgstr "hiển thị các nhánh remote-tracking"
 
-#: builtin/show-branch.c:630
+#: builtin/show-branch.c:649
 msgid "color '*!+-' corresponding to the branch"
 msgstr "màu “*!+-” tương ứng với nhánh"
 
-#: builtin/show-branch.c:632
+#: builtin/show-branch.c:651
 msgid "show <n> more commits after the common ancestor"
 msgstr "hiển thị thêm <n> lần chuyển giao sau cha mẹ chung"
 
-#: builtin/show-branch.c:634
+#: builtin/show-branch.c:653
 msgid "synonym to more=-1"
 msgstr "đồng nghĩa với more=-1"
 
-#: builtin/show-branch.c:635
+#: builtin/show-branch.c:654
 msgid "suppress naming strings"
 msgstr "chặn các chuỗi đặt tên"
 
-#: builtin/show-branch.c:637
+#: builtin/show-branch.c:656
 msgid "include the current branch"
 msgstr "bao gồm nhánh hiện hành"
 
-#: builtin/show-branch.c:639
+#: builtin/show-branch.c:658
 msgid "name commits with their object names"
 msgstr "đặt tên các lần chuyển giao bằng các tên của đối tượng của chúng"
 
-#: builtin/show-branch.c:641
+#: builtin/show-branch.c:660
 msgid "show possible merge bases"
 msgstr "hiển thị mọi cơ sở có thể dùng để hòa trộn"
 
-#: builtin/show-branch.c:643
+#: builtin/show-branch.c:662
 msgid "show refs unreachable from any other ref"
 msgstr "hiển thị các tham chiếu không thể được đọc bởi bất kỳ tham chiếu khác"
 
-#: builtin/show-branch.c:645
+#: builtin/show-branch.c:664
 msgid "show commits in topological order"
 msgstr "hiển thị các lần chuyển giao theo thứ tự tôpô"
 
-#: builtin/show-branch.c:648
+#: builtin/show-branch.c:667
 msgid "show only commits not on the first branch"
 msgstr "chỉ hiển thị các lần chuyển giao không nằm trên nhánh đầu tiên"
 
-#: builtin/show-branch.c:650
+#: builtin/show-branch.c:669
 msgid "show merges reachable from only one tip"
 msgstr "hiển thị các lần hòa trộn có thể đọc được chỉ từ một đầu mút"
 
-#: builtin/show-branch.c:652
+#: builtin/show-branch.c:671
 msgid "topologically sort, maintaining date order where possible"
 msgstr "sắp xếp hình thái học, bảo trì thứ tự ngày nếu có thể"
 
-#: builtin/show-branch.c:655
+#: builtin/show-branch.c:674
 msgid "<n>[,<base>]"
 msgstr "<n>[,<cơ_sở>]"
 
-#: builtin/show-branch.c:656
+#: builtin/show-branch.c:675
 msgid "show <n> most recent ref-log entries starting at base"
 msgstr "hiển thị <n> các mục “ref-log” gần nhất kể từ nền (base)"
 
-#: builtin/show-branch.c:690
+#: builtin/show-branch.c:711
 msgid ""
 "--reflog is incompatible with --all, --remotes, --independent or --merge-base"
 msgstr ""
 "--reflog là không tương thích với các tùy chọn --all, --remotes, --"
 "independent hay --merge-base"
 
-#: builtin/show-branch.c:714
+#: builtin/show-branch.c:735
 msgid "no branches given, and HEAD is not valid"
 msgstr "chưa đưa ra nhánh, và HEAD không hợp lệ"
 
-#: builtin/show-branch.c:717
+#: builtin/show-branch.c:738
 msgid "--reflog option needs one branch name"
 msgstr "--reflog cần tên một nhánh"
 
-#: builtin/show-branch.c:720
+#: builtin/show-branch.c:741
 #, c-format
 msgid "only %d entry can be shown at one time."
 msgid_plural "only %d entries can be shown at one time."
 msgstr[0] "chỉ có thể hiển thị cùng lúc %d hạng mục."
 
-#: builtin/show-branch.c:724
+#: builtin/show-branch.c:745
 #, c-format
 msgid "no such ref %s"
 msgstr "không có tham chiếu nào như thế %s"
 
-#: builtin/show-branch.c:808
+#: builtin/show-branch.c:831
 #, c-format
 msgid "cannot handle more than %d rev."
 msgid_plural "cannot handle more than %d revs."
 msgstr[0] "không thể xử lý nhiều hơn %d điểm xét duyệt."
 
-#: builtin/show-branch.c:812
+#: builtin/show-branch.c:835
 #, c-format
 msgid "'%s' is not a valid ref."
 msgstr "“%s” không phải tham chiếu hợp lệ."
 
-#: builtin/show-branch.c:815
+#: builtin/show-branch.c:838
 #, c-format
 msgid "cannot find commit %s (%s)"
 msgstr "không thể tìm thấy lần chuyển giao %s (%s)"
 
-#: builtin/show-ref.c:10
+#: builtin/show-ref.c:12
 msgid ""
 "git show-ref [-q | --quiet] [--verify] [--head] [-d | --dereference] [-s | --"
 "hash[=<n>]] [--abbrev[=<n>]] [--tags] [--heads] [--] [<pattern>...]"
 msgstr ""
-"git show-ref [-q | --quiet] [--verify] [--head] [-d|--dereference] [-s|--"
-"hash[=<n>]] [--abbrev[=<n>]] [--tags] [--heads] [--] [<mẫu>…] "
+"git show-ref [-q | --quiet] [--verify] [--head] [-d | --dereference] [-s | --"
+"hash[=<n>]] [--abbrev[=<n>]] [--tags] [--heads] [--] [<mẫu>…]"
 
-#: builtin/show-ref.c:11
+#: builtin/show-ref.c:13
 msgid "git show-ref --exclude-existing[=<pattern>]"
 msgstr "git show-ref --exclude-existing[=<mẫu>]"
 
-#: builtin/show-ref.c:159
+#: builtin/show-ref.c:162
 msgid "only show tags (can be combined with heads)"
 msgstr "chỉ hiển thị thẻ (có thể tổ hợp cùng với đầu)"
 
-#: builtin/show-ref.c:160
+#: builtin/show-ref.c:163
 msgid "only show heads (can be combined with tags)"
 msgstr "chỉ hiển thị đầu (có thể tổ hợp cùng với thẻ)"
 
-#: builtin/show-ref.c:161
+#: builtin/show-ref.c:164
 msgid "stricter reference checking, requires exact ref path"
 msgstr ""
 "việc kiểm tra tham chiếu chính xác, đòi hỏi chính xác đường dẫn tham chiếu"
 
-#: builtin/show-ref.c:164 builtin/show-ref.c:166
+#: builtin/show-ref.c:167 builtin/show-ref.c:169
 msgid "show the HEAD reference, even if it would be filtered out"
 msgstr "hiển thị tham chiếu HEAD, ngay cả khi nó đã được lọc ra"
 
-#: builtin/show-ref.c:168
-msgid "dereference tags into object IDs"
-msgstr "bãi bỏ tham chiếu các thẻ thành ra các ID đối tượng"
+#: builtin/show-ref.c:171
+msgid "dereference tags into object IDs"
+msgstr "bãi bỏ tham chiếu các thẻ thành ra các ID đối tượng"
+
+#: builtin/show-ref.c:173
+msgid "only show SHA1 hash using <n> digits"
+msgstr "chỉ hiển thị mã băm SHA1 sử dụng <n> chữ số"
+
+#: builtin/show-ref.c:177
+msgid "do not print results to stdout (useful with --verify)"
+msgstr ""
+"không hiển thị kết quả ra đầu ra chuẩn (stdout) (chỉ hữu dụng với --verify)"
+
+#: builtin/show-ref.c:179
+msgid "show refs from stdin that aren't in local repository"
+msgstr ""
+"hiển thị các tham chiếu từ đầu vào tiêu chuẩn (stdin) cái mà không ở kho nội "
+"bộ"
+
+#: builtin/sparse-checkout.c:20
+msgid "git sparse-checkout (init|list|set|disable) <options>"
+msgstr "git sparse-checkout (init|list|set|disable) <các-tùy-chọn>"
+
+#: builtin/sparse-checkout.c:61
+msgid "this worktree is not sparse (sparse-checkout file may not exist)"
+msgstr ""
+"không thể phân tích cú pháp cây làm việc này (tập tin sparse-checkout có lẽ "
+"không tồn tại)"
+
+#: builtin/sparse-checkout.c:220
+msgid "failed to set extensions.worktreeConfig setting"
+msgstr "gặp lỗi khi đặt cài đặt extensions.worktreeConfig"
+
+#: builtin/sparse-checkout.c:237
+msgid "git sparse-checkout init [--cone]"
+msgstr "git sparse-checkout init [--cone]"
+
+#: builtin/sparse-checkout.c:256
+msgid "initialize the sparse-checkout in cone mode"
+msgstr "khởi tạo sparse-checkout trong chế độ nón"
+
+#: builtin/sparse-checkout.c:262
+#| msgid "skip applying sparse checkout filter"
+msgid "initialize sparse-checkout"
+msgstr "khởi tạo sparse-checkout"
+
+#: builtin/sparse-checkout.c:295
+#, c-format
+msgid "failed to open '%s'"
+msgstr "gặp lỗi khi mở “%s”"
+
+#: builtin/sparse-checkout.c:361
+#| msgid "git hash-object  --stdin-paths"
+msgid "git sparse-checkout set (--stdin | <patterns>)"
+msgstr "git sparse-checkout set (--stdin | <các mẫu>)"
+
+#: builtin/sparse-checkout.c:378
+msgid "read patterns from standard in"
+msgstr "đọc các mẫu từ đầu vào tiêu chuẩn"
+
+#: builtin/sparse-checkout.c:384
+msgid "set sparse-checkout patterns"
+msgstr "đặt các mẫu sparse-checkout"
+
+#: builtin/sparse-checkout.c:447
+msgid "disable sparse-checkout"
+msgstr "tắt sparse-checkout"
+
+#: builtin/sparse-checkout.c:459
+msgid "error while refreshing working directory"
+msgstr "gặp lỗi khi đọc lại thư mục làm việc"
+
+#: builtin/stash.c:22 builtin/stash.c:37
+msgid "git stash list [<options>]"
+msgstr "git stash list [<các tùy chọn>]"
+
+#: builtin/stash.c:23 builtin/stash.c:42
+msgid "git stash show [<options>] [<stash>]"
+msgstr "git stash show [<các tùy chọn>] <stash>"
+
+#: builtin/stash.c:24 builtin/stash.c:47
+msgid "git stash drop [-q|--quiet] [<stash>]"
+msgstr "git stash drop [-q|--quiet] [<stash>]"
+
+#: builtin/stash.c:25
+msgid "git stash ( pop | apply ) [--index] [-q|--quiet] [<stash>]"
+msgstr "git stash ( pop | apply ) [--index] [-q|--quiet] [<stash>]"
+
+#: builtin/stash.c:26 builtin/stash.c:62
+msgid "git stash branch <branchname> [<stash>]"
+msgstr "git stash branch <tên-nhánh> [<stash>]"
+
+#: builtin/stash.c:27 builtin/stash.c:67
+msgid "git stash clear"
+msgstr "git stash clear"
+
+#: builtin/stash.c:28 builtin/stash.c:77
+msgid ""
+"git stash [push [-p|--patch] [-k|--[no-]keep-index] [-q|--quiet]\n"
+"          [-u|--include-untracked] [-a|--all] [-m|--message <message>]\n"
+"          [--] [<pathspec>...]]"
+msgstr ""
+"git stash [push [-p|--patch] [-k|--[no-]keep-index] [-q|--quiet]\n"
+"          [-u|--include-untracked] [-a|--all] [-m|--message <lời nhắn>]\n"
+"          [--] [<đặc/tả/đường/dẫn>…]]"
+
+#: builtin/stash.c:31 builtin/stash.c:84
+msgid ""
+"git stash save [-p|--patch] [-k|--[no-]keep-index] [-q|--quiet]\n"
+"          [-u|--include-untracked] [-a|--all] [<message>]"
+msgstr ""
+"git stash save [-p|--patch] [-k|--[no-]keep-index] [-q|--quiet]\n"
+"          [-u|--include-untracked] [-a|--all] [<ghi chú>]"
+
+#: builtin/stash.c:52
+msgid "git stash pop [--index] [-q|--quiet] [<stash>]"
+msgstr "git stash pop [--index] [-q|--quiet] [<stash>]"
+
+#: builtin/stash.c:57
+msgid "git stash apply [--index] [-q|--quiet] [<stash>]"
+msgstr "git stash apply [--index] [-q|--quiet] [<stash>]"
+
+#: builtin/stash.c:72
+msgid "git stash store [-m|--message <message>] [-q|--quiet] <commit>"
+msgstr "git stash store [-m|--message <ghi chú>] [-q|--quiet] <commit>"
+
+#: builtin/stash.c:127
+#, c-format
+msgid "'%s' is not a stash-like commit"
+msgstr "“%s” không phải là lần chuyển giao kiểu-stash (cất đi)"
+
+#: builtin/stash.c:147
+#, c-format
+msgid "Too many revisions specified:%s"
+msgstr "Chỉ ra quá nhiều điểm xét duyệt: %s"
+
+#: builtin/stash.c:161 git-legacy-stash.sh:549
+msgid "No stash entries found."
+msgstr "Không tìm thấy các mục tạm cất (stash) nào."
+
+#: builtin/stash.c:175
+#, c-format
+msgid "%s is not a valid reference"
+msgstr "“%s” không phải một tham chiếu hợp lệ"
+
+#: builtin/stash.c:224 git-legacy-stash.sh:75
+msgid "git stash clear with parameters is unimplemented"
+msgstr ""
+"git stash clear với các tham số là chưa được thực hiện (không nhận đối số)"
+
+#: builtin/stash.c:403
+msgid "cannot apply a stash in the middle of a merge"
+msgstr "không thể áp dụng một stash ở giữa của quá trình hòa trộn"
+
+#: builtin/stash.c:414
+#, c-format
+msgid "could not generate diff %s^!."
+msgstr "không thể tạo diff %s^!."
+
+#: builtin/stash.c:421
+msgid "conflicts in index.Try without --index."
+msgstr "xung đột trong bảng mục lục. Hãy thử mà không dùng tùy chọn --index."
+
+#: builtin/stash.c:427
+msgid "could not save index tree"
+msgstr "không thể ghi lại cây chỉ mục"
+
+#: builtin/stash.c:436
+msgid "could not restore untracked files from stash"
+msgstr "không thể phục hồi các tập tin chưa theo dõi từ mục cất đi (stash)"
+
+#: builtin/stash.c:450
+#, c-format
+msgid "Merging %s with %s"
+msgstr "Đang hòa trộn %s với %s"
+
+#: builtin/stash.c:460 git-legacy-stash.sh:681
+msgid "Index was not unstashed."
+msgstr "Bảng mục lục đã không được bỏ stash."
+
+#: builtin/stash.c:521 builtin/stash.c:620
+msgid "attempt to recreate the index"
+msgstr "gặp lỗi đọc bảng mục lục"
+
+#: builtin/stash.c:554
+#, c-format
+msgid "Dropped %s (%s)"
+msgstr "Đã xóa %s (%s)"
+
+#: builtin/stash.c:557
+#, c-format
+msgid "%s: Could not drop stash entry"
+msgstr "%s: Không thể xóa bỏ mục stash"
+
+#: builtin/stash.c:582
+#, c-format
+msgid "'%s' is not a stash reference"
+msgstr "”%s” không phải tham chiếu đến stash"
+
+#: builtin/stash.c:632 git-legacy-stash.sh:695
+msgid "The stash entry is kept in case you need it again."
+msgstr "Các mục tạm cất (stash) được giữ trong trường hợp bạn lại cần nó."
+
+#: builtin/stash.c:655 git-legacy-stash.sh:713
+msgid "No branch name specified"
+msgstr "Chưa chỉ ra tên của nhánh"
+
+#: builtin/stash.c:795 builtin/stash.c:832
+#, c-format
+msgid "Cannot update %s with %s"
+msgstr "Không thể cập nhật %s với %s"
+
+#: builtin/stash.c:813 builtin/stash.c:1470 builtin/stash.c:1506
+msgid "stash message"
+msgstr "phần chú thích cho stash"
+
+#: builtin/stash.c:823
+msgid "\"git stash store\" requires one <commit> argument"
+msgstr "\"git stash store\" cần một đối số <lần chuyển giao>"
+
+#: builtin/stash.c:1045 git-legacy-stash.sh:218
+msgid "No changes selected"
+msgstr "Chưa có thay đổi nào được chọn"
+
+#: builtin/stash.c:1145 git-legacy-stash.sh:150
+msgid "You do not have the initial commit yet"
+msgstr "Bạn chưa còn có lần chuyển giao khởi tạo"
+
+#: builtin/stash.c:1172 git-legacy-stash.sh:165
+msgid "Cannot save the current index state"
+msgstr "Không thể ghi lại trạng thái bảng mục lục hiện hành"
+
+#: builtin/stash.c:1181 git-legacy-stash.sh:180
+msgid "Cannot save the untracked files"
+msgstr "Không thể ghi lại các tập tin chưa theo dõi"
+
+#: builtin/stash.c:1192 builtin/stash.c:1201 git-legacy-stash.sh:201
+#: git-legacy-stash.sh:214
+msgid "Cannot save the current worktree state"
+msgstr "Không thể ghi lại trạng thái cây-làm-việc hiện hành"
+
+#: builtin/stash.c:1229 git-legacy-stash.sh:234
+msgid "Cannot record working tree state"
+msgstr "Không thể ghi lại trạng thái cây làm việc hiện hành"
+
+#: builtin/stash.c:1278 git-legacy-stash.sh:338
+msgid "Can't use --patch and --include-untracked or --all at the same time"
+msgstr "Không thể dùng --patch và --include-untracked hay --all cùng một lúc"
+
+#: builtin/stash.c:1294
+msgid "Did you forget to 'git add'?"
+msgstr "Có lẽ bạn đã quên “git add ” phải không?"
+
+#: builtin/stash.c:1309 git-legacy-stash.sh:346
+msgid "No local changes to save"
+msgstr "Không có thay đổi nội bộ nào được ghi lại"
+
+#: builtin/stash.c:1316 git-legacy-stash.sh:351
+msgid "Cannot initialize stash"
+msgstr "Không thể khởi tạo stash"
+
+#: builtin/stash.c:1331 git-legacy-stash.sh:355
+msgid "Cannot save the current status"
+msgstr "Không thể ghi lại trạng thái hiện hành"
 
-#: builtin/show-ref.c:170
-msgid "only show SHA1 hash using <n> digits"
-msgstr "chỉ hiển thị mã băm SHA1 sử dụng <n> chữ số"
+#: builtin/stash.c:1336
+#, c-format
+msgid "Saved working directory and index state %s"
+msgstr "Đã ghi lại thư mục làm việc và trạng thái mục lục %s"
 
-#: builtin/show-ref.c:174
-msgid "do not print results to stdout (useful with --verify)"
-msgstr ""
-"không hiển thị kết quả ra đầu ra chuẩn (stdout) (chỉ hữu dụng với --verify)"
+#: builtin/stash.c:1426 git-legacy-stash.sh:385
+msgid "Cannot remove worktree changes"
+msgstr "Không thể gỡ bỏ các thay đổi cây-làm-việc"
 
-#: builtin/show-ref.c:176
-msgid "show refs from stdin that aren't in local repository"
-msgstr ""
-"hiển thị các tham chiếu từ đầu vào tiêu chuẩn (stdin) cái mà không ở kho nội "
-"bộ"
+#: builtin/stash.c:1461 builtin/stash.c:1497
+msgid "keep index"
+msgstr "giữ nguyên bảng mục lục"
+
+#: builtin/stash.c:1463 builtin/stash.c:1499
+msgid "stash in patch mode"
+msgstr "cất đi ở chế độ miếng vá"
+
+#: builtin/stash.c:1464 builtin/stash.c:1500
+msgid "quiet mode"
+msgstr "chế độ im lặng"
+
+#: builtin/stash.c:1466 builtin/stash.c:1502
+msgid "include untracked files in stash"
+msgstr "bao gồm các tập tin không được theo dõi trong stash"
+
+#: builtin/stash.c:1468 builtin/stash.c:1504
+msgid "include ignore files"
+msgstr "bao gồm các tập tin bị bỏ qua"
+
+#: builtin/stash.c:1564
+#, c-format
+msgid "could not exec %s"
+msgstr "không thể thực thi %s"
 
 #: builtin/stripspace.c:18
 msgid "git stripspace [-s | --strip-comments]"
@@ -14175,105 +20295,138 @@ msgstr "git stripspace [-s | --strip-com
 msgid "git stripspace [-c | --comment-lines]"
 msgstr "git stripspace [-c | --comment-lines]"
 
-#: builtin/stripspace.c:36
+#: builtin/stripspace.c:37
 msgid "skip and remove all lines starting with comment character"
 msgstr "giữ và xóa bỏ mọi dòng bắt đầu bằng ký tự ghi chú"
 
-#: builtin/stripspace.c:39
+#: builtin/stripspace.c:40
 msgid "prepend comment character and space to each line"
 msgstr "treo trước ký tự ghi chú và ký tự khoảng trắng cho từng dòng"
 
-#: builtin/submodule--helper.c:37 builtin/submodule--helper.c:1688
-#, c-format
-msgid "No such ref: %s"
-msgstr "Không có tham chiếu nào như thế: %s"
-
-#: builtin/submodule--helper.c:44 builtin/submodule--helper.c:1697
+#: builtin/submodule--helper.c:47 builtin/submodule--helper.c:1970
 #, c-format
 msgid "Expecting a full ref name, got %s"
 msgstr "Cần tên tham chiếu dạng đầy đủ, nhưng lại nhận được %s"
 
-#: builtin/submodule--helper.c:61
+#: builtin/submodule--helper.c:64
 msgid "submodule--helper print-default-remote takes no arguments"
 msgstr "submodule--helper print-default-remote takes không nhận tham số"
 
-#: builtin/submodule--helper.c:98
+#: builtin/submodule--helper.c:102
 #, c-format
 msgid "cannot strip one component off url '%s'"
 msgstr "không thể cắt bỏ một thành phần ra khỏi “%s” url"
 
-#: builtin/submodule--helper.c:406 builtin/submodule--helper.c:1211
+#: builtin/submodule--helper.c:410 builtin/submodule--helper.c:1380
 msgid "alternative anchor for relative paths"
 msgstr "điểm neo thay thế cho các đường dẫn tương đối"
 
-#: builtin/submodule--helper.c:411
+#: builtin/submodule--helper.c:415
 msgid "git submodule--helper list [--prefix=<path>] [<path>...]"
 msgstr "git submodule--helper list [--prefix=</đường/dẫn>] [</đường/dẫn>…]"
 
-#: builtin/submodule--helper.c:462 builtin/submodule--helper.c:485
+#: builtin/submodule--helper.c:472 builtin/submodule--helper.c:630
+#: builtin/submodule--helper.c:653
 #, c-format
 msgid "No url found for submodule path '%s' in .gitmodules"
 msgstr "Không tìm thấy url cho đường dẫn mô-đun-con “%s” trong .gitmodules"
 
-#: builtin/submodule--helper.c:500
+#: builtin/submodule--helper.c:524
+#, c-format
+msgid "Entering '%s'\n"
+msgstr "Đang vào “%s”\n"
+
+#: builtin/submodule--helper.c:527
+#, c-format
+msgid ""
+"run_command returned non-zero status for %s\n"
+"."
+msgstr ""
+"run_command trả về trạng thái khác không cho %s\n"
+"."
+
+#: builtin/submodule--helper.c:549
+#, c-format
+msgid ""
+"run_command returned non-zero status while recursing in the nested "
+"submodules of %s\n"
+"."
+msgstr ""
+"run_command trả về trạng thái khác không trong khi đệ quy trong các mô-đun-"
+"con lồng nhau của %s\n"
+"."
+
+#: builtin/submodule--helper.c:565
+msgid "Suppress output of entering each submodule command"
+msgstr "Chặn kết xuất của từng lệnh mô-đun-con"
+
+#: builtin/submodule--helper.c:567 builtin/submodule--helper.c:1053
+msgid "Recurse into nested submodules"
+msgstr "Đệ quy vào trong các mô-đun-con lồng nhau"
+
+#: builtin/submodule--helper.c:572
+msgid "git submodule--helper foreach [--quiet] [--recursive] [--] <command>"
+msgstr "git submodule--helper foreach [--quiet] [--recursive] [--]  <lệnh>"
+
+#: builtin/submodule--helper.c:599
 #, c-format
 msgid ""
-"could not lookup configuration '%s'. Assuming this repository is its own "
+"could not look up configuration '%s'. Assuming this repository is its own "
 "authoritative upstream."
 msgstr ""
-"không thể tìm thấy cấu hình “%s”. Coi rằng kho này là thượng nguồn có quyền "
+"không thể tìm thấy cấu hình “%s”. Coi rằng đây là kho thượng nguồn có quyền "
 "sở hữu chính nó."
 
-#: builtin/submodule--helper.c:511
+#: builtin/submodule--helper.c:667
 #, c-format
 msgid "Failed to register url for submodule path '%s'"
 msgstr "Gặp lỗi khi đăng ký url cho đường dẫn mô-đun-con “%s”"
 
-#: builtin/submodule--helper.c:515
+#: builtin/submodule--helper.c:671
 #, c-format
 msgid "Submodule '%s' (%s) registered for path '%s'\n"
 msgstr "Mô-đun-con “%s” (%s) được đăng ký cho đường dẫn “%s”\n"
 
-#: builtin/submodule--helper.c:525
+#: builtin/submodule--helper.c:681
 #, c-format
 msgid "warning: command update mode suggested for submodule '%s'\n"
 msgstr "cảnh báo: chế độ lệnh cập nhật được gợi ý cho mô-đun-con “%s”\n"
 
-#: builtin/submodule--helper.c:532
+#: builtin/submodule--helper.c:688
 #, c-format
 msgid "Failed to register update mode for submodule path '%s'"
 msgstr "Gặp lỗi khi đăng ký chế độ cập nhật cho đường dẫn mô-đun-con “%s”"
 
-#: builtin/submodule--helper.c:554
+#: builtin/submodule--helper.c:710
 msgid "Suppress output for initializing a submodule"
 msgstr "Chặn kết xuất cho khởi tạo một mô-đun-con"
 
-#: builtin/submodule--helper.c:559
-msgid "git submodule--helper init [<path>]"
-msgstr "git submodule--helper init [</đường/dẫn>]"
+#: builtin/submodule--helper.c:715
+msgid "git submodule--helper init [<options>] [<path>]"
+msgstr "git submodule--helper init [<các tùy chọn>] [</đường/dẫn>]"
 
-#: builtin/submodule--helper.c:631 builtin/submodule--helper.c:757
+#: builtin/submodule--helper.c:787 builtin/submodule--helper.c:914
 #, c-format
 msgid "no submodule mapping found in .gitmodules for path '%s'"
 msgstr ""
-"Không tìm thấy ánh xạ (mapping) mô-đun-con trong .gitmodules cho đường dẫn "
+"không tìm thấy ánh xạ (mapping) mô-đun-con trong .gitmodules cho đường dẫn "
 "“%s”"
 
-#: builtin/submodule--helper.c:670
+#: builtin/submodule--helper.c:827
 #, c-format
 msgid "could not resolve HEAD ref inside the submodule '%s'"
 msgstr "không thể phân giải tham chiếu HEAD bên trong mô-đun-con “%s”"
 
-#: builtin/submodule--helper.c:697 builtin/submodule--helper.c:866
+#: builtin/submodule--helper.c:854 builtin/submodule--helper.c:1023
 #, c-format
 msgid "failed to recurse into submodule '%s'"
 msgstr "gặp lỗi khi đệ quy vào trong mô-đun-con “%s”"
 
-#: builtin/submodule--helper.c:721 builtin/submodule--helper.c:1031
+#: builtin/submodule--helper.c:878 builtin/submodule--helper.c:1189
 msgid "Suppress submodule status output"
 msgstr "Chặn két xuất tình trạng mô-đun-con"
 
-#: builtin/submodule--helper.c:722
+#: builtin/submodule--helper.c:879
 msgid ""
 "Use commit stored in the index instead of the one stored in the submodule "
 "HEAD"
@@ -14281,52 +20434,48 @@ msgstr ""
 "Dùng lần chuyển giao lưu trong mục lục thay cho cái được lưu trong HEAD mô-"
 "đun-con"
 
-#: builtin/submodule--helper.c:723
+#: builtin/submodule--helper.c:880
 msgid "recurse into nested submodules"
 msgstr "đệ quy vào trong mô-đun-con lồng nhau"
 
-#: builtin/submodule--helper.c:728
+#: builtin/submodule--helper.c:885
 msgid "git submodule status [--quiet] [--cached] [--recursive] [<path>...]"
 msgstr ""
 "git submodule status [--quiet] [--cached] [--recursive] [</đường/dẫn>…]"
 
-#: builtin/submodule--helper.c:752
+#: builtin/submodule--helper.c:909
 msgid "git submodule--helper name <path>"
 msgstr "git submodule--helper name </đường/dẫn>"
 
-#: builtin/submodule--helper.c:816
+#: builtin/submodule--helper.c:973
 #, c-format
 msgid "Synchronizing submodule url for '%s'\n"
-msgstr "url mô-đun-con đồng bộ hóa cho “%s”\n"
+msgstr "Url mô-đun-con đồng bộ hóa cho “%s”\n"
 
-#: builtin/submodule--helper.c:822
+#: builtin/submodule--helper.c:979
 #, c-format
 msgid "failed to register url for submodule path '%s'"
 msgstr "gặp lỗi khi đăng ký url cho đường dẫn mô-đun-con “%s”"
 
-#: builtin/submodule--helper.c:836
+#: builtin/submodule--helper.c:993
 #, c-format
 msgid "failed to get the default remote for submodule '%s'"
 msgstr "gặp lỗi khi lấy máy chủ mặc định cho mô-đun-con “%s”"
 
-#: builtin/submodule--helper.c:847
+#: builtin/submodule--helper.c:1004
 #, c-format
 msgid "failed to update remote for submodule '%s'"
 msgstr "gặp lỗi khi cập nhật cho mô-đun-con “%s”"
 
-#: builtin/submodule--helper.c:895
+#: builtin/submodule--helper.c:1051
 msgid "Suppress output of synchronizing submodule url"
 msgstr "Chặn kết xuất cho đồng bộ url mô-đun-con"
 
-#: builtin/submodule--helper.c:897
-msgid "Recurse into nested submodules"
-msgstr "Đệ quy vào trong các mô-đun-con lồng nhau"
-
-#: builtin/submodule--helper.c:902
+#: builtin/submodule--helper.c:1058
 msgid "git submodule--helper sync [--quiet] [--recursive] [<path>]"
 msgstr "git submodule--helper sync [--quiet] [--recursive] [</đường/dẫn>]"
 
-#: builtin/submodule--helper.c:956
+#: builtin/submodule--helper.c:1112
 #, c-format
 msgid ""
 "Submodule work tree '%s' contains a .git directory (use 'rm -rf' if you "
@@ -14335,7 +20484,7 @@ msgstr ""
 "Cây làm việc mô-đun-con “%s” có chứa thư mục .git (dùng “rm -rf” nếu bạn "
 "thực sự muốn gỡ bỏ nó cùng với toàn bộ lịch sử của chúng)"
 
-#: builtin/submodule--helper.c:968
+#: builtin/submodule--helper.c:1124
 #, c-format
 msgid ""
 "Submodule work tree '%s' contains local modifications; use '-f' to discard "
@@ -14344,80 +20493,99 @@ msgstr ""
 "Cây làm việc mô-đun-con “%s” chứa các thay đổi nội bộ; hãy dùng “-f” để loại "
 "bỏ chúng đi"
 
-#: builtin/submodule--helper.c:976
+#: builtin/submodule--helper.c:1132
 #, c-format
 msgid "Cleared directory '%s'\n"
 msgstr "Đã xóa thư mục “%s”\n"
 
-#: builtin/submodule--helper.c:978
+#: builtin/submodule--helper.c:1134
 #, c-format
 msgid "Could not remove submodule work tree '%s'\n"
 msgstr "Không thể gỡ bỏ cây làm việc mô-đun-con “%s”\n"
 
-#: builtin/submodule--helper.c:987
+#: builtin/submodule--helper.c:1145
 #, c-format
 msgid "could not create empty submodule directory %s"
 msgstr "không thể tạo thư mục mô-đun-con rỗng “%s”"
 
-#: builtin/submodule--helper.c:1003
+#: builtin/submodule--helper.c:1161
 #, c-format
 msgid "Submodule '%s' (%s) unregistered for path '%s'\n"
 msgstr "Mô-đun-con “%s” (%s) được đăng ký cho đường dẫn “%s”\n"
 
-#: builtin/submodule--helper.c:1032
+#: builtin/submodule--helper.c:1190
 msgid "Remove submodule working trees even if they contain local changes"
 msgstr "Gỡ bỏ cây làm việc của mô-đun-con ngay cả khi nó có thay đổi nội bộ"
 
-#: builtin/submodule--helper.c:1033
+#: builtin/submodule--helper.c:1191
 msgid "Unregister all submodules"
 msgstr "Bỏ đăng ký tất cả các trong mô-đun-con"
 
-#: builtin/submodule--helper.c:1038
+#: builtin/submodule--helper.c:1196
 msgid ""
 "git submodule deinit [--quiet] [-f | --force] [--all | [--] [<path>...]]"
 msgstr ""
 "git submodule deinit [--quiet] [-f | --force] [--all | [--]  [</đường/dẫn>…]]"
 
-#: builtin/submodule--helper.c:1052
+#: builtin/submodule--helper.c:1210
 msgid "Use '--all' if you really want to deinitialize all submodules"
 msgstr "Dùng “--all” nếu bạn thực sự muốn hủy khởi tạo mọi mô-đun-con"
 
-#: builtin/submodule--helper.c:1145 builtin/submodule--helper.c:1148
+#: builtin/submodule--helper.c:1275
+msgid ""
+"An alternate computed from a superproject's alternate is invalid.\n"
+"To allow Git to clone without an alternate in such a case, set\n"
+"submodule.alternateErrorStrategy to 'info' or, equivalently, clone with\n"
+"'--reference-if-able' instead of '--reference'."
+msgstr ""
+"Một cái thay thế được tính toán từ một thay thế của siêu dự án là không hợp "
+"lệ.\n"
+"Để cho Git thực hiện nhân bản mà không có cái thay thế như trong trường hợp "
+"này, đặt\n"
+"submodule.alternateErrorStrategy thành 'info' hoặc, tương đương, nhân bản "
+"bằng\n"
+"'--reference-if-able' thay vì dùng '--reference'."
+
+#: builtin/submodule--helper.c:1314 builtin/submodule--helper.c:1317
 #, c-format
 msgid "submodule '%s' cannot add alternate: %s"
 msgstr "mô-đun-con “%s” không thể thêm thay thế: %s"
 
-#: builtin/submodule--helper.c:1184
+#: builtin/submodule--helper.c:1353
 #, c-format
 msgid "Value '%s' for submodule.alternateErrorStrategy is not recognized"
 msgstr "Giá trị “%s” cho submodule.alternateErrorStrategy không được thừa nhận"
 
-#: builtin/submodule--helper.c:1191
+#: builtin/submodule--helper.c:1360
 #, c-format
 msgid "Value '%s' for submodule.alternateLocation is not recognized"
 msgstr "Giá trị “%s” cho submodule.alternateLocation không được thừa nhận"
 
-#: builtin/submodule--helper.c:1214
+#: builtin/submodule--helper.c:1383
 msgid "where the new submodule will be cloned to"
 msgstr "nhân bản mô-đun-con mới vào chỗ nào"
 
-#: builtin/submodule--helper.c:1217
+#: builtin/submodule--helper.c:1386
 msgid "name of the new submodule"
 msgstr "tên của mô-đun-con mới"
 
-#: builtin/submodule--helper.c:1220
+#: builtin/submodule--helper.c:1389
 msgid "url where to clone the submodule from"
 msgstr "url nơi mà nhân bản mô-đun-con từ đó"
 
-#: builtin/submodule--helper.c:1228
+#: builtin/submodule--helper.c:1397
 msgid "depth for shallow clones"
 msgstr "chiều sâu lịch sử khi tạo bản sao"
 
-#: builtin/submodule--helper.c:1231 builtin/submodule--helper.c:1606
+#: builtin/submodule--helper.c:1400 builtin/submodule--helper.c:1897
 msgid "force cloning progress"
 msgstr "ép buộc tiến trình nhân bản"
 
-#: builtin/submodule--helper.c:1236
+#: builtin/submodule--helper.c:1402 builtin/submodule--helper.c:1899
+msgid "disallow cloning into non-empty directory"
+msgstr "làm đầy đủ dữ liệu cho bản sao vào trong một thư mục trống rỗng"
+
+#: builtin/submodule--helper.c:1407
 msgid ""
 "git submodule--helper clone [--prefix=<path>] [--quiet] [--reference "
 "<repository>] [--name <name>] [--depth <depth>] --url <url> --path <path>"
@@ -14425,84 +20593,105 @@ msgstr ""
 "git submodule--helper clone [--prefix=</đường/dẫn>] [--quiet] [--reference "
 "<kho>] [--name <tên>] [--depth <sâu>] [--url <url>] [</đường/dẫn>…]"
 
-#: builtin/submodule--helper.c:1267
+#: builtin/submodule--helper.c:1431
+#, c-format
+msgid "refusing to create/use '%s' in another submodule's git dir"
+msgstr "từ chối tạo/dùng '%s' trong một thư mục git của mô đun con"
+
+#: builtin/submodule--helper.c:1442
 #, c-format
 msgid "clone of '%s' into submodule path '%s' failed"
-msgstr "Nhân bản “%s” vào đường dẫn mô-đun-con “%s” gặp lỗi"
+msgstr "việc sao “%s” vào đường dẫn mô-đun-con “%s” gặp lỗi"
+
+#: builtin/submodule--helper.c:1446
+#, c-format
+msgid "directory not empty: '%s'"
+msgstr "thư mục không trống: '%s'"
 
-#: builtin/submodule--helper.c:1281
+#: builtin/submodule--helper.c:1458
 #, c-format
 msgid "could not get submodule directory for '%s'"
 msgstr "không thể lấy thư mục mô-đun-con cho “%s”"
 
-#: builtin/submodule--helper.c:1347
+#: builtin/submodule--helper.c:1494
+#, c-format
+msgid "Invalid update mode '%s' for submodule path '%s'"
+msgstr "Chế độ cập nhật “%s” không hợp lệ cho đường dẫn mô-đun-con “%s”"
+
+#: builtin/submodule--helper.c:1498
+#, c-format
+msgid "Invalid update mode '%s' configured for submodule path '%s'"
+msgstr ""
+"Chế độ cập nhật “%s” không hợp lệ được cấu hình cho đường dẫn mô-đun-con “%s”"
+
+#: builtin/submodule--helper.c:1594
 #, c-format
 msgid "Submodule path '%s' not initialized"
 msgstr "Đường dẫn mô-đun-con “%s” chưa được khởi tạo"
 
-#: builtin/submodule--helper.c:1351
+#: builtin/submodule--helper.c:1598
 msgid "Maybe you want to use 'update --init'?"
 msgstr "Có lẽ bạn là bạn muốn dùng \"update --init\" phải không?"
 
-#: builtin/submodule--helper.c:1380
+#: builtin/submodule--helper.c:1628
 #, c-format
 msgid "Skipping unmerged submodule %s"
 msgstr "Bỏ qua các mô-đun-con chưa được hòa trộn %s"
 
-#: builtin/submodule--helper.c:1409
+#: builtin/submodule--helper.c:1657
 #, c-format
 msgid "Skipping submodule '%s'"
 msgstr "Bỏ qua mô-đun-con “%s”"
 
-#: builtin/submodule--helper.c:1544
+#: builtin/submodule--helper.c:1803
 #, c-format
 msgid "Failed to clone '%s'. Retry scheduled"
 msgstr "Gặp lỗi khi nhân bản “%s”. Thử lại lịch trình"
 
-#: builtin/submodule--helper.c:1555
+#: builtin/submodule--helper.c:1814
 #, c-format
 msgid "Failed to clone '%s' a second time, aborting"
 msgstr "Gặp lỗi khi nhân bản “%s” lần thứ hai nên bãi bỏ"
 
-#: builtin/submodule--helper.c:1585 builtin/submodule--helper.c:1808
+#: builtin/submodule--helper.c:1876 builtin/submodule--helper.c:2120
 msgid "path into the working tree"
 msgstr "đường dẫn đến cây làm việc"
 
-#: builtin/submodule--helper.c:1588
+#: builtin/submodule--helper.c:1879
 msgid "path into the working tree, across nested submodule boundaries"
 msgstr "đường dẫn đến cây làm việc, chéo biên giới mô-đun-con lồng nhau"
 
-#: builtin/submodule--helper.c:1592
+#: builtin/submodule--helper.c:1883
 msgid "rebase, merge, checkout or none"
 msgstr "rebase, merge, checkout hoặc không làm gì cả"
 
-#: builtin/submodule--helper.c:1598
+#: builtin/submodule--helper.c:1889
 msgid "Create a shallow clone truncated to the specified number of revisions"
 msgstr ""
 "Tạo một bản sao nông được cắt ngắn thành số lượng điểm xét duyệt đã cho"
 
-#: builtin/submodule--helper.c:1601
+#: builtin/submodule--helper.c:1892
 msgid "parallel jobs"
 msgstr "công việc đồng thời"
 
-#: builtin/submodule--helper.c:1603
+#: builtin/submodule--helper.c:1894
 msgid "whether the initial clone should follow the shallow recommendation"
 msgstr "nhân bản lần đầu có nên theo khuyến nghị là nông hay không"
 
-#: builtin/submodule--helper.c:1604
+#: builtin/submodule--helper.c:1895
 msgid "don't print cloning progress"
 msgstr "đừng in tiến trình nhân bản"
 
-#: builtin/submodule--helper.c:1611
-msgid "git submodule--helper update_clone [--prefix=<path>] [<path>...]"
+#: builtin/submodule--helper.c:1904
+msgid "git submodule--helper update-clone [--prefix=<path>] [<path>...]"
 msgstr ""
-"git submodule--helper update_clone [--prefix=</đường/dẫn>] [</đường/dẫn>…]"
+"git submodule--helper update-clone [--prefix=</đường/dẫn>] [</đường/dẫn>…]"
 
-#: builtin/submodule--helper.c:1624
+#: builtin/submodule--helper.c:1917
 msgid "bad value for update parameter"
 msgstr "giá trị cho  tham số cập nhật bị sai"
 
-#: builtin/submodule--helper.c:1692
+#: builtin/submodule--helper.c:1965
 #, c-format
 msgid ""
 "Submodule (%s) branch configured to inherit branch from superproject, but "
@@ -14511,27 +20700,57 @@ msgstr ""
 "Nhánh mô-đun-con (%s) được cấu hình kế thừa nhánh từ siêu dự án, nhưng siêu "
 "dự án lại không trên bất kỳ nhánh nào"
 
-#: builtin/submodule--helper.c:1809
+#: builtin/submodule--helper.c:2088
+#, c-format
+msgid "could not get a repository handle for submodule '%s'"
+msgstr "không thể lấy thẻ quản kho cho mô-đun-con “%s”"
+
+#: builtin/submodule--helper.c:2121
 msgid "recurse into submodules"
 msgstr "đệ quy vào trong mô-đun-con"
 
-#: builtin/submodule--helper.c:1815
-msgid "git submodule--helper embed-git-dir [<path>...]"
-msgstr "git submodule--helper embed-git-dir [</đường/dẫn>…]"
+#: builtin/submodule--helper.c:2127
+msgid "git submodule--helper absorb-git-dirs [<options>] [<path>...]"
+msgstr "git submodule--helper absorb-git-dirs [<các tùy chọn>] [</đường/dẫn>…]"
+
+#: builtin/submodule--helper.c:2183
+msgid "check if it is safe to write to the .gitmodules file"
+msgstr "chọn nếu nó là an toàn để ghi vào tập tin .gitmodules"
+
+#: builtin/submodule--helper.c:2186
+msgid "unset the config in the .gitmodules file"
+msgstr "bỏ đặt cấu hình trong tập tin .gitmodules"
+
+#: builtin/submodule--helper.c:2191
+msgid "git submodule--helper config <name> [<value>]"
+msgstr "git submodule--helper config <tên> [<giá trị>]"
+
+#: builtin/submodule--helper.c:2192
+msgid "git submodule--helper config --unset <name>"
+msgstr "git submodule--helper config --unset <tên>"
+
+#: builtin/submodule--helper.c:2193
+msgid "git submodule--helper config --check-writeable"
+msgstr "git submodule--helper config --check-writeable"
 
-#: builtin/submodule--helper.c:1901
+#: builtin/submodule--helper.c:2212 git-submodule.sh:173
+#, sh-format
+msgid "please make sure that the .gitmodules file is in the working tree"
+msgstr "hãy đảm bảo rằng tập tin .gitmodules có trong cây làm việc"
+
+#: builtin/submodule--helper.c:2262 git.c:433 git.c:684
 #, c-format
 msgid "%s doesn't support --super-prefix"
 msgstr "%s không hỗ trợ --super-prefix"
 
-#: builtin/submodule--helper.c:1907
+#: builtin/submodule--helper.c:2268
 #, c-format
 msgid "'%s' is not a valid submodule--helper subcommand"
 msgstr "“%s” không phải là lệnh con submodule--helper hợp lệ"
 
 #: builtin/symbolic-ref.c:8
 msgid "git symbolic-ref [<options>] <name> [<ref>]"
-msgstr "git symbolic-ref [<các-tùy-chọn>] <tên> [<t.chiếu>]"
+msgstr "git symbolic-ref [<các tùy chọn>] <tên> [<t.chiếu>]"
 
 #: builtin/symbolic-ref.c:9
 msgid "git symbolic-ref -d [-q] <name>"
@@ -14549,27 +20768,27 @@ msgstr "xóa tham chiếu mềm"
 msgid "shorten ref output"
 msgstr "làm ngắn kết xuất ref (tham chiếu)"
 
-#: builtin/symbolic-ref.c:43 builtin/update-ref.c:362
+#: builtin/symbolic-ref.c:43 builtin/update-ref.c:363
 msgid "reason"
 msgstr "lý do"
 
-#: builtin/symbolic-ref.c:43 builtin/update-ref.c:362
+#: builtin/symbolic-ref.c:43 builtin/update-ref.c:363
 msgid "reason of the update"
 msgstr "lý do cập nhật"
 
-#: builtin/tag.c:24
+#: builtin/tag.c:25
 msgid ""
-"git tag [-a | -s | -u <key-id>] [-f] [-m <msg> | -F <file>] <tagname> "
-"[<head>]"
+"git tag [-a | -s | -u <key-id>] [-f] [-m <msg> | -F <file>]\n"
+"\t\t<tagname> [<head>]"
 msgstr ""
-"git tag [-a | -s | -u <key-id>] [-f] [-m <msg>|-F <tập-tin>] <tên-thẻ> "
-"[<head>]"
+"git tag [-a | -s | -u <key-id>] [-f] [-m <msg> | -F <tập-tin>]\n"
+"\t\t<tên-thẻ> [<head>]"
 
-#: builtin/tag.c:25
+#: builtin/tag.c:27
 msgid "git tag -d <tagname>..."
 msgstr "git tag -d <tên-thẻ>…"
 
-#: builtin/tag.c:26
+#: builtin/tag.c:28
 msgid ""
 "git tag -l [-n[<num>]] [--contains <commit>] [--no-contains <commit>] [--"
 "points-at <object>]\n"
@@ -14579,21 +20798,21 @@ msgstr ""
 "<lần_chuyển_giao>] [--points-at <đối-tượng>]\n"
 "\t\t[--format=<định_dạng>] [--[no-]merged [<lần_chuyển_giao>]] [<mẫu>…]"
 
-#: builtin/tag.c:28
+#: builtin/tag.c:30
 msgid "git tag -v [--format=<format>] <tagname>..."
 msgstr "git tag -v [--format=<định_dạng>]  <tên-thẻ>…"
 
-#: builtin/tag.c:86
+#: builtin/tag.c:89
 #, c-format
 msgid "tag '%s' not found."
 msgstr "không tìm thấy tìm thấy thẻ “%s”."
 
-#: builtin/tag.c:102
+#: builtin/tag.c:105
 #, c-format
 msgid "Deleted tag '%s' (was %s)\n"
 msgstr "Thẻ đã bị xóa “%s” (từng là %s)\n"
 
-#: builtin/tag.c:132
+#: builtin/tag.c:135
 #, c-format
 msgid ""
 "\n"
@@ -14606,7 +20825,7 @@ msgstr ""
 "  %s\n"
 "Những dòng được bắt đầu bằng “%c” sẽ được bỏ qua.\n"
 
-#: builtin/tag.c:136
+#: builtin/tag.c:139
 #, c-format
 msgid ""
 "\n"
@@ -14621,356 +20840,368 @@ msgstr ""
 "Những dòng được bắt đầu bằng “%c” sẽ được giữ lại; bạn có thể xóa chúng đi "
 "nếu muốn.\n"
 
-#: builtin/tag.c:190
+#: builtin/tag.c:198
 msgid "unable to sign the tag"
 msgstr "không thể ký thẻ"
 
-#: builtin/tag.c:192
+#: builtin/tag.c:200
 msgid "unable to write tag file"
 msgstr "không thể ghi vào tập tin lưu thẻ"
 
-#: builtin/tag.c:217
+#: builtin/tag.c:216
+#, c-format
+msgid ""
+"You have created a nested tag. The object referred to by your new tag is\n"
+"already a tag. If you meant to tag the object that it points to, use:\n"
+"\n"
+"\tgit tag -f %s %s^{}"
+msgstr ""
+"Bạn đã tạo một thẻ lồng nhau. Đối tượng được chỉ đến thẻ mới của bạn là\n"
+"đã là một thẻ. Nếu ý bạn là gắn thẻ đối tượng mà nó trỏ đến, sử dụng:\n"
+"\n"
+"\tgit tag -f %s %s^{}"
+
+#: builtin/tag.c:232
 msgid "bad object type."
 msgstr "kiểu đối tượng sai."
 
-#: builtin/tag.c:266
+#: builtin/tag.c:284
 msgid "no tag message?"
 msgstr "không có chú thích gì cho cho thẻ à?"
 
-#: builtin/tag.c:273
+#: builtin/tag.c:291
 #, c-format
 msgid "The tag message has been left in %s\n"
 msgstr "Nội dung ghi chú còn lại %s\n"
 
-#: builtin/tag.c:382
+#: builtin/tag.c:402
 msgid "list tag names"
 msgstr "chỉ liệt kê tên các thẻ"
 
-#: builtin/tag.c:384
+#: builtin/tag.c:404
 msgid "print <n> lines of each tag message"
 msgstr "hiển thị <n> dòng cho mỗi ghi chú"
 
-#: builtin/tag.c:386
+#: builtin/tag.c:406
 msgid "delete tags"
 msgstr "xóa thẻ"
 
-#: builtin/tag.c:387
+#: builtin/tag.c:407
 msgid "verify tags"
 msgstr "thẩm tra thẻ"
 
-#: builtin/tag.c:389
+#: builtin/tag.c:409
 msgid "Tag creation options"
 msgstr "Tùy chọn tạo thẻ"
 
-#: builtin/tag.c:391
+#: builtin/tag.c:411
 msgid "annotated tag, needs a message"
 msgstr "để chú giải cho thẻ, cần một lời ghi chú"
 
-#: builtin/tag.c:393
+#: builtin/tag.c:413
 msgid "tag message"
 msgstr "phần chú thích cho thẻ"
 
-#: builtin/tag.c:395
+#: builtin/tag.c:415
 msgid "force edit of tag message"
 msgstr "ép buộc sửa thẻ lần commit"
 
-#: builtin/tag.c:396
+#: builtin/tag.c:416
 msgid "annotated and GPG-signed tag"
 msgstr "thẻ chú giải và ký kiểu GPG"
 
-#: builtin/tag.c:400
+#: builtin/tag.c:419
 msgid "use another key to sign the tag"
 msgstr "dùng kháo khác để ký thẻ"
 
-#: builtin/tag.c:401
+#: builtin/tag.c:420
 msgid "replace the tag if exists"
 msgstr "thay thế nếu thẻ đó đã có trước"
 
-#: builtin/tag.c:402 builtin/update-ref.c:368
+#: builtin/tag.c:421 builtin/update-ref.c:369
 msgid "create a reflog"
 msgstr "tạo một reflog"
 
-#: builtin/tag.c:404
+#: builtin/tag.c:423
 msgid "Tag listing options"
 msgstr "Các tùy chọn liệt kê thẻ"
 
-#: builtin/tag.c:405
+#: builtin/tag.c:424
 msgid "show tag list in columns"
 msgstr "hiển thị danh sách thẻ trong các cột"
 
-#: builtin/tag.c:406 builtin/tag.c:408
+#: builtin/tag.c:425 builtin/tag.c:427
 msgid "print only tags that contain the commit"
 msgstr "chỉ hiển thị những nhánh mà nó chứa lần chuyển giao"
 
-#: builtin/tag.c:407 builtin/tag.c:409
+#: builtin/tag.c:426 builtin/tag.c:428
 msgid "print only tags that don't contain the commit"
 msgstr "chỉ hiển thị những thẻ mà nó không chứa lần chuyển giao"
 
-#: builtin/tag.c:410
+#: builtin/tag.c:429
 msgid "print only tags that are merged"
 msgstr "chỉ hiển thị những thẻ mà nó được hòa trộn"
 
-#: builtin/tag.c:411
+#: builtin/tag.c:430
 msgid "print only tags that are not merged"
 msgstr "chỉ hiển thị những thẻ mà nó không được hòa trộn"
 
-#: builtin/tag.c:416
+#: builtin/tag.c:434
 msgid "print only tags of the object"
 msgstr "chỉ hiển thị các thẻ của đối tượng"
 
-#: builtin/tag.c:460
+#: builtin/tag.c:482
 msgid "--column and -n are incompatible"
 msgstr "--column và -n xung khắc nhau"
 
-#: builtin/tag.c:482
+#: builtin/tag.c:504
 msgid "-n option is only allowed in list mode"
 msgstr "tùy chọn -n chỉ cho phép dùng trong chế độ liệt kê"
 
-#: builtin/tag.c:484
+#: builtin/tag.c:506
 msgid "--contains option is only allowed in list mode"
 msgstr "tùy chọn --contains chỉ cho phép dùng trong chế độ liệt kê"
 
-#: builtin/tag.c:486
+#: builtin/tag.c:508
 msgid "--no-contains option is only allowed in list mode"
 msgstr "tùy chọn --no-contains chỉ cho phép dùng trong chế độ liệt kê"
 
-#: builtin/tag.c:488
+#: builtin/tag.c:510
 msgid "--points-at option is only allowed in list mode"
 msgstr "tùy chọn --points-at chỉ cho phép dùng trong chế độ liệt kê"
 
-#: builtin/tag.c:490
+#: builtin/tag.c:512
 msgid "--merged and --no-merged options are only allowed in list mode"
 msgstr ""
 "tùy chọn --merged và --no-merged chỉ cho phép dùng trong chế độ liệt kê"
 
-#: builtin/tag.c:501
+#: builtin/tag.c:523
 msgid "only one -F or -m option is allowed."
 msgstr "chỉ có một tùy chọn -F hoặc -m là được phép."
 
-#: builtin/tag.c:520
+#: builtin/tag.c:542
 msgid "too many params"
 msgstr "quá nhiều đối số"
 
-#: builtin/tag.c:526
+#: builtin/tag.c:548
 #, c-format
 msgid "'%s' is not a valid tag name."
 msgstr "“%s” không phải thẻ hợp lệ."
 
-#: builtin/tag.c:531
+#: builtin/tag.c:553
 #, c-format
 msgid "tag '%s' already exists"
-msgstr "Thẻ “%s” đã tồn tại rồi"
+msgstr "thẻ “%s” đã tồn tại rồi"
 
-#: builtin/tag.c:562
+#: builtin/tag.c:584
 #, c-format
 msgid "Updated tag '%s' (was %s)\n"
 msgstr "Đã cập nhật thẻ “%s” (trước là %s)\n"
 
-#: builtin/unpack-objects.c:498
+#: builtin/unpack-objects.c:501
 msgid "Unpacking objects"
 msgstr "Đang giải nén các đối tượng"
 
-#: builtin/update-index.c:82
+#: builtin/update-index.c:84
 #, c-format
 msgid "failed to create directory %s"
 msgstr "tạo thư mục \"%s\" gặp lỗi"
 
-#: builtin/update-index.c:88
-#, c-format
-msgid "failed to stat %s"
-msgstr "gặp lỗi khi lấy thông tin thống kê về %s"
-
-#: builtin/update-index.c:98
+#: builtin/update-index.c:100
 #, c-format
 msgid "failed to create file %s"
 msgstr "gặp lỗi khi tạo tập tin %s"
 
-#: builtin/update-index.c:106
+#: builtin/update-index.c:108
 #, c-format
 msgid "failed to delete file %s"
 msgstr "gặp lỗi khi xóa tập tin %s"
 
-#: builtin/update-index.c:113 builtin/update-index.c:219
+#: builtin/update-index.c:115 builtin/update-index.c:221
 #, c-format
 msgid "failed to delete directory %s"
 msgstr "gặp lỗi khi xóa thư mục %s"
 
-#: builtin/update-index.c:138
+#: builtin/update-index.c:140
 #, c-format
 msgid "Testing mtime in '%s' "
-msgstr "Đang kiểm thử mtime trong “%s”"
+msgstr "Đang kiểm thử mtime trong “%s” "
 
-#: builtin/update-index.c:152
+#: builtin/update-index.c:154
 msgid "directory stat info does not change after adding a new file"
 msgstr "thông tin thống kê thư mục không thay đổi sau khi thêm tập tin mới"
 
-#: builtin/update-index.c:165
+#: builtin/update-index.c:167
 msgid "directory stat info does not change after adding a new directory"
 msgstr "thông tin thống kê thư mục không thay đổi sau khi thêm thư mục mới"
 
-#: builtin/update-index.c:178
+#: builtin/update-index.c:180
 msgid "directory stat info changes after updating a file"
 msgstr "thông tin thống kê thư mục thay đổi sau khi cập nhật tập tin"
 
-#: builtin/update-index.c:189
+#: builtin/update-index.c:191
 msgid "directory stat info changes after adding a file inside subdirectory"
 msgstr ""
 "thông tin thống kê thư mục thay đổi sau khi thêm tập tin mới vào trong thư "
 "mục con"
 
-#: builtin/update-index.c:200
+#: builtin/update-index.c:202
 msgid "directory stat info does not change after deleting a file"
 msgstr "thông tin thống kê thư mục không thay đổi sau khi xóa tập tin"
 
-#: builtin/update-index.c:213
+#: builtin/update-index.c:215
 msgid "directory stat info does not change after deleting a directory"
 msgstr "thông tin thống kê thư mục không thay đổi sau khi xóa thư mục"
 
-#: builtin/update-index.c:220
+#: builtin/update-index.c:222
 msgid " OK"
 msgstr " Đồng ý"
 
-#: builtin/update-index.c:589
+#: builtin/update-index.c:591
 msgid "git update-index [<options>] [--] [<file>...]"
-msgstr "git update-index [<các-tùy-chọn>] [--] [<tập-tin>…]"
+msgstr "git update-index [<các tùy chọn>] [--] [<tập-tin>…]"
 
-#: builtin/update-index.c:946
+#: builtin/update-index.c:974
 msgid "continue refresh even when index needs update"
 msgstr "tiếp tục làm mới ngay cả khi bảng mục lục cần được cập nhật"
 
-#: builtin/update-index.c:949
+#: builtin/update-index.c:977
 msgid "refresh: ignore submodules"
 msgstr "refresh: lờ đi mô-đun-con"
 
-#: builtin/update-index.c:952
+#: builtin/update-index.c:980
 msgid "do not ignore new files"
 msgstr "không bỏ qua các tập tin mới tạo"
 
-#: builtin/update-index.c:954
+#: builtin/update-index.c:982
 msgid "let files replace directories and vice-versa"
 msgstr "để các tập tin thay thế các thư mục và “vice-versa”"
 
-#: builtin/update-index.c:956
+#: builtin/update-index.c:984
 msgid "notice files missing from worktree"
 msgstr "thông báo các tập-tin thiếu trong thư-mục làm việc"
 
-#: builtin/update-index.c:958
+#: builtin/update-index.c:986
 msgid "refresh even if index contains unmerged entries"
 msgstr ""
 "làm tươi mới thậm chí khi bảng mục lục chứa các mục tin chưa được hòa trộn"
 
-#: builtin/update-index.c:961
+#: builtin/update-index.c:989
 msgid "refresh stat information"
 msgstr "lấy lại thông tin thống kê"
 
-#: builtin/update-index.c:965
+#: builtin/update-index.c:993
 msgid "like --refresh, but ignore assume-unchanged setting"
 msgstr "giống --refresh, nhưng bỏ qua các cài đặt “assume-unchanged”"
 
-#: builtin/update-index.c:969
+#: builtin/update-index.c:997
 msgid "<mode>,<object>,<path>"
 msgstr "<chế_độ>,<đối_tượng>,<đường_dẫn>"
 
-#: builtin/update-index.c:970
+#: builtin/update-index.c:998
 msgid "add the specified entry to the index"
 msgstr "thêm các tập tin đã chỉ ra vào bảng mục lục"
 
-#: builtin/update-index.c:979
+#: builtin/update-index.c:1008
 msgid "mark files as \"not changing\""
-msgstr "Đánh dấu các tập tin là \"không thay đổi\""
+msgstr "đánh dấu các tập tin là \"không thay đổi\""
 
-#: builtin/update-index.c:982
+#: builtin/update-index.c:1011
 msgid "clear assumed-unchanged bit"
 msgstr "xóa bít assumed-unchanged (giả định là không thay đổi)"
 
-#: builtin/update-index.c:985
+#: builtin/update-index.c:1014
 msgid "mark files as \"index-only\""
 msgstr "đánh dấu các tập tin là “chỉ-đọc”"
 
-#: builtin/update-index.c:988
+#: builtin/update-index.c:1017
 msgid "clear skip-worktree bit"
 msgstr "xóa bít skip-worktree"
 
-#: builtin/update-index.c:991
+#: builtin/update-index.c:1020
+msgid "do not touch index-only entries"
+msgstr "đừng động vào các mục index-only"
+
+#: builtin/update-index.c:1022
 msgid "add to index only; do not add content to object database"
 msgstr ""
 "chỉ thêm vào bảng mục lục; không thêm nội dung vào cơ sở dữ liệu đối tượng"
 
-#: builtin/update-index.c:993
+#: builtin/update-index.c:1024
 msgid "remove named paths even if present in worktree"
 msgstr ""
 "gỡ bỏ các đường dẫn được đặt tên thậm chí cả khi nó hiện diện trong thư mục "
 "làm việc"
 
-#: builtin/update-index.c:995
+#: builtin/update-index.c:1026
 msgid "with --stdin: input lines are terminated by null bytes"
 msgstr "với tùy chọn --stdin: các dòng đầu vào được chấm dứt bởi ký tự null"
 
-#: builtin/update-index.c:997
+#: builtin/update-index.c:1028
 msgid "read list of paths to be updated from standard input"
 msgstr "đọc danh sách đường dẫn cần cập nhật từ đầu vào tiêu chuẩn"
 
-#: builtin/update-index.c:1001
+#: builtin/update-index.c:1032
 msgid "add entries from standard input to the index"
 msgstr "không thể đọc các mục từ đầu vào tiêu chuẩn vào bảng mục lục"
 
-#: builtin/update-index.c:1005
+#: builtin/update-index.c:1036
 msgid "repopulate stages #2 and #3 for the listed paths"
 msgstr "phục hồi các trạng thái #2 và #3 cho các đường dẫn được liệt kê"
 
-#: builtin/update-index.c:1009
+#: builtin/update-index.c:1040
 msgid "only update entries that differ from HEAD"
 msgstr "chỉ cập nhật các mục tin mà nó khác biệt so với HEAD"
 
-#: builtin/update-index.c:1013
+#: builtin/update-index.c:1044
 msgid "ignore files missing from worktree"
 msgstr "bỏ qua các tập-tin thiếu trong thư-mục làm việc"
 
-#: builtin/update-index.c:1016
+#: builtin/update-index.c:1047
 msgid "report actions to standard output"
 msgstr "báo cáo các thao tác ra thiết bị xuất chuẩn"
 
-#: builtin/update-index.c:1018
+#: builtin/update-index.c:1049
 msgid "(for porcelains) forget saved unresolved conflicts"
 msgstr "(cho “porcelains”) quên các xung đột chưa được giải quyết đã ghi"
 
-#: builtin/update-index.c:1022
+#: builtin/update-index.c:1053
 msgid "write index in this format"
 msgstr "ghi mục lục ở định dạng này"
 
-#: builtin/update-index.c:1024
+#: builtin/update-index.c:1055
 msgid "enable or disable split index"
 msgstr "bật/tắt chia cắt bảng mục lục"
 
-#: builtin/update-index.c:1026
+#: builtin/update-index.c:1057
 msgid "enable/disable untracked cache"
 msgstr "bật/tắt bộ đệm không theo vết"
 
-#: builtin/update-index.c:1028
+#: builtin/update-index.c:1059
 msgid "test if the filesystem supports untracked cache"
 msgstr "kiểm tra xem hệ thống tập tin có hỗ trợ đệm không theo dõi hay không"
 
-#: builtin/update-index.c:1030
+#: builtin/update-index.c:1061
 msgid "enable untracked cache without testing the filesystem"
 msgstr "bật bộ đệm không theo vết mà không kiểm tra hệ thống tập tin"
 
-#: builtin/update-index.c:1032
+#: builtin/update-index.c:1063
 msgid "write out the index even if is not flagged as changed"
 msgstr "ghi ra mục lục ngay cả khi không được đánh cờ là có thay đổi"
 
-#: builtin/update-index.c:1034
+#: builtin/update-index.c:1065
 msgid "enable or disable file system monitor"
 msgstr "bật/tắt theo dõi hệ thống tập tin"
 
-#: builtin/update-index.c:1036
+#: builtin/update-index.c:1067
 msgid "mark files as fsmonitor valid"
 msgstr "đánh dấu các tập tin là hợp lệ fsmonitor"
 
-#: builtin/update-index.c:1039
+#: builtin/update-index.c:1070
 msgid "clear fsmonitor valid bit"
 msgstr "xóa bít hợp lệ fsmonitor"
 
-#: builtin/update-index.c:1138
+#: builtin/update-index.c:1173
 msgid ""
 "core.splitIndex is set to false; remove or change it, if you really want to "
 "enable split index"
@@ -14978,7 +21209,7 @@ msgstr ""
 "core.splitIndex được đặt là sai; xóa bỏ hay thay đổi nó, nếu bạn thực sự "
 "muốn bật chia tách mục lục"
 
-#: builtin/update-index.c:1147
+#: builtin/update-index.c:1182
 msgid ""
 "core.splitIndex is set to true; remove or change it, if you really want to "
 "disable split index"
@@ -14986,7 +21217,7 @@ msgstr ""
 "core.splitIndex được đặt là đúng; xóa bỏ hay thay đổi nó, nếu bạn thực sự "
 "muốn tắt chia tách mục lục"
 
-#: builtin/update-index.c:1158
+#: builtin/update-index.c:1194
 msgid ""
 "core.untrackedCache is set to true; remove or change it, if you really want "
 "to disable the untracked cache"
@@ -14994,11 +21225,11 @@ msgstr ""
 "core.untrackedCache được đặt là đúng; xóa bỏ hay thay đổi nó, nếu bạn thực "
 "sự muốn tắt bộ đệm chưa theo dõi"
 
-#: builtin/update-index.c:1162
+#: builtin/update-index.c:1198
 msgid "Untracked cache disabled"
 msgstr "Nhớ đệm không theo vết bị tắt"
 
-#: builtin/update-index.c:1170
+#: builtin/update-index.c:1206
 msgid ""
 "core.untrackedCache is set to false; remove or change it, if you really want "
 "to enable the untracked cache"
@@ -15006,57 +21237,57 @@ msgstr ""
 "core.untrackedCache được đặt là sai; xóa bỏ hay thay đổi nó, nếu bạn thực sự "
 "muốn bật bộ đệm chưa theo dõi"
 
-#: builtin/update-index.c:1174
+#: builtin/update-index.c:1210
 #, c-format
 msgid "Untracked cache enabled for '%s'"
 msgstr "Nhớ đệm không theo vết được bật cho “%s”"
 
-#: builtin/update-index.c:1182
+#: builtin/update-index.c:1218
 msgid "core.fsmonitor is unset; set it if you really want to enable fsmonitor"
 msgstr ""
 "core.fsmonitor chưa được đặt; đặt nó nếu bạn thực sự muốn bật theo dõi hệ "
 "thống tập tin"
 
-#: builtin/update-index.c:1186
+#: builtin/update-index.c:1222
 msgid "fsmonitor enabled"
 msgstr "fsmonitor được bật"
 
-#: builtin/update-index.c:1189
+#: builtin/update-index.c:1225
 msgid ""
 "core.fsmonitor is set; remove it if you really want to disable fsmonitor"
 msgstr ""
 "core.fsmonitor đã được đặt; bỏ đặt nó nếu bạn thực sự muốn bật theo dõi hệ "
 "thống tập tin"
 
-#: builtin/update-index.c:1193
+#: builtin/update-index.c:1229
 msgid "fsmonitor disabled"
 msgstr "fsmonitor bị tắt"
 
 #: builtin/update-ref.c:10
 msgid "git update-ref [<options>] -d <refname> [<old-val>]"
-msgstr "git update-ref [<các-tùy-chọn>] -d <refname> [<biến-cũ>]"
+msgstr "git update-ref [<các tùy chọn>] -d <refname> [<biến-cũ>]"
 
 #: builtin/update-ref.c:11
 msgid "git update-ref [<options>]    <refname> <new-val> [<old-val>]"
-msgstr "git update-ref [<các-tùy-chọn>]    <refname> <biến-mới> [<biến-cũ>]"
+msgstr "git update-ref [<các tùy chọn>]    <refname> <biến-mới> [<biến-cũ>]"
 
 #: builtin/update-ref.c:12
 msgid "git update-ref [<options>] --stdin [-z]"
-msgstr "git update-ref [<các-tùy-chọn>] --stdin [-z]"
+msgstr "git update-ref [<các tùy chọn>] --stdin [-z]"
 
-#: builtin/update-ref.c:363
+#: builtin/update-ref.c:364
 msgid "delete the reference"
 msgstr "xóa tham chiếu"
 
-#: builtin/update-ref.c:365
+#: builtin/update-ref.c:366
 msgid "update <refname> not the one it points to"
 msgstr "cập nhật <tên-tham-chiếu> không phải cái nó chỉ tới"
 
-#: builtin/update-ref.c:366
+#: builtin/update-ref.c:367
 msgid "stdin has NUL-terminated arguments"
 msgstr "đầu vào tiêu chuẩn có các đối số được chấm dứt bởi NUL"
 
-#: builtin/update-ref.c:367
+#: builtin/update-ref.c:368
 msgid "read updates from stdin"
 msgstr "đọc cập nhật từ đầu vào tiêu chuẩn"
 
@@ -15070,7 +21301,11 @@ msgstr "cập nhật các tập tin thô
 
 #: builtin/upload-pack.c:11
 msgid "git upload-pack [<options>] <dir>"
-msgstr "git upload-pack [<các-tùy-chọn>] </đường/dẫn>"
+msgstr "git upload-pack [<các tùy chọn>] </đường/dẫn>"
+
+#: builtin/upload-pack.c:23 t/helper/test-serve-v2.c:17
+msgid "quit after a single request/response exchange"
+msgstr "thoát sau khi một trao đổi yêu cầu hay trả lời đơn"
 
 #: builtin/upload-pack.c:25
 msgid "exit immediately after initial ref advertisement"
@@ -15084,15 +21319,15 @@ msgstr "đừng thử <thư_mục>/.git/
 msgid "interrupt transfer after <n> seconds of inactivity"
 msgstr "ngắt truyền thông sau <n> giây không hoạt động"
 
-#: builtin/verify-commit.c:18
+#: builtin/verify-commit.c:19
 msgid "git verify-commit [-v | --verbose] <commit>..."
 msgstr "git verify-commit [-v | --verbose] <lần_chuyển_giao>…"
 
-#: builtin/verify-commit.c:73
+#: builtin/verify-commit.c:68
 msgid "print commit contents"
 msgstr "hiển thị nội dung của lần chuyển giao"
 
-#: builtin/verify-commit.c:74 builtin/verify-tag.c:38
+#: builtin/verify-commit.c:69 builtin/verify-tag.c:37
 msgid "print raw gpg status output"
 msgstr "in kết xuất trạng thái gpg dạng thô"
 
@@ -15108,25 +21343,25 @@ msgstr "chi tiết"
 msgid "show statistics only"
 msgstr "chỉ hiển thị thống kê"
 
-#: builtin/verify-tag.c:19
+#: builtin/verify-tag.c:18
 msgid "git verify-tag [-v | --verbose] [--format=<format>] <tag>..."
 msgstr "git verify-tag [-v | --verbose] [--format=<định_dạng>] <thẻ>…"
 
-#: builtin/verify-tag.c:37
+#: builtin/verify-tag.c:36
 msgid "print tag contents"
 msgstr "hiển thị nội dung của thẻ"
 
 #: builtin/worktree.c:17
 msgid "git worktree add [<options>] <path> [<commit-ish>]"
-msgstr "git worktree add [<các-tùy-chọn>] <đường-dẫn> [<commit-ish>]"
+msgstr "git worktree add [<các tùy chọn>] </đường/dẫn> [<commit-ish>]"
 
 #: builtin/worktree.c:18
 msgid "git worktree list [<options>]"
-msgstr "git worktree list [<các-tùy-chọn>]"
+msgstr "git worktree list [<các tùy chọn>]"
 
 #: builtin/worktree.c:19
 msgid "git worktree lock [<options>] <path>"
-msgstr "git worktree lock [<các-tùy-chọn>] </đường/dẫn>"
+msgstr "git worktree lock [<các tùy chọn>] </đường/dẫn>"
 
 #: builtin/worktree.c:20
 msgid "git worktree move <worktree> <new-path>"
@@ -15134,236 +21369,281 @@ msgstr "git worktree move <worktree> </
 
 #: builtin/worktree.c:21
 msgid "git worktree prune [<options>]"
-msgstr "git worktree prune [<các-tùy-chọn>]"
+msgstr "git worktree prune [<các tùy chọn>]"
 
 #: builtin/worktree.c:22
 msgid "git worktree remove [<options>] <worktree>"
-msgstr "git worktree remove [<các-tùy-chọn>] <worktree>"
+msgstr "git worktree remove [<các tùy chọn>] <worktree>"
 
 #: builtin/worktree.c:23
 msgid "git worktree unlock <path>"
 msgstr "git worktree unlock </đường/dẫn>"
 
-#: builtin/worktree.c:58
+#: builtin/worktree.c:60 builtin/worktree.c:898
+#, c-format
+msgid "failed to delete '%s'"
+msgstr "gặp lỗi khi xóa “%s”"
+
+#: builtin/worktree.c:79
 #, c-format
 msgid "Removing worktrees/%s: not a valid directory"
 msgstr "Gỡ bỏ cây làm việc/%s: không phải là thư mục hợp lệ"
 
-#: builtin/worktree.c:64
+#: builtin/worktree.c:85
 #, c-format
 msgid "Removing worktrees/%s: gitdir file does not exist"
 msgstr "Gỡ bỏ cây làm việc/%s: không có tập tin gitdir"
 
-#: builtin/worktree.c:69 builtin/worktree.c:78
+#: builtin/worktree.c:90 builtin/worktree.c:99
 #, c-format
 msgid "Removing worktrees/%s: unable to read gitdir file (%s)"
 msgstr "Gỡ bỏ cây làm việc/%s: không thể đọc tập tin gitdir (%s)"
 
-#: builtin/worktree.c:88
+#: builtin/worktree.c:109
 #, c-format
 msgid ""
 "Removing worktrees/%s: short read (expected %<PRIuMAX> bytes, read "
 "%<PRIuMAX>)"
 msgstr "Gỡ bỏ cây làm việc/%s: đọc ngắn (cần %<PRIuMAX> byte, đọc %<PRIuMAX>)"
 
-#: builtin/worktree.c:96
+#: builtin/worktree.c:117
 #, c-format
 msgid "Removing worktrees/%s: invalid gitdir file"
 msgstr "Gỡ bỏ cây làm việc/%s: tập tin gitdir không hợp lệ"
 
-#: builtin/worktree.c:105
+#: builtin/worktree.c:126
 #, c-format
 msgid "Removing worktrees/%s: gitdir file points to non-existent location"
 msgstr "Gỡ bỏ cây làm việc/%s: tập tin gitdir chỉ đến vị trí không tồn tại"
 
-#: builtin/worktree.c:152
+#: builtin/worktree.c:165
 msgid "report pruned working trees"
 msgstr "báo cáo các cây làm việc đã prune"
 
-#: builtin/worktree.c:154
+#: builtin/worktree.c:167
 msgid "expire working trees older than <time>"
 msgstr "các cây làm việc hết hạn cũ hơn khoảng <thời gian>"
 
-#: builtin/worktree.c:229
+#: builtin/worktree.c:234
 #, c-format
 msgid "'%s' already exists"
 msgstr "“%s” đã có từ trước rồi"
 
-#: builtin/worktree.c:260
+#: builtin/worktree.c:251
+#, c-format
+msgid "unable to re-add worktree '%s'"
+msgstr "không thể thêm-lại cây “%s”"
+
+#: builtin/worktree.c:256
+#, c-format
+msgid ""
+"'%s' is a missing but locked worktree;\n"
+"use 'add -f -f' to override, or 'unlock' and 'prune' or 'remove' to clear"
+msgstr ""
+"“%s” bị mất nhưng cây làm việc bị khóa;\n"
+"dùng “add -f -f” để ghi đè, hoặc “unlock” và “prune” hay “remove” để xóa"
+
+#: builtin/worktree.c:258
+#, c-format
+msgid ""
+"'%s' is a missing but already registered worktree;\n"
+"use 'add -f' to override, or 'prune' or 'remove' to clear"
+msgstr ""
+"“%s” bị mất nhưng cây làm việc đã được đăng ký;\n"
+"dùng “add -f” để ghi đè, hoặc “prune” hay “remove” để xóa"
+
+#: builtin/worktree.c:308
 #, c-format
 msgid "could not create directory of '%s'"
 msgstr "không thể tạo thư mục của “%s”"
 
-#: builtin/worktree.c:373 builtin/worktree.c:379
+#: builtin/worktree.c:439 builtin/worktree.c:445
 #, c-format
 msgid "Preparing worktree (new branch '%s')"
 msgstr "Đang chuẩn bị cây làm việc (nhánh mới “%s”)"
 
-#: builtin/worktree.c:375
+#: builtin/worktree.c:441
 #, c-format
 msgid "Preparing worktree (resetting branch '%s'; was at %s)"
 msgstr "Đang chuẩn bị cây làm việc (đang cài đặt nhánh “%s”, trước đây tại %s)"
 
-#: builtin/worktree.c:384
+#: builtin/worktree.c:450
 #, c-format
 msgid "Preparing worktree (checking out '%s')"
 msgstr "Đang chuẩn bị cây làm việc (đang lấy ra “%s”)"
 
-#: builtin/worktree.c:390
+#: builtin/worktree.c:456
 #, c-format
 msgid "Preparing worktree (detached HEAD %s)"
 msgstr "Đang chuẩn bị cây làm việc (HEAD đã tách rời “%s”)"
 
-#: builtin/worktree.c:431
+#: builtin/worktree.c:497
 msgid "checkout <branch> even if already checked out in other worktree"
 msgstr "lấy ra <nhánh> ngay cả khi nó đã được lấy ra ở cây làm việc khác"
 
-#: builtin/worktree.c:434
+#: builtin/worktree.c:500
 msgid "create a new branch"
 msgstr "tạo nhánh mới"
 
-#: builtin/worktree.c:436
+#: builtin/worktree.c:502
 msgid "create or reset a branch"
 msgstr "tạo hay đặt lại một nhánh"
 
-#: builtin/worktree.c:438
+#: builtin/worktree.c:504
 msgid "populate the new working tree"
 msgstr "di chuyển cây làm việc mới"
 
-#: builtin/worktree.c:439
+#: builtin/worktree.c:505
 msgid "keep the new working tree locked"
 msgstr "giữ cây làm việc mới bị khóa"
 
-#: builtin/worktree.c:441
+#: builtin/worktree.c:508
 msgid "set up tracking mode (see git-branch(1))"
 msgstr "cài đặt chế độ theo dõi (xem git-branch(1))"
 
-#: builtin/worktree.c:444
+#: builtin/worktree.c:511
 msgid "try to match the new branch name with a remote-tracking branch"
 msgstr "có khớp tên tên nhánh mới với một nhánh theo dõi máy chủ"
 
-#: builtin/worktree.c:452
+#: builtin/worktree.c:519
 msgid "-b, -B, and --detach are mutually exclusive"
 msgstr "Các tùy chọn -b, -B, và --detach loại từ lẫn nhau"
 
-#: builtin/worktree.c:511
+#: builtin/worktree.c:580
 msgid "--[no-]track can only be used if a new branch is created"
 msgstr "--[no-]track chỉ có thể được dùng nếu một nhánh mới được tạo"
 
-#: builtin/worktree.c:611
+#: builtin/worktree.c:680
 msgid "reason for locking"
 msgstr "lý do khóa"
 
-#: builtin/worktree.c:623 builtin/worktree.c:656 builtin/worktree.c:710
-#: builtin/worktree.c:850
+#: builtin/worktree.c:692 builtin/worktree.c:725 builtin/worktree.c:799
+#: builtin/worktree.c:926
 #, c-format
 msgid "'%s' is not a working tree"
 msgstr "%s không phải là cây làm việc"
 
-#: builtin/worktree.c:625 builtin/worktree.c:658
+#: builtin/worktree.c:694 builtin/worktree.c:727
 msgid "The main working tree cannot be locked or unlocked"
 msgstr "Cây thư mục làm việc chính không thể khóa hay bỏ khóa được"
 
-#: builtin/worktree.c:630
+#: builtin/worktree.c:699
 #, c-format
 msgid "'%s' is already locked, reason: %s"
 msgstr "“%s” đã được khóa rồi, lý do: %s"
 
-#: builtin/worktree.c:632
+#: builtin/worktree.c:701
 #, c-format
 msgid "'%s' is already locked"
 msgstr "“%s” đã được khóa rồi"
 
-#: builtin/worktree.c:660
+#: builtin/worktree.c:729
 #, c-format
 msgid "'%s' is not locked"
 msgstr "“%s” chưa bị khóa"
 
-#: builtin/worktree.c:685
+#: builtin/worktree.c:770
 msgid "working trees containing submodules cannot be moved or removed"
 msgstr "cây làm việc có chứa mô-đun-con không thể di chuyển hay xóa bỏ"
 
-#: builtin/worktree.c:712 builtin/worktree.c:852
+#: builtin/worktree.c:778
+msgid "force move even if worktree is dirty or locked"
+msgstr "ép buộc ngay cả khi cây làm việc đang bẩn hay bị khóa"
+
+#: builtin/worktree.c:801 builtin/worktree.c:928
 #, c-format
 msgid "'%s' is a main working tree"
 msgstr "“%s” là cây làm việc chính"
 
-#: builtin/worktree.c:717
+#: builtin/worktree.c:806
 #, c-format
 msgid "could not figure out destination name from '%s'"
 msgstr "không thể phác họa ra tên đích đến “%s”"
 
-#: builtin/worktree.c:723
+#: builtin/worktree.c:812
 #, c-format
 msgid "target '%s' already exists"
 msgstr "đích “%s” đã tồn tại rồi"
 
-#: builtin/worktree.c:730
+#: builtin/worktree.c:820
 #, c-format
-msgid "cannot move a locked working tree, lock reason: %s"
-msgstr "không thể di chuyển một cây-làm-việc bị khóa, khóa vì: %s"
+msgid ""
+"cannot move a locked working tree, lock reason: %s\n"
+"use 'move -f -f' to override or unlock first"
+msgstr ""
+"không thể di chuyển một cây-làm-việc bị khóa, khóa vì: %s\n"
+"dùng “move -f -f” để ghi đè hoặc mở khóa trước đã"
 
-#: builtin/worktree.c:732
-msgid "cannot move a locked working tree"
-msgstr "không thể di chuyển một cây-làm-việc bị khóa"
+#: builtin/worktree.c:822
+msgid ""
+"cannot move a locked working tree;\n"
+"use 'move -f -f' to override or unlock first"
+msgstr ""
+"không thể di chuyển một cây-làm-việc bị khóa;\n"
+"dùng “move -f -f” để ghi đè hoặc mở khóa trước đã"
 
-#: builtin/worktree.c:735
+#: builtin/worktree.c:825
 #, c-format
 msgid "validation failed, cannot move working tree: %s"
 msgstr "thẩm tra gặp lỗi, không thể di chuyển một cây-làm-việc: %s"
 
-#: builtin/worktree.c:740
+#: builtin/worktree.c:830
 #, c-format
 msgid "failed to move '%s' to '%s'"
 msgstr "gặp lỗi khi chuyển “%s” sang “%s”"
 
-#: builtin/worktree.c:788
+#: builtin/worktree.c:878
 #, c-format
 msgid "failed to run 'git status' on '%s'"
 msgstr "gặp lỗi khi chạy “git status” vào “%s”"
 
-#: builtin/worktree.c:792
+#: builtin/worktree.c:882
 #, c-format
-msgid "'%s' is dirty, use --force to delete it"
-msgstr "“%s” đang bẩn, hãy dùng --force để xóa nó"
+msgid "'%s' contains modified or untracked files, use --force to delete it"
+msgstr ""
+"“%s” có chứa các tập tin đã bị sửa chữa hoặc chưa được theo dõi, hãy dùng --"
+"force để xóa nó"
 
-#: builtin/worktree.c:797
+#: builtin/worktree.c:887
 #, c-format
 msgid "failed to run 'git status' on '%s', code %d"
 msgstr "gặp lỗi khi chạy “git status” trong “%s”, mã %d"
 
-#: builtin/worktree.c:808 builtin/worktree.c:822
-#, c-format
-msgid "failed to delete '%s'"
-msgstr "gặp lỗi khi xóa “%s”"
-
-#: builtin/worktree.c:834
-msgid "force removing even if the worktree is dirty"
-msgstr "ép buộc di chuyển thậm chí cả khi cây làm việc đang bẩn"
+#: builtin/worktree.c:910
+msgid "force removal even if worktree is dirty or locked"
+msgstr "ép buộc di chuyển thậm chí cả khi cây làm việc đang bẩn hay bị khóa"
 
-#: builtin/worktree.c:856
+#: builtin/worktree.c:933
 #, c-format
-msgid "cannot remove a locked working tree, lock reason: %s"
-msgstr "không thể gỡ bỏ một cây-làm-việc bị khóa, khóa vì: %s"
+msgid ""
+"cannot remove a locked working tree, lock reason: %s\n"
+"use 'remove -f -f' to override or unlock first"
+msgstr ""
+"không thể xóa bỏ một cây-làm-việc bị khóa, khóa vì: %s\n"
+"dùng “remove -f -f” để ghi đè hoặc mở khóa trước đã"
 
-#: builtin/worktree.c:858
-msgid "cannot remove a locked working tree"
-msgstr "không thể gỡ bỏ một cây-làm-việc bị khóa"
+#: builtin/worktree.c:935
+msgid ""
+"cannot remove a locked working tree;\n"
+"use 'remove -f -f' to override or unlock first"
+msgstr ""
+"không thể xóa bỏ một cây-làm-việc bị khóa;\n"
+"dùng “remove -f -f” để ghi đè hoặc mở khóa trước đã"
 
-#: builtin/worktree.c:861
+#: builtin/worktree.c:938
 #, c-format
 msgid "validation failed, cannot remove working tree: %s"
 msgstr "thẩm tra gặp lỗi, không thể gỡ bỏ một cây-làm-việc: %s"
 
-#: builtin/write-tree.c:14
+#: builtin/write-tree.c:15
 msgid "git write-tree [--missing-ok] [--prefix=<prefix>/]"
 msgstr "git write-tree [--missing-ok] [--prefix=<tiền-tố>/]"
 
-#: builtin/write-tree.c:27
+#: builtin/write-tree.c:28
 msgid "<prefix>/"
 msgstr "<tiền tố>/"
 
-#: builtin/write-tree.c:28
+#: builtin/write-tree.c:29
 msgid "write tree object for a subdirectory <prefix>"
 msgstr "ghi đối tượng cây (tree) cho <tiền tố> thư mục con"
 
@@ -15371,7 +21651,23 @@ msgstr "ghi đối tượng cây (tree)
 msgid "only useful for debugging"
 msgstr "chỉ hữu ích khi cần gỡ lỗi"
 
-#: credential-cache--daemon.c:222
+#: fast-import.c:3125
+#, c-format
+msgid "Expected 'mark' command, got %s"
+msgstr "Cần lệnh 'mark', nhưng lại nhận được %s"
+
+#: fast-import.c:3130
+#, c-format
+msgid "Expected 'to' command, got %s"
+msgstr "Cần lệnh 'to', nhưng lại nhận được %s"
+
+#: fast-import.c:3254
+#, c-format
+msgid "feature '%s' forbidden in input without --allow-unsafe-features"
+msgstr ""
+"tính năng ' %s ' bị cấm chỉ trong đầu vào mà không có --allow-unsafe-features"
+
+#: credential-cache--daemon.c:223
 #, c-format
 msgid ""
 "The permissions on your socket directory are too loose; other\n"
@@ -15384,10 +21680,27 @@ msgstr ""
 "\n"
 "\tchmod 0700 %s"
 
-#: credential-cache--daemon.c:271
+#: credential-cache--daemon.c:272
 msgid "print debugging messages to stderr"
 msgstr "in thông tin gỡ lỗi ra đầu ra lỗi tiêu chuẩn"
 
+#: t/helper/test-reach.c:152
+#, c-format
+msgid "commit %s is not marked reachable"
+msgstr "lần chuyển giao %s chưa được đánh dấu là tiếp cận được"
+
+#: t/helper/test-reach.c:162
+msgid "too many commits marked reachable"
+msgstr "có quá nhiều lần chuyển giao được đánh dấu là tiếp cận được"
+
+#: t/helper/test-serve-v2.c:7
+msgid "test-tool serve-v2 [<options>]"
+msgstr "test-tool serve-v2 [<các tùy chọn>]"
+
+#: t/helper/test-serve-v2.c:19
+msgid "exit immediately after advertising capabilities"
+msgstr "thoát ngay sau khi khởi tạo quảng cáo capabilities"
+
 #: git.c:27
 msgid ""
 "git [--version] [--help] [-C <path>] [-c <name>=<value>]\n"
@@ -15410,116 +21723,340 @@ msgstr ""
 msgid ""
 "'git help -a' and 'git help -g' list available subcommands and some\n"
 "concept guides. See 'git help <command>' or 'git help <concept>'\n"
-"to read about a specific subcommand or concept."
+"to read about a specific subcommand or concept.\n"
+"See 'git help git' for an overview of the system."
 msgstr ""
 "“git help -a” và “git help -g” liệt kê các câu lệnh con sẵn có và một số\n"
 "hướng dẫn về khái niệm. Xem “git help <lệnh>” hay “git help <khái-niệm>”\n"
-"để xem các đặc tả cho lệnh hay khái niệm cụ thể."
+"để xem các đặc tả cho lệnh hay khái niệm cụ thể.\n"
+"Xem 'git help git' để biết tổng quan của hệ thống."
 
-#: git.c:173
+#: git.c:186
 #, c-format
 msgid "no directory given for --git-dir\n"
 msgstr "chưa chỉ ra thư mục cho --git-dir\n"
 
-#: git.c:187
+#: git.c:200
 #, c-format
 msgid "no namespace given for --namespace\n"
 msgstr "chưa đưa ra không gian làm việc cho --namespace\n"
 
-#: git.c:201
+#: git.c:214
 #, c-format
 msgid "no directory given for --work-tree\n"
 msgstr "chưa đưa ra cây làm việc cho --work-tree\n"
 
-#: git.c:215
+#: git.c:228
 #, c-format
 msgid "no prefix given for --super-prefix\n"
 msgstr "chưa đưa ra tiền tố cho --super-prefix\n"
 
-#: git.c:237
+#: git.c:250
 #, c-format
 msgid "-c expects a configuration string\n"
 msgstr "-c cần một chuỗi cấu hình\n"
 
-#: git.c:275
+#: git.c:288
 #, c-format
 msgid "no directory given for -C\n"
-msgstr ""
-"chưa đưa ra thư mục cho -C\n"
-"\n"
+msgstr "chưa đưa ra thư mục cho -C\n"
 
-#: git.c:300
+#: git.c:314
 #, c-format
 msgid "unknown option: %s\n"
 msgstr "không hiểu tùy chọn: %s\n"
 
-#: git.c:765
+#: git.c:360
+#, c-format
+msgid "while expanding alias '%s': '%s'"
+msgstr "trong khi triển khai bí danh “%s”: “%s”"
+
+#: git.c:369
+#, c-format
+msgid ""
+"alias '%s' changes environment variables.\n"
+"You can use '!git' in the alias to do this"
+msgstr ""
+"bí danh “%s” thay đổi biến môi trường.\n"
+"Bạn có thể sử dụng “!git” trong đặt bí danh để làm việc này"
+
+#: git.c:376
+#, c-format
+msgid "empty alias for %s"
+msgstr "làm trống bí danh cho %s"
+
+#: git.c:379
+#, c-format
+msgid "recursive alias: %s"
+msgstr "đệ quy các bí danh: %s"
+
+#: git.c:459
+msgid "write failure on standard output"
+msgstr "lỗi ghi nghiêm trong trên đầu ra tiêu chuẩn"
+
+#: git.c:461
+msgid "unknown write failure on standard output"
+msgstr "lỗi nghiêm trọng chưa biết khi ghi ra đầu ra tiêu chuẩn"
+
+#: git.c:463
+msgid "close failed on standard output"
+msgstr "gặp lỗi khi đóng đầu ra tiêu chuẩn"
+
+#: git.c:793
+#, c-format
+msgid "alias loop detected: expansion of '%s' does not terminate:%s"
+msgstr ""
+"dò tìm thấy các bí danh quẩn tròn: biểu thức của “%s” không có điểm kết:%s"
+
+#: git.c:843
+#, c-format
+msgid "cannot handle %s as a builtin"
+msgstr "không thể xử lý %s như là một phần bổ sung"
+
+#: git.c:856
+#, c-format
+msgid ""
+"usage: %s\n"
+"\n"
+msgstr ""
+"cách dùng: %s\n"
+"\n"
+
+#: git.c:876
 #, c-format
 msgid "expansion of alias '%s' failed; '%s' is not a git command\n"
 msgstr "gặp lỗi khi khai triển bí danh “%s”; “%s” không phải là lệnh git\n"
 
-#: git.c:777
+#: git.c:888
+#, c-format
+msgid "failed to run command '%s': %s\n"
+msgstr "gặp lỗi khi chạy lệnh “%s”: %s\n"
+
+#: http.c:378
+#, c-format
+msgid "negative value for http.postbuffer; defaulting to %d"
+msgstr "giá trị âm cho http.postbuffer; đặt thành mặc định là %d"
+
+#: http.c:399
+msgid "Delegation control is not supported with cURL < 7.22.0"
+msgstr "Điều khiển giao quyền không được hỗ trợ với cURL < 7.22.0"
+
+#: http.c:408
+msgid "Public key pinning not supported with cURL < 7.44.0"
+msgstr "Chốt khóa công không được hỗ trợ với cURL < 7.44.0"
+
+#: http.c:876
+msgid "CURLSSLOPT_NO_REVOKE not supported with cURL < 7.44.0"
+msgstr "CURLSSLOPT_NO_REVOKE không được hỗ trợ với cURL < 7.44.0"
+
+#: http.c:949
+msgid "Protocol restrictions not supported with cURL < 7.19.4"
+msgstr "Các hạn chế giao thức không được hỗ trợ với cURL < 7.19.4"
+
+#: http.c:1086
+#, c-format
+msgid "Unsupported SSL backend '%s'. Supported SSL backends:"
+msgstr ""
+"Không hỗ trợ ứng dụng SSL chạy phía sau “%s”. Hỗ trợ ứng dụng SSL chạy phía "
+"sau:"
+
+#: http.c:1093
+#, c-format
+msgid "Could not set SSL backend to '%s': cURL was built without SSL backends"
+msgstr ""
+"Không thể đặt ứng dụng chạy SSL phía sau “%s”: cURL được biên dịch không có "
+"sự hỗ trợ ứng dụng chạy phía sau SSL"
+
+#: http.c:1097
+#, c-format
+msgid "Could not set SSL backend to '%s': already set"
+msgstr "Không thể đặt ứng dụng chạy sau SSL cho “%s”: đã đặt rồi"
+
+#: http.c:1966
+#, c-format
+msgid ""
+"unable to update url base from redirection:\n"
+"  asked for: %s\n"
+"   redirect: %s"
+msgstr ""
+"không thể cập nhật dựa trên cơ sở url từ chuyển hướng:\n"
+"      hỏi cho: %s\n"
+" chuyển hướng: %s"
+
+#: remote-curl.c:166
+#, c-format
+msgid "invalid quoting in push-option value: '%s'"
+msgstr "sai trích dẫn trong giá trị push-option :“%s”"
+
+#: remote-curl.c:263
+#, c-format
+msgid "%sinfo/refs not valid: is this a git repository?"
+msgstr "%sinfo/refs không hợp lệ: đây có phải là một kho git?"
+
+#: remote-curl.c:364
+msgid "invalid server response; expected service, got flush packet"
+msgstr ""
+"đáp ứng từ máy phục vụ không hợp lệ; cần dịch vụ, nhưng lại nhận được gói "
+"flush"
+
+#: remote-curl.c:395
+#, c-format
+msgid "invalid server response; got '%s'"
+msgstr "trả về của máy phục vụ không hợp lệ; nhận được %s"
+
+#: remote-curl.c:455
+#, c-format
+msgid "repository '%s' not found"
+msgstr "không tìm thấy kho “%s”"
+
+#: remote-curl.c:459
+#, c-format
+msgid "Authentication failed for '%s'"
+msgstr "Xác thực gặp lỗi cho “%s”"
+
+#: remote-curl.c:463
+#, c-format
+msgid "unable to access '%s': %s"
+msgstr "không thể truy cập “%s”: %s"
+
+#: remote-curl.c:469
+#, c-format
+msgid "redirecting to %s"
+msgstr "chuyển hướng đến %s"
+
+#: remote-curl.c:593
+msgid "shouldn't have EOF when not gentle on EOF"
+msgstr "không nên có EOF khi không gentle trên EOF"
+
+#: remote-curl.c:673
+msgid "unable to rewind rpc post data - try increasing http.postBuffer"
+msgstr "không thể tua lại dữ liệu post rpc - thử tăng http.postBuffer"
+
+#: remote-curl.c:733
+#, c-format
+msgid "RPC failed; %s"
+msgstr "RPC gặp lỗi; %s"
+
+#: remote-curl.c:773
+msgid "cannot handle pushes this big"
+msgstr "không thể xử lý đẩy cái lớn này"
+
+#: remote-curl.c:888
+#, c-format
+msgid "cannot deflate request; zlib deflate error %d"
+msgstr "không thể giải nén yêu cầu; có lỗi khi giải nén của zlib %d"
+
+#: remote-curl.c:892
+#, c-format
+msgid "cannot deflate request; zlib end error %d"
+msgstr "không thể giải nén yêu cầu; có lỗi ở cuối %d"
+
+#: remote-curl.c:1023
+msgid "dumb http transport does not support shallow capabilities"
+msgstr "đổ vận chuyển http không hỗ trợ khả năng nông"
+
+#: remote-curl.c:1037
+msgid "fetch failed."
+msgstr "lấy về gặp lỗi."
+
+#: remote-curl.c:1085
+msgid "cannot fetch by sha1 over smart http"
+msgstr "không thể lấy về bằng sha1 thông qua smart http"
+
+#: remote-curl.c:1129 remote-curl.c:1135
 #, c-format
-msgid "failed to run command '%s': %s\n"
-msgstr "gặp lỗi khi chạy lệnh “%s”: %s\n"
+msgid "protocol error: expected sha/ref, got '%s'"
+msgstr "lỗi giao thức: cần sha/ref, nhưng lại nhận được “%s”"
 
-#: http.c:348
+#: remote-curl.c:1147 remote-curl.c:1261
 #, c-format
-msgid "negative value for http.postbuffer; defaulting to %d"
-msgstr "giá trị âm cho http.postbuffer; mặc định là %d"
+msgid "http transport does not support %s"
+msgstr "vận chuyển http không hỗ trợ %s"
 
-#: http.c:369
-msgid "Delegation control is not supported with cURL < 7.22.0"
-msgstr "Điều khiển giao quyền không được hỗ trợ với cURL < 7.22.0"
+#: remote-curl.c:1183
+msgid "git-http-push failed"
+msgstr "git-http-push gặp lỗi"
 
-#: http.c:378
-msgid "Public key pinning not supported with cURL < 7.44.0"
-msgstr "Chốt khóa công không được hỗ trợ với cURL < 7.44.0"
+#: remote-curl.c:1367
+msgid "remote-curl: usage: git remote-curl <remote> [<url>]"
+msgstr "remote-curl: usage: git remote-curl <máy chủ> [<url>]"
 
-#: http.c:1854
-#, c-format
-msgid ""
-"unable to update url base from redirection:\n"
-"  asked for: %s\n"
-"   redirect: %s"
-msgstr ""
-"không thể cập nhật dựa trên cơ sở url từ chuyển hướng:\n"
-"      hỏi cho: %s\n"
-" chuyển hướng: %s"
+#: remote-curl.c:1399
+msgid "remote-curl: error reading command stream from git"
+msgstr "remote-curl: gặp lỗi khi đọc luồng dữ liệu lệnh từ git"
+
+#: remote-curl.c:1406
+msgid "remote-curl: fetch attempted without a local repo"
+msgstr "remote-curl: đã cố gắng fetch mà không có kho nội bộ"
 
-#: remote-curl.c:401
+#: remote-curl.c:1446
 #, c-format
-msgid "redirecting to %s"
-msgstr "chuyển hướng đến %s"
+msgid "remote-curl: unknown command '%s' from git"
+msgstr "remote-curl: không hiểu lệnh “%s” từ git"
 
-#: list-objects-filter-options.h:59
+#: list-objects-filter-options.h:85
 msgid "args"
 msgstr "các_tham_số"
 
-#: list-objects-filter-options.h:60
+#: list-objects-filter-options.h:86
 msgid "object filtering"
 msgstr "lọc đối tượng"
 
-#: parse-options.h:157
+#: parse-options.h:183
 msgid "expiry-date"
 msgstr "ngày hết hạn"
 
-#: parse-options.h:172
+#: parse-options.h:197
 msgid "no-op (backward compatibility)"
 msgstr "no-op (tương thích ngược)"
 
-#: parse-options.h:251
+#: parse-options.h:309
 msgid "be more verbose"
 msgstr "chi tiết hơn nữa"
 
-#: parse-options.h:253
+#: parse-options.h:311
 msgid "be more quiet"
 msgstr "im lặng hơn nữa"
 
-#: parse-options.h:259
+#: parse-options.h:317
 msgid "use <n> digits to display SHA-1s"
 msgstr "sử dụng <n> chữ số để hiển thị SHA-1s"
 
+#: parse-options.h:336
+msgid "how to strip spaces and #comments from message"
+msgstr "làm thế nào để cắt bỏ khoảng trắng và #ghichú từ mẩu tin nhắn"
+
+#: parse-options.h:337
+msgid "read pathspec from file"
+msgstr "đọc đặc tả đường dẫn từ tập tin"
+
+#: parse-options.h:338
+msgid ""
+"with --pathspec-from-file, pathspec elements are separated with NUL character"
+msgstr ""
+"với --pathspec-from-file, các phần tử đặc tả đường dẫn bị ngăn cách bởi ký "
+"tự NULL"
+
+#: ref-filter.h:101
+msgid "key"
+msgstr "khóa"
+
+#: ref-filter.h:101
+msgid "field name to sort on"
+msgstr "tên trường cần sắp xếp"
+
+#: rerere.h:44
+msgid "update the index with reused conflict resolution if possible"
+msgstr "cập nhật bảng mục lục với phân giải xung đột dùng lại nếu được"
+
+#: wt-status.h:67
+msgid "HEAD detached at "
+msgstr "HEAD được tách rời tại "
+
+#: wt-status.h:68
+msgid "HEAD detached from "
+msgstr "HEAD được tách rời từ "
+
 #: command-list.h:50
 msgid "Add file contents to the index"
 msgstr "Thêm nội dung tập tin vào bảng mục lục"
@@ -15538,8 +22075,8 @@ msgstr ""
 "Áp dụng một miếng vá cho các tập tin đã chỉ ra và/hoặc vào bảng mục lục"
 
 #: command-list.h:54
-msgid "Import an Arch repository into Git"
-msgstr "Nhập một kho Arch vào một kho Git"
+msgid "Import a GNU Arch repository into Git"
+msgstr "Nhập một kho GNU Arch vào một kho Git"
 
 #: command-list.h:55
 msgid "Create an archive of files from a named tree"
@@ -15620,8 +22157,8 @@ msgid "Record changes to the repository"
 msgstr "Ghi các thay đổi vào kho chứa"
 
 #: command-list.h:74
-msgid "Write and verify Git commit graph files"
-msgstr "Ghi và thẩm tra các tập tin đồ họa các lền chuyển giao git"
+msgid "Write and verify Git commit-graph files"
+msgstr "Ghi và thẩm tra các tập tin đồ họa các lần chuyển giao Git"
 
 #: command-list.h:75
 msgid "Create a new commit object"
@@ -15673,8 +22210,8 @@ msgstr ""
 #: command-list.h:86
 msgid "Show changes between commits, commit and working tree, etc"
 msgstr ""
-"Xem các thay đổi giữa những lần chuyển giao, giữa một lần chuyển giao và cây "
-"làm việc, v.v.."
+"Hiển thị các thay đổi giữa những lần chuyển giao, giữa một lần chuyển giao "
+"và cây làm việc, v.v.."
 
 #: command-list.h:87
 msgid "Compares files in the working tree and the index"
@@ -15786,8 +22323,8 @@ msgid "Instantly browse your working rep
 msgstr "Duyệt ngay kho làm việc của bạn trong gitweb"
 
 #: command-list.h:113
-msgid "add or parse structured information in commit messages"
-msgstr "thêm hay phân tích thông tin cấu trúc trong ghi chú lần chuyển giao"
+msgid "Add or parse structured information in commit messages"
+msgstr "Thêm hay phân tích thông tin cấu trúc trong ghi chú lần chuyển giao"
 
 #: command-list.h:114
 msgid "The Git repository browser"
@@ -15848,325 +22385,345 @@ msgid "Show three-way merge without touc
 msgstr "Hiển thị hòa trộn ba-đường mà không đụng chạm đến mục lục"
 
 #: command-list.h:128
+msgid "Write and verify multi-pack-indexes"
+msgstr "Ghi và thẩm tra các multi-pack-indexes"
+
+#: command-list.h:129
 msgid "Creates a tag object"
 msgstr "Tạo một đối tượng thẻ"
 
-#: command-list.h:129
+#: command-list.h:130
 msgid "Build a tree-object from ls-tree formatted text"
 msgstr "Xây dựng một tree-object từ văn bản định dạng ls-tree"
 
-#: command-list.h:130
+#: command-list.h:131
 msgid "Move or rename a file, a directory, or a symlink"
 msgstr "Di chuyển hay đổi tên một tập tin, thư mục hoặc liên kết mềm"
 
-#: command-list.h:131
+#: command-list.h:132
 msgid "Find symbolic names for given revs"
 msgstr "Tìm các tên liên kết mềm cho điểm xét đã cho"
 
-#: command-list.h:132
+#: command-list.h:133
 msgid "Add or inspect object notes"
-msgstr "thêm hoặc điều tra đối tượng ghi chú"
+msgstr "Thêm hoặc điều tra đối tượng ghi chú"
 
-#: command-list.h:133
+#: command-list.h:134
 msgid "Import from and submit to Perforce repositories"
 msgstr "Nhập vào từ và gửi đến các kho cần thiết"
 
-#: command-list.h:134
+#: command-list.h:135
 msgid "Create a packed archive of objects"
 msgstr "Tạo một kho lưu được đóng gói cho các đối"
 
-#: command-list.h:135
+#: command-list.h:136
 msgid "Find redundant pack files"
 msgstr "Tìm các tập tin gói dư thừa"
 
-#: command-list.h:136
+#: command-list.h:137
 msgid "Pack heads and tags for efficient repository access"
 msgstr "Đóng gói các phần đầu và thẻ để truy cập kho hiệu quả hơn"
 
-#: command-list.h:137
+#: command-list.h:138
 msgid "Routines to help parsing remote repository access parameters"
 msgstr "Các thủ tục để giúp phân tích các tham số truy cập kho chứa trên mạng"
 
-#: command-list.h:138
+#: command-list.h:139
 msgid "Compute unique ID for a patch"
 msgstr "Tính toán ID duy nhất cho một miếng vá"
 
-#: command-list.h:139
+#: command-list.h:140
 msgid "Prune all unreachable objects from the object database"
 msgstr ""
 "Xén bớt tất các các đối tượng không tiếp cận được từ cơ sở dữ liệu đối tượng"
 
-#: command-list.h:140
+#: command-list.h:141
 msgid "Remove extra objects that are already in pack files"
 msgstr "Xóa bỏ các đối tượng mở rộng cái mà đã sẵn có trong các tập tin gói"
 
-#: command-list.h:141
+#: command-list.h:142
 msgid "Fetch from and integrate with another repository or a local branch"
 msgstr "Lấy về và hợp nhất với kho khác hay một nhánh nội bộ"
 
-#: command-list.h:142
+#: command-list.h:143
 msgid "Update remote refs along with associated objects"
 msgstr "Cập nhật th.chiếu máy chủ cùng với các đối tượng liên quan đến nó"
 
-#: command-list.h:143
+#: command-list.h:144
 msgid "Applies a quilt patchset onto the current branch"
 msgstr "Ấp dụng một bộ miếng vá quilt vào trong nhánh hiện hành"
 
-#: command-list.h:144
+#: command-list.h:145
+msgid "Compare two commit ranges (e.g. two versions of a branch)"
+msgstr "So sánh hai vùng chuyển giao (vd: hai phiên bản của một nhánh)"
+
+#: command-list.h:146
 msgid "Reads tree information into the index"
 msgstr "Đọc thông tin cây vào trong mục lục"
 
-#: command-list.h:145
+#: command-list.h:147
 msgid "Reapply commits on top of another base tip"
 msgstr "Thu hoạch các lần chuyển giao trên đỉnh của đầu mút cơ sở khác"
 
-#: command-list.h:146
+#: command-list.h:148
 msgid "Receive what is pushed into the repository"
 msgstr "Nhận cái mà được đẩy vào trong kho"
 
-#: command-list.h:147
+#: command-list.h:149
 msgid "Manage reflog information"
 msgstr "Quản lý thông tin reflog"
 
-#: command-list.h:148
+#: command-list.h:150
 msgid "Manage set of tracked repositories"
 msgstr "Quản lý tập hợp các kho chứa đã được theo dõi"
 
-#: command-list.h:149
+#: command-list.h:151
 msgid "Pack unpacked objects in a repository"
 msgstr "Đóng gói các đối tượng chưa đóng gói ở một kho chứa"
 
-#: command-list.h:150
+#: command-list.h:152
 msgid "Create, list, delete refs to replace objects"
 msgstr "Tạo, liệt kê, xóa các tham chiếu để thay thế các đối tượng"
 
-#: command-list.h:151
+#: command-list.h:153
 msgid "Generates a summary of pending changes"
 msgstr "Tạo ra một tóm tắt các thay đổi còn treo"
 
-#: command-list.h:152
+#: command-list.h:154
 msgid "Reuse recorded resolution of conflicted merges"
 msgstr "Dùng lại các giải pháp đã ghi lại của các hòa trộn bị xung đột"
 
-#: command-list.h:153
+#: command-list.h:155
 msgid "Reset current HEAD to the specified state"
 msgstr "Đặt lại HEAD hiện hành thành trạng thái đã cho"
 
-#: command-list.h:154
+#: command-list.h:156
+msgid "Restore working tree files"
+msgstr "Hoàn nguyên các tập tin cây làm việc"
+
+#: command-list.h:157
 msgid "Revert some existing commits"
 msgstr "Hoàn lại một số lần chuyển giao sẵn có"
 
-#: command-list.h:155
+#: command-list.h:158
 msgid "Lists commit objects in reverse chronological order"
 msgstr "Liệt kê các đối tượng chuyển giao theo thứ tự tôpô đảo ngược"
 
-#: command-list.h:156
+#: command-list.h:159
 msgid "Pick out and massage parameters"
 msgstr "Cậy ra và xử lý các tham số"
 
-#: command-list.h:157
+#: command-list.h:160
 msgid "Remove files from the working tree and from the index"
 msgstr "Gỡ bỏ các tập tin từ cây làm việc và từ bảng mục lục"
 
-#: command-list.h:158
+#: command-list.h:161
 msgid "Send a collection of patches as emails"
 msgstr "Gửi một tập hợp của các miếng vá ở dạng thư điện tử"
 
-#: command-list.h:159
+#: command-list.h:162
 msgid "Push objects over Git protocol to another repository"
 msgstr "Đẩy các đối tượng lên thông qua giao thức Git đến kho chứa khác"
 
-#: command-list.h:160
+#: command-list.h:163
 msgid "Restricted login shell for Git-only SSH access"
 msgstr "Hệ vỏ đăng nhập có hạn chế cho truy cập SSH chỉ-Git"
 
-#: command-list.h:161
+#: command-list.h:164
 msgid "Summarize 'git log' output"
 msgstr "Kết xuất “git log” dạng tóm tắt"
 
-#: command-list.h:162
+#: command-list.h:165
 msgid "Show various types of objects"
 msgstr "Hiển thị các kiểu khác nhau của các đối tượng"
 
-#: command-list.h:163
+#: command-list.h:166
 msgid "Show branches and their commits"
 msgstr "Hiển thị những nhánh và các lần chuyển giao của chúng"
 
-#: command-list.h:164
+#: command-list.h:167
 msgid "Show packed archive index"
 msgstr "Hiển thị các muc lục kho nén đã đóng gói"
 
-#: command-list.h:165
+#: command-list.h:168
 msgid "List references in a local repository"
 msgstr "Liệt kê các tham chiếu trong một kho nội bộ"
 
-#: command-list.h:166
+#: command-list.h:169
 msgid "Git's i18n setup code for shell scripts"
 msgstr "Nã cài đặt quốc tế hóa của Git cho văn lệnh hệ vỏ"
 
-#: command-list.h:167
+#: command-list.h:170
 msgid "Common Git shell script setup code"
 msgstr "Mã cài đặt văn lệnh hệ vỏ Git chung"
 
-#: command-list.h:168
+#: command-list.h:171
+msgid "Initialize and modify the sparse-checkout"
+msgstr "Khởi tạo và sửa đổi sparse-checkout"
+
+#: command-list.h:172
 msgid "Stash the changes in a dirty working directory away"
 msgstr "Tạm cất đi các thay đổi trong một thư mục làm việc bẩn"
 
-#: command-list.h:169
+#: command-list.h:173
 msgid "Add file contents to the staging area"
 msgstr "Thêm nội dung tập tin vào vùng bệ phóng"
 
-#: command-list.h:170
+#: command-list.h:174
 msgid "Show the working tree status"
 msgstr "Hiển thị trạng thái cây làm việc"
 
-#: command-list.h:171
+#: command-list.h:175
 msgid "Remove unnecessary whitespace"
 msgstr "Xóa bỏ các khoảng trắng không cần thiết"
 
-#: command-list.h:172
+#: command-list.h:176
 msgid "Initialize, update or inspect submodules"
 msgstr "Khởi tạo, cập nhật hay điều tra các mô-đun-con"
 
-#: command-list.h:173
+#: command-list.h:177
 msgid "Bidirectional operation between a Subversion repository and Git"
 msgstr "Thao tác hai hướng giữ hai kho Subversion và Git"
 
-#: command-list.h:174
+#: command-list.h:178
+msgid "Switch branches"
+msgstr "Các nhánh chuyển"
+
+#: command-list.h:179
 msgid "Read, modify and delete symbolic refs"
 msgstr "Đọc, sửa và xóa tham chiếu mềm"
 
-#: command-list.h:175
+#: command-list.h:180
 msgid "Create, list, delete or verify a tag object signed with GPG"
 msgstr "Tạo, liệt kê, xóa hay xác thực một đối tượng thẻ được ký bằng GPG"
 
-#: command-list.h:176
+#: command-list.h:181
 msgid "Creates a temporary file with a blob's contents"
 msgstr "Tạo một tập tin tạm với nội dung của blob"
 
-#: command-list.h:177
+#: command-list.h:182
 msgid "Unpack objects from a packed archive"
 msgstr "Gỡ các đối tượng khỏi một kho lưu đã đóng gói"
 
-#: command-list.h:178
+#: command-list.h:183
 msgid "Register file contents in the working tree to the index"
 msgstr "Đăng ký nội dung tập tin từ cây làm việc đến bảng mục lục"
 
-#: command-list.h:179
+#: command-list.h:184
 msgid "Update the object name stored in a ref safely"
 msgstr "Cập nhật tên đối tượng được lưu trong một tham chiếu một cách an toàn"
 
-#: command-list.h:180
+#: command-list.h:185
 msgid "Update auxiliary info file to help dumb servers"
 msgstr "Cập nhật tập tin thông tin phụ trợ để giúp đỡ các dịch vụ dumb"
 
-#: command-list.h:181
+#: command-list.h:186
 msgid "Send archive back to git-archive"
 msgstr "Gửi trở lại kho lưu đến git-archive"
 
-#: command-list.h:182
+#: command-list.h:187
 msgid "Send objects packed back to git-fetch-pack"
 msgstr "Gửi trở lại các đối tượng đã đóng gói cho git-fetch-pack"
 
-#: command-list.h:183
+#: command-list.h:188
 msgid "Show a Git logical variable"
 msgstr "Hiển thị một biến Git luận lý"
 
-#: command-list.h:184
+#: command-list.h:189
 msgid "Check the GPG signature of commits"
 msgstr "Kiểm tra ký lần chuyển giao dùng GPG"
 
-#: command-list.h:185
+#: command-list.h:190
 msgid "Validate packed Git archive files"
 msgstr "Kiểm tra lại các tập tin kho (lưu trữ, nén) Git đã được đóng gói"
 
-#: command-list.h:186
+#: command-list.h:191
 msgid "Check the GPG signature of tags"
 msgstr "Kiểm tra chữ ký GPG của các thẻ"
 
-#: command-list.h:187
+#: command-list.h:192
 msgid "Git web interface (web frontend to Git repositories)"
 msgstr "Giao diện Git trên nền web (ứng dụng web chạy trên kho Git)"
 
-#: command-list.h:188
+#: command-list.h:193
 msgid "Show logs with difference each commit introduces"
 msgstr "Hiển thị các nhật ký với từng lần chuyển giao khác nhau đưa ra"
 
-#: command-list.h:189
+#: command-list.h:194
 msgid "Manage multiple working trees"
 msgstr "Quản lý nhiều cây làm việc"
 
-#: command-list.h:190
+#: command-list.h:195
 msgid "Create a tree object from the current index"
 msgstr "Tạo một đối tượng cây từ đầu vào tiêu chuẩn stdin hiện tại"
 
-#: command-list.h:191
+#: command-list.h:196
 msgid "Defining attributes per path"
 msgstr "Định nghĩa các thuộc tính cho mỗi đường dẫn"
 
-#: command-list.h:192
+#: command-list.h:197
 msgid "Git command-line interface and conventions"
 msgstr "Giao diện dòng lệnh Git và quy ước"
 
-#: command-list.h:193
+#: command-list.h:198
 msgid "A Git core tutorial for developers"
 msgstr "Hướng dẫn Git cơ bản cho nhà phát triển"
 
-#: command-list.h:194
+#: command-list.h:199
 msgid "Git for CVS users"
 msgstr "Git dành cho những người dùng CVS"
 
-#: command-list.h:195
+#: command-list.h:200
 msgid "Tweaking diff output"
 msgstr "Chỉnh kết xuất diff"
 
-#: command-list.h:196
+#: command-list.h:201
 msgid "A useful minimum set of commands for Everyday Git"
 msgstr "Một tập hợp lệnh hữu dụng tối thiểu để dùng Git hàng ngày"
 
-#: command-list.h:197
+#: command-list.h:202
 msgid "A Git Glossary"
 msgstr "Thuật ngữ chuyên môn Git"
 
-#: command-list.h:198
+#: command-list.h:203
 msgid "Hooks used by Git"
 msgstr "Các móc được sử dụng bởi Git"
 
-#: command-list.h:199
+#: command-list.h:204
 msgid "Specifies intentionally untracked files to ignore"
 msgstr "Chỉ định các tập tin không cần theo dõi"
 
-#: command-list.h:200
+#: command-list.h:205
 msgid "Defining submodule properties"
 msgstr "Định nghĩa thuộc tính mô-đun-con"
 
-#: command-list.h:201
+#: command-list.h:206
 msgid "Git namespaces"
-msgstr "không gian tên Git"
+msgstr "Không gian tên Git"
 
-#: command-list.h:202
+#: command-list.h:207
 msgid "Git Repository Layout"
 msgstr "Bố cục kho Git"
 
-#: command-list.h:203
+#: command-list.h:208
 msgid "Specifying revisions and ranges for Git"
 msgstr "Chỉ định điểm xét duyệt và vùng cho Git"
 
-#: command-list.h:204
+#: command-list.h:209
+msgid "Mounting one repository inside another"
+msgstr "Gắn một kho chứa vào trong một cái khác"
+
+#: command-list.h:210
 msgid "A tutorial introduction to Git: part two"
 msgstr "Hướng dẫn cách dùng Git: phần hai"
 
-#: command-list.h:205
+#: command-list.h:211
 msgid "A tutorial introduction to Git"
 msgstr "Hướng dẫn cách dùng Git"
 
-#: command-list.h:206
+#: command-list.h:212
 msgid "An overview of recommended workflows with Git"
-msgstr "Tổng quan về luồng công việc khuyến nghị nên dùng với Git."
-
-#: rerere.h:40
-msgid "update the index with reused conflict resolution if possible"
-msgstr "cập nhật bảng mục lục với phân giải xung đột dùng lại nếu được"
+msgstr "Tổng quan về luồng công việc khuyến nghị nên dùng với Git"
 
 #: git-bisect.sh:54
 msgid "You need to start by \"git bisect start\""
@@ -16179,137 +22736,49 @@ msgstr "Bạn cần khởi đầu bằng
 msgid "Do you want me to do it for you [Y/n]? "
 msgstr "Bạn có muốn tôi thực hiện điều này cho bạn không [Y/n]? "
 
-#: git-bisect.sh:121
-#, sh-format
-msgid "unrecognised option: '$arg'"
-msgstr "không công nhận tùy chọn: “$arg”"
-
-#: git-bisect.sh:125
-#, sh-format
-msgid "'$arg' does not appear to be a valid revision"
-msgstr "”$arg” không có vẻ như là một điểm xét duyệt hợp lệ"
-
-#: git-bisect.sh:154
-msgid "Bad HEAD - I need a HEAD"
-msgstr "HEAD sai - Tôi cần một HEAD"
-
-#: git-bisect.sh:167
-#, sh-format
-msgid ""
-"Checking out '$start_head' failed. Try 'git bisect reset <valid-branch>'."
-msgstr ""
-"Việc lấy “$start_head” ra gặp lỗi. Hãy thử \"git bisect reset <nhánh_hợp_lệ>"
-"\"."
-
-#: git-bisect.sh:177
-msgid "won't bisect on cg-seek'ed tree"
-msgstr "sẽ không di chuyển nửa bước trên cây được cg-seek"
-
-#: git-bisect.sh:181
-msgid "Bad HEAD - strange symbolic ref"
-msgstr "HEAD sai - tham chiếu mềm kỳ lạ"
-
-#: git-bisect.sh:233
-#, sh-format
-msgid "Bad bisect_write argument: $state"
-msgstr "Đối số bisect_write sai: $state"
-
-#: git-bisect.sh:246
+#: git-bisect.sh:101
 #, sh-format
 msgid "Bad rev input: $arg"
 msgstr "Đầu vào rev sai: $arg"
 
-#: git-bisect.sh:265
-#, sh-format
-msgid "Bad rev input: $bisected_head"
-msgstr "Đầu vào rev sai: $bisected_head"
-
-#: git-bisect.sh:274
-#, sh-format
-msgid "Bad rev input: $rev"
-msgstr "Đầu vào rev sai: $rev"
-
-#: git-bisect.sh:283
-#, sh-format
-msgid "'git bisect $TERM_BAD' can take only one argument."
-msgstr "“git bisect $TERM_BAD” có thể lấy chỉ một đối số."
-
-#: git-bisect.sh:306
-#, sh-format
-msgid "Warning: bisecting only with a $TERM_BAD commit."
-msgstr "Cảnh báo: chỉ thực hiện việc bisect với một lần chuyển giao $TERM_BAD."
-
-#. TRANSLATORS: Make sure to include [Y] and [n] in your
-#. translation. The program will only accept English input
-#. at this point.
-#: git-bisect.sh:312
-msgid "Are you sure [Y/n]? "
-msgstr "Bạn có chắc chắn chưa [Y/n]? "
-
-#: git-bisect.sh:324
-#, sh-format
-msgid ""
-"You need to give me at least one $bad_syn and one $good_syn revision.\n"
-"(You can use \"git bisect $bad_syn\" and \"git bisect $good_syn\" for that.)"
-msgstr ""
-"Bạn phải chỉ cho tôi ít nhất một điểm $bad_syn và một $good_syn.\n"
-"(Bạn có thể sử dụng \"git bisect $bad_syn\" và \"git bisect $good_syn\" cho "
-"cái đó.)"
-
-#: git-bisect.sh:327
-#, sh-format
-msgid ""
-"You need to start by \"git bisect start\".\n"
-"You then need to give me at least one $good_syn and one $bad_syn revision.\n"
-"(You can use \"git bisect $bad_syn\" and \"git bisect $good_syn\" for that.)"
-msgstr ""
-"Bạn cần bắt đầu bằng lệnh \"git bisect start\".\n"
-"Bạn sau đó cần phải chỉ cho tôi ít nhất một điểm xét duyệt $good_syn và một "
-"$bad_syn.\n"
-"(Bạn có thể sử dụng \"git bisect $bad_syn\" và \"git bisect $good_syn\" cho "
-"chúng.)"
-
-#: git-bisect.sh:398 git-bisect.sh:512
-msgid "We are not bisecting."
-msgstr "Chúng tôi không bisect."
+#: git-bisect.sh:121
+#, sh-format
+msgid "Bad rev input: $bisected_head"
+msgstr "Đầu vào rev sai: $bisected_head"
 
-#: git-bisect.sh:405
+#: git-bisect.sh:130
 #, sh-format
-msgid "'$invalid' is not a valid commit"
-msgstr "”$invalid” không phải là lần chuyển giao hợp lệ"
+msgid "Bad rev input: $rev"
+msgstr "Đầu vào rev sai: $rev"
 
-#: git-bisect.sh:414
+#: git-bisect.sh:139
 #, sh-format
-msgid ""
-"Could not check out original HEAD '$branch'.\n"
-"Try 'git bisect reset <commit>'."
-msgstr ""
-"Không thể check-out HEAD nguyên thủy của “$branch”.\n"
-"Hãy thử “git bisect reset <lần-chuyển-giao>”."
+msgid "'git bisect $TERM_BAD' can take only one argument."
+msgstr "“git bisect $TERM_BAD” có thể lấy chỉ một đối số."
 
-#: git-bisect.sh:422
+#: git-bisect.sh:209
 msgid "No logfile given"
 msgstr "Chưa chỉ ra tập tin ghi nhật ký"
 
-#: git-bisect.sh:423
+#: git-bisect.sh:210
 #, sh-format
 msgid "cannot read $file for replaying"
 msgstr "không thể đọc $file để thao diễn lại"
 
-#: git-bisect.sh:444
+#: git-bisect.sh:232
 msgid "?? what are you talking about?"
 msgstr "?? bạn đang nói gì thế?"
 
-#: git-bisect.sh:453
+#: git-bisect.sh:241
 msgid "bisect run failed: no command provided."
 msgstr "bisect chạy gặp lỗi: không đưa ra lệnh."
 
-#: git-bisect.sh:458
+#: git-bisect.sh:246
 #, sh-format
 msgid "running $command"
 msgstr "đang chạy lệnh $command"
 
-#: git-bisect.sh:465
+#: git-bisect.sh:253
 #, sh-format
 msgid ""
 "bisect run failed:\n"
@@ -16318,11 +22787,11 @@ msgstr ""
 "chạy bisect gặp lỗi:\n"
 "mã trả về $res từ lệnh “$command” là < 0 hoặc >= 128"
 
-#: git-bisect.sh:491
+#: git-bisect.sh:279
 msgid "bisect run cannot continue any more"
 msgstr "bisect không thể tiếp tục thêm được nữa"
 
-#: git-bisect.sh:497
+#: git-bisect.sh:285
 #, sh-format
 msgid ""
 "bisect run failed:\n"
@@ -16331,27 +22800,13 @@ msgstr ""
 "chạy bisect gặp lỗi:\n"
 "”bisect_state $state” đã thoát ra với mã lỗi $res"
 
-#: git-bisect.sh:504
+#: git-bisect.sh:292
 msgid "bisect run success"
 msgstr "bisect chạy thành công"
 
-#: git-bisect.sh:533
-#, sh-format
-msgid "Invalid command: you're currently in a $TERM_BAD/$TERM_GOOD bisect."
-msgstr "Lệnh không hợp lệ: bạn hiện đang ở bisect $TERM_BAD/$TERM_GOOD."
-
-#: git-bisect.sh:567
-msgid "no terms defined"
-msgstr "chưa định nghĩa thời kỳ nào"
-
-#: git-bisect.sh:584
-#, sh-format
-msgid ""
-"invalid argument $arg for 'git bisect terms'.\n"
-"Supported options are: --term-good|--term-old and --term-bad|--term-new."
-msgstr ""
-"tham số không hợp lệ $arg cho “git bisect terms”.\n"
-"Các tùy chọn hỗ trợ là: --term-good|--term-old và --term-bad|--term-new."
+#: git-bisect.sh:300
+msgid "We are not bisecting."
+msgstr "Chúng tôi không bisect."
 
 #: git-merge-octopus.sh:46
 msgid ""
@@ -16393,335 +22848,118 @@ msgstr "Đang thử hòa trộn đơn gi
 msgid "Simple merge did not work, trying automatic merge."
 msgstr "Hòa trộn đơn giản không làm việc, thử hòa trộn tự động."
 
-#: git-rebase.sh:61
-msgid ""
-"Resolve all conflicts manually, mark them as resolved with\n"
-"\"git add/rm <conflicted_files>\", then run \"git rebase --continue\".\n"
-"You can instead skip this commit: run \"git rebase --skip\".\n"
-"To abort and get back to the state before \"git rebase\", run \"git rebase --"
-"abort\"."
-msgstr ""
-"Giải quyết vấn đề này thủ công, hãy đanh dấu chúng đã được giải quyết bằng\n"
-"hãy chạy lệnh \"git add/rm <các_tập_tin_xung_đột>\", sau đó chạy \"git "
-"rebase --continue\".\n"
-"Bạn có thể bỏ qua miếng vá, chạy \"git rebase --skip\".\n"
-"Để bãi bỏ và quay trở lại trạng thái trước \"git rebase\", chạy \"git rebase "
-"--abort\"."
-
-#: git-rebase.sh:173 git-rebase.sh:442
-#, sh-format
-msgid "Could not move back to $head_name"
-msgstr "Không thể quay trở lại $head_name"
-
-#: git-rebase.sh:184
-msgid "Applied autostash."
-msgstr "Đã áp dụng autostash."
-
-#: git-rebase.sh:187
-#, sh-format
-msgid "Cannot store $stash_sha1"
-msgstr "Không thể lưu $stash_sha1"
-
-#: git-rebase.sh:229
-msgid "The pre-rebase hook refused to rebase."
-msgstr "Móc (hook) pre-rebase từ chối rebase."
-
-#: git-rebase.sh:234
-msgid "It looks like 'git am' is in progress. Cannot rebase."
-msgstr ""
-"Hình như đang trong quá trình thực hiện lệnh “git-am”. Không thể rebase."
-
-#: git-rebase.sh:403
-msgid "No rebase in progress?"
-msgstr "Không có tiến trình rebase nào phải không?"
-
-#: git-rebase.sh:414
-msgid "The --edit-todo action can only be used during interactive rebase."
-msgstr ""
-"Hành động “--edit-todo” chỉ có thể dùng trong quá trình “rebase” (sửa lịch "
-"sử) tương tác."
-
-#: git-rebase.sh:421
-msgid "Cannot read HEAD"
-msgstr "Không thể đọc HEAD"
-
-#: git-rebase.sh:424
-msgid ""
-"You must edit all merge conflicts and then\n"
-"mark them as resolved using git add"
-msgstr ""
-"Bạn phải sửa tất cả các lần hòa trộn xung đột và sau\n"
-"đó đánh dấu chúng là cần xử lý sử dụng lệnh git add"
-
-#: git-rebase.sh:468
-#, sh-format
-msgid ""
-"It seems that there is already a $state_dir_base directory, and\n"
-"I wonder if you are in the middle of another rebase.  If that is the\n"
-"case, please try\n"
-"\t$cmd_live_rebase\n"
-"If that is not the case, please\n"
-"\t$cmd_clear_stale_rebase\n"
-"and run me again.  I am stopping in case you still have something\n"
-"valuable there."
-msgstr ""
-"Hình như là ở đây sẵn có một thư mục $state_dir_base, và\n"
-"Tôi tự hỏi có phải bạn đang ở giữa một lệnh rebase khác. Nếu đúng là\n"
-"như vậy, xin hãy thử\n"
-"\t$cmd_live_rebase\n"
-"Nếu không phải thế, hãy thử\n"
-"\t$cmd_clear_stale_rebase\n"
-"và chạy TÔI lần nữa. TÔI  dừng lại trong trường hợp bạn vẫn\n"
-"có một số thứ quý giá ở đây."
-
-#: git-rebase.sh:509
-msgid "error: cannot combine '--signoff' with '--preserve-merges'"
-msgstr "lỗi: không thể kết hợp “--signoff” với “--preserve-merges”"
-
-#: git-rebase.sh:537
-#, sh-format
-msgid "invalid upstream '$upstream_name'"
-msgstr "thượng nguồn không hợp lệ “$upstream_name”"
-
-#: git-rebase.sh:561
-#, sh-format
-msgid "$onto_name: there are more than one merge bases"
-msgstr "$onto_name: ở đây có nhiều hơn một nền móng hòa trộn"
-
-#: git-rebase.sh:564 git-rebase.sh:568
-#, sh-format
-msgid "$onto_name: there is no merge base"
-msgstr "$onto_name: ở đây không có nền móng hòa trộn nào"
-
-#: git-rebase.sh:573
-#, sh-format
-msgid "Does not point to a valid commit: $onto_name"
-msgstr "Không chỉ đến một lần chuyển giao không hợp lệ: $onto_name"
-
-#: git-rebase.sh:599
-#, sh-format
-msgid "fatal: no such branch/commit '$branch_name'"
-msgstr "nghiêm trọng: không có nhánh như thế: “$branch_name”"
-
-#: git-rebase.sh:632
-msgid "Cannot autostash"
-msgstr "Không thể autostash"
-
-#: git-rebase.sh:637
-#, sh-format
-msgid "Created autostash: $stash_abbrev"
-msgstr "Đã tạo autostash: $stash_abbrev"
-
-#: git-rebase.sh:641
-msgid "Please commit or stash them."
-msgstr "Xin hãy chuyển giao hoặc tạm cất (stash) chúng."
-
-#: git-rebase.sh:664
-#, sh-format
-msgid "HEAD is up to date."
-msgstr "HEAD đã cập nhật."
-
-#: git-rebase.sh:666
-#, sh-format
-msgid "Current branch $branch_name is up to date."
-msgstr "Nhánh hiện tại $branch_name đã được cập nhật rồi."
-
-#: git-rebase.sh:674
-#, sh-format
-msgid "HEAD is up to date, rebase forced."
-msgstr "HEAD hiện đã được cập nhật rồi, bị ép buộc rebase."
-
-#: git-rebase.sh:676
-#, sh-format
-msgid "Current branch $branch_name is up to date, rebase forced."
-msgstr "Nhánh hiện tại $branch_name đã được cập nhật rồi, lệnh rebase ép buộc."
-
-#: git-rebase.sh:688
-#, sh-format
-msgid "Changes from $mb to $onto:"
-msgstr "Thay đổi từ $mb thành $onto:"
-
-#: git-rebase.sh:697
-msgid "First, rewinding head to replay your work on top of it..."
-msgstr "Trước tiên, di chuyển head để xem lại các công việc trên đỉnh của nó…"
-
-#: git-rebase.sh:707
-#, sh-format
-msgid "Fast-forwarded $branch_name to $onto_name."
-msgstr "Chuyển-tiếp-nhanh $branch_name thành $onto_name."
-
-#: git-stash.sh:61
-msgid "git stash clear with parameters is unimplemented"
-msgstr ""
-"git stash clear với các tham số là chưa được thực hiện (không nhận đối số)"
-
-#: git-stash.sh:108
-msgid "You do not have the initial commit yet"
-msgstr "Bạn chưa còn có lần chuyển giao khởi tạo"
-
-#: git-stash.sh:123
-msgid "Cannot save the current index state"
-msgstr "Không thể ghi lại trạng thái bảng mục lục hiện hành"
-
-#: git-stash.sh:138
-msgid "Cannot save the untracked files"
-msgstr "Không thể ghi lại các tập tin chưa theo dõi"
-
-#: git-stash.sh:158 git-stash.sh:171
-msgid "Cannot save the current worktree state"
-msgstr "Không thể ghi lại trạng thái cây-làm-việc hiện hành"
-
-#: git-stash.sh:175
-msgid "No changes selected"
-msgstr "Chưa có thay đổi nào được chọn"
-
-#: git-stash.sh:178
+#: git-legacy-stash.sh:221
 msgid "Cannot remove temporary index (can't happen)"
 msgstr "Không thể gỡ bỏ bảng mục lục tạm thời (không thể xảy ra)"
 
-#: git-stash.sh:191
-msgid "Cannot record working tree state"
-msgstr "Không thể ghi lại trạng thái cây làm việc hiện hành"
-
-#: git-stash.sh:229
+#: git-legacy-stash.sh:272
 #, sh-format
 msgid "Cannot update $ref_stash with $w_commit"
 msgstr "Không thể cập nhật $ref_stash với $w_commit"
 
-#: git-stash.sh:281
+#: git-legacy-stash.sh:324
 #, sh-format
 msgid "error: unknown option for 'stash push': $option"
 msgstr "lỗi: không hiểu tùy chọn cho “stash push”: $option"
 
-#: git-stash.sh:295
-msgid "Can't use --patch and --include-untracked or --all at the same time"
-msgstr "Không thể dùng --patch và --include-untracked hay --all cùng một lúc."
-
-#: git-stash.sh:303
-msgid "No local changes to save"
-msgstr "Không có thay đổi nội bộ nào được ghi lại"
-
-#: git-stash.sh:308
-msgid "Cannot initialize stash"
-msgstr "Không thể khởi tạo stash"
-
-#: git-stash.sh:312
-msgid "Cannot save the current status"
-msgstr "Không thể ghi lại trạng thái hiện hành"
-
-#: git-stash.sh:313
+#: git-legacy-stash.sh:356
 #, sh-format
 msgid "Saved working directory and index state $stash_msg"
 msgstr "Đã ghi lại thư mục làm việc và trạng thái mục lục $stash_msg"
 
-#: git-stash.sh:342
-msgid "Cannot remove worktree changes"
-msgstr "Không thể gỡ bỏ các thay đổi cây-làm-việc"
-
-#: git-stash.sh:490
+#: git-legacy-stash.sh:536
 #, sh-format
 msgid "unknown option: $opt"
 msgstr "không hiểu tùy chọn: $opt"
 
-#: git-stash.sh:503
-msgid "No stash entries found."
-msgstr "Không tìm thấy các mục tạm cất (stash) nào."
-
-#: git-stash.sh:510
+#: git-legacy-stash.sh:556
 #, sh-format
 msgid "Too many revisions specified: $REV"
 msgstr "Chỉ ra quá nhiều điểm xét duyệt: $REV"
 
-#: git-stash.sh:525
+#: git-legacy-stash.sh:571
 #, sh-format
 msgid "$reference is not a valid reference"
 msgstr "$reference không phải là tham chiếu hợp lệ"
 
-#: git-stash.sh:553
+#: git-legacy-stash.sh:599
 #, sh-format
 msgid "'$args' is not a stash-like commit"
 msgstr "“$args” không phải là lần chuyển giao kiểu-stash (cất đi)"
 
-#: git-stash.sh:564
+#: git-legacy-stash.sh:610
 #, sh-format
 msgid "'$args' is not a stash reference"
 msgstr "”$args” không phải tham chiếu đến stash"
 
-#: git-stash.sh:572
+#: git-legacy-stash.sh:618
 msgid "unable to refresh index"
 msgstr "không thể làm tươi mới bảng mục lục"
 
-#: git-stash.sh:576
+#: git-legacy-stash.sh:622
 msgid "Cannot apply a stash in the middle of a merge"
 msgstr "Không thể áp dụng một stash ở giữa của quá trình hòa trộn"
 
-#: git-stash.sh:584
+#: git-legacy-stash.sh:630
 msgid "Conflicts in index. Try without --index."
 msgstr "Xung đột trong bảng mục lục. Hãy thử mà không dùng tùy chọn --index."
 
-#: git-stash.sh:586
+#: git-legacy-stash.sh:632
 msgid "Could not save index tree"
 msgstr "Không thể ghi lại cây chỉ mục"
 
-#: git-stash.sh:595
+#: git-legacy-stash.sh:641
 msgid "Could not restore untracked files from stash entry"
 msgstr "Không thể phục hồi các tập tin chưa theo dõi từ mục cất đi (stash)"
 
-#: git-stash.sh:620
+#: git-legacy-stash.sh:666
 msgid "Cannot unstage modified files"
 msgstr "Không thể bỏ ra khỏi bệ phóng các tập tin đã được sửa chữa"
 
-#: git-stash.sh:635
-msgid "Index was not unstashed."
-msgstr "Bảng mục lục đã không được bỏ stash."
-
-#: git-stash.sh:649
-msgid "The stash entry is kept in case you need it again."
-msgstr "Các mục tạm cất (stash) được giữ trong trường hợp bạn lại cần nó."
-
-#: git-stash.sh:658
+#: git-legacy-stash.sh:704
 #, sh-format
 msgid "Dropped ${REV} ($s)"
 msgstr "Đã xóa ${REV} ($s)"
 
-#: git-stash.sh:659
+#: git-legacy-stash.sh:705
 #, sh-format
 msgid "${REV}: Could not drop stash entry"
 msgstr "${REV}: Không thể xóa bỏ mục stash"
 
-#: git-stash.sh:667
-msgid "No branch name specified"
-msgstr "Chưa chỉ ra tên của nhánh"
-
-#: git-stash.sh:746
+#: git-legacy-stash.sh:792
 msgid "(To restore them type \"git stash apply\")"
 msgstr "(Để phục hồi lại chúng hãy gõ \"git stash apply\")"
 
-#: git-submodule.sh:188
+#: git-submodule.sh:202
 msgid "Relative path can only be used from the toplevel of the working tree"
 msgstr ""
 "Đường dẫn tương đối chỉ có thể dùng từ thư mục ở mức cao nhất của cây làm "
 "việc"
 
-#: git-submodule.sh:198
+#: git-submodule.sh:212
 #, sh-format
 msgid "repo URL: '$repo' must be absolute or begin with ./|../"
 msgstr ""
 "repo URL: “$repo” phải là đường dẫn tuyệt đối hoặc là bắt đầu bằng ./|../"
 
-#: git-submodule.sh:217
+#: git-submodule.sh:231
 #, sh-format
 msgid "'$sm_path' already exists in the index"
 msgstr "”$sm_path” thực sự đã tồn tại ở bảng mục lục rồi"
 
-#: git-submodule.sh:220
+#: git-submodule.sh:234
 #, sh-format
 msgid "'$sm_path' already exists in the index and is not a submodule"
 msgstr ""
 "”$sm_path” thực sự đã tồn tại ở bảng mục lục rồi và không phải là một mô-đun-"
 "con"
 
-#: git-submodule.sh:226
+#: git-submodule.sh:241
+#, sh-format
+msgid "'$sm_path' does not have a commit checked out"
+msgstr "“$sm_path” không có lần chuyển giao nào được lấy ra"
+
+#: git-submodule.sh:247
 #, sh-format
 msgid ""
 "The following path is ignored by one of your .gitignore files:\n"
@@ -16733,23 +22971,23 @@ msgstr ""
 "$sm_path\n"
 "Sử dụng -f nếu bạn thực sự muốn thêm nó vào."
 
-#: git-submodule.sh:249
+#: git-submodule.sh:270
 #, sh-format
 msgid "Adding existing repo at '$sm_path' to the index"
 msgstr "Đang thêm repo có sẵn tại “$sm_path” vào bảng mục lục"
 
-#: git-submodule.sh:251
+#: git-submodule.sh:272
 #, sh-format
 msgid "'$sm_path' already exists and is not a valid git repo"
 msgstr "”$sm_path” đã tồn tại từ trước và không phải là một kho git hợp lệ"
 
-#: git-submodule.sh:259
+#: git-submodule.sh:280
 #, sh-format
 msgid "A git directory for '$sm_name' is found locally with remote(s):"
 msgstr ""
 "Thư mục git cho “$sm_name” được tìm thấy một cách cục bộ với các máy chủ:"
 
-#: git-submodule.sh:261
+#: git-submodule.sh:282
 #, sh-format
 msgid ""
 "If you want to reuse this local git directory instead of cloning again from\n"
@@ -16765,50 +23003,40 @@ msgstr ""
 "hoặc là bạn không chắc chắn điều đó nghĩa là gì thì chọn tên khác với tùy "
 "chọn “--name”."
 
-#: git-submodule.sh:267
+#: git-submodule.sh:288
 #, sh-format
 msgid "Reactivating local git directory for submodule '$sm_name'."
 msgstr ""
 "Phục hồi sự hoạt động của thư mục git nội bộ cho mô-đun-con “$sm_name”."
 
-#: git-submodule.sh:279
+#: git-submodule.sh:300
 #, sh-format
 msgid "Unable to checkout submodule '$sm_path'"
 msgstr "Không thể lấy ra mô-đun-con “$sm_path”"
 
-#: git-submodule.sh:284
+#: git-submodule.sh:305
 #, sh-format
 msgid "Failed to add submodule '$sm_path'"
 msgstr "Gặp lỗi khi thêm mô-đun-con “$sm_path”"
 
-#: git-submodule.sh:293
+#: git-submodule.sh:314
 #, sh-format
 msgid "Failed to register submodule '$sm_path'"
 msgstr "Gặp lỗi khi đăng ký với hệ thống mô-đun-con “$sm_path”"
 
-#: git-submodule.sh:354
-#, sh-format
-msgid "Entering '$displaypath'"
-msgstr "Đang vào “$displaypath”"
-
-#: git-submodule.sh:374
-#, sh-format
-msgid "Stopping at '$displaypath'; script returned non-zero status."
-msgstr "Dừng lại tại “$displaypath”; script trả về trạng thái khác không."
-
-#: git-submodule.sh:600
+#: git-submodule.sh:580
 #, sh-format
 msgid "Unable to find current revision in submodule path '$displaypath'"
 msgstr ""
 "Không tìm thấy điểm xét duyệt hiện hành trong đường dẫn mô-đun-con "
 "“$displaypath”"
 
-#: git-submodule.sh:610
+#: git-submodule.sh:590
 #, sh-format
 msgid "Unable to fetch in submodule path '$sm_path'"
 msgstr "Không thể lấy về trong đường dẫn mô-đun-con “$sm_path”"
 
-#: git-submodule.sh:615
+#: git-submodule.sh:595
 #, sh-format
 msgid ""
 "Unable to find current ${remote_name}/${branch} revision in submodule path "
@@ -16817,12 +23045,16 @@ msgstr ""
 "Không thể tìm thấy điểm xét duyệt hiện hành ${remote_name}/${branch} trong "
 "đường dẫn mô-đun-con “$sm_path”"
 
-#: git-submodule.sh:633
+#: git-submodule.sh:613
 #, sh-format
-msgid "Unable to fetch in submodule path '$displaypath'"
-msgstr "Không thể lấy về trong đường dẫn mô-đun-con “$displaypath”"
+msgid ""
+"Unable to fetch in submodule path '$displaypath'; trying to directly fetch "
+"$sha1:"
+msgstr ""
+"Không thể lấy về trong đường dẫn mô-đun-con “$displaypath”; thử lấy về trực "
+"tiếp $sha1:"
 
-#: git-submodule.sh:639
+#: git-submodule.sh:619
 #, sh-format
 msgid ""
 "Fetched in submodule path '$displaypath', but it did not contain $sha1. "
@@ -16831,74 +23063,74 @@ msgstr ""
 "Đã lấy về từ đường dẫn mô-đun con “$displaypath”, nhưng nó không chứa $sha1. "
 "Lấy về theo định hướng của lần chuyển giao đó gặp lỗi."
 
-#: git-submodule.sh:646
+#: git-submodule.sh:626
 #, sh-format
 msgid "Unable to checkout '$sha1' in submodule path '$displaypath'"
 msgstr "Không thể lấy ra “$sha1” trong đường dẫn mô-đun-con “$displaypath”"
 
-#: git-submodule.sh:647
+#: git-submodule.sh:627
 #, sh-format
 msgid "Submodule path '$displaypath': checked out '$sha1'"
 msgstr "Đường dẫn mô-đun-con “$displaypath”: đã checkout “$sha1”"
 
-#: git-submodule.sh:651
+#: git-submodule.sh:631
 #, sh-format
 msgid "Unable to rebase '$sha1' in submodule path '$displaypath'"
 msgstr "Không thể cải tổ “$sha1” trong đường dẫn mô-đun-con “$displaypath”"
 
-#: git-submodule.sh:652
+#: git-submodule.sh:632
 #, sh-format
 msgid "Submodule path '$displaypath': rebased into '$sha1'"
 msgstr "Đường dẫn mô-đun-con “$displaypath”: được rebase vào trong “$sha1”"
 
-#: git-submodule.sh:657
+#: git-submodule.sh:637
 #, sh-format
 msgid "Unable to merge '$sha1' in submodule path '$displaypath'"
 msgstr ""
 "Không thể hòa trộn (merge) “$sha1” trong đường dẫn mô-đun-con “$displaypath”"
 
-#: git-submodule.sh:658
+#: git-submodule.sh:638
 #, sh-format
 msgid "Submodule path '$displaypath': merged in '$sha1'"
 msgstr "Đường dẫn mô-đun-con “$displaypath”: được hòa trộn vào “$sha1”"
 
-#: git-submodule.sh:663
+#: git-submodule.sh:643
 #, sh-format
 msgid "Execution of '$command $sha1' failed in submodule path '$displaypath'"
 msgstr ""
 "Thực hiện không thành công lệnh “$command $sha1” trong đường dẫn mô-đun-con "
 "“$displaypath”"
 
-#: git-submodule.sh:664
+#: git-submodule.sh:644
 #, sh-format
 msgid "Submodule path '$displaypath': '$command $sha1'"
 msgstr "Đường dẫn mô-đun-con “$displaypath”: “$command $sha1”"
 
-#: git-submodule.sh:695
+#: git-submodule.sh:675
 #, sh-format
 msgid "Failed to recurse into submodule path '$displaypath'"
 msgstr "Gặp lỗi khi đệ quy vào trong đường dẫn mô-đun-con “$displaypath”"
 
-#: git-submodule.sh:791
+#: git-submodule.sh:886
 msgid "The --cached option cannot be used with the --files option"
 msgstr "Tùy chọn --cached không thể dùng cùng với tùy chọn --files"
 
-#: git-submodule.sh:843
+#: git-submodule.sh:938
 #, sh-format
 msgid "unexpected mode $mod_dst"
 msgstr "chế độ không như mong chờ $mod_dst"
 
-#: git-submodule.sh:863
+#: git-submodule.sh:958
 #, sh-format
 msgid "  Warn: $display_name doesn't contain commit $sha1_src"
 msgstr "  Cảnh báo: $display_name không chứa lần chuyển giao $sha1_src"
 
-#: git-submodule.sh:866
+#: git-submodule.sh:961
 #, sh-format
 msgid "  Warn: $display_name doesn't contain commit $sha1_dst"
 msgstr "  Cảnh báo: $display_name không chứa lần chuyển giao $sha1_dst"
 
-#: git-submodule.sh:869
+#: git-submodule.sh:964
 #, sh-format
 msgid "  Warn: $display_name doesn't contain commits $sha1_src and $sha1_dst"
 msgstr ""
@@ -16910,12 +23142,21 @@ msgstr ""
 msgid "See git-${cmd}(1) for details."
 msgstr "Xem git-${cmd}(1) để biết thêm chi tiết."
 
-#: git-rebase--interactive.sh:142
+#: git-rebase--preserve-merges.sh:109
+msgid "Applied autostash."
+msgstr "Đã áp dụng autostash."
+
+#: git-rebase--preserve-merges.sh:112
+#, sh-format
+msgid "Cannot store $stash_sha1"
+msgstr "Không thể lưu $stash_sha1"
+
+#: git-rebase--preserve-merges.sh:191
 #, sh-format
 msgid "Rebasing ($new_count/$total)"
 msgstr "Đang rebase ($new_count/$total)"
 
-#: git-rebase--interactive.sh:158
+#: git-rebase--preserve-merges.sh:207
 msgid ""
 "\n"
 "Commands:\n"
@@ -16924,7 +23165,7 @@ msgid ""
 "e, edit <commit> = use commit, but stop for amending\n"
 "s, squash <commit> = use commit, but meld into previous commit\n"
 "f, fixup <commit> = like \"squash\", but discard this commit's log message\n"
-"x, exec <command> = run command (the rest of the line) using shell\n"
+"x, exec <commit> = run command (the rest of the line) using shell\n"
 "d, drop <commit> = remove commit\n"
 "l, label <label> = label current HEAD with a name\n"
 "t, reset <label> = reset HEAD to a label\n"
@@ -16942,8 +23183,8 @@ msgstr ""
 "e, edit <commit> = dùng lần chuyển giao, nhưng dừng lại để tu bổ (amend)\n"
 "s, squash <commit> = dùng lần chuyển giao, nhưng meld vào lần chuyển giao kế "
 "trước\n"
-"f, fixup <commit> = giống như \"squash\", nhưng loại bỏ chú thích nhật ký "
-"của lần chuyển giao này\n"
+"f, fixup <commit> = giống như \"squash\", nhưng loại bỏ chú thích của lần "
+"chuyển giao này\n"
 "x, exec <commit> = chạy lệnh (phần còn lại của dòng) dùng hệ vỏ\n"
 "d, drop <commit> = xóa lần chuyển giao\n"
 "l, label <label> = đánh nhãn HEAD hiện tại bằng một tên\n"
@@ -16958,24 +23199,7 @@ msgstr ""
 "Những dòng này có thể đảo ngược thứ tự; chúng chạy từ trên đỉnh xuống dưới "
 "đáy.\n"
 
-#: git-rebase--interactive.sh:179
-msgid ""
-"\n"
-"Do not remove any line. Use 'drop' explicitly to remove a commit.\n"
-msgstr ""
-"\n"
-"Đừng xóa bất kỳ dòng nào. Dùng “drop” một cách rõ ràng để xóa bỏ một lần "
-"chuyển giao.\n"
-
-#: git-rebase--interactive.sh:183
-msgid ""
-"\n"
-"If you remove a line here THAT COMMIT WILL BE LOST.\n"
-msgstr ""
-"\n"
-"Nếu bạn xóa bỏ một dòng ở đây thì LẦN CHUYỂN GIAO ĐÓ SẼ MẤT.\n"
-
-#: git-rebase--interactive.sh:221
+#: git-rebase--preserve-merges.sh:270
 #, sh-format
 msgid ""
 "You can amend the commit now, with\n"
@@ -16994,82 +23218,82 @@ msgstr ""
 "\n"
 "\tgit rebase --continue"
 
-#: git-rebase--interactive.sh:246
+#: git-rebase--preserve-merges.sh:295
 #, sh-format
 msgid "$sha1: not a commit that can be picked"
 msgstr "$sha1: không phải là lần chuyển giao mà có thể lấy ra được"
 
-#: git-rebase--interactive.sh:285
+#: git-rebase--preserve-merges.sh:334
 #, sh-format
 msgid "Invalid commit name: $sha1"
 msgstr "Tên lần chuyển giao không hợp lệ: $sha1"
 
-#: git-rebase--interactive.sh:325
+#: git-rebase--preserve-merges.sh:364
 msgid "Cannot write current commit's replacement sha1"
 msgstr "Không thể ghi lại sha1 thay thế của lần chuyển giao"
 
-#: git-rebase--interactive.sh:376
+#: git-rebase--preserve-merges.sh:415
 #, sh-format
 msgid "Fast-forward to $sha1"
 msgstr "Chuyển-tiếp-nhanh đến $sha1"
 
-#: git-rebase--interactive.sh:378
+#: git-rebase--preserve-merges.sh:417
 #, sh-format
 msgid "Cannot fast-forward to $sha1"
 msgstr "Không thể chuyển-tiếp-nhanh đến $sha1"
 
-#: git-rebase--interactive.sh:387
+#: git-rebase--preserve-merges.sh:426
 #, sh-format
 msgid "Cannot move HEAD to $first_parent"
 msgstr "Không thể di chuyển HEAD đến $first_parent"
 
-#: git-rebase--interactive.sh:392
+#: git-rebase--preserve-merges.sh:431
 #, sh-format
 msgid "Refusing to squash a merge: $sha1"
 msgstr "Từ chối squash lần hòa trộn: $sha1"
 
-#: git-rebase--interactive.sh:410
+#: git-rebase--preserve-merges.sh:449
 #, sh-format
 msgid "Error redoing merge $sha1"
 msgstr "Gặp lỗi khi hoàn lại bước hòa trộn $sha1"
 
-#: git-rebase--interactive.sh:419
+#: git-rebase--preserve-merges.sh:458
 #, sh-format
 msgid "Could not pick $sha1"
 msgstr "Không thể lấy ra $sha1"
 
-#: git-rebase--interactive.sh:428
+#: git-rebase--preserve-merges.sh:467
 #, sh-format
 msgid "This is the commit message #${n}:"
 msgstr "Đây là chú thích cho lần chuyển giao thứ #${n}:"
 
-#: git-rebase--interactive.sh:433
+#: git-rebase--preserve-merges.sh:472
 #, sh-format
 msgid "The commit message #${n} will be skipped:"
 msgstr "Chú thích cho lần chuyển giao thứ #${n} sẽ bị bỏ qua:"
 
-#: git-rebase--interactive.sh:444
+#: git-rebase--preserve-merges.sh:483
 #, sh-format
 msgid "This is a combination of $count commit."
 msgid_plural "This is a combination of $count commits."
 msgstr[0] "Đây là tổ hợp của $count lần chuyển giao."
 
-#: git-rebase--interactive.sh:453
+#: git-rebase--preserve-merges.sh:492
 #, sh-format
 msgid "Cannot write $fixup_msg"
 msgstr "Không thể $fixup_msg"
 
-#: git-rebase--interactive.sh:456
+#: git-rebase--preserve-merges.sh:495
 msgid "This is a combination of 2 commits."
 msgstr "Đây là tổ hợp của 2 lần chuyển giao."
 
-#: git-rebase--interactive.sh:497 git-rebase--interactive.sh:540
-#: git-rebase--interactive.sh:543
+#: git-rebase--preserve-merges.sh:536 git-rebase--preserve-merges.sh:579
+#: git-rebase--preserve-merges.sh:582
 #, sh-format
 msgid "Could not apply $sha1... $rest"
 msgstr "Không thể áp dụng $sha1… $rest"
 
-#: git-rebase--interactive.sh:572
+#: git-rebase--preserve-merges.sh:611
 #, sh-format
 msgid ""
 "Could not amend commit after successfully picking $sha1... $rest\n"
@@ -17085,31 +23309,31 @@ msgstr ""
 "này\n"
 "trước khi bạn có thể làm việc lại với lần chuyển giao."
 
-#: git-rebase--interactive.sh:587
+#: git-rebase--preserve-merges.sh:626
 #, sh-format
 msgid "Stopped at $sha1_abbrev... $rest"
 msgstr "Bị dừng tại $sha1_abbrev… $rest"
 
-#: git-rebase--interactive.sh:602
+#: git-rebase--preserve-merges.sh:641
 #, sh-format
 msgid "Cannot '$squash_style' without a previous commit"
 msgstr "Không “$squash_style” thể mà không có lần chuyển giao kế trước"
 
-#: git-rebase--interactive.sh:644
+#: git-rebase--preserve-merges.sh:683
 #, sh-format
 msgid "Executing: $rest"
 msgstr "Thực thi: $rest"
 
-#: git-rebase--interactive.sh:652
+#: git-rebase--preserve-merges.sh:691
 #, sh-format
 msgid "Execution failed: $rest"
 msgstr "Thực thi gặp lỗi: $rest"
 
-#: git-rebase--interactive.sh:654
+#: git-rebase--preserve-merges.sh:693
 msgid "and made changes to the index and/or the working tree"
 msgstr "và tạo các thay đổi bảng mục lục và/hay cây làm việc"
 
-#: git-rebase--interactive.sh:656
+#: git-rebase--preserve-merges.sh:695
 msgid ""
 "You can fix the problem, and then run\n"
 "\n"
@@ -17120,7 +23344,7 @@ msgstr ""
 "\tgit rebase --continue"
 
 #. TRANSLATORS: after these lines is a command to be issued by the user
-#: git-rebase--interactive.sh:669
+#: git-rebase--preserve-merges.sh:708
 #, sh-format
 msgid ""
 "Execution succeeded: $rest\n"
@@ -17135,29 +23359,25 @@ msgstr ""
 "\n"
 "\tgit rebase --continue"
 
-#: git-rebase--interactive.sh:680
+#: git-rebase--preserve-merges.sh:719
 #, sh-format
 msgid "Unknown command: $command $sha1 $rest"
 msgstr "Lệnh chưa biết: $command $sha1 $rest"
 
-#: git-rebase--interactive.sh:681
+#: git-rebase--preserve-merges.sh:720
 msgid "Please fix this using 'git rebase --edit-todo'."
 msgstr "Vui lòng sửa lỗi này bằng cách dùng “git rebase --edit-todo”."
 
-#: git-rebase--interactive.sh:716
+#: git-rebase--preserve-merges.sh:755
 #, sh-format
 msgid "Successfully rebased and updated $head_name."
 msgstr "Cài tổ và cập nhật $head_name một cách thành công."
 
-#: git-rebase--interactive.sh:740
-msgid "could not detach HEAD"
-msgstr "không thể tách rời HEAD"
-
-#: git-rebase--interactive.sh:778
+#: git-rebase--preserve-merges.sh:812
 msgid "Could not remove CHERRY_PICK_HEAD"
 msgstr "Không thể xóa bỏ CHERRY_PICK_HEAD"
 
-#: git-rebase--interactive.sh:783
+#: git-rebase--preserve-merges.sh:817
 #, sh-format
 msgid ""
 "You have staged changes in your working tree.\n"
@@ -17188,11 +23408,11 @@ msgstr ""
 "\n"
 "  git rebase --continue\n"
 
-#: git-rebase--interactive.sh:800
+#: git-rebase--preserve-merges.sh:834
 msgid "Error trying to find the author identity to amend commit"
 msgstr "Lỗi khi cố tìm định danh của tác giả để tu bổ lần chuyển giao"
 
-#: git-rebase--interactive.sh:805
+#: git-rebase--preserve-merges.sh:839
 msgid ""
 "You have uncommitted changes in your working tree. Please commit them\n"
 "first and then run 'git rebase --continue' again."
@@ -17201,73 +23421,39 @@ msgstr ""
 "Vui lòng chuyển giao chúng và sau đó chạy lệnh “git rebase --continue” lần "
 "nữa."
 
-#: git-rebase--interactive.sh:810 git-rebase--interactive.sh:814
+#: git-rebase--preserve-merges.sh:844 git-rebase--preserve-merges.sh:848
 msgid "Could not commit staged changes."
 msgstr "Không thể chuyển giao các thay đổi đã đưa lên bệ phóng."
 
-#: git-rebase--interactive.sh:843
-msgid ""
-"\n"
-"You are editing the todo file of an ongoing interactive rebase.\n"
-"To continue rebase after editing, run:\n"
-"    git rebase --continue\n"
-"\n"
-msgstr ""
-"\n"
-"Bạn đang sửa tập tin todo của một lần cải tổ tương tác đang thực hiện.\n"
-"Để tiếp tục cải tổ sau khi sửa, chạy:\n"
-"    git rebase --continue\n"
-"\n"
-
-#: git-rebase--interactive.sh:851 git-rebase--interactive.sh:937
+#: git-rebase--preserve-merges.sh:879 git-rebase--preserve-merges.sh:965
 msgid "Could not execute editor"
 msgstr "Không thể thực thi trình biên soạn"
 
-#: git-rebase--interactive.sh:872
+#: git-rebase--preserve-merges.sh:900
 #, sh-format
 msgid "Could not checkout $switch_to"
 msgstr "Không thể checkout $switch_to"
 
-#: git-rebase--interactive.sh:879
+#: git-rebase--preserve-merges.sh:907
 msgid "No HEAD?"
 msgstr "Không HEAD?"
 
-#: git-rebase--interactive.sh:880
+#: git-rebase--preserve-merges.sh:908
 #, sh-format
 msgid "Could not create temporary $state_dir"
 msgstr "Không thể tạo thư mục tạm thời $state_dir"
 
-#: git-rebase--interactive.sh:883
+#: git-rebase--preserve-merges.sh:911
 msgid "Could not mark as interactive"
 msgstr "Không thể đánh dấu là tương tác"
 
-#: git-rebase--interactive.sh:915
+#: git-rebase--preserve-merges.sh:943
 #, sh-format
 msgid "Rebase $shortrevisions onto $shortonto ($todocount command)"
 msgid_plural "Rebase $shortrevisions onto $shortonto ($todocount commands)"
 msgstr[0] "Cải tổ $shortrevisions vào $shortonto (các lệnh $todocount)"
 
-#: git-rebase--interactive.sh:920
-msgid ""
-"\n"
-"\tHowever, if you remove everything, the rebase will be aborted.\n"
-"\n"
-"\t"
-msgstr ""
-"\n"
-"\tTuy nhiên, nếu bạn xóa bỏ mọi thứ, việc cải tổ sẽ bị bãi bỏ.\n"
-"\n"
-"\t"
-
-#: git-rebase--interactive.sh:927
-msgid "Note that empty commits are commented out"
-msgstr "Chú ý rằng lần chuyển giao trống rỗng là ghi chú"
-
-#: git-rebase--interactive.sh:980
-msgid "Could not generate todo list"
-msgstr "Không thể tạo danh sách cần làm"
-
-#: git-rebase--interactive.sh:1001 git-rebase--interactive.sh:1006
+#: git-rebase--preserve-merges.sh:997 git-rebase--preserve-merges.sh:1002
 msgid "Could not init rewritten commits"
 msgstr "Không thể khởi tạo các lần chuyển giao ghi lại"
 
@@ -17276,188 +23462,127 @@ msgstr "Không thể khởi tạo các l
 msgid "usage: $dashless $USAGE"
 msgstr "cách dùng: $dashless $USAGE"
 
-#: git-sh-setup.sh:190
+#: git-sh-setup.sh:191
 #, sh-format
 msgid "Cannot chdir to $cdup, the toplevel of the working tree"
 msgstr ""
 "Không thể chuyển thư mục (chdir) sang $cdup, thư mục ở mức cao nhất của cây "
 "làm việc"
 
-#: git-sh-setup.sh:199 git-sh-setup.sh:206
+#: git-sh-setup.sh:200 git-sh-setup.sh:207
 #, sh-format
 msgid "fatal: $program_name cannot be used without a working tree."
 msgstr ""
 "lỗi nghiêm trọng: $program_name không thể được dùng ngoaoif thư mục làm việc."
 
-#: git-sh-setup.sh:220
+#: git-sh-setup.sh:221
 msgid "Cannot rebase: You have unstaged changes."
 msgstr "Không thể cải tổ: Bạn có các thay đổi chưa được đưa lên bệ phóng."
 
-#: git-sh-setup.sh:223
+#: git-sh-setup.sh:224
 msgid "Cannot rewrite branches: You have unstaged changes."
 msgstr ""
 "Không thể ghi lại các nhánh: Bạn có các thay đổi chưa được đưa lên bệ phóng."
 
-#: git-sh-setup.sh:226
+#: git-sh-setup.sh:227
 msgid "Cannot pull with rebase: You have unstaged changes."
 msgstr ""
 "Không thể pull với cải tổ: Bạn có các thay đổi chưa được đưa lên bệ phóng."
 
-#: git-sh-setup.sh:229
+#: git-sh-setup.sh:230
 #, sh-format
 msgid "Cannot $action: You have unstaged changes."
 msgstr "Không thể $action: Bạn có các thay đổi chưa được đưa lên bệ phóng."
 
-#: git-sh-setup.sh:242
+#: git-sh-setup.sh:243
 msgid "Cannot rebase: Your index contains uncommitted changes."
 msgstr ""
 "Không thể cải tổ: Mục lục của bạn có chứa các thay đổi chưa được chuyển giao."
 
-#: git-sh-setup.sh:245
+#: git-sh-setup.sh:246
 msgid "Cannot pull with rebase: Your index contains uncommitted changes."
 msgstr "Không thể pull với cải tổ: Bạn có các thay đổi chưa được chuyển giao."
 
-#: git-sh-setup.sh:248
+#: git-sh-setup.sh:249
 #, sh-format
 msgid "Cannot $action: Your index contains uncommitted changes."
 msgstr ""
 "Không thể $action: Mục lục của bạn có chứa các thay đổi chưa được chuyển "
 "giao."
 
-#: git-sh-setup.sh:252
+#: git-sh-setup.sh:253
 msgid "Additionally, your index contains uncommitted changes."
 msgstr ""
 "Thêm vào đó, bảng mục lục của bạn có chứa các thay đổi chưa được chuyển giao."
 
-#: git-sh-setup.sh:372
-msgid "You need to run this command from the toplevel of the working tree."
-msgstr "Bạn cần chạy lệnh này từ thư mục ở mức cao nhất của cây làm việc."
-
-#: git-sh-setup.sh:377
-msgid "Unable to determine absolute path of git directory"
-msgstr "Không thể dò tìm đường dẫn tuyệt đối của thư mục git"
-
-#. TRANSLATORS: you can adjust this to align "git add -i" status menu
-#: git-add--interactive.perl:196
-#, perl-format
-msgid "%12s %12s %s"
-msgstr "%12s %12s %s"
-
-#: git-add--interactive.perl:197
-msgid "staged"
-msgstr "đã đưa lên bệ phóng"
-
-#: git-add--interactive.perl:197
-msgid "unstaged"
-msgstr "chưa đưa lên bệ phóng"
-
-#: git-add--interactive.perl:253 git-add--interactive.perl:278
-msgid "binary"
-msgstr "nhị phân"
-
-#: git-add--interactive.perl:262 git-add--interactive.perl:316
-msgid "nothing"
-msgstr "không có gì"
-
-#: git-add--interactive.perl:298 git-add--interactive.perl:313
-msgid "unchanged"
-msgstr "không thay đổi"
-
-#: git-add--interactive.perl:609
-#, perl-format
-msgid "added %d path\n"
-msgid_plural "added %d paths\n"
-msgstr[0] "đã thêm %d đường dẫn\n"
+#: git-sh-setup.sh:373
+msgid "You need to run this command from the toplevel of the working tree."
+msgstr "Bạn cần chạy lệnh này từ thư mục ở mức cao nhất của cây làm việc."
 
-#: git-add--interactive.perl:612
-#, perl-format
-msgid "updated %d path\n"
-msgid_plural "updated %d paths\n"
-msgstr[0] "đã cập nhật %d đường dẫn\n"
+#: git-sh-setup.sh:378
+msgid "Unable to determine absolute path of git directory"
+msgstr "Không thể dò tìm đường dẫn tuyệt đối của thư mục git"
 
-#: git-add--interactive.perl:615
+#. TRANSLATORS: you can adjust this to align "git add -i" status menu
+#: git-add--interactive.perl:212
 #, perl-format
-msgid "reverted %d path\n"
-msgid_plural "reverted %d paths\n"
-msgstr[0] "đã hoàn nguyên %d đường dẫn\n"
+msgid "%12s %12s %s"
+msgstr "%12s %12s %s"
 
-#: git-add--interactive.perl:618
+#: git-add--interactive.perl:634
 #, perl-format
 msgid "touched %d path\n"
 msgid_plural "touched %d paths\n"
 msgstr[0] "%d đường dẫn đã touch (chạm)\n"
 
-#: git-add--interactive.perl:627
-msgid "Update"
-msgstr "Cập nhật"
-
-#: git-add--interactive.perl:639
-msgid "Revert"
-msgstr "Hoàn nguyên"
-
-#: git-add--interactive.perl:662
-#, perl-format
-msgid "note: %s is untracked now.\n"
-msgstr "chú ý: %s giờ đã bỏ theo dõi.\n"
-
-#: git-add--interactive.perl:673
-msgid "Add untracked"
-msgstr "Thêm các cái chưa được theo dõi"
-
-#: git-add--interactive.perl:679
-msgid "No untracked files.\n"
-msgstr "Không có tập tin nào chưa được theo dõi.\n"
-
-#: git-add--interactive.perl:1033
+#: git-add--interactive.perl:1053
 msgid ""
 "If the patch applies cleanly, the edited hunk will immediately be\n"
 "marked for staging."
 msgstr ""
-"Nếu miếng vá được áp dụng sạch sẽ, hunk đã sửa sẽ ngay lập tức\n"
+"Nếu miếng vá được áp dụng sạch sẽ, khúc đã sửa sẽ ngay lập tức\n"
 "được đánh dấu để chuyển lên bệ phóng."
 
-#: git-add--interactive.perl:1036
+#: git-add--interactive.perl:1056
 msgid ""
 "If the patch applies cleanly, the edited hunk will immediately be\n"
 "marked for stashing."
 msgstr ""
-"Nếu miếng vá được áp dụng sạch sẽ, hunk đã sửa sẽ ngay lập tức\n"
+"Nếu miếng vá được áp dụng sạch sẽ, khúc đã sửa sẽ ngay lập tức\n"
 "được đánh dấu để tạm cất."
 
-#: git-add--interactive.perl:1039
+#: git-add--interactive.perl:1059
 msgid ""
 "If the patch applies cleanly, the edited hunk will immediately be\n"
 "marked for unstaging."
 msgstr ""
-"Nếu miếng vá được áp dụng sạch sẽ, hunk đã sửa sẽ ngay lập tức\n"
+"Nếu miếng vá được áp dụng sạch sẽ, khúc đã sửa sẽ ngay lập tức\n"
 "được đánh dấu để bỏ chuyển lên bệ phóng."
 
-#: git-add--interactive.perl:1042 git-add--interactive.perl:1051
+#: git-add--interactive.perl:1062 git-add--interactive.perl:1071
+#: git-add--interactive.perl:1077
 msgid ""
 "If the patch applies cleanly, the edited hunk will immediately be\n"
 "marked for applying."
 msgstr ""
-"Nếu miếng vá được áp dụng sạch sẽ, hunk đã sửa sẽ ngay lập tức\n"
+"Nếu miếng vá được áp dụng sạch sẽ, khúc đã sửa sẽ ngay lập tức\n"
 "được đánh dấu để áp dụng."
 
-#: git-add--interactive.perl:1045 git-add--interactive.perl:1048
+#: git-add--interactive.perl:1065 git-add--interactive.perl:1068
+#: git-add--interactive.perl:1074
 msgid ""
 "If the patch applies cleanly, the edited hunk will immediately be\n"
 "marked for discarding."
 msgstr ""
-"Nếu miếng vá được áp dụng sạch sẽ, hunk đã sửa sẽ ngay lập tức\n"
+"Nếu miếng vá được áp dụng sạch sẽ, khúc đã sửa sẽ ngay lập tức\n"
 "được đánh dấu để loại bỏ."
 
-#: git-add--interactive.perl:1085
+#: git-add--interactive.perl:1111
 #, perl-format
 msgid "failed to open hunk edit file for writing: %s"
-msgstr "gặp lỗi khi tập tin sửa hunk để ghi: %s"
-
-#: git-add--interactive.perl:1086
-msgid "Manual hunk edit mode -- see bottom for a quick guide.\n"
-msgstr "Chế độ sửa hunk bằng tay -- xem ở đáy để có hướng dẫn sử dụng nhanh.\n"
+msgstr "gặp lỗi khi tập tin sửa khúc để ghi: %s"
 
-#: git-add--interactive.perl:1092
+#: git-add--interactive.perl:1118
 #, perl-format
 msgid ""
 "---\n"
@@ -17470,36 +23595,12 @@ msgstr ""
 "Để xóa bỏ dòng “%s”, xóa chúng đi.\n"
 "Những dòng bắt đầu bằng %s sẽ bị loại bỏ.\n"
 
-#. TRANSLATORS: 'it' refers to the patch mentioned in the previous messages.
-#: git-add--interactive.perl:1100
-msgid ""
-"If it does not apply cleanly, you will be given an opportunity to\n"
-"edit again.  If all lines of the hunk are removed, then the edit is\n"
-"aborted and the hunk is left unchanged.\n"
-msgstr ""
-"Nếu miếng vá không được áp dụng sạch sẽ, bạn sẽ có một cơ hội\n"
-"để sửa lần nữa. Nếu mọi dòng của hunk bị xóa bỏ, thế thì những\n"
-"sửa dổi sẽ bị loại bỏ, và hunk vẫn giữ nguyên.\n"
-
-#: git-add--interactive.perl:1114
+#: git-add--interactive.perl:1140
 #, perl-format
 msgid "failed to open hunk edit file for reading: %s"
-msgstr "gặp lỗi khi mở tập tin hunk để đọc: %s"
-
-#. TRANSLATORS: do not translate [y/n]
-#. The program will only accept that input
-#. at this point.
-#. Consider translating (saying "no" discards!) as
-#. (saying "n" for "no" discards!) if the translation
-#. of the word "no" does not start with n.
-#: git-add--interactive.perl:1213
-msgid ""
-"Your edited hunk does not apply. Edit again (saying \"no\" discards!) [y/n]? "
-msgstr ""
-"Hunk đã sửa của bạn không được áp dụng. Sửa lại lần nữa (nói \"n\" để loại "
-"bỏ!) [y/n]? "
+msgstr "gặp lỗi khi mở tập tin khúc để đọc: %s"
 
-#: git-add--interactive.perl:1222
+#: git-add--interactive.perl:1248
 msgid ""
 "y - stage this hunk\n"
 "n - do not stage this hunk\n"
@@ -17507,14 +23608,14 @@ msgid ""
 "a - stage this hunk and all later hunks in the file\n"
 "d - do not stage this hunk or any of the later hunks in the file"
 msgstr ""
-"y - đưa lên bệ phóng hunk này\n"
-"n - đừng đưa lên bệ phóng hunk này\n"
-"q - thoát; đừng đưa lên bệ phóng hunk này cũng như bất kỳ cái nào còn lại\n"
-"a - đưa lên bệ phóng hunk này và tất cả các hunk sau này trong tập tin\n"
-"d - đừng đưa lên bệ phóng hunk này cũng như bất kỳ cái nào còn lại trong tập "
+"y - đưa lên bệ phóng khúc này\n"
+"n - đừng đưa lên bệ phóng khúc này\n"
+"q - thoát; đừng đưa lên bệ phóng khúc này cũng như bất kỳ cái nào còn lại\n"
+"a - đưa lên bệ phóng khúc này và tất cả các khúc sau này trong tập tin\n"
+"d - đừng đưa lên bệ phóng khúc này cũng như bất kỳ cái nào còn lại trong tập "
 "tin"
 
-#: git-add--interactive.perl:1228
+#: git-add--interactive.perl:1254
 msgid ""
 "y - stash this hunk\n"
 "n - do not stash this hunk\n"
@@ -17522,13 +23623,13 @@ msgid ""
 "a - stash this hunk and all later hunks in the file\n"
 "d - do not stash this hunk or any of the later hunks in the file"
 msgstr ""
-"y - tạm cất hunk này\n"
-"n - đừng tạm cất hunk này\n"
-"q - thoát; đừng tạm cất hunk này cũng như bất kỳ cái nào còn lại\n"
-"a - tạm cất hunk này và tất cả các hunk sau này trong tập tin\n"
-"d - đừng tạm cất hunk này cũng như bất kỳ cái nào còn lại trong tập tin"
+"y - tạm cất khúc này\n"
+"n - đừng tạm cất khúc này\n"
+"q - thoát; đừng tạm cất khúc này cũng như bất kỳ cái nào còn lại\n"
+"a - tạm cất khúc này và tất cả các khúc sau này trong tập tin\n"
+"d - đừng tạm cất khúc này cũng như bất kỳ cái nào còn lại trong tập tin"
 
-#: git-add--interactive.perl:1234
+#: git-add--interactive.perl:1260
 msgid ""
 "y - unstage this hunk\n"
 "n - do not unstage this hunk\n"
@@ -17536,15 +23637,15 @@ msgid ""
 "a - unstage this hunk and all later hunks in the file\n"
 "d - do not unstage this hunk or any of the later hunks in the file"
 msgstr ""
-"y - đưa ra khỏi bệ phóng hunk này\n"
-"n - đừng đưa ra khỏi bệ phóng hunk này\n"
-"q - thoát; đừng đưa ra khỏi bệ phóng hunk này cũng như bất kỳ cái nào còn "
+"y - đưa ra khỏi bệ phóng khúc này\n"
+"n - đừng đưa ra khỏi bệ phóng khúc này\n"
+"q - thoát; đừng đưa ra khỏi bệ phóng khúc này cũng như bất kỳ cái nào còn "
 "lại\n"
-"a - đưa ra khỏi bệ phóng hunk này và tất cả các hunk sau này trong tập tin\n"
-"d - đừng đưa ra khỏi bệ phóng hunk này cũng như bất kỳ cái nào còn lại trong "
+"a - đưa ra khỏi bệ phóng khúc này và tất cả các khúc sau này trong tập tin\n"
+"d - đừng đưa ra khỏi bệ phóng khúc này cũng như bất kỳ cái nào còn lại trong "
 "tập tin"
 
-#: git-add--interactive.perl:1240
+#: git-add--interactive.perl:1266
 msgid ""
 "y - apply this hunk to index\n"
 "n - do not apply this hunk to index\n"
@@ -17552,13 +23653,13 @@ msgid ""
 "a - apply this hunk and all later hunks in the file\n"
 "d - do not apply this hunk or any of the later hunks in the file"
 msgstr ""
-"y - áp dụng hunk này vào mục lục\n"
-"n - đừng áp dụng hunk này vào mục lục\n"
-"q - thoát; đừng áp dụng hunk này cũng như bất kỳ cái nào còn lại\n"
-"a - áp dụng hunk này và tất cả các hunk sau này trong tập tin\n"
-"d - đừng áp dụng hunk này cũng như bất kỳ cái nào sau này trong tập tin"
+"y - áp dụng khúc này vào mục lục\n"
+"n - đừng áp dụng khúc này vào mục lục\n"
+"q - thoát; đừng áp dụng khúc này cũng như bất kỳ cái nào còn lại\n"
+"a - áp dụng khúc này và tất cả các khúc sau này trong tập tin\n"
+"d - đừng áp dụng khúc này cũng như bất kỳ cái nào sau này trong tập tin"
 
-#: git-add--interactive.perl:1246
+#: git-add--interactive.perl:1272 git-add--interactive.perl:1290
 msgid ""
 "y - discard this hunk from worktree\n"
 "n - do not discard this hunk from worktree\n"
@@ -17566,13 +23667,13 @@ msgid ""
 "a - discard this hunk and all later hunks in the file\n"
 "d - do not discard this hunk or any of the later hunks in the file"
 msgstr ""
-"y - loại bỏ hunk này khỏi cây làm việc\n"
-"n - đừng loại bỏ hunk khỏi cây làm việc\n"
-"q - thoát; đừng loại bỏ hunk này cũng như bất kỳ cái nào còn lại\n"
-"a - loại bỏ hunk này và tất cả các hunk sau này trong tập tin\n"
-"d - đừng loại bỏ hunk này cũng như bất kỳ cái nào sau này trong tập tin"
+"y - loại bỏ khúc này khỏi cây làm việc\n"
+"n - đừng loại bỏ khúc khỏi cây làm việc\n"
+"q - thoát; đừng loại bỏ khúc này cũng như bất kỳ cái nào còn lại\n"
+"a - loại bỏ khúc này và tất cả các khúc sau này trong tập tin\n"
+"d - đừng loại bỏ khúc này cũng như bất kỳ cái nào sau này trong tập tin"
 
-#: git-add--interactive.perl:1252
+#: git-add--interactive.perl:1278
 msgid ""
 "y - discard this hunk from index and worktree\n"
 "n - do not discard this hunk from index and worktree\n"
@@ -17580,13 +23681,13 @@ msgid ""
 "a - discard this hunk and all later hunks in the file\n"
 "d - do not discard this hunk or any of the later hunks in the file"
 msgstr ""
-"y - loại bỏ hunk này khỏi mục lục và cây làm việc\n"
-"n - đừng loại bỏ hunk khỏi mục lục và cây làm việc\n"
-"q - thoát; đừng loại bỏ hunk này cũng như bất kỳ cái nào còn lại\n"
-"a - loại bỏ hunk này và tất cả các hunk sau này trong tập tin\n"
-"d - đừng loại bỏ hunk này cũng như bất kỳ cái nào sau này trong tập tin"
+"y - loại bỏ khúc này khỏi mục lục và cây làm việc\n"
+"n - đừng loại bỏ khúc khỏi mục lục và cây làm việc\n"
+"q - thoát; đừng loại bỏ khúc này cũng như bất kỳ cái nào còn lại\n"
+"a - loại bỏ khúc này và tất cả các khúc sau này trong tập tin\n"
+"d - đừng loại bỏ khúc này cũng như bất kỳ cái nào sau này trong tập tin"
 
-#: git-add--interactive.perl:1258
+#: git-add--interactive.perl:1284
 msgid ""
 "y - apply this hunk to index and worktree\n"
 "n - do not apply this hunk to index and worktree\n"
@@ -17594,13 +23695,27 @@ msgid ""
 "a - apply this hunk and all later hunks in the file\n"
 "d - do not apply this hunk or any of the later hunks in the file"
 msgstr ""
-"y - áp dụng hunk này vào mục lục và cây làm việc\n"
-"n - đừng áp dụng hunk vào mục lục và cây làm việc\n"
-"q - thoát; đừng áp dụng hunk này cũng như bất kỳ cái nào còn lại\n"
-"a - áp dụng hunk này và tất cả các hunk sau này trong tập tin\n"
-"d - đừng áp dụng hunk này cũng như bất kỳ cái nào sau này trong tập tin"
+"y - áp dụng khúc này vào mục lục và cây làm việc\n"
+"n - đừng áp dụng khúc vào mục lục và cây làm việc\n"
+"q - thoát; đừng áp dụng khúc này cũng như bất kỳ cái nào còn lại\n"
+"a - áp dụng khúc này và tất cả các khúc sau này trong tập tin\n"
+"d - đừng áp dụng khúc này cũng như bất kỳ cái nào sau này trong tập tin"
+
+#: git-add--interactive.perl:1296
+msgid ""
+"y - apply this hunk to worktree\n"
+"n - do not apply this hunk to worktree\n"
+"q - quit; do not apply this hunk or any of the remaining ones\n"
+"a - apply this hunk and all later hunks in the file\n"
+"d - do not apply this hunk or any of the later hunks in the file"
+msgstr ""
+"y - áp dụng khúc này vào cây làm việc\n"
+"n - đừng áp dụng khúc vào cây làm việc\n"
+"q - thoát; đừng áp dụng khúc này cũng như bất kỳ cái nào còn lại\n"
+"a - áp dụng khúc này và tất cả các khúc sau này trong tập tin\n"
+"d - đừng áp dụng khúc này cũng như bất kỳ cái nào sau này trong tập tin"
 
-#: git-add--interactive.perl:1273
+#: git-add--interactive.perl:1311
 msgid ""
 "g - select a hunk to go to\n"
 "/ - search for a hunk matching the given regex\n"
@@ -17612,219 +23727,206 @@ msgid ""
 "e - manually edit the current hunk\n"
 "? - print help\n"
 msgstr ""
-"g - chọn một hunk muốn tới\n"
-"/ - tìm một hunk khớp với biểu thức chính quy đưa ra\n"
-"j - để lại hunk này là chưa quyết định, xem hunk chưa quyết định kế\n"
-"J - để lại hunk này là chưa quyết định, xem hunk kế\n"
-"k - để lại hunk này là chưa quyết định, xem hunk chưa quyết định kế trước\n"
-"K - để lại hunk này là chưa quyết định, xem hunk kế trước\n"
-"s - chia hunk hiện tại thành các hunk nhỏ hơn\n"
-"e - sửa bằng tay hunk hiện hành\n"
+"g - chọn một khúc muốn tới\n"
+"/ - tìm một khúc khớp với biểu thức chính quy đưa ra\n"
+"j - để lại khúc này là chưa quyết định, xem khúc chưa quyết định kế\n"
+"J - để lại khúc này là chưa quyết định, xem khúc kế\n"
+"k - để lại khúc này là chưa quyết định, xem khúc chưa quyết định kế trước\n"
+"K - để lại khúc này là chưa quyết định, xem khúc kế trước\n"
+"s - chia khúc hiện tại thành các khúc nhỏ hơn\n"
+"e - sửa bằng tay khúc hiện hành\n"
 "? - in trợ giúp\n"
 
-#: git-add--interactive.perl:1304
+#: git-add--interactive.perl:1342
 msgid "The selected hunks do not apply to the index!\n"
-msgstr "Các hunk đã chọn không được áp dụng vào bảng mục lục!\n"
+msgstr "Các khúc đã chọn không được áp dụng vào bảng mục lục!\n"
 
-#: git-add--interactive.perl:1305
+#: git-add--interactive.perl:1343
 msgid "Apply them to the worktree anyway? "
 msgstr "Vẫn áp dụng chúng cho cây làm việc? "
 
-#: git-add--interactive.perl:1308
+#: git-add--interactive.perl:1346
 msgid "Nothing was applied.\n"
 msgstr "Đã không áp dụng gì cả.\n"
 
-#: git-add--interactive.perl:1319
+#: git-add--interactive.perl:1357
 #, perl-format
 msgid "ignoring unmerged: %s\n"
 msgstr "bỏ qua những thứ chưa hòa trộn: %s\n"
 
-#: git-add--interactive.perl:1328
-msgid "Only binary files changed.\n"
-msgstr "Chỉ có các tập tin nhị phân là thay đổi.\n"
-
-#: git-add--interactive.perl:1330
-msgid "No changes.\n"
-msgstr "Không có thay đổi nào.\n"
-
-#: git-add--interactive.perl:1338
-msgid "Patch update"
-msgstr "Cập nhật miếng vá"
-
-#: git-add--interactive.perl:1390
+#: git-add--interactive.perl:1428
 #, perl-format
 msgid "Stage mode change [y,n,q,a,d%s,?]? "
 msgstr "Thay đổi chế độ bệ phóng [y,n,q,a,d%s,?]? "
 
-#: git-add--interactive.perl:1391
+#: git-add--interactive.perl:1429
 #, perl-format
 msgid "Stage deletion [y,n,q,a,d%s,?]? "
 msgstr "Xóa khỏi bệ phóng [y,n,q,a,d%s,?]? "
 
-#: git-add--interactive.perl:1392
+#: git-add--interactive.perl:1430
 #, perl-format
 msgid "Stage this hunk [y,n,q,a,d%s,?]? "
-msgstr "Đưa lên bệ phóng hunk này [y,n,q,a,d%s,?]? "
+msgstr "Đưa lên bệ phóng khúc này [y,n,q,a,d%s,?]? "
 
-#: git-add--interactive.perl:1395
+#: git-add--interactive.perl:1433
 #, perl-format
 msgid "Stash mode change [y,n,q,a,d%s,?]? "
 msgstr "Thay đổi chế độ tạm cất đi [y,n,q,a,d%s,?]? "
 
-#: git-add--interactive.perl:1396
+#: git-add--interactive.perl:1434
 #, perl-format
 msgid "Stash deletion [y,n,q,a,d%s,?]? "
 msgstr "Xóa tạm cất [y,n,q,a,d%s,?]? "
 
-#: git-add--interactive.perl:1397
+#: git-add--interactive.perl:1435
 #, perl-format
 msgid "Stash this hunk [y,n,q,a,d%s,?]? "
-msgstr "Tạm cất hunk này [y,n,q,a,d%s,?]? "
+msgstr "Tạm cất khúc này [y,n,q,a,d%s,?]? "
 
-#: git-add--interactive.perl:1400
+#: git-add--interactive.perl:1438
 #, perl-format
 msgid "Unstage mode change [y,n,q,a,d%s,?]? "
 msgstr "Thay đổi chế độ bỏ ra khỏi bệ phóng [y,n,q,a,d%s,?]? "
 
-#: git-add--interactive.perl:1401
+#: git-add--interactive.perl:1439
 #, perl-format
 msgid "Unstage deletion [y,n,q,a,d%s,?]? "
 msgstr "Xóa bỏ việc bỏ ra khỏi bệ phóng [y,n,q,a,d%s,?]? "
 
-#: git-add--interactive.perl:1402
+#: git-add--interactive.perl:1440
 #, perl-format
 msgid "Unstage this hunk [y,n,q,a,d%s,?]? "
-msgstr "Bỏ ra khỏi bệ phóng hunk này [y,n,q,a,d%s,?]? "
+msgstr "Bỏ ra khỏi bệ phóng khúc này [y,n,q,a,d%s,?]? "
 
-#: git-add--interactive.perl:1405
+#: git-add--interactive.perl:1443
 #, perl-format
 msgid "Apply mode change to index [y,n,q,a,d%s,?]? "
 msgstr "Áp dụng thay đổi chế độ cho mục lục [y,n,q,a,d%s,?]? "
 
-#: git-add--interactive.perl:1406
+#: git-add--interactive.perl:1444
 #, perl-format
 msgid "Apply deletion to index [y,n,q,a,d%s,?]? "
 msgstr "Áp dụng việc xóa vào mục lục [y,n,q,a,d%s,?]? "
 
-#: git-add--interactive.perl:1407
+#: git-add--interactive.perl:1445
 #, perl-format
 msgid "Apply this hunk to index [y,n,q,a,d%s,?]? "
-msgstr "Áo dụng hunk này vào mục lục [y,n,q,a,d%s,?]? "
+msgstr "Áo dụng khúc này vào mục lục [y,n,q,a,d%s,?]? "
 
-#: git-add--interactive.perl:1410
+#: git-add--interactive.perl:1448 git-add--interactive.perl:1463
 #, perl-format
 msgid "Discard mode change from worktree [y,n,q,a,d%s,?]? "
 msgstr "Loại bỏ các thay đổi chế độ từ cây làm việc [y,n,q,a,d%s,?]? "
 
-#: git-add--interactive.perl:1411
+#: git-add--interactive.perl:1449 git-add--interactive.perl:1464
 #, perl-format
 msgid "Discard deletion from worktree [y,n,q,a,d%s,?]? "
 msgstr "Loại bỏ việc xóa khỏi cây làm việc [y,n,q,a,d%s,?]? "
 
-#: git-add--interactive.perl:1412
+#: git-add--interactive.perl:1450 git-add--interactive.perl:1465
 #, perl-format
 msgid "Discard this hunk from worktree [y,n,q,a,d%s,?]? "
-msgstr "Loại bỏ hunk này khỏi cây làm việc [y,n,q,a,d%s,?]? "
+msgstr "Loại bỏ khúc này khỏi cây làm việc [y,n,q,a,d%s,?]? "
 
-#: git-add--interactive.perl:1415
+#: git-add--interactive.perl:1453
 #, perl-format
 msgid "Discard mode change from index and worktree [y,n,q,a,d%s,?]? "
 msgstr "Loại bỏ thay đổi chế độ từ mục lục và cây làm việc [y,n,q,a,d%s,?]? "
 
-#: git-add--interactive.perl:1416
+#: git-add--interactive.perl:1454
 #, perl-format
 msgid "Discard deletion from index and worktree [y,n,q,a,d%s,?]? "
 msgstr "Loại bỏ việc xóa khỏi mục lục và cây làm việc [y,n,q,a,d%s,?]? "
 
-#: git-add--interactive.perl:1417
+#: git-add--interactive.perl:1455
 #, perl-format
 msgid "Discard this hunk from index and worktree [y,n,q,a,d%s,?]? "
-msgstr "Loại bỏ hunk này khỏi mục lục và cây làm việc [y,n,q,a,d%s,?]? "
+msgstr "Loại bỏ khúc này khỏi mục lục và cây làm việc [y,n,q,a,d%s,?]? "
 
-#: git-add--interactive.perl:1420
+#: git-add--interactive.perl:1458
 #, perl-format
 msgid "Apply mode change to index and worktree [y,n,q,a,d%s,?]? "
 msgstr "Áp dụng thay đổi chế độ cho mục lục và cây làm việc [y,n,q,a,d%s,?]? "
 
-#: git-add--interactive.perl:1421
+#: git-add--interactive.perl:1459
 #, perl-format
 msgid "Apply deletion to index and worktree [y,n,q,a,d%s,?]? "
 msgstr "Áp dụng việc xóa vào mục lục và cây làm việc [y,n,q,a,d%s,?]? "
 
-#: git-add--interactive.perl:1422
+#: git-add--interactive.perl:1460
 #, perl-format
 msgid "Apply this hunk to index and worktree [y,n,q,a,d%s,?]? "
-msgstr "Áp dụng hunk này vào mục lục và cây làm việc [y,n,q,a,d%s,?]? "
+msgstr "Áp dụng khúc này vào mục lục và cây làm việc [y,n,q,a,d%s,?]? "
 
-#: git-add--interactive.perl:1522
-msgid "No other hunks to goto\n"
-msgstr "Không còn hunk nào để mà nhảy đến\n"
+#: git-add--interactive.perl:1468
+#, perl-format
+msgid "Apply mode change to worktree [y,n,q,a,d%s,?]? "
+msgstr "Áp dụng thay đổi chế độ cho cây làm việc [y,n,q,a,d%s,?]? "
 
-#: git-add--interactive.perl:1529
-msgid "go to which hunk (<ret> to see more)? "
-msgstr "nhảy đến hunk nào (<ret> để xem thêm)? "
+#: git-add--interactive.perl:1469
+#, perl-format
+msgid "Apply deletion to worktree [y,n,q,a,d%s,?]? "
+msgstr "Áp dụng việc xóa cho cây làm việc [y,n,q,a,d%s,?]? "
 
-#: git-add--interactive.perl:1531
-msgid "go to which hunk? "
-msgstr "nhảy đến hunk nào?"
+#: git-add--interactive.perl:1470
+#, perl-format
+msgid "Apply this hunk to worktree [y,n,q,a,d%s,?]? "
+msgstr "Áp dụng khúc này vào cây làm việc [y,n,q,a,d%s,?]? "
+
+#: git-add--interactive.perl:1570
+msgid "No other hunks to goto\n"
+msgstr "Không còn khúc nào để mà nhảy đến\n"
 
-#: git-add--interactive.perl:1540
+#: git-add--interactive.perl:1588
 #, perl-format
 msgid "Invalid number: '%s'\n"
 msgstr "Số không hợp lệ: “%s”\n"
 
-#: git-add--interactive.perl:1545
+#: git-add--interactive.perl:1593
 #, perl-format
 msgid "Sorry, only %d hunk available.\n"
 msgid_plural "Sorry, only %d hunks available.\n"
-msgstr[0] "Rất tiếc, chỉ có sẵn %d hunk..\n"
+msgstr[0] "Rất tiếc, chỉ có sẵn %d khúc.\n"
 
-#: git-add--interactive.perl:1571
+#: git-add--interactive.perl:1619
 msgid "No other hunks to search\n"
-msgstr "Không còn hunk nào để mà tìm kiếm\n"
+msgstr "Không còn khúc nào để mà tìm kiếm\n"
 
-#: git-add--interactive.perl:1575
-msgid "search for regex? "
-msgstr "tìm kiếm cho regex? "
-
-#: git-add--interactive.perl:1588
+#: git-add--interactive.perl:1636
 #, perl-format
 msgid "Malformed search regexp %s: %s\n"
 msgstr "Định dạng tìm kiếm của biểu thức chính quy không đúng %s: %s\n"
 
-#: git-add--interactive.perl:1598
+#: git-add--interactive.perl:1646
 msgid "No hunk matches the given pattern\n"
-msgstr "Không thấy hunk nào khớp mẫu đã cho\n"
+msgstr "Không thấy khúc nào khớp mẫu đã cho\n"
 
-#: git-add--interactive.perl:1610 git-add--interactive.perl:1632
+#: git-add--interactive.perl:1658 git-add--interactive.perl:1680
 msgid "No previous hunk\n"
-msgstr "Không có hunk kế trước\n"
+msgstr "Không có khúc kế trước\n"
 
-#: git-add--interactive.perl:1619 git-add--interactive.perl:1638
+#: git-add--interactive.perl:1667 git-add--interactive.perl:1686
 msgid "No next hunk\n"
-msgstr "Không có hunk kế tiếp\n"
+msgstr "Không có khúc kế tiếp\n"
 
-#: git-add--interactive.perl:1644
+#: git-add--interactive.perl:1692
 msgid "Sorry, cannot split this hunk\n"
-msgstr "Rất tiếc, không thể chia nhỏ hunk này\n"
+msgstr "Rất tiếc, không thể chia nhỏ khúc này\n"
 
-#: git-add--interactive.perl:1650
+#: git-add--interactive.perl:1698
 #, perl-format
 msgid "Split into %d hunk.\n"
 msgid_plural "Split into %d hunks.\n"
-msgstr[0] "Chi nhỏ thành %d hunks.\n"
+msgstr[0] "Chi nhỏ thành %d khúc.\n"
 
-#: git-add--interactive.perl:1660
+#: git-add--interactive.perl:1708
 msgid "Sorry, cannot edit this hunk\n"
-msgstr "Rất tiếc, không thể sửa hunk này\n"
-
-#: git-add--interactive.perl:1706
-msgid "Review diff"
-msgstr "Xem xét lại diff"
+msgstr "Rất tiếc, không thể sửa khúc này\n"
 
 #. TRANSLATORS: please do not translate the command names
 #. 'status', 'update', 'revert', etc.
-#: git-add--interactive.perl:1725
+#: git-add--interactive.perl:1773
 msgid ""
 "status        - show paths with changes\n"
 "update        - add working tree state to the staged set of changes\n"
@@ -17839,59 +23941,60 @@ msgstr ""
 "đặt lên bệ phóng\n"
 "revert        - hoàn nguyên tập hợp các thay đổi đã đặt lên bệ phóng trở lại "
 "phiên bản HEAD\n"
-"patch         - cậy các hunk và cập nhật có lựa chọn\n"
+"patch         - cậy các khúc và cập nhật có lựa chọn\n"
 "diff\t      - xem khác biệt giữa HEAD và mục lục\n"
 "add untracked - thêm nội dung các các tập tin chưa theo dõi và tập hợp các "
 "thay đổi đã đặt lên bệ phóng\n"
 
-#: git-add--interactive.perl:1742 git-add--interactive.perl:1747
-#: git-add--interactive.perl:1750 git-add--interactive.perl:1757
-#: git-add--interactive.perl:1761 git-add--interactive.perl:1767
+#: git-add--interactive.perl:1790 git-add--interactive.perl:1795
+#: git-add--interactive.perl:1798 git-add--interactive.perl:1805
+#: git-add--interactive.perl:1808 git-add--interactive.perl:1815
+#: git-add--interactive.perl:1819 git-add--interactive.perl:1825
 msgid "missing --"
 msgstr "thiếu --"
 
-#: git-add--interactive.perl:1763
+#: git-add--interactive.perl:1821
 #, perl-format
 msgid "unknown --patch mode: %s"
 msgstr "không hiểu chế độ --patch: %s"
 
-#: git-add--interactive.perl:1769 git-add--interactive.perl:1775
+#: git-add--interactive.perl:1827 git-add--interactive.perl:1833
 #, perl-format
 msgid "invalid argument %s, expecting --"
 msgstr "đối số không hợp lệ %s, cần --"
 
-#: git-send-email.perl:130
+#: git-send-email.perl:138
 msgid "local zone differs from GMT by a non-minute interval\n"
 msgstr "múi giờ nội bộ khác biệt với GMT bởi khoảng thời gian không-phút\n"
 
-#: git-send-email.perl:137 git-send-email.perl:143
+#: git-send-email.perl:145 git-send-email.perl:151
 msgid "local time offset greater than or equal to 24 hours\n"
 msgstr "khoảng bù thời gian nội bộ lớn hơn hoặc bằng 24 giờ\n"
 
-#: git-send-email.perl:211 git-send-email.perl:217
+#: git-send-email.perl:223 git-send-email.perl:229
 msgid "the editor exited uncleanly, aborting everything"
 msgstr "trình soạn thảo thoát không sạch sẽ, bãi bỏ mọi thứ"
 
-#: git-send-email.perl:294
+#: git-send-email.perl:310
 #, perl-format
 msgid ""
 "'%s' contains an intermediate version of the email you were composing.\n"
 msgstr "“%s” có chưa một phiên bản trung gian của thư bạn đã soạn.\n"
 
-#: git-send-email.perl:299
+#: git-send-email.perl:315
 #, perl-format
 msgid "'%s.final' contains the composed email.\n"
 msgstr "“%s.final” chứa thư điện tử đã soạn thảo.\n"
 
-#: git-send-email.perl:317
+#: git-send-email.perl:408
 msgid "--dump-aliases incompatible with other options\n"
 msgstr "--dump-aliases xung khắc với các tùy chọn khác\n"
 
-#: git-send-email.perl:383 git-send-email.perl:638
+#: git-send-email.perl:481 git-send-email.perl:683
 msgid "Cannot run git format-patch from outside a repository\n"
 msgstr "Không thể chạy git format-patch ở ngoài một kho chứa\n"
 
-#: git-send-email.perl:386
+#: git-send-email.perl:484
 msgid ""
 "`batch-size` and `relogin` must be specified together (via command-line or "
 "configuration option)\n"
@@ -17899,37 +24002,37 @@ msgstr ""
 "“batch-size” và “relogin” phải được chỉ định cùng với nhau (thông qua dòng "
 "lệnh hoặc tùy chọn cấu hình)\n"
 
-#: git-send-email.perl:456
+#: git-send-email.perl:497
 #, perl-format
 msgid "Unknown --suppress-cc field: '%s'\n"
 msgstr "Không hiểu trường --suppress-cc: “%s”\n"
 
-#: git-send-email.perl:485
+#: git-send-email.perl:528
 #, perl-format
 msgid "Unknown --confirm setting: '%s'\n"
 msgstr "Không hiểu cài đặt --confirm: “%s”\n"
 
-#: git-send-email.perl:513
+#: git-send-email.perl:556
 #, perl-format
 msgid "warning: sendmail alias with quotes is not supported: %s\n"
 msgstr "cảnh báo: bí danh sendmail với dấu trích dẫn không được hỗ trợ: %s\n"
 
-#: git-send-email.perl:515
+#: git-send-email.perl:558
 #, perl-format
 msgid "warning: `:include:` not supported: %s\n"
 msgstr "cảnh báo: “:include:“ không được hỗ trợ: %s\n"
 
-#: git-send-email.perl:517
+#: git-send-email.perl:560
 #, perl-format
 msgid "warning: `/file` or `|pipe` redirection not supported: %s\n"
 msgstr "cảnh báo: chuyển hướng “/file“ hay “|pipe“ không được hỗ trợ: %s\n"
 
-#: git-send-email.perl:522
+#: git-send-email.perl:565
 #, perl-format
 msgid "warning: sendmail line is not recognized: %s\n"
 msgstr "cảnh báo: dòng sendmail không nhận ra được: %s\n"
 
-#: git-send-email.perl:604
+#: git-send-email.perl:649
 #, perl-format
 msgid ""
 "File '%s' exists but it could also be the range of commits\n"
@@ -17944,12 +24047,12 @@ msgstr ""
 "    * Nói \"./%s\" nếu ý bạn là một tập tin; hoặc\n"
 "    * Đưa ra tùy chọn --format-patch nếu ý bạn là chuẩn bị.\n"
 
-#: git-send-email.perl:625
+#: git-send-email.perl:670
 #, perl-format
 msgid "Failed to opendir %s: %s"
 msgstr "Gặp lỗi khi mở thư mục “%s”: %s"
 
-#: git-send-email.perl:649
+#: git-send-email.perl:694
 #, perl-format
 msgid ""
 "fatal: %s: %s\n"
@@ -17958,7 +24061,7 @@ msgstr ""
 "nghiêm trọng: %s: %s\n"
 "cảnh báo: không có miếng vá nào được gửi đi\n"
 
-#: git-send-email.perl:660
+#: git-send-email.perl:705
 msgid ""
 "\n"
 "No patch files specified!\n"
@@ -17968,17 +24071,17 @@ msgstr ""
 "Chưa chỉ định các tập tin miếng vá!\n"
 "\n"
 
-#: git-send-email.perl:673
+#: git-send-email.perl:718
 #, perl-format
 msgid "No subject line in %s?"
 msgstr "Không có dòng chủ đề trong %s?"
 
-#: git-send-email.perl:683
+#: git-send-email.perl:728
 #, perl-format
 msgid "Failed to open for writing %s: %s"
 msgstr "Gặp lỗi khi mở “%s” để ghi: %s"
 
-#: git-send-email.perl:694
+#: git-send-email.perl:739
 msgid ""
 "Lines beginning in \"GIT:\" will be removed.\n"
 "Consider including an overall diffstat or table of contents\n"
@@ -17992,27 +24095,27 @@ msgstr ""
 "\n"
 "Xóa nội dung phần thân nếu bạn không muốn gửi tóm tắt.\n"
 
-#: git-send-email.perl:718
+#: git-send-email.perl:763
 #, perl-format
 msgid "Failed to open %s: %s"
 msgstr "Gặp lỗi khi mở “%s”: %s"
 
-#: git-send-email.perl:735
+#: git-send-email.perl:780
 #, perl-format
 msgid "Failed to open %s.final: %s"
 msgstr "Gặp lỗi khi mở %s.final: %s"
 
-#: git-send-email.perl:778
+#: git-send-email.perl:823
 msgid "Summary email is empty, skipping it\n"
 msgstr "Thư tổng thể là trống rỗng, nên bỏ qua nó\n"
 
 #. TRANSLATORS: please keep [y/N] as is.
-#: git-send-email.perl:813
+#: git-send-email.perl:858
 #, perl-format
 msgid "Are you sure you want to use <%s> [y/N]? "
 msgstr "Bạn có chắc muốn dùng <%s> [y/N]? "
 
-#: git-send-email.perl:868
+#: git-send-email.perl:913
 msgid ""
 "The following files are 8bit, but do not declare a Content-Transfer-"
 "Encoding.\n"
@@ -18020,11 +24123,11 @@ msgstr ""
 "Các trường sau đây là 8bit, nhưng không khai báo một Content-Transfer-"
 "Encoding.\n"
 
-#: git-send-email.perl:873
+#: git-send-email.perl:918
 msgid "Which 8bit encoding should I declare [UTF-8]? "
 msgstr "Bảng mã 8bit nào tôi nên khai báo [UTF-8]? "
 
-#: git-send-email.perl:881
+#: git-send-email.perl:926
 #, perl-format
 msgid ""
 "Refusing to send because the patch\n"
@@ -18037,20 +24140,20 @@ msgstr ""
 "có chủ đề ở dạng mẫu “*** SUBJECT HERE ***”. Dùng --force nếu bạn thực sự "
 "muốn gửi.\n"
 
-#: git-send-email.perl:900
+#: git-send-email.perl:945
 msgid "To whom should the emails be sent (if anyone)?"
 msgstr "Tới người mà thư được gửi (nếu có)?"
 
-#: git-send-email.perl:918
+#: git-send-email.perl:963
 #, perl-format
 msgid "fatal: alias '%s' expands to itself\n"
 msgstr "nghiêm trọng: bí danh “%s” được khai triển thành chính nó\n"
 
-#: git-send-email.perl:930
+#: git-send-email.perl:975
 msgid "Message-ID to be used as In-Reply-To for the first email (if any)? "
 msgstr "Message-ID được dùng như là In-Reply-To cho thư đầu tiên (nếu có)? "
 
-#: git-send-email.perl:988 git-send-email.perl:996
+#: git-send-email.perl:1033 git-send-email.perl:1041
 #, perl-format
 msgid "error: unable to extract a valid address from: %s\n"
 msgstr "lỗi: không thể rút trích một địa chỉ hợp lệ từ: %s\n"
@@ -18058,16 +24161,16 @@ msgstr "lỗi: không thể rút trích
 #. TRANSLATORS: Make sure to include [q] [d] [e] in your
 #. translation. The program will only accept English input
 #. at this point.
-#: git-send-email.perl:1000
+#: git-send-email.perl:1045
 msgid "What to do with this address? ([q]uit|[d]rop|[e]dit): "
 msgstr "Làm gì với địa chỉ này? (thoát[q]|xóa[d]|sửa[e]): "
 
-#: git-send-email.perl:1317
+#: git-send-email.perl:1362
 #, perl-format
 msgid "CA path \"%s\" does not exist"
-msgstr "đường dẫn CA “%s” không tồn tại"
+msgstr "Đường dẫn CA “%s” không tồn tại"
 
-#: git-send-email.perl:1400
+#: git-send-email.perl:1445
 msgid ""
 "    The Cc list above has been expanded by additional\n"
 "    addresses found in the patch commit message. By default\n"
@@ -18094,134 +24197,492 @@ msgstr ""
 #. TRANSLATORS: Make sure to include [y] [n] [e] [q] [a] in your
 #. translation. The program will only accept English input
 #. at this point.
-#: git-send-email.perl:1415
+#: git-send-email.perl:1460
 msgid "Send this email? ([y]es|[n]o|[e]dit|[q]uit|[a]ll): "
 msgstr "Gửi thư này chứ? ([y]có|[n]không|[e]sửa|[q]thoát|[a]tất): "
 
-#: git-send-email.perl:1418
+#: git-send-email.perl:1463
 msgid "Send this email reply required"
 msgstr "Gửi thư này trả lời yêu cầu"
 
-#: git-send-email.perl:1446
+#: git-send-email.perl:1491
 msgid "The required SMTP server is not properly defined."
 msgstr "Máy phục vụ SMTP chưa được định nghĩa một cách thích hợp."
 
-#: git-send-email.perl:1493
+#: git-send-email.perl:1538
 #, perl-format
 msgid "Server does not support STARTTLS! %s"
 msgstr "Máy chủ không hỗ trợ STARTTLS! %s"
 
-#: git-send-email.perl:1498 git-send-email.perl:1502
+#: git-send-email.perl:1543 git-send-email.perl:1547
 #, perl-format
 msgid "STARTTLS failed! %s"
 msgstr "STARTTLS gặp lỗi! %s"
 
-#: git-send-email.perl:1512
+#: git-send-email.perl:1556
 msgid "Unable to initialize SMTP properly. Check config and use --smtp-debug."
 msgstr ""
 "Không thể khởi tạo SMTP một cách đúng đắn. Kiểm tra cấu hình và dùng --smtp-"
 "debug."
 
-#: git-send-email.perl:1530
+#: git-send-email.perl:1574
 #, perl-format
 msgid "Failed to send %s\n"
 msgstr "Gặp lỗi khi gửi %s\n"
 
-#: git-send-email.perl:1533
+#: git-send-email.perl:1577
 #, perl-format
 msgid "Dry-Sent %s\n"
 msgstr "Thử gửi %s\n"
 
-#: git-send-email.perl:1533
+#: git-send-email.perl:1577
 #, perl-format
 msgid "Sent %s\n"
 msgstr "Gửi %s\n"
 
-#: git-send-email.perl:1535
+#: git-send-email.perl:1579
 msgid "Dry-OK. Log says:\n"
 msgstr "Dry-OK. Nhật ký nói rằng:\n"
 
-#: git-send-email.perl:1535
+#: git-send-email.perl:1579
 msgid "OK. Log says:\n"
 msgstr "OK. Nhật ký nói rằng:\n"
 
-#: git-send-email.perl:1547
+#: git-send-email.perl:1591
 msgid "Result: "
 msgstr "Kết quả: "
 
-#: git-send-email.perl:1550
+#: git-send-email.perl:1594
 msgid "Result: OK\n"
 msgstr "Kết quả: Tốt\n"
 
-#: git-send-email.perl:1568
+#: git-send-email.perl:1612
 #, perl-format
 msgid "can't open file %s"
 msgstr "không thể mở tập tin “%s”"
 
-#: git-send-email.perl:1615 git-send-email.perl:1635
+#: git-send-email.perl:1659 git-send-email.perl:1679
 #, perl-format
 msgid "(mbox) Adding cc: %s from line '%s'\n"
 msgstr "(mbox) Thêm cc: %s từ dòng “%s”\n"
 
-#: git-send-email.perl:1621
+#: git-send-email.perl:1665
 #, perl-format
 msgid "(mbox) Adding to: %s from line '%s'\n"
 msgstr "(mbox) Đang thêm to: %s từ dòng “%s”\n"
 
-#: git-send-email.perl:1674
+#: git-send-email.perl:1718
 #, perl-format
 msgid "(non-mbox) Adding cc: %s from line '%s'\n"
 msgstr "(non-mbox) Thêm cc: %s từ dòng “%s”\n"
 
-#: git-send-email.perl:1699
+#: git-send-email.perl:1753
 #, perl-format
 msgid "(body) Adding cc: %s from line '%s'\n"
 msgstr "(body) Thêm cc: %s từ dòng “%s”\n"
 
-#: git-send-email.perl:1817
+#: git-send-email.perl:1864
 #, perl-format
 msgid "(%s) Could not execute '%s'"
 msgstr "(%s) Không thể thực thi “%s”"
 
-#: git-send-email.perl:1824
+#: git-send-email.perl:1871
 #, perl-format
 msgid "(%s) Adding %s: %s from: '%s'\n"
 msgstr "(%s) Đang thêm %s: %s từ: “%s”\n"
 
-#: git-send-email.perl:1828
+#: git-send-email.perl:1875
 #, perl-format
 msgid "(%s) failed to close pipe to '%s'"
 msgstr "(%s) gặp lỗi khi đóng đường ống đến “%s”"
 
-#: git-send-email.perl:1855
+#: git-send-email.perl:1905
 msgid "cannot send message as 7bit"
 msgstr "không thể lấy gửi thư dạng 7 bít"
 
-#: git-send-email.perl:1863
+#: git-send-email.perl:1913
 msgid "invalid transfer encoding"
 msgstr "bảng mã truyền không hợp lệ"
 
-#: git-send-email.perl:1901 git-send-email.perl:1952 git-send-email.perl:1962
+#: git-send-email.perl:1954 git-send-email.perl:2006 git-send-email.perl:2016
 #, perl-format
 msgid "unable to open %s: %s\n"
 msgstr "không thể mở %s: %s\n"
 
-#: git-send-email.perl:1904
+#: git-send-email.perl:1957
 #, perl-format
 msgid "%s: patch contains a line longer than 998 characters"
 msgstr "%s: miếng vá có chứa dòng dài hơn 998 ký tự"
 
-#: git-send-email.perl:1920
+#: git-send-email.perl:1974
 #, perl-format
 msgid "Skipping %s with backup suffix '%s'.\n"
 msgstr "Bỏ qua %s với hậu tố sao lưu dự phòng “%s”.\n"
 
 #. TRANSLATORS: please keep "[y|N]" as is.
-#: git-send-email.perl:1924
+#: git-send-email.perl:1978
 #, perl-format
 msgid "Do you really want to send %s? [y|N]: "
 msgstr "Bạn có thực sự muốn gửi %s? [y|N](có/KHÔNG): "
 
+#, c-format
+#~ msgid "unable to get tree for %s"
+#~ msgstr "không thể lấy cây cho %s"
+
+#~ msgid "Use an experimental heuristic to improve diffs"
+#~ msgstr "Dùng một phỏng đoán thử nghiệm để tăng cường các diff"
+
+#~ msgid "git commit-graph [--object-dir <objdir>]"
+#~ msgstr "git commit-graph [--object-dir <objdir>]"
+
+#~ msgid "git commit-graph read [--object-dir <objdir>]"
+#~ msgstr "git commit-graph read [--object-dir <objdir>]"
+
+#, c-format
+#~ msgid "unknown core.untrackedCache value '%s'; using 'keep' default value"
+#~ msgstr ""
+#~ "không hiểu giá trị core.untrackedCache “%s”; dùng giá trị mặc định “keep”"
+
+#~ msgid "cannot change partial clone promisor remote"
+#~ msgstr "không thể thay đổi nhân bản từng phần máy chủ promisor"
+
+#~ msgid "error building trees"
+#~ msgstr "gặp lỗi khi xây dựng cây"
+
+#, c-format
+#~ msgid "invalid date format '%s' in '%s'"
+#~ msgstr "định dạng ngày tháng không hợp lệ “%s” trong “%s”"
+
+#~ msgid "writing root commit"
+#~ msgstr "ghi chuyển giao gốc"
+
+#, c-format
+#~ msgid "staged changes in the following files may be lost: %s"
+#~ msgstr ""
+#~ "các thay đổi đã đưa lên bệ phóng trong các tập tin sau đây có thể bị mất: "
+#~ "%s"
+
+#~ msgid ""
+#~ "--filter can only be used with the remote configured in extensions."
+#~ "partialClone"
+#~ msgstr ""
+#~ "--filter chỉ có thể được dùng với máy chủ được cấu hình bằng extensions."
+#~ "partialClone"
+
+#~ msgid "verify commit-msg hook"
+#~ msgstr "thẩm tra móc (hook) commit-msg"
+
+#~ msgid "cannot combine '--rebase-merges' with '--strategy-option'"
+#~ msgstr "không thể kết hợp “--rebase-merges” với “--strategy-option”"
+
+#, c-format
+#~ msgid "invalid sparse value '%s'"
+#~ msgstr "giá trị sparse không hợp lệ “%s”"
+
+#~ msgid ""
+#~ "Fetch normally indicates which branches had a forced update, but that "
+#~ "check has been disabled."
+#~ msgstr ""
+#~ "Lấy về bình thường cho biết các các nhánh nào buộc phải cập nhật, nhưng "
+#~ "việc kiểm tra đã bị vô hiệu hóa."
+
+#~ msgid ""
+#~ "or run 'git config fetch.showForcedUpdates false' to avoid this check.\n"
+#~ msgstr ""
+#~ "hoặc chạy 'git config fetch.showForcedUpdates false' để tránh kiểm tra "
+#~ "này.\n"
+
+#~ msgid ""
+#~ "log.mailmap is not set; its implicit value will change in an\n"
+#~ "upcoming release. To squelch this message and preserve current\n"
+#~ "behaviour, set the log.mailmap configuration value to false.\n"
+#~ "\n"
+#~ "To squelch this message and adopt the new behaviour now, set the\n"
+#~ "log.mailmap configuration value to true.\n"
+#~ "\n"
+#~ "See 'git help config' and search for 'log.mailmap' for further "
+#~ "information."
+#~ msgstr ""
+#~ "log.mailmap không được đặt; giá trị ngầm của nó sẽ thay đổi trong một\n"
+#~ "phát hành sắp tới. Để chấm dứt thông báo này và duy trì hành xử\n"
+#~ "hiện tại, đặt giá trị cấu hình log.mailmap thành false.\n"
+#~ "\n"
+#~ "Để làm chấm dứt thông báo này và áp cách hành xử mới, hãy đặt\n"
+#~ "giá trị cấu hình log.mailmap true.\n"
+#~ "\n"
+#~ "Xem 'git help config ' và tìm kiếm ' log.mailmap ' để biết thêm thông tin."
+
+#~ msgid "Server supports multi_ack_detailed"
+#~ msgstr "Máy chủ hỗ trợ multi_ack_detailed"
+
+#~ msgid "Server supports no-done"
+#~ msgstr "Máy chủ hỗ trợ no-done"
+
+#~ msgid "Server supports multi_ack"
+#~ msgstr "Máy chủ hỗ trợ multi_ack"
+
+#~ msgid "Server supports side-band-64k"
+#~ msgstr "Máy chủ hỗ trợ side-band-64k"
+
+#~ msgid "Server supports side-band"
+#~ msgstr "Máy chủ hỗ trợ side-band"
+
+#~ msgid "Server supports allow-tip-sha1-in-want"
+#~ msgstr "Máy chủ hỗ trợ allow-tip-sha1-in-want"
+
+#~ msgid "Server supports allow-reachable-sha1-in-want"
+#~ msgstr "Máy chủ hỗ trợ allow-reachable-sha1-in-want"
+
+#~ msgid "Server supports ofs-delta"
+#~ msgstr "Máy chủ hỗ trợ ofs-delta"
+
+#~ msgid "(HEAD detached at %s)"
+#~ msgstr "(HEAD được tách rời tại %s)"
+
+#~ msgid "(HEAD detached from %s)"
+#~ msgstr "(HEAD được tách rời từ %s)"
+
+#~ msgid "Checking out files"
+#~ msgstr "Đang lấy ra các tập tin"
+
+#~ msgid "cannot be interactive without stdin connected to a terminal."
+#~ msgstr ""
+#~ "không thể được tương tác mà không có stdin kết nối với một thiết bị cuối."
+
+#~ msgid "failed to stat %s\n"
+#~ msgstr "gặp lỗi khi lấy thông tin thống kê về %s\n"
+
+#~ msgid ""
+#~ "If you wish to skip this commit, use:\n"
+#~ "\n"
+#~ "    git reset\n"
+#~ "\n"
+#~ "Then \"git cherry-pick --continue\" will resume cherry-picking\n"
+#~ "the remaining commits.\n"
+#~ msgstr ""
+#~ "Nếu bạn muốn bỏ qua lần chuyển giao này thì dùng:\n"
+#~ "\n"
+#~ "    git reset\n"
+#~ "\n"
+#~ "Thế thì \"git cherry-pick --continue\" sẽ phục hồi lại việc cherry-pick\n"
+#~ "những lần chuyển giao còn lại.\n"
+
+#~ msgid "unrecognized verb: %s"
+#~ msgstr "verb không được thừa nhận: %s"
+
+#~ msgid "hash version %X does not match version %X"
+#~ msgstr "phiên bản băm “%X” không có phiên bản khớp %X"
+
+#~ msgid "option '%s' requires a value"
+#~ msgstr "tùy chọn “%s” yêu cầu một giá trị"
+
+#~ msgid "could not transform the todo list"
+#~ msgstr "không thể chuyển dạng danh sách cần làm"
+
+#~ msgid "default"
+#~ msgstr "mặc định"
+
+#~ msgid "Could not create directory '%s'"
+#~ msgstr "Không thể tạo thư mục “%s”"
+
+#~ msgid "allow rerere to update index with resolved conflict"
+#~ msgstr ""
+#~ "cho phép rerere cập nhật bảng mục lục với các xung đột đã được giải quyết"
+
+#~ msgid "could not open %s"
+#~ msgstr "không thể mở %s"
+
+#~ msgid "Could not move back to $head_name"
+#~ msgstr "Không thể quay trở lại $head_name"
+
+#~ msgid ""
+#~ "It seems that there is already a $state_dir_base directory, and\n"
+#~ "I wonder if you are in the middle of another rebase.  If that is the\n"
+#~ "case, please try\n"
+#~ "\t$cmd_live_rebase\n"
+#~ "If that is not the case, please\n"
+#~ "\t$cmd_clear_stale_rebase\n"
+#~ "and run me again.  I am stopping in case you still have something\n"
+#~ "valuable there."
+#~ msgstr ""
+#~ "Hình như là ở đây sẵn có một thư mục $state_dir_base, và\n"
+#~ "Tôi tự hỏi có phải bạn đang ở giữa một lệnh rebase khác. Nếu đúng là\n"
+#~ "như vậy, xin hãy thử\n"
+#~ "\t$cmd_live_rebase\n"
+#~ "Nếu không phải thế, hãy thử\n"
+#~ "\t$cmd_clear_stale_rebase\n"
+#~ "và chạy TÔI lần nữa. TÔI  dừng lại trong trường hợp bạn vẫn\n"
+#~ "có một số thứ quý giá ở đây."
+
+#~ msgid ""
+#~ "fatal: cannot combine am options with either interactive or merge options"
+#~ msgstr ""
+#~ "lỗi nghiêm trọng: không thể tổ hợp các tùy chọn am với các tùy chọn tương "
+#~ "tác hay hòa trộn"
+
+#~ msgid "fatal: cannot combine '--signoff' with '--preserve-merges'"
+#~ msgstr ""
+#~ "lỗi nghiêm trọng: không thể kết hợp “--signoff” với “--preserve-merges”"
+
+#~ msgid "fatal: cannot combine '--preserve-merges' with '--rebase-merges'"
+#~ msgstr ""
+#~ "lỗi nghiêm trọng: không thể kết hợp “--preserve-merges” với “--rebase-"
+#~ "merges”"
+
+#~ msgid "fatal: cannot combine '--rebase-merges' with '--strategy-option'"
+#~ msgstr ""
+#~ "lỗi nghiêm trọng: không thể kết hợp “--rebase-merges” với “--strategy-"
+#~ "option”"
+
+#~ msgid "fatal: cannot combine '--rebase-merges' with '--strategy'"
+#~ msgstr ""
+#~ "lỗi nghiêm trọng: không thể kết hợp “--rebase-merges” với “--strategy”"
+
+#~ msgid "invalid upstream '$upstream_name'"
+#~ msgstr "thượng nguồn không hợp lệ “$upstream_name”"
+
+#~ msgid "$onto_name: there are more than one merge bases"
+#~ msgstr "$onto_name: ở đây có nhiều hơn một nền móng hòa trộn"
+
+#~ msgid "$onto_name: there is no merge base"
+#~ msgstr "$onto_name: ở đây không có nền móng hòa trộn nào"
+
+#~ msgid "Does not point to a valid commit: $onto_name"
+#~ msgstr "Không chỉ đến một lần chuyển giao không hợp lệ: $onto_name"
+
+#~ msgid "fatal: no such branch/commit '$branch_name'"
+#~ msgstr "nghiêm trọng: không có nhánh như thế: “$branch_name”"
+
+#~ msgid "Created autostash: $stash_abbrev"
+#~ msgstr "Đã tạo autostash: $stash_abbrev"
+
+#~ msgid "Current branch $branch_name is up to date."
+#~ msgstr "Nhánh hiện tại $branch_name đã được cập nhật rồi."
+
+#~ msgid "Current branch $branch_name is up to date, rebase forced."
+#~ msgstr ""
+#~ "Nhánh hiện tại $branch_name đã được cập nhật rồi, lệnh rebase ép buộc."
+
+#~ msgid "Changes to $onto:"
+#~ msgstr "Thay đổi thành $onto:"
+
+#~ msgid "Changes from $mb to $onto:"
+#~ msgstr "Thay đổi từ $mb thành $onto:"
+
+#~ msgid "Fast-forwarded $branch_name to $onto_name."
+#~ msgstr "Chuyển-tiếp-nhanh $branch_name thành $onto_name."
+
+#~ msgid "First, rewinding head to replay your work on top of it..."
+#~ msgstr ""
+#~ "Trước tiên, di chuyển head để xem lại các công việc trên đỉnh của nó…"
+
+#~ msgid "ignoring unknown color-moved-ws mode '%s'"
+#~ msgstr "bỏ qua chế độ color-moved-ws chưa biết “%s”"
+
+#~ msgid "only 'tree:0' is supported"
+#~ msgstr "chỉ “tree:0” là được hỗ trợ"
+
+#~ msgid "Renaming %s to %s and %s to %s instead"
+#~ msgstr "Đang đổi tên %s thành %s thay vì %s thành %s"
+
+#~ msgid "Adding merged %s"
+#~ msgstr "Thêm hòa trộn %s"
+
+#~ msgid "Internal error"
+#~ msgstr "Lỗi nội bộ"
+
+#~ msgid "mainline was specified but commit %s is not a merge."
+#~ msgstr ""
+#~ "luồng chính đã được chỉ ra nhưng lần chuyển giao %s không phải là một lần "
+#~ "hòa trộn."
+
+#~ msgid "unable to write sha1 filename %s"
+#~ msgstr "không thể ghi vào tên tập tin sha1 %s"
+
+#~ msgid "cannot read sha1_file for %s"
+#~ msgstr "không thể đọc sha1_file cho %s"
+
+#~ msgid ""
+#~ "error: cannot combine interactive options (--interactive, --exec, --"
+#~ "rebase-merges, --preserve-merges, --keep-empty, --root + --onto) with am "
+#~ "options (%s)"
+#~ msgstr ""
+#~ "lỗi: không thể tổ hợp các tùy chọn tương tác (--interactive, --exec, --"
+#~ "rebase-merges, --preserve-merges, --keep-empty, --root + --onto) với các "
+#~ "tùy chọn am (%s)"
+
+#~ msgid ""
+#~ "error: cannot combine merge options (--merge, --strategy, --strategy-"
+#~ "option) with am options (%s)"
+#~ msgstr ""
+#~ "lỗi: không thể kết hợp các tùy chọn hòa trộn (--merge, --strategy, --"
+#~ "strategy-option) với một tùy chọn am (%s)"
+
+#~ msgid "unrecognised option: '$arg'"
+#~ msgstr "không công nhận tùy chọn: “$arg”"
+
+#~ msgid "'$invalid' is not a valid commit"
+#~ msgstr "”$invalid” không phải là lần chuyển giao hợp lệ"
+
+#~ msgid "could not parse '%s' (looking for '%s')"
+#~ msgstr "không thể phân tích “%s” (đang tìm kiếm cho “%s”)"
+
+#~ msgid "deprecated synonym for --create-reflog"
+#~ msgstr "đồng nghĩa đã lạc hậu cho --create-reflog"
+
+#~ msgid "Can't stat %s"
+#~ msgstr "không thể lấy thông tin thống kê về “%s”"
+
+#~ msgid "abort rebase"
+#~ msgstr "bãi bỏ việc cải tổ"
+
+#~ msgid "make rebase script"
+#~ msgstr "tạo văn lệnh rebase"
+
+#~ msgid "No such remote: %s"
+#~ msgstr "Không có máy chủ nào như thế: %s"
+
+#~ msgid "cannot move a locked working tree"
+#~ msgstr "không thể di chuyển một cây-làm-việc bị khóa"
+
+#~ msgid "cannot remove a locked working tree"
+#~ msgstr "không thể gỡ bỏ một cây-làm-việc bị khóa"
+
+#~ msgid ""
+#~ "\n"
+#~ "\tHowever, if you remove everything, the rebase will be aborted.\n"
+#~ "\n"
+#~ "\t"
+#~ msgstr ""
+#~ "\n"
+#~ "\tTuy nhiên, nếu bạn xóa bỏ mọi thứ, việc cải tổ sẽ bị bãi bỏ.\n"
+#~ "\n"
+#~ "\t"
+
+#~ msgid "could not parse '%s' (looking for '%s'"
+#~ msgstr "không thể phân tích “%s” (tìm kiếm cho “%s”"
+
+#~ msgid "push|fetch"
+#~ msgstr "push|fetch"
+
+#~ msgid "Dirty index: cannot merge (dirty: %s)"
+#~ msgstr "Bảng mục lục bẩn: không thể hòa trộn (bẩn: %s)"
+
+#~ msgid "(+/-)x"
+#~ msgstr "(+/-)x"
+
+#~ msgid "<command>"
+#~ msgstr "<lệnh>"
+
+#~ msgid "w[,i1[,i2]]"
+#~ msgstr "w[,i1[,i2]]"
+
+#~ msgid "Entering '$displaypath'"
+#~ msgstr "Đang vào “$displaypath”"
+
+#~ msgid "Stopping at '$displaypath'; script returned non-zero status."
+#~ msgstr "Dừng lại tại “$displaypath”; script trả về trạng thái khác không."
+
 #~ msgid "Everyday Git With 20 Commands Or So"
 #~ msgstr "Mỗi ngày học 20 lệnh Git hay hơn"
 
@@ -18278,18 +24739,9 @@ msgstr "Bạn có thực sự muốn g
 #~ "chuỗi rỗng làm đặc tả đường dẫn không hợp lệ ở lần phát hành kế tiếp. Vui "
 #~ "lòng dùng . để thay thế nếu ý bạn là khớp mọi đường dẫn"
 
-#~ msgid "unable to open '%s' for writing"
-#~ msgstr "không thể mở “%s” để ghi"
-
 #~ msgid "could not truncate '%s'"
 #~ msgstr "không thể cắt cụt “%s”"
 
-#~ msgid "could not finish '%s'"
-#~ msgstr "không thể hoàn thành “%s”"
-
-#~ msgid "could not write to %s"
-#~ msgstr "không thể ghi vào %s"
-
 #~ msgid "could not close %s"
 #~ msgstr "không thể đóng %s"
 
@@ -18302,12 +24754,6 @@ msgstr "Bạn có thực sự muốn g
 #~ msgid "Don't know how to clone %s"
 #~ msgstr "Không biết làm cách nào để nhân bản (clone) %s"
 
-#~ msgid "show ignored files"
-#~ msgstr "hiển thị các tập tin ẩn"
-
-#~ msgid "%s is not a valid '%s' object"
-#~ msgstr "%s không phải là một đối tượng “%s” hợp lệ"
-
 #~ msgid "Don't know how to fetch from %s"
 #~ msgstr "Không biết làm cách nào để lấy về từ %s"
 
@@ -18347,9 +24793,6 @@ msgstr "Bạn có thực sự muốn g
 #~ msgid "basename"
 #~ msgstr "tên cơ sở"
 
-#~ msgid "prepend parent project's basename to output"
-#~ msgstr "treo vào trước tên cơ sở cha mẹ của đường dẫn vào kết xuất"
-
 #~ msgid ""
 #~ "When you have resolved this problem, run \"git rebase --continue\".\n"
 #~ "If you prefer to skip this patch, run \"git rebase --skip\" instead.\n"
@@ -18389,9 +24832,6 @@ msgstr "Bạn có thực sự muốn g
 #~ msgid_plural "%s, %"
 #~ msgstr[0] "%s, %"
 
-#~ msgid "Could not open file '%s'"
-#~ msgstr "Không thể mở tập tin “%s”"
-
 #~ msgid "in %0.1f seconds automatically..."
 #~ msgstr "trong %0.1f giây một cách tự động…"
 
@@ -18434,9 +24874,6 @@ msgstr "Bạn có thực sự muốn g
 #~ msgid "tag: tagging "
 #~ msgstr "thẻ: đang đánh thẻ"
 
-#~ msgid "object of unknown type"
-#~ msgstr "đối tượng của kiểu chưa biết"
-
 #~ msgid "commit object"
 #~ msgstr "đối tượng lần chuyển giao"
 
@@ -18462,9 +24899,6 @@ msgstr "Bạn có thực sự muốn g
 #~ msgid "ref '%s' does not have %ld components to :strip"
 #~ msgstr "tham chiếu “%s” không có %ld thành phần để mà :strip"
 
-#~ msgid "unknown %.*s format %s"
-#~ msgstr "Không hiểu định dạng %.*s %s"
-
 #~ msgid "[%s: gone]"
 #~ msgstr "[%s: đã ra đi]"
 
@@ -18489,12 +24923,6 @@ msgstr "Bạn có thực sự muốn g
 #~ msgid "git merge [<options>] <msg> HEAD <commit>"
 #~ msgstr "git merge [<các-tùy-chọn>] <tin-nhắn> HEAD <commit>"
 
-#~ msgid "cannot open file '%s'"
-#~ msgstr "không thể mở tập tin “%s”"
-
-#~ msgid "could not close file %s"
-#~ msgstr "không thể đóng tập tin %s"
-
 #~ msgid "tag name too long: %.*s..."
 #~ msgstr "tên thẻ quá dài: %.*s…"
 
@@ -18547,24 +24975,15 @@ msgstr "Bạn có thực sự muốn g
 #~ msgstr ""
 #~ "Không thể thực hiện việc cherry-pick trong khi khi đang cherry-pick khác."
 
-#~ msgid "Could not parse line %d."
-#~ msgstr "Không phân tích được dòng %d."
-
 #~ msgid "Could not open %s"
 #~ msgstr "Không thể mở %s"
 
-#~ msgid "Could not read %s."
-#~ msgstr "Không thể đọc %s."
-
 #~ msgid "Could not format %s."
 #~ msgstr "Không thể định dạng “%s”."
 
 #~ msgid "%s: %s"
 #~ msgstr "%s: %s"
 
-#~ msgid "cannot open %s: %s"
-#~ msgstr "không thể mở %s: %s"
-
 #~ msgid "You need to set your committer info first"
 #~ msgstr "Bạn cần đặt thông tin về người chuyển giao mã nguồn trước đã"
 
@@ -18754,9 +25173,6 @@ msgstr "Bạn có thực sự muốn g
 #~ msgid "removing '%s' failed"
 #~ msgstr "gặp lỗi khi xóa bỏ “%s”"
 
-#~ msgid "program error"
-#~ msgstr "lỗi chương trình"
-
 #~ msgid "Please call 'bisect_state' with at least one argument."
 #~ msgstr "Hãy gọi lệnhl “bisect_state” với ít nhất một đối số."
 
@@ -18792,9 +25208,6 @@ msgstr "Bạn có thực sự muốn g
 #~ msgid "'%s': %s"
 #~ msgstr "“%s”: %s"
 
-#~ msgid "unable to access '%s': %s"
-#~ msgstr "không thể truy cập “%s”: %s"
-
 #~ msgid "    git branch -d %s\n"
 #~ msgstr "    git branch -d %s\n"
 
@@ -18812,9 +25225,6 @@ msgstr "Bạn có thực sự muốn g
 #~ msgid "failed to remove: %s"
 #~ msgstr "gặp lỗi khi gỡ bỏ: %s"
 
-#~ msgid "The --exec option must be used with the --interactive option"
-#~ msgstr "Tùy chọn --exec phải được sử dụng cùng với tùy chọn --interactive"
-
 #~ msgid ""
 #~ "Submodule path '$displaypath' not initialized\n"
 #~ "Maybe you want to use 'update --init'?"
@@ -18829,9 +25239,6 @@ msgstr "Bạn có thực sự muốn g
 #~ msgid "improper format entered align:%s"
 #~ msgstr "định dạng không đúng chỗ căn chỉnh:%s"
 
-#~ msgid "Could not set core.worktree in %s"
-#~ msgstr "Không thể đặt “core.worktree” trong “%s”."
-
 #~ msgid ""
 #~ "push.default is unset; its implicit value has changed in\n"
 #~ "Git 2.0 from 'matching' to 'simple'. To squelch this message\n"
@@ -18887,21 +25294,12 @@ msgstr "Bạn có thực sự muốn g
 #~ msgid "no such user"
 #~ msgstr "không có người dùng như vậy"
 
-#~ msgid "Missing author: %s"
-#~ msgstr "Thiếu tên tác giả: %s"
-
 #~ msgid "Testing "
 #~ msgstr "Đang thử"
 
 #~ msgid "branch '%s' does not point at a commit"
 #~ msgstr "nhánh “%s” không chỉ đến một lần chuyển giao nào cả"
 
-#~ msgid "object '%s' does not point to a commit"
-#~ msgstr "đối tượng “%s” không chỉ đến một lần chuyển giao nào cả"
-
-#~ msgid "some refs could not be read"
-#~ msgstr "một số tham chiếu đã không thể đọc được"
-
 #~ msgid "print only merged branches"
 #~ msgstr "chỉ hiển thị các nhánh đã hòa trộn"
 
@@ -18920,9 +25318,6 @@ msgstr "Bạn có thực sự muốn g
 #~ msgid "insanely long template path %s"
 #~ msgstr "đường dẫn mẫu “%s” dài một cách điên rồ"
 
-#~ msgid "insane git directory %s"
-#~ msgstr "thư mục git điên rồ %s"
-
 #~ msgid "unsupported sort specification '%s'"
 #~ msgstr "không hỗ trợ đặc tả sắp xếp “%s”"
 
@@ -18932,9 +25327,6 @@ msgstr "Bạn có thực sự muốn g
 #~ msgid "switch 'points-at' requires an object"
 #~ msgstr "chuyển đến “points-at” yêu cần một đối tượng"
 
-#~ msgid "sort tags"
-#~ msgstr "sắp xếp các thẻ"
-
 #~ msgid "--sort and -n are incompatible"
 #~ msgstr "--sort và -n xung khắc nhau"
 
@@ -18954,9 +25346,6 @@ msgstr "Bạn có thực sự muốn g
 #~ msgid "option %s does not accept negative form"
 #~ msgstr "tùy chọn %s không chấp nhận dạng thức âm"
 
-#~ msgid "unable to parse value '%s' for option %s"
-#~ msgstr "không thể phân tích giá trị “%s” cho tùy chọn %s"
-
 #~ msgid "-b and -B are mutually exclusive"
 #~ msgstr "-b và -B loại từ lẫn nhau."
 
@@ -19057,9 +25446,6 @@ msgstr "Bạn có thực sự muốn g
 #~ msgid "%s: cannot lock the ref"
 #~ msgstr "%s: không thể khóa ref (tham chiếu)"
 
-#~ msgid "%s: cannot update the ref"
-#~ msgstr "%s: không thể cập nhật ref (tham chiếu)"
-
 #~ msgid "Failed to lock HEAD during fast_forward_to"
 #~ msgstr "Gặp lỗi khi khóa HEAD trong quá trình fast_forward_to"
 
@@ -19242,25 +25628,12 @@ msgstr "Bạn có thực sự muốn g
 #~ msgid "git shortlog [-n] [-s] [-e] [-w] [rev-opts] [--] [<commit-id>... ]"
 #~ msgstr "git shortlog [-n] [-s] [-e] [-w] [rev-opts] [--] [<commit-id>… ]"
 
-#~ msgid "See 'git help <command>' for more information on a specific command."
-#~ msgstr ""
-#~ "Chạy lệnh “git help <tên-lệnh>” để có thêm thông tin về lệnh được chỉ ra."
-
 #~ msgid "use any ref in .git/refs"
 #~ msgstr "sử dụng bất kỳ ref nào trong .git/refs"
 
 #~ msgid "use any tag in .git/refs/tags"
 #~ msgstr "sử dụng bất kỳ thẻ nào trong .git/refs/tags"
 
-#~ msgid "bad object %s"
-#~ msgstr "đối tượng sai %s"
-
-#~ msgid "bogus committer info %s"
-#~ msgstr "thông tin người chuyển giao không có thực %s"
-
-#~ msgid "can't fdopen 'show' output fd"
-#~ msgstr "không thể fdopen “show” (lệnh hiển thị) mô tả tập tin (fd) kết xuất"
-
 #~ msgid "failed to close pipe to 'show' for object '%s'"
 #~ msgstr "gặp lỗi khi đóng đường ống cho lệnh “show” cho đối tượng “%s”"
 
@@ -19321,9 +25694,6 @@ msgstr "Bạn có thực sự muốn g
 #~ msgid "diff_setup_done failed"
 #~ msgstr "diff_setup_done gặp lỗi"
 
-#~ msgid "-d option is no longer supported.  Do not use."
-#~ msgstr "Tùy chọn -d không còn được hỗ trợ nữa. Xin đừng sử dụng."
-
 #~ msgid "%s: has been deleted/renamed"
 #~ msgstr "%s: đã được xóa/thay-tên"
 
diff -pruN 1.2.1+git2.18.0-1/git/po/zh_CN.po 1.2.3+git2.25.1-1/git/po/zh_CN.po
--- 1.2.1+git2.18.0-1/git/po/zh_CN.po	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/po/zh_CN.po	2020-02-17 04:47:35.000000000 +0000
@@ -3,7 +3,7 @@
 # Copyright (C) 2012,2013 Jiang Xin <worldhello.net AT gmail.com>
 # This file is distributed under the same license as the Git package.
 # Contributors:
-#   - Fangyi Zhou <fangyi.zhou AT yuriko.moe>
+#   - Fangyi Zhou <me AT fangyi.io>
 #   - Jiang Xin <worldhello.net AT gmail.com>
 #   - Lian Cheng <rhythm.mail AT gmail.com>
 #   - Ray Chen <oldsharp AT gmail.com>
@@ -45,8 +45,9 @@
 #   commit-ish (also committish)     |  提交号
 #   conflict                         |  冲突
 #   core Git                         |  核心 Git 工具
+#   cover letter                     |  附函
 #   DAG                              |  有向无环图
-#   dangling object                  |  摇摆对象
+#   dangling object                  |  悬空对象
 #   detached HEAD                    |  分离头指针
 #   directory                        |  目录
 #   dirty                            |  脏（的工作区）
@@ -138,8 +139,8 @@ msgid ""
 msgstr ""
 "Project-Id-Version: Git\n"
 "Report-Msgid-Bugs-To: Git Mailing List <git@vger.kernel.org>\n"
-"POT-Creation-Date: 2018-06-16 22:06+0800\n"
-"PO-Revision-Date: 2018-06-18 00:28+0800\n"
+"POT-Creation-Date: 2019-12-30 08:48+0800\n"
+"PO-Revision-Date: 2020-01-12 17:16+0800\n"
 "Last-Translator: Jiang Xin <worldhello.net@gmail.com>\n"
 "Language-Team: GitHub <https://github.com/jiangxin/git/>\n"
 "Language: zh_CN\n"
@@ -148,37 +149,458 @@ msgstr ""
 "Content-Transfer-Encoding: 8bit\n"
 "Plural-Forms: nplurals=2; plural=(n != 1);\n"
 
-#: advice.c:92
+#: add-interactive.c:347
+#, c-format
+msgid "Huh (%s)?"
+msgstr "嗯（%s）？"
+
+#: add-interactive.c:500 add-interactive.c:801 sequencer.c:3216
+#: sequencer.c:3656 builtin/rebase.c:871 builtin/rebase.c:1643
+#: builtin/rebase.c:2019 builtin/rebase.c:2063
+msgid "could not read index"
+msgstr "不能读取索引"
+
+#: add-interactive.c:555 git-add--interactive.perl:269
+#: git-add--interactive.perl:294
+msgid "binary"
+msgstr "二进制"
+
+#: add-interactive.c:613 git-add--interactive.perl:278
+#: git-add--interactive.perl:332
+msgid "nothing"
+msgstr "无"
+
+#: add-interactive.c:614 git-add--interactive.perl:314
+#: git-add--interactive.perl:329
+msgid "unchanged"
+msgstr "没有修改"
+
+#: add-interactive.c:651 git-add--interactive.perl:643
+msgid "Update"
+msgstr "更新"
+
+#: add-interactive.c:668 add-interactive.c:856
+#, c-format
+msgid "could not stage '%s'"
+msgstr "不能暂存 '%s'"
+
+#: add-interactive.c:674 add-interactive.c:863 sequencer.c:3409
+#: builtin/rebase.c:895
+msgid "could not write index"
+msgstr "不能写入索引"
+
+#: add-interactive.c:677 git-add--interactive.perl:628
+#, c-format, perl-format
+msgid "updated %d path\n"
+msgid_plural "updated %d paths\n"
+msgstr[0] "更新了 %d 个路径\n"
+msgstr[1] "更新了 %d 个路径\n"
+
+#: add-interactive.c:695 git-add--interactive.perl:678
+#, c-format, perl-format
+msgid "note: %s is untracked now.\n"
+msgstr "说明：%s 现已成为未跟踪的。\n"
+
+#: add-interactive.c:700 apply.c:4108 builtin/checkout.c:281
+#: builtin/reset.c:144
+#, c-format
+msgid "make_cache_entry failed for path '%s'"
+msgstr "对路径 '%s' 的 make_cache_entry 操作失败"
+
+#: add-interactive.c:730 git-add--interactive.perl:655
+msgid "Revert"
+msgstr "还原"
+
+#: add-interactive.c:746
+msgid "Could not parse HEAD^{tree}"
+msgstr "不能解析 HEAD^{tree}"
+
+#: add-interactive.c:784 git-add--interactive.perl:631
+#, c-format, perl-format
+msgid "reverted %d path\n"
+msgid_plural "reverted %d paths\n"
+msgstr[0] "还原了 %d 个路径\n"
+msgstr[1] "还原了 %d 个路径\n"
+
+#: add-interactive.c:835 git-add--interactive.perl:695
+#, c-format
+msgid "No untracked files.\n"
+msgstr "没有未跟踪的文件。\n"
+
+#: add-interactive.c:839 git-add--interactive.perl:689
+msgid "Add untracked"
+msgstr "添加未跟踪的"
+
+#: add-interactive.c:866 git-add--interactive.perl:625
+#, c-format, perl-format
+msgid "added %d path\n"
+msgid_plural "added %d paths\n"
+msgstr[0] "增加了 %d 个路径\n"
+msgstr[1] "增加了 %d 个路径\n"
+
+#: add-interactive.c:896
+#, c-format
+msgid "ignoring unmerged: %s"
+msgstr "忽略未合入的：%s"
+
+#: add-interactive.c:908 add-patch.c:1331 git-add--interactive.perl:1366
+#, c-format
+msgid "Only binary files changed.\n"
+msgstr "只有二进制文件被修改。\n"
+
+#: add-interactive.c:910 add-patch.c:1329 git-add--interactive.perl:1368
+#, c-format
+msgid "No changes.\n"
+msgstr "没有修改。\n"
+
+#: add-interactive.c:914 git-add--interactive.perl:1376
+msgid "Patch update"
+msgstr "补丁更新"
+
+#: add-interactive.c:953 git-add--interactive.perl:1754
+msgid "Review diff"
+msgstr "检视 diff"
+
+#: add-interactive.c:981
+msgid "show paths with changes"
+msgstr "显示含变更的路径"
+
+#: add-interactive.c:983
+msgid "add working tree state to the staged set of changes"
+msgstr "将工作区状态添加到暂存区修改集中"
+
+#: add-interactive.c:985
+msgid "revert staged set of changes back to the HEAD version"
+msgstr "将暂存的修改集恢复为 HEAD 版本"
+
+#: add-interactive.c:987
+msgid "pick hunks and update selectively"
+msgstr "挑选数据块并有选择地更新"
+
+#: add-interactive.c:989
+msgid "view diff between HEAD and index"
+msgstr "显示 HEAD 和索引的差异"
+
+#: add-interactive.c:991
+msgid "add contents of untracked files to the staged set of changes"
+msgstr "将未跟踪文件的内容添加到暂存区修改集中"
+
+#: add-interactive.c:999 add-interactive.c:1048
+msgid "Prompt help:"
+msgstr "帮助："
+
+#: add-interactive.c:1001
+msgid "select a single item"
+msgstr "选择一个条目"
+
+#: add-interactive.c:1003
+msgid "select a range of items"
+msgstr "选择一系列条目"
+
+#: add-interactive.c:1005
+msgid "select multiple ranges"
+msgstr "选择多个范围"
+
+#: add-interactive.c:1007 add-interactive.c:1052
+msgid "select item based on unique prefix"
+msgstr "基于唯一前缀选择条目"
+
+#: add-interactive.c:1009
+msgid "unselect specified items"
+msgstr "反选指定的条目"
+
+#: add-interactive.c:1011
+msgid "choose all items"
+msgstr "选择所有条目"
+
+#: add-interactive.c:1013
+msgid "(empty) finish selecting"
+msgstr "（空）结束选择"
+
+#: add-interactive.c:1050
+msgid "select a numbered item"
+msgstr "选择一个编号条目"
+
+#: add-interactive.c:1054
+msgid "(empty) select nothing"
+msgstr "（空）不选择任何内容"
+
+#: add-interactive.c:1062 builtin/clean.c:822 git-add--interactive.perl:1851
+msgid "*** Commands ***"
+msgstr "*** 命令 ***"
+
+#: add-interactive.c:1063 builtin/clean.c:823 git-add--interactive.perl:1848
+msgid "What now"
+msgstr "请选择"
+
+#: add-interactive.c:1115 git-add--interactive.perl:213
+msgid "staged"
+msgstr "缓存"
+
+#: add-interactive.c:1115 git-add--interactive.perl:213
+msgid "unstaged"
+msgstr "未缓存"
+
+#: add-interactive.c:1115 apply.c:4965 apply.c:4968 builtin/am.c:2197
+#: builtin/am.c:2200 builtin/clone.c:123 builtin/fetch.c:144
+#: builtin/merge.c:273 builtin/pull.c:209 builtin/submodule--helper.c:409
+#: builtin/submodule--helper.c:1379 builtin/submodule--helper.c:1382
+#: builtin/submodule--helper.c:1875 builtin/submodule--helper.c:1878
+#: builtin/submodule--helper.c:2119 git-add--interactive.perl:213
+msgid "path"
+msgstr "路径"
+
+#: add-interactive.c:1122
+msgid "could not refresh index"
+msgstr "不能刷新索引"
+
+#: add-interactive.c:1136 builtin/clean.c:787 git-add--interactive.perl:1765
+#, c-format
+msgid "Bye.\n"
+msgstr "再见。\n"
+
+#: add-patch.c:15
+#, c-format
+msgid "Stage mode change [y,n,a,q,d%s,?]? "
+msgstr "暂存模式变更 [y,n,a,q,d%s,?]? "
+
+#: add-patch.c:16
+#, c-format
+msgid "Stage deletion [y,n,a,q,d%s,?]? "
+msgstr "暂存删除动作 [y,n,a,q,d%s,?]? "
+
+#: add-patch.c:17
+#, c-format
+msgid "Stage this hunk [y,n,a,q,d%s,?]? "
+msgstr "暂存该块 [y,n,a,q,d%s,?]? "
+
+#: add-patch.c:111
+#, c-format
+msgid "could not parse hunk header '%.*s'"
+msgstr "无法解析数据块头信息 '%.*s'"
+
+#: add-patch.c:130 add-patch.c:134
+#, c-format
+msgid "could not parse colored hunk header '%.*s'"
+msgstr "无法解析彩色数据块头信息 '%.*s'"
+
+#: add-patch.c:176
+msgid "could not parse diff"
+msgstr "不能解析差异信息"
+
+#: add-patch.c:194
+msgid "could not parse colored diff"
+msgstr "不能解析彩色差异信息"
+
+#: add-patch.c:508
+#, c-format
+msgid ""
+"expected context line #%d in\n"
+"%.*s"
+msgstr ""
+"预期上下文行 #%d 于\n"
+"%.*s"
+
+#: add-patch.c:523
+#, c-format
+msgid ""
+"hunks do not overlap:\n"
+"%.*s\n"
+"\tdoes not end with:\n"
+"%.*s"
+msgstr ""
+"块不重叠：\n"
+"%.*s\n"
+"\t不是结尾于：\n"
+"%.*s"
+
+#: add-patch.c:799 git-add--interactive.perl:1112
+msgid "Manual hunk edit mode -- see bottom for a quick guide.\n"
+msgstr "手动块编辑模式 -- 查看底部的快速指南。\n"
+
+#: add-patch.c:803
+#, c-format
+msgid ""
+"---\n"
+"To remove '%c' lines, make them ' ' lines (context).\n"
+"To remove '%c' lines, delete them.\n"
+"Lines starting with %c will be removed.\n"
+msgstr ""
+"---\n"
+"要删除 '%c' 开始的行，使其成为 ' ' 开始的行（上下文）。\n"
+"要删除 '%c' 开始的行，删除它们。\n"
+"以 %c 开始的行将被删除。\n"
+
+#: add-patch.c:810
+msgid ""
+"If the patch applies cleanly, the edited hunk will immediately be\n"
+"marked for staging.\n"
+msgstr "如果补丁能干净地应用，编辑块将立即标记为暂存。\n"
+
+#. TRANSLATORS: 'it' refers to the patch mentioned in the previous messages.
+#: add-patch.c:818 git-add--interactive.perl:1126
+msgid ""
+"If it does not apply cleanly, you will be given an opportunity to\n"
+"edit again.  If all lines of the hunk are removed, then the edit is\n"
+"aborted and the hunk is left unchanged.\n"
+msgstr ""
+"如果不能干净地应用，您将有机会重新编辑。如果该块的全部内容删除，则\n"
+"此次编辑被终止，该块不会被修改。\n"
+
+#: add-patch.c:851
+msgid "could not parse hunk header"
+msgstr "无法解析数据块头信息"
+
+#: add-patch.c:895 add-patch.c:1294
+msgid "'git apply --cached' failed"
+msgstr "'git apply --cached' 失败"
+
+#. TRANSLATORS: do not translate [y/n]
+#. The program will only accept that input at this point.
+#. Consider translating (saying "no" discards!) as
+#. (saying "n" for "no" discards!) if the translation
+#. of the word "no" does not start with n.
+#.
+#. TRANSLATORS: do not translate [y/n]
+#. The program will only accept that input
+#. at this point.
+#. Consider translating (saying "no" discards!) as
+#. (saying "n" for "no" discards!) if the translation
+#. of the word "no" does not start with n.
+#: add-patch.c:952 git-add--interactive.perl:1239
+msgid ""
+"Your edited hunk does not apply. Edit again (saying \"no\" discards!) [y/n]? "
+msgstr "您的编辑块不能被应用。重新编辑（选择 \"no\" 丢弃！） [y/n]? "
+
+#: add-patch.c:1009
+msgid ""
+"y - stage this hunk\n"
+"n - do not stage this hunk\n"
+"q - quit; do not stage this hunk or any of the remaining ones\n"
+"a - stage this and all the remaining hunks\n"
+"d - do not stage this hunk nor any of the remaining hunks\n"
+msgstr ""
+"y - 暂存该块\n"
+"n - 不要暂存该块\n"
+"q - 退出。不暂存该块及后面的全部块\n"
+"a - 暂存该块和所有剩余的块\n"
+"d - 不暂存该块和任何剩余的块\n"
+
+#: add-patch.c:1016
+msgid ""
+"j - leave this hunk undecided, see next undecided hunk\n"
+"J - leave this hunk undecided, see next hunk\n"
+"k - leave this hunk undecided, see previous undecided hunk\n"
+"K - leave this hunk undecided, see previous hunk\n"
+"g - select a hunk to go to\n"
+"/ - search for a hunk matching the given regex\n"
+"s - split the current hunk into smaller hunks\n"
+"e - manually edit the current hunk\n"
+"? - print help\n"
+msgstr ""
+"j - 维持该块未决状态，查看下一个未决块\n"
+"J - 维持该块未决状态，查看下一个块\n"
+"k - 维持该块未决状态，查看上一个未决块\n"
+"K - 维持该块未决状态，查看上一个块\n"
+"g - 选择跳转到一个块\n"
+"/ - 查找和给定正则表达式匹配的块\n"
+"s - 拆分当前块为更小的块\n"
+"e - 手动编辑当前块\n"
+"? - 显示帮助\n"
+
+#: add-patch.c:1137 add-patch.c:1147
+msgid "No previous hunk"
+msgstr "没有前一个块"
+
+#: add-patch.c:1142 add-patch.c:1152
+msgid "No next hunk"
+msgstr "没有下一个块"
+
+#: add-patch.c:1158
+msgid "No other hunks to goto"
+msgstr "没有其它可供跳转的块"
+
+#: add-patch.c:1169 git-add--interactive.perl:1577
+msgid "go to which hunk (<ret> to see more)? "
+msgstr "跳转到哪个块（<回车> 查看更多）？ "
+
+#: add-patch.c:1170 git-add--interactive.perl:1579
+msgid "go to which hunk? "
+msgstr "跳转到哪个块？"
+
+#: add-patch.c:1181
+#, c-format
+msgid "Invalid number: '%s'"
+msgstr "无效数字：'%s'"
+
+#: add-patch.c:1186
+#, c-format
+msgid "Sorry, only %d hunk available."
+msgid_plural "Sorry, only %d hunks available."
+msgstr[0] "对不起，只有 %d 个可用块。"
+msgstr[1] "对不起，只有 %d 个可用块。"
+
+#: add-patch.c:1195
+msgid "No other hunks to search"
+msgstr "没有其它可供查找的块"
+
+#: add-patch.c:1201 git-add--interactive.perl:1623
+msgid "search for regex? "
+msgstr "使用正则表达式搜索？"
+
+#: add-patch.c:1216
+#, c-format
+msgid "Malformed search regexp %s: %s"
+msgstr "错误的正则表达式 %s：%s"
+
+#: add-patch.c:1233
+msgid "No hunk matches the given pattern"
+msgstr "没有和给定模式相匹配的块"
+
+#: add-patch.c:1240
+msgid "Sorry, cannot split this hunk"
+msgstr "对不起，不能拆分这个块"
+
+#: add-patch.c:1244
+#, c-format
+msgid "Split into %d hunks."
+msgstr "拆分为 %d 块。"
+
+#: add-patch.c:1248
+msgid "Sorry, cannot edit this hunk"
+msgstr "对不起，不能编辑这个块"
+
+#: advice.c:111
 #, c-format
 msgid "%shint: %.*s%s\n"
 msgstr "%s提示：%.*s%s\n"
 
-#: advice.c:137
+#: advice.c:164
 msgid "Cherry-picking is not possible because you have unmerged files."
 msgstr "无法拣选，因为您有未合并的文件。"
 
-#: advice.c:139
+#: advice.c:166
 msgid "Committing is not possible because you have unmerged files."
 msgstr "无法提交，因为您有未合并的文件。"
 
-#: advice.c:141
+#: advice.c:168
 msgid "Merging is not possible because you have unmerged files."
 msgstr "无法合并，因为您有未合并的文件。"
 
-#: advice.c:143
+#: advice.c:170
 msgid "Pulling is not possible because you have unmerged files."
 msgstr "无法拉取，因为您有未合并的文件。"
 
-#: advice.c:145
+#: advice.c:172
 msgid "Reverting is not possible because you have unmerged files."
 msgstr "无法回退，因为您有未合并的文件。"
 
-#: advice.c:147
+#: advice.c:174
 #, c-format
 msgid "It is not possible to %s because you have unmerged files."
 msgstr "无法 %s，因为您有未合并的文件。"
 
-#: advice.c:155
+#: advice.c:182
 msgid ""
 "Fix them up in the work tree, and then use 'git add/rm <file>'\n"
 "as appropriate to mark resolution and make a commit."
@@ -186,135 +608,145 @@ msgstr ""
 "请在工作区改正文件，然后酌情使用 'git add/rm <文件>' 命令标记\n"
 "解决方案并提交。"
 
-#: advice.c:163
+#: advice.c:190
 msgid "Exiting because of an unresolved conflict."
 msgstr "因为存在未解决的冲突而退出。"
 
-#: advice.c:168 builtin/merge.c:1250
+#: advice.c:195 builtin/merge.c:1332
 msgid "You have not concluded your merge (MERGE_HEAD exists)."
 msgstr "您尚未结束您的合并（存在 MERGE_HEAD）。"
 
-#: advice.c:170
+#: advice.c:197
 msgid "Please, commit your changes before merging."
 msgstr "请在合并前先提交您的修改。"
 
-#: advice.c:171
+#: advice.c:198
 msgid "Exiting because of unfinished merge."
 msgstr "因为存在未完成的合并而退出。"
 
-#: advice.c:177
+#: advice.c:204
 #, c-format
 msgid ""
-"Note: checking out '%s'.\n"
+"Note: switching to '%s'.\n"
 "\n"
 "You are in 'detached HEAD' state. You can look around, make experimental\n"
 "changes and commit them, and you can discard any commits you make in this\n"
-"state without impacting any branches by performing another checkout.\n"
+"state without impacting any branches by switching back to a branch.\n"
 "\n"
 "If you want to create a new branch to retain commits you create, you may\n"
-"do so (now or later) by using -b with the checkout command again. Example:\n"
+"do so (now or later) by using -c with the switch command. Example:\n"
+"\n"
+"  git switch -c <new-branch-name>\n"
 "\n"
-"  git checkout -b <new-branch-name>\n"
+"Or undo this operation with:\n"
+"\n"
+"  git switch -\n"
+"\n"
+"Turn off this advice by setting config variable advice.detachedHead to "
+"false\n"
 "\n"
 msgstr ""
-"注意：正在检出 '%s'。\n"
+"注意：正在切换到 '%s'。\n"
+"\n"
+"您正处于分离头指针状态。您可以查看、做试验性的修改及提交，并且您可以在切换\n"
+"回一个分支时，丢弃在此状态下所做的提交而不对分支造成影响。\n"
+"\n"
+"如果您想要通过创建分支来保留在此状态下所做的提交，您可以通过在 switch 命令\n"
+"中添加参数 -c 来实现（现在或稍后）。例如：\n"
 "\n"
-"您正处于分离头指针状态。您可以查看、做试验性的修改及提交，并且您可以通过另"
-"外\n"
-"的检出分支操作丢弃在这个状态下所做的任何提交。\n"
+"  git switch -c <新分支名>\n"
 "\n"
-"如果您想要通过创建分支来保留在此状态下所做的提交，您可以通过在检出命令添加\n"
-"参数 -b 来实现（现在或稍后）。例如：\n"
+"或者撤销此操作：\n"
 "\n"
-"  git checkout -b <新分支名>\n"
+"  git switch -\n"
 "\n"
+"通过将配置变量 advice.detachedHead 设置为 false 来关闭此建议\n"
+"\n"
+
+#: alias.c:50
+msgid "cmdline ends with \\"
+msgstr "命令行以 \\ 结尾"
 
-#: apply.c:58
+#: alias.c:51
+msgid "unclosed quote"
+msgstr "未关闭的引号"
+
+#: apply.c:69
 #, c-format
 msgid "unrecognized whitespace option '%s'"
 msgstr "未能识别的空白字符选项 '%s'"
 
-#: apply.c:74
+#: apply.c:85
 #, c-format
 msgid "unrecognized whitespace ignore option '%s'"
 msgstr "未能识别的空白字符忽略选项 '%s'"
 
-#: apply.c:122
+#: apply.c:135
 msgid "--reject and --3way cannot be used together."
 msgstr "--reject 和 --3way 不能同时使用。"
 
-#: apply.c:124
+#: apply.c:137
 msgid "--cached and --3way cannot be used together."
 msgstr "--cached 和 --3way 不能同时使用。"
 
-#: apply.c:127
+#: apply.c:140
 msgid "--3way outside a repository"
 msgstr "--3way 在一个仓库之外"
 
-#: apply.c:138
+#: apply.c:151
 msgid "--index outside a repository"
 msgstr "--index 在一个仓库之外"
 
-#: apply.c:141
+#: apply.c:154
 msgid "--cached outside a repository"
 msgstr "--cached 在一个仓库之外"
 
-#: apply.c:821
+#: apply.c:801
 #, c-format
 msgid "Cannot prepare timestamp regexp %s"
 msgstr "无法准备时间戳正则表达式 %s"
 
-#: apply.c:830
+#: apply.c:810
 #, c-format
 msgid "regexec returned %d for input: %s"
 msgstr "regexec 返回 %d，输入为：%s"
 
-#: apply.c:904
+#: apply.c:884
 #, c-format
 msgid "unable to find filename in patch at line %d"
 msgstr "不能在补丁的第 %d 行找到文件名"
 
-#: apply.c:942
+#: apply.c:922
 #, c-format
 msgid "git apply: bad git-diff - expected /dev/null, got %s on line %d"
 msgstr "git apply：错误的 git-diff - 应为 /dev/null，但在第 %2$d 行得到 %1$s"
 
-#: apply.c:948
+#: apply.c:928
 #, c-format
 msgid "git apply: bad git-diff - inconsistent new filename on line %d"
 msgstr "git apply：错误的 git-diff - 第 %d 行上新文件名不一致"
 
-#: apply.c:949
+#: apply.c:929
 #, c-format
 msgid "git apply: bad git-diff - inconsistent old filename on line %d"
 msgstr "git apply：错误的 git-diff - 第 %d 行上旧文件名不一致"
 
-#: apply.c:954
+#: apply.c:934
 #, c-format
 msgid "git apply: bad git-diff - expected /dev/null on line %d"
 msgstr "git apply：错误的 git-diff - 第 %d 行处应为 /dev/null"
 
-#: apply.c:983
+#: apply.c:963
 #, c-format
 msgid "invalid mode on line %d: %s"
 msgstr "第 %d 行包含无效文件模式：%s"
 
-#: apply.c:1301
+#: apply.c:1282
 #, c-format
 msgid "inconsistent header lines %d and %d"
 msgstr "不一致的文件头，%d 行和 %d 行"
 
-#: apply.c:1473
-#, c-format
-msgid "recount: unexpected line: %.*s"
-msgstr "recount：意外的行：%.*s"
-
-#: apply.c:1542
-#, c-format
-msgid "patch fragment without header at line %d: %.*s"
-msgstr "第 %d 行的补丁片段没有头信息：%.*s"
-
-#: apply.c:1562
+#: apply.c:1372
 #, c-format
 msgid ""
 "git diff header lacks filename information when removing %d leading pathname "
@@ -325,82 +757,92 @@ msgid_plural ""
 msgstr[0] "当移除 %d 个前导路径后 git diff 头缺乏文件名信息（第 %d 行）"
 msgstr[1] "当移除 %d 个前导路径后 git diff 头缺乏文件名信息（第 %d 行）"
 
-#: apply.c:1575
+#: apply.c:1385
 #, c-format
 msgid "git diff header lacks filename information (line %d)"
 msgstr "git diff 的头信息中缺乏文件名信息（第 %d 行）"
 
-#: apply.c:1763
+#: apply.c:1481
+#, c-format
+msgid "recount: unexpected line: %.*s"
+msgstr "recount：意外的行：%.*s"
+
+#: apply.c:1550
+#, c-format
+msgid "patch fragment without header at line %d: %.*s"
+msgstr "第 %d 行的补丁片段没有头信息：%.*s"
+
+#: apply.c:1753
 msgid "new file depends on old contents"
 msgstr "新文件依赖旧内容"
 
-#: apply.c:1765
+#: apply.c:1755
 msgid "deleted file still has contents"
 msgstr "删除的文件仍有内容"
 
-#: apply.c:1799
+#: apply.c:1789
 #, c-format
 msgid "corrupt patch at line %d"
 msgstr "补丁在第 %d 行损坏"
 
-#: apply.c:1836
+#: apply.c:1826
 #, c-format
 msgid "new file %s depends on old contents"
 msgstr "新文件 %s 依赖旧内容"
 
-#: apply.c:1838
+#: apply.c:1828
 #, c-format
 msgid "deleted file %s still has contents"
 msgstr "删除的文件 %s 仍有内容"
 
-#: apply.c:1841
+#: apply.c:1831
 #, c-format
 msgid "** warning: file %s becomes empty but is not deleted"
 msgstr "** 警告：文件 %s 成为空文件但并未删除"
 
-#: apply.c:1988
+#: apply.c:1978
 #, c-format
 msgid "corrupt binary patch at line %d: %.*s"
 msgstr "二进制补丁在第 %d 行损坏：%.*s"
 
-#: apply.c:2025
+#: apply.c:2015
 #, c-format
 msgid "unrecognized binary patch at line %d"
 msgstr "未能识别的二进制补丁位于第 %d 行"
 
-#: apply.c:2185
+#: apply.c:2177
 #, c-format
 msgid "patch with only garbage at line %d"
 msgstr "补丁文件的第 %d 行只有垃圾数据"
 
-#: apply.c:2271
+#: apply.c:2263
 #, c-format
 msgid "unable to read symlink %s"
 msgstr "无法读取符号链接 %s"
 
-#: apply.c:2275
+#: apply.c:2267
 #, c-format
 msgid "unable to open or read %s"
 msgstr "不能打开或读取 %s"
 
-#: apply.c:2934
+#: apply.c:2936
 #, c-format
 msgid "invalid start of line: '%c'"
 msgstr "无效的行首字符：'%c'"
 
-#: apply.c:3055
+#: apply.c:3057
 #, c-format
 msgid "Hunk #%d succeeded at %d (offset %d line)."
 msgid_plural "Hunk #%d succeeded at %d (offset %d lines)."
 msgstr[0] "块 #%d 成功应用于 %d（偏移 %d 行）"
 msgstr[1] "块 #%d 成功应用于 %d（偏移 %d 行）"
 
-#: apply.c:3067
+#: apply.c:3069
 #, c-format
 msgid "Context reduced to (%ld/%ld) to apply fragment at %d"
 msgstr "上下文减少到（%ld/%ld）以在第 %d 行应用补丁片段"
 
-#: apply.c:3073
+#: apply.c:3075
 #, c-format
 msgid ""
 "while searching for:\n"
@@ -409,563 +851,629 @@ msgstr ""
 "当查询：\n"
 "%.*s"
 
-#: apply.c:3095
+#: apply.c:3097
 #, c-format
 msgid "missing binary patch data for '%s'"
 msgstr "缺失 '%s' 的二进制补丁数据"
 
-#: apply.c:3103
+#: apply.c:3105
 #, c-format
 msgid "cannot reverse-apply a binary patch without the reverse hunk to '%s'"
 msgstr "不能反向应用一个缺少到 '%s' 的反向数据块的二进制补丁"
 
-#: apply.c:3149
+#: apply.c:3152
 #, c-format
 msgid "cannot apply binary patch to '%s' without full index line"
 msgstr "不能在 '%s' 上应用没有完整索引行的二进制补丁"
 
-#: apply.c:3159
+#: apply.c:3162
 #, c-format
 msgid ""
 "the patch applies to '%s' (%s), which does not match the current contents."
 msgstr "补丁应用到 '%s'（%s），但是和当前内容不匹配。"
 
-#: apply.c:3167
+#: apply.c:3170
 #, c-format
 msgid "the patch applies to an empty '%s' but it is not empty"
 msgstr "补丁应用到空文件 '%s'，但其并非空文件"
 
-#: apply.c:3185
+#: apply.c:3188
 #, c-format
 msgid "the necessary postimage %s for '%s' cannot be read"
-msgstr "无法读取 '%2$s' 必须的目标文件 %1$s"
+msgstr "无法读取 '%2$s' 必需的目标文件 %1$s"
 
-#: apply.c:3198
+#: apply.c:3201
 #, c-format
 msgid "binary patch does not apply to '%s'"
 msgstr "二进制补丁未应用到 '%s'"
 
-#: apply.c:3204
+#: apply.c:3207
 #, c-format
 msgid "binary patch to '%s' creates incorrect result (expecting %s, got %s)"
 msgstr "到 '%s' 的二进制补丁产生了不正确的结果（应为 %s，却为 %s）"
 
-#: apply.c:3225
+#: apply.c:3228
 #, c-format
 msgid "patch failed: %s:%ld"
 msgstr "打补丁失败：%s:%ld"
 
-#: apply.c:3347
+#: apply.c:3351
 #, c-format
 msgid "cannot checkout %s"
 msgstr "不能检出 %s"
 
-#: apply.c:3396 apply.c:3407 apply.c:3453 setup.c:278
+#: apply.c:3403 apply.c:3414 apply.c:3460 midx.c:61 setup.c:280
 #, c-format
 msgid "failed to read %s"
 msgstr "无法读取 %s"
 
-#: apply.c:3404
+#: apply.c:3411
 #, c-format
 msgid "reading from '%s' beyond a symbolic link"
 msgstr "读取位于符号链接中的 '%s'"
 
-#: apply.c:3433 apply.c:3673
+#: apply.c:3440 apply.c:3683
 #, c-format
 msgid "path %s has been renamed/deleted"
 msgstr "路径 %s 已经被重命名/删除"
 
-#: apply.c:3516 apply.c:3687
+#: apply.c:3526 apply.c:3698
 #, c-format
 msgid "%s: does not exist in index"
 msgstr "%s：不存在于索引中"
 
-#: apply.c:3525 apply.c:3695
+#: apply.c:3535 apply.c:3706
 #, c-format
 msgid "%s: does not match index"
 msgstr "%s：和索引不匹配"
 
-#: apply.c:3560
+#: apply.c:3570
 msgid "repository lacks the necessary blob to fall back on 3-way merge."
 msgstr "仓库缺乏必要的数据对象以进行三方合并。"
 
-#: apply.c:3563
+#: apply.c:3573
 #, c-format
 msgid "Falling back to three-way merge...\n"
 msgstr "回落到三方合并...\n"
 
-#: apply.c:3579 apply.c:3583
+#: apply.c:3589 apply.c:3593
 #, c-format
 msgid "cannot read the current contents of '%s'"
 msgstr "无法读取 '%s' 的当前内容"
 
-#: apply.c:3595
+#: apply.c:3605
 #, c-format
 msgid "Failed to fall back on three-way merge...\n"
 msgstr "无法回落到三方合并...\n"
 
-#: apply.c:3609
+#: apply.c:3619
 #, c-format
 msgid "Applied patch to '%s' with conflicts.\n"
 msgstr "应用补丁到 '%s' 存在冲突。\n"
 
-#: apply.c:3614
+#: apply.c:3624
 #, c-format
 msgid "Applied patch to '%s' cleanly.\n"
 msgstr "成功应用补丁到 '%s'。\n"
 
-#: apply.c:3640
+#: apply.c:3650
 msgid "removal patch leaves file contents"
 msgstr "移除补丁仍留下了文件内容"
 
-#: apply.c:3712
+#: apply.c:3723
 #, c-format
 msgid "%s: wrong type"
 msgstr "%s：错误类型"
 
-#: apply.c:3714
+#: apply.c:3725
 #, c-format
 msgid "%s has type %o, expected %o"
 msgstr "%s 的类型是 %o，应为 %o"
 
-#: apply.c:3864 apply.c:3866
+#: apply.c:3876 apply.c:3878 read-cache.c:830 read-cache.c:856
+#: read-cache.c:1320
 #, c-format
 msgid "invalid path '%s'"
 msgstr "无效路径 '%s'"
 
-#: apply.c:3922
+#: apply.c:3934
 #, c-format
 msgid "%s: already exists in index"
 msgstr "%s：已经存在于索引中"
 
-#: apply.c:3925
+#: apply.c:3937
 #, c-format
 msgid "%s: already exists in working directory"
 msgstr "%s：已经存在于工作区中"
 
-#: apply.c:3945
+#: apply.c:3957
 #, c-format
 msgid "new mode (%o) of %s does not match old mode (%o)"
 msgstr "%2$s 的新模式（%1$o）和旧模式（%3$o）不匹配"
 
-#: apply.c:3950
+#: apply.c:3962
 #, c-format
 msgid "new mode (%o) of %s does not match old mode (%o) of %s"
 msgstr "%2$s 的新模式（%1$o）和 %4$s 的旧模式（%3$o）不匹配"
 
-#: apply.c:3970
+#: apply.c:3982
 #, c-format
 msgid "affected file '%s' is beyond a symbolic link"
 msgstr "受影响的文件 '%s' 位于符号链接中"
 
-#: apply.c:3974
+#: apply.c:3986
 #, c-format
 msgid "%s: patch does not apply"
 msgstr "%s：补丁未应用"
 
-#: apply.c:3989
+#: apply.c:4001
 #, c-format
 msgid "Checking patch %s..."
-msgstr "检查补丁 %s..."
+msgstr "正在检查补丁 %s..."
 
-#: apply.c:4080
+#: apply.c:4093
 #, c-format
 msgid "sha1 information is lacking or useless for submodule %s"
 msgstr "子模组 %s 的 sha1 信息缺失或无效"
 
-#: apply.c:4087
+#: apply.c:4100
 #, c-format
 msgid "mode change for %s, which is not in current HEAD"
 msgstr "%s 的模式变更，但它不在当前 HEAD 中"
 
-#: apply.c:4090
+#: apply.c:4103
 #, c-format
 msgid "sha1 information is lacking or useless (%s)."
 msgstr "sha1 信息缺失或无效（%s）。"
 
-#: apply.c:4095 builtin/checkout.c:235 builtin/reset.c:140
-#, c-format
-msgid "make_cache_entry failed for path '%s'"
-msgstr "对路径 '%s' 的 make_cache_entry 操作失败"
-
-#: apply.c:4099
+#: apply.c:4112
 #, c-format
 msgid "could not add %s to temporary index"
 msgstr "不能在临时索引中添加 %s"
 
-#: apply.c:4109
+#: apply.c:4122
 #, c-format
 msgid "could not write temporary index to %s"
 msgstr "不能把临时索引写入到 %s"
 
-#: apply.c:4247
+#: apply.c:4260
 #, c-format
 msgid "unable to remove %s from index"
 msgstr "不能从索引中移除 %s"
 
-#: apply.c:4282
+#: apply.c:4294
 #, c-format
 msgid "corrupt patch for submodule %s"
 msgstr "子模组 %s 损坏的补丁"
 
-#: apply.c:4288
+#: apply.c:4300
 #, c-format
 msgid "unable to stat newly created file '%s'"
 msgstr "不能对新建文件 '%s' 调用 stat"
 
-#: apply.c:4296
+#: apply.c:4308
 #, c-format
 msgid "unable to create backing store for newly created file %s"
 msgstr "不能为新建文件 %s 创建后端存储"
 
-#: apply.c:4302 apply.c:4446
+#: apply.c:4314 apply.c:4459
 #, c-format
 msgid "unable to add cache entry for %s"
 msgstr "无法为 %s 添加缓存条目"
 
-#: apply.c:4343
+#: apply.c:4357
 #, c-format
 msgid "failed to write to '%s'"
-msgstr "无法写入 '%s'"
+msgstr "写入 '%s' 失败"
 
-#: apply.c:4347
+#: apply.c:4361
 #, c-format
 msgid "closing file '%s'"
 msgstr "关闭文件 '%s'"
 
-#: apply.c:4417
+#: apply.c:4431
 #, c-format
 msgid "unable to write file '%s' mode %o"
 msgstr "不能写文件 '%s' 权限 %o"
 
-#: apply.c:4515
+#: apply.c:4529
 #, c-format
 msgid "Applied patch %s cleanly."
 msgstr "成功应用补丁 %s。"
 
-#: apply.c:4523
+#: apply.c:4537
 msgid "internal error"
 msgstr "内部错误"
 
-#: apply.c:4526
+#: apply.c:4540
 #, c-format
 msgid "Applying patch %%s with %d reject..."
 msgid_plural "Applying patch %%s with %d rejects..."
 msgstr[0] "应用 %%s 个补丁，其中 %d 个被拒绝..."
 msgstr[1] "应用 %%s 个补丁，其中 %d 个被拒绝..."
 
-#: apply.c:4537
+#: apply.c:4551
 #, c-format
 msgid "truncating .rej filename to %.*s.rej"
 msgstr "截短 .rej 文件名为 %.*s.rej"
 
-#: apply.c:4545 builtin/fetch.c:786 builtin/fetch.c:1036
+#: apply.c:4559 builtin/fetch.c:901 builtin/fetch.c:1192
 #, c-format
 msgid "cannot open %s"
 msgstr "不能打开 %s"
 
-#: apply.c:4559
+#: apply.c:4573
 #, c-format
 msgid "Hunk #%d applied cleanly."
 msgstr "第 #%d 个片段成功应用。"
 
-#: apply.c:4563
+#: apply.c:4577
 #, c-format
 msgid "Rejected hunk #%d."
 msgstr "拒绝第 #%d 个片段。"
 
-#: apply.c:4673
+#: apply.c:4696
 #, c-format
 msgid "Skipped patch '%s'."
 msgstr "略过补丁 '%s'。"
 
-#: apply.c:4681
+#: apply.c:4704
 msgid "unrecognized input"
 msgstr "未能识别的输入"
 
-#: apply.c:4700
+#: apply.c:4724
 msgid "unable to read index file"
 msgstr "无法读取索引文件"
 
-#: apply.c:4837
+#: apply.c:4881
 #, c-format
 msgid "can't open patch '%s': %s"
 msgstr "不能打开补丁 '%s'：%s"
 
-#: apply.c:4864
+#: apply.c:4908
 #, c-format
 msgid "squelched %d whitespace error"
 msgid_plural "squelched %d whitespace errors"
 msgstr[0] "抑制下仍有 %d 个空白字符误用"
 msgstr[1] "抑制下仍有 %d 个空白字符误用"
 
-#: apply.c:4870 apply.c:4885
+#: apply.c:4914 apply.c:4929
 #, c-format
 msgid "%d line adds whitespace errors."
 msgid_plural "%d lines add whitespace errors."
 msgstr[0] "%d 行新增了空白字符误用。"
 msgstr[1] "%d 行新增了空白字符误用。"
 
-#: apply.c:4878
+#: apply.c:4922
 #, c-format
 msgid "%d line applied after fixing whitespace errors."
 msgid_plural "%d lines applied after fixing whitespace errors."
 msgstr[0] "修复空白错误后，应用了 %d 行。"
 msgstr[1] "修复空白错误后，应用了 %d 行。"
 
-#: apply.c:4894 builtin/add.c:538 builtin/mv.c:300 builtin/rm.c:389
+#: apply.c:4938 builtin/add.c:579 builtin/mv.c:301 builtin/rm.c:390
 msgid "Unable to write new index file"
 msgstr "无法写入新索引文件"
 
-#: apply.c:4921 apply.c:4924 builtin/am.c:2254 builtin/am.c:2257
-#: builtin/clone.c:120 builtin/fetch.c:126 builtin/pull.c:198
-#: builtin/submodule--helper.c:405 builtin/submodule--helper.c:1210
-#: builtin/submodule--helper.c:1213 builtin/submodule--helper.c:1584
-#: builtin/submodule--helper.c:1587 builtin/submodule--helper.c:1807
-#: git-add--interactive.perl:197
-msgid "path"
-msgstr "路径"
-
-#: apply.c:4922
+#: apply.c:4966
 msgid "don't apply changes matching the given path"
 msgstr "不要应用与给出路径向匹配的变更"
 
-#: apply.c:4925
+#: apply.c:4969
 msgid "apply changes matching the given path"
 msgstr "应用与给出路径向匹配的变更"
 
-#: apply.c:4927 builtin/am.c:2263
+#: apply.c:4971 builtin/am.c:2206
 msgid "num"
 msgstr "数字"
 
-#: apply.c:4928
+#: apply.c:4972
 msgid "remove <num> leading slashes from traditional diff paths"
 msgstr "从传统的 diff 路径中移除指定数量的前导斜线"
 
-#: apply.c:4931
+#: apply.c:4975
 msgid "ignore additions made by the patch"
 msgstr "忽略补丁中的添加的文件"
 
-#: apply.c:4933
+#: apply.c:4977
 msgid "instead of applying the patch, output diffstat for the input"
 msgstr "不应用补丁，而是显示输入的差异统计（diffstat）"
 
-#: apply.c:4937
+#: apply.c:4981
 msgid "show number of added and deleted lines in decimal notation"
 msgstr "以十进制数显示添加和删除的行数"
 
-#: apply.c:4939
+#: apply.c:4983
 msgid "instead of applying the patch, output a summary for the input"
 msgstr "不应用补丁，而是显示输入的概要"
 
-#: apply.c:4941
+#: apply.c:4985
 msgid "instead of applying the patch, see if the patch is applicable"
 msgstr "不应用补丁，而是查看补丁是否可应用"
 
-#: apply.c:4943
+#: apply.c:4987
 msgid "make sure the patch is applicable to the current index"
 msgstr "确认补丁可以应用到当前索引"
 
-#: apply.c:4945
+#: apply.c:4989
+msgid "mark new files with `git add --intent-to-add`"
+msgstr "使用命令 `git add --intent-to-add` 标记新增文件"
+
+#: apply.c:4991
 msgid "apply a patch without touching the working tree"
 msgstr "应用补丁而不修改工作区"
 
-#: apply.c:4947
+#: apply.c:4993
 msgid "accept a patch that touches outside the working area"
 msgstr "接受修改工作区之外文件的补丁"
 
-#: apply.c:4950
+#: apply.c:4996
 msgid "also apply the patch (use with --stat/--summary/--check)"
 msgstr "还应用此补丁（与 --stat/--summary/--check 选项同时使用）"
 
-#: apply.c:4952
+#: apply.c:4998
 msgid "attempt three-way merge if a patch does not apply"
 msgstr "如果一个补丁不能应用则尝试三方合并"
 
-#: apply.c:4954
+#: apply.c:5000
 msgid "build a temporary index based on embedded index information"
 msgstr "创建一个临时索引基于嵌入的索引信息"
 
-#: apply.c:4957 builtin/checkout-index.c:168 builtin/ls-files.c:515
+#: apply.c:5003 builtin/checkout-index.c:173 builtin/ls-files.c:524
 msgid "paths are separated with NUL character"
 msgstr "路径以 NUL 字符分隔"
 
-#: apply.c:4959
+#: apply.c:5005
 msgid "ensure at least <n> lines of context match"
 msgstr "确保至少匹配 <n> 行上下文"
 
-#: apply.c:4960 builtin/am.c:2242 builtin/interpret-trailers.c:95
-#: builtin/interpret-trailers.c:97 builtin/interpret-trailers.c:99
-#: builtin/pack-objects.c:3177
+#: apply.c:5006 builtin/am.c:2185 builtin/interpret-trailers.c:98
+#: builtin/interpret-trailers.c:100 builtin/interpret-trailers.c:102
+#: builtin/pack-objects.c:3310 builtin/rebase.c:1474
 msgid "action"
 msgstr "动作"
 
-#: apply.c:4961
+#: apply.c:5007
 msgid "detect new or modified lines that have whitespace errors"
 msgstr "检查新增和修改的行中间的空白字符滥用"
 
-#: apply.c:4964 apply.c:4967
+#: apply.c:5010 apply.c:5013
 msgid "ignore changes in whitespace when finding context"
 msgstr "查找上下文时忽略空白字符的变更"
 
-#: apply.c:4970
+#: apply.c:5016
 msgid "apply the patch in reverse"
 msgstr "反向应用补丁"
 
-#: apply.c:4972
+#: apply.c:5018
 msgid "don't expect at least one line of context"
 msgstr "无需至少一行上下文"
 
-#: apply.c:4974
+#: apply.c:5020
 msgid "leave the rejected hunks in corresponding *.rej files"
 msgstr "将拒绝的补丁片段保存在对应的 *.rej 文件中"
 
-#: apply.c:4976
+#: apply.c:5022
 msgid "allow overlapping hunks"
 msgstr "允许重叠的补丁片段"
 
-#: apply.c:4977 builtin/add.c:290 builtin/check-ignore.c:21
-#: builtin/commit.c:1301 builtin/count-objects.c:98 builtin/fsck.c:666
-#: builtin/log.c:1901 builtin/mv.c:122 builtin/read-tree.c:124
+#: apply.c:5023 builtin/add.c:309 builtin/check-ignore.c:22
+#: builtin/commit.c:1355 builtin/count-objects.c:98 builtin/fsck.c:774
+#: builtin/log.c:2166 builtin/mv.c:123 builtin/read-tree.c:128
 msgid "be verbose"
 msgstr "冗长输出"
 
-#: apply.c:4979
+#: apply.c:5025
 msgid "tolerate incorrectly detected missing new-line at the end of file"
 msgstr "允许不正确的文件末尾换行符"
 
-#: apply.c:4982
+#: apply.c:5028
 msgid "do not trust the line counts in the hunk headers"
 msgstr "不信任补丁片段的头信息中的行号"
 
-#: apply.c:4984 builtin/am.c:2251
+#: apply.c:5030 builtin/am.c:2194
 msgid "root"
 msgstr "根目录"
 
-#: apply.c:4985
+#: apply.c:5031
 msgid "prepend <root> to all filenames"
 msgstr "为所有文件名前添加 <根目录>"
 
-#: archive.c:13
+#: archive.c:14
 msgid "git archive [<options>] <tree-ish> [<path>...]"
-msgstr "git archive [<选项>] <树或提交> [<路径>...]"
+msgstr "git archive [<选项>] <树对象> [<路径>...]"
 
-#: archive.c:14
+#: archive.c:15
 msgid "git archive --list"
 msgstr "git archive --list"
 
-#: archive.c:15
+#: archive.c:16
 msgid ""
 "git archive --remote <repo> [--exec <cmd>] [<options>] <tree-ish> [<path>...]"
 msgstr ""
-"git archive --remote <仓库> [--exec <命令>] [<选项>] <树或提交> [<路径>...]"
+"git archive --remote <仓库> [--exec <命令>] [<选项>] <树对象> [<路径>...]"
 
-#: archive.c:16
+#: archive.c:17
 msgid "git archive --remote <repo> [--exec <cmd>] --list"
 msgstr "git archive --remote <仓库> [--exec <命令>] --list"
 
-#: archive.c:351 builtin/add.c:176 builtin/add.c:514 builtin/rm.c:298
+#: archive.c:372 builtin/add.c:180 builtin/add.c:555 builtin/rm.c:299
 #, c-format
 msgid "pathspec '%s' did not match any files"
 msgstr "路径规格 '%s' 未匹配任何文件"
 
-#: archive.c:434
+#: archive.c:396
+#, c-format
+msgid "no such ref: %.*s"
+msgstr "无此引用：%.*s"
+
+#: archive.c:401
+#, c-format
+msgid "not a valid object name: %s"
+msgstr "不是一个有效的对象名：%s"
+
+#: archive.c:414
+#, c-format
+msgid "not a tree object: %s"
+msgstr "不是一个树对象：%s"
+
+#: archive.c:426
+msgid "current working directory is untracked"
+msgstr "当前工作目录未被跟踪"
+
+#: archive.c:457
 msgid "fmt"
 msgstr "格式"
 
-#: archive.c:434
+#: archive.c:457
 msgid "archive format"
 msgstr "归档格式"
 
-#: archive.c:435 builtin/log.c:1462
+#: archive.c:458 builtin/log.c:1653
 msgid "prefix"
 msgstr "前缀"
 
-#: archive.c:436
+#: archive.c:459
 msgid "prepend prefix to each pathname in the archive"
 msgstr "为归档中每个路径名加上前缀"
 
-#: archive.c:437 builtin/blame.c:813 builtin/blame.c:814 builtin/config.c:127
-#: builtin/fast-export.c:1007 builtin/fast-export.c:1009 builtin/grep.c:869
-#: builtin/hash-object.c:103 builtin/ls-files.c:551 builtin/ls-files.c:554
-#: builtin/notes.c:405 builtin/notes.c:568 builtin/read-tree.c:119
-#: parse-options.h:165
+#: archive.c:460 builtin/blame.c:861 builtin/blame.c:865 builtin/blame.c:866
+#: builtin/commit-tree.c:117 builtin/config.c:129 builtin/fast-export.c:1162
+#: builtin/fast-export.c:1164 builtin/fast-export.c:1168 builtin/grep.c:899
+#: builtin/hash-object.c:105 builtin/ls-files.c:560 builtin/ls-files.c:563
+#: builtin/notes.c:412 builtin/notes.c:578 builtin/read-tree.c:123
+#: parse-options.h:190
 msgid "file"
 msgstr "文件"
 
-#: archive.c:438 builtin/archive.c:89
+#: archive.c:461 builtin/archive.c:90
 msgid "write the archive to this file"
 msgstr "归档写入此文件"
 
-#: archive.c:440
+#: archive.c:463
 msgid "read .gitattributes in working directory"
 msgstr "读取工作区中的 .gitattributes"
 
-#: archive.c:441
+#: archive.c:464
 msgid "report archived files on stderr"
 msgstr "在标准错误上报告归档文件"
 
-#: archive.c:442
+#: archive.c:465
 msgid "store only"
 msgstr "只存储"
 
-#: archive.c:443
+#: archive.c:466
 msgid "compress faster"
 msgstr "压缩速度更快"
 
-#: archive.c:451
+#: archive.c:474
 msgid "compress better"
 msgstr "压缩效果更好"
 
-#: archive.c:454
+#: archive.c:477
 msgid "list supported archive formats"
 msgstr "列出支持的归档格式"
 
-#: archive.c:456 builtin/archive.c:90 builtin/clone.c:110 builtin/clone.c:113
-#: builtin/submodule--helper.c:1222 builtin/submodule--helper.c:1593
+#: archive.c:479 builtin/archive.c:91 builtin/clone.c:113 builtin/clone.c:116
+#: builtin/submodule--helper.c:1391 builtin/submodule--helper.c:1884
 msgid "repo"
 msgstr "仓库"
 
-#: archive.c:457 builtin/archive.c:91
+#: archive.c:480 builtin/archive.c:92
 msgid "retrieve the archive from remote repository <repo>"
 msgstr "从远程仓库（<仓库>）提取归档文件"
 
-#: archive.c:458 builtin/archive.c:92 builtin/notes.c:489
+#: archive.c:481 builtin/archive.c:93 builtin/difftool.c:715
+#: builtin/notes.c:498
 msgid "command"
 msgstr "命令"
 
-#: archive.c:459 builtin/archive.c:93
+#: archive.c:482 builtin/archive.c:94
 msgid "path to the remote git-upload-archive command"
 msgstr "远程 git-upload-archive 命令的路径"
 
-#: archive.c:466
+#: archive.c:489
 msgid "Unexpected option --remote"
 msgstr "未知参数 --remote"
 
-#: archive.c:468
+#: archive.c:491
 msgid "Option --exec can only be used together with --remote"
 msgstr "选项 --exec 只能和 --remote 同时使用"
 
-#: archive.c:470
+#: archive.c:493
 msgid "Unexpected option --output"
 msgstr "未知参数 --output"
 
-#: archive.c:492
+#: archive.c:515
 #, c-format
 msgid "Unknown archive format '%s'"
 msgstr "未知归档格式 '%s'"
 
-#: archive.c:499
+#: archive.c:522
 #, c-format
 msgid "Argument not supported for format '%s': -%d"
 msgstr "参数不支持此格式 '%s'：-%d"
 
-#: attr.c:218
+#: archive-tar.c:125 archive-zip.c:350
+#, c-format
+msgid "cannot stream blob %s"
+msgstr "不能打开数据对象 %s"
+
+#: archive-tar.c:266 archive-zip.c:368
+#, c-format
+msgid "unsupported file mode: 0%o (SHA1: %s)"
+msgstr "不支持的文件模式：0%o (SHA1: %s)"
+
+#: archive-tar.c:293 archive-zip.c:358
+#, c-format
+msgid "cannot read %s"
+msgstr "不能读取 %s"
+
+#: archive-tar.c:465
+#, c-format
+msgid "unable to start '%s' filter"
+msgstr "无法启动 '%s' 过滤器"
+
+#: archive-tar.c:468
+msgid "unable to redirect descriptor"
+msgstr "无法重定向描述符"
+
+#: archive-tar.c:475
+#, c-format
+msgid "'%s' filter reported error"
+msgstr "'%s' 过滤器报告了错误"
+
+#: archive-zip.c:319
+#, c-format
+msgid "path is not valid UTF-8: %s"
+msgstr "路径不是有效的 UTF-8：%s"
+
+#: archive-zip.c:323
+#, c-format
+msgid "path too long (%d chars, SHA1: %s): %s"
+msgstr "路径太长（%d 字符，SHA1：%s）：%s"
+
+#: archive-zip.c:479 builtin/pack-objects.c:230 builtin/pack-objects.c:233
+#, c-format
+msgid "deflate error (%d)"
+msgstr "压缩错误 (%d)"
+
+#: archive-zip.c:614
+#, c-format
+msgid "timestamp too large for this system: %<PRIuMAX>"
+msgstr "对于本系统时间戳太大：%<PRIuMAX>"
+
+#: attr.c:212
 #, c-format
 msgid "%.*s is not a valid attribute name"
 msgstr "%.*s 不是一个有效的属性名"
 
-#: attr.c:415
+#: attr.c:369
+#, c-format
+msgid "%s not allowed: %s:%d"
+msgstr "不允许 %s：%s:%d"
+
+#: attr.c:409
 msgid ""
 "Negative patterns are ignored in git attributes\n"
 "Use '\\!' for literal leading exclamation."
@@ -973,22 +1481,22 @@ msgstr ""
 "负值模版在 git attributes 中被忽略\n"
 "当字符串确实要以感叹号开始时，使用 '\\!'。"
 
-#: bisect.c:461
+#: bisect.c:468
 #, c-format
 msgid "Badly quoted content in file '%s': %s"
 msgstr "文件 '%s' 包含错误的引用格式：%s"
 
-#: bisect.c:669
+#: bisect.c:678
 #, c-format
 msgid "We cannot bisect more!\n"
 msgstr "我们无法进行更多的二分查找！\n"
 
-#: bisect.c:723
+#: bisect.c:733
 #, c-format
 msgid "Not a valid commit name %s"
 msgstr "不是一个有效的提交名 %s"
 
-#: bisect.c:747
+#: bisect.c:758
 #, c-format
 msgid ""
 "The merge base %s is bad.\n"
@@ -997,7 +1505,7 @@ msgstr ""
 "合并基线 %s 是坏的。\n"
 "这意味着介于 %s 和 [%s] 之间的 bug 已经被修复。\n"
 
-#: bisect.c:752
+#: bisect.c:763
 #, c-format
 msgid ""
 "The merge base %s is new.\n"
@@ -1006,7 +1514,7 @@ msgstr ""
 "合并基线 %s 是新的。\n"
 "介于 %s 和 [%s] 之间的属性已经被修改。\n"
 
-#: bisect.c:757
+#: bisect.c:768
 #, c-format
 msgid ""
 "The merge base %s is %s.\n"
@@ -1015,7 +1523,7 @@ msgstr ""
 "合并基线 %s 是 %s。\n"
 "这意味着第一个 '%s' 提交位于 %s 和 [%s] 之间。\n"
 
-#: bisect.c:765
+#: bisect.c:776
 #, c-format
 msgid ""
 "Some %s revs are not ancestors of the %s rev.\n"
@@ -1026,7 +1534,7 @@ msgstr ""
 "这种情况下 git 二分查找无法正常工作。\n"
 "您可能弄错了 %s 和 %s 版本？\n"
 
-#: bisect.c:778
+#: bisect.c:789
 #, c-format
 msgid ""
 "the merge base between %s and [%s] must be skipped.\n"
@@ -1037,36 +1545,36 @@ msgstr ""
 "所以我们无法确认第一个 %s 提交是否介于 %s 和 %s 之间。\n"
 "我们仍旧继续。"
 
-#: bisect.c:811
+#: bisect.c:822
 #, c-format
 msgid "Bisecting: a merge base must be tested\n"
 msgstr "二分查找中：合并基线必须是经过测试的\n"
 
-#: bisect.c:851
+#: bisect.c:865
 #, c-format
 msgid "a %s revision is needed"
 msgstr "需要一个 %s 版本"
 
-#: bisect.c:870 builtin/notes.c:175 builtin/tag.c:236
+#: bisect.c:884 builtin/notes.c:177 builtin/tag.c:254
 #, c-format
 msgid "could not create file '%s'"
 msgstr "不能创建文件 '%s'"
 
-#: bisect.c:921
+#: bisect.c:928 builtin/merge.c:148
 #, c-format
 msgid "could not read file '%s'"
 msgstr "不能读取文件 '%s'"
 
-#: bisect.c:951
+#: bisect.c:958
 msgid "reading bisect refs failed"
 msgstr "读取二分查找引用失败"
 
-#: bisect.c:970
+#: bisect.c:977
 #, c-format
 msgid "%s was both %s and %s\n"
 msgstr "%s 同时为 %s 和 %s\n"
 
-#: bisect.c:978
+#: bisect.c:985
 #, c-format
 msgid ""
 "No testable commit found.\n"
@@ -1075,7 +1583,7 @@ msgstr ""
 "没有发现可测试的提交。\n"
 "可能您在运行时使用了错误的路径参数？\n"
 
-#: bisect.c:997
+#: bisect.c:1004
 #, c-format
 msgid "(roughly %d step)"
 msgid_plural "(roughly %d steps)"
@@ -1085,48 +1593,49 @@ msgstr[1] "（大概 %d 步）"
 #. TRANSLATORS: the last %s will be replaced with "(roughly %d
 #. steps)" translation.
 #.
-#: bisect.c:1003
+#: bisect.c:1010
 #, c-format
 msgid "Bisecting: %d revision left to test after this %s\n"
 msgid_plural "Bisecting: %d revisions left to test after this %s\n"
 msgstr[0] "二分查找中：在此之后，还剩 %d 个版本待测试 %s\n"
 msgstr[1] "二分查找中：在此之后，还剩 %d 个版本待测试 %s\n"
 
-#: blame.c:1756
+#: blame.c:2700
 msgid "--contents and --reverse do not blend well."
 msgstr "--contents 和 --reverse 不能混用。"
 
-#: blame.c:1767
+#: blame.c:2714
 msgid "cannot use --contents with final commit object name"
 msgstr "不能将 --contents 和最终的提交对象名共用"
 
-#: blame.c:1787
+#: blame.c:2735
 msgid "--reverse and --first-parent together require specified latest commit"
 msgstr "--reverse 和 --first-parent 共用，需要指定最新的提交"
 
-#: blame.c:1796 bundle.c:160 ref-filter.c:2075 sequencer.c:1861
-#: sequencer.c:3632 builtin/commit.c:981 builtin/log.c:366 builtin/log.c:920
-#: builtin/log.c:1371 builtin/log.c:1702 builtin/log.c:1950 builtin/merge.c:372
+#: blame.c:2744 bundle.c:167 ref-filter.c:2203 remote.c:1941 sequencer.c:2093
+#: sequencer.c:4460 builtin/commit.c:1040 builtin/log.c:388 builtin/log.c:991
+#: builtin/log.c:1520 builtin/log.c:1925 builtin/log.c:2215 builtin/merge.c:411
+#: builtin/pack-objects.c:3128 builtin/pack-objects.c:3143
 #: builtin/shortlog.c:192
 msgid "revision walk setup failed"
 msgstr "版本遍历设置失败"
 
-#: blame.c:1814
+#: blame.c:2762
 msgid ""
 "--reverse --first-parent together require range along first-parent chain"
 msgstr "--reverse 和 --first-parent 共用，需要第一祖先链上的提交范围"
 
-#: blame.c:1825
+#: blame.c:2773
 #, c-format
 msgid "no such path %s in %s"
 msgstr "在 %2$s 中无此路径 %1$s"
 
-#: blame.c:1836
+#: blame.c:2784
 #, c-format
 msgid "cannot read blob %s for path %s"
 msgstr "不能为路径 %2$s 读取数据对象 %1$s"
 
-#: branch.c:54
+#: branch.c:53
 #, c-format
 msgid ""
 "\n"
@@ -1138,85 +1647,85 @@ msgstr ""
 "在修复错误后，您可以尝试修改远程跟踪分支，通过执行命令\n"
 "\"git branch --set-upstream-to=%s%s%s\" 。"
 
-#: branch.c:68
+#: branch.c:67
 #, c-format
 msgid "Not setting branch %s as its own upstream."
 msgstr "未设置分支 %s 作为它自己的上游。"
 
-#: branch.c:94
+#: branch.c:93
 #, c-format
 msgid "Branch '%s' set up to track remote branch '%s' from '%s' by rebasing."
 msgstr "分支 '%1$s' 设置为使用变基来跟踪来自 '%3$s' 的远程分支 '%2$s'。"
 
-#: branch.c:95
+#: branch.c:94
 #, c-format
 msgid "Branch '%s' set up to track remote branch '%s' from '%s'."
 msgstr "分支 '%1$s' 设置为跟踪来自 '%3$s' 的远程分支 '%2$s'。"
 
-#: branch.c:99
+#: branch.c:98
 #, c-format
 msgid "Branch '%s' set up to track local branch '%s' by rebasing."
 msgstr "分支 '%s' 设置为使用变基来跟踪本地分支 '%s'。"
 
-#: branch.c:100
+#: branch.c:99
 #, c-format
 msgid "Branch '%s' set up to track local branch '%s'."
 msgstr "分支 '%s' 设置为跟踪本地分支 '%s'。"
 
-#: branch.c:105
+#: branch.c:104
 #, c-format
 msgid "Branch '%s' set up to track remote ref '%s' by rebasing."
 msgstr "分支 '%s' 设置为使用变基来跟踪远程引用 '%s'。"
 
-#: branch.c:106
+#: branch.c:105
 #, c-format
 msgid "Branch '%s' set up to track remote ref '%s'."
 msgstr "分支 '%s' 设置为跟踪远程引用 '%s'。"
 
-#: branch.c:110
+#: branch.c:109
 #, c-format
 msgid "Branch '%s' set up to track local ref '%s' by rebasing."
 msgstr "分支 '%s' 设置为使用变基来跟踪本地引用 '%s'。"
 
-#: branch.c:111
+#: branch.c:110
 #, c-format
 msgid "Branch '%s' set up to track local ref '%s'."
 msgstr "分支 '%s' 设置为跟踪本地引用 '%s'。"
 
-#: branch.c:120
+#: branch.c:119
 msgid "Unable to write upstream branch configuration"
 msgstr "无法写入上游分支配置"
 
-#: branch.c:157
+#: branch.c:156
 #, c-format
 msgid "Not tracking: ambiguous information for ref %s"
 msgstr "未跟踪：引用 %s 有歧义"
 
-#: branch.c:190
+#: branch.c:189
 #, c-format
 msgid "'%s' is not a valid branch name."
 msgstr "'%s' 不是一个有效的分支名称。"
 
-#: branch.c:209
+#: branch.c:208
 #, c-format
 msgid "A branch named '%s' already exists."
 msgstr "一个分支名 '%s' 已经存在。"
 
-#: branch.c:214
+#: branch.c:213
 msgid "Cannot force update the current branch."
 msgstr "无法强制更新当前分支。"
 
-#: branch.c:234
+#: branch.c:233
 #, c-format
 msgid "Cannot setup tracking information; starting point '%s' is not a branch."
 msgstr "无法设置跟踪信息；起始点 '%s' 不是一个分支。"
 
-#: branch.c:236
+#: branch.c:235
 #, c-format
 msgid "the requested upstream branch '%s' does not exist"
 msgstr "请求的上游分支 '%s' 不存在"
 
-#: branch.c:238
+#: branch.c:237
 msgid ""
 "\n"
 "If you are planning on basing your work on an upstream\n"
@@ -1249,85 +1758,94 @@ msgstr "歧义的对象名：'%s'。"
 msgid "Not a valid branch point: '%s'."
 msgstr "无效的分支点：'%s'。"
 
-#: branch.c:360
+#: branch.c:364
 #, c-format
 msgid "'%s' is already checked out at '%s'"
 msgstr "'%s' 已经检出到 '%s'"
 
-#: branch.c:383
+#: branch.c:387
 #, c-format
 msgid "HEAD of working tree %s is not updated"
 msgstr "工作区 %s 的 HEAD 指向没有被更新"
 
-#: bundle.c:34
+#: bundle.c:36
 #, c-format
 msgid "'%s' does not look like a v2 bundle file"
 msgstr "'%s' 不像是一个 v2 版本的包文件"
 
-#: bundle.c:62
+#: bundle.c:64
 #, c-format
 msgid "unrecognized header: %s%s (%d)"
 msgstr "未能识别的包头：%s%s (%d)"
 
-#: bundle.c:88 sequencer.c:2081 sequencer.c:2558 builtin/commit.c:755
+#: bundle.c:90 rerere.c:480 rerere.c:690 sequencer.c:2344 sequencer.c:3108
+#: builtin/commit.c:811
 #, c-format
 msgid "could not open '%s'"
 msgstr "不能打开 '%s'"
 
-#: bundle.c:139
+#: bundle.c:143
 msgid "Repository lacks these prerequisite commits:"
 msgstr "仓库中缺少这些必备的提交："
 
-#: bundle.c:190
+#: bundle.c:146
+msgid "need a repository to verify a bundle"
+msgstr "需要一个仓库来校验一个包"
+
+#: bundle.c:197
 #, c-format
 msgid "The bundle contains this ref:"
 msgid_plural "The bundle contains these %d refs:"
 msgstr[0] "这个包中含有这个引用："
 msgstr[1] "这个包中含有 %d 个引用："
 
-#: bundle.c:197
+#: bundle.c:204
 msgid "The bundle records a complete history."
 msgstr "这个包记录一个完整历史。"
 
-#: bundle.c:199
+#: bundle.c:206
 #, c-format
 msgid "The bundle requires this ref:"
 msgid_plural "The bundle requires these %d refs:"
 msgstr[0] "这个包需要这个引用："
 msgstr[1] "这个包需要 %d 个引用："
 
-#: bundle.c:258
+#: bundle.c:273
+msgid "unable to dup bundle descriptor"
+msgstr "无法复制 bundle 描述符"
+
+#: bundle.c:280
 msgid "Could not spawn pack-objects"
 msgstr "不能生成 pack-objects 进程"
 
-#: bundle.c:269
+#: bundle.c:291
 msgid "pack-objects died"
 msgstr "pack-objects 终止"
 
-#: bundle.c:311
+#: bundle.c:333
 msgid "rev-list died"
 msgstr "rev-list 终止"
 
-#: bundle.c:360
+#: bundle.c:382
 #, c-format
 msgid "ref '%s' is excluded by the rev-list options"
 msgstr "引用 '%s' 被 rev-list 选项排除"
 
-#: bundle.c:450 builtin/log.c:183 builtin/log.c:1607 builtin/shortlog.c:303
+#: bundle.c:461 builtin/log.c:203 builtin/log.c:1814 builtin/shortlog.c:306
 #, c-format
 msgid "unrecognized argument: %s"
 msgstr "未能识别的参数：%s"
 
-#: bundle.c:458
+#: bundle.c:469
 msgid "Refusing to create empty bundle."
 msgstr "不能创建空包。"
 
-#: bundle.c:470
+#: bundle.c:479
 #, c-format
 msgid "cannot create '%s'"
 msgstr "不能创建 '%s'"
 
-#: bundle.c:498
+#: bundle.c:504
 msgid "index-pack died"
 msgstr "index-pack 终止"
 
@@ -1336,19 +1854,18 @@ msgstr "index-pack 终止"
 msgid "invalid color value: %.*s"
 msgstr "无效的颜色值：%.*s"
 
-#: commit.c:43 sequencer.c:2364 builtin/am.c:421 builtin/am.c:465
-#: builtin/am.c:1436 builtin/am.c:2072 builtin/replace.c:376
-#: builtin/replace.c:448
+#: commit.c:51 sequencer.c:2811 builtin/am.c:354 builtin/am.c:398
+#: builtin/am.c:1366 builtin/am.c:2009 builtin/replace.c:456
 #, c-format
 msgid "could not parse %s"
 msgstr "不能解析 %s"
 
-#: commit.c:45
+#: commit.c:53
 #, c-format
 msgid "%s %s is not a commit!"
 msgstr "%s %s 不是一个提交！"
 
-#: commit.c:182
+#: commit.c:193
 msgid ""
 "Support for <GIT_DIR>/info/grafts is deprecated\n"
 "and will be removed in a future Git version.\n"
@@ -1368,7 +1885,27 @@ msgstr ""
 "设置 \"git config advice.graftFileDeprecated false\"\n"
 "可关闭本消息"
 
-#: commit.c:1540
+#: commit.c:1152
+#, c-format
+msgid "Commit %s has an untrusted GPG signature, allegedly by %s."
+msgstr "提交 %s 有一个非可信的声称来自 %s 的 GPG 签名。"
+
+#: commit.c:1155
+#, c-format
+msgid "Commit %s has a bad GPG signature allegedly by %s."
+msgstr "提交 %s 有一个错误的声称来自 %s 的 GPG 签名。"
+
+#: commit.c:1158
+#, c-format
+msgid "Commit %s does not have a GPG signature."
+msgstr "提交 %s 没有 GPG 签名。"
+
+#: commit.c:1161
+#, c-format
+msgid "Commit %s has a good GPG signature by %s\n"
+msgstr "提交 %s 有一个来自 %s 的好的 GPG 签名。\n"
+
+#: commit.c:1415
 msgid ""
 "Warning: commit message did not conform to UTF-8.\n"
 "You may want to amend it after fixing the message, or set the config\n"
@@ -1378,182 +1915,566 @@ msgstr ""
 "您可以通过修补提交来改正提交说明，或者将配置变量 i18n.commitencoding\n"
 "设置为您项目所用的字符编码。\n"
 
-#: commit-graph.c:669
+#: commit-graph.c:130
+msgid "commit-graph file is too small"
+msgstr "提交图形文件太小"
+
+#: commit-graph.c:195
+#, c-format
+msgid "commit-graph signature %X does not match signature %X"
+msgstr "提交图形签名 %X 和签名 %X 不匹配"
+
+#: commit-graph.c:202
+#, c-format
+msgid "commit-graph version %X does not match version %X"
+msgstr "提交图形版本 %X 和版本 %X 不匹配"
+
+#: commit-graph.c:209
+#, c-format
+msgid "commit-graph hash version %X does not match version %X"
+msgstr "提交图形哈希版本 %X 和版本 %X 不匹配"
+
+#: commit-graph.c:232
+msgid "commit-graph chunk lookup table entry missing; file may be incomplete"
+msgstr "提交图形块查找表条目丢失，文件可能不完整"
+
+#: commit-graph.c:243
+#, c-format
+msgid "commit-graph improper chunk offset %08x%08x"
+msgstr "提交图形不正确的块偏移 %08x%08x"
+
+#: commit-graph.c:286
+#, c-format
+msgid "commit-graph chunk id %08x appears multiple times"
+msgstr "提交图形块 id %08x 出现了多次"
+
+#: commit-graph.c:350
+msgid "commit-graph has no base graphs chunk"
+msgstr "提交图形没有基础图形块"
+
+#: commit-graph.c:360
+msgid "commit-graph chain does not match"
+msgstr "提交图形链不匹配"
+
+#: commit-graph.c:407
+#, c-format
+msgid "invalid commit-graph chain: line '%s' not a hash"
+msgstr "无效的提交图形链：行 '%s' 不是一个哈希值"
+
+#: commit-graph.c:433
+msgid "unable to find all commit-graph files"
+msgstr "无法找到所有提交图形文件"
+
+#: commit-graph.c:564 commit-graph.c:624
+msgid "invalid commit position. commit-graph is likely corrupt"
+msgstr "无效的提交位置。提交图形可能已损坏"
+
+#: commit-graph.c:585
+#, c-format
+msgid "could not find commit %s"
+msgstr "无法找到提交 %s"
+
+#: commit-graph.c:858 builtin/am.c:1287
+#, c-format
+msgid "unable to parse commit %s"
+msgstr "不能解析提交 %s"
+
+#: commit-graph.c:1017 builtin/pack-objects.c:2641
+#, c-format
+msgid "unable to get type of object %s"
+msgstr "无法获得对象 %s 类型"
+
+#: commit-graph.c:1049
+msgid "Loading known commits in commit graph"
+msgstr "正在加载提交图中的已知提交"
+
+#: commit-graph.c:1066
+msgid "Expanding reachable commits in commit graph"
+msgstr "正在扩展提交图中的可达提交"
+
+#: commit-graph.c:1085
+msgid "Clearing commit marks in commit graph"
+msgstr "正在清除提交图中的提交标记"
+
+#: commit-graph.c:1104
+msgid "Computing commit graph generation numbers"
+msgstr "正在计算提交图世代数字"
+
+#: commit-graph.c:1179
+#, c-format
+msgid "Finding commits for commit graph in %d pack"
+msgid_plural "Finding commits for commit graph in %d packs"
+msgstr[0] "正在 %d 个包中查找提交图的提交"
+msgstr[1] "正在 %d 个包中查找提交图的提交"
+
+#: commit-graph.c:1192
+#, c-format
+msgid "error adding pack %s"
+msgstr "添加包 %s 出错"
+
+#: commit-graph.c:1196
+#, c-format
+msgid "error opening index for %s"
+msgstr "为 %s 打开索引出错"
+
+#: commit-graph.c:1220
+#, c-format
+msgid "Finding commits for commit graph from %d ref"
+msgid_plural "Finding commits for commit graph from %d refs"
+msgstr[0] "正在从 %d 个引用中查找提交图的提交"
+msgstr[1] "正在从 %d 个引用中查找提交图的提交"
+
+#: commit-graph.c:1240
+#, c-format
+msgid "invalid commit object id: %s"
+msgstr "无效的提交对象 ID：%s"
+
+#: commit-graph.c:1255
+msgid "Finding commits for commit graph among packed objects"
+msgstr "正在打包对象中查找提交图的提交"
+
+#: commit-graph.c:1270
+msgid "Counting distinct commits in commit graph"
+msgstr "正在计算提交图中不同的提交"
+
+#: commit-graph.c:1300
+msgid "Finding extra edges in commit graph"
+msgstr "正在查找提交图中额外的边"
+
+#: commit-graph.c:1346
+msgid "failed to write correct number of base graph ids"
+msgstr "无法写入正确数量的基础图形 ID"
+
+#: commit-graph.c:1379 midx.c:814
+#, c-format
+msgid "unable to create leading directories of %s"
+msgstr "不能为 %s 创建先导目录"
+
+#: commit-graph.c:1391 builtin/index-pack.c:306 builtin/repack.c:248
+#, c-format
+msgid "unable to create '%s'"
+msgstr "不能创建 '%s'"
+
+#: commit-graph.c:1451
+#, c-format
+msgid "Writing out commit graph in %d pass"
+msgid_plural "Writing out commit graph in %d passes"
+msgstr[0] "正在用 %d 步写出提交图"
+msgstr[1] "正在用 %d 步写出提交图"
+
+#: commit-graph.c:1492
+msgid "unable to open commit-graph chain file"
+msgstr "无法打开提交图形链文件"
+
+#: commit-graph.c:1504
+msgid "failed to rename base commit-graph file"
+msgstr "无法重命名基础提交图形文件"
+
+#: commit-graph.c:1524
+msgid "failed to rename temporary commit-graph file"
+msgstr "无法重命名临时提交图形文件"
+
+#: commit-graph.c:1635
+msgid "Scanning merged commits"
+msgstr "正在扫描合并提交"
+
+#: commit-graph.c:1646
+#, c-format
+msgid "unexpected duplicate commit id %s"
+msgstr "意外的重复提交 ID %s"
+
+#: commit-graph.c:1670
+msgid "Merging commit-graph"
+msgstr "正在合并提交图形"
+
+#: commit-graph.c:1860
 #, c-format
 msgid "the commit graph format cannot write %d commits"
-msgstr "提交图形格式不能写入 %d 个提交"
+msgstr "提交图格式不能写入 %d 个提交"
 
-#: commit-graph.c:696
+#: commit-graph.c:1871
 msgid "too many commits to write graph"
 msgstr "提交太多不能画图"
 
-#: commit-graph.c:707 builtin/init-db.c:516 builtin/init-db.c:521
+#: commit-graph.c:1961
+msgid "the commit-graph file has incorrect checksum and is likely corrupt"
+msgstr "提交图文件的校验码错误，可能已经损坏"
+
+#: commit-graph.c:1971
 #, c-format
-msgid "cannot mkdir %s"
-msgstr "不能创建目录 %s"
+msgid "commit-graph has incorrect OID order: %s then %s"
+msgstr "提交图形的对象 ID 顺序不正确：%s 然后 %s"
+
+#: commit-graph.c:1981 commit-graph.c:1996
+#, c-format
+msgid "commit-graph has incorrect fanout value: fanout[%d] = %u != %u"
+msgstr "提交图形有不正确的扇出值：fanout[%d] = %u != %u"
+
+#: commit-graph.c:1988
+#, c-format
+msgid "failed to parse commit %s from commit-graph"
+msgstr "无法从提交图形中解析提交 %s"
+
+#: commit-graph.c:2006
+msgid "Verifying commits in commit graph"
+msgstr "正在校验提交图中的提交"
+
+#: commit-graph.c:2020
+#, c-format
+msgid "failed to parse commit %s from object database for commit-graph"
+msgstr "无法从提交图形的对象库中解析提交 %s"
+
+#: commit-graph.c:2027
+#, c-format
+msgid "root tree OID for commit %s in commit-graph is %s != %s"
+msgstr "提交图形中的提交 %s 的根树对象 ID 是 %s != %s"
+
+#: commit-graph.c:2037
+#, c-format
+msgid "commit-graph parent list for commit %s is too long"
+msgstr "提交 %s 的提交图形父提交列表太长了"
+
+#: commit-graph.c:2046
+#, c-format
+msgid "commit-graph parent for %s is %s != %s"
+msgstr "%s 的提交图形父提交是 %s != %s"
+
+#: commit-graph.c:2059
+#, c-format
+msgid "commit-graph parent list for commit %s terminates early"
+msgstr "提交 %s 的提交图形父提交列表过早终止"
+
+#: commit-graph.c:2064
+#, c-format
+msgid ""
+"commit-graph has generation number zero for commit %s, but non-zero elsewhere"
+msgstr "提交图形中提交 %s 的世代号是零，但其它地方非零"
+
+#: commit-graph.c:2068
+#, c-format
+msgid ""
+"commit-graph has non-zero generation number for commit %s, but zero elsewhere"
+msgstr "提交图形中提交 %s 的世代号非零，但其它地方是零"
+
+#: commit-graph.c:2083
+#, c-format
+msgid "commit-graph generation for commit %s is %u != %u"
+msgstr "提交图形中的提交 %s 的世代号是 %u != %u"
+
+#: commit-graph.c:2089
+#, c-format
+msgid "commit date for commit %s in commit-graph is %<PRIuMAX> != %<PRIuMAX>"
+msgstr "提交图形中提交 %s 的提交日期是 %<PRIuMAX> != %<PRIuMAX>"
 
-#: compat/obstack.c:405 compat/obstack.c:407
+#: compat/obstack.c:406 compat/obstack.c:408
 msgid "memory exhausted"
 msgstr "内存耗尽"
 
-#: config.c:187
+#: config.c:124
+#, c-format
+msgid ""
+"exceeded maximum include depth (%d) while including\n"
+"\t%s\n"
+"from\n"
+"\t%s\n"
+"This might be due to circular includes."
+msgstr ""
+"超过了最大包含深度（%1$d），当从\n"
+"\t%3$s\n"
+"包含\n"
+"\t%2$s\n"
+"这可能是因为循环包含。"
+
+#: config.c:140
+#, c-format
+msgid "could not expand include path '%s'"
+msgstr "无法扩展包含路径 '%s'"
+
+#: config.c:151
+msgid "relative config includes must come from files"
+msgstr "相对路径的配置文件引用必须来自于文件"
+
+#: config.c:197
 msgid "relative config include conditionals must come from files"
-msgstr "包含相对路径的条件引用必须来自于文件"
+msgstr "相对路径的配置文件条件引用必须来自于文件"
+
+#: config.c:376
+#, c-format
+msgid "key does not contain a section: %s"
+msgstr "键名没有包含一个小节名称：%s"
+
+#: config.c:382
+#, c-format
+msgid "key does not contain variable name: %s"
+msgstr "键名没有包含变量名：%s"
 
-#: config.c:788
+#: config.c:406 sequencer.c:2530
+#, c-format
+msgid "invalid key: %s"
+msgstr "无效键名：%s"
+
+#: config.c:412
+#, c-format
+msgid "invalid key (newline): %s"
+msgstr "无效键名（有换行符）：%s"
+
+#: config.c:448 config.c:460
+#, c-format
+msgid "bogus config parameter: %s"
+msgstr "伪配置参数：%s"
+
+#: config.c:495
+#, c-format
+msgid "bogus format in %s"
+msgstr "%s 中格式错误"
+
+#: config.c:821
 #, c-format
 msgid "bad config line %d in blob %s"
 msgstr "数据对象 %2$s 中错误的配置行 %1$d"
 
-#: config.c:792
+#: config.c:825
 #, c-format
 msgid "bad config line %d in file %s"
 msgstr "文件 %2$s 中错误的配置行 %1$d"
 
-#: config.c:796
+#: config.c:829
 #, c-format
 msgid "bad config line %d in standard input"
 msgstr "标准输入中错误的配置行 %d"
 
-#: config.c:800
+#: config.c:833
 #, c-format
 msgid "bad config line %d in submodule-blob %s"
 msgstr "子模组数据对象 %2$s 中错误的配置行 %1$d"
 
-#: config.c:804
+#: config.c:837
 #, c-format
 msgid "bad config line %d in command line %s"
 msgstr "命令行 %2$s 中错误的配置行 %1$d"
 
-#: config.c:808
+#: config.c:841
 #, c-format
 msgid "bad config line %d in %s"
 msgstr "在 %2$s 中错误的配置行 %1$d"
 
-#: config.c:936
+#: config.c:978
 msgid "out of range"
 msgstr "超出范围"
 
-#: config.c:936
+#: config.c:978
 msgid "invalid unit"
 msgstr "无效的单位"
 
-#: config.c:942
+#: config.c:979
 #, c-format
 msgid "bad numeric config value '%s' for '%s': %s"
 msgstr "配置变量 '%2$s' 的数字取值 '%1$s' 设置错误：%3$s"
 
-#: config.c:947
+#: config.c:998
 #, c-format
 msgid "bad numeric config value '%s' for '%s' in blob %s: %s"
 msgstr "数据对象 %3$s 中配置变量 '%2$s' 错误的取值 '%1$s'：%4$s"
 
-#: config.c:950
+#: config.c:1001
 #, c-format
 msgid "bad numeric config value '%s' for '%s' in file %s: %s"
 msgstr "文件 %3$s 中配置变量 '%2$s' 错误的取值 '%1$s'：%4$s"
 
-#: config.c:953
+#: config.c:1004
 #, c-format
 msgid "bad numeric config value '%s' for '%s' in standard input: %s"
 msgstr "标准输入中配置变量 '%2$s' 错误的取值 '%1$s'：%3$s"
 
-#: config.c:956
+#: config.c:1007
 #, c-format
 msgid "bad numeric config value '%s' for '%s' in submodule-blob %s: %s"
 msgstr "子模组数据 %3$s 中配置变量 '%2$s' 错误的取值 '%1$s'：%4$s"
 
-#: config.c:959
+#: config.c:1010
 #, c-format
 msgid "bad numeric config value '%s' for '%s' in command line %s: %s"
 msgstr "命令行 %3$s 中配置变量 '%2$s' 错误的取值 '%1$s'：%4$s"
 
-#: config.c:962
+#: config.c:1013
 #, c-format
 msgid "bad numeric config value '%s' for '%s' in %s: %s"
 msgstr "在 %3$s 中配置变量 '%2$s' 错误的取值 '%1$s'：%4$s"
 
-#: config.c:1057
+#: config.c:1108
 #, c-format
 msgid "failed to expand user dir in: '%s'"
-msgstr "无法扩展 '%s' 中的用户目录"
+msgstr "无法扩展用户目录：'%s'"
 
-#: config.c:1066
+#: config.c:1117
 #, c-format
 msgid "'%s' for '%s' is not a valid timestamp"
 msgstr "'%2$s' 的值 '%1$s' 不是一个有效的时间戳"
 
-#: config.c:1171 config.c:1182
+#: config.c:1208
+#, c-format
+msgid "abbrev length out of range: %d"
+msgstr "缩写长度超出范围：%d"
+
+#: config.c:1222 config.c:1233
 #, c-format
 msgid "bad zlib compression level %d"
 msgstr "错误的 zlib 压缩级别 %d"
 
-#: config.c:1307
+#: config.c:1325
+msgid "core.commentChar should only be one character"
+msgstr "core.commentChar 应该是一个字符"
+
+#: config.c:1358
 #, c-format
 msgid "invalid mode for object creation: %s"
 msgstr "无效的对象创建模式：%s"
 
-#: config.c:1473
+#: config.c:1430
+#, c-format
+msgid "malformed value for %s"
+msgstr "%s 的取值格式错误"
+
+#: config.c:1456
+#, c-format
+msgid "malformed value for %s: %s"
+msgstr "%s 的取值格式错误：%s"
+
+#: config.c:1457
+msgid "must be one of nothing, matching, simple, upstream or current"
+msgstr "必须是其中之一：nothing、matching、simple、upstream 或 current"
+
+#: config.c:1518 builtin/pack-objects.c:3394
 #, c-format
 msgid "bad pack compression level %d"
 msgstr "错误的打包压缩级别 %d"
 
-#: config.c:1681
+#: config.c:1639
+#, c-format
+msgid "unable to load config blob object '%s'"
+msgstr "无法从数据对象 '%s' 加载配置"
+
+#: config.c:1642
+#, c-format
+msgid "reference '%s' does not point to a blob"
+msgstr "引用 '%s' 没有指向一个数据对象"
+
+#: config.c:1659
+#, c-format
+msgid "unable to resolve config blob '%s'"
+msgstr "不能解析配置对象 '%s'"
+
+#: config.c:1689
+#, c-format
+msgid "failed to parse %s"
+msgstr "解析 %s 失败"
+
+#: config.c:1745
 msgid "unable to parse command-line config"
 msgstr "无法解析命令行中的配置"
 
-#: config.c:2013
+#: config.c:2096
 msgid "unknown error occurred while reading the configuration files"
 msgstr "在读取配置文件时遇到未知错误"
 
-#: config.c:2200
+#: config.c:2266
 #, c-format
 msgid "Invalid %s: '%s'"
 msgstr "无效 %s：'%s'"
 
-#: config.c:2243
-#, c-format
-msgid "unknown core.untrackedCache value '%s'; using 'keep' default value"
-msgstr "未知的 core.untrackedCache 取值 '%s'，使用默认值 'keep'"
-
-#: config.c:2269
+#: config.c:2311
 #, c-format
 msgid "splitIndex.maxPercentChange value '%d' should be between 0 and 100"
 msgstr "splitIndex.maxPercentChange 的取值 '%d' 应该介于 0 和 100 之间"
 
-#: config.c:2294
+#: config.c:2357
 #, c-format
 msgid "unable to parse '%s' from command-line config"
 msgstr "无法解析命令行配置中的 '%s'"
 
-#: config.c:2296
+#: config.c:2359
 #, c-format
 msgid "bad config variable '%s' in file '%s' at line %d"
 msgstr "在文件 '%2$s' 的第 %3$d 行发现错误的配置变量 '%1$s'"
 
-#: config.c:2402
+#: config.c:2440
+#, c-format
+msgid "invalid section name '%s'"
+msgstr "无效的小节名称 '%s'"
+
+#: config.c:2472
 #, c-format
 msgid "%s has multiple values"
 msgstr "%s 有多个取值"
 
-#: config.c:2766 config.c:3019
+#: config.c:2501
+#, c-format
+msgid "failed to write new configuration file %s"
+msgstr "写入新的配置文件 %s 失败"
+
+#: config.c:2753 config.c:3077
+#, c-format
+msgid "could not lock config file %s"
+msgstr "不能锁定配置文件 %s"
+
+#: config.c:2764
+#, c-format
+msgid "opening %s"
+msgstr "打开 %s"
+
+#: config.c:2799 builtin/config.c:328
+#, c-format
+msgid "invalid pattern: %s"
+msgstr "无效模式：%s"
+
+#: config.c:2824
+#, c-format
+msgid "invalid config file %s"
+msgstr "无效的配置文件 %s"
+
+#: config.c:2837 config.c:3090
 #, c-format
 msgid "fstat on %s failed"
 msgstr "对 %s 调用 fstat 失败"
 
-#: config.c:2905
+#: config.c:2848
+#, c-format
+msgid "unable to mmap '%s'"
+msgstr "不能 mmap '%s'"
+
+#: config.c:2857 config.c:3095
+#, c-format
+msgid "chmod on %s failed"
+msgstr "对 %s 调用 chmod 失败"
+
+#: config.c:2942 config.c:3192
+#, c-format
+msgid "could not write config file %s"
+msgstr "不能写入配置文件 %s"
+
+#: config.c:2976
 #, c-format
 msgid "could not set '%s' to '%s'"
 msgstr "不能设置 '%s' 为 '%s'"
 
-#: config.c:2907 builtin/remote.c:779
+#: config.c:2978 builtin/remote.c:781
 #, c-format
 msgid "could not unset '%s'"
 msgstr "不能取消设置 '%s'"
 
+#: config.c:3068
+#, c-format
+msgid "invalid section name: %s"
+msgstr "无效的小节名称：%s"
+
+#: config.c:3235
+#, c-format
+msgid "missing value for '%s'"
+msgstr "%s 的取值缺失"
+
 #: connect.c:61
-msgid "The remote end hung up upon initial contact"
-msgstr "远端在连接发起时即挂断"
+msgid "the remote end hung up upon initial contact"
+msgstr "远端在初始连接时即挂断"
 
 #: connect.c:63
 msgid ""
@@ -1566,137 +2487,335 @@ msgstr ""
 "\n"
 "请确认您有正确的访问权限并且仓库存在。"
 
-#: connected.c:66 builtin/fsck.c:201 builtin/prune.c:145
-msgid "Checking connectivity"
-msgstr "检查连接中"
+#: connect.c:81
+#, c-format
+msgid "server doesn't support '%s'"
+msgstr "服务器不支持 '%s'"
 
-#: connected.c:78
-msgid "Could not run 'git rev-list'"
-msgstr "不能执行 'git rev-list'"
+#: connect.c:103
+#, c-format
+msgid "server doesn't support feature '%s'"
+msgstr "服务器不支持特性 '%s'"
 
-#: connected.c:98
-msgid "failed write to rev-list"
-msgstr "无法写入 rev-list"
+#: connect.c:114
+msgid "expected flush after capabilities"
+msgstr "在能力之后应为一个 flush 包"
 
-#: connected.c:105
-msgid "failed to close rev-list's stdin"
-msgstr "无法关闭 rev-list 的标准输入"
+#: connect.c:233
+#, c-format
+msgid "ignoring capabilities after first line '%s'"
+msgstr "忽略第一行 '%s' 之后的能力字段"
 
-#: convert.c:206
+#: connect.c:252
+msgid "protocol error: unexpected capabilities^{}"
+msgstr "协议错误：意外的 capabilities^{}"
+
+#: connect.c:273
 #, c-format
-msgid "CRLF would be replaced by LF in %s."
-msgstr "文件 %s 中的 CRLF 将被 LF 替换。"
+msgid "protocol error: expected shallow sha-1, got '%s'"
+msgstr "协议错误：预期浅克隆 sha-1，却得到 '%s'"
+
+#: connect.c:275
+msgid "repository on the other end cannot be shallow"
+msgstr "另一端的仓库不能是浅克隆仓库"
 
-#: convert.c:208
+#: connect.c:313
+msgid "invalid packet"
+msgstr "无效数据包"
+
+#: connect.c:333
 #, c-format
-msgid ""
-"CRLF will be replaced by LF in %s.\n"
-"The file will have its original line endings in your working directory."
-msgstr ""
-"文件 %s 中的 CRLF 将被 LF 替换。\n"
-"在工作区中该文件仍保持原有的换行符。"
+msgid "protocol error: unexpected '%s'"
+msgstr "协议错误：意外的 '%s'"
 
-#: convert.c:216
+#: connect.c:441
 #, c-format
-msgid "LF would be replaced by CRLF in %s"
-msgstr "文件 %s 中的 LF 将被 CRLF 替换"
+msgid "invalid ls-refs response: %s"
+msgstr "无效的 ls-refs 响应：%s"
+
+#: connect.c:445
+msgid "expected flush after ref listing"
+msgstr "在引用列表之后应该有一个 flush 包"
 
-#: convert.c:218
+#: connect.c:544
 #, c-format
-msgid ""
-"LF will be replaced by CRLF in %s.\n"
-"The file will have its original line endings in your working directory."
-msgstr ""
-"文件 %s 中的 LF 将被 CRLF 替换。\n"
-"在工作区中该文件仍保持原有的换行符。"
+msgid "protocol '%s' is not supported"
+msgstr "不支持 '%s' 协议"
 
-#: convert.c:279
+#: connect.c:595
+msgid "unable to set SO_KEEPALIVE on socket"
+msgstr "无法为 socket 设置 SO_KEEPALIVE"
+
+#: connect.c:635 connect.c:698
 #, c-format
-msgid "BOM is prohibited in '%s' if encoded as %s"
-msgstr "如果使用 %2$s 编码，禁止在 '%1$s' 中使用 BOM"
+msgid "Looking up %s ... "
+msgstr "查找 %s ..."
 
-#: convert.c:286
+#: connect.c:639
 #, c-format
-msgid ""
-"The file '%s' contains a byte order mark (BOM). Please use UTF-%s as working-"
-"tree-encoding."
-msgstr "文件 '%s' 包含一个字节顺序标记（BOM）。请使用 UTF-%s 作为工作区编码。"
+msgid "unable to look up %s (port %s) (%s)"
+msgstr "无法查找 %s（端口 %s）（%s）"
 
-#: convert.c:304
+#. TRANSLATORS: this is the end of "Looking up %s ... "
+#: connect.c:643 connect.c:714
 #, c-format
-msgid "BOM is required in '%s' if encoded as %s"
-msgstr "如果编码为 %2$s，需要在 '%1$s' 中使用 BOM"
+msgid ""
+"done.\n"
+"Connecting to %s (port %s) ... "
+msgstr ""
+"完成。\n"
+"连接到 %s（端口 %s）... "
 
-#: convert.c:306
+#: connect.c:665 connect.c:742
 #, c-format
 msgid ""
-"The file '%s' is missing a byte order mark (BOM). Please use UTF-%sBE or UTF-"
-"%sLE (depending on the byte order) as working-tree-encoding."
+"unable to connect to %s:\n"
+"%s"
 msgstr ""
-"文件 '%s' 缺失一个字节顺序标记（BOM）。请使用 UTF-%sBE or UTF-%sLE（取决于字"
-"节序）作为工作区编码。"
+"无法连接到 %s：\n"
+"%s"
 
-#: convert.c:424
+#. TRANSLATORS: this is the end of "Connecting to %s (port %s) ... "
+#: connect.c:671 connect.c:748
+msgid "done."
+msgstr "完成。"
+
+#: connect.c:702
 #, c-format
-msgid "failed to encode '%s' from %s to %s"
-msgstr "无法对 '%s' 进行从 %s 到 %s 的编码"
+msgid "unable to look up %s (%s)"
+msgstr "无法查找 %s（%s）"
 
-#: convert.c:467
+#: connect.c:708
 #, c-format
-msgid "encoding '%s' from %s to %s and back is not the same"
-msgstr "将'%s' 的编码从 %s 到 %s 来回转换不一致"
+msgid "unknown port %s"
+msgstr "未知端口 %s"
 
-#: convert.c:1225
-msgid "true/false are no valid working-tree-encodings"
-msgstr "true/false 不是有效的工作区编码"
+#: connect.c:845 connect.c:1175
+#, c-format
+msgid "strange hostname '%s' blocked"
+msgstr "已阻止奇怪的主机名 '%s'"
 
-#: date.c:116
+#: connect.c:847
+#, c-format
+msgid "strange port '%s' blocked"
+msgstr "已阻止奇怪的端口号 '%s'"
+
+#: connect.c:857
+#, c-format
+msgid "cannot start proxy %s"
+msgstr "不能启动代理 %s"
+
+#: connect.c:928
+msgid "no path specified; see 'git help pull' for valid url syntax"
+msgstr "未指定路径，执行 'git help pull' 查看有效的 url 语法"
+
+#: connect.c:1123
+msgid "ssh variant 'simple' does not support -4"
+msgstr "ssh 变体 'simple' 不支持 -4"
+
+#: connect.c:1135
+msgid "ssh variant 'simple' does not support -6"
+msgstr "ssh 变体 'simple' 不支持 -6"
+
+#: connect.c:1152
+msgid "ssh variant 'simple' does not support setting port"
+msgstr "ssh 变体 'simple' 不支持设置端口"
+
+#: connect.c:1264
+#, c-format
+msgid "strange pathname '%s' blocked"
+msgstr "已阻止奇怪的路径名 '%s'"
+
+#: connect.c:1311
+msgid "unable to fork"
+msgstr "无法 fork"
+
+#: connected.c:89 builtin/fsck.c:208 builtin/prune.c:43
+msgid "Checking connectivity"
+msgstr "正在检查连通性"
+
+#: connected.c:101
+msgid "Could not run 'git rev-list'"
+msgstr "不能执行 'git rev-list'"
+
+#: connected.c:121
+msgid "failed write to rev-list"
+msgstr "写入 rev-list 失败"
+
+#: connected.c:128
+msgid "failed to close rev-list's stdin"
+msgstr "关闭 rev-list 的标准输入失败"
+
+#: convert.c:194
+#, c-format
+msgid "illegal crlf_action %d"
+msgstr "非法的 crlf 动作 %d"
+
+#: convert.c:207
+#, c-format
+msgid "CRLF would be replaced by LF in %s"
+msgstr "%s 中的 CRLF 将被 LF 替换"
+
+#: convert.c:209
+#, c-format
+msgid ""
+"CRLF will be replaced by LF in %s.\n"
+"The file will have its original line endings in your working directory"
+msgstr ""
+"%s 中的 CRLF 将被 LF 替换。<\n"
+"在工作区中该文件仍保持原有的换行符。"
+
+#: convert.c:217
+#, c-format
+msgid "LF would be replaced by CRLF in %s"
+msgstr "文件 %s 中的 LF 将被 CRLF 替换"
+
+#: convert.c:219
+#, c-format
+msgid ""
+"LF will be replaced by CRLF in %s.\n"
+"The file will have its original line endings in your working directory"
+msgstr ""
+"%s 中的 LF 将被 CRLF 替换。\n"
+"在工作区中该文件仍保持原有的换行符"
+
+#: convert.c:284
+#, c-format
+msgid "BOM is prohibited in '%s' if encoded as %s"
+msgstr "如果使用 %2$s 编码，禁止在 '%1$s' 中使用 BOM"
+
+#: convert.c:291
+#, c-format
+msgid ""
+"The file '%s' contains a byte order mark (BOM). Please use UTF-%.*s as "
+"working-tree-encoding."
+msgstr "文件 '%s' 包含一个字节顺序标记（BOM）。请使用 UTF-%.*s 作为工作区编码。"
+
+#: convert.c:304
+#, c-format
+msgid "BOM is required in '%s' if encoded as %s"
+msgstr "如果编码为 %2$s，需要在 '%1$s' 中使用 BOM"
+
+#: convert.c:306
+#, c-format
+msgid ""
+"The file '%s' is missing a byte order mark (BOM). Please use UTF-%sBE or UTF-"
+"%sLE (depending on the byte order) as working-tree-encoding."
+msgstr ""
+"文件 '%s' 缺失一个字节顺序标记（BOM）。请使用 UTF-%sBE or UTF-%sLE（取决于字"
+"节序）作为工作区编码。"
+
+#: convert.c:419 convert.c:490
+#, c-format
+msgid "failed to encode '%s' from %s to %s"
+msgstr "无法对 '%s' 进行从 %s 到 %s 的编码"
+
+#: convert.c:462
+#, c-format
+msgid "encoding '%s' from %s to %s and back is not the same"
+msgstr "将'%s' 的编码从 %s 到 %s 来回转换不一致"
+
+#: convert.c:668
+#, c-format
+msgid "cannot fork to run external filter '%s'"
+msgstr "不能 fork 以执行外部过滤器 '%s'"
+
+#: convert.c:688
+#, c-format
+msgid "cannot feed the input to external filter '%s'"
+msgstr "不能将输入传递给外部过滤器 '%s'"
+
+#: convert.c:695
+#, c-format
+msgid "external filter '%s' failed %d"
+msgstr "外部过滤器 '%s' 失败码 %d"
+
+#: convert.c:730 convert.c:733
+#, c-format
+msgid "read from external filter '%s' failed"
+msgstr "从外部过滤器 '%s' 读取失败"
+
+#: convert.c:736 convert.c:791
+#, c-format
+msgid "external filter '%s' failed"
+msgstr "外部过滤器 '%s' 失败"
+
+#: convert.c:839
+msgid "unexpected filter type"
+msgstr "意外的过滤类型"
+
+#: convert.c:850
+msgid "path name too long for external filter"
+msgstr "外部过滤器的路径名太长"
+
+#: convert.c:924
+#, c-format
+msgid ""
+"external filter '%s' is not available anymore although not all paths have "
+"been filtered"
+msgstr "外部过滤器 '%s' 不再可用，但并非所有路径都已过滤"
+
+#: convert.c:1223
+msgid "true/false are no valid working-tree-encodings"
+msgstr "true/false 不是有效的工作区编码"
+
+#: convert.c:1411 convert.c:1445
+#, c-format
+msgid "%s: clean filter '%s' failed"
+msgstr "%s：clean 过滤器 '%s' 失败"
+
+#: convert.c:1489
+#, c-format
+msgid "%s: smudge filter %s failed"
+msgstr "%s：smudge 过滤器 %s 失败"
+
+#: date.c:138
 msgid "in the future"
 msgstr "在将来"
 
-#: date.c:122
+#: date.c:144
 #, c-format
 msgid "%<PRIuMAX> second ago"
 msgid_plural "%<PRIuMAX> seconds ago"
 msgstr[0] "%<PRIuMAX> 秒钟前"
 msgstr[1] "%<PRIuMAX> 秒钟前"
 
-#: date.c:129
+#: date.c:151
 #, c-format
 msgid "%<PRIuMAX> minute ago"
 msgid_plural "%<PRIuMAX> minutes ago"
 msgstr[0] "%<PRIuMAX> 分钟前"
 msgstr[1] "%<PRIuMAX> 分钟前"
 
-#: date.c:136
+#: date.c:158
 #, c-format
 msgid "%<PRIuMAX> hour ago"
 msgid_plural "%<PRIuMAX> hours ago"
 msgstr[0] "%<PRIuMAX> 小时前"
 msgstr[1] "%<PRIuMAX> 小时前"
 
-#: date.c:143
+#: date.c:165
 #, c-format
 msgid "%<PRIuMAX> day ago"
 msgid_plural "%<PRIuMAX> days ago"
 msgstr[0] "%<PRIuMAX> 天前"
 msgstr[1] "%<PRIuMAX> 天前"
 
-#: date.c:149
+#: date.c:171
 #, c-format
 msgid "%<PRIuMAX> week ago"
 msgid_plural "%<PRIuMAX> weeks ago"
 msgstr[0] "%<PRIuMAX> 周前"
 msgstr[1] "%<PRIuMAX> 周前"
 
-#: date.c:156
+#: date.c:178
 #, c-format
 msgid "%<PRIuMAX> month ago"
 msgid_plural "%<PRIuMAX> months ago"
 msgstr[0] "%<PRIuMAX> 个月前"
 msgstr[1] "%<PRIuMAX> 个月前"
 
-#: date.c:167
+#: date.c:189
 #, c-format
 msgid "%<PRIuMAX> year"
 msgid_plural "%<PRIuMAX> years"
@@ -1704,59 +2823,104 @@ msgstr[0] "%<PRIuMAX> 年"
 msgstr[1] "%<PRIuMAX> 年"
 
 #. TRANSLATORS: "%s" is "<n> years"
-#: date.c:170
+#: date.c:192
 #, c-format
 msgid "%s, %<PRIuMAX> month ago"
 msgid_plural "%s, %<PRIuMAX> months ago"
 msgstr[0] "%s %<PRIuMAX> 个月前"
 msgstr[1] "%s %<PRIuMAX> 个月前"
 
-#: date.c:175 date.c:180
+#: date.c:197 date.c:202
 #, c-format
 msgid "%<PRIuMAX> year ago"
 msgid_plural "%<PRIuMAX> years ago"
 msgstr[0] "%<PRIuMAX> 年前"
 msgstr[1] "%<PRIuMAX> 年前"
 
+#: delta-islands.c:272
+msgid "Propagating island marks"
+msgstr "正在传播数据岛标记"
+
+#: delta-islands.c:290
+#, c-format
+msgid "bad tree object %s"
+msgstr "坏的树对象 %s"
+
+#: delta-islands.c:334
+#, c-format
+msgid "failed to load island regex for '%s': %s"
+msgstr "未能加载 '%s' 的数据岛正则表达式：%s"
+
+#: delta-islands.c:390
+#, c-format
+msgid "island regex from config has too many capture groups (max=%d)"
+msgstr "来自 config 的数据岛正则表达式有太多的捕获组（最多 %d 个）"
+
+#: delta-islands.c:467
+#, c-format
+msgid "Marked %d islands, done.\n"
+msgstr "已标记 %d 个数据岛，结束。\n"
+
 #: diffcore-order.c:24
 #, c-format
 msgid "failed to read orderfile '%s'"
-msgstr "无法读取排序文件 '%s'"
+msgstr "读取排序文件 '%s' 失败"
 
-#: diffcore-rename.c:535
+#: diffcore-rename.c:543
 msgid "Performing inexact rename detection"
 msgstr "正在进行非精确的重命名探测"
 
-#: diff.c:74
-#, c-format
-msgid "option '%s' requires a value"
-msgstr "选项 '%s'  需要一个值"
+#: diff-no-index.c:238
+msgid "git diff --no-index [<options>] <path> <path>"
+msgstr "git diff --no-index [<选项>] <路径> <路径>"
+
+#: diff-no-index.c:263
+msgid ""
+"Not a git repository. Use --no-index to compare two paths outside a working "
+"tree"
+msgstr "不是一个 git 仓库。使用 --no-index 比较工作区之外的两个路径"
 
 #  译者：注意保持前导空格
-#: diff.c:152
+#: diff.c:155
 #, c-format
 msgid "  Failed to parse dirstat cut-off percentage '%s'\n"
 msgstr "  无法解析 dirstat 截止（cut-off）百分比 '%s'\n"
 
 #  译者：注意保持前导空格
-#: diff.c:157
+#: diff.c:160
 #, c-format
 msgid "  Unknown dirstat parameter '%s'\n"
 msgstr "  未知的 dirstat 参数 '%s'\n"
 
-#: diff.c:281
+#: diff.c:296
 msgid ""
-"color moved setting must be one of 'no', 'default', 'zebra', 'dimmed_zebra', "
+"color moved setting must be one of 'no', 'default', 'blocks', 'zebra', "
+"'dimmed-zebra', 'plain'"
+msgstr ""
+"移动的颜色设置必须是 'no'、'default'、'blocks'、'zebra'、'dimmed_zebra' 或 "
 "'plain'"
+
+#: diff.c:324
+#, c-format
+msgid ""
+"unknown color-moved-ws mode '%s', possible values are 'ignore-space-change', "
+"'ignore-space-at-eol', 'ignore-all-space', 'allow-indentation-change'"
 msgstr ""
-"代码移动的颜色设置必须是 'no'、'default'、'zebra'、'dimmed_zebra' 或 'plain'"
+"未知的 color-moved-ws 模式 '%s'，可能的取值有 'ignore-space-change'、'ignore-"
+"space-at-eol'、'ignore-all-space'、'allow-indentation-change'"
 
-#: diff.c:341
+#: diff.c:332
+msgid ""
+"color-moved-ws: allow-indentation-change cannot be combined with other "
+"whitespace modes"
+msgstr "color-moved-ws：allow-indentation-change 不能与其它空白字符模式共用"
+
+#: diff.c:405
 #, c-format
 msgid "Unknown value for 'diff.submodule' config variable: '%s'"
 msgstr "配置变量 'diff.submodule' 未知的取值：'%s'"
 
-#: diff.c:401
+#: diff.c:465
 #, c-format
 msgid ""
 "Found errors in 'diff.dirstat' config variable:\n"
@@ -1765,24 +2929,35 @@ msgstr ""
 "发现配置变量 'diff.dirstat' 中的错误：\n"
 "%s"
 
-#: diff.c:3823
+#: diff.c:4202
 #, c-format
 msgid "external diff died, stopping at %s"
 msgstr "外部 diff 退出，停止在 %s"
 
-#: diff.c:4153
+#: diff.c:4547
 msgid "--name-only, --name-status, --check and -s are mutually exclusive"
 msgstr "--name-only、--name-status、--check 和 -s 是互斥的"
 
-#: diff.c:4156
+#: diff.c:4550
 msgid "-G, -S and --find-object are mutually exclusive"
 msgstr "-G、-S 和 --find-object 是互斥的"
 
-#: diff.c:4244
+#: diff.c:4628
 msgid "--follow requires exactly one pathspec"
 msgstr "--follow 明确要求只跟一个路径规格"
 
-#: diff.c:4410
+#: diff.c:4676
+#, c-format
+msgid "invalid --stat value: %s"
+msgstr "无效的 --stat 值：%s"
+
+#: diff.c:4681 diff.c:4686 diff.c:4691 diff.c:4696 diff.c:5209
+#: parse-options.c:199 parse-options.c:203
+#, c-format
+msgid "%s expects a numerical value"
+msgstr "%s 期望一个数字值"
+
+#: diff.c:4713
 #, c-format
 msgid ""
 "Failed to parse --dirstat/-X option parameter:\n"
@@ -1791,10858 +2966,15133 @@ msgstr ""
 "无法解析 --dirstat/-X 选项的参数：\n"
 "%s"
 
-#: diff.c:4424
+#: diff.c:4798
 #, c-format
-msgid "Failed to parse --submodule option parameter: '%s'"
-msgstr "无法解析 --submodule 选项的参数：'%s'"
+msgid "unknown change class '%c' in --diff-filter=%s"
+msgstr "--diff-filter=%2$s 中未知的变更类 '%1$c'"
 
-#: diff.c:5500
-msgid "inexact rename detection was skipped due to too many files."
-msgstr "因为文件太多，略过不严格的重命名检查。"
+#: diff.c:4822
+#, c-format
+msgid "unknown value after ws-error-highlight=%.*s"
+msgstr "ws-error-highlight=%.*s 之后未知的值"
 
-#: diff.c:5503
-msgid "only found copies from modified paths due to too many files."
-msgstr "因为文件太多，只在修改的路径中查找拷贝。"
+#: diff.c:4836
+#, c-format
+msgid "unable to resolve '%s'"
+msgstr "不能解析 '%s'"
 
-#: diff.c:5506
+#: diff.c:4886 diff.c:4892
 #, c-format
-msgid ""
-"you may want to set your %s variable to at least %d and retry the command."
-msgstr "您可能想要将变量 %s 设置为至少 %d 并再次执行此命令。"
+msgid "%s expects <n>/<m> form"
+msgstr "%s 期望 <n>/<m> 格式"
 
-#: dir.c:1867
+#: diff.c:4904
 #, c-format
-msgid "could not open directory '%s'"
-msgstr "不能打开目录 '%s'"
+msgid "%s expects a character, got '%s'"
+msgstr "%s 期望一个字符，得到 '%s'"
 
-#: dir.c:2109
-msgid "failed to get kernel name and information"
-msgstr "无法获得内核名称和信息"
+#: diff.c:4925
+#, c-format
+msgid "bad --color-moved argument: %s"
+msgstr "坏的 --color-moved 参数：%s"
+
+#: diff.c:4944
+#, c-format
+msgid "invalid mode '%s' in --color-moved-ws"
+msgstr "--color-moved-ws 中的无效模式 '%s' "
 
-#: dir.c:2233
-msgid "Untracked cache is disabled on this system or location."
-msgstr "缓存未跟踪文件在本系统或位置中被禁用。"
+#: diff.c:4984
+msgid ""
+"option diff-algorithm accepts \"myers\", \"minimal\", \"patience\" and "
+"\"histogram\""
+msgstr ""
+"diff-algorithm 选项有 \"myers\"、\"minimal\"、\"patience\" 和 \"histogram\""
 
-#: dir.c:3075 dir.c:3080
+#: diff.c:5020 diff.c:5040
 #, c-format
-msgid "could not create directories for %s"
-msgstr "不能为 %s 创建目录"
+msgid "invalid argument to %s"
+msgstr "%s 的参数无效"
 
-#: dir.c:3109
+#: diff.c:5178
 #, c-format
-msgid "could not migrate git directory from '%s' to '%s'"
-msgstr "不能从 '%s' 迁移 git 目录到 '%s'"
+msgid "failed to parse --submodule option parameter: '%s'"
+msgstr "无法解析 --submodule 选项的参数：'%s'"
 
-#: editor.c:61
+#: diff.c:5234
 #, c-format
-msgid "hint: Waiting for your editor to close the file...%c"
-msgstr "提示：等待您的编辑器关闭文件...%c"
+msgid "bad --word-diff argument: %s"
+msgstr "坏的 --word-diff 参数：%s"
 
-#: entry.c:177
-msgid "Filtering content"
-msgstr "过滤内容"
+#: diff.c:5257
+msgid "Diff output format options"
+msgstr "差异输出格式化选项"
 
-#: entry.c:435
-#, c-format
-msgid "could not stat file '%s'"
-msgstr "不能对文件 '%s' 调用 stat"
+#: diff.c:5259 diff.c:5265
+msgid "generate patch"
+msgstr "生成补丁"
 
-#: fetch-object.c:17
-msgid "Remote with no URL"
-msgstr "远程未设置 URL"
+#: diff.c:5262 builtin/log.c:173
+msgid "suppress diff output"
+msgstr "不显示差异输出"
 
-#: fetch-pack.c:254
-msgid "git fetch-pack: expected shallow list"
-msgstr "git fetch-pack：应为 shallow 列表"
+#: diff.c:5267 diff.c:5381 diff.c:5388
+msgid "<n>"
+msgstr "<n>"
 
-#: fetch-pack.c:266
-msgid "git fetch-pack: expected ACK/NAK, got a flush packet"
-msgstr "git fetch-pack：期望 ACK/NAK，却得到 flush 包"
+#: diff.c:5268 diff.c:5271
+msgid "generate diffs with <n> lines context"
+msgstr "生成含 <n> 行上下文的差异"
 
-#: fetch-pack.c:285 builtin/archive.c:63
-#, c-format
-msgid "remote error: %s"
-msgstr "远程错误：%s"
+#: diff.c:5273
+msgid "generate the diff in raw format"
+msgstr "生成原始格式的差异"
 
-#: fetch-pack.c:286
-#, c-format
-msgid "git fetch-pack: expected ACK/NAK, got '%s'"
-msgstr "git fetch-pack：应为 ACK/NAK，却得到 '%s'"
+#: diff.c:5276
+msgid "synonym for '-p --raw'"
+msgstr "和 '-p --raw' 同义"
 
-#: fetch-pack.c:338
-msgid "--stateless-rpc requires multi_ack_detailed"
-msgstr "--stateless-rpc 需要 multi_ack_detailed"
+#: diff.c:5280
+msgid "synonym for '-p --stat'"
+msgstr "和 '-p --stat' 同义"
 
-#: fetch-pack.c:429 fetch-pack.c:1310
-#, c-format
-msgid "invalid shallow line: %s"
-msgstr "无效的 shallow 信息：%s"
+#: diff.c:5284
+msgid "machine friendly --stat"
+msgstr "机器友好的 --stat"
 
-#: fetch-pack.c:435 fetch-pack.c:1316
-#, c-format
-msgid "invalid unshallow line: %s"
-msgstr "无效的 unshallow 信息：%s"
+#: diff.c:5287
+msgid "output only the last line of --stat"
+msgstr "只输出 --stat 的最后一行"
 
-#: fetch-pack.c:437 fetch-pack.c:1318
-#, c-format
-msgid "object not found: %s"
-msgstr "对象未找到：%s"
+#: diff.c:5289 diff.c:5297
+msgid "<param1,param2>..."
+msgstr "<参数1,参数2>..."
 
-#: fetch-pack.c:440 fetch-pack.c:1321
-#, c-format
-msgid "error in object: %s"
-msgstr "对象中出错：%s"
+#: diff.c:5290
+msgid ""
+"output the distribution of relative amount of changes for each sub-directory"
+msgstr "输出每个子目录相对变更的分布"
 
-#: fetch-pack.c:442 fetch-pack.c:1323
-#, c-format
-msgid "no shallow found: %s"
-msgstr "未发现 shallow：%s"
+#: diff.c:5294
+msgid "synonym for --dirstat=cumulative"
+msgstr "和 --dirstat=cumulative 同义"
 
-#: fetch-pack.c:445 fetch-pack.c:1326
-#, c-format
-msgid "expected shallow/unshallow, got %s"
-msgstr "应为 shallow/unshallow，却得到 %s"
+#: diff.c:5298
+msgid "synonym for --dirstat=files,param1,param2..."
+msgstr "是 --dirstat=files,param1,param2... 的同义词"
 
-#: fetch-pack.c:486
-#, c-format
-msgid "got %s %d %s"
-msgstr "得到 %s %d %s"
+#: diff.c:5302
+msgid "warn if changes introduce conflict markers or whitespace errors"
+msgstr "如果变更中引入冲突定界符或空白错误，给出警告"
 
-#: fetch-pack.c:500
-#, c-format
-msgid "invalid commit %s"
-msgstr "无效提交 %s"
+#: diff.c:5305
+msgid "condensed summary such as creations, renames and mode changes"
+msgstr "精简摘要，例如创建、重命名和模式变更"
 
-#: fetch-pack.c:533
-msgid "giving up"
-msgstr "放弃"
+#: diff.c:5308
+msgid "show only names of changed files"
+msgstr "只显示变更文件的文件名"
 
-#: fetch-pack.c:543 progress.c:229
-msgid "done"
-msgstr "完成"
+#: diff.c:5311
+msgid "show only names and status of changed files"
+msgstr "只显示变更文件的文件名和状态"
 
-#: fetch-pack.c:555
-#, c-format
-msgid "got %s (%d) %s"
-msgstr "得到 %s (%d) %s"
+#: diff.c:5313
+msgid "<width>[,<name-width>[,<count>]]"
+msgstr "<宽度>[,<文件名宽度>[,<次数>]]"
 
-#: fetch-pack.c:601
-#, c-format
-msgid "Marking %s as complete"
-msgstr "标记 %s 为完成"
+#: diff.c:5314
+msgid "generate diffstat"
+msgstr "生成差异统计（diffstat）"
 
-#: fetch-pack.c:828
-#, c-format
-msgid "already have %s (%s)"
-msgstr "已经有 %s（%s）"
+#: diff.c:5316 diff.c:5319 diff.c:5322
+msgid "<width>"
+msgstr "<宽度>"
 
-#: fetch-pack.c:869
-msgid "fetch-pack: unable to fork off sideband demultiplexer"
-msgstr "fetch-pack：无法派生 sideband 多路输出"
+#: diff.c:5317
+msgid "generate diffstat with a given width"
+msgstr "使用给定的长度生成差异统计"
 
-#: fetch-pack.c:877
-msgid "protocol error: bad pack header"
-msgstr "协议错误：坏的包头"
+#: diff.c:5320
+msgid "generate diffstat with a given name width"
+msgstr "使用给定的文件名长度生成差异统计"
 
-#: fetch-pack.c:944
-#, c-format
-msgid "fetch-pack: unable to fork off %s"
-msgstr "fetch-pack：无法派生进程 %s"
+#: diff.c:5323
+msgid "generate diffstat with a given graph width"
+msgstr "使用给定的图形长度生成差异统计"
 
-#: fetch-pack.c:960
-#, c-format
-msgid "%s failed"
-msgstr "%s 失败"
+#: diff.c:5325
+msgid "<count>"
+msgstr "<次数>"
 
-#: fetch-pack.c:962
-msgid "error in sideband demultiplexer"
-msgstr "sideband 多路输出出错"
+#: diff.c:5326
+msgid "generate diffstat with limited lines"
+msgstr "生成有限行数的差异统计"
 
-#: fetch-pack.c:989
-msgid "Server does not support shallow clients"
-msgstr "服务器不支持 shalllow 客户端"
+#: diff.c:5329
+msgid "generate compact summary in diffstat"
+msgstr "生成差异统计的简洁摘要"
 
-#: fetch-pack.c:993
-msgid "Server supports multi_ack_detailed"
-msgstr "服务器支持 multi_ack_detailed"
-
-#: fetch-pack.c:996
-msgid "Server supports no-done"
-msgstr "服务器支持 no-done"
-
-#: fetch-pack.c:1002
-msgid "Server supports multi_ack"
-msgstr "服务器支持 multi_ack"
-
-#: fetch-pack.c:1006
-msgid "Server supports side-band-64k"
-msgstr "服务器支持 side-band-64k"
-
-#: fetch-pack.c:1010
-msgid "Server supports side-band"
-msgstr "服务器支持 side-band"
-
-#: fetch-pack.c:1014
-msgid "Server supports allow-tip-sha1-in-want"
-msgstr "服务器支持 allow-tip-sha1-in-want"
-
-#: fetch-pack.c:1018
-msgid "Server supports allow-reachable-sha1-in-want"
-msgstr "服务器支持 allow-reachable-sha1-in-want"
-
-#: fetch-pack.c:1028
-msgid "Server supports ofs-delta"
-msgstr "服务器支持 ofs-delta"
+#: diff.c:5332
+msgid "output a binary diff that can be applied"
+msgstr "输出一个可以应用的二进制差异"
 
-#: fetch-pack.c:1034 fetch-pack.c:1204
-msgid "Server supports filter"
-msgstr "服务器支持 filter"
+#: diff.c:5335
+msgid "show full pre- and post-image object names on the \"index\" lines"
+msgstr "在 \"index\" 行显示完整的前后对象名称"
 
-#: fetch-pack.c:1042
-#, c-format
-msgid "Server version is %.*s"
-msgstr "服务器版本 %.*s"
+#: diff.c:5337
+msgid "show colored diff"
+msgstr "显示带颜色的差异"
 
-#: fetch-pack.c:1048
-msgid "Server does not support --shallow-since"
-msgstr "服务器不支持 --shallow-since"
+#: diff.c:5338
+msgid "<kind>"
+msgstr "<类型>"
 
-#: fetch-pack.c:1052
-msgid "Server does not support --shallow-exclude"
-msgstr "服务器不支持 --shallow-exclude"
+#: diff.c:5339
+msgid ""
+"highlight whitespace errors in the 'context', 'old' or 'new' lines in the "
+"diff"
+msgstr "对于差异中的上下文、旧的和新的行，加亮显示错误的空白字符"
 
-#: fetch-pack.c:1054
-msgid "Server does not support --deepen"
-msgstr "服务器不支持 --deepen"
+#: diff.c:5342
+msgid ""
+"do not munge pathnames and use NULs as output field terminators in --raw or "
+"--numstat"
+msgstr ""
+"在 --raw 或者 --numstat 中，不对路径字符转码并使用 NUL 字符做为输出字段的分隔"
+"符"
 
-#: fetch-pack.c:1065
-msgid "no common commits"
-msgstr "没有共同的提交"
+#: diff.c:5345 diff.c:5348 diff.c:5351 diff.c:5457
+msgid "<prefix>"
+msgstr "<前缀>"
 
-#: fetch-pack.c:1077 fetch-pack.c:1414
-msgid "git fetch-pack: fetch failed."
-msgstr "git fetch-pack：获取失败。"
+#: diff.c:5346
+msgid "show the given source prefix instead of \"a/\""
+msgstr "显示给定的源前缀取代 \"a/\""
 
-#: fetch-pack.c:1199
-msgid "Server does not support shallow requests"
-msgstr "服务器不支持 shalllow 请求"
+#: diff.c:5349
+msgid "show the given destination prefix instead of \"b/\""
+msgstr "显示给定的目标前缀取代 \"b/\""
 
-#: fetch-pack.c:1584
-msgid "no matching remote head"
-msgstr "没有匹配的远程分支"
+#: diff.c:5352
+msgid "prepend an additional prefix to every line of output"
+msgstr "输出的每一行附加前缀"
 
-#: fetch-pack.c:1610
-#, c-format
-msgid "no such remote ref %s"
-msgstr "没有这样的远程引用 %s"
+#: diff.c:5355
+msgid "do not show any source or destination prefix"
+msgstr "不显示任何源和目标前缀"
 
-#: fetch-pack.c:1613
-#, c-format
-msgid "Server does not allow request for unadvertised object %s"
-msgstr "服务器不允许请求未公开的对象 %s"
+#: diff.c:5358
+msgid "show context between diff hunks up to the specified number of lines"
+msgstr "显示指定行数的差异块间的上下文"
 
-#: gpg-interface.c:185
-msgid "gpg failed to sign the data"
-msgstr "gpg 无法为数据签名"
+#: diff.c:5362 diff.c:5367 diff.c:5372
+msgid "<char>"
+msgstr "<字符>"
 
-#: gpg-interface.c:210
-msgid "could not create temporary file"
-msgstr "不能创建临时文件"
+#: diff.c:5363
+msgid "specify the character to indicate a new line instead of '+'"
+msgstr "指定一个字符取代 '+' 来表示新的一行"
 
-#: gpg-interface.c:213
-#, c-format
-msgid "failed writing detached signature to '%s'"
-msgstr "无法将分离式签名写入 '%s'"
+#: diff.c:5368
+msgid "specify the character to indicate an old line instead of '-'"
+msgstr "指定一个字符取代 '-' 来表示旧的一行"
 
-#: graph.c:97
-#, c-format
-msgid "ignore invalid color '%.*s' in log.graphColors"
-msgstr "忽略 log.graphColors 中无效的颜色 '%.*s'"
+#: diff.c:5373
+msgid "specify the character to indicate a context instead of ' '"
+msgstr "指定一个字符取代 ' ' 来表示一行上下文"
 
-#: grep.c:2020
-#, c-format
-msgid "'%s': unable to read %s"
-msgstr "'%s'：无法读取 %s"
+#: diff.c:5376
+msgid "Diff rename options"
+msgstr "差异重命名选项"
 
-#: grep.c:2037 setup.c:164 builtin/clone.c:409 builtin/diff.c:81
-#: builtin/rm.c:134
-#, c-format
-msgid "failed to stat '%s'"
-msgstr "对 '%s' 调用 stat 失败"
+#: diff.c:5377
+msgid "<n>[/<m>]"
+msgstr "<n>[/<m>]"
 
-#: grep.c:2048
-#, c-format
-msgid "'%s': short read"
-msgstr "'%s'：读取不完整"
+#: diff.c:5378
+msgid "break complete rewrite changes into pairs of delete and create"
+msgstr "将完全重写的变更打破为成对的删除和创建"
 
-#: help.c:23
-msgid "start a working area (see also: git help tutorial)"
-msgstr "开始一个工作区（参见：git help tutorial）"
+#: diff.c:5382
+msgid "detect renames"
+msgstr "检测重命名"
 
-#: help.c:24
-msgid "work on the current change (see also: git help everyday)"
-msgstr "在当前变更上工作（参见：git help everyday）"
+#: diff.c:5386
+msgid "omit the preimage for deletes"
+msgstr "省略删除操作的差异输出"
 
-#: help.c:25
-msgid "examine the history and state (see also: git help revisions)"
-msgstr "检查历史和状态（参见：git help revisions）"
+#: diff.c:5389
+msgid "detect copies"
+msgstr "检测拷贝"
 
-#: help.c:26
-msgid "grow, mark and tweak your common history"
-msgstr "扩展、标记和调校您的历史记录"
+#: diff.c:5393
+msgid "use unmodified files as source to find copies"
+msgstr "使用未修改的文件做为发现拷贝的源"
 
-#: help.c:27
-msgid "collaborate (see also: git help workflows)"
-msgstr "协同（参见：git help workflows）"
+#: diff.c:5395
+msgid "disable rename detection"
+msgstr "禁用重命名探测"
 
-#: help.c:31
-msgid "Main Porcelain Commands"
-msgstr "主要的上层命令"
+#: diff.c:5398
+msgid "use empty blobs as rename source"
+msgstr "使用空的数据对象做为重命名的源"
 
-#: help.c:32
-msgid "Ancillary Commands / Manipulators"
-msgstr "辅助命令/操作者"
+#: diff.c:5400
+msgid "continue listing the history of a file beyond renames"
+msgstr "继续列出文件重命名以外的历史记录"
 
-#: help.c:33
-msgid "Ancillary Commands / Interrogators"
-msgstr "辅助命令/询问者"
+#: diff.c:5403
+msgid ""
+"prevent rename/copy detection if the number of rename/copy targets exceeds "
+"given limit"
+msgstr "如果重命名/拷贝目标超过给定的限制，禁止重命名/拷贝检测"
 
-#: help.c:34
-msgid "Interacting with Others"
-msgstr "与其它系统交互"
+#: diff.c:5405
+msgid "Diff algorithm options"
+msgstr "差异算法选项"
 
-#: help.c:35
-msgid "Low-level Commands / Manipulators"
-msgstr "低级命令/操作者"
+#: diff.c:5407
+msgid "produce the smallest possible diff"
+msgstr "生成尽可能小的差异"
 
-#: help.c:36
-msgid "Low-level Commands / Interrogators"
-msgstr "低级命令/询问者"
+#: diff.c:5410
+msgid "ignore whitespace when comparing lines"
+msgstr "行比较时忽略空白字符"
 
-#: help.c:37
-msgid "Low-level Commands / Synching Repositories"
-msgstr "低级命令/同步仓库"
+#: diff.c:5413
+msgid "ignore changes in amount of whitespace"
+msgstr "忽略空白字符的变更"
 
-#: help.c:38
-msgid "Low-level Commands / Internal Helpers"
-msgstr "低级命令/内部助手"
+#: diff.c:5416
+msgid "ignore changes in whitespace at EOL"
+msgstr "忽略行尾的空白字符变更"
 
-#: help.c:293
-#, c-format
-msgid "available git commands in '%s'"
-msgstr "在 '%s' 下可用的 git 命令"
+#: diff.c:5419
+msgid "ignore carrier-return at the end of line"
+msgstr "忽略行尾的回车符（CR）"
 
-#: help.c:300
-msgid "git commands available from elsewhere on your $PATH"
-msgstr "在 $PATH 路径中的其他地方可用的 git 命令"
+#: diff.c:5422
+msgid "ignore changes whose lines are all blank"
+msgstr "忽略整行都是空白的变更"
 
-#: help.c:309
-msgid "These are common Git commands used in various situations:"
-msgstr "这些是各种场合常见的 Git 命令："
+#: diff.c:5425
+msgid "heuristic to shift diff hunk boundaries for easy reading"
+msgstr "启发式转换差异边界以便阅读"
 
-#: help.c:358 git.c:90
-#, c-format
-msgid "unsupported command listing type '%s'"
-msgstr "不支持的命令列表类型 '%s'"
+#: diff.c:5428
+msgid "generate diff using the \"patience diff\" algorithm"
+msgstr "使用 \"patience diff\" 算法生成差异"
 
-#: help.c:405
-msgid "The common Git guides are:"
-msgstr "最常用的 Git 向导有："
+#: diff.c:5432
+msgid "generate diff using the \"histogram diff\" algorithm"
+msgstr "使用 \"histogram diff\" 算法生成差异"
 
-#: help.c:467
-#, c-format
-msgid ""
-"'%s' appears to be a git command, but we were not\n"
-"able to execute it. Maybe git-%s is broken?"
-msgstr ""
-"'%s' 像是一个 git 命令，但却无法运行。\n"
-"可能是 git-%s 受损？"
+#: diff.c:5434
+msgid "<algorithm>"
+msgstr "<算法>"
 
-#: help.c:526
-msgid "Uh oh. Your system reports no Git commands at all."
-msgstr "唉呀，您的系统中未发现 Git 命令。"
+#: diff.c:5435
+msgid "choose a diff algorithm"
+msgstr "选择一个差异算法"
 
-#: help.c:548
-#, c-format
-msgid "WARNING: You called a Git command named '%s', which does not exist."
-msgstr "警告：您运行了一个并不存在的 Git 命令 '%s'。"
+#: diff.c:5437
+msgid "<text>"
+msgstr "<文本>"
 
-#: help.c:553
-#, c-format
-msgid "Continuing under the assumption that you meant '%s'."
-msgstr "假定你想要的是 '%s' 并继续。"
+#: diff.c:5438
+msgid "generate diff using the \"anchored diff\" algorithm"
+msgstr "使用 \"anchored diff\" 算法生成差异"
 
-#: help.c:558
-#, c-format
-msgid "Continuing in %0.1f seconds, assuming that you meant '%s'."
-msgstr "假定你想要的是 '%2$s'，在 %1$0.1f 秒钟后继续。"
+#: diff.c:5440 diff.c:5449 diff.c:5452
+msgid "<mode>"
+msgstr "<模式>"
 
-#: help.c:566
-#, c-format
-msgid "git: '%s' is not a git command. See 'git --help'."
-msgstr "git：'%s' 不是一个 git 命令。参见 'git --help'。"
+#: diff.c:5441
+msgid "show word diff, using <mode> to delimit changed words"
+msgstr "显示单词差异，使用 <模式> 分隔变更的单词"
 
-#: help.c:570
-msgid ""
-"\n"
-"The most similar command is"
-msgid_plural ""
-"\n"
-"The most similar commands are"
-msgstr[0] ""
-"\n"
-"最相似的命令是"
-msgstr[1] ""
-"\n"
-"最相似的命令是"
+#: diff.c:5443 diff.c:5446 diff.c:5491
+msgid "<regex>"
+msgstr "<正则>"
 
-#: help.c:585
-msgid "git version [<options>]"
-msgstr "git version [<选项>]"
+#: diff.c:5444
+msgid "use <regex> to decide what a word is"
+msgstr "使用 <正则表达式> 确定何为一个词"
 
-#: help.c:652
-#, c-format
-msgid "%s: %s - %s"
-msgstr "%s：%s - %s"
+#: diff.c:5447
+msgid "equivalent to --word-diff=color --word-diff-regex=<regex>"
+msgstr "相当于 --word-diff=color --word-diff-regex=<正则>"
 
-#: help.c:656
-msgid ""
-"\n"
-"Did you mean this?"
-msgid_plural ""
-"\n"
-"Did you mean one of these?"
-msgstr[0] ""
-"\n"
-"您指的是这个么？"
-msgstr[1] ""
-"\n"
-"您指的是这其中的某一个么？"
+#: diff.c:5450
+msgid "moved lines of code are colored differently"
+msgstr "移动的代码行用不同方式着色"
 
-#: ident.c:342
-msgid ""
-"\n"
-"*** Please tell me who you are.\n"
-"\n"
-"Run\n"
-"\n"
-"  git config --global user.email \"you@example.com\"\n"
-"  git config --global user.name \"Your Name\"\n"
-"\n"
-"to set your account's default identity.\n"
-"Omit --global to set the identity only in this repository.\n"
-"\n"
-msgstr ""
-"\n"
-"*** 请告诉我你是谁。\n"
-"\n"
-"运行\n"
-"\n"
-"  git config --global user.email \"you@example.com\"\n"
-"  git config --global user.name \"Your Name\"\n"
-"\n"
-"来设置您账号的缺省身份标识。\n"
-"如果仅在本仓库设置身份标识，则省略 --global 参数。\n"
+#: diff.c:5453
+msgid "how white spaces are ignored in --color-moved"
+msgstr "在 --color-moved 下如何忽略空白字符"
 
-#: ident.c:366
-msgid "no email was given and auto-detection is disabled"
-msgstr "未提供邮件地址且自动探测被禁用"
+#: diff.c:5456
+msgid "Other diff options"
+msgstr "其它差异选项"
 
-#: ident.c:371
-#, c-format
-msgid "unable to auto-detect email address (got '%s')"
-msgstr "无法自动探测邮件地址（得到 '%s'）"
+#: diff.c:5458
+msgid "when run from subdir, exclude changes outside and show relative paths"
+msgstr "当从子目录运行，排除目录之外的变更并显示相对路径"
 
-#: ident.c:381
-msgid "no name was given and auto-detection is disabled"
-msgstr "未提供姓名且自动探测被禁用"
+#: diff.c:5462
+msgid "treat all files as text"
+msgstr "把所有文件当做文本处理"
 
-#: ident.c:387
-#, c-format
-msgid "unable to auto-detect name (got '%s')"
-msgstr "无法自动探测姓名（得到 '%s'）"
+#: diff.c:5464
+msgid "swap two inputs, reverse the diff"
+msgstr "交换两个输入，反转差异"
 
-#: ident.c:395
-#, c-format
-msgid "empty ident name (for <%s>) not allowed"
-msgstr "不允许空的姓名（对于 <%s>）"
+#: diff.c:5466
+msgid "exit with 1 if there were differences, 0 otherwise"
+msgstr "有差异时退出码为 1，否则为 0"
 
-#: ident.c:401
-#, c-format
-msgid "name consists only of disallowed characters: %s"
-msgstr "姓名中仅包含禁用字符：%s"
+#: diff.c:5468
+msgid "disable all output of the program"
+msgstr "禁用本程序的所有输出"
 
-#: ident.c:416 builtin/commit.c:587
-#, c-format
-msgid "invalid date format: %s"
-msgstr "无效的日期格式：%s"
+#: diff.c:5470
+msgid "allow an external diff helper to be executed"
+msgstr "允许执行一个外置的差异助手"
 
-#: list-objects-filter-options.c:36
-msgid "multiple filter-specs cannot be combined"
-msgstr "不能混用多种过滤规格"
+#: diff.c:5472
+msgid "run external text conversion filters when comparing binary files"
+msgstr "当比较二进制文件时，运行外部的文本转换过滤器"
 
-#: list-objects-filter-options.c:126
-msgid "cannot change partial clone promisor remote"
-msgstr "无法修改部分克隆的 promisor 远程仓库"
+#: diff.c:5474
+msgid "<when>"
+msgstr "<何时>"
 
-#: lockfile.c:151
-#, c-format
+#: diff.c:5475
+msgid "ignore changes to submodules in the diff generation"
+msgstr "在生成差异时，忽略子模组的更改"
+
+#: diff.c:5478
+msgid "<format>"
+msgstr "<格式>"
+
+#: diff.c:5479
+msgid "specify how differences in submodules are shown"
+msgstr "指定子模组的差异如何显示"
+
+#: diff.c:5483
+msgid "hide 'git add -N' entries from the index"
+msgstr "隐藏索引中 'git add -N' 条目"
+
+#: diff.c:5486
+msgid "treat 'git add -N' entries as real in the index"
+msgstr "将索引中 'git add -N' 条目当做真实的"
+
+#: diff.c:5488
+msgid "<string>"
+msgstr "<字符串>"
+
+#: diff.c:5489
 msgid ""
-"Unable to create '%s.lock': %s.\n"
-"\n"
-"Another git process seems to be running in this repository, e.g.\n"
-"an editor opened by 'git commit'. Please make sure all processes\n"
-"are terminated then try again. If it still fails, a git process\n"
-"may have crashed in this repository earlier:\n"
-"remove the file manually to continue."
-msgstr ""
-"无法创建 '%s.lock'：%s。\n"
-"\n"
-"似乎另外一个 git 进程在这个仓库中运行，例如：'git commit' 命令打\n"
-"开了一个编辑器。请确认所有进程都已经关闭然后重试。如果仍然报错，\n"
-"可能之前有一个 git 进程在这个仓库中异常退出：\n"
-"手动删除这个文件再继续。"
+"look for differences that change the number of occurrences of the specified "
+"string"
+msgstr "查找改变了指定字符串出现次数的差异"
 
-#: lockfile.c:159
-#, c-format
-msgid "Unable to create '%s.lock': %s"
-msgstr "不能创建 '%s.lock'：%s"
+#: diff.c:5492
+msgid ""
+"look for differences that change the number of occurrences of the specified "
+"regex"
+msgstr "查找改变指定正则匹配出现次数的差异"
 
-#: merge.c:71
-msgid "failed to read the cache"
-msgstr "无法读取缓存"
+#: diff.c:5495
+msgid "show all changes in the changeset with -S or -G"
+msgstr "显示使用 -S 或 -G 的变更集的所有变更"
 
-#: merge.c:136 builtin/am.c:1946 builtin/am.c:1980 builtin/checkout.c:378
-#: builtin/checkout.c:606 builtin/clone.c:761
-msgid "unable to write new index file"
-msgstr "无法写新的索引文件"
+#: diff.c:5498
+msgid "treat <string> in -S as extended POSIX regular expression"
+msgstr "将 -S 的 <string> 当做扩展的 POSIX 正则表达式"
 
-#: merge-recursive.c:298
-msgid "(bad commit)\n"
-msgstr "（坏提交）\n"
+#: diff.c:5501
+msgid "control the order in which files appear in the output"
+msgstr "控制输出中的文件显示顺序"
 
-#: merge-recursive.c:320
-#, c-format
-msgid "add_cacheinfo failed for path '%s'; merge aborting."
-msgstr "addinfo_cache 对路径 '%s' 执行失败，合并终止。"
+#: diff.c:5502
+msgid "<object-id>"
+msgstr "<对象 ID>"
 
-#: merge-recursive.c:328
-#, c-format
-msgid "add_cacheinfo failed to refresh for path '%s'; merge aborting."
-msgstr "addinfo_cache 无法刷新路径 '%s'，合并终止。"
+#: diff.c:5503
+msgid ""
+"look for differences that change the number of occurrences of the specified "
+"object"
+msgstr "查找改变指定对象出现次数的差异"
+
+#: diff.c:5505
+msgid "[(A|C|D|M|R|T|U|X|B)...[*]]"
+msgstr "[(A|C|D|M|R|T|U|X|B)...[*]]"
 
-#: merge-recursive.c:410
-msgid "error building trees"
-msgstr "无法创建树"
+#: diff.c:5506
+msgid "select files by diff type"
+msgstr "通过差异类型选择文件"
 
-#: merge-recursive.c:881
-#, c-format
-msgid "failed to create path '%s'%s"
-msgstr "无法创建路径 '%s'%s"
+#: diff.c:5508
+msgid "<file>"
+msgstr "<文件>"
+
+#: diff.c:5509
+msgid "Output to a specific file"
+msgstr "输出到一个指定的文件"
+
+#: diff.c:6164
+msgid "inexact rename detection was skipped due to too many files."
+msgstr "因为文件太多，略过不严格的重命名检查。"
+
+#: diff.c:6167
+msgid "only found copies from modified paths due to too many files."
+msgstr "因为文件太多，只在修改的路径中查找拷贝。"
 
-#: merge-recursive.c:892
+#: diff.c:6170
 #, c-format
-msgid "Removing %s to make room for subdirectory\n"
-msgstr "删除 %s 以便为子目录留出空间\n"
+msgid ""
+"you may want to set your %s variable to at least %d and retry the command."
+msgstr "您可能想要将变量 %s 设置为至少 %d 并再次执行此命令。"
 
-#: merge-recursive.c:906 merge-recursive.c:925
-msgid ": perhaps a D/F conflict?"
-msgstr "：可能是一个目录/文件冲突？"
+#: dir.c:554
+#, c-format
+msgid "pathspec '%s' did not match any file(s) known to git"
+msgstr "路径规格 '%s' 未匹配任何 git 已知文件"
 
-#: merge-recursive.c:915
+#: dir.c:664
 #, c-format
-msgid "refusing to lose untracked file at '%s'"
-msgstr "拒绝丢弃 '%s' 中的未跟踪文件"
+msgid "unrecognized pattern: '%s'"
+msgstr "未识别的模式：'%s'"
 
-#: merge-recursive.c:957 builtin/cat-file.c:37
+#: dir.c:682 dir.c:696
 #, c-format
-msgid "cannot read object %s '%s'"
-msgstr "不能读取对象 %s '%s'"
+msgid "unrecognized negative pattern: '%s'"
+msgstr "未识别的反向模式：'%s'"
 
-#: merge-recursive.c:959
+#: dir.c:714
 #, c-format
-msgid "blob expected for %s '%s'"
-msgstr "%s '%s' 应为数据对象"
+msgid "your sparse-checkout file may have issues: pattern '%s' is repeated"
+msgstr "您的 sparse-checkout 文件可能有问题：重复的模式 '%s'"
+
+#: dir.c:724
+msgid "disabling cone pattern matching"
+msgstr "禁止 cone 模式匹配"
 
-#: merge-recursive.c:983
+#: dir.c:1101
 #, c-format
-msgid "failed to open '%s': %s"
-msgstr "无法打开 '%s'：%s"
+msgid "cannot use %s as an exclude file"
+msgstr "不能将 %s 用作排除文件"
 
-#: merge-recursive.c:994
+#: dir.c:2078
 #, c-format
-msgid "failed to symlink '%s': %s"
-msgstr "无法创建符号链接 '%s'：%s"
+msgid "could not open directory '%s'"
+msgstr "不能打开目录 '%s'"
 
-#: merge-recursive.c:999
+#: dir.c:2415
+msgid "failed to get kernel name and information"
+msgstr "无法获得内核名称和信息"
+
+#: dir.c:2539
+msgid "untracked cache is disabled on this system or location"
+msgstr "缓存未跟踪文件在本系统或位置中被禁用"
+
+#: dir.c:3343
 #, c-format
-msgid "do not know what to do with %06o %s '%s'"
-msgstr "不知道如何处理 %06o %s '%s'"
+msgid "index file corrupt in repo %s"
+msgstr "仓库 %s 中的索引文件损坏"
 
-#: merge-recursive.c:1186
+#: dir.c:3388 dir.c:3393
 #, c-format
-msgid "Failed to merge submodule %s (not checked out)"
-msgstr "无法合并子模组 %s （没有检出）"
+msgid "could not create directories for %s"
+msgstr "不能为 %s 创建目录"
 
-#: merge-recursive.c:1193
+#: dir.c:3422
 #, c-format
-msgid "Failed to merge submodule %s (commits not present)"
-msgstr "无法合并子模组 %s（提交不存在）"
+msgid "could not migrate git directory from '%s' to '%s'"
+msgstr "不能从 '%s' 迁移 git 目录到 '%s'"
 
-#: merge-recursive.c:1200
+#: editor.c:73
 #, c-format
-msgid "Failed to merge submodule %s (commits don't follow merge-base)"
-msgstr "无法合并子模组 %s （提交未跟随合并基线）"
+msgid "hint: Waiting for your editor to close the file...%c"
+msgstr "提示：等待您的编辑器关闭文件...%c"
+
+#: entry.c:178
+msgid "Filtering content"
+msgstr "过滤内容"
 
-#: merge-recursive.c:1208 merge-recursive.c:1220
+#: entry.c:476
 #, c-format
-msgid "Fast-forwarding submodule %s to the following commit:"
-msgstr "子模组 %s 快进到如下提交："
+msgid "could not stat file '%s'"
+msgstr "不能对文件 '%s' 调用 stat"
 
-#: merge-recursive.c:1211 merge-recursive.c:1223
+#: environment.c:149
 #, c-format
-msgid "Fast-forwarding submodule %s"
-msgstr "快进子模组 %s"
+msgid "bad git namespace path \"%s\""
+msgstr "错误的 git 名字空间路径 \"%s\""
 
-#: merge-recursive.c:1245
+#: environment.c:331
 #, c-format
-msgid "Failed to merge submodule %s (merge following commits not found)"
-msgstr "无法合并子模组 %s （没发现合并跟随的提交）"
+msgid "could not set GIT_DIR to '%s'"
+msgstr "不能设置 GIT_DIR 为 '%s'"
 
-#: merge-recursive.c:1249
+#: exec-cmd.c:363
 #, c-format
-msgid "Failed to merge submodule %s (not fast-forward)"
-msgstr "无法合并子模组 %s（非快进）"
+msgid "too many args to run %s"
+msgstr "执行 %s 的参数太多"
 
-#: merge-recursive.c:1250
-msgid "Found a possible merge resolution for the submodule:\n"
-msgstr "找到子模组的一个可能的合并方案：\n"
+#: fetch-pack.c:150
+msgid "git fetch-pack: expected shallow list"
+msgstr "git fetch-pack：应为 shallow 列表"
+
+#: fetch-pack.c:153
+msgid "git fetch-pack: expected a flush packet after shallow list"
+msgstr "git fetch-pack：在浅克隆列表之后期望一个 flush 包"
 
-#: merge-recursive.c:1253
+#: fetch-pack.c:164
+msgid "git fetch-pack: expected ACK/NAK, got a flush packet"
+msgstr "git fetch-pack：期望 ACK/NAK，却得到 flush 包"
+
+#: fetch-pack.c:184
 #, c-format
-msgid ""
-"If this is correct simply add it to the index for example\n"
-"by using:\n"
-"\n"
-"  git update-index --cacheinfo 160000 %s \"%s\"\n"
-"\n"
-"which will accept this suggestion.\n"
-msgstr ""
-"如果这个正确，将其添加到索引，例如使用命令：\n"
-"\n"
-"  git update-index --cacheinfo 160000 %s \"%s\"\n"
-"\n"
-"以接受此建议。\n"
+msgid "git fetch-pack: expected ACK/NAK, got '%s'"
+msgstr "git fetch-pack：应为 ACK/NAK，却得到 '%s'"
 
-#: merge-recursive.c:1262
-#, c-format
-msgid "Failed to merge submodule %s (multiple merges found)"
-msgstr "无法合并子模组 %s （发现多个合并）"
+#: fetch-pack.c:195
+msgid "unable to write to remote"
+msgstr "无法写到远程"
 
-#: merge-recursive.c:1321
-msgid "Failed to execute internal merge"
-msgstr "无法执行内部合并"
+#: fetch-pack.c:257
+msgid "--stateless-rpc requires multi_ack_detailed"
+msgstr "--stateless-rpc 需要 multi_ack_detailed"
 
-#: merge-recursive.c:1326
+#: fetch-pack.c:356 fetch-pack.c:1340
 #, c-format
-msgid "Unable to add %s to database"
-msgstr "不能添加 %s 至对象库"
+msgid "invalid shallow line: %s"
+msgstr "无效的 shallow 信息：%s"
 
-#: merge-recursive.c:1358
+#: fetch-pack.c:362 fetch-pack.c:1346
 #, c-format
-msgid "Auto-merging %s"
-msgstr "自动合并 %s"
+msgid "invalid unshallow line: %s"
+msgstr "无效的 unshallow 信息：%s"
 
-#: merge-recursive.c:1423
+#: fetch-pack.c:364 fetch-pack.c:1348
 #, c-format
-msgid "Error: Refusing to lose untracked file at %s; writing to %s instead."
-msgstr "错误：拒绝丢失未跟踪文件 '%s'，而是写入 %s。"
+msgid "object not found: %s"
+msgstr "对象未找到：%s"
 
-#: merge-recursive.c:1475
+#: fetch-pack.c:367 fetch-pack.c:1351
 #, c-format
-msgid ""
-"CONFLICT (%s/delete): %s deleted in %s and %s in %s. Version %s of %s left "
-"in tree."
-msgstr ""
-"冲突（%1$s/删除）：%2$s 在 %3$s 中被删除，在 %5$s 中被 %4$s。%7$s 的 %6$s 版"
-"本被保留。"
+msgid "error in object: %s"
+msgstr "对象中出错：%s"
 
-#: merge-recursive.c:1480
+#: fetch-pack.c:369 fetch-pack.c:1353
 #, c-format
-msgid ""
-"CONFLICT (%s/delete): %s deleted in %s and %s to %s in %s. Version %s of %s "
-"left in tree."
-msgstr ""
-"冲突（%1$s/删除）：%2$s 在 %3$s 中被删除，在 %6$s 中的 %5$s 被 %4$s。%8$s 的 "
-"%7$s 版本被保留。"
+msgid "no shallow found: %s"
+msgstr "未发现 shallow：%s"
 
-#: merge-recursive.c:1487
+#: fetch-pack.c:372 fetch-pack.c:1357
 #, c-format
-msgid ""
-"CONFLICT (%s/delete): %s deleted in %s and %s in %s. Version %s of %s left "
-"in tree at %s."
-msgstr ""
-"冲突（%1$s/删除）：%2$s 在 %3$s 中被删除，在 %5$s 中被 %4$s。%7$s 的 %6$s 版"
-"本保留在 %8$s 中。"
+msgid "expected shallow/unshallow, got %s"
+msgstr "应为 shallow/unshallow，却得到 %s"
 
-#: merge-recursive.c:1492
+#: fetch-pack.c:414
 #, c-format
-msgid ""
-"CONFLICT (%s/delete): %s deleted in %s and %s to %s in %s. Version %s of %s "
-"left in tree at %s."
-msgstr ""
-"冲突（%1$s/删除）：%2$s 在 %3$s 中被删除，在 %6$s 中的 %5$s 被 %4$s。%8$s 的 "
-"%7$s 版本保留在 %9$s 中。"
-
-#: merge-recursive.c:1526
-msgid "rename"
-msgstr "重命名"
-
-#: merge-recursive.c:1526
-msgid "renamed"
-msgstr "重命名"
+msgid "got %s %d %s"
+msgstr "得到 %s %d %s"
 
-#: merge-recursive.c:1580 merge-recursive.c:1736 merge-recursive.c:2368
-#: merge-recursive.c:3086
+#: fetch-pack.c:431
 #, c-format
-msgid "Refusing to lose dirty file at %s"
-msgstr "拒绝丢失脏文件 '%s'"
+msgid "invalid commit %s"
+msgstr "无效提交 %s"
 
-#: merge-recursive.c:1594
-#, c-format
-msgid "%s is a directory in %s adding as %s instead"
-msgstr "%s 是 %s 中的一个目录而以 %s 为名被添加"
+#: fetch-pack.c:462
+msgid "giving up"
+msgstr "放弃"
 
-#: merge-recursive.c:1599
-#, c-format
-msgid "Refusing to lose untracked file at %s; adding as %s instead"
-msgstr "拒绝丢失未跟踪文件 '%s'，而是添加为 %s"
+#: fetch-pack.c:475 progress.c:323
+msgid "done"
+msgstr "完成"
 
-#: merge-recursive.c:1625
+#: fetch-pack.c:487
 #, c-format
-msgid ""
-"CONFLICT (rename/rename): Rename \"%s\"->\"%s\" in branch \"%s\" rename \"%s"
-"\"->\"%s\" in \"%s\"%s"
-msgstr ""
-"冲突（重命名/重命名）：在分支 \"%3$s\" 中重命名 \"%1$s\"->\"%2$s\"，在分支 "
-"\"%6$s\" 中重命名 \"%4$s\"->\"%5$s\"%7$s"
-
-#: merge-recursive.c:1630
-msgid " (left unresolved)"
-msgstr "（留下未解决）"
+msgid "got %s (%d) %s"
+msgstr "得到 %s (%d) %s"
 
-#: merge-recursive.c:1694
+#: fetch-pack.c:533
 #, c-format
-msgid "CONFLICT (rename/rename): Rename %s->%s in %s. Rename %s->%s in %s"
-msgstr ""
-"冲突（重命名/重命名）：在 %3$s 中重命名 %1$s->%2$s，在 %6$s 中重命名 %4$s->"
-"%5$s"
+msgid "Marking %s as complete"
+msgstr "标记 %s 为完成"
 
-#: merge-recursive.c:1733
+#: fetch-pack.c:754
 #, c-format
-msgid "Renaming %s to %s and %s to %s instead"
-msgstr "而是重命名 %s 至 %s，以及 %s 至 %s"
+msgid "already have %s (%s)"
+msgstr "已经有 %s（%s）"
 
-#: merge-recursive.c:1745
-#, c-format
-msgid "Refusing to lose untracked file at %s, even though it's in the way."
-msgstr "拒绝丢失未跟踪文件 '%s'，即使它妨碍了。"
+#: fetch-pack.c:818
+msgid "fetch-pack: unable to fork off sideband demultiplexer"
+msgstr "fetch-pack：无法派生 sideband 多路输出"
 
-#: merge-recursive.c:1951
-#, c-format
-msgid ""
-"CONFLICT (directory rename split): Unclear where to place %s because "
-"directory %s was renamed to multiple other directories, with no destination "
-"getting a majority of the files."
-msgstr ""
-"冲突（分割的目录重命名）：不清楚 %s 应该放在哪里，因为目录 %s 被重命名到多个"
-"其它目录，没有一个目录包含主要的文件。"
+#: fetch-pack.c:826
+msgid "protocol error: bad pack header"
+msgstr "协议错误：坏的包头"
 
-#: merge-recursive.c:1983
+#: fetch-pack.c:900
 #, c-format
-msgid ""
-"CONFLICT (implicit dir rename): Existing file/dir at %s in the way of "
-"implicit directory rename(s) putting the following path(s) there: %s."
-msgstr ""
-"冲突（隐式目录重命名）：处于隐式目录重命名的现存文件/目录 %s，将以下路径放"
-"在：%s。"
+msgid "fetch-pack: unable to fork off %s"
+msgstr "fetch-pack：无法派生进程 %s"
 
-#: merge-recursive.c:1993
+#: fetch-pack.c:916
 #, c-format
-msgid ""
-"CONFLICT (implicit dir rename): Cannot map more than one path to %s; "
-"implicit directory renames tried to put these paths there: %s"
-msgstr ""
-"冲突（隐式目录重命名）：无法映射一个以上路径到 %s，隐式目录重命名尝试将这些路"
-"径放置于此：%s"
+msgid "%s failed"
+msgstr "%s 失败"
 
-#: merge-recursive.c:2085
-#, c-format
-msgid ""
-"CONFLICT (rename/rename): Rename directory %s->%s in %s. Rename directory %s-"
-">%s in %s"
-msgstr ""
-"冲突（重命名/重命名）：在 %3$s 中重命名目录 %1$s->%2$s，在 %6$s 中重命名目录 "
-"%4$s->%5$s"
+#: fetch-pack.c:918
+msgid "error in sideband demultiplexer"
+msgstr "sideband 多路输出出错"
 
-#: merge-recursive.c:2330
+#: fetch-pack.c:965
 #, c-format
-msgid ""
-"WARNING: Avoiding applying %s -> %s rename to %s, because %s itself was "
-"renamed."
-msgstr "警告：避免应用 %s -> %s 的重命名到 %s，因为 %s 本身已被重命名。"
+msgid "Server version is %.*s"
+msgstr "服务器版本 %.*s"
 
-#: merge-recursive.c:2736
+#: fetch-pack.c:970 fetch-pack.c:976 fetch-pack.c:979 fetch-pack.c:985
+#: fetch-pack.c:989 fetch-pack.c:993 fetch-pack.c:997 fetch-pack.c:1001
+#: fetch-pack.c:1005 fetch-pack.c:1009 fetch-pack.c:1013 fetch-pack.c:1017
+#: fetch-pack.c:1023 fetch-pack.c:1029 fetch-pack.c:1034 fetch-pack.c:1039
 #, c-format
-msgid "CONFLICT (rename/add): Rename %s->%s in %s. %s added in %s"
-msgstr "冲突（重命名/添加）：在 %3$s 中重命名 %1$s->%2$s。在 %5$s 中添加 %4$s"
+msgid "Server supports %s"
+msgstr "服务器支持 %s"
 
-#: merge-recursive.c:2751
-#, c-format
-msgid "Adding merged %s"
-msgstr "添加合并后的 %s"
+#: fetch-pack.c:972
+msgid "Server does not support shallow clients"
+msgstr "服务器不支持 shalllow 客户端"
 
-#: merge-recursive.c:2758 merge-recursive.c:3089
-#, c-format
-msgid "Adding as %s instead"
-msgstr "而是以 %s 为名添加"
+#: fetch-pack.c:1032
+msgid "Server does not support --shallow-since"
+msgstr "服务器不支持 --shallow-since"
 
-#: merge-recursive.c:2914
-#, c-format
-msgid "cannot read object %s"
-msgstr "不能读取对象 %s"
+#: fetch-pack.c:1037
+msgid "Server does not support --shallow-exclude"
+msgstr "服务器不支持 --shallow-exclude"
 
-#: merge-recursive.c:2917
-#, c-format
-msgid "object %s is not a blob"
-msgstr "对象 %s 不是一个数据对象"
+#: fetch-pack.c:1041
+msgid "Server does not support --deepen"
+msgstr "服务器不支持 --deepen"
 
-#: merge-recursive.c:2986
-msgid "modify"
-msgstr "修改"
+#: fetch-pack.c:1058
+msgid "no common commits"
+msgstr "没有共同的提交"
 
-#: merge-recursive.c:2986
-msgid "modified"
-msgstr "修改"
+#: fetch-pack.c:1070 fetch-pack.c:1536
+msgid "git fetch-pack: fetch failed."
+msgstr "git fetch-pack：获取失败。"
 
-#: merge-recursive.c:2997
-msgid "content"
-msgstr "内容"
+#: fetch-pack.c:1209
+msgid "Server does not support shallow requests"
+msgstr "服务器不支持 shalllow 请求"
 
-#: merge-recursive.c:3004
-msgid "add/add"
-msgstr "添加/添加"
+#: fetch-pack.c:1216
+msgid "Server supports filter"
+msgstr "服务器支持 filter"
 
-#: merge-recursive.c:3046
+#: fetch-pack.c:1239
+msgid "unable to write request to remote"
+msgstr "无法将请求写到远程"
+
+#: fetch-pack.c:1257
 #, c-format
-msgid "Skipped %s (merged same as existing)"
-msgstr "略过 %s（已经做过相同合并）"
+msgid "error reading section header '%s'"
+msgstr "读取节标题 '%s' 出错"
 
-#: merge-recursive.c:3055 git-submodule.sh:895
-msgid "submodule"
-msgstr "子模组"
+#: fetch-pack.c:1263
+#, c-format
+msgid "expected '%s', received '%s'"
+msgstr "预期 '%s'，得到 '%s'"
 
-#: merge-recursive.c:3056
+#: fetch-pack.c:1303
 #, c-format
-msgid "CONFLICT (%s): Merge conflict in %s"
-msgstr "冲突（%s）：合并冲突于 %s"
+msgid "unexpected acknowledgment line: '%s'"
+msgstr "意外的确认行：'%s'"
 
-#: merge-recursive.c:3178
+#: fetch-pack.c:1308
 #, c-format
-msgid "Removing %s"
-msgstr "删除 %s"
+msgid "error processing acks: %d"
+msgstr "处理 ack 出错：%d"
 
-#: merge-recursive.c:3204
-msgid "file/directory"
-msgstr "文件/目录"
+#: fetch-pack.c:1318
+msgid "expected packfile to be sent after 'ready'"
+msgstr "预期在 'ready' 之后发送 packfile"
 
-#: merge-recursive.c:3210
-msgid "directory/file"
-msgstr "目录/文件"
+#: fetch-pack.c:1320
+msgid "expected no other sections to be sent after no 'ready'"
+msgstr "在没有 'ready' 不应该发送其它小节"
 
-#: merge-recursive.c:3217
+#: fetch-pack.c:1362
 #, c-format
-msgid "CONFLICT (%s): There is a directory with name %s in %s. Adding %s as %s"
-msgstr "冲突（%1$s）：在 %3$s 中有一个名为 %2$s 的目录。以 %5$s 为名添加 %4$s"
+msgid "error processing shallow info: %d"
+msgstr "处理浅克隆信息出错：%d"
 
-#: merge-recursive.c:3226
+#: fetch-pack.c:1409
 #, c-format
-msgid "Adding %s"
-msgstr "添加 %s"
+msgid "expected wanted-ref, got '%s'"
+msgstr "预期 wanted-ref，得到 '%s'"
 
-#: merge-recursive.c:3267
+#: fetch-pack.c:1414
 #, c-format
-msgid "Dirty index: cannot merge (dirty: %s)"
-msgstr "脏索引：不能合并（脏文件：%s）"
-
-#: merge-recursive.c:3271
-msgid "Already up to date!"
-msgstr "已经是最新的！"
+msgid "unexpected wanted-ref: '%s'"
+msgstr "意外的 wanted-ref：'%s'"
 
-#: merge-recursive.c:3280
+#: fetch-pack.c:1419
 #, c-format
-msgid "merging of trees %s and %s failed"
-msgstr "无法合并树 %s 和 %s"
+msgid "error processing wanted refs: %d"
+msgstr "处理要获取的引用出错：%d"
 
-#: merge-recursive.c:3379
-msgid "Merging:"
-msgstr "合并："
+#: fetch-pack.c:1762
+msgid "no matching remote head"
+msgstr "没有匹配的远程分支"
+
+#: fetch-pack.c:1785 builtin/clone.c:688
+msgid "remote did not send all necessary objects"
+msgstr "远程没有发送所有必需的对象"
 
-#: merge-recursive.c:3392
+#: fetch-pack.c:1812
 #, c-format
-msgid "found %u common ancestor:"
-msgid_plural "found %u common ancestors:"
-msgstr[0] "发现 %u 个共同祖先："
-msgstr[1] "发现 %u 个共同祖先："
+msgid "no such remote ref %s"
+msgstr "没有这样的远程引用 %s"
 
-#: merge-recursive.c:3431
-msgid "merge returned no commit"
-msgstr "合并未返回提交"
+#: fetch-pack.c:1815
+#, c-format
+msgid "Server does not allow request for unadvertised object %s"
+msgstr "服务器不允许请求未公开的对象 %s"
 
-#: merge-recursive.c:3495
+#: gpg-interface.c:223
+msgid "could not create temporary file"
+msgstr "不能创建临时文件"
+
+#: gpg-interface.c:226
 #, c-format
-msgid "Could not parse object '%s'"
-msgstr "不能解析对象 '%s'"
+msgid "failed writing detached signature to '%s'"
+msgstr "无法将分离式签名写入 '%s'"
 
-#: merge-recursive.c:3511 builtin/merge.c:659 builtin/merge.c:816
-msgid "Unable to write index."
-msgstr "不能写入索引。"
+#: gpg-interface.c:390
+msgid "gpg failed to sign the data"
+msgstr "gpg 无法为数据签名"
 
-#: notes-merge.c:272
+#: graph.c:98
 #, c-format
+msgid "ignore invalid color '%.*s' in log.graphColors"
+msgstr "忽略 log.graphColors 中无效的颜色 '%.*s'"
+
+#: grep.c:668
 msgid ""
-"You have not concluded your previous notes merge (%s exists).\n"
-"Please, use 'git notes merge --commit' or 'git notes merge --abort' to "
-"commit/abort the previous merge before you start a new notes merge."
+"given pattern contains NULL byte (via -f <file>). This is only supported "
+"with -P under PCRE v2"
 msgstr ""
-"您的前一次注释合并尚未结束（存在 %s）。\n"
-"在开始一个新的注释合并之前，请使用 'git notes merge --commit' 或者 'git "
-"notes merge --abort' 来提交/终止前一次合并。"
+"给定的模式包含 NULL 字符（通过 -f <文件> 参数）。只有 PCRE v2 下的 -P 支持此"
+"功能"
 
-#: notes-merge.c:279
+#: grep.c:2124
 #, c-format
-msgid "You have not concluded your notes merge (%s exists)."
-msgstr "您尚未结束注释合并（存在 %s）。"
-
-#: notes-utils.c:43
-msgid "Cannot commit uninitialized/unreferenced notes tree"
-msgstr "不能提交未初始化/未引用的注解树"
+msgid "'%s': unable to read %s"
+msgstr "'%s'：无法读取 %s"
 
-#: notes-utils.c:102
+#: grep.c:2141 setup.c:165 builtin/clone.c:411 builtin/diff.c:82
+#: builtin/rm.c:135
 #, c-format
-msgid "Bad notes.rewriteMode value: '%s'"
-msgstr "坏的 notes.rewriteMode 值：'%s'"
+msgid "failed to stat '%s'"
+msgstr "对 '%s' 调用 stat 失败"
 
-#: notes-utils.c:112
+#: grep.c:2152
 #, c-format
-msgid "Refusing to rewrite notes in %s (outside of refs/notes/)"
-msgstr "拒绝向 %s（在 refs/notes/ 之外）写入注解"
+msgid "'%s': short read"
+msgstr "'%s'：读取不完整"
 
-#. TRANSLATORS: The first %s is the name of
-#. the environment variable, the second %s is
-#. its value.
-#.
-#: notes-utils.c:142
-#, c-format
-msgid "Bad %s value: '%s'"
-msgstr "坏的 %s 值：'%s'"
+#: help.c:23
+msgid "start a working area (see also: git help tutorial)"
+msgstr "开始一个工作区（参见：git help tutorial）"
 
-#: object.c:242
-#, c-format
-msgid "unable to parse object: %s"
-msgstr "不能解析对象：%s"
+#: help.c:24
+msgid "work on the current change (see also: git help everyday)"
+msgstr "在当前变更上工作（参见：git help everyday）"
 
-#: packfile.c:563
-msgid "offset before end of packfile (broken .idx?)"
-msgstr "偏移量在包文件结束之前（损坏的 .idx？）"
+#: help.c:25
+msgid "examine the history and state (see also: git help revisions)"
+msgstr "检查历史和状态（参见：git help revisions）"
 
-#: packfile.c:1742
-#, c-format
-msgid "offset before start of pack index for %s (corrupt index?)"
-msgstr "偏移量在 %s 的包索引开始之前（损坏的索引？）"
+#: help.c:26
+msgid "grow, mark and tweak your common history"
+msgstr "扩展、标记和调校您的历史记录"
 
-#: packfile.c:1746
-#, c-format
-msgid "offset beyond end of pack index for %s (truncated index?)"
-msgstr "偏移量越过了 %s 的包索引的结尾（被截断的索引？）"
+#: help.c:27
+msgid "collaborate (see also: git help workflows)"
+msgstr "协同（参见：git help workflows）"
 
-#: parse-options.c:621
-msgid "..."
-msgstr "..."
+#: help.c:31
+msgid "Main Porcelain Commands"
+msgstr "主要的上层命令"
 
-#: parse-options.c:640
-#, c-format
-msgid "usage: %s"
-msgstr "用法：%s"
+#: help.c:32
+msgid "Ancillary Commands / Manipulators"
+msgstr "辅助命令/操作者"
 
-#. TRANSLATORS: the colon here should align with the
-#. one in "usage: %s" translation.
-#.
-#: parse-options.c:646
-#, c-format
-msgid "   or: %s"
-msgstr "  或：%s"
+#: help.c:33
+msgid "Ancillary Commands / Interrogators"
+msgstr "辅助命令/询问者"
 
-#  译者：为保证在输出中对齐，注意调整句中空格！
-#: parse-options.c:649
-#, c-format
-msgid "    %s"
-msgstr "    %s"
+#: help.c:34
+msgid "Interacting with Others"
+msgstr "与其它系统交互"
 
-#: parse-options.c:688
-msgid "-NUM"
-msgstr "-数字"
+#: help.c:35
+msgid "Low-level Commands / Manipulators"
+msgstr "低级命令/操作者"
 
-#: parse-options-cb.c:44
-#, c-format
-msgid "malformed expiration date '%s'"
-msgstr "格式错误的到期时间：'%s'"
+#: help.c:36
+msgid "Low-level Commands / Interrogators"
+msgstr "低级命令/询问者"
 
-#: parse-options-cb.c:112
-#, c-format
-msgid "malformed object name '%s'"
-msgstr "格式错误的对象名 '%s'"
+#: help.c:37
+msgid "Low-level Commands / Syncing Repositories"
+msgstr "低级命令/同步仓库"
 
-#: path.c:892
-#, c-format
-msgid "Could not make %s writable by group"
-msgstr "不能设置 %s 为组可写"
+#: help.c:38
+msgid "Low-level Commands / Internal Helpers"
+msgstr "低级命令/内部助手"
 
-#: pathspec.c:129
-msgid "Escape character '\\' not allowed as last character in attr value"
-msgstr "转义字符 '\\' 不能作为属性值的最后一个字符"
+#: help.c:298
+#, c-format
+msgid "available git commands in '%s'"
+msgstr "在 '%s' 下可用的 git 命令"
 
-#: pathspec.c:147
-msgid "Only one 'attr:' specification is allowed."
-msgstr "只允许一个 'attr:' 规格。"
+#: help.c:305
+msgid "git commands available from elsewhere on your $PATH"
+msgstr "在 $PATH 路径中的其他地方可用的 git 命令"
 
-#: pathspec.c:150
-msgid "attr spec must not be empty"
-msgstr "属性规格不能为空"
+#: help.c:314
+msgid "These are common Git commands used in various situations:"
+msgstr "这些是各种场合常见的 Git 命令："
 
-#: pathspec.c:193
+#: help.c:363 git.c:98
 #, c-format
-msgid "invalid attribute name %s"
-msgstr "无效的属性名 %s"
-
-#: pathspec.c:258
-msgid "global 'glob' and 'noglob' pathspec settings are incompatible"
-msgstr "全局的 'glob' 和 'noglob' 路径规格设置不兼容"
+msgid "unsupported command listing type '%s'"
+msgstr "不支持的命令列表类型 '%s'"
 
-#: pathspec.c:265
-msgid ""
-"global 'literal' pathspec setting is incompatible with all other global "
-"pathspec settings"
-msgstr "全局的 'literal' 路径规格设置和其它的全局路径规格设置不兼容"
+#: help.c:403
+msgid "The common Git guides are:"
+msgstr "最常用的 Git 向导有："
 
-#: pathspec.c:305
-msgid "invalid parameter for pathspec magic 'prefix'"
-msgstr "路径规格包含无效的神奇前缀"
+#: help.c:512
+msgid "See 'git help <command>' to read about a specific subcommand"
+msgstr "执行　'git help <command>' 来查看特定子命令"
+
+#: help.c:517
+msgid "External commands"
+msgstr "外部命令"
+
+#: help.c:532
+msgid "Command aliases"
+msgstr "命令别名"
 
-#: pathspec.c:326
+#: help.c:596
 #, c-format
-msgid "Invalid pathspec magic '%.*s' in '%s'"
-msgstr "在路径规格 '%3$s' 中无效的神奇前缀 '%2$.*1$s'"
+msgid ""
+"'%s' appears to be a git command, but we were not\n"
+"able to execute it. Maybe git-%s is broken?"
+msgstr ""
+"'%s' 像是一个 git 命令，但却无法运行。\n"
+"可能是 git-%s 受损？"
 
-#: pathspec.c:331
-#, c-format
-msgid "Missing ')' at the end of pathspec magic in '%s'"
-msgstr "路径规格 '%s' 的神奇前缀结尾少了一个 ')'"
+#: help.c:655
+msgid "Uh oh. Your system reports no Git commands at all."
+msgstr "唉呀，您的系统中未发现 Git 命令。"
 
-#: pathspec.c:369
+#: help.c:677
 #, c-format
-msgid "Unimplemented pathspec magic '%c' in '%s'"
-msgstr "路径规格 '%2$s' 中包含未实现的神奇前缀 '%1$c'"
+msgid "WARNING: You called a Git command named '%s', which does not exist."
+msgstr "警告：您运行了一个并不存在的 Git 命令 '%s'。"
 
-#: pathspec.c:428
+#: help.c:682
 #, c-format
-msgid "%s: 'literal' and 'glob' are incompatible"
-msgstr "%s：'literal' 和 'glob' 不兼容"
+msgid "Continuing under the assumption that you meant '%s'."
+msgstr "假定你想要的是 '%s' 并继续。"
 
-#: pathspec.c:441
+#: help.c:687
 #, c-format
-msgid "%s: '%s' is outside repository"
-msgstr "%s：'%s' 在仓库之外"
+msgid "Continuing in %0.1f seconds, assuming that you meant '%s'."
+msgstr "假定你想要的是 '%2$s'，在 %1$0.1f 秒钟后继续。"
 
-#: pathspec.c:515
+#: help.c:695
 #, c-format
-msgid "'%s' (mnemonic: '%c')"
-msgstr "'%s'（助记符：'%c'）"
+msgid "git: '%s' is not a git command. See 'git --help'."
+msgstr "git：'%s' 不是一个 git 命令。参见 'git --help'。"
 
-#: pathspec.c:525
-#, c-format
-msgid "%s: pathspec magic not supported by this command: %s"
-msgstr "%s：路径规格神奇前缀不被此命令支持：%s"
+#: help.c:699
+msgid ""
+"\n"
+"The most similar command is"
+msgid_plural ""
+"\n"
+"The most similar commands are"
+msgstr[0] ""
+"\n"
+"最相似的命令是"
+msgstr[1] ""
+"\n"
+"最相似的命令是"
+
+#: help.c:714
+msgid "git version [<options>]"
+msgstr "git version [<选项>]"
 
-#: pathspec.c:592
+#: help.c:783
 #, c-format
-msgid "pathspec '%s' is beyond a symbolic link"
-msgstr "路径规格 '%s' 位于符号链接中"
+msgid "%s: %s - %s"
+msgstr "%s：%s - %s"
 
-#: pretty.c:962
-msgid "unable to parse --pretty format"
-msgstr "不能解析 --pretty 格式"
+#: help.c:787
+msgid ""
+"\n"
+"Did you mean this?"
+msgid_plural ""
+"\n"
+"Did you mean one of these?"
+msgstr[0] ""
+"\n"
+"您指的是这个么？"
+msgstr[1] ""
+"\n"
+"您指的是这其中的某一个么？"
 
-#: read-cache.c:1500
-#, c-format
+#: ident.c:349
 msgid ""
-"index.version set, but the value is invalid.\n"
-"Using version %i"
+"\n"
+"*** Please tell me who you are.\n"
+"\n"
+"Run\n"
+"\n"
+"  git config --global user.email \"you@example.com\"\n"
+"  git config --global user.name \"Your Name\"\n"
+"\n"
+"to set your account's default identity.\n"
+"Omit --global to set the identity only in this repository.\n"
+"\n"
 msgstr ""
-"设置了 index.version，但是取值无效。\n"
-"使用版本 %i"
+"\n"
+"*** 请告诉我你是谁。\n"
+"\n"
+"运行\n"
+"\n"
+"  git config --global user.email \"you@example.com\"\n"
+"  git config --global user.name \"Your Name\"\n"
+"\n"
+"来设置您账号的缺省身份标识。\n"
+"如果仅在本仓库设置身份标识，则省略 --global 参数。\n"
 
-#: read-cache.c:1510
+#: ident.c:379
+msgid "no email was given and auto-detection is disabled"
+msgstr "未提供邮件地址且自动探测被禁用"
+
+#: ident.c:384
 #, c-format
-msgid ""
-"GIT_INDEX_VERSION set, but the value is invalid.\n"
-"Using version %i"
-msgstr ""
-"设置了 GIT_INDEX_VERSION，但是取值无效。\n"
-"使用版本 %i"
+msgid "unable to auto-detect email address (got '%s')"
+msgstr "无法自动探测邮件地址（得到 '%s'）"
+
+#: ident.c:401
+msgid "no name was given and auto-detection is disabled"
+msgstr "未提供姓名且自动探测被禁用"
 
-#: read-cache.c:2404 sequencer.c:4338 wrapper.c:658 builtin/merge.c:1048
+#: ident.c:407
 #, c-format
-msgid "could not close '%s'"
-msgstr "不能关闭 '%s'"
+msgid "unable to auto-detect name (got '%s')"
+msgstr "无法自动探测姓名（得到 '%s'）"
 
-#: read-cache.c:2477 sequencer.c:2102 sequencer.c:3234
+#: ident.c:415
 #, c-format
-msgid "could not stat '%s'"
-msgstr "不能对 '%s' 调用 stat"
+msgid "empty ident name (for <%s>) not allowed"
+msgstr "不允许空的姓名（对于 <%s>）"
 
-#: read-cache.c:2490
+#: ident.c:421
 #, c-format
-msgid "unable to open git dir: %s"
-msgstr "不能打开 git 目录：%s"
+msgid "name consists only of disallowed characters: %s"
+msgstr "姓名中仅包含禁用字符：%s"
 
-#: read-cache.c:2502
+#: ident.c:436 builtin/commit.c:631
 #, c-format
-msgid "unable to unlink: %s"
-msgstr "无法删除：%s"
+msgid "invalid date format: %s"
+msgstr "无效的日期格式：%s"
 
-#: refs.c:732 sequencer.c:4334 sequencer.c:4393 wrapper.c:225 wrapper.c:395
-#: builtin/am.c:779
+#: list-objects.c:127
 #, c-format
-msgid "could not open '%s' for writing"
-msgstr "无法打开 '%s' 进行写入"
+msgid "entry '%s' in tree %s has tree mode, but is not a tree"
+msgstr "树 %2$s 中的条目 '%1$s' 具有树的属性，但不是一个树对象"
 
-#: refs.c:1880
-msgid "ref updates forbidden inside quarantine environment"
-msgstr "在隔离环境中禁止更新引用"
+#: list-objects.c:140
+#, c-format
+msgid "entry '%s' in tree %s has blob mode, but is not a blob"
+msgstr "树 %2$s 中的条目 '%1$s' 具有数据对象的属性，但不是一个数据对象"
 
-#: refs/files-backend.c:1191
+#: list-objects.c:375
 #, c-format
-msgid "could not remove reference %s"
-msgstr "无法删除引用 %s"
+msgid "unable to load root tree for commit %s"
+msgstr "无法为提交 %s 加载根树"
 
-#: refs/files-backend.c:1205 refs/packed-backend.c:1531
-#: refs/packed-backend.c:1541
+#: list-objects-filter.c:492
 #, c-format
-msgid "could not delete reference %s: %s"
-msgstr "无法删除引用 %s：%s"
+msgid "unable to access sparse blob in '%s'"
+msgstr "不能访问 '%s' 中的稀疏数据对象"
 
-#: refs/files-backend.c:1208 refs/packed-backend.c:1544
+#: list-objects-filter.c:495
 #, c-format
-msgid "could not delete references: %s"
-msgstr "无法删除引用：%s"
+msgid "unable to parse sparse filter data in %s"
+msgstr "无法解析 %s 中的稀疏过滤器数据"
 
-#: ref-filter.c:35 wt-status.c:1850
-msgid "gone"
-msgstr "丢失"
+#: list-objects-filter-options.c:58
+msgid "expected 'tree:<depth>'"
+msgstr "期望 'tree:<深度>'"
 
-#: ref-filter.c:36
+#: list-objects-filter-options.c:73
+msgid "sparse:path filters support has been dropped"
+msgstr "sparse:path 过滤器支持已被删除"
+
+#: list-objects-filter-options.c:86
 #, c-format
-msgid "ahead %d"
-msgstr "领先 %d"
+msgid "invalid filter-spec '%s'"
+msgstr "无效的过滤器表达式 '%s'"
 
-#: ref-filter.c:37
+#: list-objects-filter-options.c:102
 #, c-format
-msgid "behind %d"
-msgstr "落后 %d"
+msgid "must escape char in sub-filter-spec: '%c'"
+msgstr "必须对 sub-filter-spec 中的字符进行转义：'%c'"
 
-#: ref-filter.c:38
-#, c-format
-msgid "ahead %d, behind %d"
-msgstr "领先 %d，落后 %d"
+#: list-objects-filter-options.c:144
+msgid "expected something after combine:"
+msgstr "期望在组合后有一些东西："
 
-#: ref-filter.c:121
-#, c-format
-msgid "expected format: %%(color:<color>)"
-msgstr "期望的格式：%%(color:<颜色>)"
+#: list-objects-filter-options.c:226
+msgid "multiple filter-specs cannot be combined"
+msgstr "不能混用多种过滤规格"
 
-#: ref-filter.c:123
+#: lockfile.c:151
 #, c-format
-msgid "unrecognized color: %%(color:%s)"
-msgstr "未能识别的颜色：%%(color:%s)"
+msgid ""
+"Unable to create '%s.lock': %s.\n"
+"\n"
+"Another git process seems to be running in this repository, e.g.\n"
+"an editor opened by 'git commit'. Please make sure all processes\n"
+"are terminated then try again. If it still fails, a git process\n"
+"may have crashed in this repository earlier:\n"
+"remove the file manually to continue."
+msgstr ""
+"无法创建 '%s.lock'：%s。\n"
+"\n"
+"似乎另外一个 git 进程在这个仓库中运行，例如：'git commit' 命令打\n"
+"开了一个编辑器。请确认所有进程都已经关闭然后重试。如果仍然报错，\n"
+"可能之前有一个 git 进程在这个仓库中异常退出：\n"
+"手动删除这个文件再继续。"
 
-#: ref-filter.c:145
+#: lockfile.c:159
 #, c-format
-msgid "Integer value expected refname:lstrip=%s"
-msgstr "期望整数值 refname:lstrip=%s"
+msgid "Unable to create '%s.lock': %s"
+msgstr "不能创建 '%s.lock'：%s"
 
-#: ref-filter.c:149
-#, c-format
-msgid "Integer value expected refname:rstrip=%s"
-msgstr "期望整数值 refname:rstrip=%s"
+#: merge.c:41
+msgid "failed to read the cache"
+msgstr "读取缓存失败"
 
-#: ref-filter.c:151
-#, c-format
-msgid "unrecognized %%(%s) argument: %s"
-msgstr "未能识别的 %%(%s) 参数：%s"
+#: merge.c:107 rerere.c:720 builtin/am.c:1874 builtin/am.c:1908
+#: builtin/checkout.c:539 builtin/checkout.c:798 builtin/clone.c:809
+#: builtin/stash.c:264
+msgid "unable to write new index file"
+msgstr "无法写新的索引文件"
 
-#: ref-filter.c:206
-#, c-format
-msgid "%%(body) does not take arguments"
-msgstr "%%(body) 不带参数"
+#: merge-recursive.c:367
+msgid "(bad commit)\n"
+msgstr "（坏提交）\n"
 
-#: ref-filter.c:215
+#: merge-recursive.c:390
 #, c-format
-msgid "%%(subject) does not take arguments"
-msgstr "%%(subject) 不带参数"
+msgid "add_cacheinfo failed for path '%s'; merge aborting."
+msgstr "add_cacheinfo 对路径 '%s' 执行失败，合并终止。"
 
-#: ref-filter.c:235
+#: merge-recursive.c:399
 #, c-format
-msgid "unknown %%(trailers) argument: %s"
-msgstr "未知的 %%(trailers) 参数：%s"
+msgid "add_cacheinfo failed to refresh for path '%s'; merge aborting."
+msgstr "add_cacheinfo 无法刷新路径 '%s'，合并终止。"
 
-#: ref-filter.c:264
+#: merge-recursive.c:885
 #, c-format
-msgid "positive value expected contents:lines=%s"
-msgstr "期望一个正数 contents:lines=%s"
+msgid "failed to create path '%s'%s"
+msgstr "创建路径 '%s'%s 失败"
 
-#: ref-filter.c:266
+#: merge-recursive.c:896
 #, c-format
-msgid "unrecognized %%(contents) argument: %s"
-msgstr "未能识别的 %%(contents) 参数：%s"
+msgid "Removing %s to make room for subdirectory\n"
+msgstr "删除 %s 以便为子目录留出空间\n"
 
-#: ref-filter.c:281
-#, c-format
-msgid "positive value expected objectname:short=%s"
-msgstr "期望一个正数 objectname:short=%s"
+#: merge-recursive.c:910 merge-recursive.c:929
+msgid ": perhaps a D/F conflict?"
+msgstr "：可能是一个目录/文件冲突？"
 
-#: ref-filter.c:285
+#: merge-recursive.c:919
 #, c-format
-msgid "unrecognized %%(objectname) argument: %s"
-msgstr "未能识别的 %%(objectname) 参数：%s"
+msgid "refusing to lose untracked file at '%s'"
+msgstr "拒绝丢弃 '%s' 中的未跟踪文件"
 
-#: ref-filter.c:315
+#: merge-recursive.c:960 builtin/cat-file.c:41
 #, c-format
-msgid "expected format: %%(align:<width>,<position>)"
-msgstr "期望的格式：%%(align:<宽度>,<位置>)"
+msgid "cannot read object %s '%s'"
+msgstr "不能读取对象 %s '%s'"
 
-#: ref-filter.c:327
+#: merge-recursive.c:965
 #, c-format
-msgid "unrecognized position:%s"
-msgstr "未能识别的位置：%s"
+msgid "blob expected for %s '%s'"
+msgstr "%s '%s' 应为数据对象"
 
-#: ref-filter.c:334
+#: merge-recursive.c:990
 #, c-format
-msgid "unrecognized width:%s"
-msgstr "未能识别的宽度：%s"
+msgid "failed to open '%s': %s"
+msgstr "打开 '%s' 失败：%s"
 
-#: ref-filter.c:343
+#: merge-recursive.c:1001
 #, c-format
-msgid "unrecognized %%(align) argument: %s"
-msgstr "未能识别的 %%(align) 参数：%s"
+msgid "failed to symlink '%s': %s"
+msgstr "创建符号链接 '%s' 失败：%s"
 
-#: ref-filter.c:351
+#: merge-recursive.c:1006
 #, c-format
-msgid "positive width expected with the %%(align) atom"
-msgstr "元素 %%(align) 需要一个正数的宽度"
+msgid "do not know what to do with %06o %s '%s'"
+msgstr "不知道如何处理 %06o %s '%s'"
 
-#: ref-filter.c:369
+#: merge-recursive.c:1199
 #, c-format
-msgid "unrecognized %%(if) argument: %s"
-msgstr "未能识别的 %%(if) 参数：%s"
+msgid "Failed to merge submodule %s (not checked out)"
+msgstr "无法合并子模组 %s （没有检出）"
 
-#: ref-filter.c:464
+#: merge-recursive.c:1206
 #, c-format
-msgid "malformed field name: %.*s"
-msgstr "格式错误的字段名：%.*s"
+msgid "Failed to merge submodule %s (commits not present)"
+msgstr "无法合并子模组 %s（提交不存在）"
 
-#: ref-filter.c:491
+#: merge-recursive.c:1213
 #, c-format
-msgid "unknown field name: %.*s"
-msgstr "未知的字段名：%.*s"
+msgid "Failed to merge submodule %s (commits don't follow merge-base)"
+msgstr "无法合并子模组 %s （提交未跟随合并基线）"
 
-#: ref-filter.c:608
+#: merge-recursive.c:1221 merge-recursive.c:1233
 #, c-format
-msgid "format: %%(if) atom used without a %%(then) atom"
-msgstr "格式：使用了 %%(if) 元素而没有 %%(then) 元素"
+msgid "Fast-forwarding submodule %s to the following commit:"
+msgstr "子模组 %s 快进到如下提交："
 
-#: ref-filter.c:671
+#: merge-recursive.c:1224 merge-recursive.c:1236
 #, c-format
-msgid "format: %%(then) atom used without an %%(if) atom"
-msgstr "格式：使用了 %%(then) 元素而没有 %%(if) 元素"
+msgid "Fast-forwarding submodule %s"
+msgstr "快进子模组 %s"
 
-#: ref-filter.c:673
+#: merge-recursive.c:1259
 #, c-format
-msgid "format: %%(then) atom used more than once"
-msgstr "格式：%%(then) 元素用了多次"
+msgid "Failed to merge submodule %s (merge following commits not found)"
+msgstr "无法合并子模组 %s （没发现合并跟随的提交）"
 
-#: ref-filter.c:675
+#: merge-recursive.c:1263
 #, c-format
-msgid "format: %%(then) atom used after %%(else)"
-msgstr "格式：%%(then) 元素用在了 %%(else) 之后"
+msgid "Failed to merge submodule %s (not fast-forward)"
+msgstr "无法合并子模组 %s（非快进）"
 
-#: ref-filter.c:703
-#, c-format
-msgid "format: %%(else) atom used without an %%(if) atom"
-msgstr "格式：使用了 %%(else) 元素而没有 %%(if) 元素"
+#: merge-recursive.c:1264
+msgid "Found a possible merge resolution for the submodule:\n"
+msgstr "找到子模组的一个可能的合并方案：\n"
 
-#: ref-filter.c:705
+#: merge-recursive.c:1267
 #, c-format
-msgid "format: %%(else) atom used without a %%(then) atom"
-msgstr "格式：使用了 %%(else) 元素而没有 %%(then) 元素"
+msgid ""
+"If this is correct simply add it to the index for example\n"
+"by using:\n"
+"\n"
+"  git update-index --cacheinfo 160000 %s \"%s\"\n"
+"\n"
+"which will accept this suggestion.\n"
+msgstr ""
+"如果这个正确，将其添加到索引，例如使用命令：\n"
+"\n"
+"  git update-index --cacheinfo 160000 %s \"%s\"\n"
+"\n"
+"以接受此建议。\n"
 
-#: ref-filter.c:707
+#: merge-recursive.c:1276
 #, c-format
-msgid "format: %%(else) atom used more than once"
-msgstr "格式：%%(else) 元素用了多次"
+msgid "Failed to merge submodule %s (multiple merges found)"
+msgstr "无法合并子模组 %s （发现多个合并）"
+
+#: merge-recursive.c:1349
+msgid "Failed to execute internal merge"
+msgstr "无法执行内部合并"
 
-#: ref-filter.c:722
+#: merge-recursive.c:1354
 #, c-format
-msgid "format: %%(end) atom used without corresponding atom"
-msgstr "格式：使用了 %%(end) 元素却没有它的对应元素"
+msgid "Unable to add %s to database"
+msgstr "不能添加 %s 至对象库"
 
-#: ref-filter.c:779
+#: merge-recursive.c:1386
 #, c-format
-msgid "malformed format string %s"
-msgstr "错误的格式化字符串 %s"
+msgid "Auto-merging %s"
+msgstr "自动合并 %s"
 
-#: ref-filter.c:1387
+#: merge-recursive.c:1410
 #, c-format
-msgid "(no branch, rebasing %s)"
-msgstr "（非分支，正变基 %s）"
+msgid "Error: Refusing to lose untracked file at %s; writing to %s instead."
+msgstr "错误：拒绝丢失未跟踪文件 '%s'，而是写入 %s。"
 
-#: ref-filter.c:1390
+#: merge-recursive.c:1482
 #, c-format
-msgid "(no branch, rebasing detached HEAD %s)"
-msgstr "（非分支，正变基分离头指针 %s）"
+msgid ""
+"CONFLICT (%s/delete): %s deleted in %s and %s in %s. Version %s of %s left "
+"in tree."
+msgstr ""
+"冲突（%1$s/删除）：%2$s 在 %3$s 中被删除，在 %5$s 中被 %4$s。%7$s 的 %6$s 版"
+"本被保留。"
 
-#: ref-filter.c:1393
+#: merge-recursive.c:1487
 #, c-format
-msgid "(no branch, bisect started on %s)"
-msgstr "（非分支，二分查找开始于 %s）"
+msgid ""
+"CONFLICT (%s/delete): %s deleted in %s and %s to %s in %s. Version %s of %s "
+"left in tree."
+msgstr ""
+"冲突（%1$s/删除）：%2$s 在 %3$s 中被删除，在 %6$s 中的 %5$s 被 %4$s。%8$s 的 "
+"%7$s 版本被保留。"
 
-#. TRANSLATORS: make sure this matches "HEAD
-#. detached at " in wt-status.c
-#.
-#: ref-filter.c:1401
+#: merge-recursive.c:1494
 #, c-format
-msgid "(HEAD detached at %s)"
-msgstr "（头指针分离于 %s）"
+msgid ""
+"CONFLICT (%s/delete): %s deleted in %s and %s in %s. Version %s of %s left "
+"in tree at %s."
+msgstr ""
+"冲突（%1$s/删除）：%2$s 在 %3$s 中被删除，在 %5$s 中被 %4$s。%7$s 的 %6$s 版"
+"本保留在 %8$s 中。"
 
-#. TRANSLATORS: make sure this matches "HEAD
-#. detached from " in wt-status.c
-#.
-#: ref-filter.c:1408
+#: merge-recursive.c:1499
 #, c-format
-msgid "(HEAD detached from %s)"
-msgstr "（头指针分离自 %s）"
+msgid ""
+"CONFLICT (%s/delete): %s deleted in %s and %s to %s in %s. Version %s of %s "
+"left in tree at %s."
+msgstr ""
+"冲突（%1$s/删除）：%2$s 在 %3$s 中被删除，在 %6$s 中的 %5$s 被 %4$s。%8$s 的 "
+"%7$s 版本保留在 %9$s 中。"
 
-#: ref-filter.c:1412
-msgid "(no branch)"
-msgstr "（非分支）"
+#: merge-recursive.c:1534
+msgid "rename"
+msgstr "重命名"
 
-#: ref-filter.c:1442
-#, c-format
-msgid "missing object %s for %s"
-msgstr "缺失 %2$s 的对象 %1$s"
+#: merge-recursive.c:1534
+msgid "renamed"
+msgstr "重命名"
 
-#: ref-filter.c:1445
+#: merge-recursive.c:1614 merge-recursive.c:2530 merge-recursive.c:3175
 #, c-format
-msgid "parse_object_buffer failed on %s for %s"
-msgstr "parse_object_buffer 失败于 %2$s 的 %1$s"
+msgid "Refusing to lose dirty file at %s"
+msgstr "拒绝丢失脏文件 '%s'"
 
-#: ref-filter.c:1902
+#: merge-recursive.c:1624
 #, c-format
-msgid "malformed object at '%s'"
-msgstr "格式错误的对象 '%s'"
+msgid "Refusing to lose untracked file at %s, even though it's in the way."
+msgstr "拒绝在 '%s' 处失去未跟踪文件，即使它存在于重命名中。"
 
-#: ref-filter.c:1984
+#: merge-recursive.c:1682
 #, c-format
-msgid "ignoring ref with broken name %s"
-msgstr "忽略带有错误名称 %s 的引用"
+msgid "CONFLICT (rename/add): Rename %s->%s in %s.  Added %s in %s"
+msgstr "冲突（重命名/添加）：在 %3$s 中重命名 %1$s->%2$s。在 %5$s 中添加 %4$s"
 
-#: ref-filter.c:1989
+#: merge-recursive.c:1713
 #, c-format
-msgid "ignoring broken ref %s"
-msgstr "忽略损坏的引用 %s"
+msgid "%s is a directory in %s adding as %s instead"
+msgstr "%s 是 %s 中的一个目录而以 %s 为名被添加"
 
-#: ref-filter.c:2261
+#: merge-recursive.c:1718
 #, c-format
-msgid "format: %%(end) atom missing"
-msgstr "格式：缺少 %%(end) 元素"
+msgid "Refusing to lose untracked file at %s; adding as %s instead"
+msgstr "拒绝丢失未跟踪文件 '%s'，而是添加为 %s"
 
-#: ref-filter.c:2365
+#: merge-recursive.c:1737
 #, c-format
-msgid "malformed object name %s"
-msgstr "格式错误的对象名 %s"
+msgid ""
+"CONFLICT (rename/rename): Rename \"%s\"->\"%s\" in branch \"%s\" rename \"%s"
+"\"->\"%s\" in \"%s\"%s"
+msgstr ""
+"冲突（重命名/重命名）：在分支 \"%3$s\" 中重命名 \"%1$s\"->\"%2$s\"，在分支 "
+"\"%6$s\" 中重命名 \"%4$s\"->\"%5$s\"%7$s"
 
-#: remote.c:605
-#, c-format
-msgid "Cannot fetch both %s and %s to %s"
-msgstr "不能同时获取 %s 和 %s 至 %s"
+#: merge-recursive.c:1742
+msgid " (left unresolved)"
+msgstr "（留下未解决）"
 
-#: remote.c:609
+#: merge-recursive.c:1851
 #, c-format
-msgid "%s usually tracks %s, not %s"
-msgstr "%s 通常跟踪 %s，而非 %s"
+msgid "CONFLICT (rename/rename): Rename %s->%s in %s. Rename %s->%s in %s"
+msgstr ""
+"冲突（重命名/重命名）：在 %3$s 中重命名 %1$s->%2$s，在 %6$s 中重命名 %4$s->"
+"%5$s"
 
-#: remote.c:613
+#: merge-recursive.c:2114
 #, c-format
-msgid "%s tracks both %s and %s"
-msgstr "%s 同时跟踪 %s 和 %s"
-
-#: remote.c:621
-msgid "Internal error"
-msgstr "内部错误"
-
-#: remote.c:1534 remote.c:1635
-msgid "HEAD does not point to a branch"
-msgstr "HEAD 没有指向一个分支"
+msgid ""
+"CONFLICT (directory rename split): Unclear where to place %s because "
+"directory %s was renamed to multiple other directories, with no destination "
+"getting a majority of the files."
+msgstr ""
+"冲突（分割的目录重命名）：不清楚 %s 应该放在哪里，因为目录 %s 被重命名到多个"
+"其它目录，没有目录包含大部分文件。"
 
-#: remote.c:1543
+#: merge-recursive.c:2146
 #, c-format
-msgid "no such branch: '%s'"
-msgstr "没有此分支：'%s'"
+msgid ""
+"CONFLICT (implicit dir rename): Existing file/dir at %s in the way of "
+"implicit directory rename(s) putting the following path(s) there: %s."
+msgstr ""
+"冲突（隐式目录重命名）：处于隐式目录重命名的现存文件/目录 %s，将以下路径放"
+"在：%s。"
 
-#: remote.c:1546
+#: merge-recursive.c:2156
 #, c-format
-msgid "no upstream configured for branch '%s'"
-msgstr "尚未给分支 '%s' 设置上游"
+msgid ""
+"CONFLICT (implicit dir rename): Cannot map more than one path to %s; "
+"implicit directory renames tried to put these paths there: %s"
+msgstr ""
+"冲突（隐式目录重命名）：无法映射一个以上路径到 %s，隐式目录重命名尝试将这些路"
+"径放置于此：%s"
 
-#: remote.c:1552
+#: merge-recursive.c:2248
 #, c-format
-msgid "upstream branch '%s' not stored as a remote-tracking branch"
-msgstr "上游分支 '%s' 没有存储为一个远程跟踪分支"
-
-#: remote.c:1567
+msgid ""
+"CONFLICT (rename/rename): Rename directory %s->%s in %s. Rename directory %s-"
+">%s in %s"
+msgstr ""
+"冲突（重命名/重命名）：在 %3$s 中重命名目录 %1$s->%2$s，在 %6$s 中重命名目录 "
+"%4$s->%5$s"
+
+#: merge-recursive.c:2493
 #, c-format
-msgid "push destination '%s' on remote '%s' has no local tracking branch"
-msgstr "推送目标 '%s' 至远程 '%s' 没有本地跟踪分支"
+msgid ""
+"WARNING: Avoiding applying %s -> %s rename to %s, because %s itself was "
+"renamed."
+msgstr "警告：避免应用 %s -> %s 的重命名到 %s，因为 %s 本身已被重命名。"
 
-#: remote.c:1579
+#: merge-recursive.c:3019
 #, c-format
-msgid "branch '%s' has no remote for pushing"
-msgstr "分支 '%s' 没有设置要推送的远程服务器"
+msgid "cannot read object %s"
+msgstr "不能读取对象 %s"
 
-#: remote.c:1589
+#: merge-recursive.c:3022
 #, c-format
-msgid "push refspecs for '%s' do not include '%s'"
-msgstr "向 '%s' 推送引用规格未包含 '%s'"
+msgid "object %s is not a blob"
+msgstr "对象 %s 不是一个数据对象"
 
-#: remote.c:1602
-msgid "push has no destination (push.default is 'nothing')"
-msgstr "推送无目标（push.default 是 'nothing'）"
+#: merge-recursive.c:3086
+msgid "modify"
+msgstr "修改"
 
-#: remote.c:1624
-msgid "cannot resolve 'simple' push to a single destination"
-msgstr "无法解析 'simple' 推送至一个单独的目标"
+#: merge-recursive.c:3086
+msgid "modified"
+msgstr "修改"
+
+#: merge-recursive.c:3098
+msgid "content"
+msgstr "内容"
+
+#: merge-recursive.c:3102
+msgid "add/add"
+msgstr "添加/添加"
 
-#: remote.c:1939
+#: merge-recursive.c:3125
 #, c-format
-msgid "Your branch is based on '%s', but the upstream is gone.\n"
-msgstr "您的分支基于 '%s'，但此上游分支已经不存在。\n"
+msgid "Skipped %s (merged same as existing)"
+msgstr "略过 %s（已经做过相同合并）"
 
-#: remote.c:1943
-msgid "  (use \"git branch --unset-upstream\" to fixup)\n"
-msgstr "  （使用 \"git branch --unset-upstream\" 来修复）\n"
+#: merge-recursive.c:3147 git-submodule.sh:993
+msgid "submodule"
+msgstr "子模组"
 
-#: remote.c:1946
+#: merge-recursive.c:3148
 #, c-format
-msgid "Your branch is up to date with '%s'.\n"
-msgstr "您的分支与上游分支 '%s' 一致。\n"
+msgid "CONFLICT (%s): Merge conflict in %s"
+msgstr "冲突（%s）：合并冲突于 %s"
 
-#: remote.c:1950
+#: merge-recursive.c:3178
 #, c-format
-msgid "Your branch and '%s' refer to different commits.\n"
-msgstr "您的分支和 '%s' 指向不同的提交。\n"
+msgid "Adding as %s instead"
+msgstr "而是以 %s 为名添加"
 
-#: remote.c:1953
+#: merge-recursive.c:3261
 #, c-format
-msgid "  (use \"%s\" for details)\n"
-msgstr "  （使用 \"%s\" 查看详情）\n"
+msgid ""
+"Path updated: %s added in %s inside a directory that was renamed in %s; "
+"moving it to %s."
+msgstr ""
+"路径已更新：%s 添加到 %s，位于一个被重命名到 %s 的目录中，将其移动到 %s。"
 
-#: remote.c:1957
+#: merge-recursive.c:3264
 #, c-format
-msgid "Your branch is ahead of '%s' by %d commit.\n"
-msgid_plural "Your branch is ahead of '%s' by %d commits.\n"
-msgstr[0] "您的分支领先 '%s' 共 %d 个提交。\n"
-msgstr[1] "您的分支领先 '%s' 共 %d 个提交。\n"
+msgid ""
+"CONFLICT (file location): %s added in %s inside a directory that was renamed "
+"in %s, suggesting it should perhaps be moved to %s."
+msgstr ""
+"冲突（文件位置）：%s 添加到 %s，位于一个被重命名为 %s 的目录中，建议将其移动"
+"到 %s。"
 
-#: remote.c:1963
-msgid "  (use \"git push\" to publish your local commits)\n"
-msgstr "  （使用 \"git push\" 来发布您的本地提交）\n"
+#: merge-recursive.c:3268
+#, c-format
+msgid ""
+"Path updated: %s renamed to %s in %s, inside a directory that was renamed in "
+"%s; moving it to %s."
+msgstr ""
+"路径已更新：%1$s 重命名为 %3$s 中的 %2$s，而该目录被重命名到 %4$s 中，将其移"
+"动到 %5$s。"
 
-#: remote.c:1966
+#: merge-recursive.c:3271
 #, c-format
-msgid "Your branch is behind '%s' by %d commit, and can be fast-forwarded.\n"
-msgid_plural ""
-"Your branch is behind '%s' by %d commits, and can be fast-forwarded.\n"
-msgstr[0] "您的分支落后 '%s' 共 %d 个提交，并且可以快进。\n"
-msgstr[1] "您的分支落后 '%s' 共 %d 个提交，并且可以快进。\n"
+msgid ""
+"CONFLICT (file location): %s renamed to %s in %s, inside a directory that "
+"was renamed in %s, suggesting it should perhaps be moved to %s."
+msgstr ""
+"冲突（文件位置）：%1$s 重命名为 %3$s 中的 %2$s，而该目录被重命名到 %4$s 中，"
+"建议将其移动到 %5$s。"
 
-#  译者：注意保持前导空格
-#: remote.c:1974
-msgid "  (use \"git pull\" to update your local branch)\n"
-msgstr "  （使用 \"git pull\" 来更新您的本地分支）\n"
+#: merge-recursive.c:3385
+#, c-format
+msgid "Removing %s"
+msgstr "删除 %s"
+
+#: merge-recursive.c:3408
+msgid "file/directory"
+msgstr "文件/目录"
+
+#: merge-recursive.c:3413
+msgid "directory/file"
+msgstr "目录/文件"
 
-#: remote.c:1977
+#: merge-recursive.c:3420
 #, c-format
-msgid ""
-"Your branch and '%s' have diverged,\n"
-"and have %d and %d different commit each, respectively.\n"
-msgid_plural ""
-"Your branch and '%s' have diverged,\n"
-"and have %d and %d different commits each, respectively.\n"
-msgstr[0] ""
-"您的分支和 '%s' 出现了偏离，\n"
-"并且分别有 %d 和 %d 处不同的提交。\n"
-msgstr[1] ""
-"您的分支和 '%s' 出现了偏离，\n"
-"并且分别有 %d 和 %d 处不同的提交。\n"
+msgid "CONFLICT (%s): There is a directory with name %s in %s. Adding %s as %s"
+msgstr "冲突（%1$s）：在 %3$s 中有一个名为 %2$s 的目录。以 %5$s 为名添加 %4$s"
 
-#  译者：注意保持前导空格
-#: remote.c:1987
-msgid "  (use \"git pull\" to merge the remote branch into yours)\n"
-msgstr "  （使用 \"git pull\" 来合并远程分支）\n"
+#: merge-recursive.c:3429
+#, c-format
+msgid "Adding %s"
+msgstr "添加 %s"
 
-#: revision.c:2289
-msgid "your current branch appears to be broken"
-msgstr "您的当前分支好像被损坏"
+#: merge-recursive.c:3438
+#, c-format
+msgid "CONFLICT (add/add): Merge conflict in %s"
+msgstr "冲突（add/add）：合并冲突于 %s"
 
-#: revision.c:2292
+#: merge-recursive.c:3482
+msgid "Already up to date!"
+msgstr "已经是最新的！"
+
+#: merge-recursive.c:3491
 #, c-format
-msgid "your current branch '%s' does not have any commits yet"
-msgstr "您的当前分支 '%s' 尚无任何提交"
+msgid "merging of trees %s and %s failed"
+msgstr "无法合并树 %s 和 %s"
 
-#: revision.c:2489
-msgid "--first-parent is incompatible with --bisect"
-msgstr "--first-parent 与 --bisect 不兼容"
+#: merge-recursive.c:3595
+msgid "Merging:"
+msgstr "合并："
 
-#: run-command.c:728
-msgid "open /dev/null failed"
-msgstr "不能打开 /dev/null"
+#: merge-recursive.c:3608
+#, c-format
+msgid "found %u common ancestor:"
+msgid_plural "found %u common ancestors:"
+msgstr[0] "发现 %u 个共同祖先："
+msgstr[1] "发现 %u 个共同祖先："
+
+#: merge-recursive.c:3658
+msgid "merge returned no commit"
+msgstr "合并未返回提交"
 
-#: run-command.c:1271
+#: merge-recursive.c:3717
 #, c-format
 msgid ""
-"The '%s' hook was ignored because it's not set as executable.\n"
-"You can disable this warning with `git config advice.ignoredHook false`."
+"Your local changes to the following files would be overwritten by merge:\n"
+"  %s"
 msgstr ""
-"因为没有将钩子 '%s' 设置为可执行，钩子被忽略。您可以通过\n"
-"配置 `git config advice.ignoredHook false` 来关闭这条警告。"
+"您对下列文件的本地修改将被合并操作覆盖：\n"
+"  %s"
 
-#: send-pack.c:141
-msgid "unexpected flush packet while reading remote unpack status"
-msgstr "读取远程解包状态时收到意外的 flush 包"
+#: merge-recursive.c:3814
+#, c-format
+msgid "Could not parse object '%s'"
+msgstr "不能解析对象 '%s'"
 
-#: send-pack.c:143
+#: merge-recursive.c:3832 builtin/merge.c:694 builtin/merge.c:874
+msgid "Unable to write index."
+msgstr "不能写入索引。"
+
+#: midx.c:68
 #, c-format
-msgid "unable to parse remote unpack status: %s"
-msgstr "不能解析远程解包状态：%s"
+msgid "multi-pack-index file %s is too small"
+msgstr "多包索引文件 %s 太小"
 
-#: send-pack.c:145
+#: midx.c:84
 #, c-format
-msgid "remote unpack failed: %s"
-msgstr "远程解包失败：%s"
+msgid "multi-pack-index signature 0x%08x does not match signature 0x%08x"
+msgstr "多包索引签名 0x%08x 和签名 0x%08x 不匹配"
 
-#: send-pack.c:308
-msgid "failed to sign the push certificate"
-msgstr "无法为推送证书签名"
+#: midx.c:89
+#, c-format
+msgid "multi-pack-index version %d not recognized"
+msgstr "multi-pack-index 版本 %d 不能被识别"
 
-#: send-pack.c:421
-msgid "the receiving end does not support --signed push"
-msgstr "接收端不支持签名推送"
+#: midx.c:94
+#, c-format
+msgid "hash version %u does not match"
+msgstr "散列版本 %u 不匹配"
 
-#: send-pack.c:423
-msgid ""
-"not sending a push certificate since the receiving end does not support --"
-"signed push"
-msgstr "未发送推送证书，因为接收端不支持签名推送"
+#: midx.c:108
+msgid "invalid chunk offset (too large)"
+msgstr "无效的块偏移（太大）"
 
-#: send-pack.c:435
-msgid "the receiving end does not support --atomic push"
-msgstr "接收端不支持原子推送"
+#: midx.c:132
+msgid "terminating multi-pack-index chunk id appears earlier than expected"
+msgstr "终止多包索引块 id 出现时间早于预期"
 
-#: send-pack.c:440
-msgid "the receiving end does not support push options"
-msgstr "接收端不支持推送选项"
+#: midx.c:145
+msgid "multi-pack-index missing required pack-name chunk"
+msgstr "多包索引缺少必需的包名块"
+
+#: midx.c:147
+msgid "multi-pack-index missing required OID fanout chunk"
+msgstr "多包索引缺少必需的对象 ID 扇出块"
+
+#: midx.c:149
+msgid "multi-pack-index missing required OID lookup chunk"
+msgstr "多包索引缺少必需的对象 ID 查询块"
+
+#: midx.c:151
+msgid "multi-pack-index missing required object offsets chunk"
+msgstr "多包索引缺少必需的对象偏移块"
 
-#: sequencer.c:175
+#: midx.c:165
 #, c-format
-msgid "invalid commit message cleanup mode '%s'"
-msgstr "无效的提交信息清理模式 '%s'"
+msgid "multi-pack-index pack names out of order: '%s' before '%s'"
+msgstr "多包索引包名无序：'%s' 在 '%s' 之前"
 
-#: sequencer.c:275
+#: midx.c:210
 #, c-format
-msgid "could not delete '%s'"
-msgstr "无法删除 '%s'"
+msgid "bad pack-int-id: %u (%u total packs)"
+msgstr "错的 pack-int-id：%u（共有 %u 个包）"
 
-#: sequencer.c:301
-msgid "revert"
-msgstr "还原"
+#: midx.c:260
+msgid "multi-pack-index stores a 64-bit offset, but off_t is too small"
+msgstr "多包索引存储一个64位偏移，但是 off_t 太小"
 
-#: sequencer.c:303
-msgid "cherry-pick"
-msgstr "拣选"
+#: midx.c:288
+msgid "error preparing packfile from multi-pack-index"
+msgstr "从多包索引准备 packfile 出错"
 
-#: sequencer.c:305
-msgid "rebase -i"
-msgstr "rebase -i"
+#: midx.c:472
+#, c-format
+msgid "failed to add packfile '%s'"
+msgstr "添加包文件 '%s' 失败"
 
-#: sequencer.c:307
+#: midx.c:478
 #, c-format
-msgid "Unknown action: %d"
-msgstr "未知动作：%d"
+msgid "failed to open pack-index '%s'"
+msgstr "打开包索引 '%s' 失败"
 
-#: sequencer.c:364
-msgid ""
-"after resolving the conflicts, mark the corrected paths\n"
-"with 'git add <paths>' or 'git rm <paths>'"
-msgstr ""
-"冲突解决完毕后，用 'git add <路径>' 或 'git rm <路径>'\n"
-"命令标记修正后的文件"
+#: midx.c:538
+#, c-format
+msgid "failed to locate object %d in packfile"
+msgstr "在包文件中定位对象 %d 失败"
 
-#: sequencer.c:367
-msgid ""
-"after resolving the conflicts, mark the corrected paths\n"
-"with 'git add <paths>' or 'git rm <paths>'\n"
-"and commit the result with 'git commit'"
-msgstr ""
-"冲突解决完毕后，用 'git add <路径>' 或 'git rm <路径>'\n"
-"对修正后的文件做标记，然后用 'git commit' 提交"
+#: midx.c:842
+msgid "Adding packfiles to multi-pack-index"
+msgstr "添加包文件到多包索引"
 
-#: sequencer.c:380 sequencer.c:2468
+#: midx.c:875
 #, c-format
-msgid "could not lock '%s'"
-msgstr "不能锁定 '%s'"
+msgid "did not see pack-file %s to drop"
+msgstr "没有看到要丢弃的包文件 %s"
 
-#: sequencer.c:382 sequencer.c:2346 sequencer.c:2472 sequencer.c:2486
-#: sequencer.c:2694 sequencer.c:4336 sequencer.c:4399 wrapper.c:656
-#, c-format
-msgid "could not write to '%s'"
-msgstr "不能写入 '%s'"
+#: midx.c:973
+msgid "Writing chunks to multi-pack-index"
+msgstr "写入块到多包索引"
 
-#: sequencer.c:387
+#: midx.c:1052
 #, c-format
-msgid "could not write eol to '%s'"
-msgstr "不能将换行符写入 '%s'"
+msgid "failed to clear multi-pack-index at %s"
+msgstr "清理位于 %s 的多包索引失败"
 
-#: sequencer.c:392 sequencer.c:2351 sequencer.c:2474 sequencer.c:2488
-#: sequencer.c:2702
+#: midx.c:1108
+msgid "Looking for referenced packfiles"
+msgstr "正在查找引用的包文件"
+
+#: midx.c:1123
 #, c-format
-msgid "failed to finalize '%s'"
-msgstr "无法完成 '%s'"
+msgid ""
+"oid fanout out of order: fanout[%d] = %<PRIx32> > %<PRIx32> = fanout[%d]"
+msgstr "对象 ID 扇出无序：fanout[%d] = %<PRIx32> > %<PRIx32> = fanout[%d]"
 
-#: sequencer.c:415 sequencer.c:804 sequencer.c:1493 sequencer.c:2371
-#: sequencer.c:2684 sequencer.c:2788 builtin/am.c:259 builtin/commit.c:727
-#: builtin/merge.c:1046
+#: midx.c:1128
+msgid "Verifying OID order in multi-pack-index"
+msgstr "校验多包索引中的 OID 顺序"
+
+#: midx.c:1137
 #, c-format
-msgid "could not read '%s'"
-msgstr "不能读取 '%s'"
+msgid "oid lookup out of order: oid[%d] = %s >= %s = oid[%d]"
+msgstr "对象 ID 查询无序：oid[%d] = %s >= %s = oid[%d]"
+
+#: midx.c:1157
+msgid "Sorting objects by packfile"
+msgstr "通过包文件为对象排序"
 
-#: sequencer.c:441
+#: midx.c:1164
+msgid "Verifying object offsets"
+msgstr "校验对象偏移"
+
+#: midx.c:1180
 #, c-format
-msgid "your local changes would be overwritten by %s."
-msgstr "您的本地修改将被%s覆盖。"
+msgid "failed to load pack entry for oid[%d] = %s"
+msgstr "为 oid[%d] = %s 加载包条目失败"
 
-#: sequencer.c:445
-msgid "commit your changes or stash them to proceed."
-msgstr "提交您的修改或贮藏后再继续。"
+#: midx.c:1186
+#, c-format
+msgid "failed to load pack-index for packfile %s"
+msgstr "为包文件 %s 加载包索引失败"
 
-#: sequencer.c:474
+#: midx.c:1195
 #, c-format
-msgid "%s: fast-forward"
-msgstr "%s：快进"
+msgid "incorrect object offset for oid[%d] = %s: %<PRIx64> != %<PRIx64>"
+msgstr "oid[%d] = %s 错误的对象偏移：%<PRIx64> != %<PRIx64>"
 
-#. TRANSLATORS: %s will be "revert", "cherry-pick" or
-#. "rebase -i".
-#.
-#: sequencer.c:563
+#: midx.c:1220
+msgid "Counting referenced objects"
+msgstr "正在对引用对象计数"
+
+#: midx.c:1230
+msgid "Finding and deleting unreferenced packfiles"
+msgstr "正在查找和删除未引用的包文件"
+
+#: midx.c:1388
+msgid "could not start pack-objects"
+msgstr "不能开始 pack-objects"
+
+#: midx.c:1407
+msgid "could not finish pack-objects"
+msgstr "不能结束 pack-objects"
+
+#: name-hash.c:537
 #, c-format
-msgid "%s: Unable to write new index file"
-msgstr "%s：无法写入新索引文件"
+msgid "unable to create lazy_dir thread: %s"
+msgstr "不能创建 lazy_dir 线程：%s"
 
-#: sequencer.c:579
-msgid "unable to update cache tree"
-msgstr "不能更新缓存树"
+#: name-hash.c:559
+#, c-format
+msgid "unable to create lazy_name thread: %s"
+msgstr "不能创建 lazy_name 线程：%s"
 
-#: sequencer.c:592
-msgid "could not resolve HEAD commit"
-msgstr "不能解析 HEAD 提交"
+#: name-hash.c:565
+#, c-format
+msgid "unable to join lazy_name thread: %s"
+msgstr "不能加入 lasy_name 线程：%s"
 
-#: sequencer.c:749
+#: notes-merge.c:277
 #, c-format
 msgid ""
-"you have staged changes in your working tree\n"
-"If these changes are meant to be squashed into the previous commit, run:\n"
-"\n"
-"  git commit --amend %s\n"
-"\n"
-"If they are meant to go into a new commit, run:\n"
-"\n"
-"  git commit %s\n"
-"\n"
-"In both cases, once you're done, continue with:\n"
-"\n"
-"  git rebase --continue\n"
+"You have not concluded your previous notes merge (%s exists).\n"
+"Please, use 'git notes merge --commit' or 'git notes merge --abort' to "
+"commit/abort the previous merge before you start a new notes merge."
 msgstr ""
-"您的工作区中存在已暂存的修改\n"
-"如果这些修改需要被并入前一个提交，执行：\n"
-"\n"
-"  git commit --amend %s\n"
-"\n"
-"如果这些修改要形成一个新提交，执行：\n"
-"\n"
-"  git commit %s\n"
-"\n"
-"无论哪种情况，当您完成提交，继续执行：\n"
-"\n"
-"  git rebase --continue\n"
-
-#: sequencer.c:818
-msgid "writing root commit"
-msgstr "写根提交"
-
-#: sequencer.c:1043
-msgid "'prepare-commit-msg' hook failed"
-msgstr "'prepare-commit-msg' 钩子失败"
+"您的前一次注释合并尚未结束（存在 %s）。\n"
+"在开始一个新的注释合并之前，请使用 'git notes merge --commit' 或者 'git "
+"notes merge --abort' 来提交/终止前一次合并。"
 
-#: sequencer.c:1050
-msgid ""
-"Your name and email address were configured automatically based\n"
-"on your username and hostname. Please check that they are accurate.\n"
-"You can suppress this message by setting them explicitly. Run the\n"
-"following command and follow the instructions in your editor to edit\n"
-"your configuration file:\n"
-"\n"
-"    git config --global --edit\n"
-"\n"
-"After doing this, you may fix the identity used for this commit with:\n"
-"\n"
-"    git commit --amend --reset-author\n"
-msgstr ""
-"您的姓名和邮件地址基于登录名和主机名进行了自动设置。请检查它们正确\n"
-"与否。您可以对其进行设置以免再出现本提示信息。运行如下命令在编辑器\n"
-"中编辑您的配置文件：\n"
-"\n"
-"    git config --global --edit\n"
-"\n"
-"设置完毕后，您可以用下面的命令来修正本次提交所使用的用户身份：\n"
-"\n"
-"    git commit --amend --reset-author\n"
+#: notes-merge.c:284
+#, c-format
+msgid "You have not concluded your notes merge (%s exists)."
+msgstr "您尚未结束注释合并（存在 %s）。"
 
-#: sequencer.c:1063
-msgid ""
-"Your name and email address were configured automatically based\n"
-"on your username and hostname. Please check that they are accurate.\n"
-"You can suppress this message by setting them explicitly:\n"
-"\n"
-"    git config --global user.name \"Your Name\"\n"
-"    git config --global user.email you@example.com\n"
-"\n"
-"After doing this, you may fix the identity used for this commit with:\n"
-"\n"
-"    git commit --amend --reset-author\n"
-msgstr ""
-"您的姓名和邮件地址基于登录名和主机名进行了自动设置。请检查它们正确\n"
-"与否。您可以对其进行设置以免再出现本提示信息：\n"
-"\n"
-"    git config --global user.name \"Your Name\"\n"
-"    git config --global user.email you@example.com\n"
-"\n"
-"设置完毕后，您可以用下面的命令来修正本次提交所使用的用户身份：\n"
-"\n"
-"    git commit --amend --reset-author\n"
+#: notes-utils.c:46
+msgid "Cannot commit uninitialized/unreferenced notes tree"
+msgstr "不能提交未初始化/未引用的注解树"
 
-#: sequencer.c:1103
-msgid "couldn't look up newly created commit"
-msgstr "无法找到新创建的提交"
+#: notes-utils.c:105
+#, c-format
+msgid "Bad notes.rewriteMode value: '%s'"
+msgstr "坏的 notes.rewriteMode 值：'%s'"
 
-#: sequencer.c:1105
-msgid "could not parse newly created commit"
-msgstr "不能解析新创建的提交"
+#: notes-utils.c:115
+#, c-format
+msgid "Refusing to rewrite notes in %s (outside of refs/notes/)"
+msgstr "拒绝向 %s（在 refs/notes/ 之外）写入注解"
 
-#: sequencer.c:1151
-msgid "unable to resolve HEAD after creating commit"
-msgstr "创建提交后，不能解析 HEAD"
+#. TRANSLATORS: The first %s is the name of
+#. the environment variable, the second %s is
+#. its value.
+#.
+#: notes-utils.c:145
+#, c-format
+msgid "Bad %s value: '%s'"
+msgstr "坏的 %s 值：'%s'"
 
-#: sequencer.c:1153
-msgid "detached HEAD"
-msgstr "分离头指针"
+#: object.c:53
+#, c-format
+msgid "invalid object type \"%s\""
+msgstr "无效的对象类型 \"%s\""
 
-#  译者：中文字符串拼接，可删除前导空格
-#: sequencer.c:1157
-msgid " (root-commit)"
-msgstr "（根提交）"
+#: object.c:173
+#, c-format
+msgid "object %s is a %s, not a %s"
+msgstr "对象 %s 是一个 %s，不是一个 %s"
 
-#: sequencer.c:1178
-msgid "could not parse HEAD"
-msgstr "不能解析 HEAD"
+#: object.c:233
+#, c-format
+msgid "object %s has unknown type id %d"
+msgstr "对象 %s 有未知的类型 id %d"
 
-#: sequencer.c:1180
+#: object.c:246
 #, c-format
-msgid "HEAD %s is not a commit!"
-msgstr "HEAD %s 不是一个提交！"
+msgid "unable to parse object: %s"
+msgstr "不能解析对象：%s"
 
-#: sequencer.c:1184 builtin/commit.c:1528
-msgid "could not parse HEAD commit"
-msgstr "不能解析 HEAD 提交"
+#: object.c:266 object.c:277
+#, c-format
+msgid "hash mismatch %s"
+msgstr "哈希值与 %s 不匹配"
 
-#: sequencer.c:1235 sequencer.c:1832
-msgid "unable to parse commit author"
-msgstr "不能解析提交作者"
+#: packfile.c:641
+msgid "offset before end of packfile (broken .idx?)"
+msgstr "偏移量在包文件结束之前（损坏的 .idx？）"
 
-#: sequencer.c:1245 builtin/am.c:1630 builtin/merge.c:645
-msgid "git write-tree failed to write a tree"
-msgstr "git write-tree 无法写入树对象"
+#: packfile.c:1888
+#, c-format
+msgid "offset before start of pack index for %s (corrupt index?)"
+msgstr "偏移量在 %s 的包索引开始之前（损坏的索引？）"
 
-#: sequencer.c:1262 sequencer.c:1317
+#: packfile.c:1892
 #, c-format
-msgid "unable to read commit message from '%s'"
-msgstr "不能从 '%s' 读取提交说明"
+msgid "offset beyond end of pack index for %s (truncated index?)"
+msgstr "偏移量越过了 %s 的包索引的结尾（被截断的索引？）"
 
-#: sequencer.c:1284 builtin/am.c:1650 builtin/commit.c:1631 builtin/merge.c:825
-#: builtin/merge.c:850
-msgid "failed to write commit object"
-msgstr "无法写提交对象"
+#: parse-options.c:38
+#, c-format
+msgid "%s requires a value"
+msgstr "%s 需要一个值"
 
-#: sequencer.c:1344
+#: parse-options.c:73
 #, c-format
-msgid "could not parse commit %s"
-msgstr "不能解析提交 %s"
+msgid "%s is incompatible with %s"
+msgstr "%s 与 %s 不兼容"
 
-#: sequencer.c:1349
+#: parse-options.c:78
 #, c-format
-msgid "could not parse parent commit %s"
-msgstr "不能解析父提交 %s"
+msgid "%s : incompatible with something else"
+msgstr "%s：和其它的不兼容"
 
-#: sequencer.c:1500 sequencer.c:1525
+#: parse-options.c:92 parse-options.c:96 parse-options.c:319
 #, c-format
-msgid "This is a combination of %d commits."
-msgstr "这是一个 %d 个提交的组合。"
+msgid "%s takes no value"
+msgstr "%s 不取值"
 
-#: sequencer.c:1510 sequencer.c:4355
-msgid "need a HEAD to fixup"
-msgstr "需要一个 HEAD 来修复"
+#: parse-options.c:94
+#, c-format
+msgid "%s isn't available"
+msgstr "%s 不可用"
 
-#: sequencer.c:1512 sequencer.c:2729
-msgid "could not read HEAD"
-msgstr "不能读取 HEAD"
+#: parse-options.c:219
+#, c-format
+msgid "%s expects a non-negative integer value with an optional k/m/g suffix"
+msgstr "%s 期望一个非负整数和一个可选的 k/m/g 后缀"
 
-#: sequencer.c:1514
-msgid "could not read HEAD's commit message"
-msgstr "不能读取 HEAD 的提交说明"
+#: parse-options.c:389
+#, c-format
+msgid "ambiguous option: %s (could be --%s%s or --%s%s)"
+msgstr "有歧义的选项：%s（可以是 --%s%s 或 --%s%s）"
 
-#: sequencer.c:1520
+#: parse-options.c:423 parse-options.c:431
 #, c-format
-msgid "cannot write '%s'"
-msgstr "不能写 '%s'"
+msgid "did you mean `--%s` (with two dashes ?)"
+msgstr "你的意思是 `--%s`（有两个短线？）"
 
-#: sequencer.c:1527 git-rebase--interactive.sh:457
-msgid "This is the 1st commit message:"
-msgstr "这是第一个提交说明："
+#: parse-options.c:860
+#, c-format
+msgid "unknown option `%s'"
+msgstr "未知选项 `%s'"
 
-#: sequencer.c:1535
+#: parse-options.c:862
 #, c-format
-msgid "could not read commit message of %s"
-msgstr "不能读取 %s 的提交说明"
+msgid "unknown switch `%c'"
+msgstr "未知开关 `%c'"
 
-#: sequencer.c:1542
+#: parse-options.c:864
 #, c-format
-msgid "This is the commit message #%d:"
-msgstr "这是提交说明 #%d："
+msgid "unknown non-ascii option in string: `%s'"
+msgstr "字符串中未知的非 ascii 字符选项：`%s'"
+
+#: parse-options.c:888
+msgid "..."
+msgstr "..."
 
-#: sequencer.c:1548
+#: parse-options.c:907
 #, c-format
-msgid "The commit message #%d will be skipped:"
-msgstr "提交说明 #%d 将被跳过："
+msgid "usage: %s"
+msgstr "用法：%s"
 
-#: sequencer.c:1553
+#. TRANSLATORS: the colon here should align with the
+#. one in "usage: %s" translation.
+#.
+#: parse-options.c:913
 #, c-format
-msgid "unknown command: %d"
-msgstr "未知命令：%d"
+msgid "   or: %s"
+msgstr "  或：%s"
 
-#: sequencer.c:1631
-msgid "your index file is unmerged."
-msgstr "您的索引文件未完成合并。"
+#  译者：为保证在输出中对齐，注意调整句中空格！
+#: parse-options.c:916
+#, c-format
+msgid "    %s"
+msgstr "    %s"
 
-#: sequencer.c:1638
-msgid "cannot fixup root commit"
-msgstr "不能修复根提交"
+#: parse-options.c:955
+msgid "-NUM"
+msgstr "-数字"
 
-#: sequencer.c:1657
+#: parse-options.c:969
 #, c-format
-msgid "commit %s is a merge but no -m option was given."
-msgstr "提交 %s 是一个合并提交但未提供 -m 选项。"
+msgid "alias of --%s"
+msgstr "--%s 的别名"
 
-#: sequencer.c:1665
+#: parse-options-cb.c:20 parse-options-cb.c:24
 #, c-format
-msgid "commit %s does not have parent %d"
-msgstr "提交 %s 没有第 %d 个父提交"
+msgid "option `%s' expects a numerical value"
+msgstr "选项 `%s' 期望一个数字值"
 
-#: sequencer.c:1669
+#: parse-options-cb.c:41
 #, c-format
-msgid "mainline was specified but commit %s is not a merge."
-msgstr "指定了主线，但是提交 %s 不是一个合并提交。"
+msgid "malformed expiration date '%s'"
+msgstr "格式错误的到期时间：'%s'"
 
-#: sequencer.c:1675
+#: parse-options-cb.c:54
 #, c-format
-msgid "cannot get commit message for %s"
-msgstr "不能得到 %s 的提交说明"
+msgid "option `%s' expects \"always\", \"auto\", or \"never\""
+msgstr "选项 `%s' 期望 \"always\"、\"auto\" 或 \"never\""
 
-#. TRANSLATORS: The first %s will be a "todo" command like
-#. "revert" or "pick", the second %s a SHA1.
-#: sequencer.c:1694
+#: parse-options-cb.c:130 parse-options-cb.c:147
 #, c-format
-msgid "%s: cannot parse parent commit %s"
-msgstr "%s：不能解析父提交 %s"
+msgid "malformed object name '%s'"
+msgstr "格式错误的对象名 '%s'"
 
-#: sequencer.c:1759
+#: path.c:915
 #, c-format
-msgid "could not rename '%s' to '%s'"
-msgstr "不能将 '%s' 重命名为 '%s'"
+msgid "Could not make %s writable by group"
+msgstr "不能设置 %s 为组可写"
 
-#: sequencer.c:1813
-#, c-format
-msgid "could not revert %s... %s"
-msgstr "不能还原 %s... %s"
+#: pathspec.c:130
+msgid "Escape character '\\' not allowed as last character in attr value"
+msgstr "转义字符 '\\' 不能作为属性值的最后一个字符"
+
+#: pathspec.c:148
+msgid "Only one 'attr:' specification is allowed."
+msgstr "只允许一个 'attr:' 规格。"
 
-#: sequencer.c:1814
+#: pathspec.c:151
+msgid "attr spec must not be empty"
+msgstr "属性规格不能为空"
+
+#: pathspec.c:194
 #, c-format
-msgid "could not apply %s... %s"
-msgstr "不能应用 %s... %s"
+msgid "invalid attribute name %s"
+msgstr "无效的属性名 %s"
 
-#: sequencer.c:1864
-msgid "empty commit set passed"
-msgstr "提供了空的提交集"
+#: pathspec.c:259
+msgid "global 'glob' and 'noglob' pathspec settings are incompatible"
+msgstr "全局的 'glob' 和 'noglob' 路径规格设置不兼容"
+
+#: pathspec.c:266
+msgid ""
+"global 'literal' pathspec setting is incompatible with all other global "
+"pathspec settings"
+msgstr "全局的 'literal' 路径规格设置和其它的全局路径规格设置不兼容"
 
-#: sequencer.c:1874
+#: pathspec.c:306
+msgid "invalid parameter for pathspec magic 'prefix'"
+msgstr "路径规格包含无效的神奇前缀"
+
+#: pathspec.c:327
 #, c-format
-msgid "git %s: failed to read the index"
-msgstr "git %s：无法读取索引"
+msgid "Invalid pathspec magic '%.*s' in '%s'"
+msgstr "在路径规格 '%3$s' 中无效的神奇前缀 '%2$.*1$s'"
 
-#: sequencer.c:1881
+#: pathspec.c:332
 #, c-format
-msgid "git %s: failed to refresh the index"
-msgstr "git %s：无法刷新索引"
+msgid "Missing ')' at the end of pathspec magic in '%s'"
+msgstr "路径规格 '%s' 的神奇前缀结尾少了一个 ')'"
 
-#: sequencer.c:1961
+#: pathspec.c:370
 #, c-format
-msgid "%s does not accept arguments: '%s'"
-msgstr "%s 不接受参数：'%s'"
+msgid "Unimplemented pathspec magic '%c' in '%s'"
+msgstr "路径规格 '%2$s' 中包含未实现的神奇前缀 '%1$c'"
 
-#: sequencer.c:1970
+#: pathspec.c:429
 #, c-format
-msgid "missing arguments for %s"
-msgstr "缺少 %s 的参数"
+msgid "%s: 'literal' and 'glob' are incompatible"
+msgstr "%s：'literal' 和 'glob' 不兼容"
 
-#: sequencer.c:2029
+#: pathspec.c:442
 #, c-format
-msgid "invalid line %d: %.*s"
-msgstr "无效行 %d：%.*s"
+msgid "%s: '%s' is outside repository"
+msgstr "%s：'%s' 在仓库之外"
 
-#: sequencer.c:2037
+#: pathspec.c:516
 #, c-format
-msgid "cannot '%s' without a previous commit"
-msgstr "没有父提交的情况下不能 '%s'"
+msgid "'%s' (mnemonic: '%c')"
+msgstr "'%s'（助记符：'%c'）"
 
-#: sequencer.c:2085 sequencer.c:4138 sequencer.c:4173
+#: pathspec.c:526
 #, c-format
-msgid "could not read '%s'."
-msgstr "不能读取 '%s'。"
+msgid "%s: pathspec magic not supported by this command: %s"
+msgstr "%s：路径规格神奇前缀不被此命令支持：%s"
 
-#: sequencer.c:2108
-msgid "please fix this using 'git rebase --edit-todo'."
-msgstr "请用 'git rebase --edit-todo' 来修改。"
+#: pathspec.c:593
+#, c-format
+msgid "pathspec '%s' is beyond a symbolic link"
+msgstr "路径规格 '%s' 位于符号链接中"
 
-#: sequencer.c:2110
+#: pathspec.c:638
 #, c-format
-msgid "unusable instruction sheet: '%s'"
-msgstr "不可用的指令清单：'%s'"
+msgid "line is badly quoted: %s"
+msgstr "行被错误地引用：%s"
 
-#: sequencer.c:2115
-msgid "no commits parsed."
-msgstr "没有解析提交。"
+#: pkt-line.c:92
+msgid "unable to write flush packet"
+msgstr "无法写 flush 包"
 
-#: sequencer.c:2126
-msgid "cannot cherry-pick during a revert."
-msgstr "不能在回退中执行拣选。"
+#: pkt-line.c:99
+msgid "unable to write delim packet"
+msgstr "无法写 delim 包"
 
-#: sequencer.c:2128
-msgid "cannot revert during a cherry-pick."
-msgstr "不能在拣选中执行回退。"
+#: pkt-line.c:106
+msgid "flush packet write failed"
+msgstr "flush 包写错误"
+
+#: pkt-line.c:146 pkt-line.c:232
+msgid "protocol error: impossibly long line"
+msgstr "协议错误：不可能的长行"
+
+#: pkt-line.c:162 pkt-line.c:164
+msgid "packet write with format failed"
+msgstr "格式化包写入错误"
+
+#: pkt-line.c:196
+msgid "packet write failed - data exceeds max packet size"
+msgstr "写数据包失败：数据超过了包的最大长度"
 
-#: sequencer.c:2195
+#: pkt-line.c:203 pkt-line.c:210
+msgid "packet write failed"
+msgstr "数据包写入失败"
+
+#: pkt-line.c:295
+msgid "read error"
+msgstr "读取错误"
+
+#: pkt-line.c:303
+msgid "the remote end hung up unexpectedly"
+msgstr "远端意外挂断了"
+
+#: pkt-line.c:331
 #, c-format
-msgid "invalid key: %s"
-msgstr "无效键名：%s"
+msgid "protocol error: bad line length character: %.4s"
+msgstr "协议错误：错误的行长度字符串：%.4s"
 
-#: sequencer.c:2198
+#: pkt-line.c:341 pkt-line.c:346
 #, c-format
-msgid "invalid value for %s: %s"
-msgstr "%s 的值无效：%s"
+msgid "protocol error: bad line length %d"
+msgstr "协议错误：错误的行长度 %d"
 
-#: sequencer.c:2269
-msgid "unusable squash-onto"
-msgstr "不可用的 squash-onto"
+#: pkt-line.c:362
+#, c-format
+msgid "remote error: %s"
+msgstr "远程错误：%s"
+
+#: preload-index.c:119
+msgid "Refreshing index"
+msgstr "正在刷新索引"
 
-#: sequencer.c:2285
+#: preload-index.c:138
 #, c-format
-msgid "malformed options sheet: '%s'"
-msgstr "格式错误的选项清单：'%s'"
+msgid "unable to create threaded lstat: %s"
+msgstr "无法创建线程 lstat：%s"
 
-#: sequencer.c:2323
-msgid "a cherry-pick or revert is already in progress"
-msgstr "一个拣选或还原操作已在进行"
-
-#: sequencer.c:2324
-msgid "try \"git cherry-pick (--continue | --quit | --abort)\""
-msgstr "尝试 \"git cherry-pick (--continue | --quit | --abort)\""
+#: pretty.c:981
+msgid "unable to parse --pretty format"
+msgstr "不能解析 --pretty 格式"
+
+#: promisor-remote.c:23
+msgid "Remote with no URL"
+msgstr "远程未设置 URL"
 
-#: sequencer.c:2327
+#: promisor-remote.c:58
 #, c-format
-msgid "could not create sequencer directory '%s'"
-msgstr "不能创建序列目录 '%s'"
+msgid "promisor remote name cannot begin with '/': %s"
+msgstr "promisor 远程名称不能以 '/' 开始：%s"
 
-#: sequencer.c:2341
-msgid "could not lock HEAD"
-msgstr "不能锁定 HEAD"
+#: range-diff.c:75
+msgid "could not start `log`"
+msgstr "不能启动 `log`"
 
-#: sequencer.c:2396 sequencer.c:3403
-msgid "no cherry-pick or revert in progress"
-msgstr "拣选或还原操作并未进行"
+#: range-diff.c:77
+msgid "could not read `log` output"
+msgstr "不能读取 `log` 的输出"
 
-#: sequencer.c:2398
-msgid "cannot resolve HEAD"
-msgstr "不能解析 HEAD"
+#: range-diff.c:96 sequencer.c:5163
+#, c-format
+msgid "could not parse commit '%s'"
+msgstr "不能解析提交 '%s'"
 
-#: sequencer.c:2400 sequencer.c:2435
-msgid "cannot abort from a branch yet to be born"
-msgstr "不能从尚未建立的分支终止"
+#: range-diff.c:122
+#, c-format
+msgid "could not parse git header '%.*s'"
+msgstr "无法解析 git 头 '%.*s'"
+
+#: range-diff.c:285
+msgid "failed to generate diff"
+msgstr "生成 diff 失败"
 
-#: sequencer.c:2421 builtin/grep.c:720
+#: range-diff.c:518 range-diff.c:520
 #, c-format
-msgid "cannot open '%s'"
-msgstr "不能打开 '%s'"
+msgid "could not parse log for '%s'"
+msgstr "不能解析 '%s' 的日志"
 
-#: sequencer.c:2423
+#: read-cache.c:680
 #, c-format
-msgid "cannot read '%s': %s"
-msgstr "不能读取 '%s'：%s"
+msgid "will not add file alias '%s' ('%s' already exists in index)"
+msgstr "将不会添加文件别名 '%s'（'%s' 已经存在于索引中）"
 
-#: sequencer.c:2424
-msgid "unexpected end of file"
-msgstr "意外的文件结束"
+#: read-cache.c:696
+msgid "cannot create an empty blob in the object database"
+msgstr "不能在对象数据库中创建空的数据对象"
 
-#: sequencer.c:2430
+#: read-cache.c:718
 #, c-format
-msgid "stored pre-cherry-pick HEAD file '%s' is corrupt"
-msgstr "保存拣选提交前的 HEAD 文件 '%s' 损坏"
+msgid "%s: can only add regular files, symbolic links or git-directories"
+msgstr "%s：只能添加常规文件、符号链接或 git 目录"
 
-#: sequencer.c:2441
-msgid "You seem to have moved HEAD. Not rewinding, check your HEAD!"
-msgstr "您好像移动了 HEAD。未能回退，检查您的 HEAD！"
+#: read-cache.c:723
+#, c-format
+msgid "'%s' does not have a commit checked out"
+msgstr "'%s' 没有检出一个提交"
 
-#: sequencer.c:2545 sequencer.c:3321
+#: read-cache.c:775
 #, c-format
-msgid "could not update %s"
-msgstr "不能更新 %s"
+msgid "unable to index file '%s'"
+msgstr "无法索引文件 '%s'"
 
-#: sequencer.c:2583 sequencer.c:3301
-msgid "cannot read HEAD"
-msgstr "不能读取 HEAD"
+#: read-cache.c:794
+#, c-format
+msgid "unable to add '%s' to index"
+msgstr "无法在索引中添加 '%s'"
 
-#: sequencer.c:2618 sequencer.c:2622 builtin/difftool.c:639
+#: read-cache.c:805
 #, c-format
-msgid "could not copy '%s' to '%s'"
-msgstr "不能拷贝 '%s' 至 '%s'"
+msgid "unable to stat '%s'"
+msgstr "无法对 %s 执行 stat"
 
-#: sequencer.c:2641
-msgid "could not read index"
-msgstr "不能读取索引"
+#: read-cache.c:1325
+#, c-format
+msgid "'%s' appears as both a file and as a directory"
+msgstr "'%s' 看起来既是文件又是目录"
 
-#  译者：注意保持前导空格
-#: sequencer.c:2646
+#: read-cache.c:1531
+msgid "Refresh index"
+msgstr "刷新索引"
+
+#: read-cache.c:1646
 #, c-format
 msgid ""
-"execution failed: %s\n"
-"%sYou can fix the problem, and then run\n"
-"\n"
-"  git rebase --continue\n"
-"\n"
+"index.version set, but the value is invalid.\n"
+"Using version %i"
 msgstr ""
-"执行失败：%s\n"
-"%s您可以改正该问题，然后运行\n"
-"\n"
-"  git rebase --continue\n"
-"\n"
-
-#: sequencer.c:2652
-msgid "and made changes to the index and/or the working tree\n"
-msgstr "并且修改索引和/或工作区\n"
+"设置了 index.version，但是取值无效。\n"
+"使用版本 %i"
 
-#: sequencer.c:2658
+#: read-cache.c:1656
 #, c-format
 msgid ""
-"execution succeeded: %s\n"
-"but left changes to the index and/or the working tree\n"
-"Commit or stash your changes, and then run\n"
-"\n"
-"  git rebase --continue\n"
-"\n"
+"GIT_INDEX_VERSION set, but the value is invalid.\n"
+"Using version %i"
 msgstr ""
-"执行成功：%s\n"
-"但是在索引和/或工作区中存在变更\n"
-"提交或贮藏修改，然后运行\n"
-"\n"
-"  git rebase --continue\n"
-"\n"
-
-#: sequencer.c:2771
-msgid "writing fake root commit"
-msgstr "写伪根提交"
-
-#: sequencer.c:2776
-msgid "writing squash-onto"
-msgstr "写入 squash-onto"
+"设置了 GIT_INDEX_VERSION，但是取值无效。\n"
+"使用版本 %i"
 
-#: sequencer.c:2811
+#: read-cache.c:1712
 #, c-format
-msgid "failed to find tree of %s"
-msgstr "无法找到 %s 指向的树。"
+msgid "bad signature 0x%08x"
+msgstr "坏的签名 0x%08x"
 
-#: sequencer.c:2829
-msgid "could not write index"
-msgstr "不能写入索引"
+#: read-cache.c:1715
+#, c-format
+msgid "bad index version %d"
+msgstr "坏的索引版本 %d"
 
-#: sequencer.c:2861
-msgid "cannot merge without a current revision"
-msgstr "没有当前版本不能合并"
+#: read-cache.c:1724
+msgid "bad index file sha1 signature"
+msgstr "坏的索引文件 sha1 签名"
 
-#: sequencer.c:2884
+#: read-cache.c:1754
 #, c-format
-msgid "could not resolve '%s'"
-msgstr "无法解析 '%s'"
+msgid "index uses %.4s extension, which we do not understand"
+msgstr "索引使用不被支持的 %.4s 扩展"
 
-#: sequencer.c:2906
+# 	
+#: read-cache.c:1756
 #, c-format
-msgid "could not get commit message of '%s'"
-msgstr "不能获取 '%s' 的提交说明"
+msgid "ignoring %.4s extension"
+msgstr "忽略 %.4s 扩展"
 
-#: sequencer.c:2916 sequencer.c:2941
+#: read-cache.c:1793
 #, c-format
-msgid "could not write '%s'"
-msgstr "不能写入 '%s'"
+msgid "unknown index entry format 0x%08x"
+msgstr "未知的索引条目格式 0x%08x"
 
-#: sequencer.c:3005
+#: read-cache.c:1809
 #, c-format
-msgid "could not even attempt to merge '%.*s'"
-msgstr "甚至不能尝试合并 '%.*s'"
+msgid "malformed name field in the index, near path '%s'"
+msgstr "索引中靠近路径 '%s' 有错误的名称字段"
 
-#: sequencer.c:3021
-msgid "merge: Unable to write new index file"
-msgstr "合并：无法写入新索引文件"
+#: read-cache.c:1866
+msgid "unordered stage entries in index"
+msgstr "索引中有未排序的暂存条目"
 
-#: sequencer.c:3088
+#: read-cache.c:1869
 #, c-format
-msgid "Applied autostash.\n"
-msgstr "已应用 autostash。\n"
+msgid "multiple stage entries for merged file '%s'"
+msgstr "合并文件 '%s' 有多个暂存条目"
 
-#: sequencer.c:3100
+#: read-cache.c:1872
 #, c-format
-msgid "cannot store %s"
-msgstr "不能存储 %s"
+msgid "unordered stage entries for '%s'"
+msgstr "'%s' 的未排序暂存条目"
 
-#: sequencer.c:3103 git-rebase.sh:188
-#, c-format
-msgid ""
-"Applying autostash resulted in conflicts.\n"
-"Your changes are safe in the stash.\n"
-"You can run \"git stash pop\" or \"git stash drop\" at any time.\n"
-msgstr ""
-"应用 autostash 导致冲突。\n"
-"您的修改安全地保存在贮藏区中。\n"
-"您可以在任何时候运行 \"git stash pop\" 或 \"git stash drop\"。\n"
+#: read-cache.c:1978 read-cache.c:2266 rerere.c:565 rerere.c:599 rerere.c:1111
+#: builtin/add.c:499 builtin/check-ignore.c:178 builtin/checkout.c:470
+#: builtin/checkout.c:654 builtin/clean.c:967 builtin/commit.c:367
+#: builtin/diff-tree.c:120 builtin/grep.c:499 builtin/mv.c:145
+#: builtin/reset.c:246 builtin/rm.c:271 builtin/submodule--helper.c:332
+msgid "index file corrupt"
+msgstr "索引文件损坏"
 
-#: sequencer.c:3134
+#: read-cache.c:2119
 #, c-format
-msgid ""
-"Could not execute the todo command\n"
-"\n"
-"    %.*s\n"
-"It has been rescheduled; To edit the command before continuing, please\n"
-"edit the todo list first:\n"
-"\n"
-"    git rebase --edit-todo\n"
-"    git rebase --continue\n"
-msgstr ""
-"无法执行待办命令\n"
-"\n"
-"    %.*s\n"
-"已被重新安排，在继续之前编辑命令，请先编辑待办列表：\n"
-"\n"
-"    git rebase --edit-todo\n"
-"    git rebase --continue\n"
+msgid "unable to create load_cache_entries thread: %s"
+msgstr "无法创建 load_cache_entries 线程：%s"
 
-#: sequencer.c:3202
+#: read-cache.c:2132
 #, c-format
-msgid "Stopped at %s...  %.*s\n"
-msgstr "停止在 %s... %.*s\n"
+msgid "unable to join load_cache_entries thread: %s"
+msgstr "无法加入 load_cache_entries 线程：%s"
 
-#: sequencer.c:3264
+#: read-cache.c:2165
 #, c-format
-msgid "unknown command %d"
-msgstr "未知命令 %d"
-
-#: sequencer.c:3309
-msgid "could not read orig-head"
-msgstr "不能读取 orig-head"
+msgid "%s: index file open failed"
+msgstr "%s：打开索引文件失败"
 
-#: sequencer.c:3314 sequencer.c:4352
-msgid "could not read 'onto'"
-msgstr "不能读取 'onto'"
-
-#: sequencer.c:3328
+#: read-cache.c:2169
 #, c-format
-msgid "could not update HEAD to %s"
-msgstr "不能更新 HEAD 为 %s"
-
-#: sequencer.c:3414
-msgid "cannot rebase: You have unstaged changes."
-msgstr "不能变基：您有未暂存的变更。"
+msgid "%s: cannot stat the open index"
+msgstr "%s：不能对打开的索引执行 stat 操作"
 
-#: sequencer.c:3423
-msgid "cannot amend non-existing commit"
-msgstr "不能修补不存在的提交"
-
-#: sequencer.c:3425
+#: read-cache.c:2173
 #, c-format
-msgid "invalid file: '%s'"
-msgstr "无效文件：'%s'"
+msgid "%s: index file smaller than expected"
+msgstr "%s：索引文件比预期的小"
 
-#: sequencer.c:3427
+#: read-cache.c:2177
 #, c-format
-msgid "invalid contents: '%s'"
-msgstr "无效内容：'%s'"
+msgid "%s: unable to map index file"
+msgstr "%s：无法对索引文件执行 map 操作"
 
-#: sequencer.c:3430
-msgid ""
-"\n"
-"You have uncommitted changes in your working tree. Please, commit them\n"
-"first and then run 'git rebase --continue' again."
-msgstr ""
-"\n"
-"您的工作区中有未提交的变更。请先提交然后再次运行 'git rebase --continue'。"
+#: read-cache.c:2219
+#, c-format
+msgid "unable to create load_index_extensions thread: %s"
+msgstr "无法创建 load_index_extensions 线程：%s"
 
-#: sequencer.c:3455 sequencer.c:3493
+#: read-cache.c:2246
 #, c-format
-msgid "could not write file: '%s'"
-msgstr "不能写入文件：'%s'"
+msgid "unable to join load_index_extensions thread: %s"
+msgstr "无法加入 load_index_extensions 线程：%s"
 
-#: sequencer.c:3508
-msgid "could not remove CHERRY_PICK_HEAD"
-msgstr "不能删除 CHERRY_PICK_HEAD"
+#: read-cache.c:2278
+#, c-format
+msgid "could not freshen shared index '%s'"
+msgstr "无法刷新共享索引 '%s'"
 
-#: sequencer.c:3515
-msgid "could not commit staged changes."
-msgstr "不能提交暂存的修改。"
+#: read-cache.c:2325
+#, c-format
+msgid "broken index, expect %s in %s, got %s"
+msgstr "损坏的索引，期望在 %2$s 中的 %1$s，得到 %3$s"
 
-#: sequencer.c:3612
+#: read-cache.c:3021 strbuf.c:1145 wrapper.c:622 builtin/merge.c:1119
 #, c-format
-msgid "%s: can't cherry-pick a %s"
-msgstr "%s：不能拣选一个%s"
+msgid "could not close '%s'"
+msgstr "不能关闭 '%s'"
 
-#: sequencer.c:3616
+#: read-cache.c:3124 sequencer.c:2429 sequencer.c:4069
 #, c-format
-msgid "%s: bad revision"
-msgstr "%s：错误的版本"
+msgid "could not stat '%s'"
+msgstr "不能对 '%s' 调用 stat"
 
-#: sequencer.c:3649
-msgid "can't revert as initial commit"
-msgstr "不能作为初始提交回退"
+#: read-cache.c:3137
+#, c-format
+msgid "unable to open git dir: %s"
+msgstr "不能打开 git 目录：%s"
 
-#: sequencer.c:4098
-msgid "make_script: unhandled options"
-msgstr "make_script：有未能处理的选项"
+#: read-cache.c:3149
+#, c-format
+msgid "unable to unlink: %s"
+msgstr "无法删除：%s"
 
-#: sequencer.c:4101
-msgid "make_script: error preparing revisions"
-msgstr "make_script：准备版本时错误"
+#: read-cache.c:3174
+#, c-format
+msgid "cannot fix permission bits on '%s'"
+msgstr "不能修复 '%s' 的权限位"
 
-#: sequencer.c:4142 sequencer.c:4177
+#: read-cache.c:3323
 #, c-format
-msgid "unusable todo list: '%s'"
-msgstr "不可用的待办列表：'%s'"
+msgid "%s: cannot drop to stage #0"
+msgstr "%s：不能落到暂存区 #0"
 
-#: sequencer.c:4236
+#: rebase-interactive.c:26
 #, c-format
 msgid ""
 "unrecognized setting %s for option rebase.missingCommitsCheck. Ignoring."
 msgstr "选项 rebase.missingCommitsCheck 的值 %s 无法识别。已忽略。"
 
-#: sequencer.c:4302
-#, c-format
-msgid ""
-"Warning: some commits may have been dropped accidentally.\n"
-"Dropped commits (newer to older):\n"
-msgstr ""
-"警告：一些提交可能被意外丢弃。\n"
-"丢弃的提交（从新到旧）：\n"
-
-#: sequencer.c:4309
-#, c-format
+#: rebase-interactive.c:35
 msgid ""
-"To avoid this message, use \"drop\" to explicitly remove a commit.\n"
 "\n"
-"Use 'git config rebase.missingCommitsCheck' to change the level of "
-"warnings.\n"
-"The possible behaviours are: ignore, warn, error.\n"
+"Commands:\n"
+"p, pick <commit> = use commit\n"
+"r, reword <commit> = use commit, but edit the commit message\n"
+"e, edit <commit> = use commit, but stop for amending\n"
+"s, squash <commit> = use commit, but meld into previous commit\n"
+"f, fixup <commit> = like \"squash\", but discard this commit's log message\n"
+"x, exec <command> = run command (the rest of the line) using shell\n"
+"b, break = stop here (continue rebase later with 'git rebase --continue')\n"
+"d, drop <commit> = remove commit\n"
+"l, label <label> = label current HEAD with a name\n"
+"t, reset <label> = reset HEAD to a label\n"
+"m, merge [-C <commit> | -c <commit>] <label> [# <oneline>]\n"
+".       create a merge commit using the original merge commit's\n"
+".       message (or the oneline, if no original merge commit was\n"
+".       specified). Use -c <commit> to reword the commit message.\n"
 "\n"
+"These lines can be re-ordered; they are executed from top to bottom.\n"
 msgstr ""
-"为避免这条信息，使用 \"drop\" 指令显式地删除一个提交。\n"
 "\n"
-"使用 'git config rebase.missingCommitsCheck' 来修改警告级别。\n"
-"可选值有：ignore、warn、error。\n"
+"命令:\n"
+"p, pick <提交> = 使用提交\n"
+"r, reword <提交> = 使用提交，但修改提交说明\n"
+"e, edit <提交> = 使用提交，进入 shell 以便进行提交修补\n"
+"s, squash <提交> = 使用提交，但融合到前一个提交\n"
+"f, fixup <提交> = 类似于 \"squash\"，但丢弃提交说明日志\n"
+"x, exec <命令> = 使用 shell 运行命令（此行剩余部分）\n"
+"b, break = 在此处停止（使用 'git rebase --continue' 继续变基）\n"
+"d, drop <提交> = 删除提交\n"
+"l, label <label> = 为当前 HEAD 打上标记\n"
+"t, reset <label> = 重置 HEAD 到该标记\n"
+"m, merge [-C <commit> | -c <commit>] <label> [# <oneline>]\n"
+".       创建一个合并提交，并使用原始的合并提交说明（如果没有指定\n"
+".       原始提交，使用注释部分的 oneline 作为提交说明）。使用\n"
+".       -c <提交> 可以编辑提交说明。\n"
 "\n"
+"可以对这些行重新排序，将从上至下执行。\n"
 
-#: sequencer.c:4321
+#: rebase-interactive.c:56
 #, c-format
+msgid "Rebase %s onto %s (%d command)"
+msgid_plural "Rebase %s onto %s (%d commands)"
+msgstr[0] "变基 %s 到 %s（%d 个提交）"
+msgstr[1] "变基 %s 到 %s（%d 个提交）"
+
+#: rebase-interactive.c:65 git-rebase--preserve-merges.sh:228
 msgid ""
-"You can fix this with 'git rebase --edit-todo' and then run 'git rebase --"
-"continue'.\n"
-"Or you can abort the rebase with 'git rebase --abort'.\n"
+"\n"
+"Do not remove any line. Use 'drop' explicitly to remove a commit.\n"
 msgstr ""
-"您可以用 'git rebase --edit-todo' 修正，然后执行 'git rebase --continue'。\n"
-"或者您可以用 'git rebase --abort' 终止变基。\n"
+"\n"
+"不要删除任意一行。使用 'drop' 显式地删除一个提交。\n"
 
-#: sequencer.c:4375
-#, c-format
-msgid "could not parse commit '%s'"
-msgstr "不能解析提交 '%s'"
+#: rebase-interactive.c:68 git-rebase--preserve-merges.sh:232
+msgid ""
+"\n"
+"If you remove a line here THAT COMMIT WILL BE LOST.\n"
+msgstr ""
+"\n"
+"如果您在这里删除一行，对应的提交将会丢失。\n"
 
-#: sequencer.c:4490
-msgid "the script was already rearranged."
-msgstr "脚本已经重新编排。"
+#: rebase-interactive.c:74 git-rebase--preserve-merges.sh:871
+msgid ""
+"\n"
+"You are editing the todo file of an ongoing interactive rebase.\n"
+"To continue rebase after editing, run:\n"
+"    git rebase --continue\n"
+"\n"
+msgstr ""
+"\n"
+"您正在修改进行中的交互式变基待办列表。若要在编辑结束后继续变基，\n"
+"请执行：\n"
+"    git rebase --continue\n"
+"\n"
+
+#: rebase-interactive.c:79 git-rebase--preserve-merges.sh:948
+msgid ""
+"\n"
+"However, if you remove everything, the rebase will be aborted.\n"
+"\n"
+msgstr ""
+"\n"
+"然而，如果您删除全部内容，变基操作将会终止。\n"
+"\n"
+
+#: rebase-interactive.c:85 git-rebase--preserve-merges.sh:955
+msgid "Note that empty commits are commented out"
+msgstr "注意空提交已被注释掉"
 
-#: setup.c:123
+#: rebase-interactive.c:105 rerere.c:485 rerere.c:692 sequencer.c:3536
+#: sequencer.c:3562 sequencer.c:5263 builtin/fsck.c:346 builtin/rebase.c:254
 #, c-format
-msgid "'%s' is outside repository"
-msgstr "'%s' 在仓库之外"
+msgid "could not write '%s'"
+msgstr "不能写入 '%s'"
 
-#: setup.c:172
+#: rebase-interactive.c:108
 #, c-format
-msgid ""
-"%s: no such path in the working tree.\n"
-"Use 'git <command> -- <path>...' to specify paths that do not exist locally."
-msgstr ""
-"%s：工作区中无此路径。\n"
-"使用命令 'git <命令> -- <路径>...' 来指定本地不存在的路径。"
+msgid "could not copy '%s' to '%s'."
+msgstr "不能拷贝 '%s' 至 '%s'。"
 
-#: setup.c:185
+#: rebase-interactive.c:173
 #, c-format
 msgid ""
-"ambiguous argument '%s': unknown revision or path not in the working tree.\n"
-"Use '--' to separate paths from revisions, like this:\n"
-"'git <command> [<revision>...] -- [<file>...]'"
+"Warning: some commits may have been dropped accidentally.\n"
+"Dropped commits (newer to older):\n"
 msgstr ""
-"有歧义的参数 '%s'：未知的版本或路径不存在于工作区中。\n"
-"使用 '--' 来分隔版本和路径，例如：\n"
-"'git <命令> [<版本>...] -- [<文件>...]'"
-
-#: setup.c:234
-#, c-format
-msgid "option '%s' must come before non-option arguments"
-msgstr "选项 '%s' 必须在其他非选项参数之前"
+"警告：一些提交可能被意外丢弃。\n"
+"丢弃的提交（从新到旧）：\n"
 
-#: setup.c:253
+#: rebase-interactive.c:180
 #, c-format
 msgid ""
-"ambiguous argument '%s': both revision and filename\n"
-"Use '--' to separate paths from revisions, like this:\n"
-"'git <command> [<revision>...] -- [<file>...]'"
+"To avoid this message, use \"drop\" to explicitly remove a commit.\n"
+"\n"
+"Use 'git config rebase.missingCommitsCheck' to change the level of "
+"warnings.\n"
+"The possible behaviours are: ignore, warn, error.\n"
+"\n"
 msgstr ""
-"有歧义的参数 '%s'：可同时是版本和文件\n"
-"使用 '--' 来分隔版本和路径，例如：\n"
-"'git <命令> [<版本>...] -- [<文件>...]'"
+"为避免这条信息，使用 \"drop\" 指令显式地删除一个提交。\n"
+"\n"
+"使用 'git config rebase.missingCommitsCheck' 来修改警告级别。\n"
+"可选值有：ignore、warn、error。\n"
+"\n"
 
-#: setup.c:389
-msgid "unable to set up work tree using invalid config"
-msgstr "无法使用无效配置来创建工作区"
+#: refs.c:262
+#, c-format
+msgid "%s does not point to a valid object!"
+msgstr "%s 没有指向一个有效的对象！"
 
-#: setup.c:393
-msgid "this operation must be run in a work tree"
-msgstr "该操作必须在一个工作区中运行"
+#: refs.c:667
+#, c-format
+msgid "ignoring dangling symref %s"
+msgstr "忽略悬空符号引用 %s"
 
-#: setup.c:503
+#: refs.c:669 ref-filter.c:2098
 #, c-format
-msgid "Expected git repo version <= %d, found %d"
-msgstr "期望 git 仓库版本 <= %d，却得到 %d"
+msgid "ignoring broken ref %s"
+msgstr "忽略损坏的引用 %s"
 
-#: setup.c:511
-msgid "unknown repository extensions found:"
-msgstr "发现未知的仓库扩展："
+#: refs.c:804
+#, c-format
+msgid "could not open '%s' for writing: %s"
+msgstr "无法为写入打开 '%s'：%s"
 
-#: setup.c:530
+#: refs.c:814 refs.c:865
 #, c-format
-msgid "error opening '%s'"
-msgstr "无法打开 '%s'"
+msgid "could not read ref '%s'"
+msgstr "无法读取引用 '%s'"
 
-#: setup.c:532
+#: refs.c:820
 #, c-format
-msgid "too large to be a .git file: '%s'"
-msgstr "文件太大，无法作为 .git 文件：'%s'"
+msgid "ref '%s' already exists"
+msgstr "引用 '%s' 已经存在"
 
-#: setup.c:534
+#: refs.c:825
 #, c-format
-msgid "error reading %s"
-msgstr "无法读取 %s"
+msgid "unexpected object ID when writing '%s'"
+msgstr "写入 '%s' 时意外的对象 ID"
 
-#: setup.c:536
+#: refs.c:833 sequencer.c:405 sequencer.c:2793 sequencer.c:2997
+#: sequencer.c:3011 sequencer.c:3269 sequencer.c:5179 strbuf.c:1142
+#: wrapper.c:620
 #, c-format
-msgid "invalid gitfile format: %s"
-msgstr "无效的 gitfile 格式：%s"
+msgid "could not write to '%s'"
+msgstr "不能写入 '%s'"
 
-#: setup.c:538
+#: refs.c:860 strbuf.c:1140 wrapper.c:188 wrapper.c:358 builtin/am.c:714
+#: builtin/rebase.c:1031
 #, c-format
-msgid "no path in gitfile: %s"
-msgstr "在 gitfile 中没有路径：%s"
+msgid "could not open '%s' for writing"
+msgstr "无法打开 '%s' 进行写入"
 
-#: setup.c:540
+#: refs.c:867
 #, c-format
-msgid "not a git repository: %s"
-msgstr "不是一个 git 仓库：%s"
+msgid "unexpected object ID when deleting '%s'"
+msgstr "删除 '%s' 时意外的对象 ID"
 
-#: setup.c:639
+#: refs.c:998
 #, c-format
-msgid "'$%s' too big"
-msgstr "'$%s' 太大"
+msgid "log for ref %s has gap after %s"
+msgstr "引用 %s 的日志在 %s 之后有缺口"
 
-#: setup.c:653
+#: refs.c:1004
 #, c-format
-msgid "not a git repository: '%s'"
-msgstr "不是一个 git 仓库：'%s'"
+msgid "log for ref %s unexpectedly ended on %s"
+msgstr "引用 %s 的日志意外终止于 %s "
 
-#: setup.c:682 setup.c:684 setup.c:715
+#: refs.c:1063
 #, c-format
-msgid "cannot chdir to '%s'"
-msgstr "不能切换目录到 '%s'"
+msgid "log for %s is empty"
+msgstr "%s 的日志为空"
 
-#: setup.c:687 setup.c:743 setup.c:753 setup.c:792 setup.c:800 setup.c:815
-msgid "cannot come back to cwd"
-msgstr "无法返回当前工作目录"
+#: refs.c:1155
+#, c-format
+msgid "refusing to update ref with bad name '%s'"
+msgstr "拒绝更新有错误名称 '%s' 的引用"
 
-#: setup.c:813
+#: refs.c:1231
 #, c-format
-msgid "not a git repository (or any of the parent directories): %s"
-msgstr "不是一个 git 仓库（或者任何父目录）：%s"
+msgid "update_ref failed for ref '%s': %s"
+msgstr "对引用 '%s' 执行 update_ref 失败：%s"
 
-#: setup.c:824
+#: refs.c:2023
 #, c-format
-msgid "failed to stat '%*s%s%s'"
-msgstr "无法获取 '%*s%s%s' 状态（stat）"
+msgid "multiple updates for ref '%s' not allowed"
+msgstr "不允许对引用 '%s' 多次更新"
 
-#: setup.c:1054
-msgid "Unable to read current working directory"
-msgstr "不能读取当前工作目录"
+#: refs.c:2055
+msgid "ref updates forbidden inside quarantine environment"
+msgstr "在隔离环境中禁止更新引用"
 
-#: setup.c:1066 setup.c:1072
+#: refs.c:2151 refs.c:2181
 #, c-format
-msgid "cannot change to '%s'"
-msgstr "不能切换到 '%s'"
+msgid "'%s' exists; cannot create '%s'"
+msgstr "'%s' 已存在，无法创建 '%s'"
 
-#: setup.c:1085
+#: refs.c:2157 refs.c:2192
 #, c-format
-msgid ""
-"not a git repository (or any parent up to mount point %s)\n"
-"Stopping at filesystem boundary (GIT_DISCOVERY_ACROSS_FILESYSTEM not set)."
-msgstr ""
-"不是一个 git 仓库（或者直至挂载点 %s 的任何父目录）\n"
-"停止在文件系统边界（未设置 GIT_DISCOVERY_ACROSS_FILESYSTEM）。"
+msgid "cannot process '%s' and '%s' at the same time"
+msgstr "无法同时处理 '%s' 和 '%s'"
 
-#: setup.c:1168
+#: refs/files-backend.c:1234
 #, c-format
-msgid ""
-"problem with core.sharedRepository filemode value (0%.3o).\n"
-"The owner of files must always have read and write permissions."
-msgstr ""
-"参数 core.sharedRepository 的文件属性值有问题（0%.3o）。\n"
-"文件属主必须始终拥有读写权限。"
-
-#: setup.c:1211
-msgid "open /dev/null or dup failed"
-msgstr "不能打开或者复制 /dev/null"
-
-#: setup.c:1226
-msgid "fork failed"
-msgstr "fork 失败"
+msgid "could not remove reference %s"
+msgstr "无法删除引用 %s"
 
-#: setup.c:1231
-msgid "setsid failed"
-msgstr "setsid 失败"
+#: refs/files-backend.c:1248 refs/packed-backend.c:1541
+#: refs/packed-backend.c:1551
+#, c-format
+msgid "could not delete reference %s: %s"
+msgstr "无法删除引用 %s：%s"
 
-#: sha1-file.c:625
+#: refs/files-backend.c:1251 refs/packed-backend.c:1554
 #, c-format
-msgid "path '%s' does not exist"
-msgstr "路径 '%s' 不存在"
+msgid "could not delete references: %s"
+msgstr "无法删除引用：%s"
 
-#: sha1-file.c:651
+#: refspec.c:137
 #, c-format
-msgid "reference repository '%s' as a linked checkout is not supported yet."
-msgstr "尚不支持将参考仓库 '%s' 作为一个链接检出。"
+msgid "invalid refspec '%s'"
+msgstr "无效的引用表达式：'%s'"
+
+#: ref-filter.c:42 wt-status.c:1938
+msgid "gone"
+msgstr "丢失"
 
-#: sha1-file.c:657
+#: ref-filter.c:43
 #, c-format
-msgid "reference repository '%s' is not a local repository."
-msgstr "参考仓库 '%s' 不是一个本地仓库。"
+msgid "ahead %d"
+msgstr "领先 %d"
 
-#: sha1-file.c:663
+#: ref-filter.c:44
 #, c-format
-msgid "reference repository '%s' is shallow"
-msgstr "参考仓库 '%s' 是一个浅克隆"
+msgid "behind %d"
+msgstr "落后 %d"
 
-#: sha1-file.c:671
+#: ref-filter.c:45
 #, c-format
-msgid "reference repository '%s' is grafted"
-msgstr "参考仓库 '%s' 已被移植"
+msgid "ahead %d, behind %d"
+msgstr "领先 %d，落后 %d"
 
-#: sha1-name.c:442
+#: ref-filter.c:165
 #, c-format
-msgid "short SHA1 %s is ambiguous"
-msgstr "短 SHA1 %s 存在歧义"
+msgid "expected format: %%(color:<color>)"
+msgstr "期望的格式：%%(color:<颜色>)"
 
-#: sha1-name.c:453
-msgid "The candidates are:"
-msgstr "候选者有："
+#: ref-filter.c:167
+#, c-format
+msgid "unrecognized color: %%(color:%s)"
+msgstr "未能识别的颜色：%%(color:%s)"
 
-#: sha1-name.c:695
-msgid ""
-"Git normally never creates a ref that ends with 40 hex characters\n"
-"because it will be ignored when you just specify 40-hex. These refs\n"
-"may be created by mistake. For example,\n"
-"\n"
-"  git checkout -b $br $(git rev-parse ...)\n"
-"\n"
-"where \"$br\" is somehow empty and a 40-hex ref is created. Please\n"
-"examine these refs and maybe delete them. Turn this message off by\n"
-"running \"git config advice.objectNameWarning false\""
-msgstr ""
-"Git 通常不会创建一个以40位十六进制字符命名的引用，因为当你提供40位\n"
-"十六进制字符时将被忽略。不过这些引用也可能被错误地创建。例如：\n"
-"\n"
-"  git checkout -b $br $(git rev-parse ...)\n"
-"\n"
-"当 \"$br\" 空白时一个40位十六进制的引用将被创建。请检查这些引用，\n"
-"可能需要删除它们。用 \"git config advice.objectNameWarning false\"\n"
-"命令关闭本消息通知。"
+#: ref-filter.c:189
+#, c-format
+msgid "Integer value expected refname:lstrip=%s"
+msgstr "期望整数值 refname:lstrip=%s"
 
-#: submodule.c:97 submodule.c:131
-msgid "Cannot change unmerged .gitmodules, resolve merge conflicts first"
-msgstr "无法修改未合并的 .gitmodules，先解决合并冲突"
+#: ref-filter.c:193
+#, c-format
+msgid "Integer value expected refname:rstrip=%s"
+msgstr "期望整数值 refname:rstrip=%s"
 
-#: submodule.c:101 submodule.c:135
+#: ref-filter.c:195
 #, c-format
-msgid "Could not find section in .gitmodules where path=%s"
-msgstr "无法在 .gitmodules 中找到 path=%s 的小节"
+msgid "unrecognized %%(%s) argument: %s"
+msgstr "未能识别的 %%(%s) 参数：%s"
 
-#: submodule.c:109
+#: ref-filter.c:250
 #, c-format
-msgid "Could not update .gitmodules entry %s"
-msgstr "不能更新 .gitmodules 条目 %s"
+msgid "%%(objecttype) does not take arguments"
+msgstr "%%(objecttype) 不带参数"
 
-#: submodule.c:142
+#: ref-filter.c:272
 #, c-format
-msgid "Could not remove .gitmodules entry for %s"
-msgstr "无法移除 %s 的 .gitmodules 条目"
+msgid "unrecognized %%(objectsize) argument: %s"
+msgstr "未能识别的 %%(objectsize) 参数：%s"
 
-#: submodule.c:153
-msgid "staging updated .gitmodules failed"
-msgstr "将更新后 .gitmodules 添加暂存区失败"
+#: ref-filter.c:280
+#, c-format
+msgid "%%(deltabase) does not take arguments"
+msgstr "%%(deltabase) 不带参数"
 
-#: submodule.c:315
+#: ref-filter.c:292
 #, c-format
-msgid "in unpopulated submodule '%s'"
-msgstr "位于未检出的子模组 '%s'"
+msgid "%%(body) does not take arguments"
+msgstr "%%(body) 不带参数"
 
-#: submodule.c:346
+#: ref-filter.c:301
 #, c-format
-msgid "Pathspec '%s' is in submodule '%.*s'"
-msgstr "路径规格 '%s' 在子模组 '%.*s' 中"
+msgid "%%(subject) does not take arguments"
+msgstr "%%(subject) 不带参数"
 
-#: submodule.c:837
+#: ref-filter.c:323
 #, c-format
-msgid "submodule entry '%s' (%s) is a %s, not a commit"
-msgstr "子模组条目 '%s'（%s）是一个 %s，不是一个提交"
+msgid "unknown %%(trailers) argument: %s"
+msgstr "未知的 %%(trailers) 参数：%s"
 
-#: submodule.c:1069 builtin/branch.c:651 builtin/submodule--helper.c:1743
-msgid "Failed to resolve HEAD as a valid ref."
-msgstr "无法将 HEAD 解析为有效引用。"
+#: ref-filter.c:352
+#, c-format
+msgid "positive value expected contents:lines=%s"
+msgstr "期望一个正数 contents:lines=%s"
 
-#: submodule.c:1375
+#: ref-filter.c:354
 #, c-format
-msgid "'%s' not recognized as a git repository"
-msgstr "无法将 '%s' 识别为一个 git 仓库"
+msgid "unrecognized %%(contents) argument: %s"
+msgstr "未能识别的 %%(contents) 参数：%s"
 
-#: submodule.c:1513
+#: ref-filter.c:369
 #, c-format
-msgid "could not start 'git status' in submodule '%s'"
-msgstr "无法在子模组 '%s' 中启动 'git status'"
+msgid "positive value expected objectname:short=%s"
+msgstr "期望一个正数 objectname:short=%s"
 
-#: submodule.c:1526
+#: ref-filter.c:373
 #, c-format
-msgid "could not run 'git status' in submodule '%s'"
-msgstr "无法在子模组 '%s' 中执行 'git status'"
+msgid "unrecognized %%(objectname) argument: %s"
+msgstr "未能识别的 %%(objectname) 参数：%s"
 
-#: submodule.c:1619
+#: ref-filter.c:403
 #, c-format
-msgid "submodule '%s' has dirty index"
-msgstr "子模组 '%s' 中有脏索引"
+msgid "expected format: %%(align:<width>,<position>)"
+msgstr "期望的格式：%%(align:<宽度>,<位置>)"
 
-#: submodule.c:1718
+#: ref-filter.c:415
 #, c-format
-msgid ""
-"relocate_gitdir for submodule '%s' with more than one worktree not supported"
-msgstr "不支持对有多个工作区的子模组 '%s' 执行 relocate_gitdir"
+msgid "unrecognized position:%s"
+msgstr "未能识别的位置：%s"
 
-#: submodule.c:1730 submodule.c:1786
+#: ref-filter.c:422
 #, c-format
-msgid "could not lookup name for submodule '%s'"
-msgstr "不能查询子模组 '%s' 的名称"
+msgid "unrecognized width:%s"
+msgstr "未能识别的宽度：%s"
 
-#: submodule.c:1734 builtin/submodule--helper.c:1261
-#: builtin/submodule--helper.c:1271
+#: ref-filter.c:431
 #, c-format
-msgid "could not create directory '%s'"
-msgstr "不能创建目录 '%s'"
+msgid "unrecognized %%(align) argument: %s"
+msgstr "未能识别的 %%(align) 参数：%s"
 
-#: submodule.c:1737
+#: ref-filter.c:439
 #, c-format
-msgid ""
-"Migrating git directory of '%s%s' from\n"
-"'%s' to\n"
-"'%s'\n"
-msgstr ""
-"将 '%s%s' 的 git 目录从\n"
-"'%s' 迁移至\n"
-"'%s'\n"
+msgid "positive width expected with the %%(align) atom"
+msgstr "元素 %%(align) 需要一个正数的宽度"
 
-#: submodule.c:1821
+#: ref-filter.c:457
 #, c-format
-msgid "could not recurse into submodule '%s'"
-msgstr "无法递归进子模组路径 '%s'"
+msgid "unrecognized %%(if) argument: %s"
+msgstr "未能识别的 %%(if) 参数：%s"
 
-#: submodule.c:1865
-msgid "could not start ls-files in .."
-msgstr "无法在 .. 中启动 ls-files"
+#: ref-filter.c:559
+#, c-format
+msgid "malformed field name: %.*s"
+msgstr "格式错误的字段名：%.*s"
 
-#: submodule.c:1904
+#: ref-filter.c:586
 #, c-format
-msgid "ls-tree returned unexpected return code %d"
-msgstr "ls-tree 返回未知返回值 %d"
+msgid "unknown field name: %.*s"
+msgstr "未知的字段名：%.*s"
 
-#: submodule-config.c:230
+#: ref-filter.c:590
 #, c-format
-msgid "ignoring suspicious submodule name: %s"
-msgstr "忽略可疑的子模组名称：%s"
+msgid ""
+"not a git repository, but the field '%.*s' requires access to object data"
+msgstr "不是一个 git 仓库，但是字段 '%.*s' 需要访问对象数据"
 
-#: submodule-config.c:294
-msgid "negative values not allowed for submodule.fetchjobs"
-msgstr "submodule.fetchjobs 不允许为负值"
+#: ref-filter.c:714
+#, c-format
+msgid "format: %%(if) atom used without a %%(then) atom"
+msgstr "格式：使用了 %%(if) 元素而没有 %%(then) 元素"
 
-#: submodule-config.c:467
+#: ref-filter.c:777
 #, c-format
-msgid "invalid value for %s"
-msgstr "%s 的值无效"
+msgid "format: %%(then) atom used without an %%(if) atom"
+msgstr "格式：使用了 %%(then) 元素而没有 %%(if) 元素"
 
-#: trailer.c:238
+#: ref-filter.c:779
 #, c-format
-msgid "running trailer command '%s' failed"
-msgstr "执行 trailer 命令 '%s' 失败"
+msgid "format: %%(then) atom used more than once"
+msgstr "格式：%%(then) 元素用了多次"
 
-#: trailer.c:485 trailer.c:490 trailer.c:495 trailer.c:549 trailer.c:553
-#: trailer.c:557
+#: ref-filter.c:781
 #, c-format
-msgid "unknown value '%s' for key '%s'"
-msgstr "键 '%2$s' 的未知取值 '%1$s'"
+msgid "format: %%(then) atom used after %%(else)"
+msgstr "格式：%%(then) 元素用在了 %%(else) 之后"
 
-#: trailer.c:539 trailer.c:544 builtin/remote.c:293
+#: ref-filter.c:809
 #, c-format
-msgid "more than one %s"
-msgstr "多于一个 %s"
+msgid "format: %%(else) atom used without an %%(if) atom"
+msgstr "格式：使用了 %%(else) 元素而没有 %%(if) 元素"
 
-#: trailer.c:730
+#: ref-filter.c:811
 #, c-format
-msgid "empty trailer token in trailer '%.*s'"
-msgstr "签名 '%.*s' 的键为空"
+msgid "format: %%(else) atom used without a %%(then) atom"
+msgstr "格式：使用了 %%(else) 元素而没有 %%(then) 元素"
 
-#: trailer.c:750
+#: ref-filter.c:813
 #, c-format
-msgid "could not read input file '%s'"
-msgstr "不能读取输入文件 '%s'"
+msgid "format: %%(else) atom used more than once"
+msgstr "格式：%%(else) 元素用了多次"
 
-#: trailer.c:753
-msgid "could not read from stdin"
-msgstr "不能自标准输入读取"
+#: ref-filter.c:828
+#, c-format
+msgid "format: %%(end) atom used without corresponding atom"
+msgstr "格式：使用了 %%(end) 元素却没有它的对应元素"
 
-#: trailer.c:1008 builtin/am.c:46
+#: ref-filter.c:885
 #, c-format
-msgid "could not stat %s"
-msgstr "不能对 %s 调用 stat"
+msgid "malformed format string %s"
+msgstr "错误的格式化字符串 %s"
 
-#: trailer.c:1010
+#: ref-filter.c:1488
 #, c-format
-msgid "file %s is not a regular file"
-msgstr "文件 %s 不是一个正规文件"
+msgid "no branch, rebasing %s"
+msgstr "非分支，正变基 %s"
 
-#: trailer.c:1012
+#: ref-filter.c:1491
 #, c-format
-msgid "file %s is not writable by user"
-msgstr "文件 %s 用户不可写"
+msgid "no branch, rebasing detached HEAD %s"
+msgstr "非分支，正变基分离头指针 %s"
 
-#: trailer.c:1024
-msgid "could not open temporary file"
-msgstr "不能打开临时文件"
+#: ref-filter.c:1494
+#, c-format
+msgid "no branch, bisect started on %s"
+msgstr "非分支，二分查找开始于 %s"
 
-#: trailer.c:1064
+#: ref-filter.c:1504
+msgid "no branch"
+msgstr "非分支"
+
+#: ref-filter.c:1540 ref-filter.c:1749
 #, c-format
-msgid "could not rename temporary file to %s"
-msgstr "不能重命名临时文件为 %s"
+msgid "missing object %s for %s"
+msgstr "缺失 %2$s 的对象 %1$s"
 
-#: transport.c:116
+#: ref-filter.c:1550
 #, c-format
-msgid "Would set upstream of '%s' to '%s' of '%s'\n"
-msgstr "将要设置 '%1$s' 的上游为 '%3$s' 的 '%2$s'\n"
+msgid "parse_object_buffer failed on %s for %s"
+msgstr "parse_object_buffer 失败于 %2$s 的 %1$s"
 
-#: transport.c:208
+#: ref-filter.c:2004
 #, c-format
-msgid "transport: invalid depth option '%s'"
-msgstr "传输：无效的深度选项 '%s'"
+msgid "malformed object at '%s'"
+msgstr "格式错误的对象 '%s'"
 
-#: transport.c:584
-msgid "could not parse transport.color.* config"
-msgstr "不能解析 transport.color.* 配置"
+#: ref-filter.c:2093
+#, c-format
+msgid "ignoring ref with broken name %s"
+msgstr "忽略带有错误名称 %s 的引用"
 
-#: transport.c:996
+#: ref-filter.c:2389
 #, c-format
-msgid ""
-"The following submodule paths contain changes that can\n"
-"not be found on any remote:\n"
-msgstr "下列子模组路径所包含的修改在任何远程源中都找不到：\n"
+msgid "format: %%(end) atom missing"
+msgstr "格式：缺少 %%(end) 元素"
 
-#: transport.c:1000
+#: ref-filter.c:2489
 #, c-format
-msgid ""
-"\n"
-"Please try\n"
-"\n"
-"\tgit push --recurse-submodules=on-demand\n"
-"\n"
-"or cd to the path and use\n"
-"\n"
-"\tgit push\n"
-"\n"
-"to push them to a remote.\n"
-"\n"
-msgstr ""
-"\n"
-"请尝试\n"
-"\n"
-"\tgit push --recurse-submodules=on-demand\n"
-"\n"
-"或者进入到子目录执行\n"
-"\n"
-"\tgit push\n"
-"\n"
-"以推送至远程。\n"
-"\n"
+msgid "option `%s' is incompatible with --merged"
+msgstr "选项 `%s' 和 --merged 不兼容"
 
-#: transport.c:1008
-msgid "Aborting."
-msgstr "正在终止。"
+#: ref-filter.c:2492
+#, c-format
+msgid "option `%s' is incompatible with --no-merged"
+msgstr "选项 `%s' 和 --no-merged 不兼容"
 
-#: transport-helper.c:1087
+#: ref-filter.c:2502
 #, c-format
-msgid "Could not read ref %s"
-msgstr "不能读取引用 %s"
+msgid "malformed object name %s"
+msgstr "格式错误的对象名 %s"
 
-#: tree-walk.c:31
-msgid "too-short tree object"
-msgstr "太短的树对象"
+#: ref-filter.c:2507
+#, c-format
+msgid "option `%s' must point to a commit"
+msgstr "选项 `%s' 必须指向一个提交"
 
-#: tree-walk.c:37
-msgid "malformed mode in tree entry"
-msgstr "树对象中的条目模式错误"
+#: remote.c:366
+#, c-format
+msgid "config remote shorthand cannot begin with '/': %s"
+msgstr "配置的远程短名称不能以 '/' 开始：%s"
 
-#: tree-walk.c:41
-msgid "empty filename in tree entry"
-msgstr "树对象条目中空的文件名"
+#: remote.c:413
+msgid "more than one receivepack given, using the first"
+msgstr "提供了一个以上的 receivepack，使用第一个"
 
-#: tree-walk.c:113
-msgid "too-short tree file"
-msgstr "太短的树文件"
+#: remote.c:421
+msgid "more than one uploadpack given, using the first"
+msgstr "提供了一个以上的 uploadpack，使用第一个"
 
-#: unpack-trees.c:111
+#: remote.c:611
 #, c-format
-msgid ""
-"Your local changes to the following files would be overwritten by checkout:\n"
-"%%sPlease commit your changes or stash them before you switch branches."
-msgstr ""
-"您对下列文件的本地修改将被检出操作覆盖：\n"
-"%%s请在切换分支前提交或贮藏您的修改。"
+msgid "Cannot fetch both %s and %s to %s"
+msgstr "不能同时获取 %s 和 %s 至 %s"
 
-#: unpack-trees.c:113
+#: remote.c:615
 #, c-format
-msgid ""
-"Your local changes to the following files would be overwritten by checkout:\n"
-"%%s"
-msgstr ""
-"您对下列文件的本地修改将被检出操作覆盖：\n"
-"%%s"
+msgid "%s usually tracks %s, not %s"
+msgstr "%s 通常跟踪 %s，而非 %s"
 
-#: unpack-trees.c:116
+#: remote.c:619
 #, c-format
-msgid ""
-"Your local changes to the following files would be overwritten by merge:\n"
-"%%sPlease commit your changes or stash them before you merge."
-msgstr ""
-"您对下列文件的本地修改将被合并操作覆盖：\n"
-"%%s请在合并前提交或贮藏您的修改。"
+msgid "%s tracks both %s and %s"
+msgstr "%s 同时跟踪 %s 和 %s"
 
-#: unpack-trees.c:118
+#: remote.c:687
 #, c-format
-msgid ""
-"Your local changes to the following files would be overwritten by merge:\n"
-"%%s"
-msgstr ""
-"您对下列文件的本地修改将被合并操作覆盖：\n"
-"%%s"
+msgid "key '%s' of pattern had no '*'"
+msgstr "模式的键 '%s' 没有 '*'"
 
-#: unpack-trees.c:121
+#: remote.c:697
 #, c-format
-msgid ""
-"Your local changes to the following files would be overwritten by %s:\n"
-"%%sPlease commit your changes or stash them before you %s."
-msgstr ""
-"您对下列文件的本地修改将被 %s 覆盖：\n"
-"%%s请在 %s 之前提交或贮藏您的修改。"
+msgid "value '%s' of pattern has no '*'"
+msgstr "模式的值 '%s' 没有 '*'"
 
-#: unpack-trees.c:123
+#: remote.c:1003
 #, c-format
-msgid ""
-"Your local changes to the following files would be overwritten by %s:\n"
-"%%s"
-msgstr ""
-"您对下列文件的本地修改将被 %s 覆盖：\n"
-"%%s"
+msgid "src refspec %s does not match any"
+msgstr "源引用表达式 %s 没有匹配"
 
-#: unpack-trees.c:128
+#: remote.c:1008
 #, c-format
-msgid ""
-"Updating the following directories would lose untracked files in them:\n"
-"%s"
-msgstr ""
-"更新如下目录将会丢失其中未跟踪的文件：\n"
-"%s"
+msgid "src refspec %s matches more than one"
+msgstr "源引用表达式 %s 匹配超过一个"
 
-#: unpack-trees.c:132
+#. TRANSLATORS: "matches '%s'%" is the <dst> part of "git push
+#. <remote> <src>:<dst>" push, and "being pushed ('%s')" is
+#. the <src>.
+#.
+#: remote.c:1023
 #, c-format
 msgid ""
-"The following untracked working tree files would be removed by checkout:\n"
-"%%sPlease move or remove them before you switch branches."
+"The destination you provided is not a full refname (i.e.,\n"
+"starting with \"refs/\"). We tried to guess what you meant by:\n"
+"\n"
+"- Looking for a ref that matches '%s' on the remote side.\n"
+"- Checking if the <src> being pushed ('%s')\n"
+"  is a ref in \"refs/{heads,tags}/\". If so we add a corresponding\n"
+"  refs/{heads,tags}/ prefix on the remote side.\n"
+"\n"
+"Neither worked, so we gave up. You must fully qualify the ref."
 msgstr ""
-"工作区中下列未跟踪的文件将会因为检出操作而被删除：\n"
-"%%s请在切换分支之前移动或删除。"
+"您提供的目标不是一个完整的引用名称（即以 \"refs/\" 开头）。我们\n"
+"试着猜测您的想法：\n"
+"\n"
+"- 在远端查询和 '%s' 匹配的引用。\n"
+"- 检查要推送的 <src>（'%s'）是不是在 \"refs/{heads,tags}/\" 中的\n"
+"  引用。如果是，我们会在对应的远端添加 refs/{heads,tags}/ 前缀。\n"
+"\n"
+"都不行，所以我们已放弃。您必须给出完整的引用。"
 
-#: unpack-trees.c:134
+#: remote.c:1043
 #, c-format
 msgid ""
-"The following untracked working tree files would be removed by checkout:\n"
-"%%s"
+"The <src> part of the refspec is a commit object.\n"
+"Did you mean to create a new branch by pushing to\n"
+"'%s:refs/heads/%s'?"
 msgstr ""
-"工作区中下列未跟踪的文件将会因为检出操作而被删除：\n"
-"%%s"
+"引用表达式的 <src> 是一个提交对象。您是想创建一个新的分支而向\n"
+"'%s:refs/heads/%s' 推送么？"
 
-#: unpack-trees.c:137
+#: remote.c:1048
 #, c-format
 msgid ""
-"The following untracked working tree files would be removed by merge:\n"
-"%%sPlease move or remove them before you merge."
+"The <src> part of the refspec is a tag object.\n"
+"Did you mean to create a new tag by pushing to\n"
+"'%s:refs/tags/%s'?"
 msgstr ""
-"工作区中下列未跟踪的文件将会因为合并操作而被删除：\n"
-"%%s请在合并前移动或删除。"
+"引用表达式的 <src> 是一个标签对象。您是想创建一个新的标签而向\n"
+"'%s:refs/tags/%s' 推送么？"
 
-#: unpack-trees.c:139
+#: remote.c:1053
 #, c-format
 msgid ""
-"The following untracked working tree files would be removed by merge:\n"
-"%%s"
+"The <src> part of the refspec is a tree object.\n"
+"Did you mean to tag a new tree by pushing to\n"
+"'%s:refs/tags/%s'?"
 msgstr ""
-"工作区中下列未跟踪的文件将会因为合并操作而被删除：\n"
-"%%s"
+"引用表达式的 <src> 是一个树对象。您是想为这个树对象创建标签而向\n"
+"'%s:refs/tags/%s' 推送么？"
 
-#: unpack-trees.c:142
+#: remote.c:1058
 #, c-format
 msgid ""
-"The following untracked working tree files would be removed by %s:\n"
-"%%sPlease move or remove them before you %s."
+"The <src> part of the refspec is a blob object.\n"
+"Did you mean to tag a new blob by pushing to\n"
+"'%s:refs/tags/%s'?"
 msgstr ""
-"工作区中下列未跟踪的文件将会因为 %s 操作而被删除：\n"
-"%%s请在 %s 前移动或删除。"
+"引用表达式的 <src> 是一个数据对象。您是想为这个数据对象创建标签而向\n"
+"'%s:refs/tags/%s' 推送么？"
 
-#: unpack-trees.c:144
+#: remote.c:1094
 #, c-format
-msgid ""
-"The following untracked working tree files would be removed by %s:\n"
-"%%s"
-msgstr ""
-"工作区中下列未跟踪的文件将会因为 %s 操作而被删除：\n"
-"%%s"
+msgid "%s cannot be resolved to branch"
+msgstr "%s 无法被解析为分支"
 
-#: unpack-trees.c:150
+#: remote.c:1105
 #, c-format
-msgid ""
-"The following untracked working tree files would be overwritten by "
-"checkout:\n"
-"%%sPlease move or remove them before you switch branches."
-msgstr ""
-"工作区中下列未跟踪的文件将会因为检出操作而被覆盖：\n"
-"%%s请在切换分支前移动或删除。"
+msgid "unable to delete '%s': remote ref does not exist"
+msgstr "无法删除 '%s'：远程引用不存在"
 
-#: unpack-trees.c:152
+#: remote.c:1117
 #, c-format
-msgid ""
-"The following untracked working tree files would be overwritten by "
-"checkout:\n"
-"%%s"
-msgstr ""
-"工作区中下列未跟踪的文件将会因为检出操作而被覆盖：\n"
-"%%s"
+msgid "dst refspec %s matches more than one"
+msgstr "目标引用表达式 %s 匹配超过一个"
 
-#: unpack-trees.c:155
+#: remote.c:1124
 #, c-format
-msgid ""
-"The following untracked working tree files would be overwritten by merge:\n"
-"%%sPlease move or remove them before you merge."
-msgstr ""
-"工作区中下列未跟踪的文件将会因为合并操作而被覆盖：\n"
-"%%s请在合并前移动或删除。"
+msgid "dst ref %s receives from more than one src"
+msgstr "目标引用 %s 接收超过一个源"
+
+#: remote.c:1627 remote.c:1728
+msgid "HEAD does not point to a branch"
+msgstr "HEAD 没有指向一个分支"
 
-#: unpack-trees.c:157
+#: remote.c:1636
 #, c-format
-msgid ""
-"The following untracked working tree files would be overwritten by merge:\n"
-"%%s"
-msgstr ""
-"工作区中下列未跟踪的文件将会因为合并操作而被覆盖：\n"
-"%%s"
+msgid "no such branch: '%s'"
+msgstr "没有此分支：'%s'"
 
-#: unpack-trees.c:160
+#: remote.c:1639
 #, c-format
-msgid ""
-"The following untracked working tree files would be overwritten by %s:\n"
-"%%sPlease move or remove them before you %s."
-msgstr ""
-"工作区中下列未跟踪的文件将会因为 %s 操作而被覆盖：\n"
-"%%s请在 %s 前移动或删除。"
+msgid "no upstream configured for branch '%s'"
+msgstr "尚未给分支 '%s' 设置上游"
 
-#: unpack-trees.c:162
+#: remote.c:1645
 #, c-format
-msgid ""
-"The following untracked working tree files would be overwritten by %s:\n"
-"%%s"
-msgstr ""
-"工作区中下列未跟踪的文件将会因为 %s 操作而被覆盖：\n"
-"%%s"
+msgid "upstream branch '%s' not stored as a remote-tracking branch"
+msgstr "上游分支 '%s' 没有存储为一个远程跟踪分支"
 
-#: unpack-trees.c:170
+#: remote.c:1660
 #, c-format
-msgid "Entry '%s' overlaps with '%s'.  Cannot bind."
-msgstr "条目 '%s' 和 '%s' 重叠。无法合并。"
+msgid "push destination '%s' on remote '%s' has no local tracking branch"
+msgstr "推送目标 '%s' 至远程 '%s' 没有本地跟踪分支"
 
-#: unpack-trees.c:173
+#: remote.c:1672
 #, c-format
-msgid ""
-"Cannot update sparse checkout: the following entries are not up to date:\n"
-"%s"
-msgstr ""
-"无法更新稀疏检出：如下条目不是最新：\n"
-"%s"
+msgid "branch '%s' has no remote for pushing"
+msgstr "分支 '%s' 没有设置要推送的远程服务器"
 
-#: unpack-trees.c:175
+#: remote.c:1682
 #, c-format
-msgid ""
-"The following working tree files would be overwritten by sparse checkout "
-"update:\n"
-"%s"
-msgstr ""
-"工作区中下列文件将被稀疏检出更新所覆盖：\n"
-"%s"
+msgid "push refspecs for '%s' do not include '%s'"
+msgstr "向 '%s' 推送引用规格未包含 '%s'"
+
+#: remote.c:1695
+msgid "push has no destination (push.default is 'nothing')"
+msgstr "推送无目标（push.default 是 'nothing'）"
 
-#: unpack-trees.c:177
+#: remote.c:1717
+msgid "cannot resolve 'simple' push to a single destination"
+msgstr "无法解析 'simple' 推送至一个单独的目标"
+
+#: remote.c:1843
 #, c-format
-msgid ""
-"The following working tree files would be removed by sparse checkout "
-"update:\n"
-"%s"
-msgstr ""
-"工作区中下列文件将被稀疏检出更新所删除：\n"
-"%s"
+msgid "couldn't find remote ref %s"
+msgstr "无法找到远程引用 %s"
 
-#: unpack-trees.c:179
+#: remote.c:1856
 #, c-format
-msgid ""
-"Cannot update submodule:\n"
-"%s"
-msgstr ""
-"无法更新子模组：\n"
-"%s"
+msgid "* Ignoring funny ref '%s' locally"
+msgstr "* 在本地忽略可笑的引用 '%s'"
 
-#: unpack-trees.c:262
+#: remote.c:2019
 #, c-format
-msgid "Aborting\n"
-msgstr "终止中\n"
+msgid "Your branch is based on '%s', but the upstream is gone.\n"
+msgstr "您的分支基于 '%s'，但此上游分支已经不存在。\n"
 
-#: unpack-trees.c:344
-msgid "Checking out files"
-msgstr "正在检出文件"
+#: remote.c:2023
+msgid "  (use \"git branch --unset-upstream\" to fixup)\n"
+msgstr "  （使用 \"git branch --unset-upstream\" 来修复）\n"
 
-#: urlmatch.c:163
-msgid "invalid URL scheme name or missing '://' suffix"
-msgstr "无效的 URL 方案名称或丢失 '://' 后缀"
+#: remote.c:2026
+#, c-format
+msgid "Your branch is up to date with '%s'.\n"
+msgstr "您的分支与上游分支 '%s' 一致。\n"
 
-#: urlmatch.c:187 urlmatch.c:346 urlmatch.c:405
+#: remote.c:2030
 #, c-format
-msgid "invalid %XX escape sequence"
-msgstr "无效的 %XX 转义序列"
+msgid "Your branch and '%s' refer to different commits.\n"
+msgstr "您的分支和 '%s' 指向不同的提交。\n"
 
-#: urlmatch.c:215
-msgid "missing host and scheme is not 'file:'"
-msgstr "缺失主机名且 URL 方案不是 'file:'"
+#: remote.c:2033
+#, c-format
+msgid "  (use \"%s\" for details)\n"
+msgstr "  （使用 \"%s\" 查看详情）\n"
 
-#: urlmatch.c:232
-msgid "a 'file:' URL may not have a port number"
-msgstr "一个 'file:' URL 不应该包含端口号"
+#: remote.c:2037
+#, c-format
+msgid "Your branch is ahead of '%s' by %d commit.\n"
+msgid_plural "Your branch is ahead of '%s' by %d commits.\n"
+msgstr[0] "您的分支领先 '%s' 共 %d 个提交。\n"
+msgstr[1] "您的分支领先 '%s' 共 %d 个提交。\n"
 
-#: urlmatch.c:247
-msgid "invalid characters in host name"
-msgstr "主机名中包含无效的字符"
+#: remote.c:2043
+msgid "  (use \"git push\" to publish your local commits)\n"
+msgstr "  （使用 \"git push\" 来发布您的本地提交）\n"
 
-#: urlmatch.c:292 urlmatch.c:303
-msgid "invalid port number"
-msgstr "无效的端口号"
+#: remote.c:2046
+#, c-format
+msgid "Your branch is behind '%s' by %d commit, and can be fast-forwarded.\n"
+msgid_plural ""
+"Your branch is behind '%s' by %d commits, and can be fast-forwarded.\n"
+msgstr[0] "您的分支落后 '%s' 共 %d 个提交，并且可以快进。\n"
+msgstr[1] "您的分支落后 '%s' 共 %d 个提交，并且可以快进。\n"
 
-#: urlmatch.c:371
-msgid "invalid '..' path segment"
-msgstr "无效的 '..' 路径片段"
+#  译者：注意保持前导空格
+#: remote.c:2054
+msgid "  (use \"git pull\" to update your local branch)\n"
+msgstr "  （使用 \"git pull\" 来更新您的本地分支）\n"
 
-#: worktree.c:245 builtin/am.c:2147
+#: remote.c:2057
 #, c-format
-msgid "failed to read '%s'"
-msgstr "无法读取 '%s'"
+msgid ""
+"Your branch and '%s' have diverged,\n"
+"and have %d and %d different commit each, respectively.\n"
+msgid_plural ""
+"Your branch and '%s' have diverged,\n"
+"and have %d and %d different commits each, respectively.\n"
+msgstr[0] ""
+"您的分支和 '%s' 出现了偏离，\n"
+"并且分别有 %d 和 %d 处不同的提交。\n"
+msgstr[1] ""
+"您的分支和 '%s' 出现了偏离，\n"
+"并且分别有 %d 和 %d 处不同的提交。\n"
+
+#  译者：注意保持前导空格
+#: remote.c:2067
+msgid "  (use \"git pull\" to merge the remote branch into yours)\n"
+msgstr "  （使用 \"git pull\" 来合并远程分支）\n"
 
-#: worktree.c:291
+#: remote.c:2250
 #, c-format
-msgid "'%s' at main working tree is not the repository directory"
-msgstr "在主工作区的 '%s' 不是仓库目录"
+msgid "cannot parse expected object name '%s'"
+msgstr "无法解析期望的对象名 '%s'"
 
-#: worktree.c:302
+#: replace-object.c:21
 #, c-format
-msgid "'%s' file does not contain absolute path to the working tree location"
-msgstr "文件 '%s' 不包含工作区的绝对路径"
+msgid "bad replace ref name: %s"
+msgstr "错误的替换引用名称：%s"
 
-#: worktree.c:314
+#: replace-object.c:30
 #, c-format
-msgid "'%s' does not exist"
-msgstr "'%s' 不存在"
+msgid "duplicate replace ref: %s"
+msgstr "重复的替换引用：%s"
 
-#: worktree.c:320
+#: replace-object.c:73
 #, c-format
-msgid "'%s' is not a .git file, error code %d"
-msgstr "'%s' 不是一个 .git 文件，错误码 %d"
+msgid "replace depth too high for object %s"
+msgstr "对象 %s 的替换层级太深"
+
+#: rerere.c:217 rerere.c:226 rerere.c:229
+msgid "corrupt MERGE_RR"
+msgstr "损坏的 MERGE_RR"
 
-#: worktree.c:328
+#: rerere.c:264 rerere.c:269
+msgid "unable to write rerere record"
+msgstr "无法写入 rerere 记录"
+
+#: rerere.c:495
 #, c-format
-msgid "'%s' does not point back to '%s'"
-msgstr "'%s' 没有指回到 '%s'"
+msgid "there were errors while writing '%s' (%s)"
+msgstr "写入 '%s' (%s) 时出错"
 
-#: wrapper.c:223 wrapper.c:393
+#: rerere.c:498
 #, c-format
-msgid "could not open '%s' for reading and writing"
-msgstr "无法打开 '%s' 进行读写"
+msgid "failed to flush '%s'"
+msgstr "刷新 '%s' 失败"
 
-#: wrapper.c:227 wrapper.c:397 builtin/am.c:320 builtin/am.c:770
-#: builtin/am.c:862 builtin/merge.c:1043
+#: rerere.c:503 rerere.c:1039
 #, c-format
-msgid "could not open '%s' for reading"
-msgstr "无法打开 '%s' 进行读取"
+msgid "could not parse conflict hunks in '%s'"
+msgstr "不能解析 '%s' 中的冲突块"
 
-#: wrapper.c:424 wrapper.c:624
+#: rerere.c:684
 #, c-format
-msgid "unable to access '%s'"
-msgstr "不能访问 '%s'"
+msgid "failed utime() on '%s'"
+msgstr "在 '%s' 上调用 utime() 失败"
 
-#: wrapper.c:632
-msgid "unable to get current working directory"
-msgstr "不能获取当前工作目录"
+#: rerere.c:694
+#, c-format
+msgid "writing '%s' failed"
+msgstr "写入 '%s' 失败"
 
-#: wt-status.c:154
-msgid "Unmerged paths:"
-msgstr "未合并的路径："
+#: rerere.c:714
+#, c-format
+msgid "Staged '%s' using previous resolution."
+msgstr "使用之前的解决方案暂存 '%s'。"
 
-#  译者：注意保持前导空格
-#: wt-status.c:181 wt-status.c:208
+#: rerere.c:753
 #, c-format
-msgid "  (use \"git reset %s <file>...\" to unstage)"
-msgstr "  （使用 \"git reset %s <文件>...\" 以取消暂存）"
+msgid "Recorded resolution for '%s'."
+msgstr "已记录 '%s' 的解决方案。"
 
-#  译者：注意保持前导空格
-#: wt-status.c:183 wt-status.c:210
-msgid "  (use \"git rm --cached <file>...\" to unstage)"
-msgstr "  （使用 \"git rm --cached <文件>...\" 以取消暂存）"
+#: rerere.c:788
+#, c-format
+msgid "Resolved '%s' using previous resolution."
+msgstr "使用之前的解决方案解决 '%s'。"
 
-#  译者：注意保持前导空格
-#: wt-status.c:187
-msgid "  (use \"git add <file>...\" to mark resolution)"
-msgstr "  （使用 \"git add <文件>...\" 标记解决方案）"
+#: rerere.c:803
+#, c-format
+msgid "cannot unlink stray '%s'"
+msgstr "不能删除 stray '%s'"
 
-#  译者：注意保持前导空格
-#: wt-status.c:189 wt-status.c:193
-msgid "  (use \"git add/rm <file>...\" as appropriate to mark resolution)"
-msgstr "  （酌情使用 \"git add/rm <文件>...\" 标记解决方案）"
+#: rerere.c:807
+#, c-format
+msgid "Recorded preimage for '%s'"
+msgstr "为 '%s' 记录 preimage"
 
-#  译者：注意保持前导空格
-#: wt-status.c:191
-msgid "  (use \"git rm <file>...\" to mark resolution)"
-msgstr "  （使用 \"git rm <文件>...\" 标记解决方案）"
+#: rerere.c:881 submodule.c:2067 builtin/log.c:1871
+#: builtin/submodule--helper.c:1436 builtin/submodule--helper.c:1448
+#, c-format
+msgid "could not create directory '%s'"
+msgstr "不能创建目录 '%s'"
 
-#: wt-status.c:202 wt-status.c:1015
-msgid "Changes to be committed:"
-msgstr "要提交的变更："
+#: rerere.c:1057
+#, c-format
+msgid "failed to update conflicted state in '%s'"
+msgstr "更新 '%s' 中的冲突状态失败"
 
-#: wt-status.c:220 wt-status.c:1024
-msgid "Changes not staged for commit:"
-msgstr "尚未暂存以备提交的变更："
+#: rerere.c:1068 rerere.c:1075
+#, c-format
+msgid "no remembered resolution for '%s'"
+msgstr "没有为 '%s' 记忆的解决方案"
 
-#  译者：注意保持前导空格
-#: wt-status.c:224
-msgid "  (use \"git add <file>...\" to update what will be committed)"
-msgstr "  （使用 \"git add <文件>...\" 更新要提交的内容）"
+#: rerere.c:1077
+#, c-format
+msgid "cannot unlink '%s'"
+msgstr "不能删除 '%s'"
 
-#  译者：注意保持前导空格
-#: wt-status.c:226
-msgid "  (use \"git add/rm <file>...\" to update what will be committed)"
-msgstr "  （使用 \"git add/rm <文件>...\" 更新要提交的内容）"
+#: rerere.c:1087
+#, c-format
+msgid "Updated preimage for '%s'"
+msgstr "已为 '%s' 更新 preimage"
 
-#  译者：注意保持前导空格
-#: wt-status.c:227
-msgid ""
-"  (use \"git checkout -- <file>...\" to discard changes in working directory)"
-msgstr "  （使用 \"git checkout -- <文件>...\" 丢弃工作区的改动）"
+#: rerere.c:1096
+#, c-format
+msgid "Forgot resolution for '%s'\n"
+msgstr "忘记 '%s' 的解决方案\n"
 
-#  译者：注意保持前导空格
-#: wt-status.c:229
-msgid "  (commit or discard the untracked or modified content in submodules)"
-msgstr "  （提交或丢弃子模组中未跟踪或修改的内容）"
+#: rerere.c:1199
+msgid "unable to open rr-cache directory"
+msgstr "不能打开 rr-cache 目录"
 
-#  译者：注意保持前导空格
-#: wt-status.c:241
-#, c-format
-msgid "  (use \"git %s <file>...\" to include in what will be committed)"
-msgstr "  （使用 \"git %s <文件>...\" 以包含要提交的内容）"
+#: revision.c:2497
+msgid "your current branch appears to be broken"
+msgstr "您的当前分支好像被损坏"
 
-#: wt-status.c:256
-msgid "both deleted:"
-msgstr "双方删除："
+#: revision.c:2500
+#, c-format
+msgid "your current branch '%s' does not have any commits yet"
+msgstr "您的当前分支 '%s' 尚无任何提交"
 
-#: wt-status.c:258
-msgid "added by us:"
-msgstr "由我们添加："
+#: revision.c:2708
+msgid "--first-parent is incompatible with --bisect"
+msgstr "--first-parent 与 --bisect 不兼容"
 
-#: wt-status.c:260
-msgid "deleted by them:"
-msgstr "由他们删除："
+#: revision.c:2712
+msgid "-L does not yet support diff formats besides -p and -s"
+msgstr "-L 尚不支持 -p 和 -s 之外的差异格式"
 
-#: wt-status.c:262
-msgid "added by them:"
-msgstr "由他们添加："
+#: run-command.c:762
+msgid "open /dev/null failed"
+msgstr "不能打开 /dev/null"
 
-#: wt-status.c:264
-msgid "deleted by us:"
-msgstr "由我们删除："
+#: run-command.c:1268
+#, c-format
+msgid "cannot create async thread: %s"
+msgstr "不能创建 async 线程：%s"
 
-#: wt-status.c:266
-msgid "both added:"
-msgstr "双方添加："
+#: run-command.c:1332
+#, c-format
+msgid ""
+"The '%s' hook was ignored because it's not set as executable.\n"
+"You can disable this warning with `git config advice.ignoredHook false`."
+msgstr ""
+"因为没有将钩子 '%s' 设置为可执行，钩子被忽略。您可以通过\n"
+"配置 `git config advice.ignoredHook false` 来关闭这条警告。"
 
-#: wt-status.c:268
-msgid "both modified:"
-msgstr "双方修改："
+#: send-pack.c:144
+msgid "unexpected flush packet while reading remote unpack status"
+msgstr "读取远程解包状态时收到意外的 flush 包"
 
-#: wt-status.c:278
-msgid "new file:"
-msgstr "新文件："
+#: send-pack.c:146
+#, c-format
+msgid "unable to parse remote unpack status: %s"
+msgstr "不能解析远程解包状态：%s"
 
-#: wt-status.c:280
-msgid "copied:"
-msgstr "拷贝："
+#: send-pack.c:148
+#, c-format
+msgid "remote unpack failed: %s"
+msgstr "远程解包失败：%s"
 
-#: wt-status.c:282
-msgid "deleted:"
-msgstr "删除："
+#: send-pack.c:309
+msgid "failed to sign the push certificate"
+msgstr "为推送证书签名失败"
 
-#: wt-status.c:284
-msgid "modified:"
-msgstr "修改："
+#: send-pack.c:423
+msgid "the receiving end does not support --signed push"
+msgstr "接收端不支持签名推送"
 
-#: wt-status.c:286
-msgid "renamed:"
-msgstr "重命名："
+#: send-pack.c:425
+msgid ""
+"not sending a push certificate since the receiving end does not support --"
+"signed push"
+msgstr "未发送推送证书，因为接收端不支持签名推送"
 
-#: wt-status.c:288
-msgid "typechange:"
-msgstr "类型变更："
+#: send-pack.c:437
+msgid "the receiving end does not support --atomic push"
+msgstr "接收端不支持原子推送"
 
-#: wt-status.c:290
-msgid "unknown:"
-msgstr "未知："
+#: send-pack.c:442
+msgid "the receiving end does not support push options"
+msgstr "接收端不支持推送选项"
 
-#: wt-status.c:292
-msgid "unmerged:"
-msgstr "未合并："
+#: sequencer.c:189
+#, c-format
+msgid "invalid commit message cleanup mode '%s'"
+msgstr "无效的提交信息清理模式 '%s'"
 
-#  译者：末尾两个字节可能被删减，如果翻译为中文标点会出现半个汉字
-#: wt-status.c:372
-msgid "new commits, "
-msgstr "新提交, "
+#: sequencer.c:294
+#, c-format
+msgid "could not delete '%s'"
+msgstr "无法删除 '%s'"
 
-#  译者：末尾两个字节可能被删减，如果翻译为中文标点会出现半个汉字
-#: wt-status.c:374
-msgid "modified content, "
-msgstr "修改的内容, "
+#: sequencer.c:313 builtin/rebase.c:781 builtin/rebase.c:1706 builtin/rm.c:369
+#, c-format
+msgid "could not remove '%s'"
+msgstr "无法删除 '%s'"
 
-#  译者：末尾两个字节可能被删减，如果翻译为中文标点会出现半个汉字
-#: wt-status.c:376
-msgid "untracked content, "
-msgstr "未跟踪的内容, "
+#: sequencer.c:323
+msgid "revert"
+msgstr "还原"
 
-#: wt-status.c:853
-#, c-format
-msgid "Your stash currently has %d entry"
-msgid_plural "Your stash currently has %d entries"
-msgstr[0] "您的贮藏区当前有 %d 条记录"
-msgstr[1] "您的贮藏区当前有 %d 条记录"
+#: sequencer.c:325
+msgid "cherry-pick"
+msgstr "拣选"
 
-#: wt-status.c:885
-msgid "Submodules changed but not updated:"
-msgstr "子模组已修改但尚未更新："
+#: sequencer.c:327
+msgid "rebase -i"
+msgstr "rebase -i"
 
-#: wt-status.c:887
-msgid "Submodule changes to be committed:"
-msgstr "要提交的子模组变更："
+#: sequencer.c:329
+#, c-format
+msgid "unknown action: %d"
+msgstr "未知动作：%d"
 
-#: wt-status.c:969
+#: sequencer.c:387
 msgid ""
-"Do not modify or remove the line above.\n"
-"Everything below it will be ignored."
+"after resolving the conflicts, mark the corrected paths\n"
+"with 'git add <paths>' or 'git rm <paths>'"
 msgstr ""
-"不要改动或删除上面的一行。\n"
-"其下所有内容都将被忽略。"
+"冲突解决完毕后，用 'git add <路径>' 或 'git rm <路径>'\n"
+"命令标记修正后的文件"
 
-#: wt-status.c:1084
-msgid "You have unmerged paths."
-msgstr "您有尚未合并的路径。"
+#: sequencer.c:390
+msgid ""
+"after resolving the conflicts, mark the corrected paths\n"
+"with 'git add <paths>' or 'git rm <paths>'\n"
+"and commit the result with 'git commit'"
+msgstr ""
+"冲突解决完毕后，用 'git add <路径>' 或 'git rm <路径>'\n"
+"对修正后的文件做标记，然后用 'git commit' 提交"
 
-#  译者：注意保持前导空格
-#: wt-status.c:1087
-msgid "  (fix conflicts and run \"git commit\")"
-msgstr "  （解决冲突并运行 \"git commit\"）"
+#: sequencer.c:403 sequencer.c:2993
+#, c-format
+msgid "could not lock '%s'"
+msgstr "不能锁定 '%s'"
 
-#  译者：注意保持前导空格
-#: wt-status.c:1089
-msgid "  (use \"git merge --abort\" to abort the merge)"
-msgstr "  （使用 \"git merge --abort\" 终止合并）"
+#: sequencer.c:410
+#, c-format
+msgid "could not write eol to '%s'"
+msgstr "不能将换行符写入 '%s'"
 
-#: wt-status.c:1094
-msgid "All conflicts fixed but you are still merging."
-msgstr "所有冲突已解决但您仍处于合并中。"
+#: sequencer.c:415 sequencer.c:2798 sequencer.c:2999 sequencer.c:3013
+#: sequencer.c:3277
+#, c-format
+msgid "failed to finalize '%s'"
+msgstr "无法完成 '%s'"
 
-#  译者：注意保持前导空格
-#: wt-status.c:1097
-msgid "  (use \"git commit\" to conclude merge)"
-msgstr "  （使用 \"git commit\" 结束合并）"
+#: sequencer.c:438 sequencer.c:1707 sequencer.c:2818 sequencer.c:3259
+#: sequencer.c:3368 builtin/am.c:244 builtin/commit.c:783 builtin/merge.c:1117
+#: builtin/rebase.c:589
+#, c-format
+msgid "could not read '%s'"
+msgstr "不能读取 '%s'"
 
-#: wt-status.c:1107
-msgid "You are in the middle of an am session."
-msgstr "您正处于 am 操作过程中。"
+#: sequencer.c:464
+#, c-format
+msgid "your local changes would be overwritten by %s."
+msgstr "您的本地修改将被%s覆盖。"
 
-#: wt-status.c:1110
-msgid "The current patch is empty."
-msgstr "当前的补丁为空。"
+#: sequencer.c:468
+msgid "commit your changes or stash them to proceed."
+msgstr "提交您的修改或贮藏后再继续。"
 
-#  译者：注意保持前导空格
-#: wt-status.c:1114
-msgid "  (fix conflicts and then run \"git am --continue\")"
-msgstr "  （解决冲突，然后运行 \"git am --continue\"）"
+#: sequencer.c:500
+#, c-format
+msgid "%s: fast-forward"
+msgstr "%s：快进"
 
-#  译者：注意保持前导空格
-#: wt-status.c:1116
-msgid "  (use \"git am --skip\" to skip this patch)"
-msgstr "  （使用 \"git am --skip\" 跳过此补丁）"
+#: sequencer.c:539 builtin/tag.c:565
+#, c-format
+msgid "Invalid cleanup mode %s"
+msgstr "无效的清理模式 %s"
 
-#  译者：注意保持前导空格
-#: wt-status.c:1118
-msgid "  (use \"git am --abort\" to restore the original branch)"
-msgstr "  （使用 \"git am --abort\" 恢复原有分支）"
+#. TRANSLATORS: %s will be "revert", "cherry-pick" or
+#. "rebase -i".
+#.
+#: sequencer.c:633
+#, c-format
+msgid "%s: Unable to write new index file"
+msgstr "%s：无法写入新索引文件"
 
-#: wt-status.c:1250
-msgid "git-rebase-todo is missing."
-msgstr "git-rebase-todo 丢失。"
+#: sequencer.c:650
+msgid "unable to update cache tree"
+msgstr "不能更新缓存树"
 
-#: wt-status.c:1252
-msgid "No commands done."
-msgstr "没有命令被执行。"
+#: sequencer.c:664
+msgid "could not resolve HEAD commit"
+msgstr "不能解析 HEAD 提交"
 
-#: wt-status.c:1255
+#: sequencer.c:744
 #, c-format
-msgid "Last command done (%d command done):"
-msgid_plural "Last commands done (%d commands done):"
-msgstr[0] "最后一条命令已完成（%d 条命令被执行）："
-msgstr[1] "最后的命令已完成（%d 条命令被执行）："
+msgid "no key present in '%.*s'"
+msgstr "在 '%.*s' 中没有 key"
 
-#: wt-status.c:1266
+#: sequencer.c:755
 #, c-format
-msgid "  (see more in file %s)"
-msgstr "  （更多参见文件 %s）"
+msgid "unable to dequote value of '%s'"
+msgstr "无法为 '%s' 的值去引号"
 
-#: wt-status.c:1271
-msgid "No commands remaining."
-msgstr "未剩下任何命令。"
-
-#: wt-status.c:1274
+#: sequencer.c:792 wrapper.c:190 wrapper.c:360 builtin/am.c:705
+#: builtin/am.c:797 builtin/merge.c:1114 builtin/rebase.c:1074
 #, c-format
-msgid "Next command to do (%d remaining command):"
-msgid_plural "Next commands to do (%d remaining commands):"
-msgstr[0] "接下来要执行的命令（剩余 %d 条命令）："
-msgstr[1] "接下来要执行的命令（剩余 %d 条命令）："
+msgid "could not open '%s' for reading"
+msgstr "无法打开 '%s' 进行读取"
 
-#  译者：注意保持前导空格
-#: wt-status.c:1282
-msgid "  (use \"git rebase --edit-todo\" to view and edit)"
-msgstr "  （使用 \"git rebase --edit-todo\" 来查看和编辑）"
+#: sequencer.c:802
+msgid "'GIT_AUTHOR_NAME' already given"
+msgstr "已经给出 'GIT_AUTHOR_NAME'"
 
-#: wt-status.c:1295
-#, c-format
-msgid "You are currently rebasing branch '%s' on '%s'."
-msgstr "您在执行将分支 '%s' 变基到 '%s' 的操作。"
+#: sequencer.c:807
+msgid "'GIT_AUTHOR_EMAIL' already given"
+msgstr "已经给出 'GIT_AUTHOR_EMAIL'"
 
-#: wt-status.c:1300
-msgid "You are currently rebasing."
-msgstr "您在执行变基操作。"
+#: sequencer.c:812
+msgid "'GIT_AUTHOR_DATE' already given"
+msgstr "已经给出 'GIT_AUTHOR_DATE'"
 
-#  译者：注意保持前导空格
-#: wt-status.c:1314
-msgid "  (fix conflicts and then run \"git rebase --continue\")"
-msgstr "  （解决冲突，然后运行 \"git rebase --continue\"）"
+#: sequencer.c:816
+#, c-format
+msgid "unknown variable '%s'"
+msgstr "未知变量 '%s'"
 
-#  译者：注意保持前导空格
-#: wt-status.c:1316
-msgid "  (use \"git rebase --skip\" to skip this patch)"
-msgstr "  （使用 \"git rebase --skip\" 跳过此补丁）"
+#: sequencer.c:821
+msgid "missing 'GIT_AUTHOR_NAME'"
+msgstr "缺少 'GIT_AUTHOR_NAME'"
 
-#  译者：注意保持前导空格
-#: wt-status.c:1318
-msgid "  (use \"git rebase --abort\" to check out the original branch)"
-msgstr "  （使用 \"git rebase --abort\" 以检出原有分支）"
+#: sequencer.c:823
+msgid "missing 'GIT_AUTHOR_EMAIL'"
+msgstr "缺少 'GIT_AUTHOR_EMAIL'"
 
-#  译者：注意保持前导空格
-#: wt-status.c:1324
-msgid "  (all conflicts fixed: run \"git rebase --continue\")"
-msgstr "  （所有冲突已解决：运行 \"git rebase --continue\"）"
+#: sequencer.c:825
+msgid "missing 'GIT_AUTHOR_DATE'"
+msgstr "缺少 'GIT_AUTHOR_DATE'"
+
+#: sequencer.c:902 sequencer.c:1427
+msgid "malformed ident line"
+msgstr "错误的身份信息"
 
-#: wt-status.c:1328
+#: sequencer.c:925
 #, c-format
 msgid ""
-"You are currently splitting a commit while rebasing branch '%s' on '%s'."
-msgstr "您在执行将分支 '%s' 变基到 '%s' 的操作时拆分提交。"
+"you have staged changes in your working tree\n"
+"If these changes are meant to be squashed into the previous commit, run:\n"
+"\n"
+"  git commit --amend %s\n"
+"\n"
+"If they are meant to go into a new commit, run:\n"
+"\n"
+"  git commit %s\n"
+"\n"
+"In both cases, once you're done, continue with:\n"
+"\n"
+"  git rebase --continue\n"
+msgstr ""
+"您的工作区中存在已暂存的修改\n"
+"如果这些修改需要被并入前一个提交，执行：\n"
+"\n"
+"  git commit --amend %s\n"
+"\n"
+"如果这些修改要形成一个新提交，执行：\n"
+"\n"
+"  git commit %s\n"
+"\n"
+"无论哪种情况，当您完成提交，继续执行：\n"
+"\n"
+"  git rebase --continue\n"
 
-#: wt-status.c:1333
-msgid "You are currently splitting a commit during a rebase."
-msgstr "您在执行变基操作时拆分提交。"
+#: sequencer.c:1218
+msgid "'prepare-commit-msg' hook failed"
+msgstr "'prepare-commit-msg' 钩子失败"
 
-#  译者：注意保持前导空格
-#: wt-status.c:1336
-msgid "  (Once your working directory is clean, run \"git rebase --continue\")"
-msgstr "  （一旦您工作目录提交干净后，运行 \"git rebase --continue\"）"
+#: sequencer.c:1224
+msgid ""
+"Your name and email address were configured automatically based\n"
+"on your username and hostname. Please check that they are accurate.\n"
+"You can suppress this message by setting them explicitly. Run the\n"
+"following command and follow the instructions in your editor to edit\n"
+"your configuration file:\n"
+"\n"
+"    git config --global --edit\n"
+"\n"
+"After doing this, you may fix the identity used for this commit with:\n"
+"\n"
+"    git commit --amend --reset-author\n"
+msgstr ""
+"您的姓名和邮件地址基于登录名和主机名进行了自动设置。请检查它们正确\n"
+"与否。您可以对其进行设置以免再出现本提示信息。运行如下命令在编辑器\n"
+"中编辑您的配置文件：\n"
+"\n"
+"    git config --global --edit\n"
+"\n"
+"设置完毕后，您可以用下面的命令来修正本次提交所使用的用户身份：\n"
+"\n"
+"    git commit --amend --reset-author\n"
+
+#: sequencer.c:1237
+msgid ""
+"Your name and email address were configured automatically based\n"
+"on your username and hostname. Please check that they are accurate.\n"
+"You can suppress this message by setting them explicitly:\n"
+"\n"
+"    git config --global user.name \"Your Name\"\n"
+"    git config --global user.email you@example.com\n"
+"\n"
+"After doing this, you may fix the identity used for this commit with:\n"
+"\n"
+"    git commit --amend --reset-author\n"
+msgstr ""
+"您的姓名和邮件地址基于登录名和主机名进行了自动设置。请检查它们正确\n"
+"与否。您可以对其进行设置以免再出现本提示信息：\n"
+"\n"
+"    git config --global user.name \"Your Name\"\n"
+"    git config --global user.email you@example.com\n"
+"\n"
+"设置完毕后，您可以用下面的命令来修正本次提交所使用的用户身份：\n"
+"\n"
+"    git commit --amend --reset-author\n"
+
+#: sequencer.c:1279
+msgid "couldn't look up newly created commit"
+msgstr "无法找到新创建的提交"
+
+#: sequencer.c:1281
+msgid "could not parse newly created commit"
+msgstr "不能解析新创建的提交"
+
+#: sequencer.c:1327
+msgid "unable to resolve HEAD after creating commit"
+msgstr "创建提交后，不能解析 HEAD"
+
+#: sequencer.c:1329
+msgid "detached HEAD"
+msgstr "分离头指针"
+
+#  译者：中文字符串拼接，可删除前导空格
+#: sequencer.c:1333
+msgid " (root-commit)"
+msgstr "（根提交）"
+
+#: sequencer.c:1354
+msgid "could not parse HEAD"
+msgstr "不能解析 HEAD"
+
+#: sequencer.c:1356
+#, c-format
+msgid "HEAD %s is not a commit!"
+msgstr "HEAD %s 不是一个提交！"
+
+#: sequencer.c:1360 sequencer.c:1458 builtin/commit.c:1569
+msgid "could not parse HEAD commit"
+msgstr "不能解析 HEAD 提交"
+
+#: sequencer.c:1411 sequencer.c:2055
+msgid "unable to parse commit author"
+msgstr "不能解析提交作者"
+
+#: sequencer.c:1431
+msgid "corrupted author without date information"
+msgstr "损坏的没有日期的作者信息"
+
+#: sequencer.c:1447 builtin/am.c:1561 builtin/merge.c:684
+msgid "git write-tree failed to write a tree"
+msgstr "git write-tree 无法写入树对象"
+
+#: sequencer.c:1480 sequencer.c:1550
+#, c-format
+msgid "unable to read commit message from '%s'"
+msgstr "不能从 '%s' 读取提交说明"
+
+#: sequencer.c:1516 builtin/am.c:1583 builtin/commit.c:1668 builtin/merge.c:883
+#: builtin/merge.c:908
+msgid "failed to write commit object"
+msgstr "写提交对象失败"
+
+#: sequencer.c:1577
+#, c-format
+msgid "could not parse commit %s"
+msgstr "不能解析提交 %s"
+
+#: sequencer.c:1582
+#, c-format
+msgid "could not parse parent commit %s"
+msgstr "不能解析父提交 %s"
+
+#: sequencer.c:1656 sequencer.c:1767
+#, c-format
+msgid "unknown command: %d"
+msgstr "未知命令：%d"
+
+#: sequencer.c:1714 sequencer.c:1739
+#, c-format
+msgid "This is a combination of %d commits."
+msgstr "这是一个 %d 个提交的组合。"
+
+#: sequencer.c:1724
+msgid "need a HEAD to fixup"
+msgstr "需要一个 HEAD 来修复"
+
+#: sequencer.c:1726 sequencer.c:3304
+msgid "could not read HEAD"
+msgstr "不能读取 HEAD"
+
+#: sequencer.c:1728
+msgid "could not read HEAD's commit message"
+msgstr "不能读取 HEAD 的提交说明"
+
+#: sequencer.c:1734
+#, c-format
+msgid "cannot write '%s'"
+msgstr "不能写 '%s'"
+
+#: sequencer.c:1741 git-rebase--preserve-merges.sh:496
+msgid "This is the 1st commit message:"
+msgstr "这是第一个提交说明："
+
+#: sequencer.c:1749
+#, c-format
+msgid "could not read commit message of %s"
+msgstr "不能读取 %s 的提交说明"
+
+#: sequencer.c:1756
+#, c-format
+msgid "This is the commit message #%d:"
+msgstr "这是提交说明 #%d："
+
+#: sequencer.c:1762
+#, c-format
+msgid "The commit message #%d will be skipped:"
+msgstr "提交说明 #%d 将被跳过："
+
+#: sequencer.c:1850
+msgid "your index file is unmerged."
+msgstr "您的索引文件未完成合并。"
+
+#: sequencer.c:1857
+msgid "cannot fixup root commit"
+msgstr "不能修复根提交"
+
+#: sequencer.c:1876
+#, c-format
+msgid "commit %s is a merge but no -m option was given."
+msgstr "提交 %s 是一个合并提交但未提供 -m 选项。"
+
+#: sequencer.c:1884 sequencer.c:1892
+#, c-format
+msgid "commit %s does not have parent %d"
+msgstr "提交 %s 没有第 %d 个父提交"
+
+#: sequencer.c:1898
+#, c-format
+msgid "cannot get commit message for %s"
+msgstr "不能得到 %s 的提交说明"
+
+#. TRANSLATORS: The first %s will be a "todo" command like
+#. "revert" or "pick", the second %s a SHA1.
+#: sequencer.c:1917
+#, c-format
+msgid "%s: cannot parse parent commit %s"
+msgstr "%s：不能解析父提交 %s"
+
+#: sequencer.c:1982
+#, c-format
+msgid "could not rename '%s' to '%s'"
+msgstr "不能将 '%s' 重命名为 '%s'"
+
+#: sequencer.c:2037
+#, c-format
+msgid "could not revert %s... %s"
+msgstr "不能还原 %s... %s"
+
+#: sequencer.c:2038
+#, c-format
+msgid "could not apply %s... %s"
+msgstr "不能应用 %s... %s"
+
+#: sequencer.c:2105
+#, c-format
+msgid "git %s: failed to read the index"
+msgstr "git %s：无法读取索引"
+
+#: sequencer.c:2112
+#, c-format
+msgid "git %s: failed to refresh the index"
+msgstr "git %s：无法刷新索引"
+
+#: sequencer.c:2189
+#, c-format
+msgid "%s does not accept arguments: '%s'"
+msgstr "%s 不接受参数：'%s'"
+
+#: sequencer.c:2198
+#, c-format
+msgid "missing arguments for %s"
+msgstr "缺少 %s 的参数"
+
+#: sequencer.c:2235
+#, c-format
+msgid "could not parse '%.*s'"
+msgstr "无法解析 '%.*s'"
+
+#: sequencer.c:2289
+#, c-format
+msgid "invalid line %d: %.*s"
+msgstr "无效行 %d：%.*s"
+
+#: sequencer.c:2300
+#, c-format
+msgid "cannot '%s' without a previous commit"
+msgstr "没有父提交的情况下不能 '%s'"
+
+#: sequencer.c:2348 builtin/rebase.c:172 builtin/rebase.c:197
+#: builtin/rebase.c:223 builtin/rebase.c:248
+#, c-format
+msgid "could not read '%s'."
+msgstr "不能读取 '%s'。"
+
+#: sequencer.c:2384
+msgid "cancelling a cherry picking in progress"
+msgstr "正在取消一个进行中的拣选"
+
+#: sequencer.c:2391
+msgid "cancelling a revert in progress"
+msgstr "正在取消一个进行中的还原"
+
+#: sequencer.c:2435
+msgid "please fix this using 'git rebase --edit-todo'."
+msgstr "请用 'git rebase --edit-todo' 来修改。"
+
+#: sequencer.c:2437
+#, c-format
+msgid "unusable instruction sheet: '%s'"
+msgstr "不可用的指令清单：'%s'"
+
+#: sequencer.c:2442
+msgid "no commits parsed."
+msgstr "没有解析提交。"
+
+#: sequencer.c:2453
+msgid "cannot cherry-pick during a revert."
+msgstr "不能在回退中执行拣选。"
+
+#: sequencer.c:2455
+msgid "cannot revert during a cherry-pick."
+msgstr "不能在拣选中执行回退。"
+
+#: sequencer.c:2533
+#, c-format
+msgid "invalid value for %s: %s"
+msgstr "%s 的值无效：%s"
+
+#: sequencer.c:2630
+msgid "unusable squash-onto"
+msgstr "不可用的 squash-onto"
+
+#: sequencer.c:2646
+#, c-format
+msgid "malformed options sheet: '%s'"
+msgstr "格式错误的选项清单：'%s'"
+
+#: sequencer.c:2736 sequencer.c:4463
+msgid "empty commit set passed"
+msgstr "提供了空的提交集"
+
+#: sequencer.c:2752
+msgid "revert is already in progress"
+msgstr "一个还原操作已在进行"
+
+#: sequencer.c:2754
+#, c-format
+msgid "try \"git revert (--continue | %s--abort | --quit)\""
+msgstr "尝试 \"git revert (--continue | %s--abort | --quit)\""
+
+#: sequencer.c:2757
+msgid "cherry-pick is already in progress"
+msgstr "拣选操作已在进行"
+
+#: sequencer.c:2759
+#, c-format
+msgid "try \"git cherry-pick (--continue | %s--abort | --quit)\""
+msgstr "尝试 \"git cherry-pick (--continue | %s--abort | --quit)\""
+
+#: sequencer.c:2773
+#, c-format
+msgid "could not create sequencer directory '%s'"
+msgstr "不能创建序列目录 '%s'"
+
+#: sequencer.c:2788
+msgid "could not lock HEAD"
+msgstr "不能锁定 HEAD"
+
+#: sequencer.c:2848 sequencer.c:4209
+msgid "no cherry-pick or revert in progress"
+msgstr "拣选或还原操作并未进行"
+
+#: sequencer.c:2850 sequencer.c:2861
+msgid "cannot resolve HEAD"
+msgstr "不能解析 HEAD"
+
+#: sequencer.c:2852 sequencer.c:2896
+msgid "cannot abort from a branch yet to be born"
+msgstr "不能从尚未建立的分支终止"
+
+#: sequencer.c:2882 builtin/grep.c:736
+#, c-format
+msgid "cannot open '%s'"
+msgstr "不能打开 '%s'"
+
+#: sequencer.c:2884
+#, c-format
+msgid "cannot read '%s': %s"
+msgstr "不能读取 '%s'：%s"
+
+#: sequencer.c:2885
+msgid "unexpected end of file"
+msgstr "意外的文件结束"
+
+#: sequencer.c:2891
+#, c-format
+msgid "stored pre-cherry-pick HEAD file '%s' is corrupt"
+msgstr "保存拣选提交前的 HEAD 文件 '%s' 损坏"
+
+#: sequencer.c:2902
+msgid "You seem to have moved HEAD. Not rewinding, check your HEAD!"
+msgstr "您好像移动了 HEAD。未能回退，检查您的 HEAD！"
+
+#: sequencer.c:2943
+msgid "no revert in progress"
+msgstr "没有正在进行的还原"
+
+#: sequencer.c:2951
+msgid "no cherry-pick in progress"
+msgstr "没有正在进行的拣选"
+
+#: sequencer.c:2961
+msgid "failed to skip the commit"
+msgstr "无法跳过这个提交"
+
+#: sequencer.c:2968
+msgid "there is nothing to skip"
+msgstr "没有要跳过的"
+
+#: sequencer.c:2971
+#, c-format
+msgid ""
+"have you committed already?\n"
+"try \"git %s --continue\""
+msgstr ""
+"您已经提交了么？\n"
+"试试 \"git %s --continue\""
+
+#: sequencer.c:3095 sequencer.c:4121
+#, c-format
+msgid "could not update %s"
+msgstr "不能更新 %s"
+
+#: sequencer.c:3134 sequencer.c:4101
+msgid "cannot read HEAD"
+msgstr "不能读取 HEAD"
+
+#: sequencer.c:3151
+#, c-format
+msgid "unable to copy '%s' to '%s'"
+msgstr "无法拷贝 '%s' 至 '%s'"
+
+#: sequencer.c:3159
+#, c-format
+msgid ""
+"You can amend the commit now, with\n"
+"\n"
+"  git commit --amend %s\n"
+"\n"
+"Once you are satisfied with your changes, run\n"
+"\n"
+"  git rebase --continue\n"
+msgstr ""
+"您现在可以修补这个提交，使用\n"
+"\n"
+"  git commit --amend %s\n"
+"\n"
+"当您对变更感到满意，执行\n"
+"\n"
+"  git rebase --continue\n"
+
+#: sequencer.c:3169
+#, c-format
+msgid "Could not apply %s... %.*s"
+msgstr "不能应用 %s... %.*s"
+
+#: sequencer.c:3176
+#, c-format
+msgid "Could not merge %.*s"
+msgstr "不能合并 %.*s"
+
+#: sequencer.c:3190 sequencer.c:3194 builtin/difftool.c:641
+#, c-format
+msgid "could not copy '%s' to '%s'"
+msgstr "不能拷贝 '%s' 至 '%s'"
+
+#  译者：注意保持前导空格
+#: sequencer.c:3221
+#, c-format
+msgid ""
+"execution failed: %s\n"
+"%sYou can fix the problem, and then run\n"
+"\n"
+"  git rebase --continue\n"
+"\n"
+msgstr ""
+"执行失败：%s\n"
+"%s您可以改正该问题，然后运行\n"
+"\n"
+"  git rebase --continue\n"
+"\n"
+
+#: sequencer.c:3227
+msgid "and made changes to the index and/or the working tree\n"
+msgstr "并且修改索引和/或工作区\n"
+
+#: sequencer.c:3233
+#, c-format
+msgid ""
+"execution succeeded: %s\n"
+"but left changes to the index and/or the working tree\n"
+"Commit or stash your changes, and then run\n"
+"\n"
+"  git rebase --continue\n"
+"\n"
+msgstr ""
+"执行成功：%s\n"
+"但是在索引和/或工作区中存在变更\n"
+"提交或贮藏修改，然后运行\n"
+"\n"
+"  git rebase --continue\n"
+"\n"
+
+#: sequencer.c:3294
+#, c-format
+msgid "illegal label name: '%.*s'"
+msgstr "非法的标签名称：'%.*s'"
+
+#: sequencer.c:3348
+msgid "writing fake root commit"
+msgstr "写伪根提交"
+
+#: sequencer.c:3353
+msgid "writing squash-onto"
+msgstr "写入 squash-onto"
+
+#: sequencer.c:3391 builtin/rebase.c:876 builtin/rebase.c:882
+#, c-format
+msgid "failed to find tree of %s"
+msgstr "无法找到 %s 指向的树。"
+
+#: sequencer.c:3436
+#, c-format
+msgid "could not resolve '%s'"
+msgstr "无法解析 '%s'"
+
+#: sequencer.c:3467
+msgid "cannot merge without a current revision"
+msgstr "没有当前版本不能合并"
+
+#: sequencer.c:3489
+#, c-format
+msgid "unable to parse '%.*s'"
+msgstr "无法解析 '%.*s'"
+
+#: sequencer.c:3498
+#, c-format
+msgid "nothing to merge: '%.*s'"
+msgstr "无可用合并：'%.*s'"
+
+#: sequencer.c:3510
+msgid "octopus merge cannot be executed on top of a [new root]"
+msgstr "章鱼合并不能在一个新的根提交上执行"
+
+#: sequencer.c:3526
+#, c-format
+msgid "could not get commit message of '%s'"
+msgstr "不能获取 '%s' 的提交说明"
+
+#: sequencer.c:3688
+#, c-format
+msgid "could not even attempt to merge '%.*s'"
+msgstr "甚至不能尝试合并 '%.*s'"
+
+#: sequencer.c:3704
+msgid "merge: Unable to write new index file"
+msgstr "合并：无法写入新索引文件"
+
+#: sequencer.c:3773 builtin/rebase.c:733
+#, c-format
+msgid "Applied autostash.\n"
+msgstr "已应用 autostash。\n"
+
+#: sequencer.c:3785
+#, c-format
+msgid "cannot store %s"
+msgstr "不能存储 %s"
+
+#: sequencer.c:3788 builtin/rebase.c:749 git-rebase--preserve-merges.sh:113
+#, c-format
+msgid ""
+"Applying autostash resulted in conflicts.\n"
+"Your changes are safe in the stash.\n"
+"You can run \"git stash pop\" or \"git stash drop\" at any time.\n"
+msgstr ""
+"应用 autostash 导致冲突。\n"
+"您的修改安全地保存在贮藏区中。\n"
+"您可以在任何时候运行 \"git stash pop\" 或 \"git stash drop\"。\n"
+
+#: sequencer.c:3849
+#, c-format
+msgid "could not checkout %s"
+msgstr "不能检出 %s"
+
+#: sequencer.c:3863
+#, c-format
+msgid "%s: not a valid OID"
+msgstr "%s：不是一个有效的对象 ID"
+
+#: sequencer.c:3868 git-rebase--preserve-merges.sh:779
+msgid "could not detach HEAD"
+msgstr "不能分离头指针"
+
+#: sequencer.c:3883
+#, c-format
+msgid "Stopped at HEAD\n"
+msgstr "停止在 HEAD\n"
+
+#: sequencer.c:3885
+#, c-format
+msgid "Stopped at %s\n"
+msgstr "停止在 %s\n"
+
+#: sequencer.c:3893
+#, c-format
+msgid ""
+"Could not execute the todo command\n"
+"\n"
+"    %.*s\n"
+"It has been rescheduled; To edit the command before continuing, please\n"
+"edit the todo list first:\n"
+"\n"
+"    git rebase --edit-todo\n"
+"    git rebase --continue\n"
+msgstr ""
+"无法执行待办命令\n"
+"\n"
+"    %.*s\n"
+"已被重新安排，在继续之前编辑命令，请先编辑待办列表：\n"
+"\n"
+"    git rebase --edit-todo\n"
+"    git rebase --continue\n"
+
+#: sequencer.c:3979
+#, c-format
+msgid "Stopped at %s...  %.*s\n"
+msgstr "停止在 %s... %.*s\n"
+
+#: sequencer.c:4050
+#, c-format
+msgid "unknown command %d"
+msgstr "未知命令 %d"
+
+#: sequencer.c:4109
+msgid "could not read orig-head"
+msgstr "不能读取 orig-head"
+
+#: sequencer.c:4114
+msgid "could not read 'onto'"
+msgstr "不能读取 'onto'"
+
+#: sequencer.c:4128
+#, c-format
+msgid "could not update HEAD to %s"
+msgstr "不能更新 HEAD 为 %s"
+
+#: sequencer.c:4221
+msgid "cannot rebase: You have unstaged changes."
+msgstr "不能变基：您有未暂存的变更。"
+
+#: sequencer.c:4230
+msgid "cannot amend non-existing commit"
+msgstr "不能修补不存在的提交"
+
+#: sequencer.c:4232
+#, c-format
+msgid "invalid file: '%s'"
+msgstr "无效文件：'%s'"
+
+#: sequencer.c:4234
+#, c-format
+msgid "invalid contents: '%s'"
+msgstr "无效内容：'%s'"
+
+#: sequencer.c:4237
+msgid ""
+"\n"
+"You have uncommitted changes in your working tree. Please, commit them\n"
+"first and then run 'git rebase --continue' again."
+msgstr ""
+"\n"
+"您的工作区中有未提交的变更。请先提交然后再次运行 'git rebase --continue'。"
+
+#: sequencer.c:4273 sequencer.c:4312
+#, c-format
+msgid "could not write file: '%s'"
+msgstr "不能写入文件：'%s'"
+
+#: sequencer.c:4327
+msgid "could not remove CHERRY_PICK_HEAD"
+msgstr "不能删除 CHERRY_PICK_HEAD"
+
+#: sequencer.c:4334
+msgid "could not commit staged changes."
+msgstr "不能提交暂存的修改。"
+
+#: sequencer.c:4440
+#, c-format
+msgid "%s: can't cherry-pick a %s"
+msgstr "%s：不能拣选一个%s"
+
+#: sequencer.c:4444
+#, c-format
+msgid "%s: bad revision"
+msgstr "%s：错误的版本"
+
+#: sequencer.c:4479
+msgid "can't revert as initial commit"
+msgstr "不能作为初始提交回退"
+
+#: sequencer.c:4952
+msgid "make_script: unhandled options"
+msgstr "make_script：有未能处理的选项"
+
+#: sequencer.c:4955
+msgid "make_script: error preparing revisions"
+msgstr "make_script：准备版本时错误"
+
+#: sequencer.c:5113
+msgid ""
+"You can fix this with 'git rebase --edit-todo' and then run 'git rebase --"
+"continue'.\n"
+"Or you can abort the rebase with 'git rebase --abort'.\n"
+msgstr ""
+"您可以用 'git rebase --edit-todo' 修正，然后执行 'git rebase --continue'。\n"
+"或者您可以用 'git rebase --abort' 终止变基。\n"
+
+#: sequencer.c:5226 sequencer.c:5243
+msgid "nothing to do"
+msgstr "无事可做"
+
+#: sequencer.c:5257
+msgid "could not skip unnecessary pick commands"
+msgstr "无法跳过不必要的拣选"
+
+#: sequencer.c:5351
+msgid "the script was already rearranged."
+msgstr "脚本已经重新编排。"
+
+#: setup.c:124
+#, c-format
+msgid "'%s' is outside repository"
+msgstr "'%s' 在仓库之外"
+
+#: setup.c:174
+#, c-format
+msgid ""
+"%s: no such path in the working tree.\n"
+"Use 'git <command> -- <path>...' to specify paths that do not exist locally."
+msgstr ""
+"%s：工作区中无此路径。\n"
+"使用命令 'git <命令> -- <路径>...' 来指定本地不存在的路径。"
+
+#: setup.c:187
+#, c-format
+msgid ""
+"ambiguous argument '%s': unknown revision or path not in the working tree.\n"
+"Use '--' to separate paths from revisions, like this:\n"
+"'git <command> [<revision>...] -- [<file>...]'"
+msgstr ""
+"有歧义的参数 '%s'：未知的版本或路径不存在于工作区中。\n"
+"使用 '--' 来分隔版本和路径，例如：\n"
+"'git <命令> [<版本>...] -- [<文件>...]'"
+
+#: setup.c:236
+#, c-format
+msgid "option '%s' must come before non-option arguments"
+msgstr "选项 '%s' 必须在其他非选项参数之前"
+
+#: setup.c:255
+#, c-format
+msgid ""
+"ambiguous argument '%s': both revision and filename\n"
+"Use '--' to separate paths from revisions, like this:\n"
+"'git <command> [<revision>...] -- [<file>...]'"
+msgstr ""
+"有歧义的参数 '%s'：可同时是版本和文件\n"
+"使用 '--' 来分隔版本和路径，例如：\n"
+"'git <命令> [<版本>...] -- [<文件>...]'"
+
+#: setup.c:391
+msgid "unable to set up work tree using invalid config"
+msgstr "无法使用无效配置来创建工作区"
+
+#: setup.c:395
+msgid "this operation must be run in a work tree"
+msgstr "该操作必须在一个工作区中运行"
+
+#: setup.c:541
+#, c-format
+msgid "Expected git repo version <= %d, found %d"
+msgstr "期望 git 仓库版本 <= %d，却得到 %d"
+
+#: setup.c:549
+msgid "unknown repository extensions found:"
+msgstr "发现未知的仓库扩展："
+
+#: setup.c:568
+#, c-format
+msgid "error opening '%s'"
+msgstr "打开 '%s' 出错"
+
+#: setup.c:570
+#, c-format
+msgid "too large to be a .git file: '%s'"
+msgstr "文件太大，无法作为 .git 文件：'%s'"
+
+#: setup.c:572
+#, c-format
+msgid "error reading %s"
+msgstr "读取 %s 出错"
+
+#: setup.c:574
+#, c-format
+msgid "invalid gitfile format: %s"
+msgstr "无效的 gitfile 格式：%s"
+
+#: setup.c:576
+#, c-format
+msgid "no path in gitfile: %s"
+msgstr "在 gitfile 中没有路径：%s"
+
+#: setup.c:578
+#, c-format
+msgid "not a git repository: %s"
+msgstr "不是一个 git 仓库：%s"
+
+#: setup.c:677
+#, c-format
+msgid "'$%s' too big"
+msgstr "'$%s' 太大"
+
+#: setup.c:691
+#, c-format
+msgid "not a git repository: '%s'"
+msgstr "不是一个 git 仓库：'%s'"
+
+#: setup.c:720 setup.c:722 setup.c:753
+#, c-format
+msgid "cannot chdir to '%s'"
+msgstr "不能切换目录到 '%s'"
+
+#: setup.c:725 setup.c:781 setup.c:791 setup.c:830 setup.c:838
+msgid "cannot come back to cwd"
+msgstr "无法返回当前工作目录"
+
+#: setup.c:852
+#, c-format
+msgid "failed to stat '%*s%s%s'"
+msgstr "获取 '%*s%s%s' 状态（stat）失败"
+
+#: setup.c:1090
+msgid "Unable to read current working directory"
+msgstr "不能读取当前工作目录"
+
+#: setup.c:1099 setup.c:1105
+#, c-format
+msgid "cannot change to '%s'"
+msgstr "不能切换到 '%s'"
+
+#: setup.c:1110
+#, c-format
+msgid "not a git repository (or any of the parent directories): %s"
+msgstr "不是一个 git 仓库（或者任何父目录）：%s"
+
+#: setup.c:1116
+#, c-format
+msgid ""
+"not a git repository (or any parent up to mount point %s)\n"
+"Stopping at filesystem boundary (GIT_DISCOVERY_ACROSS_FILESYSTEM not set)."
+msgstr ""
+"不是一个 git 仓库（或者直至挂载点 %s 的任何父目录）\n"
+"停止在文件系统边界（未设置 GIT_DISCOVERY_ACROSS_FILESYSTEM）。"
+
+#: setup.c:1227
+#, c-format
+msgid ""
+"problem with core.sharedRepository filemode value (0%.3o).\n"
+"The owner of files must always have read and write permissions."
+msgstr ""
+"参数 core.sharedRepository 的文件属性值有问题（0%.3o）。\n"
+"文件属主必须始终拥有读写权限。"
+
+#: setup.c:1271
+msgid "open /dev/null or dup failed"
+msgstr "不能打开或者复制 /dev/null"
+
+#: setup.c:1286
+msgid "fork failed"
+msgstr "fork 失败"
+
+#: setup.c:1291
+msgid "setsid failed"
+msgstr "setsid 失败"
+
+#: sha1-file.c:452
+#, c-format
+msgid "object directory %s does not exist; check .git/objects/info/alternates"
+msgstr "对象目录 %s 不存在，检查 .git/objects/info/alternates"
+
+#: sha1-file.c:503
+#, c-format
+msgid "unable to normalize alternate object path: %s"
+msgstr "无法规范化备用对象路径：%s"
+
+#: sha1-file.c:575
+#, c-format
+msgid "%s: ignoring alternate object stores, nesting too deep"
+msgstr "%s：忽略备用对象库，嵌套太深"
+
+#: sha1-file.c:582
+#, c-format
+msgid "unable to normalize object directory: %s"
+msgstr "无法规范化对象目录: %s"
+
+#: sha1-file.c:625
+msgid "unable to fdopen alternates lockfile"
+msgstr "无法 fdopen 替换锁文件"
+
+#: sha1-file.c:643
+msgid "unable to read alternates file"
+msgstr "无法读取替代文件"
+
+#: sha1-file.c:650
+msgid "unable to move new alternates file into place"
+msgstr "无法将新的替代文件移动到位"
+
+#: sha1-file.c:685
+#, c-format
+msgid "path '%s' does not exist"
+msgstr "路径 '%s' 不存在"
+
+#: sha1-file.c:711
+#, c-format
+msgid "reference repository '%s' as a linked checkout is not supported yet."
+msgstr "尚不支持将参考仓库 '%s' 作为一个链接检出。"
+
+#: sha1-file.c:717
+#, c-format
+msgid "reference repository '%s' is not a local repository."
+msgstr "参考仓库 '%s' 不是一个本地仓库。"
+
+#: sha1-file.c:723
+#, c-format
+msgid "reference repository '%s' is shallow"
+msgstr "参考仓库 '%s' 是一个浅克隆"
+
+#: sha1-file.c:731
+#, c-format
+msgid "reference repository '%s' is grafted"
+msgstr "参考仓库 '%s' 已被移植"
+
+#: sha1-file.c:791
+#, c-format
+msgid "invalid line while parsing alternate refs: %s"
+msgstr "解析备用引用时无效的行：%s"
+
+#: sha1-file.c:943
+#, c-format
+msgid "attempting to mmap %<PRIuMAX> over limit %<PRIuMAX>"
+msgstr "尝试 mmap %<PRIuMAX>，超过了最大值 %<PRIuMAX>"
+
+#: sha1-file.c:964
+msgid "mmap failed"
+msgstr "mmap 失败"
+
+#: sha1-file.c:1128
+#, c-format
+msgid "object file %s is empty"
+msgstr "对象文件 %s 为空"
+
+#: sha1-file.c:1252 sha1-file.c:2392
+#, c-format
+msgid "corrupt loose object '%s'"
+msgstr "损坏的松散对象 '%s'"
+
+#: sha1-file.c:1254 sha1-file.c:2396
+#, c-format
+msgid "garbage at end of loose object '%s'"
+msgstr "松散对象 '%s' 后面有垃圾数据"
+
+#: sha1-file.c:1296
+msgid "invalid object type"
+msgstr "无效的对象类型"
+
+#: sha1-file.c:1380
+#, c-format
+msgid "unable to unpack %s header with --allow-unknown-type"
+msgstr "无法用 --allow-unknown-type 参数解开 %s 头信息"
+
+#: sha1-file.c:1383
+#, c-format
+msgid "unable to unpack %s header"
+msgstr "无法解开 %s 头部"
+
+#: sha1-file.c:1389
+#, c-format
+msgid "unable to parse %s header with --allow-unknown-type"
+msgstr "无法用 --allow-unknown-type 参数解析 %s 头信息"
+
+#: sha1-file.c:1392
+#, c-format
+msgid "unable to parse %s header"
+msgstr "无法解析 %s 头部"
+
+#: sha1-file.c:1584
+#, c-format
+msgid "failed to read object %s"
+msgstr "读取对象 %s 失败"
+
+#: sha1-file.c:1588
+#, c-format
+msgid "replacement %s not found for %s"
+msgstr "找不到 %2$s 的替代 %1$s"
+
+#: sha1-file.c:1592
+#, c-format
+msgid "loose object %s (stored in %s) is corrupt"
+msgstr "松散对象 %s（保存在 %s）已损坏"
+
+#: sha1-file.c:1596
+#, c-format
+msgid "packed object %s (stored in %s) is corrupt"
+msgstr "打包对象 %s（保存在 %s）已损坏"
+
+#: sha1-file.c:1699
+#, c-format
+msgid "unable to write file %s"
+msgstr "无法写文件 %s"
+
+#: sha1-file.c:1706
+#, c-format
+msgid "unable to set permission to '%s'"
+msgstr "无法为 '%s' 设置权限"
+
+#: sha1-file.c:1713
+msgid "file write error"
+msgstr "文件写错误"
+
+#: sha1-file.c:1732
+msgid "error when closing loose object file"
+msgstr "关闭松散对象文件时出错"
+
+#: sha1-file.c:1797
+#, c-format
+msgid "insufficient permission for adding an object to repository database %s"
+msgstr "权限不足，无法在仓库对象库 %s 中添加对象"
+
+#: sha1-file.c:1799
+msgid "unable to create temporary file"
+msgstr "无法创建临时文件"
+
+#: sha1-file.c:1823
+msgid "unable to write loose object file"
+msgstr "不能写松散对象文件"
+
+#: sha1-file.c:1829
+#, c-format
+msgid "unable to deflate new object %s (%d)"
+msgstr "不能压缩新对象 %s（%d）"
+
+#: sha1-file.c:1833
+#, c-format
+msgid "deflateEnd on object %s failed (%d)"
+msgstr "在对象 %s 上调用 deflateEnd 失败（%d）"
+
+#: sha1-file.c:1837
+#, c-format
+msgid "confused by unstable object source data for %s"
+msgstr "被 %s 的不稳定对象源数据搞糊涂了"
+
+#: sha1-file.c:1847 builtin/pack-objects.c:925
+#, c-format
+msgid "failed utime() on %s"
+msgstr "在 %s 上调用 utime() 失败"
+
+#: sha1-file.c:1922
+#, c-format
+msgid "cannot read object for %s"
+msgstr "不能读取对象 %s"
+
+#: sha1-file.c:1962
+msgid "corrupt commit"
+msgstr "损坏的提交"
+
+#: sha1-file.c:1970
+msgid "corrupt tag"
+msgstr "损坏的标签"
+
+#: sha1-file.c:2069
+#, c-format
+msgid "read error while indexing %s"
+msgstr "索引 %s 时读取错误"
+
+#: sha1-file.c:2072
+#, c-format
+msgid "short read while indexing %s"
+msgstr "索引 %s 时读入不完整"
+
+#: sha1-file.c:2145 sha1-file.c:2154
+#, c-format
+msgid "%s: failed to insert into database"
+msgstr "%s：插入数据库失败"
+
+#: sha1-file.c:2160
+#, c-format
+msgid "%s: unsupported file type"
+msgstr "%s：不支持的文件类型"
+
+#: sha1-file.c:2184
+#, c-format
+msgid "%s is not a valid object"
+msgstr "%s 不是一个有效的对象"
+
+#: sha1-file.c:2186
+#, c-format
+msgid "%s is not a valid '%s' object"
+msgstr "%s 不是一个有效的 '%s' 对象"
+
+#: sha1-file.c:2213 builtin/index-pack.c:155
+#, c-format
+msgid "unable to open %s"
+msgstr "不能打开 %s"
+
+#: sha1-file.c:2403 sha1-file.c:2455
+#, c-format
+msgid "hash mismatch for %s (expected %s)"
+msgstr "%s 的哈希值不匹配（预期 %s）"
+
+#: sha1-file.c:2427
+#, c-format
+msgid "unable to mmap %s"
+msgstr "不能 mmap %s"
+
+#: sha1-file.c:2432
+#, c-format
+msgid "unable to unpack header of %s"
+msgstr "无法解压缩 %s 的头部"
+
+#: sha1-file.c:2438
+#, c-format
+msgid "unable to parse header of %s"
+msgstr "无法解析 %s 的头部"
+
+#: sha1-file.c:2449
+#, c-format
+msgid "unable to unpack contents of %s"
+msgstr "无法解压缩 %s 的内容"
+
+#: sha1-name.c:487
+#, c-format
+msgid "short SHA1 %s is ambiguous"
+msgstr "短 SHA1 %s 存在歧义"
+
+#: sha1-name.c:498
+msgid "The candidates are:"
+msgstr "候选者有："
+
+#: sha1-name.c:797
+msgid ""
+"Git normally never creates a ref that ends with 40 hex characters\n"
+"because it will be ignored when you just specify 40-hex. These refs\n"
+"may be created by mistake. For example,\n"
+"\n"
+"  git switch -c $br $(git rev-parse ...)\n"
+"\n"
+"where \"$br\" is somehow empty and a 40-hex ref is created. Please\n"
+"examine these refs and maybe delete them. Turn this message off by\n"
+"running \"git config advice.objectNameWarning false\""
+msgstr ""
+"Git 通常不会创建一个以40个十六进制字符结尾的引用，因为当您只提供40\n"
+"个十六进制字符时将被忽略。这些引用可能被错误地创建。例如：\n"
+"\n"
+"  git switch -c $br $(git rev-parse ...)\n"
+"\n"
+"当 \"$br\" 某种原因空白时，一个40位十六进制的引用将被创建。请检查这些\n"
+"引用，可能需要删除它们。运行 \"git config advice.objectNameWarning\n"
+"false\" 命令关闭本消息通知。"
+
+#. TRANSLATORS: IEC 80000-13:2008 gibibyte
+#: strbuf.c:822
+#, c-format
+msgid "%u.%2.2u GiB"
+msgstr "%u.%2.2u GiB"
+
+#. TRANSLATORS: IEC 80000-13:2008 gibibyte/second
+#: strbuf.c:824
+#, c-format
+msgid "%u.%2.2u GiB/s"
+msgstr "%u.%2.2u GiB/s"
+
+#. TRANSLATORS: IEC 80000-13:2008 mebibyte
+#: strbuf.c:832
+#, c-format
+msgid "%u.%2.2u MiB"
+msgstr "%u.%2.2u MiB"
+
+#. TRANSLATORS: IEC 80000-13:2008 mebibyte/second
+#: strbuf.c:834
+#, c-format
+msgid "%u.%2.2u MiB/s"
+msgstr "%u.%2.2u MiB/s"
+
+#. TRANSLATORS: IEC 80000-13:2008 kibibyte
+#: strbuf.c:841
+#, c-format
+msgid "%u.%2.2u KiB"
+msgstr "%u.%2.2u KiB"
+
+#. TRANSLATORS: IEC 80000-13:2008 kibibyte/second
+#: strbuf.c:843
+#, c-format
+msgid "%u.%2.2u KiB/s"
+msgstr "%u.%2.2u KiB/s"
+
+#. TRANSLATORS: IEC 80000-13:2008 byte
+#: strbuf.c:849
+#, c-format
+msgid "%u byte"
+msgid_plural "%u bytes"
+msgstr[0] "%u 字节"
+msgstr[1] "%u 字节"
+
+#. TRANSLATORS: IEC 80000-13:2008 byte/second
+#: strbuf.c:851
+#, c-format
+msgid "%u byte/s"
+msgid_plural "%u bytes/s"
+msgstr[0] "%u 字节/秒"
+msgstr[1] "%u 字节/秒"
+
+#: strbuf.c:1149
+#, c-format
+msgid "could not edit '%s'"
+msgstr "不能编辑 '%s'"
+
+#: submodule.c:114 submodule.c:143
+msgid "Cannot change unmerged .gitmodules, resolve merge conflicts first"
+msgstr "无法修改未合并的 .gitmodules，先解决合并冲突"
+
+#: submodule.c:118 submodule.c:147
+#, c-format
+msgid "Could not find section in .gitmodules where path=%s"
+msgstr "无法在 .gitmodules 中找到 path=%s 的小节"
+
+#: submodule.c:154
+#, c-format
+msgid "Could not remove .gitmodules entry for %s"
+msgstr "无法移除 %s 的 .gitmodules 条目"
+
+#: submodule.c:165
+msgid "staging updated .gitmodules failed"
+msgstr "将更新后 .gitmodules 添加暂存区失败"
+
+#: submodule.c:327
+#, c-format
+msgid "in unpopulated submodule '%s'"
+msgstr "位于未检出的子模组 '%s'"
+
+#: submodule.c:358
+#, c-format
+msgid "Pathspec '%s' is in submodule '%.*s'"
+msgstr "路径规格 '%s' 在子模组 '%.*s' 中"
+
+#: submodule.c:910
+#, c-format
+msgid "submodule entry '%s' (%s) is a %s, not a commit"
+msgstr "子模组条目 '%s'（%s）是一个 %s，不是一个提交"
+
+#: submodule.c:1147 builtin/branch.c:680 builtin/submodule--helper.c:2016
+msgid "Failed to resolve HEAD as a valid ref."
+msgstr "无法将 HEAD 解析为有效引用。"
+
+#: submodule.c:1481
+#, c-format
+msgid "Could not access submodule '%s'"
+msgstr "无法访问子模组 '%s'"
+
+#: submodule.c:1651
+#, c-format
+msgid "'%s' not recognized as a git repository"
+msgstr "无法将 '%s' 识别为一个 git 仓库"
+
+#: submodule.c:1789
+#, c-format
+msgid "could not start 'git status' in submodule '%s'"
+msgstr "无法在子模组 '%s' 中启动 'git status'"
+
+#: submodule.c:1802
+#, c-format
+msgid "could not run 'git status' in submodule '%s'"
+msgstr "无法在子模组 '%s' 中执行 'git status'"
+
+#: submodule.c:1817
+#, c-format
+msgid "Could not unset core.worktree setting in submodule '%s'"
+msgstr "无法在子模组 '%s' 中取消 core.worktree 的设置"
+
+#: submodule.c:1907
+#, c-format
+msgid "submodule '%s' has dirty index"
+msgstr "子模组 '%s' 中有脏索引"
+
+#: submodule.c:1959
+#, c-format
+msgid "Submodule '%s' could not be updated."
+msgstr "子模组 '%s' 无法被更新。"
+
+#: submodule.c:2027
+#, c-format
+msgid "submodule git dir '%s' is inside git dir '%.*s'"
+msgstr "子模组 git 目录 '%s' 位于 git 目录 '%.*s' 中"
+
+#: submodule.c:2048
+#, c-format
+msgid ""
+"relocate_gitdir for submodule '%s' with more than one worktree not supported"
+msgstr "不支持对有多个工作区的子模组 '%s' 执行 relocate_gitdir"
+
+#: submodule.c:2060 submodule.c:2119
+#, c-format
+msgid "could not lookup name for submodule '%s'"
+msgstr "不能查询子模组 '%s' 的名称"
+
+#: submodule.c:2064
+#, c-format
+msgid "refusing to move '%s' into an existing git dir"
+msgstr "禁止移动 '%s' 到现存 git 目录中"
+
+#: submodule.c:2071
+#, c-format
+msgid ""
+"Migrating git directory of '%s%s' from\n"
+"'%s' to\n"
+"'%s'\n"
+msgstr ""
+"将 '%s%s' 的 git 目录从\n"
+"'%s' 迁移至\n"
+"'%s'\n"
+
+#: submodule.c:2154
+#, c-format
+msgid "could not recurse into submodule '%s'"
+msgstr "无法递归进子模组路径 '%s'"
+
+#: submodule.c:2198
+msgid "could not start ls-files in .."
+msgstr "无法在 .. 中启动 ls-files"
+
+#: submodule.c:2237
+#, c-format
+msgid "ls-tree returned unexpected return code %d"
+msgstr "ls-tree 返回未知返回值 %d"
+
+#: submodule-config.c:236
+#, c-format
+msgid "ignoring suspicious submodule name: %s"
+msgstr "忽略可疑的子模组名称：%s"
+
+#: submodule-config.c:303
+msgid "negative values not allowed for submodule.fetchjobs"
+msgstr "submodule.fetchjobs 不允许为负值"
+
+#: submodule-config.c:401
+#, c-format
+msgid "ignoring '%s' which may be interpreted as a command-line option: %s"
+msgstr "忽略可能被解析为命令行选项的 '%s'：%s"
+
+#: submodule-config.c:498
+#, c-format
+msgid "invalid value for %s"
+msgstr "%s 的值无效"
+
+#: submodule-config.c:769
+#, c-format
+msgid "Could not update .gitmodules entry %s"
+msgstr "不能更新 .gitmodules 条目 %s"
+
+#: trailer.c:238
+#, c-format
+msgid "running trailer command '%s' failed"
+msgstr "执行 trailer 命令 '%s' 失败"
+
+#: trailer.c:485 trailer.c:490 trailer.c:495 trailer.c:549 trailer.c:553
+#: trailer.c:557
+#, c-format
+msgid "unknown value '%s' for key '%s'"
+msgstr "键 '%2$s' 的未知取值 '%1$s'"
+
+#: trailer.c:539 trailer.c:544 builtin/remote.c:295
+#, c-format
+msgid "more than one %s"
+msgstr "多于一个 %s"
+
+#: trailer.c:730
+#, c-format
+msgid "empty trailer token in trailer '%.*s'"
+msgstr "签名 '%.*s' 的键为空"
+
+#: trailer.c:750
+#, c-format
+msgid "could not read input file '%s'"
+msgstr "不能读取输入文件 '%s'"
+
+#: trailer.c:753
+msgid "could not read from stdin"
+msgstr "不能自标准输入读取"
+
+#: trailer.c:1011 wrapper.c:665
+#, c-format
+msgid "could not stat %s"
+msgstr "不能对 %s 调用 stat"
+
+#: trailer.c:1013
+#, c-format
+msgid "file %s is not a regular file"
+msgstr "文件 %s 不是一个正规文件"
+
+#: trailer.c:1015
+#, c-format
+msgid "file %s is not writable by user"
+msgstr "文件 %s 用户不可写"
+
+#: trailer.c:1027
+msgid "could not open temporary file"
+msgstr "不能打开临时文件"
+
+#: trailer.c:1067
+#, c-format
+msgid "could not rename temporary file to %s"
+msgstr "不能重命名临时文件为 %s"
+
+#: transport.c:116
+#, c-format
+msgid "Would set upstream of '%s' to '%s' of '%s'\n"
+msgstr "将要设置 '%1$s' 的上游为 '%3$s' 的 '%2$s'\n"
+
+#: transport.c:145
+#, c-format
+msgid "could not read bundle '%s'"
+msgstr "无法读取 bundle '%s'"
+
+#: transport.c:214
+#, c-format
+msgid "transport: invalid depth option '%s'"
+msgstr "传输：无效的深度选项 '%s'"
+
+#: transport.c:266
+msgid "see protocol.version in 'git help config' for more details"
+msgstr "查看 'git help config' 中的 protocol.version 获取更多信息"
+
+#: transport.c:267
+msgid "server options require protocol version 2 or later"
+msgstr "服务端选项需要版本 2 协议或更高"
+
+#: transport.c:632
+msgid "could not parse transport.color.* config"
+msgstr "不能解析 transport.color.* 配置"
+
+#: transport.c:705
+msgid "support for protocol v2 not implemented yet"
+msgstr "协议 v2 的支持尚未实现"
+
+#: transport.c:831
+#, c-format
+msgid "unknown value for config '%s': %s"
+msgstr "配置 '%s' 的取值未知：%s"
+
+#: transport.c:897
+#, c-format
+msgid "transport '%s' not allowed"
+msgstr "传输 '%s' 不允许"
+
+#: transport.c:949
+msgid "git-over-rsync is no longer supported"
+msgstr "不再支持 git-over-rsync"
+
+#: transport.c:1044
+#, c-format
+msgid ""
+"The following submodule paths contain changes that can\n"
+"not be found on any remote:\n"
+msgstr "下列子模组路径所包含的修改在任何远程源中都找不到：\n"
+
+#: transport.c:1048
+#, c-format
+msgid ""
+"\n"
+"Please try\n"
+"\n"
+"\tgit push --recurse-submodules=on-demand\n"
+"\n"
+"or cd to the path and use\n"
+"\n"
+"\tgit push\n"
+"\n"
+"to push them to a remote.\n"
+"\n"
+msgstr ""
+"\n"
+"请尝试\n"
+"\n"
+"\tgit push --recurse-submodules=on-demand\n"
+"\n"
+"或者进入到子目录执行\n"
+"\n"
+"\tgit push\n"
+"\n"
+"以推送至远程。\n"
+"\n"
+
+#: transport.c:1056
+msgid "Aborting."
+msgstr "正在终止。"
+
+#: transport.c:1201
+msgid "failed to push all needed submodules"
+msgstr "不能推送全部需要的子模组"
+
+#: transport.c:1345 transport-helper.c:656
+msgid "operation not supported by protocol"
+msgstr "协议不支持该操作"
+
+#: transport-helper.c:61 transport-helper.c:90
+msgid "full write to remote helper failed"
+msgstr "完整写入远程助手失败"
+
+#: transport-helper.c:144
+#, c-format
+msgid "unable to find remote helper for '%s'"
+msgstr "无法为 '%s' 找到远程助手"
+
+#: transport-helper.c:160 transport-helper.c:570
+msgid "can't dup helper output fd"
+msgstr "无法复制助手输出文件句柄"
+
+#: transport-helper.c:211
+#, c-format
+msgid ""
+"unknown mandatory capability %s; this remote helper probably needs newer "
+"version of Git"
+msgstr "未知的强制能力 %s，该远程助手可能需要新版本的Git"
+
+#: transport-helper.c:217
+msgid "this remote helper should implement refspec capability"
+msgstr "远程助手需要实现 refspec 能力"
+
+#: transport-helper.c:284 transport-helper.c:424
+#, c-format
+msgid "%s unexpectedly said: '%s'"
+msgstr "%s 意外地说：'%s'"
+
+#: transport-helper.c:413
+#, c-format
+msgid "%s also locked %s"
+msgstr "%s 也锁定了 %s"
+
+#: transport-helper.c:492
+msgid "couldn't run fast-import"
+msgstr "不能执行 fast-import"
+
+#: transport-helper.c:515
+msgid "error while running fast-import"
+msgstr "执行 fast-import 出错"
+
+#: transport-helper.c:544 transport-helper.c:1133
+#, c-format
+msgid "could not read ref %s"
+msgstr "无法读取引用 %s"
+
+#: transport-helper.c:589
+#, c-format
+msgid "unknown response to connect: %s"
+msgstr "连接时未知的响应：%s"
+
+#: transport-helper.c:611
+msgid "setting remote service path not supported by protocol"
+msgstr "协议不支持设置远程服务路径"
+
+#: transport-helper.c:613
+msgid "invalid remote service path"
+msgstr "无效的远程服务路径"
+
+#: transport-helper.c:659
+#, c-format
+msgid "can't connect to subservice %s"
+msgstr "不能连接到子服务 %s"
+
+#: transport-helper.c:735
+#, c-format
+msgid "expected ok/error, helper said '%s'"
+msgstr "预期 ok/error，助手说 '%s'"
+
+#: transport-helper.c:788
+#, c-format
+msgid "helper reported unexpected status of %s"
+msgstr "助手报告 %s 的意外状态"
+
+#: transport-helper.c:849
+#, c-format
+msgid "helper %s does not support dry-run"
+msgstr "助手 %s 不支持 dry-run"
+
+#: transport-helper.c:852
+#, c-format
+msgid "helper %s does not support --signed"
+msgstr "助手 %s 不支持 --signed"
+
+#: transport-helper.c:855
+#, c-format
+msgid "helper %s does not support --signed=if-asked"
+msgstr "助手 %s 不支持 --signed=if-asked"
+
+#: transport-helper.c:860
+#, c-format
+msgid "helper %s does not support --atomic"
+msgstr "助手 %s 不支持 --atomic"
+
+#: transport-helper.c:866
+#, c-format
+msgid "helper %s does not support 'push-option'"
+msgstr "助手 %s 不支持 'push-option'"
+
+#: transport-helper.c:964
+msgid "remote-helper doesn't support push; refspec needed"
+msgstr "remote-heper 不支持 push，需要引用表达式"
+
+#: transport-helper.c:969
+#, c-format
+msgid "helper %s does not support 'force'"
+msgstr "助手 %s 不支持 'force'"
+
+#: transport-helper.c:1016
+msgid "couldn't run fast-export"
+msgstr "无法执行 fast-export"
+
+#: transport-helper.c:1021
+msgid "error while running fast-export"
+msgstr "执行 fast-export 时出错"
+
+#: transport-helper.c:1046
+#, c-format
+msgid ""
+"No refs in common and none specified; doing nothing.\n"
+"Perhaps you should specify a branch such as 'master'.\n"
+msgstr ""
+"没有共同的引用并且也没有指定，什么也不会做。\n"
+"可能您应该指定一个分支如 'master'。\n"
+
+#: transport-helper.c:1119
+#, c-format
+msgid "malformed response in ref list: %s"
+msgstr "引用列表中格式错误的响应：%s"
+
+#: transport-helper.c:1271
+#, c-format
+msgid "read(%s) failed"
+msgstr "读取（%s）失败"
+
+#: transport-helper.c:1298
+#, c-format
+msgid "write(%s) failed"
+msgstr "写（%s）失败"
+
+#: transport-helper.c:1347
+#, c-format
+msgid "%s thread failed"
+msgstr "%s 线程失败"
+
+#: transport-helper.c:1351
+#, c-format
+msgid "%s thread failed to join: %s"
+msgstr "%s 线程等待失败：%s"
+
+#: transport-helper.c:1370 transport-helper.c:1374
+#, c-format
+msgid "can't start thread for copying data: %s"
+msgstr "不能启动线程来拷贝数据：%s"
+
+#: transport-helper.c:1411
+#, c-format
+msgid "%s process failed to wait"
+msgstr "%s 进程等待失败"
+
+#: transport-helper.c:1415
+#, c-format
+msgid "%s process failed"
+msgstr "%s 进程失败"
+
+#: transport-helper.c:1433 transport-helper.c:1442
+msgid "can't start thread for copying data"
+msgstr "不能启动线程来拷贝数据"
+
+#: tree-walk.c:33
+msgid "too-short tree object"
+msgstr "太短的树对象"
+
+#: tree-walk.c:39
+msgid "malformed mode in tree entry"
+msgstr "树对象中的条目模式错误"
+
+#: tree-walk.c:43
+msgid "empty filename in tree entry"
+msgstr "树对象条目中空的文件名"
+
+#: tree-walk.c:48
+#, c-format
+msgid "filename in tree entry contains backslash: '%s'"
+msgstr "树条目中的文件名包含反斜杠：'%s'"
+
+#: tree-walk.c:124
+msgid "too-short tree file"
+msgstr "太短的树文件"
+
+#: unpack-trees.c:110
+#, c-format
+msgid ""
+"Your local changes to the following files would be overwritten by checkout:\n"
+"%%sPlease commit your changes or stash them before you switch branches."
+msgstr ""
+"您对下列文件的本地修改将被检出操作覆盖：\n"
+"%%s请在切换分支前提交或贮藏您的修改。"
+
+#: unpack-trees.c:112
+#, c-format
+msgid ""
+"Your local changes to the following files would be overwritten by checkout:\n"
+"%%s"
+msgstr ""
+"您对下列文件的本地修改将被检出操作覆盖：\n"
+"%%s"
+
+#: unpack-trees.c:115
+#, c-format
+msgid ""
+"Your local changes to the following files would be overwritten by merge:\n"
+"%%sPlease commit your changes or stash them before you merge."
+msgstr ""
+"您对下列文件的本地修改将被合并操作覆盖：\n"
+"%%s请在合并前提交或贮藏您的修改。"
+
+#: unpack-trees.c:117
+#, c-format
+msgid ""
+"Your local changes to the following files would be overwritten by merge:\n"
+"%%s"
+msgstr ""
+"您对下列文件的本地修改将被合并操作覆盖：\n"
+"%%s"
+
+#: unpack-trees.c:120
+#, c-format
+msgid ""
+"Your local changes to the following files would be overwritten by %s:\n"
+"%%sPlease commit your changes or stash them before you %s."
+msgstr ""
+"您对下列文件的本地修改将被 %s 覆盖：\n"
+"%%s请在 %s 之前提交或贮藏您的修改。"
+
+#: unpack-trees.c:122
+#, c-format
+msgid ""
+"Your local changes to the following files would be overwritten by %s:\n"
+"%%s"
+msgstr ""
+"您对下列文件的本地修改将被 %s 覆盖：\n"
+"%%s"
+
+#: unpack-trees.c:127
+#, c-format
+msgid ""
+"Updating the following directories would lose untracked files in them:\n"
+"%s"
+msgstr ""
+"更新如下目录将会丢失其中未跟踪的文件：\n"
+"%s"
+
+#: unpack-trees.c:131
+#, c-format
+msgid ""
+"The following untracked working tree files would be removed by checkout:\n"
+"%%sPlease move or remove them before you switch branches."
+msgstr ""
+"工作区中下列未跟踪的文件将会因为检出操作而被删除：\n"
+"%%s请在切换分支之前移动或删除。"
+
+#: unpack-trees.c:133
+#, c-format
+msgid ""
+"The following untracked working tree files would be removed by checkout:\n"
+"%%s"
+msgstr ""
+"工作区中下列未跟踪的文件将会因为检出操作而被删除：\n"
+"%%s"
+
+#: unpack-trees.c:136
+#, c-format
+msgid ""
+"The following untracked working tree files would be removed by merge:\n"
+"%%sPlease move or remove them before you merge."
+msgstr ""
+"工作区中下列未跟踪的文件将会因为合并操作而被删除：\n"
+"%%s请在合并前移动或删除。"
+
+#: unpack-trees.c:138
+#, c-format
+msgid ""
+"The following untracked working tree files would be removed by merge:\n"
+"%%s"
+msgstr ""
+"工作区中下列未跟踪的文件将会因为合并操作而被删除：\n"
+"%%s"
+
+#: unpack-trees.c:141
+#, c-format
+msgid ""
+"The following untracked working tree files would be removed by %s:\n"
+"%%sPlease move or remove them before you %s."
+msgstr ""
+"工作区中下列未跟踪的文件将会因为 %s 操作而被删除：\n"
+"%%s请在 %s 前移动或删除。"
+
+#: unpack-trees.c:143
+#, c-format
+msgid ""
+"The following untracked working tree files would be removed by %s:\n"
+"%%s"
+msgstr ""
+"工作区中下列未跟踪的文件将会因为 %s 操作而被删除：\n"
+"%%s"
+
+#: unpack-trees.c:149
+#, c-format
+msgid ""
+"The following untracked working tree files would be overwritten by "
+"checkout:\n"
+"%%sPlease move or remove them before you switch branches."
+msgstr ""
+"工作区中下列未跟踪的文件将会因为检出操作而被覆盖：\n"
+"%%s请在切换分支前移动或删除。"
+
+#: unpack-trees.c:151
+#, c-format
+msgid ""
+"The following untracked working tree files would be overwritten by "
+"checkout:\n"
+"%%s"
+msgstr ""
+"工作区中下列未跟踪的文件将会因为检出操作而被覆盖：\n"
+"%%s"
+
+#: unpack-trees.c:154
+#, c-format
+msgid ""
+"The following untracked working tree files would be overwritten by merge:\n"
+"%%sPlease move or remove them before you merge."
+msgstr ""
+"工作区中下列未跟踪的文件将会因为合并操作而被覆盖：\n"
+"%%s请在合并前移动或删除。"
+
+#: unpack-trees.c:156
+#, c-format
+msgid ""
+"The following untracked working tree files would be overwritten by merge:\n"
+"%%s"
+msgstr ""
+"工作区中下列未跟踪的文件将会因为合并操作而被覆盖：\n"
+"%%s"
+
+#: unpack-trees.c:159
+#, c-format
+msgid ""
+"The following untracked working tree files would be overwritten by %s:\n"
+"%%sPlease move or remove them before you %s."
+msgstr ""
+"工作区中下列未跟踪的文件将会因为 %s 操作而被覆盖：\n"
+"%%s请在 %s 前移动或删除。"
+
+#: unpack-trees.c:161
+#, c-format
+msgid ""
+"The following untracked working tree files would be overwritten by %s:\n"
+"%%s"
+msgstr ""
+"工作区中下列未跟踪的文件将会因为 %s 操作而被覆盖：\n"
+"%%s"
+
+#: unpack-trees.c:169
+#, c-format
+msgid "Entry '%s' overlaps with '%s'.  Cannot bind."
+msgstr "条目 '%s' 和 '%s' 重叠。无法合并。"
+
+#: unpack-trees.c:172
+#, c-format
+msgid ""
+"Cannot update sparse checkout: the following entries are not up to date:\n"
+"%s"
+msgstr ""
+"无法更新稀疏检出：如下条目不是最新：\n"
+"%s"
+
+#: unpack-trees.c:174
+#, c-format
+msgid ""
+"The following working tree files would be overwritten by sparse checkout "
+"update:\n"
+"%s"
+msgstr ""
+"工作区中下列文件将被稀疏检出更新所覆盖：\n"
+"%s"
+
+#: unpack-trees.c:176
+#, c-format
+msgid ""
+"The following working tree files would be removed by sparse checkout "
+"update:\n"
+"%s"
+msgstr ""
+"工作区中下列文件将被稀疏检出更新所删除：\n"
+"%s"
+
+#: unpack-trees.c:178
+#, c-format
+msgid ""
+"Cannot update submodule:\n"
+"%s"
+msgstr ""
+"无法更新子模组：\n"
+"%s"
+
+#: unpack-trees.c:255
+#, c-format
+msgid "Aborting\n"
+msgstr "正在终止\n"
+
+#: unpack-trees.c:317
+msgid "Updating files"
+msgstr "正在更新文件"
+
+#: unpack-trees.c:349
+msgid ""
+"the following paths have collided (e.g. case-sensitive paths\n"
+"on a case-insensitive filesystem) and only one from the same\n"
+"colliding group is in the working tree:\n"
+msgstr ""
+"以下路径发生碰撞（如：在不区分大小写的文件系统上的区分大小写的路径），\n"
+"并且碰撞组中只有一个文件存在工作区中：\n"
+
+#: unpack-trees.c:1441
+msgid "Updating index flags"
+msgstr "正在更新索引标志"
+
+#: urlmatch.c:163
+msgid "invalid URL scheme name or missing '://' suffix"
+msgstr "无效的 URL 方案名称或丢失 '://' 后缀"
+
+#: urlmatch.c:187 urlmatch.c:346 urlmatch.c:405
+#, c-format
+msgid "invalid %XX escape sequence"
+msgstr "无效的 %XX 转义序列"
+
+#: urlmatch.c:215
+msgid "missing host and scheme is not 'file:'"
+msgstr "缺失主机名且 URL 方案不是 'file:'"
+
+#: urlmatch.c:232
+msgid "a 'file:' URL may not have a port number"
+msgstr "一个 'file:' URL 不应该包含端口号"
+
+#: urlmatch.c:247
+msgid "invalid characters in host name"
+msgstr "主机名中包含无效的字符"
+
+#: urlmatch.c:292 urlmatch.c:303
+msgid "invalid port number"
+msgstr "无效的端口号"
+
+#: urlmatch.c:371
+msgid "invalid '..' path segment"
+msgstr "无效的 '..' 路径片段"
+
+#: worktree.c:258 builtin/am.c:2084
+#, c-format
+msgid "failed to read '%s'"
+msgstr "读取 '%s' 失败"
+
+#: worktree.c:304
+#, c-format
+msgid "'%s' at main working tree is not the repository directory"
+msgstr "在主工作区的 '%s' 不是仓库目录"
+
+#: worktree.c:315
+#, c-format
+msgid "'%s' file does not contain absolute path to the working tree location"
+msgstr "文件 '%s' 不包含工作区的绝对路径"
+
+#: worktree.c:327
+#, c-format
+msgid "'%s' does not exist"
+msgstr "'%s' 不存在"
+
+#: worktree.c:333
+#, c-format
+msgid "'%s' is not a .git file, error code %d"
+msgstr "'%s' 不是一个 .git 文件，错误码 %d"
+
+#: worktree.c:341
+#, c-format
+msgid "'%s' does not point back to '%s'"
+msgstr "'%s' 没有指回到 '%s'"
+
+#: wrapper.c:186 wrapper.c:356
+#, c-format
+msgid "could not open '%s' for reading and writing"
+msgstr "无法打开 '%s' 进行读写"
+
+#: wrapper.c:387 wrapper.c:588
+#, c-format
+msgid "unable to access '%s'"
+msgstr "不能访问 '%s'"
+
+#: wrapper.c:596
+msgid "unable to get current working directory"
+msgstr "不能获取当前工作目录"
+
+#: wt-status.c:158
+msgid "Unmerged paths:"
+msgstr "未合并的路径："
+
+#  译者：注意保持前导空格
+#: wt-status.c:187 wt-status.c:219
+msgid "  (use \"git restore --staged <file>...\" to unstage)"
+msgstr "  （使用 \"git restore --staged <文件>...\" 以取消暂存）"
+
+#  译者：注意保持前导空格
+#: wt-status.c:190 wt-status.c:222
+#, c-format
+msgid "  (use \"git restore --source=%s --staged <file>...\" to unstage)"
+msgstr "  （使用 \"git restore --source=%s --staged <文件>...\" 以取消暂存）"
+
+#  译者：注意保持前导空格
+#: wt-status.c:193 wt-status.c:225
+msgid "  (use \"git rm --cached <file>...\" to unstage)"
+msgstr "  （使用 \"git rm --cached <文件>...\" 以取消暂存）"
+
+#  译者：注意保持前导空格
+#: wt-status.c:197
+msgid "  (use \"git add <file>...\" to mark resolution)"
+msgstr "  （使用 \"git add <文件>...\" 标记解决方案）"
+
+#  译者：注意保持前导空格
+#: wt-status.c:199 wt-status.c:203
+msgid "  (use \"git add/rm <file>...\" as appropriate to mark resolution)"
+msgstr "  （酌情使用 \"git add/rm <文件>...\" 标记解决方案）"
+
+#  译者：注意保持前导空格
+#: wt-status.c:201
+msgid "  (use \"git rm <file>...\" to mark resolution)"
+msgstr "  （使用 \"git rm <文件>...\" 标记解决方案）"
+
+#: wt-status.c:211 wt-status.c:1074
+msgid "Changes to be committed:"
+msgstr "要提交的变更："
+
+#: wt-status.c:234 wt-status.c:1083
+msgid "Changes not staged for commit:"
+msgstr "尚未暂存以备提交的变更："
+
+#  译者：注意保持前导空格
+#: wt-status.c:238
+msgid "  (use \"git add <file>...\" to update what will be committed)"
+msgstr "  （使用 \"git add <文件>...\" 更新要提交的内容）"
+
+#  译者：注意保持前导空格
+#: wt-status.c:240
+msgid "  (use \"git add/rm <file>...\" to update what will be committed)"
+msgstr "  （使用 \"git add/rm <文件>...\" 更新要提交的内容）"
+
+#  译者：注意保持前导空格
+#: wt-status.c:241
+msgid ""
+"  (use \"git restore <file>...\" to discard changes in working directory)"
+msgstr "  （使用 \"git restore <文件>...\" 丢弃工作区的改动）"
+
+#  译者：注意保持前导空格
+#: wt-status.c:243
+msgid "  (commit or discard the untracked or modified content in submodules)"
+msgstr "  （提交或丢弃子模组中未跟踪或修改的内容）"
+
+#  译者：注意保持前导空格
+#: wt-status.c:254
+#, c-format
+msgid "  (use \"git %s <file>...\" to include in what will be committed)"
+msgstr "  （使用 \"git %s <文件>...\" 以包含要提交的内容）"
+
+#: wt-status.c:268
+msgid "both deleted:"
+msgstr "双方删除："
+
+#: wt-status.c:270
+msgid "added by us:"
+msgstr "由我们添加："
+
+#: wt-status.c:272
+msgid "deleted by them:"
+msgstr "由他们删除："
+
+#: wt-status.c:274
+msgid "added by them:"
+msgstr "由他们添加："
+
+#: wt-status.c:276
+msgid "deleted by us:"
+msgstr "由我们删除："
+
+#: wt-status.c:278
+msgid "both added:"
+msgstr "双方添加："
+
+#: wt-status.c:280
+msgid "both modified:"
+msgstr "双方修改："
+
+#: wt-status.c:290
+msgid "new file:"
+msgstr "新文件："
+
+#: wt-status.c:292
+msgid "copied:"
+msgstr "拷贝："
+
+#: wt-status.c:294
+msgid "deleted:"
+msgstr "删除："
+
+#: wt-status.c:296
+msgid "modified:"
+msgstr "修改："
+
+#: wt-status.c:298
+msgid "renamed:"
+msgstr "重命名："
+
+#: wt-status.c:300
+msgid "typechange:"
+msgstr "类型变更："
+
+#: wt-status.c:302
+msgid "unknown:"
+msgstr "未知："
+
+#: wt-status.c:304
+msgid "unmerged:"
+msgstr "未合并："
+
+#  译者：末尾两个字节可能被删减，如果翻译为中文标点会出现半个汉字
+#: wt-status.c:384
+msgid "new commits, "
+msgstr "新提交, "
+
+#  译者：末尾两个字节可能被删减，如果翻译为中文标点会出现半个汉字
+#: wt-status.c:386
+msgid "modified content, "
+msgstr "修改的内容, "
+
+#  译者：末尾两个字节可能被删减，如果翻译为中文标点会出现半个汉字
+#: wt-status.c:388
+msgid "untracked content, "
+msgstr "未跟踪的内容, "
+
+#: wt-status.c:906
+#, c-format
+msgid "Your stash currently has %d entry"
+msgid_plural "Your stash currently has %d entries"
+msgstr[0] "您的贮藏区当前有 %d 条记录"
+msgstr[1] "您的贮藏区当前有 %d 条记录"
+
+#: wt-status.c:938
+msgid "Submodules changed but not updated:"
+msgstr "子模组已修改但尚未更新："
+
+#: wt-status.c:940
+msgid "Submodule changes to be committed:"
+msgstr "要提交的子模组变更："
+
+#: wt-status.c:1022
+msgid ""
+"Do not modify or remove the line above.\n"
+"Everything below it will be ignored."
+msgstr ""
+"不要改动或删除上面的一行。\n"
+"其下所有内容都将被忽略。"
+
+#: wt-status.c:1114
+#, c-format
+msgid ""
+"\n"
+"It took %.2f seconds to compute the branch ahead/behind values.\n"
+"You can use '--no-ahead-behind' to avoid this.\n"
+msgstr ""
+"\n"
+"花了 %.2f 秒才计算出分支的领先/落后范围。\n"
+"为避免，您可以使用 '--no-ahead-behind'。\n"
+
+#: wt-status.c:1144
+msgid "You have unmerged paths."
+msgstr "您有尚未合并的路径。"
+
+#  译者：注意保持前导空格
+#: wt-status.c:1147
+msgid "  (fix conflicts and run \"git commit\")"
+msgstr "  （解决冲突并运行 \"git commit\"）"
+
+#  译者：注意保持前导空格
+#: wt-status.c:1149
+msgid "  (use \"git merge --abort\" to abort the merge)"
+msgstr "  （使用 \"git merge --abort\" 终止合并）"
+
+#: wt-status.c:1153
+msgid "All conflicts fixed but you are still merging."
+msgstr "所有冲突已解决但您仍处于合并中。"
+
+#  译者：注意保持前导空格
+#: wt-status.c:1156
+msgid "  (use \"git commit\" to conclude merge)"
+msgstr "  （使用 \"git commit\" 结束合并）"
+
+#: wt-status.c:1165
+msgid "You are in the middle of an am session."
+msgstr "您正处于 am 操作过程中。"
+
+#: wt-status.c:1168
+msgid "The current patch is empty."
+msgstr "当前的补丁为空。"
+
+#  译者：注意保持前导空格
+#: wt-status.c:1172
+msgid "  (fix conflicts and then run \"git am --continue\")"
+msgstr "  （解决冲突，然后运行 \"git am --continue\"）"
+
+#  译者：注意保持前导空格
+#: wt-status.c:1174
+msgid "  (use \"git am --skip\" to skip this patch)"
+msgstr "  （使用 \"git am --skip\" 跳过此补丁）"
+
+#  译者：注意保持前导空格
+#: wt-status.c:1176
+msgid "  (use \"git am --abort\" to restore the original branch)"
+msgstr "  （使用 \"git am --abort\" 恢复原有分支）"
+
+#: wt-status.c:1309
+msgid "git-rebase-todo is missing."
+msgstr "git-rebase-todo 丢失。"
+
+#: wt-status.c:1311
+msgid "No commands done."
+msgstr "没有命令被执行。"
+
+#: wt-status.c:1314
+#, c-format
+msgid "Last command done (%d command done):"
+msgid_plural "Last commands done (%d commands done):"
+msgstr[0] "最后一条命令已完成（%d 条命令被执行）："
+msgstr[1] "最后的命令已完成（%d 条命令被执行）："
+
+#: wt-status.c:1325
+#, c-format
+msgid "  (see more in file %s)"
+msgstr "  （更多参见文件 %s）"
+
+#: wt-status.c:1330
+msgid "No commands remaining."
+msgstr "未剩下任何命令。"
+
+#: wt-status.c:1333
+#, c-format
+msgid "Next command to do (%d remaining command):"
+msgid_plural "Next commands to do (%d remaining commands):"
+msgstr[0] "接下来要执行的命令（剩余 %d 条命令）："
+msgstr[1] "接下来要执行的命令（剩余 %d 条命令）："
+
+#  译者：注意保持前导空格
+#: wt-status.c:1341
+msgid "  (use \"git rebase --edit-todo\" to view and edit)"
+msgstr "  （使用 \"git rebase --edit-todo\" 来查看和编辑）"
+
+#: wt-status.c:1353
+#, c-format
+msgid "You are currently rebasing branch '%s' on '%s'."
+msgstr "您在执行将分支 '%s' 变基到 '%s' 的操作。"
+
+#: wt-status.c:1358
+msgid "You are currently rebasing."
+msgstr "您在执行变基操作。"
+
+#  译者：注意保持前导空格
+#: wt-status.c:1371
+msgid "  (fix conflicts and then run \"git rebase --continue\")"
+msgstr "  （解决冲突，然后运行 \"git rebase --continue\"）"
+
+#  译者：注意保持前导空格
+#: wt-status.c:1373
+msgid "  (use \"git rebase --skip\" to skip this patch)"
+msgstr "  （使用 \"git rebase --skip\" 跳过此补丁）"
+
+#  译者：注意保持前导空格
+#: wt-status.c:1375
+msgid "  (use \"git rebase --abort\" to check out the original branch)"
+msgstr "  （使用 \"git rebase --abort\" 以检出原有分支）"
+
+#  译者：注意保持前导空格
+#: wt-status.c:1382
+msgid "  (all conflicts fixed: run \"git rebase --continue\")"
+msgstr "  （所有冲突已解决：运行 \"git rebase --continue\"）"
+
+#: wt-status.c:1386
+#, c-format
+msgid ""
+"You are currently splitting a commit while rebasing branch '%s' on '%s'."
+msgstr "您在执行将分支 '%s' 变基到 '%s' 的操作时拆分提交。"
+
+#: wt-status.c:1391
+msgid "You are currently splitting a commit during a rebase."
+msgstr "您在执行变基操作时拆分提交。"
+
+#  译者：注意保持前导空格
+#: wt-status.c:1394
+msgid "  (Once your working directory is clean, run \"git rebase --continue\")"
+msgstr "  （一旦您工作目录提交干净后，运行 \"git rebase --continue\"）"
+
+#: wt-status.c:1398
+#, c-format
+msgid "You are currently editing a commit while rebasing branch '%s' on '%s'."
+msgstr "您在执行将分支 '%s' 变基到 '%s' 的操作时编辑提交。"
+
+#: wt-status.c:1403
+msgid "You are currently editing a commit during a rebase."
+msgstr "您在执行变基操作时编辑提交。"
+
+#  译者：注意保持前导空格
+#: wt-status.c:1406
+msgid "  (use \"git commit --amend\" to amend the current commit)"
+msgstr "  （使用 \"git commit --amend\" 修补当前提交）"
+
+#  译者：注意保持前导空格
+#: wt-status.c:1408
+msgid ""
+"  (use \"git rebase --continue\" once you are satisfied with your changes)"
+msgstr "  （当您对您的修改满意后执行 \"git rebase --continue\"）"
+
+#: wt-status.c:1419
+msgid "Cherry-pick currently in progress."
+msgstr "拣选操作正在进行中。"
+
+#: wt-status.c:1422
+#, c-format
+msgid "You are currently cherry-picking commit %s."
+msgstr "您在执行拣选提交 %s 的操作。"
+
+#  译者：注意保持前导空格
+#: wt-status.c:1429
+msgid "  (fix conflicts and run \"git cherry-pick --continue\")"
+msgstr "  （解决冲突并运行 \"git cherry-pick --continue\"）"
+
+#  译者：注意保持前导空格
+#: wt-status.c:1432
+msgid "  (run \"git cherry-pick --continue\" to continue)"
+msgstr "  （执行 \"git cherry-pick --continue\" 以继续）"
+
+#  译者：注意保持前导空格
+#: wt-status.c:1435
+msgid "  (all conflicts fixed: run \"git cherry-pick --continue\")"
+msgstr "  （所有冲突已解决：运行 \"git cherry-pick --continue\"）"
+
+#  译者：注意保持前导空格
+#: wt-status.c:1437
+msgid "  (use \"git cherry-pick --skip\" to skip this patch)"
+msgstr "  （使用 \"git cherry-pick --skip\" 跳过此补丁）"
+
+#  译者：注意保持前导空格
+#: wt-status.c:1439
+msgid "  (use \"git cherry-pick --abort\" to cancel the cherry-pick operation)"
+msgstr "  （使用 \"git cherry-pick --abort\" 以取消拣选操作）"
+
+#: wt-status.c:1449
+msgid "Revert currently in progress."
+msgstr "还原操作正在行中。"
+
+#: wt-status.c:1452
+#, c-format
+msgid "You are currently reverting commit %s."
+msgstr "您在执行反转提交 %s 的操作。"
+
+#  译者：注意保持前导空格
+#: wt-status.c:1458
+msgid "  (fix conflicts and run \"git revert --continue\")"
+msgstr "  （解决冲突并执行 \"git revert --continue\"）"
+
+#  译者：注意保持前导空格
+#: wt-status.c:1461
+msgid "  (run \"git revert --continue\" to continue)"
+msgstr "  （执行 \"git revert --continue\" 以继续）"
+
+#  译者：注意保持前导空格
+#: wt-status.c:1464
+msgid "  (all conflicts fixed: run \"git revert --continue\")"
+msgstr "  （所有冲突已解决：执行 \"git revert --continue\"）"
+
+#  译者：注意保持前导空格
+#: wt-status.c:1466
+msgid "  (use \"git revert --skip\" to skip this patch)"
+msgstr "  （使用 \"git revert --skip\" 跳过此补丁）"
+
+#  译者：注意保持前导空格
+#: wt-status.c:1468
+msgid "  (use \"git revert --abort\" to cancel the revert operation)"
+msgstr "  （使用 \"git revert --abort\" 以取消反转提交操作）"
+
+#: wt-status.c:1478
+#, c-format
+msgid "You are currently bisecting, started from branch '%s'."
+msgstr "您在执行从分支 '%s' 开始的二分查找操作。"
+
+#: wt-status.c:1482
+msgid "You are currently bisecting."
+msgstr "您在执行二分查找操作。"
+
+#  译者：注意保持前导空格
+#: wt-status.c:1485
+msgid "  (use \"git bisect reset\" to get back to the original branch)"
+msgstr "  （使用 \"git bisect reset\" 以回到原有分支）"
+
+#: wt-status.c:1694
+msgid "On branch "
+msgstr "位于分支 "
+
+#: wt-status.c:1701
+msgid "interactive rebase in progress; onto "
+msgstr "交互式变基操作正在进行中；至 "
+
+#: wt-status.c:1703
+msgid "rebase in progress; onto "
+msgstr "变基操作正在进行中；至 "
+
+#: wt-status.c:1713
+msgid "Not currently on any branch."
+msgstr "当前不在任何分支上。"
+
+#: wt-status.c:1730
+msgid "Initial commit"
+msgstr "初始提交"
+
+#: wt-status.c:1731
+msgid "No commits yet"
+msgstr "尚无提交"
+
+#: wt-status.c:1745
+msgid "Untracked files"
+msgstr "未跟踪的文件"
+
+#: wt-status.c:1747
+msgid "Ignored files"
+msgstr "忽略的文件"
+
+#: wt-status.c:1751
+#, c-format
+msgid ""
+"It took %.2f seconds to enumerate untracked files. 'status -uno'\n"
+"may speed it up, but you have to be careful not to forget to add\n"
+"new files yourself (see 'git help status')."
+msgstr ""
+"耗费了 %.2f 秒以枚举未跟踪的文件。'status -uno' 也许能提高速度，\n"
+"但您需要小心不要忘了添加新文件（参见 'git help status'）。"
+
+#: wt-status.c:1757
+#, c-format
+msgid "Untracked files not listed%s"
+msgstr "未跟踪的文件没有列出%s"
+
+#  译者：中文字符串拼接，可删除前导空格
+#: wt-status.c:1759
+msgid " (use -u option to show untracked files)"
+msgstr "（使用 -u 参数显示未跟踪的文件）"
+
+#: wt-status.c:1765
+msgid "No changes"
+msgstr "没有修改"
+
+#: wt-status.c:1770
+#, c-format
+msgid "no changes added to commit (use \"git add\" and/or \"git commit -a\")\n"
+msgstr "修改尚未加入提交（使用 \"git add\" 和/或 \"git commit -a\"）\n"
+
+#: wt-status.c:1773
+#, c-format
+msgid "no changes added to commit\n"
+msgstr "修改尚未加入提交\n"
+
+#: wt-status.c:1776
+#, c-format
+msgid ""
+"nothing added to commit but untracked files present (use \"git add\" to "
+"track)\n"
+msgstr "提交为空，但是存在尚未跟踪的文件（使用 \"git add\" 建立跟踪）\n"
+
+#: wt-status.c:1779
+#, c-format
+msgid "nothing added to commit but untracked files present\n"
+msgstr "提交为空，但是存在尚未跟踪的文件\n"
+
+#  译者：中文字符串拼接，可删除前导空格
+#: wt-status.c:1782
+#, c-format
+msgid "nothing to commit (create/copy files and use \"git add\" to track)\n"
+msgstr "无文件要提交（创建/拷贝文件并使用 \"git add\" 建立跟踪）\n"
+
+#: wt-status.c:1785 wt-status.c:1790
+#, c-format
+msgid "nothing to commit\n"
+msgstr "无文件要提交\n"
+
+#  译者：中文字符串拼接，可删除前导空格
+#: wt-status.c:1788
+#, c-format
+msgid "nothing to commit (use -u to show untracked files)\n"
+msgstr "无文件要提交（使用 -u 显示未跟踪的文件）\n"
+
+#  译者：中文字符串拼接，可删除前导空格
+#: wt-status.c:1792
+#, c-format
+msgid "nothing to commit, working tree clean\n"
+msgstr "无文件要提交，干净的工作区\n"
+
+#: wt-status.c:1905
+msgid "No commits yet on "
+msgstr "尚无提交在 "
+
+#: wt-status.c:1909
+msgid "HEAD (no branch)"
+msgstr "HEAD（非分支）"
+
+#: wt-status.c:1940
+msgid "different"
+msgstr "不同"
+
+#  译者：注意保持句尾空格
+#: wt-status.c:1942 wt-status.c:1950
+msgid "behind "
+msgstr "落后 "
+
+#: wt-status.c:1945 wt-status.c:1948
+msgid "ahead "
+msgstr "领先 "
+
+#. TRANSLATORS: the action is e.g. "pull with rebase"
+#: wt-status.c:2470
+#, c-format
+msgid "cannot %s: You have unstaged changes."
+msgstr "不能%s：您有未暂存的变更。"
+
+#: wt-status.c:2476
+msgid "additionally, your index contains uncommitted changes."
+msgstr "另外，您的索引中包含未提交的变更。"
+
+#: wt-status.c:2478
+#, c-format
+msgid "cannot %s: Your index contains uncommitted changes."
+msgstr "不能%s：您的索引中包含未提交的变更。"
+
+#: compat/precompose_utf8.c:58 builtin/clone.c:455
+#, c-format
+msgid "failed to unlink '%s'"
+msgstr "删除 '%s' 失败"
+
+#: builtin/add.c:26
+msgid "git add [<options>] [--] <pathspec>..."
+msgstr "git add [<选项>] [--] <路径规格>..."
+
+#: builtin/add.c:87
+#, c-format
+msgid "unexpected diff status %c"
+msgstr "意外的差异状态 %c"
+
+#: builtin/add.c:92 builtin/commit.c:288
+msgid "updating files failed"
+msgstr "更新文件失败"
+
+#: builtin/add.c:102
+#, c-format
+msgid "remove '%s'\n"
+msgstr "删除 '%s'\n"
+
+#: builtin/add.c:177
+msgid "Unstaged changes after refreshing the index:"
+msgstr "刷新索引之后尚未被暂存的变更："
+
+#: builtin/add.c:252 builtin/rev-parse.c:899
+msgid "Could not read the index"
+msgstr "不能读取索引"
+
+#: builtin/add.c:263
+#, c-format
+msgid "Could not open '%s' for writing."
+msgstr "无法为写入打开 '%s'。"
+
+#: builtin/add.c:267
+msgid "Could not write patch"
+msgstr "不能生成补丁"
+
+#: builtin/add.c:270
+msgid "editing patch failed"
+msgstr "编辑补丁失败"
+
+#: builtin/add.c:273
+#, c-format
+msgid "Could not stat '%s'"
+msgstr "不能对 '%s' 调用 stat"
+
+#: builtin/add.c:275
+msgid "Empty patch. Aborted."
+msgstr "空补丁。异常终止。"
+
+#: builtin/add.c:280
+#, c-format
+msgid "Could not apply '%s'"
+msgstr "不能应用 '%s'"
+
+#: builtin/add.c:288
+msgid "The following paths are ignored by one of your .gitignore files:\n"
+msgstr "下列路径根据您的一个 .gitignore 文件而被忽略：\n"
+
+#: builtin/add.c:308 builtin/clean.c:910 builtin/fetch.c:163 builtin/mv.c:124
+#: builtin/prune-packed.c:56 builtin/pull.c:223 builtin/push.c:548
+#: builtin/remote.c:1344 builtin/rm.c:241 builtin/send-pack.c:165
+msgid "dry run"
+msgstr "演习"
+
+#: builtin/add.c:311
+msgid "interactive picking"
+msgstr "交互式拣选"
+
+#: builtin/add.c:312 builtin/checkout.c:1482 builtin/reset.c:307
+msgid "select hunks interactively"
+msgstr "交互式挑选数据块"
+
+#: builtin/add.c:313
+msgid "edit current diff and apply"
+msgstr "编辑当前差异并应用"
+
+#: builtin/add.c:314
+msgid "allow adding otherwise ignored files"
+msgstr "允许添加忽略的文件"
+
+#: builtin/add.c:315
+msgid "update tracked files"
+msgstr "更新已跟踪的文件"
+
+#: builtin/add.c:316
+msgid "renormalize EOL of tracked files (implies -u)"
+msgstr "对已跟踪文件（暗含 -u）重新归一换行符"
+
+#: builtin/add.c:317
+msgid "record only the fact that the path will be added later"
+msgstr "只记录，该路径稍后再添加"
+
+#: builtin/add.c:318
+msgid "add changes from all tracked and untracked files"
+msgstr "添加所有改变的已跟踪文件和未跟踪文件"
+
+#: builtin/add.c:321
+msgid "ignore paths removed in the working tree (same as --no-all)"
+msgstr "忽略工作区中移除的路径（和 --no-all 相同）"
+
+#: builtin/add.c:323
+msgid "don't add, only refresh the index"
+msgstr "不添加，只刷新索引"
+
+#: builtin/add.c:324
+msgid "just skip files which cannot be added because of errors"
+msgstr "跳过因出错不能添加的文件"
+
+#: builtin/add.c:325
+msgid "check if - even missing - files are ignored in dry run"
+msgstr "检查在演习模式下文件（即使不存在）是否被忽略"
+
+#: builtin/add.c:327 builtin/update-index.c:1004
+msgid "override the executable bit of the listed files"
+msgstr "覆盖列表里文件的可执行位"
+
+#: builtin/add.c:329
+msgid "warn when adding an embedded repository"
+msgstr "创建一个嵌入式仓库时给予警告"
+
+#: builtin/add.c:347
+#, c-format
+msgid ""
+"You've added another git repository inside your current repository.\n"
+"Clones of the outer repository will not contain the contents of\n"
+"the embedded repository and will not know how to obtain it.\n"
+"If you meant to add a submodule, use:\n"
+"\n"
+"\tgit submodule add <url> %s\n"
+"\n"
+"If you added this path by mistake, you can remove it from the\n"
+"index with:\n"
+"\n"
+"\tgit rm --cached %s\n"
+"\n"
+"See \"git help submodule\" for more information."
+msgstr ""
+"您在当前仓库中添加了另一个Git仓库。克隆外层的仓库将不包含嵌入仓库的\n"
+"内容，并且不知道该如何获取它。如果您要添加一个子模组，使用：\n"
+"\n"
+"\tgit submodule add <url> %s\n"
+"\n"
+"如果您不小心添加了这个路径，可以用下面的命令将其从索引中删除：\n"
+"\n"
+"\tgit rm --cached %s\n"
+"\n"
+"参见 \"git help submodule\" 获取更多信息。"
+
+#: builtin/add.c:375
+#, c-format
+msgid "adding embedded git repository: %s"
+msgstr "正在添加嵌入式 git 仓库：%s"
+
+#: builtin/add.c:393
+#, c-format
+msgid "Use -f if you really want to add them.\n"
+msgstr "使用 -f 参数如果您确实要添加它们。\n"
+
+#: builtin/add.c:400
+msgid "adding files failed"
+msgstr "添加文件失败"
+
+#: builtin/add.c:428 builtin/commit.c:348
+msgid "--pathspec-from-file is incompatible with --interactive/--patch"
+msgstr "--pathspec-from-file 与 --interactive/--patch 不兼容"
+
+#: builtin/add.c:434
+msgid "--pathspec-from-file is incompatible with --edit"
+msgstr "--pathspec-from-file 与 --edit 不兼容"
+
+#: builtin/add.c:446
+msgid "-A and -u are mutually incompatible"
+msgstr "-A 和 -u 选项互斥"
+
+#: builtin/add.c:449
+msgid "Option --ignore-missing can only be used together with --dry-run"
+msgstr "选项 --ignore-missing 只能和 --dry-run 同时使用"
+
+#: builtin/add.c:453
+#, c-format
+msgid "--chmod param '%s' must be either -x or +x"
+msgstr "参数 --chmod 取值 '%s' 必须是 -x 或 +x"
+
+#: builtin/add.c:471 builtin/checkout.c:1648 builtin/commit.c:354
+#: builtin/reset.c:327
+msgid "--pathspec-from-file is incompatible with pathspec arguments"
+msgstr "--pathspec-from-file 与路径表达式参数不兼容"
+
+#: builtin/add.c:478 builtin/checkout.c:1660 builtin/commit.c:360
+#: builtin/reset.c:333
+msgid "--pathspec-file-nul requires --pathspec-from-file"
+msgstr "--pathspec-file-nul 需要 --pathspec-from-file"
+
+#: builtin/add.c:482
+#, c-format
+msgid "Nothing specified, nothing added.\n"
+msgstr "没有指定文件，也没有文件被添加。\n"
+
+#: builtin/add.c:483
+#, c-format
+msgid "Maybe you wanted to say 'git add .'?\n"
+msgstr "也许您想要执行 'git add .'？\n"
+
+#: builtin/am.c:347
+msgid "could not parse author script"
+msgstr "不能解析作者脚本"
+
+#: builtin/am.c:431
+#, c-format
+msgid "'%s' was deleted by the applypatch-msg hook"
+msgstr "'%s' 被 applypatch-msg 钩子删除"
+
+#: builtin/am.c:473
+#, c-format
+msgid "Malformed input line: '%s'."
+msgstr "非法的输入行：'%s'。"
+
+#: builtin/am.c:511
+#, c-format
+msgid "Failed to copy notes from '%s' to '%s'"
+msgstr "从 '%s' 拷贝注解到 '%s' 时失败"
+
+#: builtin/am.c:537
+msgid "fseek failed"
+msgstr "fseek 失败"
+
+#: builtin/am.c:725
+#, c-format
+msgid "could not parse patch '%s'"
+msgstr "无法解析补丁 '%s'"
+
+#: builtin/am.c:790
+msgid "Only one StGIT patch series can be applied at once"
+msgstr "一次只能有一个 StGIT 补丁队列被应用"
+
+#: builtin/am.c:838
+msgid "invalid timestamp"
+msgstr "无效的时间戳"
+
+#: builtin/am.c:843 builtin/am.c:855
+msgid "invalid Date line"
+msgstr "无效的日期行"
+
+#: builtin/am.c:850
+msgid "invalid timezone offset"
+msgstr "无效的时区偏移值"
+
+#: builtin/am.c:943
+msgid "Patch format detection failed."
+msgstr "补丁格式探测失败。"
+
+#: builtin/am.c:948 builtin/clone.c:409
+#, c-format
+msgid "failed to create directory '%s'"
+msgstr "创建目录 '%s' 失败"
+
+#: builtin/am.c:953
+msgid "Failed to split patches."
+msgstr "拆分补丁失败。"
+
+#: builtin/am.c:1084
+#, c-format
+msgid "When you have resolved this problem, run \"%s --continue\"."
+msgstr "当您解决这一问题，执行 \"%s --continue\"。"
+
+#: builtin/am.c:1085
+#, c-format
+msgid "If you prefer to skip this patch, run \"%s --skip\" instead."
+msgstr "如果您想要跳过这一补丁，则执行 \"%s --skip\"。"
+
+#: builtin/am.c:1086
+#, c-format
+msgid "To restore the original branch and stop patching, run \"%s --abort\"."
+msgstr "若要复原至原始分支并停止补丁操作，执行 \"%s --abort\"。"
+
+#: builtin/am.c:1169
+msgid "Patch sent with format=flowed; space at the end of lines might be lost."
+msgstr "补丁使用 format=flowed 格式发送，行尾的空格可能会丢失。"
+
+#: builtin/am.c:1197
+msgid "Patch is empty."
+msgstr "补丁为空。"
+
+#: builtin/am.c:1262
+#, c-format
+msgid "missing author line in commit %s"
+msgstr "在提交 %s 中缺失作者行"
+
+#: builtin/am.c:1265
+#, c-format
+msgid "invalid ident line: %.*s"
+msgstr "无效的身份标识：%.*s"
+
+#: builtin/am.c:1484
+msgid "Repository lacks necessary blobs to fall back on 3-way merge."
+msgstr "仓库缺乏必要的数据对象以进行三方合并。"
+
+#: builtin/am.c:1486
+msgid "Using index info to reconstruct a base tree..."
+msgstr "使用索引来重建一个（三方合并的）基础目录树..."
+
+#: builtin/am.c:1505
+msgid ""
+"Did you hand edit your patch?\n"
+"It does not apply to blobs recorded in its index."
+msgstr ""
+"您是否曾手动编辑过您的补丁？\n"
+"无法应用补丁到索引中的数据对象上。"
+
+#: builtin/am.c:1511
+msgid "Falling back to patching base and 3-way merge..."
+msgstr "回落到基础版本上打补丁及进行三方合并..."
+
+#: builtin/am.c:1537
+msgid "Failed to merge in the changes."
+msgstr "无法合并变更。"
+
+#: builtin/am.c:1569
+msgid "applying to an empty history"
+msgstr "正应用到一个空历史上"
+
+#: builtin/am.c:1616 builtin/am.c:1620
+#, c-format
+msgid "cannot resume: %s does not exist."
+msgstr "无法继续：%s 不存在。"
+
+#: builtin/am.c:1638
+msgid "Commit Body is:"
+msgstr "提交内容为："
+
+#  译者：注意保持句尾空格
+#. TRANSLATORS: Make sure to include [y], [n], [e], [v] and [a]
+#. in your translation. The program will only accept English
+#. input at this point.
+#.
+#: builtin/am.c:1648
+#, c-format
+msgid "Apply? [y]es/[n]o/[e]dit/[v]iew patch/[a]ccept all: "
+msgstr "应用？是[y]/否[n]/编辑[e]/查看补丁[v]/应用所有[a]："
+
+#: builtin/am.c:1695 builtin/commit.c:394
+msgid "unable to write index file"
+msgstr "无法写入索引文件"
+
+#: builtin/am.c:1699
+#, c-format
+msgid "Dirty index: cannot apply patches (dirty: %s)"
+msgstr "脏索引：不能应用补丁（脏文件：%s）"
+
+#: builtin/am.c:1739 builtin/am.c:1807
+#, c-format
+msgid "Applying: %.*s"
+msgstr "应用：%.*s"
+
+#: builtin/am.c:1756
+msgid "No changes -- Patch already applied."
+msgstr "没有变更 —— 补丁已经应用过。"
+
+#: builtin/am.c:1762
+#, c-format
+msgid "Patch failed at %s %.*s"
+msgstr "打补丁失败于 %s %.*s"
+
+#: builtin/am.c:1766
+msgid "Use 'git am --show-current-patch' to see the failed patch"
+msgstr "用 'git am --show-current-patch' 命令查看失败的补丁"
+
+#: builtin/am.c:1810
+msgid ""
+"No changes - did you forget to use 'git add'?\n"
+"If there is nothing left to stage, chances are that something else\n"
+"already introduced the same changes; you might want to skip this patch."
+msgstr ""
+"没有变更 —— 您是不是忘了执行 'git add'？\n"
+"如果没有什么要添加到暂存区的，则很可能是其它提交已经引入了相同的变更。\n"
+"您也许想要跳过这个补丁。"
+
+#: builtin/am.c:1817
+msgid ""
+"You still have unmerged paths in your index.\n"
+"You should 'git add' each file with resolved conflicts to mark them as "
+"such.\n"
+"You might run `git rm` on a file to accept \"deleted by them\" for it."
+msgstr ""
+"在您的索引中仍存在未合并的路径。\n"
+"您应该对已经冲突解决的每一个文件执行 'git add' 来标记已经完成。 \n"
+"你可以对 \"由他们删除\" 的文件执行 `git rm` 命令。"
+
+#: builtin/am.c:1924 builtin/am.c:1928 builtin/am.c:1940 builtin/reset.c:346
+#: builtin/reset.c:354
+#, c-format
+msgid "Could not parse object '%s'."
+msgstr "不能解析对象 '%s'。"
+
+#: builtin/am.c:1976
+msgid "failed to clean index"
+msgstr "清空索引失败"
+
+#: builtin/am.c:2020
+msgid ""
+"You seem to have moved HEAD since the last 'am' failure.\n"
+"Not rewinding to ORIG_HEAD"
+msgstr "您好像在上一次 'am' 失败后移动了 HEAD。未回退至 ORIG_HEAD"
+
+#: builtin/am.c:2117
+#, c-format
+msgid "Invalid value for --patch-format: %s"
+msgstr "无效的 --patch-format 值：%s"
+
+#: builtin/am.c:2153
+msgid "git am [<options>] [(<mbox> | <Maildir>)...]"
+msgstr "git am [<选项>] [(<mbox> | <Maildir>)...]"
+
+#: builtin/am.c:2154
+msgid "git am [<options>] (--continue | --skip | --abort)"
+msgstr "git am [<选项>] (--continue | --skip | --abort)"
+
+#: builtin/am.c:2160
+msgid "run interactively"
+msgstr "以交互式方式运行"
+
+#: builtin/am.c:2162
+msgid "historical option -- no-op"
+msgstr "老的参数 —— 无作用"
+
+#: builtin/am.c:2164
+msgid "allow fall back on 3way merging if needed"
+msgstr "如果必要，允许使用三方合并。"
+
+#: builtin/am.c:2165 builtin/init-db.c:494 builtin/prune-packed.c:58
+#: builtin/repack.c:304 builtin/stash.c:811
+msgid "be quiet"
+msgstr "静默模式"
+
+#: builtin/am.c:2167
+msgid "add a Signed-off-by line to the commit message"
+msgstr "在提交说明中添加一个 Signed-off-by 签名"
+
+#: builtin/am.c:2170
+msgid "recode into utf8 (default)"
+msgstr "使用 utf8 字符集（默认）"
+
+#: builtin/am.c:2172
+msgid "pass -k flag to git-mailinfo"
+msgstr "向 git-mailinfo 传递 -k 参数"
+
+#: builtin/am.c:2174
+msgid "pass -b flag to git-mailinfo"
+msgstr "向 git-mailinfo 传递 -b 参数"
+
+#: builtin/am.c:2176
+msgid "pass -m flag to git-mailinfo"
+msgstr "向 git-mailinfo 传递 -m 参数"
+
+#: builtin/am.c:2178
+msgid "pass --keep-cr flag to git-mailsplit for mbox format"
+msgstr "针对 mbox 格式，向 git-mailsplit 传递 --keep-cr 参数"
+
+#: builtin/am.c:2181
+msgid "do not pass --keep-cr flag to git-mailsplit independent of am.keepcr"
+msgstr "不向 git-mailsplit 传递 --keep-cr 参数，覆盖 am.keepcr 的设置"
+
+#: builtin/am.c:2184
+msgid "strip everything before a scissors line"
+msgstr "丢弃裁切线前的所有内容"
+
+#: builtin/am.c:2186 builtin/am.c:2189 builtin/am.c:2192 builtin/am.c:2195
+#: builtin/am.c:2198 builtin/am.c:2201 builtin/am.c:2204 builtin/am.c:2207
+#: builtin/am.c:2213
+msgid "pass it through git-apply"
+msgstr "传递给 git-apply"
+
+#: builtin/am.c:2203 builtin/commit.c:1386 builtin/fmt-merge-msg.c:673
+#: builtin/fmt-merge-msg.c:676 builtin/grep.c:883 builtin/merge.c:249
+#: builtin/pull.c:160 builtin/pull.c:219 builtin/rebase.c:1469
+#: builtin/repack.c:315 builtin/repack.c:319 builtin/repack.c:321
+#: builtin/show-branch.c:650 builtin/show-ref.c:172 builtin/tag.c:403
+#: parse-options.h:154 parse-options.h:175 parse-options.h:316
+msgid "n"
+msgstr "n"
+
+#: builtin/am.c:2209 builtin/branch.c:661 builtin/for-each-ref.c:38
+#: builtin/replace.c:555 builtin/tag.c:437 builtin/verify-tag.c:38
+msgid "format"
+msgstr "格式"
+
+#: builtin/am.c:2210
+msgid "format the patch(es) are in"
+msgstr "补丁的格式"
+
+#: builtin/am.c:2216
+msgid "override error message when patch failure occurs"
+msgstr "打补丁失败时显示的错误信息"
+
+#: builtin/am.c:2218
+msgid "continue applying patches after resolving a conflict"
+msgstr "冲突解决后继续应用补丁"
+
+#: builtin/am.c:2221
+msgid "synonyms for --continue"
+msgstr "和 --continue 同义"
+
+#: builtin/am.c:2224
+msgid "skip the current patch"
+msgstr "跳过当前补丁"
+
+#: builtin/am.c:2227
+msgid "restore the original branch and abort the patching operation."
+msgstr "恢复原始分支并终止打补丁操作。"
+
+#: builtin/am.c:2230
+msgid "abort the patching operation but keep HEAD where it is."
+msgstr "终止补丁操作但保持 HEAD 不变。"
+
+#: builtin/am.c:2233
+msgid "show the patch being applied."
+msgstr "显示正在应用的补丁。"
+
+#: builtin/am.c:2237
+msgid "lie about committer date"
+msgstr "将作者日期作为提交日期"
+
+#: builtin/am.c:2239
+msgid "use current timestamp for author date"
+msgstr "用当前时间作为作者日期"
+
+#: builtin/am.c:2241 builtin/commit-tree.c:120 builtin/commit.c:1507
+#: builtin/merge.c:286 builtin/pull.c:194 builtin/rebase.c:509
+#: builtin/rebase.c:1513 builtin/revert.c:117 builtin/tag.c:418
+msgid "key-id"
+msgstr "key-id"
+
+#: builtin/am.c:2242 builtin/rebase.c:510 builtin/rebase.c:1514
+msgid "GPG-sign commits"
+msgstr "使用 GPG 签名提交"
+
+#: builtin/am.c:2245
+msgid "(internal use for git-rebase)"
+msgstr "（内部使用，用于 git-rebase）"
+
+#: builtin/am.c:2263
+msgid ""
+"The -b/--binary option has been a no-op for long time, and\n"
+"it will be removed. Please do not use it anymore."
+msgstr ""
+"参数 -b/--binary 已经很长时间不做任何实质操作了，并且将被移除。\n"
+"请不要再使用它了。"
+
+#: builtin/am.c:2270
+msgid "failed to read the index"
+msgstr "读取索引失败"
+
+#: builtin/am.c:2285
+#, c-format
+msgid "previous rebase directory %s still exists but mbox given."
+msgstr "之前的变基目录 %s 仍然存在，但却提供了 mbox。"
+
+#: builtin/am.c:2309
+#, c-format
+msgid ""
+"Stray %s directory found.\n"
+"Use \"git am --abort\" to remove it."
+msgstr ""
+"发现了错误的 %s 目录。\n"
+"使用 \"git am --abort\" 删除它。"
+
+#: builtin/am.c:2315
+msgid "Resolve operation not in progress, we are not resuming."
+msgstr "解决操作未进行，我们不会继续。"
+
+#: builtin/am.c:2325
+msgid "interactive mode requires patches on the command line"
+msgstr "交互式模式需要命令行上提供补丁"
+
+#: builtin/apply.c:8
+msgid "git apply [<options>] [<patch>...]"
+msgstr "git apply [<选项>] [<补丁>...]"
+
+#: builtin/archive.c:17
+#, c-format
+msgid "could not create archive file '%s'"
+msgstr "不能创建归档文件 '%s'"
+
+#: builtin/archive.c:20
+msgid "could not redirect output"
+msgstr "不能重定向输出"
+
+#: builtin/archive.c:37
+msgid "git archive: Remote with no URL"
+msgstr "git archive：未提供远程 URL"
+
+#: builtin/archive.c:61
+msgid "git archive: expected ACK/NAK, got a flush packet"
+msgstr "git archive：期望是 ACK/NAK，却得到 flush 包"
+
+#: builtin/archive.c:64
+#, c-format
+msgid "git archive: NACK %s"
+msgstr "git archive：NACK %s"
+
+#: builtin/archive.c:65
+msgid "git archive: protocol error"
+msgstr "git archive：协议错误"
+
+#: builtin/archive.c:69
+msgid "git archive: expected a flush"
+msgstr "git archive：应有一个 flush 包"
+
+#: builtin/bisect--helper.c:22
+msgid "git bisect--helper --next-all [--no-checkout]"
+msgstr "git bisect--helper --next-all [--no-checkout]"
+
+#: builtin/bisect--helper.c:23
+msgid "git bisect--helper --write-terms <bad_term> <good_term>"
+msgstr "git bisect--helper --write-terms <坏-术语> <好-术语>"
+
+#: builtin/bisect--helper.c:24
+msgid "git bisect--helper --bisect-clean-state"
+msgstr "git bisect--helper --bisect-clean-state"
+
+#: builtin/bisect--helper.c:25
+msgid "git bisect--helper --bisect-reset [<commit>]"
+msgstr "git bisect--helper --bisect-reset [<提交>]"
+
+#: builtin/bisect--helper.c:26
+msgid ""
+"git bisect--helper --bisect-write [--no-log] <state> <revision> <good_term> "
+"<bad_term>"
+msgstr ""
+"git bisect--helper --bisect-write [--no-log] <状态> <版本> <好-术语> <坏-术语"
+">"
+
+#: builtin/bisect--helper.c:27
+msgid ""
+"git bisect--helper --bisect-check-and-set-terms <command> <good_term> "
+"<bad_term>"
+msgstr ""
+"git bisect--helper --bisect-check-and-set-terms <命令> <好-术语> <坏-术语>"
+
+#: builtin/bisect--helper.c:28
+msgid "git bisect--helper --bisect-next-check <good_term> <bad_term> [<term>]"
+msgstr "git bisect--helper --bisect-next-check <好-术语> <坏-术语> [<术语>]"
+
+#: builtin/bisect--helper.c:29
+msgid ""
+"git bisect--helper --bisect-terms [--term-good | --term-old | --term-bad | --"
+"term-new]"
+msgstr ""
+"git bisect--helper --bisect-terms [--term-good | --term-old | --term-bad | --"
+"term-new]"
+
+#: builtin/bisect--helper.c:30
+msgid ""
+"git bisect--helper --bisect-start [--term-{old,good}=<term> --term-{new,bad}"
+"=<term>][--no-checkout] [<bad> [<good>...]] [--] [<paths>...]"
+msgstr ""
+"git bisect--helper --bisect-start [--term-{old,good}=<术语> --term-{new,bad}"
+"=<术语>][--no-checkout] [<坏> [<好>...]] [--] [<路径>...]"
+
+#: builtin/bisect--helper.c:86
+#, c-format
+msgid "'%s' is not a valid term"
+msgstr "'%s' 不是一个有效的术语"
+
+#: builtin/bisect--helper.c:90
+#, c-format
+msgid "can't use the builtin command '%s' as a term"
+msgstr "不能使用内置命令 '%s' 作为术语"
+
+#: builtin/bisect--helper.c:100
+#, c-format
+msgid "can't change the meaning of the term '%s'"
+msgstr "不能修改术语 '%s' 的含义"
+
+#: builtin/bisect--helper.c:111
+msgid "please use two different terms"
+msgstr "请使用两个不同的术语"
+
+#: builtin/bisect--helper.c:118
+msgid "could not open the file BISECT_TERMS"
+msgstr "不能打开文件 BISECT_TERMS"
+
+#: builtin/bisect--helper.c:155
+#, c-format
+msgid "We are not bisecting.\n"
+msgstr "我们没有在二分查找。\n"
+
+#: builtin/bisect--helper.c:163
+#, c-format
+msgid "'%s' is not a valid commit"
+msgstr "'%s' 不是一个有效的提交"
+
+#: builtin/bisect--helper.c:172
+#, c-format
+msgid ""
+"could not check out original HEAD '%s'. Try 'git bisect reset <commit>'."
+msgstr "不能检出原始 HEAD '%s'。尝试 'git bisect reset <提交>'。"
+
+#: builtin/bisect--helper.c:216
+#, c-format
+msgid "Bad bisect_write argument: %s"
+msgstr "坏的 bisect_write 参数：%s"
+
+#: builtin/bisect--helper.c:221
+#, c-format
+msgid "couldn't get the oid of the rev '%s'"
+msgstr "无法获取版本 '%s' 的对象 ID"
+
+#: builtin/bisect--helper.c:233
+#, c-format
+msgid "couldn't open the file '%s'"
+msgstr "无法打开文件 '%s'"
+
+#: builtin/bisect--helper.c:259
+#, c-format
+msgid "Invalid command: you're currently in a %s/%s bisect"
+msgstr "无效的命令：您当前正处于一个 %s/%s 二分查找中"
+
+#: builtin/bisect--helper.c:286
+#, c-format
+msgid ""
+"You need to give me at least one %s and %s revision.\n"
+"You can use \"git bisect %s\" and \"git bisect %s\" for that."
+msgstr ""
+"您需要给我至少一个 %s 和一个 %s 版本。\n"
+"为此您可以用 \"git bisect %s\" 和 \"git bisect %s\"。"
+
+#: builtin/bisect--helper.c:290
+#, c-format
+msgid ""
+"You need to start by \"git bisect start\".\n"
+"You then need to give me at least one %s and %s revision.\n"
+"You can use \"git bisect %s\" and \"git bisect %s\" for that."
+msgstr ""
+"您需要执行 \"git bisect start\" 来开始。\n"
+"然后需要提供我至少一个 %s 和一个 %s 版本。\n"
+"为此您可以用 \"git bisect %s\" 和 \"git bisect %s\" 命令。"
+
+#: builtin/bisect--helper.c:322
+#, c-format
+msgid "bisecting only with a %s commit"
+msgstr "在只有一个 %s 提交的情况下二分查找"
+
+#  译者：注意保持句尾空格
+#. TRANSLATORS: Make sure to include [Y] and [n] in your
+#. translation. The program will only accept English input
+#. at this point.
+#.
+#: builtin/bisect--helper.c:330
+msgid "Are you sure [Y/n]? "
+msgstr "您确认么[Y/n]？ "
+
+#: builtin/bisect--helper.c:377
+msgid "no terms defined"
+msgstr "未定义术语"
+
+#: builtin/bisect--helper.c:380
+#, c-format
+msgid ""
+"Your current terms are %s for the old state\n"
+"and %s for the new state.\n"
+msgstr "您当前针对旧状态的术语是 %s，对新状态的术语是 %s。\n"
+
+#: builtin/bisect--helper.c:390
+#, c-format
+msgid ""
+"invalid argument %s for 'git bisect terms'.\n"
+"Supported options are: --term-good|--term-old and --term-bad|--term-new."
+msgstr ""
+"命令 'git bisect terms' 的参数 %s 无效。\n"
+"支持的选项有：--term-good|--term-old 和 --term-bad|--term-new。"
+
+#: builtin/bisect--helper.c:476
+#, c-format
+msgid "unrecognized option: '%s'"
+msgstr "未识别的选项：'%s'"
+
+#: builtin/bisect--helper.c:480
+#, c-format
+msgid "'%s' does not appear to be a valid revision"
+msgstr "'%s' 看起来不是一个有效的版本"
+
+#: builtin/bisect--helper.c:512
+msgid "bad HEAD - I need a HEAD"
+msgstr "坏的 HEAD - 我需要一个 HEAD"
+
+#: builtin/bisect--helper.c:527
+#, c-format
+msgid "checking out '%s' failed. Try 'git bisect start <valid-branch>'."
+msgstr "检出 '%s' 失败。尝试 'git bisect start <有效分支>'。"
+
+#: builtin/bisect--helper.c:548
+msgid "won't bisect on cg-seek'ed tree"
+msgstr "不会在做了 cg-seek 的树上做二分查找"
+
+#: builtin/bisect--helper.c:551
+msgid "bad HEAD - strange symbolic ref"
+msgstr "坏的 HEAD - 奇怪的符号引用"
+
+#: builtin/bisect--helper.c:575
+#, c-format
+msgid "invalid ref: '%s'"
+msgstr "无效的引用：'%s'"
+
+#: builtin/bisect--helper.c:631
+msgid "perform 'git bisect next'"
+msgstr "执行 'git bisect next'"
+
+#: builtin/bisect--helper.c:633
+msgid "write the terms to .git/BISECT_TERMS"
+msgstr "将术语写入 .git/BISECT_TERMS"
+
+#: builtin/bisect--helper.c:635
+msgid "cleanup the bisection state"
+msgstr "清除二分查找状态"
+
+#: builtin/bisect--helper.c:637
+msgid "check for expected revs"
+msgstr "检查预期的版本"
+
+#: builtin/bisect--helper.c:639
+msgid "reset the bisection state"
+msgstr "清除二分查找状态"
+
+#: builtin/bisect--helper.c:641
+msgid "write out the bisection state in BISECT_LOG"
+msgstr "将二分查找的状态写入 BISECT_LOG"
+
+#: builtin/bisect--helper.c:643
+msgid "check and set terms in a bisection state"
+msgstr "在一个二分查找状态中检查和设置术语"
+
+#: builtin/bisect--helper.c:645
+msgid "check whether bad or good terms exist"
+msgstr "检查坏的或好的术语是否存在"
+
+#: builtin/bisect--helper.c:647
+msgid "print out the bisect terms"
+msgstr "打印二分查找术语"
+
+#: builtin/bisect--helper.c:649
+msgid "start the bisect session"
+msgstr "启动二分查找过程"
+
+#: builtin/bisect--helper.c:651
+msgid "update BISECT_HEAD instead of checking out the current commit"
+msgstr "更新 BISECT_HEAD 而非检出当前提交"
+
+#: builtin/bisect--helper.c:653
+msgid "no log for BISECT_WRITE"
+msgstr "BISECT_WRITE 无日志"
+
+#: builtin/bisect--helper.c:670
+msgid "--write-terms requires two arguments"
+msgstr "--write-terms 需要两个参数"
+
+#: builtin/bisect--helper.c:674
+msgid "--bisect-clean-state requires no arguments"
+msgstr "--bisect-clean-state 不带参数"
+
+#: builtin/bisect--helper.c:681
+msgid "--bisect-reset requires either no argument or a commit"
+msgstr "--bisect-reset 无需参数或者需要一个提交"
+
+#: builtin/bisect--helper.c:685
+msgid "--bisect-write requires either 4 or 5 arguments"
+msgstr "--bisect-write 需要 4 或 5 个参数"
+
+#: builtin/bisect--helper.c:691
+msgid "--check-and-set-terms requires 3 arguments"
+msgstr "--check-and-set-terms 需要 3 个参数"
+
+#: builtin/bisect--helper.c:697
+msgid "--bisect-next-check requires 2 or 3 arguments"
+msgstr "--bisect-next-check 需要 2 或 3 个参数"
+
+#: builtin/bisect--helper.c:703
+msgid "--bisect-terms requires 0 or 1 argument"
+msgstr "--bisect-terms 需要 0 或 1 个参数"
+
+#: builtin/blame.c:31
+msgid "git blame [<options>] [<rev-opts>] [<rev>] [--] <file>"
+msgstr "git blame [<选项>] [<版本选项>] [<版本>] [--] <文件>"
+
+#: builtin/blame.c:36
+msgid "<rev-opts> are documented in git-rev-list(1)"
+msgstr "<版本选项> 的文档记录在 git-rev-list(1) 中"
+
+#: builtin/blame.c:409
+#, c-format
+msgid "expecting a color: %s"
+msgstr "期望一个颜色：%s"
+
+#: builtin/blame.c:416
+msgid "must end with a color"
+msgstr "必须以一个颜色结尾"
+
+#: builtin/blame.c:729
+#, c-format
+msgid "invalid color '%s' in color.blame.repeatedLines"
+msgstr "设置 color.blame.repeatedLines 中的无效颜色 '%s'"
+
+#: builtin/blame.c:747
+msgid "invalid value for blame.coloring"
+msgstr "设置 blame.coloring 中的无效取值"
+
+#: builtin/blame.c:822
+#, c-format
+msgid "cannot find revision %s to ignore"
+msgstr "不能找到要忽略的版本 %s"
+
+#: builtin/blame.c:844
+msgid "Show blame entries as we find them, incrementally"
+msgstr "增量式地显示发现的 blame 条目"
+
+#: builtin/blame.c:845
+msgid "Show blank SHA-1 for boundary commits (Default: off)"
+msgstr "边界提交显示空的 SHA-1（默认：关闭）"
+
+#: builtin/blame.c:846
+msgid "Do not treat root commits as boundaries (Default: off)"
+msgstr "不把根提交作为边界（默认：关闭）"
+
+#: builtin/blame.c:847
+msgid "Show work cost statistics"
+msgstr "显示命令消耗统计"
+
+#: builtin/blame.c:848
+msgid "Force progress reporting"
+msgstr "强制进度显示"
+
+#: builtin/blame.c:849
+msgid "Show output score for blame entries"
+msgstr "显示判断 blame 条目位移的得分诊断信息"
+
+#: builtin/blame.c:850
+msgid "Show original filename (Default: auto)"
+msgstr "显示原始文件名（默认：自动）"
+
+#: builtin/blame.c:851
+msgid "Show original linenumber (Default: off)"
+msgstr "显示原始的行号（默认：关闭）"
+
+#: builtin/blame.c:852
+msgid "Show in a format designed for machine consumption"
+msgstr "显示为一个适合机器读取的格式"
+
+#: builtin/blame.c:853
+msgid "Show porcelain format with per-line commit information"
+msgstr "为每一行显示机器适用的提交信息"
+
+#: builtin/blame.c:854
+msgid "Use the same output mode as git-annotate (Default: off)"
+msgstr "使用和 git-annotate 相同的输出模式（默认：关闭）"
+
+#: builtin/blame.c:855
+msgid "Show raw timestamp (Default: off)"
+msgstr "显示原始时间戳（默认：关闭）"
+
+#: builtin/blame.c:856
+msgid "Show long commit SHA1 (Default: off)"
+msgstr "显示长的 SHA1 提交号（默认：关闭）"
+
+#: builtin/blame.c:857
+msgid "Suppress author name and timestamp (Default: off)"
+msgstr "隐藏作者名字和时间戳（默认：关闭）"
+
+#: builtin/blame.c:858
+msgid "Show author email instead of name (Default: off)"
+msgstr "显示作者的邮箱而不是名字（默认：关闭）"
+
+#: builtin/blame.c:859
+msgid "Ignore whitespace differences"
+msgstr "忽略空白差异"
+
+#: builtin/blame.c:860 builtin/log.c:1702
+msgid "rev"
+msgstr "版本"
+
+#: builtin/blame.c:860
+msgid "Ignore <rev> when blaming"
+msgstr "在执行 blame 操作时忽略 <版本>"
+
+#: builtin/blame.c:861
+msgid "Ignore revisions from <file>"
+msgstr "忽略来自 <文件> 中的版本"
+
+#: builtin/blame.c:862
+msgid "color redundant metadata from previous line differently"
+msgstr "使用颜色间隔输出与前一行不同的重复元信息"
+
+#: builtin/blame.c:863
+msgid "color lines by age"
+msgstr "依据时间着色"
+
+#: builtin/blame.c:864
+msgid "Spend extra cycles to find better match"
+msgstr "花费额外的循环来找到更好的匹配"
+
+#: builtin/blame.c:865
+msgid "Use revisions from <file> instead of calling git-rev-list"
+msgstr "使用来自 <文件> 的修订集而不是调用 git-rev-list"
+
+#: builtin/blame.c:866
+msgid "Use <file>'s contents as the final image"
+msgstr "使用 <文件> 的内容作为最终的图片"
+
+#: builtin/blame.c:867 builtin/blame.c:868
+msgid "score"
+msgstr "得分"
+
+#: builtin/blame.c:867
+msgid "Find line copies within and across files"
+msgstr "找到文件内及跨文件的行拷贝"
+
+#: builtin/blame.c:868
+msgid "Find line movements within and across files"
+msgstr "找到文件内及跨文件的行移动"
+
+#: builtin/blame.c:869
+msgid "n,m"
+msgstr "n,m"
+
+#: builtin/blame.c:869
+msgid "Process only line range n,m, counting from 1"
+msgstr "只处理行范围在 n 和 m 之间的，从 1 开始"
+
+#: builtin/blame.c:921
+msgid "--progress can't be used with --incremental or porcelain formats"
+msgstr "--progress 不能和 --incremental 或 --porcelain 同时使用"
+
+#. TRANSLATORS: This string is used to tell us the
+#. maximum display width for a relative timestamp in
+#. "git blame" output.  For C locale, "4 years, 11
+#. months ago", which takes 22 places, is the longest
+#. among various forms of relative timestamps, but
+#. your language may need more or fewer display
+#. columns.
+#.
+#: builtin/blame.c:972
+msgid "4 years, 11 months ago"
+msgstr "4 年 11 个月前"
+
+#: builtin/blame.c:1079
+#, c-format
+msgid "file %s has only %lu line"
+msgid_plural "file %s has only %lu lines"
+msgstr[0] "文件 %s 只有 %lu 行"
+msgstr[1] "文件 %s 只有 %lu 行"
+
+#: builtin/blame.c:1125
+msgid "Blaming lines"
+msgstr "追踪代码行"
+
+#: builtin/branch.c:29
+msgid "git branch [<options>] [-r | -a] [--merged | --no-merged]"
+msgstr "git branch [<选项>] [-r | -a] [--merged | --no-merged]"
+
+#: builtin/branch.c:30
+msgid "git branch [<options>] [-l] [-f] <branch-name> [<start-point>]"
+msgstr "git branch [<选项>] [-l] [-f] <分支名> [<起始点>]"
+
+#: builtin/branch.c:31
+msgid "git branch [<options>] [-r] (-d | -D) <branch-name>..."
+msgstr "git branch [<选项>] [-r] (-d | -D) <分支名>..."
+
+#: builtin/branch.c:32
+msgid "git branch [<options>] (-m | -M) [<old-branch>] <new-branch>"
+msgstr "git branch [<选项>] (-m | -M) [<旧分支>] <新分支>"
+
+#: builtin/branch.c:33
+msgid "git branch [<options>] (-c | -C) [<old-branch>] <new-branch>"
+msgstr "git branch [<选项>] (-c | -C) [<老分支>] <新分支>"
+
+#: builtin/branch.c:34
+msgid "git branch [<options>] [-r | -a] [--points-at]"
+msgstr "git branch [<选项>] [-r | -a] [--points-at]"
+
+#: builtin/branch.c:35
+msgid "git branch [<options>] [-r | -a] [--format]"
+msgstr "git branch [<选项>] [-r | -a] [--format]"
+
+#  译者：保持原换行格式，在输出时 %s 的替代内容会让字符串变长
+#: builtin/branch.c:154
+#, c-format
+msgid ""
+"deleting branch '%s' that has been merged to\n"
+"         '%s', but not yet merged to HEAD."
+msgstr ""
+"将要删除的分支 '%s' 已经被合并到\n"
+"         '%s'，但未合并到 HEAD。"
+
+#  译者：保持原换行格式，在输出时 %s 的替代内容会让字符串变长
+#: builtin/branch.c:158
+#, c-format
+msgid ""
+"not deleting branch '%s' that is not yet merged to\n"
+"         '%s', even though it is merged to HEAD."
+msgstr ""
+"并未删除分支 '%s'， 虽然它已经合并到 HEAD，\n"
+"         然而却尚未被合并到分支 '%s' 。"
 
-#: wt-status.c:1340
+#: builtin/branch.c:172
 #, c-format
-msgid "You are currently editing a commit while rebasing branch '%s' on '%s'."
-msgstr "您在执行将分支 '%s' 变基到 '%s' 的操作时编辑提交。"
-
-#: wt-status.c:1345
-msgid "You are currently editing a commit during a rebase."
-msgstr "您在执行变基操作时编辑提交。"
-
-#  译者：注意保持前导空格
-#: wt-status.c:1348
-msgid "  (use \"git commit --amend\" to amend the current commit)"
-msgstr "  （使用 \"git commit --amend\" 修补当前提交）"
+msgid "Couldn't look up commit object for '%s'"
+msgstr "无法查询 '%s' 指向的提交对象"
 
-#  译者：注意保持前导空格
-#: wt-status.c:1350
+#: builtin/branch.c:176
+#, c-format
 msgid ""
-"  (use \"git rebase --continue\" once you are satisfied with your changes)"
-msgstr "  （当您对您的修改满意后执行 \"git rebase --continue\"）"
+"The branch '%s' is not fully merged.\n"
+"If you are sure you want to delete it, run 'git branch -D %s'."
+msgstr ""
+"分支 '%s' 没有完全合并。\n"
+"如果您确认要删除它，执行 'git branch -D %s'。"
 
-#: wt-status.c:1360
-#, c-format
-msgid "You are currently cherry-picking commit %s."
-msgstr "您在执行拣选提交 %s 的操作。"
+#: builtin/branch.c:189
+msgid "Update of config-file failed"
+msgstr "更新配置文件失败"
 
-#  译者：注意保持前导空格
-#: wt-status.c:1365
-msgid "  (fix conflicts and run \"git cherry-pick --continue\")"
-msgstr "  （解决冲突并运行 \"git cherry-pick --continue\"）"
+#: builtin/branch.c:220
+msgid "cannot use -a with -d"
+msgstr "不能将 -a 和 -d 同时使用"
 
-#  译者：注意保持前导空格
-#: wt-status.c:1368
-msgid "  (all conflicts fixed: run \"git cherry-pick --continue\")"
-msgstr "  （所有冲突已解决：运行 \"git cherry-pick --continue\"）"
+#: builtin/branch.c:226
+msgid "Couldn't look up commit object for HEAD"
+msgstr "无法查询 HEAD 指向的提交对象"
 
-#  译者：注意保持前导空格
-#: wt-status.c:1370
-msgid "  (use \"git cherry-pick --abort\" to cancel the cherry-pick operation)"
-msgstr "  （使用 \"git cherry-pick --abort\" 以取消拣选操作）"
+#: builtin/branch.c:240
+#, c-format
+msgid "Cannot delete branch '%s' checked out at '%s'"
+msgstr "无法删除检出于 '%2$s' 的分支 '%1$s'。"
 
-#: wt-status.c:1379
+#: builtin/branch.c:255
 #, c-format
-msgid "You are currently reverting commit %s."
-msgstr "您在执行反转提交 %s 的操作。"
+msgid "remote-tracking branch '%s' not found."
+msgstr "未能找到远程跟踪分支 '%s'。"
 
-#  译者：注意保持前导空格
-#: wt-status.c:1384
-msgid "  (fix conflicts and run \"git revert --continue\")"
-msgstr "  （解决冲突并运行 \"git revert --continue\"）"
+#: builtin/branch.c:256
+#, c-format
+msgid "branch '%s' not found."
+msgstr "分支 '%s' 未发现。"
 
-#  译者：注意保持前导空格
-#: wt-status.c:1387
-msgid "  (all conflicts fixed: run \"git revert --continue\")"
-msgstr "  （所有冲突已解决：运行 \"git revert --continue\"）"
+#: builtin/branch.c:271
+#, c-format
+msgid "Error deleting remote-tracking branch '%s'"
+msgstr "无法删除远程跟踪分支 '%s'"
 
-#  译者：注意保持前导空格
-#: wt-status.c:1389
-msgid "  (use \"git revert --abort\" to cancel the revert operation)"
-msgstr "  （使用 \"git revert --abort\" 以取消反转提交操作）"
+#: builtin/branch.c:272
+#, c-format
+msgid "Error deleting branch '%s'"
+msgstr "无法删除分支 '%s'"
 
-#: wt-status.c:1400
+#: builtin/branch.c:279
 #, c-format
-msgid "You are currently bisecting, started from branch '%s'."
-msgstr "您在执行从分支 '%s' 开始的二分查找操作。"
+msgid "Deleted remote-tracking branch %s (was %s).\n"
+msgstr "已删除远程跟踪分支 %s（曾为 %s）。\n"
 
-#: wt-status.c:1404
-msgid "You are currently bisecting."
-msgstr "您在执行二分查找操作。"
+#: builtin/branch.c:280
+#, c-format
+msgid "Deleted branch %s (was %s).\n"
+msgstr "已删除分支 %s（曾为 %s）。\n"
 
-#  译者：注意保持前导空格
-#: wt-status.c:1407
-msgid "  (use \"git bisect reset\" to get back to the original branch)"
-msgstr "  （使用 \"git bisect reset\" 以回到原有分支）"
+#: builtin/branch.c:429 builtin/tag.c:61
+msgid "unable to parse format string"
+msgstr "不能解析格式化字符串"
 
-#: wt-status.c:1604
-msgid "On branch "
-msgstr "位于分支 "
+#: builtin/branch.c:460
+msgid "could not resolve HEAD"
+msgstr "不能解析 HEAD 提交"
 
-#: wt-status.c:1610
-msgid "interactive rebase in progress; onto "
-msgstr "交互式变基操作正在进行中；至 "
+#: builtin/branch.c:466
+#, c-format
+msgid "HEAD (%s) points outside of refs/heads/"
+msgstr "HEAD (%s) 指向 refs/heads/ 之外"
 
-#: wt-status.c:1612
-msgid "rebase in progress; onto "
-msgstr "变基操作正在进行中；至 "
+#: builtin/branch.c:481
+#, c-format
+msgid "Branch %s is being rebased at %s"
+msgstr "分支 %s 正被变基到 %s"
 
-#: wt-status.c:1617
-msgid "HEAD detached at "
-msgstr "头指针分离于 "
+#: builtin/branch.c:485
+#, c-format
+msgid "Branch %s is being bisected at %s"
+msgstr "分支 %s 正被二分查找于 %s"
 
-#: wt-status.c:1619
-msgid "HEAD detached from "
-msgstr "头指针分离自 "
+#: builtin/branch.c:502
+msgid "cannot copy the current branch while not on any."
+msgstr "无法拷贝当前分支因为不处于任何分支上。"
 
-#: wt-status.c:1622
-msgid "Not currently on any branch."
-msgstr "当前不在任何分支上。"
+#: builtin/branch.c:504
+msgid "cannot rename the current branch while not on any."
+msgstr "无法重命名当前分支因为不处于任何分支上。"
 
-#: wt-status.c:1642
-msgid "Initial commit"
-msgstr "初始提交"
+#: builtin/branch.c:515
+#, c-format
+msgid "Invalid branch name: '%s'"
+msgstr "无效的分支名：'%s'"
 
-#: wt-status.c:1643
-msgid "No commits yet"
-msgstr "尚无提交"
+#: builtin/branch.c:542
+msgid "Branch rename failed"
+msgstr "分支重命名失败"
 
-#: wt-status.c:1657
-msgid "Untracked files"
-msgstr "未跟踪的文件"
+#: builtin/branch.c:544
+msgid "Branch copy failed"
+msgstr "分支拷贝失败"
 
-#: wt-status.c:1659
-msgid "Ignored files"
-msgstr "忽略的文件"
+#: builtin/branch.c:548
+#, c-format
+msgid "Created a copy of a misnamed branch '%s'"
+msgstr "已为错误命名的分支 '%s' 创建了一个副本"
 
-#: wt-status.c:1663
+#: builtin/branch.c:551
 #, c-format
-msgid ""
-"It took %.2f seconds to enumerate untracked files. 'status -uno'\n"
-"may speed it up, but you have to be careful not to forget to add\n"
-"new files yourself (see 'git help status')."
-msgstr ""
-"耗费了 %.2f 秒以枚举未跟踪的文件。'status -uno' 也许能提高速度，\n"
-"但您需要小心不要忘了添加新文件（参见 'git help status'）。"
+msgid "Renamed a misnamed branch '%s' away"
+msgstr "已将错误命名的分支 '%s' 重命名"
 
-#: wt-status.c:1669
+#: builtin/branch.c:557
 #, c-format
-msgid "Untracked files not listed%s"
-msgstr "未跟踪的文件没有列出%s"
+msgid "Branch renamed to %s, but HEAD is not updated!"
+msgstr "分支重命名为 %s，但 HEAD 没有更新！"
 
-#  译者：中文字符串拼接，可删除前导空格
-#: wt-status.c:1671
-msgid " (use -u option to show untracked files)"
-msgstr "（使用 -u 参数显示未跟踪的文件）"
+#: builtin/branch.c:566
+msgid "Branch is renamed, but update of config-file failed"
+msgstr "分支被重命名，但更新配置文件失败"
 
-#: wt-status.c:1677
-msgid "No changes"
-msgstr "没有修改"
+#: builtin/branch.c:568
+msgid "Branch is copied, but update of config-file failed"
+msgstr "分支已拷贝，但更新配置文件失败"
 
-#: wt-status.c:1682
+#: builtin/branch.c:584
 #, c-format
-msgid "no changes added to commit (use \"git add\" and/or \"git commit -a\")\n"
-msgstr "修改尚未加入提交（使用 \"git add\" 和/或 \"git commit -a\"）\n"
+msgid ""
+"Please edit the description for the branch\n"
+"  %s\n"
+"Lines starting with '%c' will be stripped.\n"
+msgstr ""
+"请编辑分支的描述\n"
+"  %s\n"
+"以 '%c' 开头的行将被过滤。\n"
 
-#: wt-status.c:1685
-#, c-format
-msgid "no changes added to commit\n"
-msgstr "修改尚未加入提交\n"
+#: builtin/branch.c:618
+msgid "Generic options"
+msgstr "通用选项"
 
-#: wt-status.c:1688
-#, c-format
-msgid ""
-"nothing added to commit but untracked files present (use \"git add\" to "
-"track)\n"
-msgstr "提交为空，但是存在尚未跟踪的文件（使用 \"git add\" 建立跟踪）\n"
+#: builtin/branch.c:620
+msgid "show hash and subject, give twice for upstream branch"
+msgstr "显示哈希值和主题，若参数出现两次则显示上游分支"
 
-#: wt-status.c:1691
-#, c-format
-msgid "nothing added to commit but untracked files present\n"
-msgstr "提交为空，但是存在尚未跟踪的文件\n"
+#: builtin/branch.c:621
+msgid "suppress informational messages"
+msgstr "不显示信息"
 
-#  译者：中文字符串拼接，可删除前导空格
-#: wt-status.c:1694
-#, c-format
-msgid "nothing to commit (create/copy files and use \"git add\" to track)\n"
-msgstr "无文件要提交（创建/拷贝文件并使用 \"git add\" 建立跟踪）\n"
+#: builtin/branch.c:622
+msgid "set up tracking mode (see git-pull(1))"
+msgstr "设置跟踪模式（参见 git-pull(1)）"
 
-#: wt-status.c:1697 wt-status.c:1702
-#, c-format
-msgid "nothing to commit\n"
-msgstr "无文件要提交\n"
+#: builtin/branch.c:624
+msgid "do not use"
+msgstr "不要使用"
 
-#  译者：中文字符串拼接，可删除前导空格
-#: wt-status.c:1700
-#, c-format
-msgid "nothing to commit (use -u to show untracked files)\n"
-msgstr "无文件要提交（使用 -u 显示未跟踪的文件）\n"
+#: builtin/branch.c:626 builtin/rebase.c:505
+msgid "upstream"
+msgstr "上游"
 
-#  译者：中文字符串拼接，可删除前导空格
-#: wt-status.c:1704
-#, c-format
-msgid "nothing to commit, working tree clean\n"
-msgstr "无文件要提交，干净的工作区\n"
+#: builtin/branch.c:626
+msgid "change the upstream info"
+msgstr "改变上游信息"
 
-#: wt-status.c:1817
-msgid "No commits yet on "
-msgstr "尚无提交在 "
+#: builtin/branch.c:627
+msgid "unset the upstream info"
+msgstr "取消上游信息的设置"
 
-#: wt-status.c:1821
-msgid "HEAD (no branch)"
-msgstr "HEAD（非分支）"
+#: builtin/branch.c:628
+msgid "use colored output"
+msgstr "使用彩色输出"
 
-#: wt-status.c:1852
-msgid "different"
-msgstr "不同"
+#: builtin/branch.c:629
+msgid "act on remote-tracking branches"
+msgstr "作用于远程跟踪分支"
 
-#  译者：注意保持句尾空格
-#: wt-status.c:1854 wt-status.c:1862
-msgid "behind "
-msgstr "落后 "
+#: builtin/branch.c:631 builtin/branch.c:633
+msgid "print only branches that contain the commit"
+msgstr "只打印包含该提交的分支"
 
-#: wt-status.c:1857 wt-status.c:1860
-msgid "ahead "
-msgstr "领先 "
+#: builtin/branch.c:632 builtin/branch.c:634
+msgid "print only branches that don't contain the commit"
+msgstr "只打印不包含该提交的分支"
 
-#. TRANSLATORS: the action is e.g. "pull with rebase"
-#: wt-status.c:2366
-#, c-format
-msgid "cannot %s: You have unstaged changes."
-msgstr "不能%s：您有未暂存的变更。"
+#: builtin/branch.c:637
+msgid "Specific git-branch actions:"
+msgstr "具体的 git-branch 动作："
 
-#: wt-status.c:2372
-msgid "additionally, your index contains uncommitted changes."
-msgstr "另外，您的索引中包含未提交的变更。"
+#: builtin/branch.c:638
+msgid "list both remote-tracking and local branches"
+msgstr "列出远程跟踪及本地分支"
 
-#: wt-status.c:2374
-#, c-format
-msgid "cannot %s: Your index contains uncommitted changes."
-msgstr "不能%s：您的索引中包含未提交的变更。"
+#: builtin/branch.c:640
+msgid "delete fully merged branch"
+msgstr "删除完全合并的分支"
 
-#: compat/precompose_utf8.c:58 builtin/clone.c:442
-#, c-format
-msgid "failed to unlink '%s'"
-msgstr "无法删除 '%s'"
+#: builtin/branch.c:641
+msgid "delete branch (even if not merged)"
+msgstr "删除分支（即使没有合并）"
 
-#: builtin/add.c:24
-msgid "git add [<options>] [--] <pathspec>..."
-msgstr "git add [<选项>] [--] <路径规格>..."
+#: builtin/branch.c:642
+msgid "move/rename a branch and its reflog"
+msgstr "移动/重命名一个分支，以及它的引用日志"
 
-#: builtin/add.c:83
-#, c-format
-msgid "unexpected diff status %c"
-msgstr "意外的差异状态 %c"
+#: builtin/branch.c:643
+msgid "move/rename a branch, even if target exists"
+msgstr "移动/重命名一个分支，即使目标已存在"
 
-#: builtin/add.c:88 builtin/commit.c:266
-msgid "updating files failed"
-msgstr "更新文件失败"
+#: builtin/branch.c:644
+msgid "copy a branch and its reflog"
+msgstr "拷贝一个分支和它的引用日志"
+
+#: builtin/branch.c:645
+msgid "copy a branch, even if target exists"
+msgstr "拷贝一个分支，即使目标已存在"
+
+#: builtin/branch.c:646
+msgid "list branch names"
+msgstr "列出分支名"
 
-#: builtin/add.c:98
-#, c-format
-msgid "remove '%s'\n"
-msgstr "删除 '%s'\n"
+#: builtin/branch.c:647
+msgid "show current branch name"
+msgstr "显示当前分支名"
 
-#: builtin/add.c:173
-msgid "Unstaged changes after refreshing the index:"
-msgstr "刷新索引之后尚未被暂存的变更："
+#: builtin/branch.c:648
+msgid "create the branch's reflog"
+msgstr "创建分支的引用日志"
 
-#: builtin/add.c:233 builtin/rev-parse.c:892
-msgid "Could not read the index"
-msgstr "不能读取索引"
+#: builtin/branch.c:650
+msgid "edit the description for the branch"
+msgstr "标记分支的描述"
 
-#: builtin/add.c:244
-#, c-format
-msgid "Could not open '%s' for writing."
-msgstr "无法打开 '%s' 进行写入。"
+#: builtin/branch.c:651
+msgid "force creation, move/rename, deletion"
+msgstr "强制创建、移动/重命名、删除"
 
-#: builtin/add.c:248
-msgid "Could not write patch"
-msgstr "不能生成补丁"
+#: builtin/branch.c:652
+msgid "print only branches that are merged"
+msgstr "只打印已经合并的分支"
 
-#: builtin/add.c:251
-msgid "editing patch failed"
-msgstr "编辑补丁失败"
+#: builtin/branch.c:653
+msgid "print only branches that are not merged"
+msgstr "只打印尚未合并的分支"
 
-#: builtin/add.c:254
-#, c-format
-msgid "Could not stat '%s'"
-msgstr "不能对 '%s' 调用 stat"
+#: builtin/branch.c:654
+msgid "list branches in columns"
+msgstr "以列的方式显示分支"
 
-#: builtin/add.c:256
-msgid "Empty patch. Aborted."
-msgstr "空补丁。异常终止。"
+#: builtin/branch.c:657 builtin/for-each-ref.c:42 builtin/notes.c:415
+#: builtin/notes.c:418 builtin/notes.c:581 builtin/notes.c:584
+#: builtin/tag.c:433
+msgid "object"
+msgstr "对象"
 
-#: builtin/add.c:261
-#, c-format
-msgid "Could not apply '%s'"
-msgstr "不能应用 '%s'"
+#: builtin/branch.c:658
+msgid "print only branches of the object"
+msgstr "只打印指向该对象的分支"
 
-#: builtin/add.c:269
-msgid "The following paths are ignored by one of your .gitignore files:\n"
-msgstr "下列路径根据您的一个 .gitignore 文件而被忽略：\n"
+#: builtin/branch.c:660 builtin/for-each-ref.c:48 builtin/tag.c:440
+msgid "sorting and filtering are case insensitive"
+msgstr "排序和过滤属于大小写不敏感"
 
-#: builtin/add.c:289 builtin/clean.c:911 builtin/fetch.c:145 builtin/mv.c:123
-#: builtin/prune-packed.c:55 builtin/pull.c:212 builtin/push.c:557
-#: builtin/remote.c:1342 builtin/rm.c:240 builtin/send-pack.c:165
-msgid "dry run"
-msgstr "演习"
+#: builtin/branch.c:661 builtin/for-each-ref.c:38 builtin/tag.c:438
+#: builtin/verify-tag.c:38
+msgid "format to use for the output"
+msgstr "输出格式"
 
-#: builtin/add.c:292
-msgid "interactive picking"
-msgstr "交互式拣选"
+#: builtin/branch.c:684 builtin/clone.c:784
+msgid "HEAD not found below refs/heads!"
+msgstr "HEAD 没有位于 /refs/heads 之下！"
 
-#: builtin/add.c:293 builtin/checkout.c:1135 builtin/reset.c:302
-msgid "select hunks interactively"
-msgstr "交互式挑选数据块"
+#: builtin/branch.c:708
+msgid "--column and --verbose are incompatible"
+msgstr "--column 和 --verbose 不兼容"
 
-#: builtin/add.c:294
-msgid "edit current diff and apply"
-msgstr "编辑当前差异并应用"
+#: builtin/branch.c:723 builtin/branch.c:777 builtin/branch.c:786
+msgid "branch name required"
+msgstr "必须提供分支名"
 
-#: builtin/add.c:295
-msgid "allow adding otherwise ignored files"
-msgstr "允许添加忽略的文件"
+#: builtin/branch.c:753
+msgid "Cannot give description to detached HEAD"
+msgstr "不能向分离头指针提供描述"
 
-#: builtin/add.c:296
-msgid "update tracked files"
-msgstr "更新已跟踪的文件"
+#: builtin/branch.c:758
+msgid "cannot edit description of more than one branch"
+msgstr "不能为一个以上的分支编辑描述"
 
-#: builtin/add.c:297
-msgid "renormalize EOL of tracked files (implies -u)"
-msgstr "对已跟踪文件（暗含 -u）重新归一换行符"
+#: builtin/branch.c:765
+#, c-format
+msgid "No commit on branch '%s' yet."
+msgstr "分支 '%s' 尚无提交。"
 
-#: builtin/add.c:298
-msgid "record only the fact that the path will be added later"
-msgstr "只记录，该路径稍后再添加"
+#: builtin/branch.c:768
+#, c-format
+msgid "No branch named '%s'."
+msgstr "没有分支 '%s'。"
 
-#: builtin/add.c:299
-msgid "add changes from all tracked and untracked files"
-msgstr "添加所有改变的已跟踪文件和未跟踪文件"
+#: builtin/branch.c:783
+msgid "too many branches for a copy operation"
+msgstr "为拷贝操作提供了太多的分支名"
 
-#: builtin/add.c:302
-msgid "ignore paths removed in the working tree (same as --no-all)"
-msgstr "忽略工作区中移除的路径（和 --no-all 相同）"
+#: builtin/branch.c:792
+msgid "too many arguments for a rename operation"
+msgstr "为重命名操作提供了太多的参数"
 
-#: builtin/add.c:304
-msgid "don't add, only refresh the index"
-msgstr "不添加，只刷新索引"
+#: builtin/branch.c:797
+msgid "too many arguments to set new upstream"
+msgstr "为设置新上游提供了太多的参数"
 
-#: builtin/add.c:305
-msgid "just skip files which cannot be added because of errors"
-msgstr "跳过因出错不能添加的文件"
+#: builtin/branch.c:801
+#, c-format
+msgid ""
+"could not set upstream of HEAD to %s when it does not point to any branch."
+msgstr "无法设置 HEAD 的上游为 %s，因为 HEAD 没有指向任何分支。"
 
-#: builtin/add.c:306
-msgid "check if - even missing - files are ignored in dry run"
-msgstr "检查在演习模式下文件（即使不存在）是否被忽略"
+#: builtin/branch.c:804 builtin/branch.c:827
+#, c-format
+msgid "no such branch '%s'"
+msgstr "没有此分支 '%s'"
 
-#: builtin/add.c:307 builtin/update-index.c:974
-msgid "(+/-)x"
-msgstr "(+/-)x"
+#: builtin/branch.c:808
+#, c-format
+msgid "branch '%s' does not exist"
+msgstr "分支 '%s' 不存在"
 
-#: builtin/add.c:307 builtin/update-index.c:975
-msgid "override the executable bit of the listed files"
-msgstr "覆盖列表里文件的可执行位"
+#: builtin/branch.c:821
+msgid "too many arguments to unset upstream"
+msgstr "为取消上游设置操作提供了太多的参数"
 
-#: builtin/add.c:309
-msgid "warn when adding an embedded repository"
-msgstr "创建一个嵌入式仓库时给予警告"
+#: builtin/branch.c:825
+msgid "could not unset upstream of HEAD when it does not point to any branch."
+msgstr "无法取消 HEAD 的上游设置因为它没有指向一个分支"
 
-#: builtin/add.c:324
+#: builtin/branch.c:831
 #, c-format
+msgid "Branch '%s' has no upstream information"
+msgstr "分支 '%s' 没有上游信息"
+
+#: builtin/branch.c:841
 msgid ""
-"You've added another git repository inside your current repository.\n"
-"Clones of the outer repository will not contain the contents of\n"
-"the embedded repository and will not know how to obtain it.\n"
-"If you meant to add a submodule, use:\n"
-"\n"
-"\tgit submodule add <url> %s\n"
-"\n"
-"If you added this path by mistake, you can remove it from the\n"
-"index with:\n"
-"\n"
-"\tgit rm --cached %s\n"
-"\n"
-"See \"git help submodule\" for more information."
+"The -a, and -r, options to 'git branch' do not take a branch name.\n"
+"Did you mean to use: -a|-r --list <pattern>?"
 msgstr ""
-"您在当前仓库中添加了另外一个Git仓库。克隆外层的仓库将不包含嵌入仓库的内容，并"
-"且不知道该如何获取它。\n"
-"如果您要添加一个子模组，使用：\n"
-"\n"
-"\tgit submodule add <url> %s\n"
-"\n"
-"如果您不小心添加了这个路径，可以用下面的命令将其从索引中删除：\n"
-"\n"
-"\tgit rm --cached %s\n"
-"\n"
-"参见 \"git help submodule\" 获取更多信息。"
+"'git branch' 的 -a 和 -r 选项不带一个分支名。\n"
+"您是否想要使用：-a|-r --list <模式>？"
 
-#: builtin/add.c:352
-#, c-format
-msgid "adding embedded git repository: %s"
-msgstr "正在添加嵌入式 git 仓库：%s"
+#: builtin/branch.c:845
+msgid ""
+"the '--set-upstream' option is no longer supported. Please use '--track' or "
+"'--set-upstream-to' instead."
+msgstr ""
+"不再支持选项 '--set-upstream'。请使用 '--track' 或 '--set-upstream-to'。"
 
-#: builtin/add.c:370
-#, c-format
-msgid "Use -f if you really want to add them.\n"
-msgstr "使用 -f 参数如果您确实要添加它们。\n"
+#: builtin/bundle.c:15 builtin/bundle.c:23
+msgid "git bundle create [<options>] <file> <git-rev-list args>"
+msgstr "git bundle create [<选项>] <文件> <git-rev-list 参数>"
+
+#: builtin/bundle.c:16 builtin/bundle.c:28
+msgid "git bundle verify [<options>] <file>"
+msgstr "git bundle verify [<选项>] <文件>"
+
+#: builtin/bundle.c:17 builtin/bundle.c:33
+msgid "git bundle list-heads <file> [<refname>...]"
+msgstr "git bundle list-heads <文件> [<引用名>...]"
+
+#: builtin/bundle.c:18 builtin/bundle.c:38
+msgid "git bundle unbundle <file> [<refname>...]"
+msgstr "git bundle unbundle <文件> [<引用名>...]"
 
-#: builtin/add.c:378
-msgid "adding files failed"
-msgstr "添加文件失败"
+#: builtin/bundle.c:66 builtin/pack-objects.c:3228
+msgid "do not show progress meter"
+msgstr "不显示进度表"
 
-#: builtin/add.c:416
-msgid "-A and -u are mutually incompatible"
-msgstr "-A 和 -u 选项互斥"
+#: builtin/bundle.c:68 builtin/pack-objects.c:3230
+msgid "show progress meter"
+msgstr "显示进度表"
 
-#: builtin/add.c:423
-msgid "Option --ignore-missing can only be used together with --dry-run"
-msgstr "选项 --ignore-missing 只能和 --dry-run 同时使用"
+#: builtin/bundle.c:70 builtin/pack-objects.c:3232
+msgid "show progress meter during object writing phase"
+msgstr "在对象写入阶段显示进度表"
 
-#: builtin/add.c:427
-#, c-format
-msgid "--chmod param '%s' must be either -x or +x"
-msgstr "参数 --chmod 取值 '%s' 必须是 -x 或 +x"
+#: builtin/bundle.c:73 builtin/pack-objects.c:3235
+msgid "similar to --all-progress when progress meter is shown"
+msgstr "当进度表显示时类似于 --all-progress"
 
-#: builtin/add.c:442
-#, c-format
-msgid "Nothing specified, nothing added.\n"
-msgstr "没有指定文件，也没有文件被添加。\n"
+#: builtin/bundle.c:93
+msgid "Need a repository to create a bundle."
+msgstr "需要一个仓库来创建包。"
 
-#: builtin/add.c:443
+#: builtin/bundle.c:104
+msgid "do not show bundle details"
+msgstr "不显示 bundle 细节"
+
+#: builtin/bundle.c:119
 #, c-format
-msgid "Maybe you wanted to say 'git add .'?\n"
-msgstr "也许您想要执行 'git add .'？\n"
+msgid "%s is okay\n"
+msgstr "%s 可以\n"
 
-#: builtin/add.c:448 builtin/check-ignore.c:177 builtin/checkout.c:280
-#: builtin/checkout.c:483 builtin/clean.c:958 builtin/commit.c:325
-#: builtin/diff-tree.c:114 builtin/mv.c:144 builtin/reset.c:241
-#: builtin/rm.c:270 builtin/submodule--helper.c:328
-msgid "index file corrupt"
-msgstr "索引文件损坏"
+#: builtin/bundle.c:160
+msgid "Need a repository to unbundle."
+msgstr "需要一个仓库来解包。"
 
-#: builtin/am.c:414
-msgid "could not parse author script"
-msgstr "不能解析作者脚本"
+#: builtin/bundle.c:168 builtin/remote.c:1609
+msgid "be verbose; must be placed before a subcommand"
+msgstr "冗长输出；必须置于子命令之前"
 
-#: builtin/am.c:498
+#: builtin/bundle.c:190 builtin/remote.c:1640
 #, c-format
-msgid "'%s' was deleted by the applypatch-msg hook"
-msgstr "'%s' 被 applypatch-msg 钩子删除"
+msgid "Unknown subcommand: %s"
+msgstr "未知子命令：%s"
 
-#: builtin/am.c:539
-#, c-format
-msgid "Malformed input line: '%s'."
-msgstr "非法的输入行：'%s'。"
+#: builtin/cat-file.c:595
+msgid ""
+"git cat-file (-t [--allow-unknown-type] | -s [--allow-unknown-type] | -e | -"
+"p | <type> | --textconv | --filters) [--path=<path>] <object>"
+msgstr ""
+"git cat-file (-t [--allow-unknown-type] | -s [--allow-unknown-type] | -e | -"
+"p | <类型> | --textconv | --filters) [--path=<路径>] <对象>"
 
-#: builtin/am.c:576
-#, c-format
-msgid "Failed to copy notes from '%s' to '%s'"
-msgstr "从 '%s' 拷贝注解到 '%s' 时失败"
+#: builtin/cat-file.c:596
+msgid ""
+"git cat-file (--batch | --batch-check) [--follow-symlinks] [--textconv | --"
+"filters]"
+msgstr ""
+"git cat-file (--batch | --batch-check) [--follow-symlinks] [--textconv | --"
+"filters]"
 
-#: builtin/am.c:602
-msgid "fseek failed"
-msgstr "fseek 失败"
+#: builtin/cat-file.c:617
+msgid "only one batch option may be specified"
+msgstr "只能指定一个批处理选项"
 
-#: builtin/am.c:790
-#, c-format
-msgid "could not parse patch '%s'"
-msgstr "无法解析补丁 '%s'"
+#: builtin/cat-file.c:635
+msgid "<type> can be one of: blob, tree, commit, tag"
+msgstr "<类型> 可以是其中之一：blob、tree、commit、tag"
 
-#: builtin/am.c:855
-msgid "Only one StGIT patch series can be applied at once"
-msgstr "一次只能有一个 StGIT 补丁队列被应用"
+#: builtin/cat-file.c:636
+msgid "show object type"
+msgstr "显示对象类型"
 
-#: builtin/am.c:903
-msgid "invalid timestamp"
-msgstr "无效的时间戳"
+#: builtin/cat-file.c:637
+msgid "show object size"
+msgstr "显示对象大小"
 
-#: builtin/am.c:908 builtin/am.c:920
-msgid "invalid Date line"
-msgstr "无效的日期行"
+#: builtin/cat-file.c:639
+msgid "exit with zero when there's no error"
+msgstr "当没有错误时退出并返回零"
 
-#: builtin/am.c:915
-msgid "invalid timezone offset"
-msgstr "无效的时区偏移值"
+#: builtin/cat-file.c:640
+msgid "pretty-print object's content"
+msgstr "美观地打印对象的内容"
 
-#: builtin/am.c:1008
-msgid "Patch format detection failed."
-msgstr "补丁格式探测失败。"
+#: builtin/cat-file.c:642
+msgid "for blob objects, run textconv on object's content"
+msgstr "对于数据对象，对其内容做文本转换"
 
-#: builtin/am.c:1013 builtin/clone.c:407
-#, c-format
-msgid "failed to create directory '%s'"
-msgstr "无法创建目录 '%s'"
+#: builtin/cat-file.c:644
+msgid "for blob objects, run filters on object's content"
+msgstr "对于数据对象，对其内容做过滤"
 
-#: builtin/am.c:1018
-msgid "Failed to split patches."
-msgstr "无法拆分补丁。"
+#: builtin/cat-file.c:645 git-submodule.sh:992
+msgid "blob"
+msgstr "数据对象"
 
-#: builtin/am.c:1148 builtin/commit.c:351
-msgid "unable to write index file"
-msgstr "无法写入索引文件"
+#: builtin/cat-file.c:646
+msgid "use a specific path for --textconv/--filters"
+msgstr "对于 --textconv/--filters 使用一个特定的路径"
 
-#: builtin/am.c:1162
-#, c-format
-msgid "When you have resolved this problem, run \"%s --continue\"."
-msgstr "当您解决这一问题，执行 \"%s --continue\"。"
+#: builtin/cat-file.c:648
+msgid "allow -s and -t to work with broken/corrupt objects"
+msgstr "允许 -s 和 -t 对损坏的对象生效"
 
-#: builtin/am.c:1163
-#, c-format
-msgid "If you prefer to skip this patch, run \"%s --skip\" instead."
-msgstr "如果您想要跳过这一补丁，则执行 \"%s --skip\"。"
+#: builtin/cat-file.c:649
+msgid "buffer --batch output"
+msgstr "缓冲 --batch 的输出"
+
+#: builtin/cat-file.c:651
+msgid "show info and content of objects fed from the standard input"
+msgstr "显示从标准输入提供的对象的信息和内容"
 
-#: builtin/am.c:1164
-#, c-format
-msgid "To restore the original branch and stop patching, run \"%s --abort\"."
-msgstr "若要复原至原始分支并停止补丁操作，执行 \"%s --abort\"。"
+#: builtin/cat-file.c:655
+msgid "show info about objects fed from the standard input"
+msgstr "显示从标准输入提供的对象的信息"
 
-#: builtin/am.c:1271
-msgid "Patch is empty."
-msgstr "补丁为空。"
+#: builtin/cat-file.c:659
+msgid "follow in-tree symlinks (used with --batch or --batch-check)"
+msgstr "跟随树内符号链接（和 --batch 或 --batch-check 共用）"
 
-#: builtin/am.c:1337
-#, c-format
-msgid "invalid ident line: %.*s"
-msgstr "无效的身份标识：%.*s"
+#: builtin/cat-file.c:661
+msgid "show all objects with --batch or --batch-check"
+msgstr "使用 --batch 或 --batch-check 参数显示所有对象"
 
-#: builtin/am.c:1359
-#, c-format
-msgid "unable to parse commit %s"
-msgstr "不能解析提交 %s"
+#: builtin/cat-file.c:663
+msgid "do not order --batch-all-objects output"
+msgstr "不要对 --batch-all-objects 的输出排序"
 
-#: builtin/am.c:1554
-msgid "Repository lacks necessary blobs to fall back on 3-way merge."
-msgstr "仓库缺乏必要的数据对象以进行三方合并。"
+#: builtin/check-attr.c:13
+msgid "git check-attr [-a | --all | <attr>...] [--] <pathname>..."
+msgstr "git check-attr [-a | --all | <属性>...] [--] <路径名>..."
 
-#: builtin/am.c:1556
-msgid "Using index info to reconstruct a base tree..."
-msgstr "使用索引来重建一个（三方合并的）基础目录树..."
+#: builtin/check-attr.c:14
+msgid "git check-attr --stdin [-z] [-a | --all | <attr>...]"
+msgstr "git check-attr --stdin [-z] [-a | --all | <属性>...]"
 
-#: builtin/am.c:1575
-msgid ""
-"Did you hand edit your patch?\n"
-"It does not apply to blobs recorded in its index."
-msgstr ""
-"您是否曾手动编辑过您的补丁？\n"
-"无法应用补丁到索引中的数据对象上。"
+#: builtin/check-attr.c:21
+msgid "report all attributes set on file"
+msgstr "报告设置在文件上的所有属性"
 
-#: builtin/am.c:1581
-msgid "Falling back to patching base and 3-way merge..."
-msgstr "回落到基础版本上打补丁及进行三方合并..."
+#: builtin/check-attr.c:22
+msgid "use .gitattributes only from the index"
+msgstr "只使用索引中的 .gitattributes"
 
-#: builtin/am.c:1606
-msgid "Failed to merge in the changes."
-msgstr "无法合并变更。"
+#: builtin/check-attr.c:23 builtin/check-ignore.c:25 builtin/hash-object.c:102
+msgid "read file names from stdin"
+msgstr "从标准输入读出文件名"
 
-#: builtin/am.c:1637
-msgid "applying to an empty history"
-msgstr "正应用到一个空历史上"
+#: builtin/check-attr.c:25 builtin/check-ignore.c:27
+msgid "terminate input and output records by a NUL character"
+msgstr "输入和输出的记录使用 NUL 字符终结"
 
-#: builtin/am.c:1683 builtin/am.c:1687
-#, c-format
-msgid "cannot resume: %s does not exist."
-msgstr "无法继续：%s 不存在。"
+#: builtin/check-ignore.c:21 builtin/checkout.c:1435 builtin/gc.c:537
+#: builtin/worktree.c:506
+msgid "suppress progress reporting"
+msgstr "不显示进度报告"
 
-#: builtin/am.c:1703
-msgid "cannot be interactive without stdin connected to a terminal."
-msgstr "标准输入没有和终端关联，不能进行交互式操作。"
+#: builtin/check-ignore.c:29
+msgid "show non-matching input paths"
+msgstr "显示未匹配的输入路径"
 
-#: builtin/am.c:1708
-msgid "Commit Body is:"
-msgstr "提交内容为："
+#: builtin/check-ignore.c:31
+msgid "ignore index when checking"
+msgstr "检查时忽略索引"
 
-#  译者：注意保持句尾空格
-#. TRANSLATORS: Make sure to include [y], [n], [e], [v] and [a]
-#. in your translation. The program will only accept English
-#. input at this point.
-#.
-#: builtin/am.c:1718
-msgid "Apply? [y]es/[n]o/[e]dit/[v]iew patch/[a]ccept all: "
-msgstr "应用？是[y]/否[n]/编辑[e]/查看补丁[v]/应用所有[a]："
+#: builtin/check-ignore.c:160
+msgid "cannot specify pathnames with --stdin"
+msgstr "不能同时指定路径及 --stdin 参数"
 
-#: builtin/am.c:1768
-#, c-format
-msgid "Dirty index: cannot apply patches (dirty: %s)"
-msgstr "脏索引：不能应用补丁（脏文件：%s）"
+#: builtin/check-ignore.c:163
+msgid "-z only makes sense with --stdin"
+msgstr "-z 需要和 --stdin 参数共用才有意义"
 
-#: builtin/am.c:1808 builtin/am.c:1879
-#, c-format
-msgid "Applying: %.*s"
-msgstr "应用：%.*s"
+#: builtin/check-ignore.c:165
+msgid "no path specified"
+msgstr "未指定路径"
 
-#: builtin/am.c:1824
-msgid "No changes -- Patch already applied."
-msgstr "没有变更 —— 补丁已经应用过。"
+#: builtin/check-ignore.c:169
+msgid "--quiet is only valid with a single pathname"
+msgstr "参数 --quiet 只在提供一个路径名时有效"
 
-#: builtin/am.c:1832
-#, c-format
-msgid "Patch failed at %s %.*s"
-msgstr "打补丁失败于 %s %.*s"
+#: builtin/check-ignore.c:171
+msgid "cannot have both --quiet and --verbose"
+msgstr "不能同时提供 --quiet 和 --verbose 参数"
 
-#: builtin/am.c:1838
-msgid "Use 'git am --show-current-patch' to see the failed patch"
-msgstr "用 'git am --show-current-patch' 命令查看失败的补丁"
+#: builtin/check-ignore.c:174
+msgid "--non-matching is only valid with --verbose"
+msgstr "--non-matching 选项只在使用 --verbose 时有效"
 
-#: builtin/am.c:1882
-msgid ""
-"No changes - did you forget to use 'git add'?\n"
-"If there is nothing left to stage, chances are that something else\n"
-"already introduced the same changes; you might want to skip this patch."
-msgstr ""
-"没有变更 —— 您是不是忘了执行 'git add'？\n"
-"如果没有什么要添加到暂存区的，则很可能是其它提交已经引入了相同的变更。\n"
-"您也许想要跳过这个补丁。"
+#: builtin/check-mailmap.c:9
+msgid "git check-mailmap [<options>] <contact>..."
+msgstr "git check-mailmap [<选项>] <联系地址>..."
 
-#: builtin/am.c:1889
-msgid ""
-"You still have unmerged paths in your index.\n"
-"You should 'git add' each file with resolved conflicts to mark them as "
-"such.\n"
-"You might run `git rm` on a file to accept \"deleted by them\" for it."
-msgstr ""
-"在您的索引中仍存在未合并的路径。\n"
-"您应该对已经冲突解决的每一个文件执行 'git add' 来标记已经完成。 \n"
-"你可以对 \"由他们删除\" 的文件执行 `git rm` 命令。"
+#: builtin/check-mailmap.c:14
+msgid "also read contacts from stdin"
+msgstr "还从标准输入读取联系地址"
 
-#: builtin/am.c:1996 builtin/am.c:2000 builtin/am.c:2012 builtin/reset.c:324
-#: builtin/reset.c:332
+#: builtin/check-mailmap.c:25
 #, c-format
-msgid "Could not parse object '%s'."
-msgstr "不能解析对象 '%s'。"
-
-#: builtin/am.c:2048
-msgid "failed to clean index"
-msgstr "无法清空索引"
+msgid "unable to parse contact: %s"
+msgstr "不能解析联系地址：%s"
 
-#: builtin/am.c:2083
-msgid ""
-"You seem to have moved HEAD since the last 'am' failure.\n"
-"Not rewinding to ORIG_HEAD"
-msgstr "您好像在上一次 'am' 失败后移动了 HEAD。未回退至 ORIG_HEAD"
+#: builtin/check-mailmap.c:48
+msgid "no contacts specified"
+msgstr "未指定联系地址"
 
-#: builtin/am.c:2174
-#, c-format
-msgid "Invalid value for --patch-format: %s"
-msgstr "无效的 --patch-format 值：%s"
+#: builtin/checkout-index.c:131
+msgid "git checkout-index [<options>] [--] [<file>...]"
+msgstr "git checkout-index [<选项>] [--] [<文件>...]"
 
-#: builtin/am.c:2210
-msgid "git am [<options>] [(<mbox> | <Maildir>)...]"
-msgstr "git am [<选项>] [(<mbox> | <Maildir>)...]"
+#: builtin/checkout-index.c:148
+msgid "stage should be between 1 and 3 or all"
+msgstr "索引值应该取值 1 到 3 或者 all"
 
-#: builtin/am.c:2211
-msgid "git am [<options>] (--continue | --skip | --abort)"
-msgstr "git am [<选项>] (--continue | --skip | --abort)"
+#: builtin/checkout-index.c:164
+msgid "check out all files in the index"
+msgstr "检出索引区的所有文件"
 
-#: builtin/am.c:2217
-msgid "run interactively"
-msgstr "以交互式方式运行"
+#: builtin/checkout-index.c:165
+msgid "force overwrite of existing files"
+msgstr "强制覆盖现有的文件"
 
-#: builtin/am.c:2219
-msgid "historical option -- no-op"
-msgstr "老的参数 —— 无作用"
+#: builtin/checkout-index.c:167
+msgid "no warning for existing files and files not in index"
+msgstr "存在或不在索引中的文件都没有警告"
 
-#: builtin/am.c:2221
-msgid "allow fall back on 3way merging if needed"
-msgstr "如果必要，允许使用三方合并。"
+#: builtin/checkout-index.c:169
+msgid "don't checkout new files"
+msgstr "不检出新文件"
 
-#: builtin/am.c:2222 builtin/init-db.c:484 builtin/prune-packed.c:57
-#: builtin/repack.c:192
-msgid "be quiet"
-msgstr "静默模式"
+#: builtin/checkout-index.c:171
+msgid "update stat information in the index file"
+msgstr "更新索引中文件的状态信息"
 
-#: builtin/am.c:2224
-msgid "add a Signed-off-by line to the commit message"
-msgstr "在提交说明中添加一个 Signed-off-by 签名"
+#: builtin/checkout-index.c:175
+msgid "read list of paths from the standard input"
+msgstr "从标准输入读取路径列表"
 
-#: builtin/am.c:2227
-msgid "recode into utf8 (default)"
-msgstr "使用 utf8 字符集（默认）"
+#: builtin/checkout-index.c:177
+msgid "write the content to temporary files"
+msgstr "将内容写入临时文件"
 
-#: builtin/am.c:2229
-msgid "pass -k flag to git-mailinfo"
-msgstr "向 git-mailinfo 传递 -k 参数"
+#: builtin/checkout-index.c:178 builtin/column.c:31
+#: builtin/submodule--helper.c:1385 builtin/submodule--helper.c:1388
+#: builtin/submodule--helper.c:1396 builtin/submodule--helper.c:1882
+#: builtin/worktree.c:679
+msgid "string"
+msgstr "字符串"
 
-#: builtin/am.c:2231
-msgid "pass -b flag to git-mailinfo"
-msgstr "向 git-mailinfo 传递 -b 参数"
+#: builtin/checkout-index.c:179
+msgid "when creating files, prepend <string>"
+msgstr "在创建文件时，在前面加上 <字符串>"
 
-#: builtin/am.c:2233
-msgid "pass -m flag to git-mailinfo"
-msgstr "向 git-mailinfo 传递 -m 参数"
+#: builtin/checkout-index.c:181
+msgid "copy out the files from named stage"
+msgstr "从指定暂存区中拷出文件"
 
-#: builtin/am.c:2235
-msgid "pass --keep-cr flag to git-mailsplit for mbox format"
-msgstr "针对 mbox 格式，向 git-mailsplit 传递 --keep-cr 参数"
+#: builtin/checkout.c:31
+msgid "git checkout [<options>] <branch>"
+msgstr "git checkout [<选项>] <分支>"
 
-#: builtin/am.c:2238
-msgid "do not pass --keep-cr flag to git-mailsplit independent of am.keepcr"
-msgstr "不向 git-mailsplit 传递 --keep-cr 参数，覆盖 am.keepcr 的设置"
+#: builtin/checkout.c:32
+msgid "git checkout [<options>] [<branch>] -- <file>..."
+msgstr "git checkout [<选项>] [<分支>] -- <文件>..."
 
-#: builtin/am.c:2241
-msgid "strip everything before a scissors line"
-msgstr "丢弃裁切线前的所有内容"
+#: builtin/checkout.c:37
+msgid "git switch [<options>] [<branch>]"
+msgstr "git switch [<选项>] [<分支>]"
+
+#: builtin/checkout.c:42
+msgid "git restore [<options>] [--source=<branch>] <file>..."
+msgstr "git restore [<选项>] [--source=<分支>] <文件>..."
 
-#: builtin/am.c:2243 builtin/am.c:2246 builtin/am.c:2249 builtin/am.c:2252
-#: builtin/am.c:2255 builtin/am.c:2258 builtin/am.c:2261 builtin/am.c:2264
-#: builtin/am.c:2270
-msgid "pass it through git-apply"
-msgstr "传递给 git-apply"
+#: builtin/checkout.c:175 builtin/checkout.c:214
+#, c-format
+msgid "path '%s' does not have our version"
+msgstr "路径 '%s' 没有我们的版本"
 
-#: builtin/am.c:2260 builtin/commit.c:1332 builtin/fmt-merge-msg.c:665
-#: builtin/fmt-merge-msg.c:668 builtin/grep.c:853 builtin/merge.c:208
-#: builtin/pull.c:150 builtin/pull.c:208 builtin/repack.c:201
-#: builtin/repack.c:205 builtin/repack.c:207 builtin/show-branch.c:631
-#: builtin/show-ref.c:169 builtin/tag.c:383 parse-options.h:144
-#: parse-options.h:146 parse-options.h:258
-msgid "n"
-msgstr "n"
+#: builtin/checkout.c:177 builtin/checkout.c:216
+#, c-format
+msgid "path '%s' does not have their version"
+msgstr "路径 '%s' 没有他们的版本"
 
-#: builtin/am.c:2266 builtin/branch.c:632 builtin/for-each-ref.c:38
-#: builtin/replace.c:543 builtin/tag.c:419 builtin/verify-tag.c:39
-msgid "format"
-msgstr "格式"
+#: builtin/checkout.c:193
+#, c-format
+msgid "path '%s' does not have all necessary versions"
+msgstr "路径 '%s' 没有全部必需的版本"
 
-#: builtin/am.c:2267
-msgid "format the patch(es) are in"
-msgstr "补丁的格式"
+#: builtin/checkout.c:243
+#, c-format
+msgid "path '%s' does not have necessary versions"
+msgstr "路径 '%s' 没有必需的版本"
 
-#: builtin/am.c:2273
-msgid "override error message when patch failure occurs"
-msgstr "打补丁失败时显示的错误信息"
+#: builtin/checkout.c:261
+#, c-format
+msgid "path '%s': cannot merge"
+msgstr "path '%s'：无法合并"
 
-#: builtin/am.c:2275
-msgid "continue applying patches after resolving a conflict"
-msgstr "冲突解决后继续应用补丁"
+#: builtin/checkout.c:277
+#, c-format
+msgid "Unable to add merge result for '%s'"
+msgstr "无法为 '%s' 添加合并结果"
 
-#: builtin/am.c:2278
-msgid "synonyms for --continue"
-msgstr "和 --continue 同义"
+#: builtin/checkout.c:377
+#, c-format
+msgid "Recreated %d merge conflict"
+msgid_plural "Recreated %d merge conflicts"
+msgstr[0] "重新创建了 %d 个合并冲突"
+msgstr[1] "重新创建了 %d 个合并冲突"
 
-#: builtin/am.c:2281
-msgid "skip the current patch"
-msgstr "跳过当前补丁"
+#: builtin/checkout.c:382
+#, c-format
+msgid "Updated %d path from %s"
+msgid_plural "Updated %d paths from %s"
+msgstr[0] "从 %2$s 更新了 %1$d 个路径"
+msgstr[1] "从 %2$s 更新了 %1$d 个路径"
 
-#: builtin/am.c:2284
-msgid "restore the original branch and abort the patching operation."
-msgstr "恢复原始分支并终止打补丁操作。"
+#: builtin/checkout.c:389
+#, c-format
+msgid "Updated %d path from the index"
+msgid_plural "Updated %d paths from the index"
+msgstr[0] "从索引区更新了 %d 个路径"
+msgstr[1] "从索引区更新了 %d 个路径"
 
-#: builtin/am.c:2287
-msgid "abort the patching operation but keep HEAD where it is."
-msgstr "终止补丁操作但保持 HEAD 不变。"
+#: builtin/checkout.c:412 builtin/checkout.c:415 builtin/checkout.c:418
+#: builtin/checkout.c:422
+#, c-format
+msgid "'%s' cannot be used with updating paths"
+msgstr "'%s' 不能在更新路径时使用"
 
-#: builtin/am.c:2290
-msgid "show the patch being applied."
-msgstr "显示正在应用的补丁。"
+#: builtin/checkout.c:425 builtin/checkout.c:428
+#, c-format
+msgid "'%s' cannot be used with %s"
+msgstr "'%s' 不能和 %s 同时使用"
 
-#: builtin/am.c:2294
-msgid "lie about committer date"
-msgstr "将作者日期作为提交日期"
+#: builtin/checkout.c:432
+#, c-format
+msgid "Cannot update paths and switch to branch '%s' at the same time."
+msgstr "不能同时更新路径并切换到分支'%s'。"
 
-#: builtin/am.c:2296
-msgid "use current timestamp for author date"
-msgstr "用当前时间作为作者日期"
+#: builtin/checkout.c:436
+#, c-format
+msgid "neither '%s' or '%s' is specified"
+msgstr "'%s' 或 '%s' 都没有指定"
 
-#: builtin/am.c:2298 builtin/commit.c:1468 builtin/merge.c:239
-#: builtin/pull.c:183 builtin/revert.c:112 builtin/tag.c:399
-msgid "key-id"
-msgstr "key-id"
+#: builtin/checkout.c:440
+#, c-format
+msgid "'%s' must be used when '%s' is not specified"
+msgstr "未指定 '%2$s' 时，必须使用 '%1$s'"
 
-#: builtin/am.c:2299
-msgid "GPG-sign commits"
-msgstr "使用 GPG 签名提交"
+#: builtin/checkout.c:445 builtin/checkout.c:450
+#, c-format
+msgid "'%s' or '%s' cannot be used with %s"
+msgstr "'%s' 或 '%s' 不能和 %s 一起使用"
 
-#: builtin/am.c:2302
-msgid "(internal use for git-rebase)"
-msgstr "（内部使用，用于 git-rebase）"
+#: builtin/checkout.c:509 builtin/checkout.c:516
+#, c-format
+msgid "path '%s' is unmerged"
+msgstr "路径 '%s' 未合并"
+
+#: builtin/checkout.c:682 builtin/sparse-checkout.c:82
+msgid "you need to resolve your current index first"
+msgstr "您需要先解决当前索引的冲突"
 
-#: builtin/am.c:2320
+#: builtin/checkout.c:732
+#, c-format
 msgid ""
-"The -b/--binary option has been a no-op for long time, and\n"
-"it will be removed. Please do not use it anymore."
+"cannot continue with staged changes in the following files:\n"
+"%s"
 msgstr ""
-"参数 -b/--binary 已经很长时间不做任何实质操作了，并且将被移除。\n"
-"请不要再使用它了。"
-
-#: builtin/am.c:2327
-msgid "failed to read the index"
-msgstr "无法读取索引"
+"不能继续，下列文件有暂存的修改：\n"
+"%s"
 
-#: builtin/am.c:2342
+#: builtin/checkout.c:835
 #, c-format
-msgid "previous rebase directory %s still exists but mbox given."
-msgstr "之前的变基目录 %s 仍然存在，但却提供了 mbox。"
+msgid "Can not do reflog for '%s': %s\n"
+msgstr "不能对 '%s' 执行 reflog 操作：%s\n"
+
+#: builtin/checkout.c:877
+msgid "HEAD is now at"
+msgstr "HEAD 目前位于"
+
+#: builtin/checkout.c:881 builtin/clone.c:716
+msgid "unable to update HEAD"
+msgstr "不能更新 HEAD"
 
-#: builtin/am.c:2366
+#: builtin/checkout.c:885
 #, c-format
-msgid ""
-"Stray %s directory found.\n"
-"Use \"git am --abort\" to remove it."
-msgstr ""
-"发现了错误的 %s 目录。\n"
-"使用 \"git am --abort\" 删除它。"
+msgid "Reset branch '%s'\n"
+msgstr "重置分支 '%s'\n"
 
-#: builtin/am.c:2372
-msgid "Resolve operation not in progress, we are not resuming."
-msgstr "解决操作未进行，我们不会继续。"
+#: builtin/checkout.c:888
+#, c-format
+msgid "Already on '%s'\n"
+msgstr "已经位于 '%s'\n"
 
-#: builtin/apply.c:8
-msgid "git apply [<options>] [<patch>...]"
-msgstr "git apply [<选项>] [<补丁>...]"
+#: builtin/checkout.c:892
+#, c-format
+msgid "Switched to and reset branch '%s'\n"
+msgstr "切换并重置分支 '%s'\n"
 
-#: builtin/archive.c:17
+#: builtin/checkout.c:894 builtin/checkout.c:1291
 #, c-format
-msgid "could not create archive file '%s'"
-msgstr "不能创建归档文件 '%s'"
+msgid "Switched to a new branch '%s'\n"
+msgstr "切换到一个新分支 '%s'\n"
 
-#: builtin/archive.c:20
-msgid "could not redirect output"
-msgstr "不能重定向输出"
+#: builtin/checkout.c:896
+#, c-format
+msgid "Switched to branch '%s'\n"
+msgstr "切换到分支 '%s'\n"
 
-#: builtin/archive.c:37
-msgid "git archive: Remote with no URL"
-msgstr "git archive：未提供远程 URL"
+#  译者：注意保持前导空格
+#: builtin/checkout.c:947
+#, c-format
+msgid " ... and %d more.\n"
+msgstr " ... 及其它 %d 个。\n"
 
-#: builtin/archive.c:58
-msgid "git archive: expected ACK/NAK, got a flush packet"
-msgstr "git archive：期望是 ACK/NAK，却得到 flush 包"
+#: builtin/checkout.c:953
+#, c-format
+msgid ""
+"Warning: you are leaving %d commit behind, not connected to\n"
+"any of your branches:\n"
+"\n"
+"%s\n"
+msgid_plural ""
+"Warning: you are leaving %d commits behind, not connected to\n"
+"any of your branches:\n"
+"\n"
+"%s\n"
+msgstr[0] ""
+"警告：您正丢下 %d 个提交，未和任何分支关联：\n"
+"\n"
+"%s\n"
+msgstr[1] ""
+"警告：您正丢下 %d 个提交，未和任何分支关联：\n"
+"\n"
+"%s\n"
 
-#: builtin/archive.c:61
+#: builtin/checkout.c:972
 #, c-format
-msgid "git archive: NACK %s"
-msgstr "git archive：NACK %s"
+msgid ""
+"If you want to keep it by creating a new branch, this may be a good time\n"
+"to do so with:\n"
+"\n"
+" git branch <new-branch-name> %s\n"
+"\n"
+msgid_plural ""
+"If you want to keep them by creating a new branch, this may be a good time\n"
+"to do so with:\n"
+"\n"
+" git branch <new-branch-name> %s\n"
+"\n"
+msgstr[0] ""
+"如果您想要通过创建新分支保存它，这可能是一个好时候。\n"
+"如下操作：\n"
+"\n"
+" git branch <新分支名> %s\n"
+"\n"
+msgstr[1] ""
+"如果您想要通过创建新分支保存它们，这可能是一个好时候。\n"
+"如下操作：\n"
+"\n"
+" git branch <新分支名> %s\n"
+"\n"
 
-#: builtin/archive.c:64
-msgid "git archive: protocol error"
-msgstr "git archive：协议错误"
+#: builtin/checkout.c:1007
+msgid "internal error in revision walk"
+msgstr "在版本遍历时遇到内部错误"
 
-#: builtin/archive.c:68
-msgid "git archive: expected a flush"
-msgstr "git archive：应有一个 flush 包"
+#: builtin/checkout.c:1011
+msgid "Previous HEAD position was"
+msgstr "之前的 HEAD 位置是"
 
-#: builtin/bisect--helper.c:12
-msgid "git bisect--helper --next-all [--no-checkout]"
-msgstr "git bisect--helper --next-all [--no-checkout]"
+#: builtin/checkout.c:1051 builtin/checkout.c:1286
+msgid "You are on a branch yet to be born"
+msgstr "您位于一个尚未初始化的分支"
 
-#: builtin/bisect--helper.c:13
-msgid "git bisect--helper --write-terms <bad_term> <good_term>"
-msgstr "git bisect--helper --write-terms <坏-术语> <好-术语>"
+#: builtin/checkout.c:1178
+msgid "only one reference expected"
+msgstr "预期只有一个引用"
 
-#: builtin/bisect--helper.c:14
-msgid "git bisect--helper --bisect-clean-state"
-msgstr "git bisect--helper --bisect-clean-state"
+#: builtin/checkout.c:1195
+#, c-format
+msgid "only one reference expected, %d given."
+msgstr "应只有一个引用，却给出了 %d 个"
 
-#: builtin/bisect--helper.c:46
+#: builtin/checkout.c:1232
 #, c-format
-msgid "'%s' is not a valid term"
-msgstr "'%s' 不是一个有效的术语"
+msgid ""
+"'%s' could be both a local file and a tracking branch.\n"
+"Please use -- (and optionally --no-guess) to disambiguate"
+msgstr ""
+"'%s' 既可以是一个本地文件，也可以是一个跟踪分支。\n"
+"请使用 --（和可选的 --no-guess）来消除歧义"
 
-#: builtin/bisect--helper.c:50
+#: builtin/checkout.c:1245 builtin/worktree.c:290 builtin/worktree.c:455
 #, c-format
-msgid "can't use the builtin command '%s' as a term"
-msgstr "不能使用内置命令 '%s' 作为术语"
+msgid "invalid reference: %s"
+msgstr "无效引用：%s"
 
-#: builtin/bisect--helper.c:60
+#: builtin/checkout.c:1258 builtin/checkout.c:1622
 #, c-format
-msgid "can't change the meaning of the term '%s'"
-msgstr "不能修改术语 '%s' 的含义"
+msgid "reference is not a tree: %s"
+msgstr "引用不是一个树：%s"
 
-#: builtin/bisect--helper.c:71
-msgid "please use two different terms"
-msgstr "请使用两个不同的术语"
+#: builtin/checkout.c:1305
+#, c-format
+msgid "a branch is expected, got tag '%s'"
+msgstr "期望一个分支，得到标签 '%s'"
 
-#: builtin/bisect--helper.c:78
-msgid "could not open the file BISECT_TERMS"
-msgstr "不能打开文件 BISECT_TERMS"
+#: builtin/checkout.c:1307
+#, c-format
+msgid "a branch is expected, got remote branch '%s'"
+msgstr "期望一个分支，得到远程分支 '%s'"
 
-#: builtin/bisect--helper.c:120
-msgid "perform 'git bisect next'"
-msgstr "执行 'git bisect next'"
+#: builtin/checkout.c:1308 builtin/checkout.c:1316
+#, c-format
+msgid "a branch is expected, got '%s'"
+msgstr "期望一个分支，得到 '%s'"
 
-#: builtin/bisect--helper.c:122
-msgid "write the terms to .git/BISECT_TERMS"
-msgstr "将术语写入 .git/BISECT_TERMS"
+#: builtin/checkout.c:1311
+#, c-format
+msgid "a branch is expected, got commit '%s'"
+msgstr "期望一个分支，得到提交 '%s'"
 
-#: builtin/bisect--helper.c:124
-msgid "cleanup the bisection state"
-msgstr "清除二分查找状态"
+#: builtin/checkout.c:1327
+msgid ""
+"cannot switch branch while merging\n"
+"Consider \"git merge --quit\" or \"git worktree add\"."
+msgstr ""
+"不能在合并时切换分支\n"
+"考虑使用 \"git merge --quit\" 或 \"git worktree add\"。"
 
-#: builtin/bisect--helper.c:126
-msgid "check for expected revs"
-msgstr "检查预期的版本"
+#: builtin/checkout.c:1331
+msgid ""
+"cannot switch branch in the middle of an am session\n"
+"Consider \"git am --quit\" or \"git worktree add\"."
+msgstr ""
+"不能在一个 am 会话期间切换分支\n"
+"考虑使用 \"git am --quit\" 或 \"git worktree add\"。"
 
-#: builtin/bisect--helper.c:128
-msgid "update BISECT_HEAD instead of checking out the current commit"
-msgstr "更新 BISECT_HEAD 而非检出当前提交"
+#: builtin/checkout.c:1335
+msgid ""
+"cannot switch branch while rebasing\n"
+"Consider \"git rebase --quit\" or \"git worktree add\"."
+msgstr ""
+"不能在变基时切换分支\n"
+"考虑使用 \"git rebase --quit\" 或 \"git worktree add\"。"
 
-#: builtin/bisect--helper.c:143
-msgid "--write-terms requires two arguments"
-msgstr "--write-terms 需要两个参数"
+#: builtin/checkout.c:1339
+msgid ""
+"cannot switch branch while cherry-picking\n"
+"Consider \"git cherry-pick --quit\" or \"git worktree add\"."
+msgstr ""
+"不能在拣选时切换分支\n"
+"考虑使用 \"git cherry-pick --quit\" 或 \"git worktree add\"。"
 
-#: builtin/bisect--helper.c:147
-msgid "--bisect-clean-state requires no arguments"
-msgstr "--bisect-clean-state 不需要参数"
+#: builtin/checkout.c:1343
+msgid ""
+"cannot switch branch while reverting\n"
+"Consider \"git revert --quit\" or \"git worktree add\"."
+msgstr ""
+"不能在还原时切换分支\n"
+"考虑使用 \"git revert --quit\" 或 \"git worktree add\"。"
 
-#: builtin/blame.c:29
-msgid "git blame [<options>] [<rev-opts>] [<rev>] [--] <file>"
-msgstr "git blame [<选项>] [<版本选项>] [<版本>] [--] <文件>"
+#: builtin/checkout.c:1347
+msgid "you are switching branch while bisecting"
+msgstr "您在执行二分查找时切换分支"
 
-#: builtin/blame.c:34
-msgid "<rev-opts> are documented in git-rev-list(1)"
-msgstr "<版本选项> 的文档记录在 git-rev-list(1) 中"
+#: builtin/checkout.c:1354
+msgid "paths cannot be used with switching branches"
+msgstr "路径不能和切换分支同时使用"
 
-#: builtin/blame.c:404
+#: builtin/checkout.c:1357 builtin/checkout.c:1361 builtin/checkout.c:1365
 #, c-format
-msgid "expecting a color: %s"
-msgstr "期望一个颜色：%s"
+msgid "'%s' cannot be used with switching branches"
+msgstr "'%s' 不能和切换分支同时使用"
 
-#: builtin/blame.c:411
-msgid "must end with a color"
-msgstr "必须以一个颜色结尾"
+#: builtin/checkout.c:1369 builtin/checkout.c:1372 builtin/checkout.c:1375
+#: builtin/checkout.c:1380 builtin/checkout.c:1385
+#, c-format
+msgid "'%s' cannot be used with '%s'"
+msgstr "'%s' 不能和 '%s' 同时使用"
 
-#: builtin/blame.c:697
+#: builtin/checkout.c:1382
 #, c-format
-msgid "invalid color '%s' in color.blame.repeatedLines"
-msgstr "设置 color.blame.repeatedLines 中的无效颜色 '%s'"
+msgid "'%s' cannot take <start-point>"
+msgstr "'%s' 不带 <起始点>"
 
-#: builtin/blame.c:715
-msgid "invalid value for blame.coloring"
-msgstr "设置 blame.coloring 中的无效取值"
+#: builtin/checkout.c:1390
+#, c-format
+msgid "Cannot switch branch to a non-commit '%s'"
+msgstr "不能切换分支到一个非提交 '%s'"
 
-#: builtin/blame.c:786
-msgid "Show blame entries as we find them, incrementally"
-msgstr "增量式地显示发现的 blame 条目"
+#: builtin/checkout.c:1397
+msgid "missing branch or commit argument"
+msgstr "缺少分支或提交参数"
+
+#: builtin/checkout.c:1439 builtin/clone.c:91 builtin/commit-graph.c:52
+#: builtin/commit-graph.c:113 builtin/fetch.c:167 builtin/merge.c:285
+#: builtin/multi-pack-index.c:27 builtin/pull.c:138 builtin/push.c:563
+#: builtin/send-pack.c:174
+msgid "force progress reporting"
+msgstr "强制显示进度报告"
 
-#: builtin/blame.c:787
-msgid "Show blank SHA-1 for boundary commits (Default: off)"
-msgstr "边界提交显示空的 SHA-1（默认：关闭）"
+#: builtin/checkout.c:1440
+msgid "perform a 3-way merge with the new branch"
+msgstr "和新的分支执行三方合并"
 
-#: builtin/blame.c:788
-msgid "Do not treat root commits as boundaries (Default: off)"
-msgstr "不把根提交作为边界（默认：关闭）"
+#: builtin/checkout.c:1441 builtin/log.c:1690 parse-options.h:322
+msgid "style"
+msgstr "风格"
 
-#: builtin/blame.c:789
-msgid "Show work cost statistics"
-msgstr "显示命令消耗统计"
+#: builtin/checkout.c:1442
+msgid "conflict style (merge or diff3)"
+msgstr "冲突输出风格（merge 或 diff3）"
 
-#: builtin/blame.c:790
-msgid "Force progress reporting"
-msgstr "强制进度显示"
+#: builtin/checkout.c:1454 builtin/worktree.c:503
+msgid "detach HEAD at named commit"
+msgstr "HEAD 从指定的提交分离"
 
-#: builtin/blame.c:791
-msgid "Show output score for blame entries"
-msgstr "显示判断 blame 条目位移的得分诊断信息"
+#: builtin/checkout.c:1455
+msgid "set upstream info for new branch"
+msgstr "为新的分支设置上游信息"
 
-#: builtin/blame.c:792
-msgid "Show original filename (Default: auto)"
-msgstr "显示原始文件名（默认：自动）"
+#: builtin/checkout.c:1457
+msgid "force checkout (throw away local modifications)"
+msgstr "强制检出（丢弃本地修改）"
 
-#: builtin/blame.c:793
-msgid "Show original linenumber (Default: off)"
-msgstr "显示原始的行号（默认：关闭）"
+#: builtin/checkout.c:1459
+msgid "new-branch"
+msgstr "新分支"
 
-#: builtin/blame.c:794
-msgid "Show in a format designed for machine consumption"
-msgstr "显示为一个适合机器读取的格式"
+#: builtin/checkout.c:1459
+msgid "new unparented branch"
+msgstr "新的没有父提交的分支"
 
-#: builtin/blame.c:795
-msgid "Show porcelain format with per-line commit information"
-msgstr "为每一行显示机器适用的提交信息"
+#: builtin/checkout.c:1461 builtin/merge.c:288
+msgid "update ignored files (default)"
+msgstr "更新忽略的文件（默认）"
 
-#: builtin/blame.c:796
-msgid "Use the same output mode as git-annotate (Default: off)"
-msgstr "使用和 git-annotate 相同的输出模式（默认：关闭）"
+#: builtin/checkout.c:1464
+msgid "do not check if another worktree is holding the given ref"
+msgstr "不检查指定的引用是否被其他工作区所占用"
 
-#: builtin/blame.c:797
-msgid "Show raw timestamp (Default: off)"
-msgstr "显示原始时间戳（默认：关闭）"
+#: builtin/checkout.c:1477
+msgid "checkout our version for unmerged files"
+msgstr "对尚未合并的文件检出我们的版本"
 
-#: builtin/blame.c:798
-msgid "Show long commit SHA1 (Default: off)"
-msgstr "显示长的 SHA1 提交号（默认：关闭）"
+#: builtin/checkout.c:1480
+msgid "checkout their version for unmerged files"
+msgstr "对尚未合并的文件检出他们的版本"
 
-#: builtin/blame.c:799
-msgid "Suppress author name and timestamp (Default: off)"
-msgstr "隐藏作者名字和时间戳（默认：关闭）"
+#: builtin/checkout.c:1484
+msgid "do not limit pathspecs to sparse entries only"
+msgstr "对路径不做稀疏检出的限制"
 
-#: builtin/blame.c:800
-msgid "Show author email instead of name (Default: off)"
-msgstr "显示作者的邮箱而不是名字（默认：关闭）"
+#: builtin/checkout.c:1537
+msgid "-b, -B and --orphan are mutually exclusive"
+msgstr "-b、-B 和 --orphan 是互斥的"
 
-#: builtin/blame.c:801
-msgid "Ignore whitespace differences"
-msgstr "忽略空白差异"
+#: builtin/checkout.c:1540
+msgid "-p and --overlay are mutually exclusive"
+msgstr "-p 和 --overlay 互斥"
 
-#: builtin/blame.c:802
-msgid "color redundant metadata from previous line differently"
-msgstr "使用颜色间隔输出与前一行不同的重复元信息"
+#: builtin/checkout.c:1577
+msgid "--track needs a branch name"
+msgstr "--track 需要一个分支名"
 
-#: builtin/blame.c:803
-msgid "color lines by age"
-msgstr "依据时间着色"
+#: builtin/checkout.c:1582
+msgid "missing branch name; try -b"
+msgstr "缺少分支名，尝试 -b"
 
-#: builtin/blame.c:810
-msgid "Use an experimental heuristic to improve diffs"
-msgstr "使用一个试验性的启发式算法改进差异显示"
+#: builtin/checkout.c:1615
+#, c-format
+msgid "could not resolve %s"
+msgstr "无法解析 %s"
 
-#: builtin/blame.c:812
-msgid "Spend extra cycles to find better match"
-msgstr "花费额外的循环来找到更好的匹配"
+#: builtin/checkout.c:1631
+msgid "invalid path specification"
+msgstr "无效的路径规格"
 
-#: builtin/blame.c:813
-msgid "Use revisions from <file> instead of calling git-rev-list"
-msgstr "使用来自 <文件> 的修订集而不是调用 git-rev-list"
+#: builtin/checkout.c:1638
+#, c-format
+msgid "'%s' is not a commit and a branch '%s' cannot be created from it"
+msgstr "'%s' 不是一个提交，不能基于它创建分支 '%s'"
 
-#: builtin/blame.c:814
-msgid "Use <file>'s contents as the final image"
-msgstr "使用 <文件> 的内容作为最终的图片"
+#: builtin/checkout.c:1642
+#, c-format
+msgid "git checkout: --detach does not take a path argument '%s'"
+msgstr "git checkout：--detach 不能接收路径参数 '%s'"
 
-#: builtin/blame.c:815 builtin/blame.c:816
-msgid "score"
-msgstr "得分"
+#: builtin/checkout.c:1651
+msgid "--pathspec-from-file is incompatible with --detach"
+msgstr "--pathspec-from-file 与 --detach 不兼容"
+
+#: builtin/checkout.c:1654 builtin/reset.c:324
+msgid "--pathspec-from-file is incompatible with --patch"
+msgstr "--pathspec-from-file 与 --patch 不兼容"
 
-#: builtin/blame.c:815
-msgid "Find line copies within and across files"
-msgstr "找到文件内及跨文件的行拷贝"
+#: builtin/checkout.c:1665
+msgid ""
+"git checkout: --ours/--theirs, --force and --merge are incompatible when\n"
+"checking out of the index."
+msgstr ""
+"git checkout：在从索引检出时，--ours/--theirs、--force 和 --merge 不兼容。"
 
-#: builtin/blame.c:816
-msgid "Find line movements within and across files"
-msgstr "找到文件内及跨文件的行移动"
+#: builtin/checkout.c:1670
+msgid "you must specify path(s) to restore"
+msgstr "您必须指定一个要恢复的路径"
 
-#: builtin/blame.c:817
-msgid "n,m"
-msgstr "n,m"
+#: builtin/checkout.c:1689
+#, c-format
+msgid ""
+"'%s' matched more than one remote tracking branch.\n"
+"We found %d remotes with a reference that matched. So we fell back\n"
+"on trying to resolve the argument as a path, but failed there too!\n"
+"\n"
+"If you meant to check out a remote tracking branch on, e.g. 'origin',\n"
+"you can do so by fully qualifying the name with the --track option:\n"
+"\n"
+"    git checkout --track origin/<name>\n"
+"\n"
+"If you'd like to always have checkouts of an ambiguous <name> prefer\n"
+"one remote, e.g. the 'origin' remote, consider setting\n"
+"checkout.defaultRemote=origin in your config."
+msgstr ""
+"'%s' 匹配了一个以上的远程跟踪分支。\n"
+"我们发现 %d 个远程仓库具有同名分支。所以我们转而尝试将这个参数解析为\n"
+"路径，但是也失败了！\n"
+"\n"
+"如果您想要检出一个远程跟踪分支，例如在远程仓库 'origin' 上的，您可以\n"
+"使用分支全名和 --track 选项：\n"
+"\n"
+"    git checkout --track origin/<name>\n"
+"\n"
+"如果您总是喜欢使用模糊的简短分支名 <name>，而不喜欢如 'origin' 的远程\n"
+"仓库名，可以在配置中设置 checkout.defaultRemote=origin。"
 
-#: builtin/blame.c:817
-msgid "Process only line range n,m, counting from 1"
-msgstr "只处理行范围在 n 和 m 之间的，从 1 开始"
+#: builtin/checkout.c:1714 builtin/checkout.c:1716 builtin/checkout.c:1765
+#: builtin/checkout.c:1767 builtin/clone.c:121 builtin/remote.c:169
+#: builtin/remote.c:171 builtin/worktree.c:499 builtin/worktree.c:501
+msgid "branch"
+msgstr "分支"
 
-#: builtin/blame.c:866
-msgid "--progress can't be used with --incremental or porcelain formats"
-msgstr "--progress 不能和 --incremental 或 --porcelain 同时使用"
+#: builtin/checkout.c:1715
+msgid "create and checkout a new branch"
+msgstr "创建并检出一个新的分支"
 
-#. TRANSLATORS: This string is used to tell us the
-#. maximum display width for a relative timestamp in
-#. "git blame" output.  For C locale, "4 years, 11
-#. months ago", which takes 22 places, is the longest
-#. among various forms of relative timestamps, but
-#. your language may need more or fewer display
-#. columns.
-#.
-#: builtin/blame.c:917
-msgid "4 years, 11 months ago"
-msgstr "4 年 11 个月前"
+#: builtin/checkout.c:1717
+msgid "create/reset and checkout a branch"
+msgstr "创建/重置并检出一个分支"
 
-#: builtin/blame.c:1003
-#, c-format
-msgid "file %s has only %lu line"
-msgid_plural "file %s has only %lu lines"
-msgstr[0] "文件 %s 只有 %lu 行"
-msgstr[1] "文件 %s 只有 %lu 行"
+#: builtin/checkout.c:1718
+msgid "create reflog for new branch"
+msgstr "为新的分支创建引用日志"
 
-#: builtin/blame.c:1049
-msgid "Blaming lines"
-msgstr "追踪代码行"
+#: builtin/checkout.c:1720
+msgid "second guess 'git checkout <no-such-branch>' (default)"
+msgstr "二次猜测 'git checkout <无此分支>'（默认）"
+
+#: builtin/checkout.c:1721
+msgid "use overlay mode (default)"
+msgstr "使用叠加模式（默认）"
+
+#: builtin/checkout.c:1766
+msgid "create and switch to a new branch"
+msgstr "创建并切换一个新分支"
+
+#: builtin/checkout.c:1768
+msgid "create/reset and switch to a branch"
+msgstr "创建/重置并切换一个分支"
+
+#: builtin/checkout.c:1770
+msgid "second guess 'git switch <no-such-branch>'"
+msgstr "二次猜测 'git switch <无此分支>'"
+
+#: builtin/checkout.c:1772
+msgid "throw away local modifications"
+msgstr "丢弃本地修改"
+
+#: builtin/checkout.c:1804
+msgid "which tree-ish to checkout from"
+msgstr "要检出哪一个树"
+
+#: builtin/checkout.c:1806
+msgid "restore the index"
+msgstr "恢复索引"
+
+#: builtin/checkout.c:1808
+msgid "restore the working tree (default)"
+msgstr "恢复工作区（默认）"
+
+#: builtin/checkout.c:1810
+msgid "ignore unmerged entries"
+msgstr "忽略未合并条目"
+
+#: builtin/checkout.c:1811
+msgid "use overlay mode"
+msgstr "使用叠加模式"
 
-#: builtin/branch.c:27
-msgid "git branch [<options>] [-r | -a] [--merged | --no-merged]"
-msgstr "git branch [<选项>] [-r | -a] [--merged | --no-merged]"
+#: builtin/clean.c:28
+msgid ""
+"git clean [-d] [-f] [-i] [-n] [-q] [-e <pattern>] [-x | -X] [--] <paths>..."
+msgstr ""
+"git clean [-d] [-f] [-i] [-n] [-q] [-e <模式>] [-x | -X] [--] <路径>..."
 
-#: builtin/branch.c:28
-msgid "git branch [<options>] [-l] [-f] <branch-name> [<start-point>]"
-msgstr "git branch [<选项>] [-l] [-f] <分支名> [<起始点>]"
+#: builtin/clean.c:32
+#, c-format
+msgid "Removing %s\n"
+msgstr "正删除 %s\n"
 
-#: builtin/branch.c:29
-msgid "git branch [<options>] [-r] (-d | -D) <branch-name>..."
-msgstr "git branch [<选项>] [-r] (-d | -D) <分支名>..."
+#: builtin/clean.c:33
+#, c-format
+msgid "Would remove %s\n"
+msgstr "将删除 %s\n"
 
-#: builtin/branch.c:30
-msgid "git branch [<options>] (-m | -M) [<old-branch>] <new-branch>"
-msgstr "git branch [<选项>] (-m | -M) [<旧分支>] <新分支>"
+#: builtin/clean.c:34
+#, c-format
+msgid "Skipping repository %s\n"
+msgstr "忽略仓库 %s\n"
 
-#: builtin/branch.c:31
-msgid "git branch [<options>] (-c | -C) [<old-branch>] <new-branch>"
-msgstr "git branch [<选项>] (-c | -C) [<老分支>] <新分支>"
+#: builtin/clean.c:35
+#, c-format
+msgid "Would skip repository %s\n"
+msgstr "将忽略仓库 %s\n"
 
-#: builtin/branch.c:32
-msgid "git branch [<options>] [-r | -a] [--points-at]"
-msgstr "git branch [<选项>] [-r | -a] [--points-at]"
+#: builtin/clean.c:36
+#, c-format
+msgid "failed to remove %s"
+msgstr "删除 %s 失败"
 
-#: builtin/branch.c:33
-msgid "git branch [<options>] [-r | -a] [--format]"
-msgstr "git branch [<选项>] [-r | -a] [--format]"
+#: builtin/clean.c:37
+#, c-format
+msgid "could not lstat %s\n"
+msgstr "不能对 %s 调用 lstat\n"
 
-#  译者：保持原换行格式，在输出时 %s 的替代内容会让字符串变长
-#: builtin/branch.c:146
+#: builtin/clean.c:301 git-add--interactive.perl:595
 #, c-format
 msgid ""
-"deleting branch '%s' that has been merged to\n"
-"         '%s', but not yet merged to HEAD."
+"Prompt help:\n"
+"1          - select a numbered item\n"
+"foo        - select item based on unique prefix\n"
+"           - (empty) select nothing\n"
 msgstr ""
-"将要删除的分支 '%s' 已经被合并到\n"
-"         '%s'，但未合并到 HEAD。"
+"帮助：\n"
+"1          - 通过编号选择一个选项\n"
+"foo        - 通过唯一前缀选择一个选项\n"
+"           - （空）什么也不选择\n"
 
-#  译者：保持原换行格式，在输出时 %s 的替代内容会让字符串变长
-#: builtin/branch.c:150
+#: builtin/clean.c:305 git-add--interactive.perl:604
 #, c-format
 msgid ""
-"not deleting branch '%s' that is not yet merged to\n"
-"         '%s', even though it is merged to HEAD."
+"Prompt help:\n"
+"1          - select a single item\n"
+"3-5        - select a range of items\n"
+"2-3,6-9    - select multiple ranges\n"
+"foo        - select item based on unique prefix\n"
+"-...       - unselect specified items\n"
+"*          - choose all items\n"
+"           - (empty) finish selecting\n"
 msgstr ""
-"并未删除分支 '%s'， 虽然它已经合并到 HEAD，\n"
-"         然而却尚未被合并到分支 '%s' 。"
+"帮助：\n"
+"1          - 选择一个选项\n"
+"3-5        - 选择一个范围内的所有选项\n"
+"2-3,6-9    - 选择多个范围内的所有选项\n"
+"foo        - 通过唯一前缀选择一个选项\n"
+"-...       - 反选特定的选项\n"
+"*          - 选择所有选项\n"
+"           - （空）结束选择\n"
+
+#: builtin/clean.c:521 git-add--interactive.perl:570
+#: git-add--interactive.perl:575
+#, c-format, perl-format
+msgid "Huh (%s)?\n"
+msgstr "嗯（%s）？\n"
 
-#: builtin/branch.c:164
+#: builtin/clean.c:663
 #, c-format
-msgid "Couldn't look up commit object for '%s'"
-msgstr "无法查询 '%s' 指向的提交对象"
+msgid "Input ignore patterns>> "
+msgstr "输入模版以排除条目>> "
+
+#: builtin/clean.c:700
+#, c-format
+msgid "WARNING: Cannot find items matched by: %s"
+msgstr "警告：无法找到和 %s 匹配的条目"
+
+#: builtin/clean.c:721
+msgid "Select items to delete"
+msgstr "选择要删除的条目"
 
-#: builtin/branch.c:168
+#. TRANSLATORS: Make sure to keep [y/N] as is
+#: builtin/clean.c:762
 #, c-format
+msgid "Remove %s [y/N]? "
+msgstr "删除 %s [y/N]？"
+
+#: builtin/clean.c:795
 msgid ""
-"The branch '%s' is not fully merged.\n"
-"If you are sure you want to delete it, run 'git branch -D %s'."
+"clean               - start cleaning\n"
+"filter by pattern   - exclude items from deletion\n"
+"select by numbers   - select items to be deleted by numbers\n"
+"ask each            - confirm each deletion (like \"rm -i\")\n"
+"quit                - stop cleaning\n"
+"help                - this screen\n"
+"?                   - help for prompt selection"
 msgstr ""
-"分支 '%s' 没有完全合并。\n"
-"如果您确认要删除它，执行 'git branch -D %s'。"
+"clean               - 开始清理\n"
+"filter by pattern   - 通过模版排除要删除的条目\n"
+"select by numbers   - 通过数字选择要删除的条目\n"
+"ask each            - 针对删除逐一询问（就像 \"rm -i\"）\n"
+"quit                - 停止删除并退出\n"
+"help                - 显示本帮助\n"
+"?                   - 显示如何在提示符下选择的帮助"
 
-#: builtin/branch.c:181
-msgid "Update of config-file failed"
-msgstr "更新配置文件失败"
+#: builtin/clean.c:831
+msgid "Would remove the following item:"
+msgid_plural "Would remove the following items:"
+msgstr[0] "将删除如下条目："
+msgstr[1] "将删除如下条目："
 
-#: builtin/branch.c:212
-msgid "cannot use -a with -d"
-msgstr "不能将 -a 和 -d 同时使用"
+#: builtin/clean.c:847
+msgid "No more files to clean, exiting."
+msgstr "没有要清理的文件，退出。"
 
-#: builtin/branch.c:218
-msgid "Couldn't look up commit object for HEAD"
-msgstr "无法查询 HEAD 指向的提交对象"
+#: builtin/clean.c:909
+msgid "do not print names of files removed"
+msgstr "不打印删除文件的名称"
 
-#: builtin/branch.c:232
-#, c-format
-msgid "Cannot delete branch '%s' checked out at '%s'"
-msgstr "无法删除检出于 '%2$s' 的分支 '%1$s'。"
+#: builtin/clean.c:911
+msgid "force"
+msgstr "强制"
 
-#: builtin/branch.c:247
-#, c-format
-msgid "remote-tracking branch '%s' not found."
-msgstr "未能找到远程跟踪分支 '%s'。"
+#: builtin/clean.c:912
+msgid "interactive cleaning"
+msgstr "交互式清除"
 
-#: builtin/branch.c:248
-#, c-format
-msgid "branch '%s' not found."
-msgstr "分支 '%s' 未发现。"
+#: builtin/clean.c:914
+msgid "remove whole directories"
+msgstr "删除整个目录"
 
-#: builtin/branch.c:263
-#, c-format
-msgid "Error deleting remote-tracking branch '%s'"
-msgstr "无法删除远程跟踪分支 '%s'"
+#: builtin/clean.c:915 builtin/describe.c:548 builtin/describe.c:550
+#: builtin/grep.c:901 builtin/log.c:177 builtin/log.c:179
+#: builtin/ls-files.c:557 builtin/name-rev.c:464 builtin/name-rev.c:466
+#: builtin/show-ref.c:179
+msgid "pattern"
+msgstr "模式"
+
+#: builtin/clean.c:916
+msgid "add <pattern> to ignore rules"
+msgstr "添加 <模式> 到忽略规则"
+
+#: builtin/clean.c:917
+msgid "remove ignored files, too"
+msgstr "也删除忽略的文件"
+
+#: builtin/clean.c:919
+msgid "remove only ignored files"
+msgstr "只删除忽略的文件"
+
+#: builtin/clean.c:937
+msgid "-x and -X cannot be used together"
+msgstr "-x 和 -X 不能同时使用"
+
+#: builtin/clean.c:941
+msgid ""
+"clean.requireForce set to true and neither -i, -n, nor -f given; refusing to "
+"clean"
+msgstr ""
+"clean.requireForce 设置为 true 且未提供 -i、-n 或 -f 选项，拒绝执行清理动作"
+
+#: builtin/clean.c:944
+msgid ""
+"clean.requireForce defaults to true and neither -i, -n, nor -f given; "
+"refusing to clean"
+msgstr ""
+"clean.requireForce 默认为 true 且未提供 -i、-n 或 -f 选项，拒绝执行清理动作"
+
+#: builtin/clone.c:45
+msgid "git clone [<options>] [--] <repo> [<dir>]"
+msgstr "git clone [<选项>] [--] <仓库> [<路径>]"
+
+#: builtin/clone.c:93
+msgid "don't create a checkout"
+msgstr "不创建一个检出"
 
-#: builtin/branch.c:264
-#, c-format
-msgid "Error deleting branch '%s'"
-msgstr "无法删除分支 '%s'"
+#: builtin/clone.c:94 builtin/clone.c:96 builtin/init-db.c:489
+msgid "create a bare repository"
+msgstr "创建一个纯仓库"
 
-#: builtin/branch.c:271
-#, c-format
-msgid "Deleted remote-tracking branch %s (was %s).\n"
-msgstr "已删除远程跟踪分支 %s（曾为 %s）。\n"
+#: builtin/clone.c:98
+msgid "create a mirror repository (implies bare)"
+msgstr "创建一个镜像仓库（也是纯仓库）"
 
-#: builtin/branch.c:272
-#, c-format
-msgid "Deleted branch %s (was %s).\n"
-msgstr "已删除分支 %s（曾为 %s）。\n"
+#: builtin/clone.c:100
+msgid "to clone from a local repository"
+msgstr "从本地仓库克隆"
 
-#: builtin/branch.c:416 builtin/tag.c:58
-msgid "unable to parse format string"
-msgstr "不能解析格式化字符串"
+#: builtin/clone.c:102
+msgid "don't use local hardlinks, always copy"
+msgstr "不使用本地硬链接，始终复制"
 
-#: builtin/branch.c:453
-#, c-format
-msgid "Branch %s is being rebased at %s"
-msgstr "分支 %s 正被变基到 %s"
+#: builtin/clone.c:104
+msgid "setup as shared repository"
+msgstr "设置为共享仓库"
 
-#: builtin/branch.c:457
-#, c-format
-msgid "Branch %s is being bisected at %s"
-msgstr "分支 %s 正被二分查找于 %s"
+#: builtin/clone.c:107
+msgid "pathspec"
+msgstr "路径规格"
 
-#: builtin/branch.c:474
-msgid "cannot copy the current branch while not on any."
-msgstr "无法拷贝当前分支因为不处于任何分支上。"
+#: builtin/clone.c:107
+msgid "initialize submodules in the clone"
+msgstr "在克隆时初始化子模组"
 
-#: builtin/branch.c:476
-msgid "cannot rename the current branch while not on any."
-msgstr "无法重命名当前分支因为不处于任何分支上。"
+#: builtin/clone.c:110
+msgid "number of submodules cloned in parallel"
+msgstr "并发克隆的子模组的数量"
 
-#: builtin/branch.c:487
-#, c-format
-msgid "Invalid branch name: '%s'"
-msgstr "无效的分支名：'%s'"
+#: builtin/clone.c:111 builtin/init-db.c:486
+msgid "template-directory"
+msgstr "模板目录"
 
-#: builtin/branch.c:514
-msgid "Branch rename failed"
-msgstr "分支重命名失败"
+#: builtin/clone.c:112 builtin/init-db.c:487
+msgid "directory from which templates will be used"
+msgstr "模板目录将被使用"
 
-#: builtin/branch.c:516
-msgid "Branch copy failed"
-msgstr "分支拷贝失败"
+#: builtin/clone.c:114 builtin/clone.c:116 builtin/submodule--helper.c:1392
+#: builtin/submodule--helper.c:1885
+msgid "reference repository"
+msgstr "参考仓库"
 
-#: builtin/branch.c:520
-#, c-format
-msgid "Created a copy of a misnamed branch '%s'"
-msgstr "已为错误命名的分支 '%s' 创建了一个副本"
+#: builtin/clone.c:118 builtin/submodule--helper.c:1394
+#: builtin/submodule--helper.c:1887
+msgid "use --reference only while cloning"
+msgstr "仅在克隆时参考 --reference 指向的本地仓库"
 
-#: builtin/branch.c:523
-#, c-format
-msgid "Renamed a misnamed branch '%s' away"
-msgstr "已将错误命名的分支 '%s' 重命名"
+#: builtin/clone.c:119 builtin/column.c:27 builtin/merge-file.c:46
+#: builtin/pack-objects.c:3294 builtin/repack.c:327
+msgid "name"
+msgstr "名称"
 
-#: builtin/branch.c:529
-#, c-format
-msgid "Branch renamed to %s, but HEAD is not updated!"
-msgstr "分支重命名为 %s，但 HEAD 没有更新！"
+#: builtin/clone.c:120
+msgid "use <name> instead of 'origin' to track upstream"
+msgstr "使用 <名称> 而不是 'origin' 去跟踪上游"
 
-#: builtin/branch.c:538
-msgid "Branch is renamed, but update of config-file failed"
-msgstr "分支被重命名，但更新配置文件失败"
+#: builtin/clone.c:122
+msgid "checkout <branch> instead of the remote's HEAD"
+msgstr "检出 <分支> 而不是远程 HEAD"
 
-#: builtin/branch.c:540
-msgid "Branch is copied, but update of config-file failed"
-msgstr "分支已拷贝，但更新配置文件失败"
+#: builtin/clone.c:124
+msgid "path to git-upload-pack on the remote"
+msgstr "远程 git-upload-pack 路径"
 
-#: builtin/branch.c:556
-#, c-format
-msgid ""
-"Please edit the description for the branch\n"
-"  %s\n"
-"Lines starting with '%c' will be stripped.\n"
-msgstr ""
-"请编辑分支的描述\n"
-"  %s\n"
-"以 '%c' 开头的行将被过滤。\n"
+#: builtin/clone.c:125 builtin/fetch.c:168 builtin/grep.c:840
+#: builtin/pull.c:227
+msgid "depth"
+msgstr "深度"
 
-#: builtin/branch.c:589
-msgid "Generic options"
-msgstr "通用选项"
+#: builtin/clone.c:126
+msgid "create a shallow clone of that depth"
+msgstr "创建一个指定深度的浅克隆"
 
-#: builtin/branch.c:591
-msgid "show hash and subject, give twice for upstream branch"
-msgstr "显示哈希值和主题，若参数出现两次则显示上游分支"
+#: builtin/clone.c:127 builtin/fetch.c:170 builtin/pack-objects.c:3283
+msgid "time"
+msgstr "时间"
 
-#: builtin/branch.c:592
-msgid "suppress informational messages"
-msgstr "不显示信息"
+#: builtin/clone.c:128
+msgid "create a shallow clone since a specific time"
+msgstr "从一个特定时间创建一个浅克隆"
 
-#: builtin/branch.c:593
-msgid "set up tracking mode (see git-pull(1))"
-msgstr "设置跟踪模式（参见 git-pull(1)）"
+#: builtin/clone.c:129 builtin/fetch.c:172 builtin/fetch.c:195
+#: builtin/rebase.c:1445
+msgid "revision"
+msgstr "版本"
 
-#: builtin/branch.c:595
-msgid "do not use"
-msgstr "不要使用"
+#: builtin/clone.c:130 builtin/fetch.c:173
+msgid "deepen history of shallow clone, excluding rev"
+msgstr "深化浅克隆的历史，除了特定版本"
 
-#: builtin/branch.c:597
-msgid "upstream"
-msgstr "上游"
+#: builtin/clone.c:132
+msgid "clone only one branch, HEAD or --branch"
+msgstr "只克隆一个分支、HEAD 或 --branch"
 
-#: builtin/branch.c:597
-msgid "change the upstream info"
-msgstr "改变上游信息"
+#: builtin/clone.c:134
+msgid "don't clone any tags, and make later fetches not to follow them"
+msgstr "不要克隆任何标签，并且后续获取操作也不下载它们"
 
-#: builtin/branch.c:598
-msgid "Unset the upstream info"
-msgstr "取消上游信息的设置"
+#: builtin/clone.c:136
+msgid "any cloned submodules will be shallow"
+msgstr "子模组将以浅下载模式克隆"
 
-#: builtin/branch.c:599
-msgid "use colored output"
-msgstr "使用彩色输出"
+#: builtin/clone.c:137 builtin/init-db.c:495
+msgid "gitdir"
+msgstr "git目录"
 
-#: builtin/branch.c:600
-msgid "act on remote-tracking branches"
-msgstr "作用于远程跟踪分支"
+#: builtin/clone.c:138 builtin/init-db.c:496
+msgid "separate git dir from working tree"
+msgstr "git目录和工作区分离"
 
-#: builtin/branch.c:602 builtin/branch.c:604
-msgid "print only branches that contain the commit"
-msgstr "只打印包含该提交的分支"
+#: builtin/clone.c:139
+msgid "key=value"
+msgstr "key=value"
 
-#: builtin/branch.c:603 builtin/branch.c:605
-msgid "print only branches that don't contain the commit"
-msgstr "只打印不包含该提交的分支"
+#: builtin/clone.c:140
+msgid "set config inside the new repository"
+msgstr "在新仓库中设置配置信息"
 
-#: builtin/branch.c:608
-msgid "Specific git-branch actions:"
-msgstr "具体的 git-branch 动作："
+#: builtin/clone.c:142 builtin/fetch.c:190 builtin/ls-remote.c:76
+#: builtin/push.c:573 builtin/send-pack.c:172
+msgid "server-specific"
+msgstr "server-specific"
 
-#: builtin/branch.c:609
-msgid "list both remote-tracking and local branches"
-msgstr "列出远程跟踪及本地分支"
+#: builtin/clone.c:142 builtin/fetch.c:190 builtin/ls-remote.c:76
+#: builtin/push.c:573 builtin/send-pack.c:173
+msgid "option to transmit"
+msgstr "传输选项"
 
-#: builtin/branch.c:611
-msgid "delete fully merged branch"
-msgstr "删除完全合并的分支"
+#: builtin/clone.c:143 builtin/fetch.c:191 builtin/pull.c:240
+#: builtin/push.c:574
+msgid "use IPv4 addresses only"
+msgstr "只使用 IPv4 地址"
 
-#: builtin/branch.c:612
-msgid "delete branch (even if not merged)"
-msgstr "删除分支（即使没有合并）"
+#: builtin/clone.c:145 builtin/fetch.c:193 builtin/pull.c:243
+#: builtin/push.c:576
+msgid "use IPv6 addresses only"
+msgstr "只使用 IPv6 地址"
 
-#: builtin/branch.c:613
-msgid "move/rename a branch and its reflog"
-msgstr "移动/重命名一个分支，以及它的引用日志"
+#: builtin/clone.c:149
+msgid "any cloned submodules will use their remote-tracking branch"
+msgstr "任何克隆的子模组将使用它们的远程跟踪分支"
+
+#: builtin/clone.c:151
+msgid "initialize sparse-checkout file to include only files at root"
+msgstr "初始化稀疏检出文件，只包含根目录文件"
 
-#: builtin/branch.c:614
-msgid "move/rename a branch, even if target exists"
-msgstr "移动/重命名一个分支，即使目标已存在"
+#: builtin/clone.c:287
+msgid ""
+"No directory name could be guessed.\n"
+"Please specify a directory on the command line"
+msgstr ""
+"无法猜到目录名。\n"
+"请在命令行指定一个目录"
 
-#: builtin/branch.c:615
-msgid "copy a branch and its reflog"
-msgstr "拷贝一个分支和它的引用日志"
+#: builtin/clone.c:340
+#, c-format
+msgid "info: Could not add alternate for '%s': %s\n"
+msgstr "info: 不能为 '%s' 添加一个备用：%s\n"
 
-#: builtin/branch.c:616
-msgid "copy a branch, even if target exists"
-msgstr "拷贝一个分支，即使目标已存在"
+#: builtin/clone.c:413
+#, c-format
+msgid "%s exists and is not a directory"
+msgstr "%s 存在且不是一个目录"
 
-#: builtin/branch.c:617
-msgid "list branch names"
-msgstr "列出分支名"
+#: builtin/clone.c:430
+#, c-format
+msgid "failed to start iterator over '%s'"
+msgstr "无法在 '%s' 上启动迭代器"
 
-#: builtin/branch.c:618
-msgid "create the branch's reflog"
-msgstr "创建分支的引用日志"
+#: builtin/clone.c:460
+#, c-format
+msgid "failed to create link '%s'"
+msgstr "创建链接 '%s' 失败"
 
-#: builtin/branch.c:620
-msgid "edit the description for the branch"
-msgstr "标记分支的描述"
+#: builtin/clone.c:464
+#, c-format
+msgid "failed to copy file to '%s'"
+msgstr "拷贝文件至 '%s' 失败"
 
-#: builtin/branch.c:621
-msgid "force creation, move/rename, deletion"
-msgstr "强制创建、移动/重命名、删除"
+#: builtin/clone.c:469
+#, c-format
+msgid "failed to iterate over '%s'"
+msgstr "无法在 '%s' 上迭代"
 
-#: builtin/branch.c:622
-msgid "print only branches that are merged"
-msgstr "只打印已经合并的分支"
+#: builtin/clone.c:494
+#, c-format
+msgid "done.\n"
+msgstr "完成。\n"
 
-#: builtin/branch.c:623
-msgid "print only branches that are not merged"
-msgstr "只打印尚未合并的分支"
+#: builtin/clone.c:508
+msgid ""
+"Clone succeeded, but checkout failed.\n"
+"You can inspect what was checked out with 'git status'\n"
+"and retry with 'git restore --source=HEAD :/'\n"
+msgstr ""
+"克隆成功，但是检出失败。\n"
+"您可以通过 'git status' 检查哪些已被检出，然后使用命令\n"
+"'git restore --source=HEAD :/' 重试\n"
 
-#: builtin/branch.c:624
-msgid "list branches in columns"
-msgstr "以列的方式显示分支"
+#: builtin/clone.c:585
+#, c-format
+msgid "Could not find remote branch %s to clone."
+msgstr "不能发现要克隆的远程分支 %s。"
 
-#: builtin/branch.c:625 builtin/for-each-ref.c:40 builtin/ls-remote.c:70
-#: builtin/tag.c:412
-msgid "key"
-msgstr "key"
+#: builtin/clone.c:704
+#, c-format
+msgid "unable to update %s"
+msgstr "不能更新 %s"
 
-#: builtin/branch.c:626 builtin/for-each-ref.c:41 builtin/ls-remote.c:71
-#: builtin/tag.c:413
-msgid "field name to sort on"
-msgstr "排序的字段名"
+#: builtin/clone.c:752
+msgid "failed to initialize sparse-checkout"
+msgstr "无法初始化稀疏检出"
 
-#: builtin/branch.c:628 builtin/for-each-ref.c:43 builtin/notes.c:408
-#: builtin/notes.c:411 builtin/notes.c:571 builtin/notes.c:574
-#: builtin/tag.c:415
-msgid "object"
-msgstr "对象"
+#: builtin/clone.c:775
+msgid "remote HEAD refers to nonexistent ref, unable to checkout.\n"
+msgstr "远程 HEAD 指向一个不存在的引用，无法检出。\n"
 
-#: builtin/branch.c:629
-msgid "print only branches of the object"
-msgstr "只打印指向该对象的分支"
+#: builtin/clone.c:806
+msgid "unable to checkout working tree"
+msgstr "不能检出工作区"
 
-#: builtin/branch.c:631 builtin/for-each-ref.c:49 builtin/tag.c:422
-msgid "sorting and filtering are case insensitive"
-msgstr "排序和过滤属于大小写不敏感"
+#: builtin/clone.c:856
+msgid "unable to write parameters to config file"
+msgstr "无法将参数写入配置文件"
 
-#: builtin/branch.c:632 builtin/for-each-ref.c:38 builtin/tag.c:420
-#: builtin/verify-tag.c:39
-msgid "format to use for the output"
-msgstr "输出格式"
+#: builtin/clone.c:919
+msgid "cannot repack to clean up"
+msgstr "无法执行 repack 来清理"
 
-#: builtin/branch.c:655 builtin/clone.c:737
-msgid "HEAD not found below refs/heads!"
-msgstr "HEAD 没有位于 /refs/heads 之下！"
+#: builtin/clone.c:921
+msgid "cannot unlink temporary alternates file"
+msgstr "无法删除临时的 alternates 文件"
 
-#: builtin/branch.c:678
-msgid "--column and --verbose are incompatible"
-msgstr "--column 和 --verbose 不兼容"
+#: builtin/clone.c:959 builtin/receive-pack.c:1948
+msgid "Too many arguments."
+msgstr "太多参数。"
 
-#: builtin/branch.c:693 builtin/branch.c:745 builtin/branch.c:754
-msgid "branch name required"
-msgstr "必须提供分支名"
+#: builtin/clone.c:963
+msgid "You must specify a repository to clone."
+msgstr "您必须指定一个仓库来克隆。"
 
-#: builtin/branch.c:721
-msgid "Cannot give description to detached HEAD"
-msgstr "不能向分离头指针提供描述"
+#: builtin/clone.c:976
+#, c-format
+msgid "--bare and --origin %s options are incompatible."
+msgstr "--bare 和 --origin %s 选项不兼容。"
 
-#: builtin/branch.c:726
-msgid "cannot edit description of more than one branch"
-msgstr "不能为一个以上的分支编辑描述"
+#: builtin/clone.c:979
+msgid "--bare and --separate-git-dir are incompatible."
+msgstr "--bare 和 --separate-git-dir 选项不兼容。"
 
-#: builtin/branch.c:733
+#: builtin/clone.c:992
 #, c-format
-msgid "No commit on branch '%s' yet."
-msgstr "分支 '%s' 尚无提交。"
+msgid "repository '%s' does not exist"
+msgstr "仓库 '%s' 不存在"
 
-#: builtin/branch.c:736
+#: builtin/clone.c:998 builtin/fetch.c:1787
 #, c-format
-msgid "No branch named '%s'."
-msgstr "没有分支 '%s'。"
+msgid "depth %s is not a positive number"
+msgstr "深度 %s 不是一个正数"
 
-#: builtin/branch.c:751
-msgid "too many branches for a copy operation"
-msgstr "为拷贝操作提供了太多的分支名"
+#: builtin/clone.c:1008
+#, c-format
+msgid "destination path '%s' already exists and is not an empty directory."
+msgstr "目标路径 '%s' 已经存在，并且不是一个空目录。"
 
-#: builtin/branch.c:760
-msgid "too many arguments for a rename operation"
-msgstr "为重命名操作提供了太多的参数"
+#: builtin/clone.c:1018
+#, c-format
+msgid "working tree '%s' already exists."
+msgstr "工作区 '%s' 已经存在。"
 
-#: builtin/branch.c:765
-msgid "too many arguments to set new upstream"
-msgstr "为设置新上游提供了太多的参数"
+#: builtin/clone.c:1033 builtin/clone.c:1054 builtin/difftool.c:271
+#: builtin/log.c:1866 builtin/worktree.c:302 builtin/worktree.c:334
+#, c-format
+msgid "could not create leading directories of '%s'"
+msgstr "不能为 '%s' 创建先导目录"
 
-#: builtin/branch.c:769
+#: builtin/clone.c:1038
 #, c-format
-msgid ""
-"could not set upstream of HEAD to %s when it does not point to any branch."
-msgstr "无法设置 HEAD 的上游为 %s，因为 HEAD 没有指向任何分支。"
+msgid "could not create work tree dir '%s'"
+msgstr "不能创建工作区目录 '%s'"
 
-#: builtin/branch.c:772 builtin/branch.c:794 builtin/branch.c:810
+#: builtin/clone.c:1058
 #, c-format
-msgid "no such branch '%s'"
-msgstr "没有此分支 '%s'"
+msgid "Cloning into bare repository '%s'...\n"
+msgstr "克隆到纯仓库 '%s'...\n"
 
-#: builtin/branch.c:776
+#: builtin/clone.c:1060
 #, c-format
-msgid "branch '%s' does not exist"
-msgstr "分支 '%s' 不存在"
+msgid "Cloning into '%s'...\n"
+msgstr "正克隆到 '%s'...\n"
 
-#: builtin/branch.c:788
-msgid "too many arguments to unset upstream"
-msgstr "为取消上游设置操作提供了太多的参数"
+#: builtin/clone.c:1084
+msgid ""
+"clone --recursive is not compatible with both --reference and --reference-if-"
+"able"
+msgstr "clone --recursive 和 --reference 以及 --reference-if-able 不兼容"
 
-#: builtin/branch.c:792
-msgid "could not unset upstream of HEAD when it does not point to any branch."
-msgstr "无法取消 HEAD 的上游设置因为它没有指向一个分支"
+#: builtin/clone.c:1148
+msgid "--depth is ignored in local clones; use file:// instead."
+msgstr "--depth 在本地克隆时被忽略，请改用 file:// 协议。"
 
-#: builtin/branch.c:798
-#, c-format
-msgid "Branch '%s' has no upstream information"
-msgstr "分支 '%s' 没有上游信息"
+#: builtin/clone.c:1150
+msgid "--shallow-since is ignored in local clones; use file:// instead."
+msgstr "--shallow-since 在本地克隆时被忽略，请改用 file:// 协议。"
 
-#: builtin/branch.c:813
-msgid "-a and -r options to 'git branch' do not make sense with a branch name"
-msgstr "'git branch' 的 -a 和 -r 选项带一个分支名参数没有意义"
+#: builtin/clone.c:1152
+msgid "--shallow-exclude is ignored in local clones; use file:// instead."
+msgstr "--shallow-exclude 在本地克隆时被忽略，请改用 file:// 协议。"
 
-#: builtin/branch.c:816
-msgid ""
-"the '--set-upstream' option is no longer supported. Please use '--track' or "
-"'--set-upstream-to' instead."
-msgstr ""
-"不再支持选项 '--set-upstream'。请使用 '--track' 或 '--set-upstream-to'。"
+#: builtin/clone.c:1154
+msgid "--filter is ignored in local clones; use file:// instead."
+msgstr "--filter 在本地克隆时被忽略，请改用 file:// 协议。"
+
+#: builtin/clone.c:1157
+msgid "source repository is shallow, ignoring --local"
+msgstr "源仓库是浅克隆，忽略 --local"
+
+#: builtin/clone.c:1162
+msgid "--local is ignored"
+msgstr "--local 被忽略"
 
-#: builtin/bundle.c:45
+#: builtin/clone.c:1237 builtin/clone.c:1245
 #, c-format
-msgid "%s is okay\n"
-msgstr "%s 可以\n"
+msgid "Remote branch %s not found in upstream %s"
+msgstr "远程分支 %s 在上游 %s 未发现"
 
-#: builtin/bundle.c:58
-msgid "Need a repository to create a bundle."
-msgstr "需要一个仓库来创建包。"
+#: builtin/clone.c:1248
+msgid "You appear to have cloned an empty repository."
+msgstr "您似乎克隆了一个空仓库。"
 
-#: builtin/bundle.c:62
-msgid "Need a repository to unbundle."
-msgstr "需要一个仓库来解包。"
+#: builtin/column.c:10
+msgid "git column [<options>]"
+msgstr "git column [<选项>]"
 
-#: builtin/cat-file.c:525
-msgid ""
-"git cat-file (-t [--allow-unknown-type] | -s [--allow-unknown-type] | -e | -"
-"p | <type> | --textconv | --filters) [--path=<path>] <object>"
-msgstr ""
-"git cat-file (-t [--allow-unknown-type] | -s [--allow-unknown-type] | -e | -"
-"p | <类型> | --textconv | --filters) [--path=<路径>] <对象>"
+#: builtin/column.c:27
+msgid "lookup config vars"
+msgstr "查找配置变量"
 
-#: builtin/cat-file.c:526
-msgid ""
-"git cat-file (--batch | --batch-check) [--follow-symlinks] [--textconv | --"
-"filters]"
-msgstr ""
-"git cat-file (--batch | --batch-check) [--follow-symlinks] [--textconv | --"
-"filters]"
+#: builtin/column.c:28 builtin/column.c:29
+msgid "layout to use"
+msgstr "要使用的布局"
 
-#: builtin/cat-file.c:563
-msgid "<type> can be one of: blob, tree, commit, tag"
-msgstr "<类型> 可以是其中之一：blob、tree、commit、tag"
+#: builtin/column.c:30
+msgid "Maximum width"
+msgstr "最大宽度"
 
-#: builtin/cat-file.c:564
-msgid "show object type"
-msgstr "显示对象类型"
+#: builtin/column.c:31
+msgid "Padding space on left border"
+msgstr "左边框的填充空间"
 
-#: builtin/cat-file.c:565
-msgid "show object size"
-msgstr "显示对象大小"
+#: builtin/column.c:32
+msgid "Padding space on right border"
+msgstr "右边框的填充空间"
 
-#: builtin/cat-file.c:567
-msgid "exit with zero when there's no error"
-msgstr "当没有错误时退出并返回零"
+#: builtin/column.c:33
+msgid "Padding space between columns"
+msgstr "两列之间的填充空间"
 
-#: builtin/cat-file.c:568
-msgid "pretty-print object's content"
-msgstr "美观地打印对象的内容"
+#: builtin/column.c:51
+msgid "--command must be the first argument"
+msgstr "--command 必须是第一个参数"
 
-#: builtin/cat-file.c:570
-msgid "for blob objects, run textconv on object's content"
-msgstr "对于数据对象，对其内容做文本转换"
+#: builtin/commit-tree.c:18
+msgid ""
+"git commit-tree [(-p <parent>)...] [-S[<keyid>]] [(-m <message>)...] [(-F "
+"<file>)...] <tree>"
+msgstr ""
+"git commit-tree [(-p <父提交>)...] [-S[<keyid>]] [(-m <消息>)...] [(-F <文件"
+">)...] <树>"
 
-#: builtin/cat-file.c:572
-msgid "for blob objects, run filters on object's content"
-msgstr "对于数据对象，对其内容做过滤"
+#: builtin/commit-tree.c:31
+#, c-format
+msgid "duplicate parent %s ignored"
+msgstr "忽略重复的父提交 %s"
 
-#: builtin/cat-file.c:573 git-submodule.sh:894
-msgid "blob"
-msgstr "数据对象"
+#: builtin/commit-tree.c:56 builtin/commit-tree.c:136 builtin/log.c:526
+#, c-format
+msgid "not a valid object name %s"
+msgstr "不是一个有效的对象名 %s"
 
-#: builtin/cat-file.c:574
-msgid "use a specific path for --textconv/--filters"
-msgstr "对于 --textconv/--filters 使用一个特定的路径"
+#: builtin/commit-tree.c:93
+#, c-format
+msgid "git commit-tree: failed to open '%s'"
+msgstr "git commit-tree：无法打开 '%s'"
 
-#: builtin/cat-file.c:576
-msgid "allow -s and -t to work with broken/corrupt objects"
-msgstr "允许 -s 和 -t 对损坏的对象生效"
+#: builtin/commit-tree.c:96
+#, c-format
+msgid "git commit-tree: failed to read '%s'"
+msgstr "git commit-tree：无法读取 '%s'"
 
-#: builtin/cat-file.c:577
-msgid "buffer --batch output"
-msgstr "缓冲 --batch 的输出"
+#: builtin/commit-tree.c:98
+#, c-format
+msgid "git commit-tree: failed to close '%s'"
+msgstr "git commit-tree：无法关闭 '%s'"
 
-#: builtin/cat-file.c:579
-msgid "show info and content of objects fed from the standard input"
-msgstr "显示从标准输入提供的对象的信息和内容"
+#: builtin/commit-tree.c:111
+msgid "parent"
+msgstr "父提交"
 
-#: builtin/cat-file.c:582
-msgid "show info about objects fed from the standard input"
-msgstr "显示从标准输入提供的对象的信息"
+#: builtin/commit-tree.c:112
+msgid "id of a parent commit object"
+msgstr "父提交对象 ID"
 
-#: builtin/cat-file.c:585
-msgid "follow in-tree symlinks (used with --batch or --batch-check)"
-msgstr "跟随树内符号链接（和 --batch 或 --batch-check 共用）"
+#: builtin/commit-tree.c:114 builtin/commit.c:1496 builtin/merge.c:270
+#: builtin/notes.c:409 builtin/notes.c:575 builtin/stash.c:1469
+#: builtin/tag.c:412
+msgid "message"
+msgstr "说明"
 
-#: builtin/cat-file.c:587
-msgid "show all objects with --batch or --batch-check"
-msgstr "使用 --batch 或 --batch-check 参数显示所有对象"
+#: builtin/commit-tree.c:115 builtin/commit.c:1496
+msgid "commit message"
+msgstr "提交说明"
 
-#: builtin/check-attr.c:12
-msgid "git check-attr [-a | --all | <attr>...] [--] <pathname>..."
-msgstr "git check-attr [-a | --all | <属性>...] [--] <路径名>..."
+#: builtin/commit-tree.c:118
+msgid "read commit log message from file"
+msgstr "从文件中读取提交说明"
 
-#: builtin/check-attr.c:13
-msgid "git check-attr --stdin [-z] [-a | --all | <attr>...]"
-msgstr "git check-attr --stdin [-z] [-a | --all | <属性>...]"
+#: builtin/commit-tree.c:121 builtin/commit.c:1508 builtin/merge.c:287
+#: builtin/pull.c:195 builtin/revert.c:118
+msgid "GPG sign commit"
+msgstr "GPG 提交签名"
 
-#: builtin/check-attr.c:20
-msgid "report all attributes set on file"
-msgstr "报告设置在文件上的所有属性"
+#: builtin/commit-tree.c:133
+msgid "must give exactly one tree"
+msgstr "必须精确地提供一个树"
+
+#: builtin/commit-tree.c:140
+msgid "git commit-tree: failed to read"
+msgstr "git commit-tree：读取失败"
 
-#: builtin/check-attr.c:21
-msgid "use .gitattributes only from the index"
-msgstr "只使用索引中的 .gitattributes"
+#: builtin/commit.c:41
+msgid "git commit [<options>] [--] <pathspec>..."
+msgstr "git commit [<选项>] [--] <路径规格>..."
 
-#: builtin/check-attr.c:22 builtin/check-ignore.c:24 builtin/hash-object.c:100
-msgid "read file names from stdin"
-msgstr "从标准输入读出文件名"
+#: builtin/commit.c:46
+msgid "git status [<options>] [--] <pathspec>..."
+msgstr "git status [<选项>] [--] <路径规格>..."
 
-#: builtin/check-attr.c:24 builtin/check-ignore.c:26
-msgid "terminate input and output records by a NUL character"
-msgstr "输入和输出的记录使用 NUL 字符终结"
+#: builtin/commit.c:51
+msgid ""
+"You asked to amend the most recent commit, but doing so would make\n"
+"it empty. You can repeat your command with --allow-empty, or you can\n"
+"remove the commit entirely with \"git reset HEAD^\".\n"
+msgstr ""
+"您要修补最近的提交，但这么做会让它成为空提交。您可以重复您的命令并带上\n"
+"--allow-empty 选项，或者您可用命令 \"git reset HEAD^\" 整个删除该提交。\n"
 
-#: builtin/check-ignore.c:20 builtin/checkout.c:1113 builtin/gc.c:500
-msgid "suppress progress reporting"
-msgstr "不显示进度报告"
+#: builtin/commit.c:56
+msgid ""
+"The previous cherry-pick is now empty, possibly due to conflict resolution.\n"
+"If you wish to commit it anyway, use:\n"
+"\n"
+"    git commit --allow-empty\n"
+"\n"
+msgstr ""
+"之前的拣选操作现在是一个空提交，可能是由冲突解决导致的。如果您无论如何\n"
+"也要提交，使用命令：\n"
+"\n"
+"    git commit --allow-empty\n"
+"\n"
 
-#: builtin/check-ignore.c:28
-msgid "show non-matching input paths"
-msgstr "显示未匹配的输入路径"
+#: builtin/commit.c:63
+msgid "Otherwise, please use 'git cherry-pick --skip'\n"
+msgstr "否则，请使用 'git cherry-pick --skip'\n"
 
-#: builtin/check-ignore.c:30
-msgid "ignore index when checking"
-msgstr "检查时忽略索引"
+#: builtin/commit.c:66
+msgid ""
+"and then use:\n"
+"\n"
+"    git cherry-pick --continue\n"
+"\n"
+"to resume cherry-picking the remaining commits.\n"
+"If you wish to skip this commit, use:\n"
+"\n"
+"    git cherry-pick --skip\n"
+"\n"
+msgstr ""
+"然后使用：\n"
+"\n"
+"    git cherry-pick --continue\n"
+"\n"
+"来继续拣选剩余提交。如果您想跳过此提交，使用：\n"
+"\n"
+"    git cherry-pick --skip\n"
+"\n"
 
-#: builtin/check-ignore.c:159
-msgid "cannot specify pathnames with --stdin"
-msgstr "不能同时指定路径及 --stdin 参数"
+#: builtin/commit.c:315
+msgid "failed to unpack HEAD tree object"
+msgstr "解包 HEAD 树对象失败"
 
-#: builtin/check-ignore.c:162
-msgid "-z only makes sense with --stdin"
-msgstr "-z 需要和 --stdin 参数共用才有意义"
+#: builtin/commit.c:351
+msgid "--pathspec-from-file with -a does not make sense"
+msgstr "--pathspec-from-file 和 -a 在一起没有意义"
 
-#: builtin/check-ignore.c:164
-msgid "no path specified"
-msgstr "未指定路径"
+#: builtin/commit.c:364
+msgid "No paths with --include/--only does not make sense."
+msgstr "参数 --include/--only 不跟路径没有意义。"
 
-#: builtin/check-ignore.c:168
-msgid "--quiet is only valid with a single pathname"
-msgstr "参数 --quiet 只在提供一个路径名时有效"
+#: builtin/commit.c:376
+msgid "unable to create temporary index"
+msgstr "不能创建临时索引"
 
-#: builtin/check-ignore.c:170
-msgid "cannot have both --quiet and --verbose"
-msgstr "不能同时提供 --quiet 和 --verbose 参数"
+#: builtin/commit.c:382
+msgid "interactive add failed"
+msgstr "交互式添加失败"
 
-#: builtin/check-ignore.c:173
-msgid "--non-matching is only valid with --verbose"
-msgstr "--non-matching 选项只在使用 --verbose 时有效"
+#: builtin/commit.c:396
+msgid "unable to update temporary index"
+msgstr "无法更新临时索引"
 
-#: builtin/check-mailmap.c:9
-msgid "git check-mailmap [<options>] <contact>..."
-msgstr "git check-mailmap [<选项>] <联系地址>..."
+#: builtin/commit.c:398
+msgid "Failed to update main cache tree"
+msgstr "不能更新树的主缓存"
 
-#: builtin/check-mailmap.c:14
-msgid "also read contacts from stdin"
-msgstr "还从标准输入读取联系地址"
+#: builtin/commit.c:423 builtin/commit.c:446 builtin/commit.c:492
+msgid "unable to write new_index file"
+msgstr "无法写 new_index 文件"
 
-#: builtin/check-mailmap.c:25
-#, c-format
-msgid "unable to parse contact: %s"
-msgstr "不能解析联系地址：%s"
+#: builtin/commit.c:475
+msgid "cannot do a partial commit during a merge."
+msgstr "在合并过程中不能做部分提交。"
 
-#: builtin/check-mailmap.c:48
-msgid "no contacts specified"
-msgstr "未指定联系地址"
+#: builtin/commit.c:477
+msgid "cannot do a partial commit during a cherry-pick."
+msgstr "在拣选过程中不能做部分提交。"
 
-#: builtin/checkout-index.c:128
-msgid "git checkout-index [<options>] [--] [<file>...]"
-msgstr "git checkout-index [<选项>] [--] [<文件>...]"
+#: builtin/commit.c:485
+msgid "cannot read the index"
+msgstr "无法读取索引"
 
-#: builtin/checkout-index.c:143
-msgid "stage should be between 1 and 3 or all"
-msgstr "索引值应该取值 1 到 3 或者 all"
+#: builtin/commit.c:504
+msgid "unable to write temporary index file"
+msgstr "无法写临时索引文件"
 
-#: builtin/checkout-index.c:159
-msgid "check out all files in the index"
-msgstr "检出索引区的所有文件"
+#: builtin/commit.c:602
+#, c-format
+msgid "commit '%s' lacks author header"
+msgstr "提交 '%s' 缺少作者信息"
 
-#: builtin/checkout-index.c:160
-msgid "force overwrite of existing files"
-msgstr "强制覆盖现有的文件"
+#: builtin/commit.c:604
+#, c-format
+msgid "commit '%s' has malformed author line"
+msgstr "提交 '%s' 有格式错误的作者信息"
 
-#: builtin/checkout-index.c:162
-msgid "no warning for existing files and files not in index"
-msgstr "存在或不在索引中的文件都没有警告"
+#: builtin/commit.c:623
+msgid "malformed --author parameter"
+msgstr "格式错误的 --author 参数"
 
-#: builtin/checkout-index.c:164
-msgid "don't checkout new files"
-msgstr "不检出新文件"
+#: builtin/commit.c:676
+msgid ""
+"unable to select a comment character that is not used\n"
+"in the current commit message"
+msgstr "无法选择一个未被当前提交说明使用的注释字符"
 
-#: builtin/checkout-index.c:166
-msgid "update stat information in the index file"
-msgstr "更新索引中文件的状态信息"
+#: builtin/commit.c:714 builtin/commit.c:747 builtin/commit.c:1092
+#, c-format
+msgid "could not lookup commit %s"
+msgstr "不能查询提交 %s"
 
-#: builtin/checkout-index.c:170
-msgid "read list of paths from the standard input"
-msgstr "从标准输入读取路径列表"
+#: builtin/commit.c:726 builtin/shortlog.c:319
+#, c-format
+msgid "(reading log message from standard input)\n"
+msgstr "（正从标准输入中读取日志信息）\n"
 
-#: builtin/checkout-index.c:172
-msgid "write the content to temporary files"
-msgstr "将内容写入临时文件"
+#: builtin/commit.c:728
+msgid "could not read log from standard input"
+msgstr "不能从标准输入中读取日志信息"
 
-#: builtin/checkout-index.c:173 builtin/column.c:31
-#: builtin/submodule--helper.c:1216 builtin/submodule--helper.c:1219
-#: builtin/submodule--helper.c:1227 builtin/submodule--helper.c:1591
-#: builtin/worktree.c:610
-msgid "string"
-msgstr "字符串"
+#: builtin/commit.c:732
+#, c-format
+msgid "could not read log file '%s'"
+msgstr "不能读取日志文件 '%s'"
 
-#: builtin/checkout-index.c:174
-msgid "when creating files, prepend <string>"
-msgstr "在创建文件时，在前面加上 <字符串>"
+#: builtin/commit.c:763 builtin/commit.c:779
+msgid "could not read SQUASH_MSG"
+msgstr "不能读取 SQUASH_MSG"
 
-#: builtin/checkout-index.c:176
-msgid "copy out the files from named stage"
-msgstr "从指定暂存区中拷出文件"
+#: builtin/commit.c:770
+msgid "could not read MERGE_MSG"
+msgstr "不能读取 MERGE_MSG"
 
-#: builtin/checkout.c:27
-msgid "git checkout [<options>] <branch>"
-msgstr "git checkout [<选项>] <分支>"
+#: builtin/commit.c:830
+msgid "could not write commit template"
+msgstr "不能写提交模版"
 
-#: builtin/checkout.c:28
-msgid "git checkout [<options>] [<branch>] -- <file>..."
-msgstr "git checkout [<选项>] [<分支>] -- <文件>..."
+#: builtin/commit.c:849
+#, c-format
+msgid ""
+"\n"
+"It looks like you may be committing a merge.\n"
+"If this is not correct, please remove the file\n"
+"\t%s\n"
+"and try again.\n"
+msgstr ""
+"\n"
+"似乎您正在做一个合并提交。如果不对，请删除文件\n"
+"\t%s\n"
+"然后重试。\n"
 
-#: builtin/checkout.c:136 builtin/checkout.c:169
+#: builtin/commit.c:854
 #, c-format
-msgid "path '%s' does not have our version"
-msgstr "路径 '%s' 没有我们的版本"
+msgid ""
+"\n"
+"It looks like you may be committing a cherry-pick.\n"
+"If this is not correct, please remove the file\n"
+"\t%s\n"
+"and try again.\n"
+msgstr ""
+"\n"
+"似乎您正在做一个拣选提交。如果不对，请删除文件\n"
+"\t%s\n"
+"然后重试。\n"
 
-#: builtin/checkout.c:138 builtin/checkout.c:171
+#: builtin/commit.c:867
 #, c-format
-msgid "path '%s' does not have their version"
-msgstr "路径 '%s' 没有他们的版本"
+msgid ""
+"Please enter the commit message for your changes. Lines starting\n"
+"with '%c' will be ignored, and an empty message aborts the commit.\n"
+msgstr ""
+"请为您的变更输入提交说明。以 '%c' 开始的行将被忽略，而一个空的提交\n"
+"说明将会终止提交。\n"
 
-#: builtin/checkout.c:154
+#: builtin/commit.c:875
 #, c-format
-msgid "path '%s' does not have all necessary versions"
-msgstr "路径 '%s' 没有全部必须的版本"
+msgid ""
+"Please enter the commit message for your changes. Lines starting\n"
+"with '%c' will be kept; you may remove them yourself if you want to.\n"
+"An empty message aborts the commit.\n"
+msgstr ""
+"请为您的变更输入提交说明。以 '%c' 开始的行将被保留，如果您原意\n"
+"也可以删除它们。一个空的提交说明将会终止提交。\n"
 
-#: builtin/checkout.c:198
+#  译者：为保证在输出中对齐，注意调整句中空格！
+#: builtin/commit.c:892
 #, c-format
-msgid "path '%s' does not have necessary versions"
-msgstr "路径 '%s' 没有必须的版本"
+msgid "%sAuthor:    %.*s <%.*s>"
+msgstr "%s作者：  %.*s <%.*s>"
 
-#: builtin/checkout.c:215
+#  译者：为保证在输出中对齐，注意调整句中空格！
+#: builtin/commit.c:900
 #, c-format
-msgid "path '%s': cannot merge"
-msgstr "path '%s'：无法合并"
+msgid "%sDate:      %s"
+msgstr "%s日期：  %s"
 
-#: builtin/checkout.c:231
+#  译者：为保证在输出中对齐，注意调整句中空格！
+#: builtin/commit.c:907
 #, c-format
-msgid "Unable to add merge result for '%s'"
-msgstr "无法为 '%s' 添加合并结果"
+msgid "%sCommitter: %.*s <%.*s>"
+msgstr "%s提交者：%.*s <%.*s>"
+
+#: builtin/commit.c:925
+msgid "Cannot read index"
+msgstr "无法读取索引"
+
+#: builtin/commit.c:992
+msgid "Error building trees"
+msgstr "无法创建树对象"
 
-#: builtin/checkout.c:253 builtin/checkout.c:256 builtin/checkout.c:259
-#: builtin/checkout.c:262
+#: builtin/commit.c:1006 builtin/tag.c:275
 #, c-format
-msgid "'%s' cannot be used with updating paths"
-msgstr "'%s' 不能在更新路径时使用"
+msgid "Please supply the message using either -m or -F option.\n"
+msgstr "请使用 -m 或 -F 选项提供提交说明。\n"
 
-#: builtin/checkout.c:265 builtin/checkout.c:268
+#: builtin/commit.c:1050
 #, c-format
-msgid "'%s' cannot be used with %s"
-msgstr "'%s' 不能和 %s 同时使用"
+msgid "--author '%s' is not 'Name <email>' and matches no existing author"
+msgstr "--author '%s' 不是 '姓名 <邮箱>' 格式，且未能在现有作者中找到匹配"
 
-#: builtin/checkout.c:271
+#: builtin/commit.c:1064
 #, c-format
-msgid "Cannot update paths and switch to branch '%s' at the same time."
-msgstr "不能同时更新路径并切换到分支'%s'。"
+msgid "Invalid ignored mode '%s'"
+msgstr "无效的忽略模式 '%s'"
 
-#: builtin/checkout.c:340 builtin/checkout.c:347
+#: builtin/commit.c:1082 builtin/commit.c:1322
 #, c-format
-msgid "path '%s' is unmerged"
-msgstr "路径 '%s' 未合并"
+msgid "Invalid untracked files mode '%s'"
+msgstr "无效的未追踪文件参数 '%s'"
 
-#: builtin/checkout.c:506
-msgid "you need to resolve your current index first"
-msgstr "您需要先解决当前索引的冲突"
+#: builtin/commit.c:1122
+msgid "--long and -z are incompatible"
+msgstr "--long 和 -z 选项不兼容"
 
-#: builtin/checkout.c:643
-#, c-format
-msgid "Can not do reflog for '%s': %s\n"
-msgstr "不能对 '%s' 执行 reflog 操作：%s\n"
+#: builtin/commit.c:1166
+msgid "Using both --reset-author and --author does not make sense"
+msgstr "同时使用 --reset-author 和 --author 没有意义"
 
-#: builtin/checkout.c:684
-msgid "HEAD is now at"
-msgstr "HEAD 目前位于"
+#: builtin/commit.c:1175
+msgid "You have nothing to amend."
+msgstr "您没有可修补的提交。"
 
-#: builtin/checkout.c:688 builtin/clone.c:691
-msgid "unable to update HEAD"
-msgstr "不能更新 HEAD"
+#: builtin/commit.c:1178
+msgid "You are in the middle of a merge -- cannot amend."
+msgstr "您正处于一个合并过程中 -- 无法修补提交。"
 
-#: builtin/checkout.c:692
-#, c-format
-msgid "Reset branch '%s'\n"
-msgstr "重置分支 '%s'\n"
+#: builtin/commit.c:1180
+msgid "You are in the middle of a cherry-pick -- cannot amend."
+msgstr "您正处于一个拣选过程中 -- 无法修补提交。"
 
-#: builtin/checkout.c:695
-#, c-format
-msgid "Already on '%s'\n"
-msgstr "已经位于 '%s'\n"
+#: builtin/commit.c:1183
+msgid "Options --squash and --fixup cannot be used together"
+msgstr "选项 --squash 和 --fixup 不能同时使用"
 
-#: builtin/checkout.c:699
-#, c-format
-msgid "Switched to and reset branch '%s'\n"
-msgstr "切换并重置分支 '%s'\n"
+#: builtin/commit.c:1193
+msgid "Only one of -c/-C/-F/--fixup can be used."
+msgstr "只能用一个 -c/-C/-F/--fixup 选项。"
 
-#: builtin/checkout.c:701 builtin/checkout.c:1046
-#, c-format
-msgid "Switched to a new branch '%s'\n"
-msgstr "切换到一个新分支 '%s'\n"
+#: builtin/commit.c:1195
+msgid "Option -m cannot be combined with -c/-C/-F."
+msgstr "选项 -m 不能和 -c/-C/-F 同时使用。"
 
-#: builtin/checkout.c:703
-#, c-format
-msgid "Switched to branch '%s'\n"
-msgstr "切换到分支 '%s'\n"
+#: builtin/commit.c:1203
+msgid "--reset-author can be used only with -C, -c or --amend."
+msgstr "--reset-author 只能和 -C、-c 或 --amend 同时使用。"
 
-#  译者：注意保持前导空格
-#: builtin/checkout.c:754
-#, c-format
-msgid " ... and %d more.\n"
-msgstr " ... 及其它 %d 个。\n"
+#: builtin/commit.c:1220
+msgid "Only one of --include/--only/--all/--interactive/--patch can be used."
+msgstr "只能用一个 --include/--only/--all/--interactive/--patch 选项。"
 
-#: builtin/checkout.c:760
+#: builtin/commit.c:1226
 #, c-format
-msgid ""
-"Warning: you are leaving %d commit behind, not connected to\n"
-"any of your branches:\n"
-"\n"
-"%s\n"
-msgid_plural ""
-"Warning: you are leaving %d commits behind, not connected to\n"
-"any of your branches:\n"
-"\n"
-"%s\n"
-msgstr[0] ""
-"警告：您正丢下 %d 个提交，未和任何分支关联：\n"
-"\n"
-"%s\n"
-msgstr[1] ""
-"警告：您正丢下 %d 个提交，未和任何分支关联：\n"
-"\n"
-"%s\n"
+msgid "paths '%s ...' with -a does not make sense"
+msgstr "路径  '%s ...' 和 -a 选项同时使用没有意义"
 
-#: builtin/checkout.c:779
-#, c-format
-msgid ""
-"If you want to keep it by creating a new branch, this may be a good time\n"
-"to do so with:\n"
-"\n"
-" git branch <new-branch-name> %s\n"
-"\n"
-msgid_plural ""
-"If you want to keep them by creating a new branch, this may be a good time\n"
-"to do so with:\n"
-"\n"
-" git branch <new-branch-name> %s\n"
-"\n"
-msgstr[0] ""
-"如果您想要通过创建新分支保存它，这可能是一个好时候。\n"
-"如下操作：\n"
-"\n"
-" git branch <新分支名> %s\n"
-"\n"
-msgstr[1] ""
-"如果您想要通过创建新分支保存它们，这可能是一个好时候。\n"
-"如下操作：\n"
-"\n"
-" git branch <新分支名> %s\n"
-"\n"
+#: builtin/commit.c:1357 builtin/commit.c:1519
+msgid "show status concisely"
+msgstr "以简洁的格式显示状态"
 
-#: builtin/checkout.c:811
-msgid "internal error in revision walk"
-msgstr "在版本遍历时遇到内部错误"
+#: builtin/commit.c:1359 builtin/commit.c:1521
+msgid "show branch information"
+msgstr "显示分支信息"
 
-#: builtin/checkout.c:815
-msgid "Previous HEAD position was"
-msgstr "之前的 HEAD 位置是"
+#: builtin/commit.c:1361
+msgid "show stash information"
+msgstr "显示贮藏区信息"
 
-#: builtin/checkout.c:843 builtin/checkout.c:1041
-msgid "You are on a branch yet to be born"
-msgstr "您位于一个尚未初始化的分支"
+#: builtin/commit.c:1363 builtin/commit.c:1523
+msgid "compute full ahead/behind values"
+msgstr "计算完整的领先/落后值"
 
-#: builtin/checkout.c:947
-#, c-format
-msgid "only one reference expected, %d given."
-msgstr "应只有一个引用，却给出了 %d 个"
+#: builtin/commit.c:1365
+msgid "version"
+msgstr "版本"
 
-#: builtin/checkout.c:987 builtin/worktree.c:240 builtin/worktree.c:389
-#, c-format
-msgid "invalid reference: %s"
-msgstr "无效引用：%s"
+#: builtin/commit.c:1365 builtin/commit.c:1525 builtin/push.c:549
+#: builtin/worktree.c:650
+msgid "machine-readable output"
+msgstr "机器可读的输出"
 
-#: builtin/checkout.c:1016
-#, c-format
-msgid "reference is not a tree: %s"
-msgstr "引用不是一个树：%s"
+#: builtin/commit.c:1368 builtin/commit.c:1527
+msgid "show status in long format (default)"
+msgstr "以长格式显示状态（默认）"
 
-#: builtin/checkout.c:1055
-msgid "paths cannot be used with switching branches"
-msgstr "路径不能和切换分支同时使用"
+#: builtin/commit.c:1371 builtin/commit.c:1530
+msgid "terminate entries with NUL"
+msgstr "条目以 NUL 字符结尾"
 
-#: builtin/checkout.c:1058 builtin/checkout.c:1062
-#, c-format
-msgid "'%s' cannot be used with switching branches"
-msgstr "'%s' 不能和切换分支同时使用"
+#: builtin/commit.c:1373 builtin/commit.c:1377 builtin/commit.c:1533
+#: builtin/fast-export.c:1153 builtin/fast-export.c:1156
+#: builtin/fast-export.c:1159 builtin/rebase.c:1525 parse-options.h:336
+msgid "mode"
+msgstr "模式"
 
-#: builtin/checkout.c:1066 builtin/checkout.c:1069 builtin/checkout.c:1074
-#: builtin/checkout.c:1077
-#, c-format
-msgid "'%s' cannot be used with '%s'"
-msgstr "'%s' 不能和 '%s' 同时使用"
+#: builtin/commit.c:1374 builtin/commit.c:1533
+msgid "show untracked files, optional modes: all, normal, no. (Default: all)"
+msgstr "显示未跟踪的文件，“模式”的可选参数：all、normal、no。（默认：all）"
 
-#: builtin/checkout.c:1082
-#, c-format
-msgid "Cannot switch branch to a non-commit '%s'"
-msgstr "不能切换分支到一个非提交 '%s'"
+#: builtin/commit.c:1378
+msgid ""
+"show ignored files, optional modes: traditional, matching, no. (Default: "
+"traditional)"
+msgstr ""
+"显示已忽略的文件，可选模式：traditional、matching、no。（默认：traditional）"
 
-#: builtin/checkout.c:1114 builtin/checkout.c:1116 builtin/clone.c:118
-#: builtin/remote.c:167 builtin/remote.c:169 builtin/worktree.c:433
-#: builtin/worktree.c:435
-msgid "branch"
-msgstr "分支"
+#: builtin/commit.c:1380 parse-options.h:192
+msgid "when"
+msgstr "何时"
 
-#: builtin/checkout.c:1115
-msgid "create and checkout a new branch"
-msgstr "创建并检出一个新的分支"
+#: builtin/commit.c:1381
+msgid ""
+"ignore changes to submodules, optional when: all, dirty, untracked. "
+"(Default: all)"
+msgstr ""
+"忽略子模组的更改，“何时”的可选参数：all、dirty、untracked。（默认：all）"
 
-#: builtin/checkout.c:1117
-msgid "create/reset and checkout a branch"
-msgstr "创建/重置并检出一个分支"
+#: builtin/commit.c:1383
+msgid "list untracked files in columns"
+msgstr "以列的方式显示未跟踪的文件"
 
-#: builtin/checkout.c:1118
-msgid "create reflog for new branch"
-msgstr "为新的分支创建引用日志"
+#: builtin/commit.c:1384
+msgid "do not detect renames"
+msgstr "不检测重命名"
 
-#: builtin/checkout.c:1119 builtin/worktree.c:437
-msgid "detach HEAD at named commit"
-msgstr "HEAD 从指定的提交分离"
+#: builtin/commit.c:1386
+msgid "detect renames, optionally set similarity index"
+msgstr "检测重命名，可以设置索引相似度"
 
-#: builtin/checkout.c:1120
-msgid "set upstream info for new branch"
-msgstr "为新的分支设置上游信息"
+#: builtin/commit.c:1406
+msgid "Unsupported combination of ignored and untracked-files arguments"
+msgstr "不支持已忽略和未跟踪文件参数的组合"
 
-#: builtin/checkout.c:1122
-msgid "new-branch"
-msgstr "新分支"
+#: builtin/commit.c:1489
+msgid "suppress summary after successful commit"
+msgstr "提交成功后不显示概述信息"
 
-#: builtin/checkout.c:1122
-msgid "new unparented branch"
-msgstr "新的没有父提交的分支"
+#: builtin/commit.c:1490
+msgid "show diff in commit message template"
+msgstr "在提交说明模板里显示差异"
 
-#: builtin/checkout.c:1123
-msgid "checkout our version for unmerged files"
-msgstr "对尚未合并的文件检出我们的版本"
+#: builtin/commit.c:1492
+msgid "Commit message options"
+msgstr "提交说明选项"
 
-#: builtin/checkout.c:1125
-msgid "checkout their version for unmerged files"
-msgstr "对尚未合并的文件检出他们的版本"
+#: builtin/commit.c:1493 builtin/merge.c:274 builtin/tag.c:414
+msgid "read message from file"
+msgstr "从文件中读取提交说明"
 
-#: builtin/checkout.c:1127
-msgid "force checkout (throw away local modifications)"
-msgstr "强制检出（丢弃本地修改）"
+#: builtin/commit.c:1494
+msgid "author"
+msgstr "作者"
 
-#: builtin/checkout.c:1129
-msgid "perform a 3-way merge with the new branch"
-msgstr "和新的分支执行三方合并"
+#: builtin/commit.c:1494
+msgid "override author for commit"
+msgstr "提交时覆盖作者"
 
-#: builtin/checkout.c:1131 builtin/merge.c:241
-msgid "update ignored files (default)"
-msgstr "更新忽略的文件（默认）"
+#: builtin/commit.c:1495 builtin/gc.c:538
+msgid "date"
+msgstr "日期"
 
-#: builtin/checkout.c:1133 builtin/log.c:1499 parse-options.h:264
-msgid "style"
-msgstr "风格"
+#: builtin/commit.c:1495
+msgid "override date for commit"
+msgstr "提交时覆盖日期"
 
-#: builtin/checkout.c:1134
-msgid "conflict style (merge or diff3)"
-msgstr "冲突输出风格（merge 或 diff3）"
+#: builtin/commit.c:1497 builtin/commit.c:1498 builtin/commit.c:1499
+#: builtin/commit.c:1500 parse-options.h:328 ref-filter.h:92
+msgid "commit"
+msgstr "提交"
 
-#: builtin/checkout.c:1137
-msgid "do not limit pathspecs to sparse entries only"
-msgstr "对路径不做稀疏检出的限制"
+#: builtin/commit.c:1497
+msgid "reuse and edit message from specified commit"
+msgstr "重用并编辑指定提交的提交说明"
 
-#: builtin/checkout.c:1139
-msgid "second guess 'git checkout <no-such-branch>'"
-msgstr "二次猜测'git checkout <无此分支>'"
+#: builtin/commit.c:1498
+msgid "reuse message from specified commit"
+msgstr "重用指定提交的提交说明"
 
-#: builtin/checkout.c:1141
-msgid "do not check if another worktree is holding the given ref"
-msgstr "不检查指定的引用是否被其他工作区所占用"
+#: builtin/commit.c:1499
+msgid "use autosquash formatted message to fixup specified commit"
+msgstr "使用 autosquash 格式的提交说明用以修正指定的提交"
 
-#: builtin/checkout.c:1145 builtin/clone.c:85 builtin/fetch.c:149
-#: builtin/merge.c:238 builtin/pull.c:128 builtin/push.c:572
-#: builtin/send-pack.c:174
-msgid "force progress reporting"
-msgstr "强制显示进度报告"
+#: builtin/commit.c:1500
+msgid "use autosquash formatted message to squash specified commit"
+msgstr "使用 autosquash 格式的提交说明用以压缩至指定的提交"
 
-#: builtin/checkout.c:1175
-msgid "-b, -B and --orphan are mutually exclusive"
-msgstr "-b、-B 和 --orphan 是互斥的"
+#: builtin/commit.c:1501
+msgid "the commit is authored by me now (used with -C/-c/--amend)"
+msgstr "现在将该提交的作者改为我（和 -C/-c/--amend 参数共用）"
 
-#: builtin/checkout.c:1192
-msgid "--track needs a branch name"
-msgstr "--track 需要一个分支名"
+#: builtin/commit.c:1502 builtin/log.c:1634 builtin/merge.c:289
+#: builtin/pull.c:164 builtin/revert.c:110
+msgid "add Signed-off-by:"
+msgstr "添加 Signed-off-by: 签名"
 
-#: builtin/checkout.c:1197
-msgid "Missing branch name; try -b"
-msgstr "缺少分支名；尝试 -b"
+#: builtin/commit.c:1503
+msgid "use specified template file"
+msgstr "使用指定的模板文件"
 
-#: builtin/checkout.c:1233
-msgid "invalid path specification"
-msgstr "无效的路径规格"
+#: builtin/commit.c:1504
+msgid "force edit of commit"
+msgstr "强制编辑提交"
 
-#: builtin/checkout.c:1240
-#, c-format
-msgid "'%s' is not a commit and a branch '%s' cannot be created from it"
-msgstr "'%s' 不是一个提交，不能基于它创建分支 '%s'"
+#: builtin/commit.c:1506
+msgid "include status in commit message template"
+msgstr "在提交说明模板里包含状态信息"
 
-#: builtin/checkout.c:1244
-#, c-format
-msgid "git checkout: --detach does not take a path argument '%s'"
-msgstr "git checkout：--detach 不能接收路径参数 '%s'"
+#: builtin/commit.c:1511
+msgid "Commit contents options"
+msgstr "提交内容选项"
 
-#: builtin/checkout.c:1248
-msgid ""
-"git checkout: --ours/--theirs, --force and --merge are incompatible when\n"
-"checking out of the index."
-msgstr ""
-"git checkout：在从索引检出时，--ours/--theirs、--force 和 --merge 不兼容。"
+#: builtin/commit.c:1512
+msgid "commit all changed files"
+msgstr "提交所有改动的文件"
 
-#: builtin/clean.c:26
-msgid ""
-"git clean [-d] [-f] [-i] [-n] [-q] [-e <pattern>] [-x | -X] [--] <paths>..."
-msgstr ""
-"git clean [-d] [-f] [-i] [-n] [-q] [-e <模式>] [-x | -X] [--] <路径>..."
+#: builtin/commit.c:1513
+msgid "add specified files to index for commit"
+msgstr "添加指定的文件到索引区等待提交"
 
-#: builtin/clean.c:30
-#, c-format
-msgid "Removing %s\n"
-msgstr "正删除 %s\n"
+#: builtin/commit.c:1514
+msgid "interactively add files"
+msgstr "交互式添加文件"
 
-#: builtin/clean.c:31
-#, c-format
-msgid "Would remove %s\n"
-msgstr "将删除 %s\n"
+#: builtin/commit.c:1515
+msgid "interactively add changes"
+msgstr "交互式添加变更"
 
-#: builtin/clean.c:32
-#, c-format
-msgid "Skipping repository %s\n"
-msgstr "忽略仓库 %s\n"
+#: builtin/commit.c:1516
+msgid "commit only specified files"
+msgstr "只提交指定的文件"
 
-#: builtin/clean.c:33
-#, c-format
-msgid "Would skip repository %s\n"
-msgstr "将忽略仓库 %s\n"
+#: builtin/commit.c:1517
+msgid "bypass pre-commit and commit-msg hooks"
+msgstr "绕过 pre-commit 和 commit-msg 钩子"
 
-#: builtin/clean.c:34
-#, c-format
-msgid "failed to remove %s"
-msgstr "无法删除 %s"
+#: builtin/commit.c:1518
+msgid "show what would be committed"
+msgstr "显示将要提交的内容"
 
-#: builtin/clean.c:302 git-add--interactive.perl:579
-#, c-format
-msgid ""
-"Prompt help:\n"
-"1          - select a numbered item\n"
-"foo        - select item based on unique prefix\n"
-"           - (empty) select nothing\n"
-msgstr ""
-"帮助：\n"
-"1          - 通过编号选择一个选项\n"
-"foo        - 通过唯一前缀选择一个选项\n"
-"           - （空）什么也不选择\n"
+#: builtin/commit.c:1531
+msgid "amend previous commit"
+msgstr "修改先前的提交"
 
-#: builtin/clean.c:306 git-add--interactive.perl:588
-#, c-format
-msgid ""
-"Prompt help:\n"
-"1          - select a single item\n"
-"3-5        - select a range of items\n"
-"2-3,6-9    - select multiple ranges\n"
-"foo        - select item based on unique prefix\n"
-"-...       - unselect specified items\n"
-"*          - choose all items\n"
-"           - (empty) finish selecting\n"
-msgstr ""
-"帮助：\n"
-"1          - 选择一个选项\n"
-"3-5        - 选择一个范围内的所有选项\n"
-"2-3,6-9    - 选择多个范围内的所有选项\n"
-"foo        - 通过唯一前缀选择一个选项\n"
-"-...       - 反选特定的选项\n"
-"*          - 选择所有选项\n"
-"           - （空）结束选择\n"
+#: builtin/commit.c:1532
+msgid "bypass post-rewrite hook"
+msgstr "绕过 post-rewrite 钩子"
 
-#: builtin/clean.c:522 git-add--interactive.perl:554
-#: git-add--interactive.perl:559
-#, c-format, perl-format
-msgid "Huh (%s)?\n"
-msgstr "嗯（%s）？\n"
+#: builtin/commit.c:1539
+msgid "ok to record an empty change"
+msgstr "允许一个空提交"
 
-#: builtin/clean.c:664
-#, c-format
-msgid "Input ignore patterns>> "
-msgstr "输入模版以排除条目>> "
+#: builtin/commit.c:1541
+msgid "ok to record a change with an empty message"
+msgstr "允许空的提交说明"
 
-#: builtin/clean.c:701
+#: builtin/commit.c:1614
 #, c-format
-msgid "WARNING: Cannot find items matched by: %s"
-msgstr "警告：无法找到和 %s 匹配的条目"
+msgid "Corrupt MERGE_HEAD file (%s)"
+msgstr "损坏的 MERGE_HEAD 文件（%s）"
 
-#: builtin/clean.c:722
-msgid "Select items to delete"
-msgstr "选择要删除的条目"
+#: builtin/commit.c:1621
+msgid "could not read MERGE_MODE"
+msgstr "不能读取 MERGE_MODE"
 
-#. TRANSLATORS: Make sure to keep [y/N] as is
-#: builtin/clean.c:763
+#: builtin/commit.c:1640
 #, c-format
-msgid "Remove %s [y/N]? "
-msgstr "删除 %s [y/N]？"
+msgid "could not read commit message: %s"
+msgstr "不能读取提交说明：%s"
 
-#: builtin/clean.c:788 git-add--interactive.perl:1717
+#: builtin/commit.c:1647
 #, c-format
-msgid "Bye.\n"
-msgstr "再见。\n"
-
-#: builtin/clean.c:796
-msgid ""
-"clean               - start cleaning\n"
-"filter by pattern   - exclude items from deletion\n"
-"select by numbers   - select items to be deleted by numbers\n"
-"ask each            - confirm each deletion (like \"rm -i\")\n"
-"quit                - stop cleaning\n"
-"help                - this screen\n"
-"?                   - help for prompt selection"
-msgstr ""
-"clean               - 开始清理\n"
-"filter by pattern   - 通过模版排除要删除的条目\n"
-"select by numbers   - 通过数字选择要删除的条目\n"
-"ask each            - 针对删除逐一询问（就像 \"rm -i\"）\n"
-"quit                - 停止删除并退出\n"
-"help                - 显示本帮助\n"
-"?                   - 显示如何在提示符下选择的帮助"
+msgid "Aborting commit due to empty commit message.\n"
+msgstr "终止提交因为提交说明为空。\n"
 
-#: builtin/clean.c:823 git-add--interactive.perl:1793
-msgid "*** Commands ***"
-msgstr "*** 命令 ***"
+#: builtin/commit.c:1652
+#, c-format
+msgid "Aborting commit; you did not edit the message.\n"
+msgstr "终止提交；您未更改来自模版的提交说明。\n"
 
-#: builtin/clean.c:824 git-add--interactive.perl:1790
-msgid "What now"
-msgstr "请选择"
+#: builtin/commit.c:1686
+msgid ""
+"repository has been updated, but unable to write\n"
+"new_index file. Check that disk is not full and quota is\n"
+"not exceeded, and then \"git restore --staged :/\" to recover."
+msgstr ""
+"仓库已更新，但无法写 new_index 文件。检查是否磁盘已满或\n"
+"磁盘配额已耗尽，然后执行 \"git restore --staged :/\" 恢复。"
 
-#: builtin/clean.c:832
-msgid "Would remove the following item:"
-msgid_plural "Would remove the following items:"
-msgstr[0] "将删除如下条目："
-msgstr[1] "将删除如下条目："
+#: builtin/commit-graph.c:11 builtin/commit-graph.c:17
+msgid ""
+"git commit-graph verify [--object-dir <objdir>] [--shallow] [--[no-]progress]"
+msgstr ""
+"git commit-graph verify [--object-dir <对象目录>] [--shallow] [--"
+"[no-]progress]"
 
-#: builtin/clean.c:848
-msgid "No more files to clean, exiting."
-msgstr "没有要清理的文件，退出。"
+#: builtin/commit-graph.c:12 builtin/commit-graph.c:22
+msgid ""
+"git commit-graph write [--object-dir <objdir>] [--append|--split] [--"
+"reachable|--stdin-packs|--stdin-commits] [--[no-]progress] <split options>"
+msgstr ""
+"git commit-graph write [--object-dir <对象目录>] [--append|--split] [--"
+"reachable|--stdin-packs|--stdin-commits] [--[no-]progress] <split options>"
 
-#: builtin/clean.c:910
-msgid "do not print names of files removed"
-msgstr "不打印删除文件的名称"
+#: builtin/commit-graph.c:48 builtin/commit-graph.c:103
+#: builtin/commit-graph.c:187 builtin/fetch.c:179 builtin/log.c:1657
+msgid "dir"
+msgstr "目录"
 
-#: builtin/clean.c:912
-msgid "force"
-msgstr "强制"
+#: builtin/commit-graph.c:49 builtin/commit-graph.c:104
+#: builtin/commit-graph.c:188
+msgid "The object directory to store the graph"
+msgstr "保存图形的对象目录"
 
-#: builtin/clean.c:913
-msgid "interactive cleaning"
-msgstr "交互式清除"
+#: builtin/commit-graph.c:51
+msgid "if the commit-graph is split, only verify the tip file"
+msgstr "如果提交图形被拆分，只验证头一个文件"
+
+#: builtin/commit-graph.c:73 t/helper/test-read-graph.c:23
+#, c-format
+msgid "Could not open commit-graph '%s'"
+msgstr "无法打开提交图形 '%s'"
+
+#: builtin/commit-graph.c:106
+msgid "start walk at all refs"
+msgstr "开始遍历所有引用"
 
-#: builtin/clean.c:915
-msgid "remove whole directories"
-msgstr "删除整个目录"
+#: builtin/commit-graph.c:108
+msgid "scan pack-indexes listed by stdin for commits"
+msgstr "从标准输入中的包索引文件列表中扫描提交"
 
-#: builtin/clean.c:916 builtin/describe.c:533 builtin/describe.c:535
-#: builtin/grep.c:871 builtin/log.c:157 builtin/log.c:159
-#: builtin/ls-files.c:548 builtin/name-rev.c:397 builtin/name-rev.c:399
-#: builtin/show-ref.c:176
-msgid "pattern"
-msgstr "模式"
+#: builtin/commit-graph.c:110
+msgid "start walk at commits listed by stdin"
+msgstr "从标准输入中的提交开始扫描"
 
-#: builtin/clean.c:917
-msgid "add <pattern> to ignore rules"
-msgstr "添加 <模式> 到忽略规则"
+#: builtin/commit-graph.c:112
+msgid "include all commits already in the commit-graph file"
+msgstr "包含 commit-graph 文件中已有所有提交"
 
-#: builtin/clean.c:918
-msgid "remove ignored files, too"
-msgstr "也删除忽略的文件"
+#: builtin/commit-graph.c:115
+msgid "allow writing an incremental commit-graph file"
+msgstr "允许写一个增量提交图形文件"
+
+#: builtin/commit-graph.c:117 builtin/commit-graph.c:121
+msgid "maximum number of commits in a non-base split commit-graph"
+msgstr "在非基本拆分提交图形中的最大提交数"
+
+#: builtin/commit-graph.c:119
+msgid "maximum ratio between two levels of a split commit-graph"
+msgstr "一个拆分提交图形的两个级别之间的最大比率"
+
+#: builtin/commit-graph.c:137
+msgid "use at most one of --reachable, --stdin-commits, or --stdin-packs"
+msgstr "不能同时使用 --reachable、--stdin-commits 或 --stdin-packs"
 
-#: builtin/clean.c:920
-msgid "remove only ignored files"
-msgstr "只删除忽略的文件"
+#: builtin/config.c:11
+msgid "git config [<options>]"
+msgstr "git config [<选项>]"
 
-#: builtin/clean.c:938
-msgid "-x and -X cannot be used together"
-msgstr "-x 和 -X 不能同时使用"
+#: builtin/config.c:103 builtin/env--helper.c:23
+#, c-format
+msgid "unrecognized --type argument, %s"
+msgstr "未能识别的 --type 参数，%s"
 
-#: builtin/clean.c:942
-msgid ""
-"clean.requireForce set to true and neither -i, -n, nor -f given; refusing to "
-"clean"
-msgstr ""
-"clean.requireForce 设置为 true 且未提供 -i、-n 或 -f 选项，拒绝执行清理动作"
+#: builtin/config.c:115
+msgid "only one type at a time"
+msgstr "一次只能一个类型"
 
-#: builtin/clean.c:945
-msgid ""
-"clean.requireForce defaults to true and neither -i, -n, nor -f given; "
-"refusing to clean"
-msgstr ""
-"clean.requireForce 默认为 true 且未提供 -i、-n 或 -f 选项，拒绝执行清理动作"
+#: builtin/config.c:124
+msgid "Config file location"
+msgstr "配置文件位置"
 
-#: builtin/clone.c:42
-msgid "git clone [<options>] [--] <repo> [<dir>]"
-msgstr "git clone [<选项>] [--] <仓库> [<路径>]"
+#: builtin/config.c:125
+msgid "use global config file"
+msgstr "使用全局配置文件"
 
-#: builtin/clone.c:87
-msgid "don't create a checkout"
-msgstr "不创建一个检出"
+#: builtin/config.c:126
+msgid "use system config file"
+msgstr "使用系统级配置文件"
 
-#: builtin/clone.c:88 builtin/clone.c:90 builtin/init-db.c:479
-msgid "create a bare repository"
-msgstr "创建一个纯仓库"
+#: builtin/config.c:127
+msgid "use repository config file"
+msgstr "使用仓库级配置文件"
 
-#: builtin/clone.c:92
-msgid "create a mirror repository (implies bare)"
-msgstr "创建一个镜像仓库（也是纯仓库）"
+#: builtin/config.c:128
+msgid "use per-worktree config file"
+msgstr "使用工作区级别的配置文件"
 
-#: builtin/clone.c:94
-msgid "to clone from a local repository"
-msgstr "从本地仓库克隆"
+#: builtin/config.c:129
+msgid "use given config file"
+msgstr "使用指定的配置文件"
 
-#: builtin/clone.c:96
-msgid "don't use local hardlinks, always copy"
-msgstr "不使用本地硬链接，始终复制"
+#: builtin/config.c:130
+msgid "blob-id"
+msgstr "数据对象 ID"
 
-#: builtin/clone.c:98
-msgid "setup as shared repository"
-msgstr "设置为共享仓库"
+#: builtin/config.c:130
+msgid "read config from given blob object"
+msgstr "从给定的数据对象读取配置"
 
-#: builtin/clone.c:100 builtin/clone.c:104
-msgid "pathspec"
-msgstr "路径规格"
+#: builtin/config.c:131
+msgid "Action"
+msgstr "操作"
 
-#: builtin/clone.c:100 builtin/clone.c:104
-msgid "initialize submodules in the clone"
-msgstr "在克隆时初始化子模组"
+#: builtin/config.c:132
+msgid "get value: name [value-regex]"
+msgstr "获取值：name [value-regex]"
 
-#: builtin/clone.c:107
-msgid "number of submodules cloned in parallel"
-msgstr "并发克隆的子模组的数量"
+#: builtin/config.c:133
+msgid "get all values: key [value-regex]"
+msgstr "获得所有的值：key [value-regex]"
 
-#: builtin/clone.c:108 builtin/init-db.c:476
-msgid "template-directory"
-msgstr "模板目录"
+#: builtin/config.c:134
+msgid "get values for regexp: name-regex [value-regex]"
+msgstr "根据正则表达式获得值：name-regex [value-regex]"
 
-#: builtin/clone.c:109 builtin/init-db.c:477
-msgid "directory from which templates will be used"
-msgstr "模板目录将被使用"
+#: builtin/config.c:135
+msgid "get value specific for the URL: section[.var] URL"
+msgstr "获得 URL 取值：section[.var] URL"
 
-#: builtin/clone.c:111 builtin/clone.c:113 builtin/submodule--helper.c:1223
-#: builtin/submodule--helper.c:1594
-msgid "reference repository"
-msgstr "参考仓库"
+#: builtin/config.c:136
+msgid "replace all matching variables: name value [value_regex]"
+msgstr "替换所有匹配的变量：name value [value_regex]"
 
-#: builtin/clone.c:115 builtin/submodule--helper.c:1225
-#: builtin/submodule--helper.c:1596
-msgid "use --reference only while cloning"
-msgstr "仅在克隆时参考 --reference 指向的本地仓库"
+#: builtin/config.c:137
+msgid "add a new variable: name value"
+msgstr "添加一个新的变量：name value"
 
-#: builtin/clone.c:116 builtin/column.c:27 builtin/merge-file.c:44
-#: builtin/pack-objects.c:3166 builtin/repack.c:213
-msgid "name"
-msgstr "名称"
+#: builtin/config.c:138
+msgid "remove a variable: name [value-regex]"
+msgstr "删除一个变量：name [value-regex]"
 
-#: builtin/clone.c:117
-msgid "use <name> instead of 'origin' to track upstream"
-msgstr "使用 <名称> 而不是 'origin' 去跟踪上游"
+#: builtin/config.c:139
+msgid "remove all matches: name [value-regex]"
+msgstr "删除所有匹配项：name [value-regex]"
 
-#: builtin/clone.c:119
-msgid "checkout <branch> instead of the remote's HEAD"
-msgstr "检出 <分支> 而不是远程 HEAD"
+#: builtin/config.c:140
+msgid "rename section: old-name new-name"
+msgstr "重命名小节：old-name new-name"
 
-#: builtin/clone.c:121
-msgid "path to git-upload-pack on the remote"
-msgstr "远程 git-upload-pack 路径"
+#: builtin/config.c:141
+msgid "remove a section: name"
+msgstr "删除一个小节：name"
 
-#: builtin/clone.c:122 builtin/fetch.c:150 builtin/grep.c:813
-#: builtin/pull.c:216
-msgid "depth"
-msgstr "深度"
+#: builtin/config.c:142
+msgid "list all"
+msgstr "列出所有"
 
-#: builtin/clone.c:123
-msgid "create a shallow clone of that depth"
-msgstr "创建一个指定深度的浅克隆"
+#: builtin/config.c:143
+msgid "open an editor"
+msgstr "打开一个编辑器"
 
-#: builtin/clone.c:124 builtin/fetch.c:152 builtin/pack-objects.c:3157
-#: parse-options.h:154
-msgid "time"
-msgstr "时间"
+#: builtin/config.c:144
+msgid "find the color configured: slot [default]"
+msgstr "获得配置的颜色：配置 [默认]"
 
-#: builtin/clone.c:125
-msgid "create a shallow clone since a specific time"
-msgstr "从一个特定时间创建一个浅克隆"
+#: builtin/config.c:145
+msgid "find the color setting: slot [stdout-is-tty]"
+msgstr "获得颜色设置：配置 [stdout-is-tty]"
 
-#: builtin/clone.c:126 builtin/fetch.c:154
-msgid "revision"
-msgstr "版本"
+#: builtin/config.c:146
+msgid "Type"
+msgstr "类型"
 
-#: builtin/clone.c:127 builtin/fetch.c:155
-msgid "deepen history of shallow clone, excluding rev"
-msgstr "深化浅克隆的历史，除了特定版本"
+#: builtin/config.c:147 builtin/env--helper.c:38
+msgid "value is given this type"
+msgstr "取值为该类型"
 
-#: builtin/clone.c:129
-msgid "clone only one branch, HEAD or --branch"
-msgstr "只克隆一个分支、HEAD 或 --branch"
+#: builtin/config.c:148
+msgid "value is \"true\" or \"false\""
+msgstr "值是 \"true\" 或 \"false\""
 
-#: builtin/clone.c:131
-msgid "don't clone any tags, and make later fetches not to follow them"
-msgstr "不要克隆任何标签，并且后续获取操作也不下载它们"
+#: builtin/config.c:149
+msgid "value is decimal number"
+msgstr "值是十进制数"
 
-#: builtin/clone.c:133
-msgid "any cloned submodules will be shallow"
-msgstr "子模组将以浅下载模式克隆"
+#: builtin/config.c:150
+msgid "value is --bool or --int"
+msgstr "值是 --bool or --int"
 
-#: builtin/clone.c:134 builtin/init-db.c:485
-msgid "gitdir"
-msgstr "git目录"
+#: builtin/config.c:151
+msgid "value is a path (file or directory name)"
+msgstr "值是一个路径（文件或目录名）"
 
-#: builtin/clone.c:135 builtin/init-db.c:486
-msgid "separate git dir from working tree"
-msgstr "git目录和工作区分离"
+#: builtin/config.c:152
+msgid "value is an expiry date"
+msgstr "值是一个到期日期"
 
-#: builtin/clone.c:136
-msgid "key=value"
-msgstr "key=value"
+#: builtin/config.c:153
+msgid "Other"
+msgstr "其它"
 
-#: builtin/clone.c:137
-msgid "set config inside the new repository"
-msgstr "在新仓库中设置配置信息"
+#: builtin/config.c:154
+msgid "terminate values with NUL byte"
+msgstr "终止值是 NUL 字节"
 
-#: builtin/clone.c:138 builtin/fetch.c:173 builtin/pull.c:229
-#: builtin/push.c:583
-msgid "use IPv4 addresses only"
-msgstr "只使用 IPv4 地址"
+#: builtin/config.c:155
+msgid "show variable names only"
+msgstr "只显示变量名"
 
-#: builtin/clone.c:140 builtin/fetch.c:175 builtin/pull.c:232
-#: builtin/push.c:585
-msgid "use IPv6 addresses only"
-msgstr "只使用 IPv6 地址"
+#: builtin/config.c:156
+msgid "respect include directives on lookup"
+msgstr "查询时参照 include 指令递归查找"
 
-#: builtin/clone.c:278
-msgid ""
-"No directory name could be guessed.\n"
-"Please specify a directory on the command line"
-msgstr ""
-"无法猜到目录名。\n"
-"请在命令行指定一个目录"
+#: builtin/config.c:157
+msgid "show origin of config (file, standard input, blob, command line)"
+msgstr "显示配置的来源（文件、标准输入、数据对象，或命令行）"
 
-#: builtin/clone.c:331
-#, c-format
-msgid "info: Could not add alternate for '%s': %s\n"
-msgstr "info: 不能为 '%s' 添加一个备用：%s\n"
+#: builtin/config.c:158 builtin/env--helper.c:40
+msgid "value"
+msgstr "取值"
 
-#: builtin/clone.c:403
-#, c-format
-msgid "failed to open '%s'"
-msgstr "无法打开 '%s'"
+#: builtin/config.c:158
+msgid "with --get, use default value when missing entry"
+msgstr "使用 --get 参数，当缺少设置时使用默认值"
 
-#: builtin/clone.c:411
-#, c-format
-msgid "%s exists and is not a directory"
-msgstr "%s 存在且不是一个目录"
+#: builtin/config.c:172
+#, c-format
+msgid "wrong number of arguments, should be %d"
+msgstr "错误的参数个数，应该为 %d 个"
 
-#: builtin/clone.c:425
+#: builtin/config.c:174
 #, c-format
-msgid "failed to stat %s\n"
-msgstr "对 %s 调用 stat 失败\n"
+msgid "wrong number of arguments, should be from %d to %d"
+msgstr "错误的参数个数，应该为从 %d 个到 %d 个"
 
-#: builtin/clone.c:447
+#: builtin/config.c:308
 #, c-format
-msgid "failed to create link '%s'"
-msgstr "无法创建链接 '%s'"
+msgid "invalid key pattern: %s"
+msgstr "无效键名模式：%s"
 
-#: builtin/clone.c:451
+#: builtin/config.c:344
 #, c-format
-msgid "failed to copy file to '%s'"
-msgstr "无法拷贝文件至 '%s'"
+msgid "failed to format default config value: %s"
+msgstr "格式化默认配置值失败：%s"
 
-#: builtin/clone.c:477
+#: builtin/config.c:401
 #, c-format
-msgid "done.\n"
-msgstr "完成。\n"
+msgid "cannot parse color '%s'"
+msgstr "无法解析颜色 '%s'"
 
-#: builtin/clone.c:491
-msgid ""
-"Clone succeeded, but checkout failed.\n"
-"You can inspect what was checked out with 'git status'\n"
-"and retry the checkout with 'git checkout -f HEAD'\n"
-msgstr ""
-"克隆成功，但是检出失败。\n"
-"您可以通过 'git status' 检查哪些已被检出，然后使用命令\n"
-"'git checkout -f HEAD' 重试\n"
+#: builtin/config.c:443
+msgid "unable to parse default color value"
+msgstr "无法解析默认颜色值"
 
-#: builtin/clone.c:568
-#, c-format
-msgid "Could not find remote branch %s to clone."
-msgstr "不能发现要克隆的远程分支 %s。"
+#: builtin/config.c:496 builtin/config.c:742
+msgid "not in a git directory"
+msgstr "不在 git 仓库中"
 
-#: builtin/clone.c:663
-msgid "remote did not send all necessary objects"
-msgstr "远程没有发送所有必须的对象"
+#: builtin/config.c:499
+msgid "writing to stdin is not supported"
+msgstr "不支持写到标准输入"
+
+#: builtin/config.c:502
+msgid "writing config blobs is not supported"
+msgstr "不支持写到配置数据对象"
 
-#: builtin/clone.c:679
+#: builtin/config.c:587
 #, c-format
-msgid "unable to update %s"
-msgstr "不能更新 %s"
+msgid ""
+"# This is Git's per-user configuration file.\n"
+"[user]\n"
+"# Please adapt and uncomment the following lines:\n"
+"#\tname = %s\n"
+"#\temail = %s\n"
+msgstr ""
+"# This is Git's per-user configuration file.\n"
+"[user]\n"
+"# Please adapt and uncomment the following lines:\n"
+"#\tname = %s\n"
+"#\temail = %s\n"
 
-#: builtin/clone.c:728
-msgid "remote HEAD refers to nonexistent ref, unable to checkout.\n"
-msgstr "远程 HEAD 指向一个不存在的引用，无法检出。\n"
+#: builtin/config.c:611
+msgid "only one config file at a time"
+msgstr "一次只能有一个配置文件"
 
-#: builtin/clone.c:758
-msgid "unable to checkout working tree"
-msgstr "不能检出工作区"
+#: builtin/config.c:616
+msgid "--local can only be used inside a git repository"
+msgstr "--local 只能在一个仓库内使用"
 
-#: builtin/clone.c:803
-msgid "unable to write parameters to config file"
-msgstr "无法将参数写入配置文件"
+#: builtin/config.c:619
+msgid "--blob can only be used inside a git repository"
+msgstr "--blob 只能在一个仓库内使用"
 
-#: builtin/clone.c:866
-msgid "cannot repack to clean up"
-msgstr "无法执行 repack 来清理"
+#: builtin/config.c:638
+msgid "$HOME not set"
+msgstr "$HOME 未设置"
 
-#: builtin/clone.c:868
-msgid "cannot unlink temporary alternates file"
-msgstr "无法删除临时的 alternates 文件"
+#: builtin/config.c:658
+msgid ""
+"--worktree cannot be used with multiple working trees unless the config\n"
+"extension worktreeConfig is enabled. Please read \"CONFIGURATION FILE\"\n"
+"section in \"git help worktree\" for details"
+msgstr ""
+"不能和多个工作区一起使用 --worktree，除非启用 worktreeConfig 配置扩展。\n"
+"详情请阅读“git help worktree”的“CONFIGURATION FILE”小节"
 
-#: builtin/clone.c:907 builtin/receive-pack.c:1947
-msgid "Too many arguments."
-msgstr "太多参数。"
+#: builtin/config.c:688
+msgid "--get-color and variable type are incoherent"
+msgstr "--get-color 和变量类型不兼容"
 
-#: builtin/clone.c:911
-msgid "You must specify a repository to clone."
-msgstr "您必须指定一个仓库来克隆。"
+#: builtin/config.c:693
+msgid "only one action at a time"
+msgstr "一次只能有一个动作"
 
-#: builtin/clone.c:924
-#, c-format
-msgid "--bare and --origin %s options are incompatible."
-msgstr "--bare 和 --origin %s 选项不兼容。"
+#: builtin/config.c:706
+msgid "--name-only is only applicable to --list or --get-regexp"
+msgstr "--name-only 仅适用于 --list 或 --get-regexp"
 
-#: builtin/clone.c:927
-msgid "--bare and --separate-git-dir are incompatible."
-msgstr "--bare 和 --separate-git-dir 选项不兼容。"
+#: builtin/config.c:712
+msgid ""
+"--show-origin is only applicable to --get, --get-all, --get-regexp, and --"
+"list"
+msgstr "--show-origin 仅适用于 --get、--get-all、--get-regexp 和 --list"
 
-#: builtin/clone.c:940
-#, c-format
-msgid "repository '%s' does not exist"
-msgstr "仓库 '%s' 不存在"
+#: builtin/config.c:718
+msgid "--default is only applicable to --get"
+msgstr "--default 仅适用于 --get"
 
-#: builtin/clone.c:946 builtin/fetch.c:1460
+#: builtin/config.c:731
 #, c-format
-msgid "depth %s is not a positive number"
-msgstr "深度 %s 不是一个正数"
+msgid "unable to read config file '%s'"
+msgstr "无法读取配置文件 '%s'"
 
-#: builtin/clone.c:956
-#, c-format
-msgid "destination path '%s' already exists and is not an empty directory."
-msgstr "目标路径 '%s' 已经存在，并且不是一个空目录。"
+#: builtin/config.c:734
+msgid "error processing config file(s)"
+msgstr "处理配置文件出错"
 
-#: builtin/clone.c:966
-#, c-format
-msgid "working tree '%s' already exists."
-msgstr "工作区 '%s' 已经存在。"
+#: builtin/config.c:744
+msgid "editing stdin is not supported"
+msgstr "不支持编辑标准输入"
 
-#: builtin/clone.c:981 builtin/clone.c:1002 builtin/difftool.c:270
-#: builtin/worktree.c:246 builtin/worktree.c:276
-#, c-format
-msgid "could not create leading directories of '%s'"
-msgstr "不能为 '%s' 创建先导目录"
+#: builtin/config.c:746
+msgid "editing blobs is not supported"
+msgstr "不支持编辑数据对象"
 
-#: builtin/clone.c:986
+#: builtin/config.c:760
 #, c-format
-msgid "could not create work tree dir '%s'"
-msgstr "不能创建工作区目录 '%s'"
+msgid "cannot create configuration file %s"
+msgstr "不能创建配置文件 %s"
 
-#: builtin/clone.c:1006
+#: builtin/config.c:773
 #, c-format
-msgid "Cloning into bare repository '%s'...\n"
-msgstr "克隆到纯仓库 '%s'...\n"
+msgid ""
+"cannot overwrite multiple values with a single value\n"
+"       Use a regexp, --add or --replace-all to change %s."
+msgstr ""
+"无法用一个值覆盖多个值\n"
+"       使用一个正则表达式、--add 或 --replace-all 来修改 %s。"
 
-#: builtin/clone.c:1008
+#: builtin/config.c:847 builtin/config.c:858
 #, c-format
-msgid "Cloning into '%s'...\n"
-msgstr "正克隆到 '%s'...\n"
+msgid "no such section: %s"
+msgstr "无此小节：%s"
 
-#: builtin/clone.c:1032
-msgid ""
-"clone --recursive is not compatible with both --reference and --reference-if-"
-"able"
-msgstr "clone --recursive 和 --reference 以及 --reference-if-able 不兼容"
+#: builtin/count-objects.c:90
+msgid "git count-objects [-v] [-H | --human-readable]"
+msgstr "git count-objects [-v] [-H | --human-readable]"
 
-#: builtin/clone.c:1093
-msgid "--depth is ignored in local clones; use file:// instead."
-msgstr "--depth 在本地克隆时被忽略，请改用 file:// 协议。"
+#: builtin/count-objects.c:100
+msgid "print sizes in human readable format"
+msgstr "以用户可读的格式显示大小"
 
-#: builtin/clone.c:1095
-msgid "--shallow-since is ignored in local clones; use file:// instead."
-msgstr "--shallow-since 在本地克隆时被忽略，请改用 file:// 协议。"
+#: builtin/describe.c:26
+msgid "git describe [<options>] [<commit-ish>...]"
+msgstr "git describe [<选项>] [<提交号>...]"
 
-#: builtin/clone.c:1097
-msgid "--shallow-exclude is ignored in local clones; use file:// instead."
-msgstr "--shallow-exclude 在本地克隆时被忽略，请改用 file:// 协议。"
+#: builtin/describe.c:27
+msgid "git describe [<options>] --dirty"
+msgstr "git describe [<选项>] --dirty"
 
-#: builtin/clone.c:1099
-msgid "--filter is ignored in local clones; use file:// instead."
-msgstr "--filter 在本地克隆时被忽略，请改用 file:// 协议。"
+#: builtin/describe.c:62
+msgid "head"
+msgstr "头"
 
-#: builtin/clone.c:1102
-msgid "source repository is shallow, ignoring --local"
-msgstr "源仓库是浅克隆，忽略 --local"
+#: builtin/describe.c:62
+msgid "lightweight"
+msgstr "轻量级的"
 
-#: builtin/clone.c:1107
-msgid "--local is ignored"
-msgstr "--local 被忽略"
+#: builtin/describe.c:62
+msgid "annotated"
+msgstr "附注的"
 
-#: builtin/clone.c:1169 builtin/clone.c:1177
+#: builtin/describe.c:275
 #, c-format
-msgid "Remote branch %s not found in upstream %s"
-msgstr "远程分支 %s 在上游 %s 未发现"
-
-#: builtin/clone.c:1180
-msgid "You appear to have cloned an empty repository."
-msgstr "您似乎克隆了一个空仓库。"
-
-#: builtin/column.c:10
-msgid "git column [<options>]"
-msgstr "git column [<选项>]"
-
-#: builtin/column.c:27
-msgid "lookup config vars"
-msgstr "查找配置变量"
-
-#: builtin/column.c:28 builtin/column.c:29
-msgid "layout to use"
-msgstr "要使用的布局"
-
-#: builtin/column.c:30
-msgid "Maximum width"
-msgstr "最大宽度"
-
-#: builtin/column.c:31
-msgid "Padding space on left border"
-msgstr "左边框的填充空间"
+msgid "annotated tag %s not available"
+msgstr "附注标签 %s 无效"
 
-#: builtin/column.c:32
-msgid "Padding space on right border"
-msgstr "右边框的填充空间"
+#: builtin/describe.c:279
+#, c-format
+msgid "annotated tag %s has no embedded name"
+msgstr "附注标签 %s 没有嵌入名称"
 
-#: builtin/column.c:33
-msgid "Padding space between columns"
-msgstr "两列之间的填充空间"
+#: builtin/describe.c:281
+#, c-format
+msgid "tag '%s' is really '%s' here"
+msgstr "标签 '%s' 的确是在 '%s'"
 
-#: builtin/column.c:51
-msgid "--command must be the first argument"
-msgstr "--command 必须是第一个参数"
+#: builtin/describe.c:325
+#, c-format
+msgid "no tag exactly matches '%s'"
+msgstr "没有标签准确匹配 '%s'"
 
-#: builtin/commit.c:37
-msgid "git commit [<options>] [--] <pathspec>..."
-msgstr "git commit [<选项>] [--] <路径规格>..."
+#: builtin/describe.c:327
+#, c-format
+msgid "No exact match on refs or tags, searching to describe\n"
+msgstr "没有精确匹配到引用或标签，继续搜索进行描述\n"
 
-#: builtin/commit.c:42
-msgid "git status [<options>] [--] <pathspec>..."
-msgstr "git status [<选项>] [--] <路径规格>..."
+#: builtin/describe.c:381
+#, c-format
+msgid "finished search at %s\n"
+msgstr "完成搜索 %s\n"
 
-#: builtin/commit.c:47
+#: builtin/describe.c:407
+#, c-format
 msgid ""
-"You asked to amend the most recent commit, but doing so would make\n"
-"it empty. You can repeat your command with --allow-empty, or you can\n"
-"remove the commit entirely with \"git reset HEAD^\".\n"
+"No annotated tags can describe '%s'.\n"
+"However, there were unannotated tags: try --tags."
 msgstr ""
-"您要修补最近的提交，但这么做会让它成为空提交。您可以重复您的命令并带上\n"
-"--allow-empty 选项，或者您可用命令 \"git reset HEAD^\" 整个删除该提交。\n"
+"没有附注标签能描述 '%s'。\n"
+"然而，存在未附注标签：尝试 --tags。"
 
-#: builtin/commit.c:52
+#: builtin/describe.c:411
+#, c-format
 msgid ""
-"The previous cherry-pick is now empty, possibly due to conflict resolution.\n"
-"If you wish to commit it anyway, use:\n"
-"\n"
-"    git commit --allow-empty\n"
-"\n"
+"No tags can describe '%s'.\n"
+"Try --always, or create some tags."
 msgstr ""
-"之前的拣选操作现在是一个空提交，可能是由冲突解决导致的。如果您无论如何\n"
-"也要提交，使用命令：\n"
-"\n"
-"    git commit --allow-empty\n"
-"\n"
+"没有标签能描述 '%s'。\n"
+"尝试 --always，或者创建一些标签。"
 
-#: builtin/commit.c:59
-msgid "Otherwise, please use 'git reset'\n"
-msgstr "否则，请使用命令 'git reset'\n"
+#: builtin/describe.c:441
+#, c-format
+msgid "traversed %lu commits\n"
+msgstr "已遍历 %lu 个提交\n"
 
-#: builtin/commit.c:62
+#: builtin/describe.c:444
+#, c-format
 msgid ""
-"If you wish to skip this commit, use:\n"
-"\n"
-"    git reset\n"
-"\n"
-"Then \"git cherry-pick --continue\" will resume cherry-picking\n"
-"the remaining commits.\n"
+"more than %i tags found; listed %i most recent\n"
+"gave up search at %s\n"
 msgstr ""
-"如果您想跳过这个提交，使用命令：\n"
-"\n"
-"    git reset\n"
-"\n"
-"然后执行 \"git cherry-pick --continue\" 继续对其余提交执行拣选\n"
-"操作。\n"
+"发现多于 %i 个标签，列出最近的 %i 个\n"
+"在 %s 放弃搜索\n"
 
-#: builtin/commit.c:293
-msgid "failed to unpack HEAD tree object"
-msgstr "无法解包 HEAD 树对象"
+#: builtin/describe.c:512
+#, c-format
+msgid "describe %s\n"
+msgstr "描述 %s\n"
 
-#: builtin/commit.c:334
-msgid "unable to create temporary index"
-msgstr "不能创建临时索引"
+#: builtin/describe.c:515
+#, c-format
+msgid "Not a valid object name %s"
+msgstr "不是一个有效的对象名 %s"
 
-#: builtin/commit.c:340
-msgid "interactive add failed"
-msgstr "交互式添加失败"
+#: builtin/describe.c:523
+#, c-format
+msgid "%s is neither a commit nor blob"
+msgstr "%s 既不是提交也不是数据对象"
 
-#: builtin/commit.c:353
-msgid "unable to update temporary index"
-msgstr "无法更新临时索引"
+#: builtin/describe.c:537
+msgid "find the tag that comes after the commit"
+msgstr "寻找该提交之后的标签"
 
-#: builtin/commit.c:355
-msgid "Failed to update main cache tree"
-msgstr "不能更新树的主缓存"
+#: builtin/describe.c:538
+msgid "debug search strategy on stderr"
+msgstr "在标准错误上调试搜索策略"
+
+#: builtin/describe.c:539
+msgid "use any ref"
+msgstr "使用任意引用"
+
+#: builtin/describe.c:540
+msgid "use any tag, even unannotated"
+msgstr "使用任意标签，即使未附带注释"
+
+#: builtin/describe.c:541
+msgid "always use long format"
+msgstr "始终使用长提交号格式"
+
+#: builtin/describe.c:542
+msgid "only follow first parent"
+msgstr "只跟随第一个父提交"
+
+#: builtin/describe.c:545
+msgid "only output exact matches"
+msgstr "只输出精确匹配"
+
+#: builtin/describe.c:547
+msgid "consider <n> most recent tags (default: 10)"
+msgstr "考虑最近 <n> 个标签（默认：10）"
+
+#: builtin/describe.c:549
+msgid "only consider tags matching <pattern>"
+msgstr "只考虑匹配 <模式> 的标签"
 
-#: builtin/commit.c:380 builtin/commit.c:403 builtin/commit.c:449
-msgid "unable to write new_index file"
-msgstr "无法写 new_index 文件"
+#: builtin/describe.c:551
+msgid "do not consider tags matching <pattern>"
+msgstr "不考虑匹配 <模式> 的标签"
 
-#: builtin/commit.c:432
-msgid "cannot do a partial commit during a merge."
-msgstr "在合并过程中不能做部分提交。"
+#: builtin/describe.c:553 builtin/name-rev.c:473
+msgid "show abbreviated commit object as fallback"
+msgstr "显示简写的提交号作为后备"
 
-#: builtin/commit.c:434
-msgid "cannot do a partial commit during a cherry-pick."
-msgstr "在拣选过程中不能做部分提交。"
+#: builtin/describe.c:554 builtin/describe.c:557
+msgid "mark"
+msgstr "标记"
 
-#: builtin/commit.c:442
-msgid "cannot read the index"
-msgstr "无法读取索引"
+#: builtin/describe.c:555
+msgid "append <mark> on dirty working tree (default: \"-dirty\")"
+msgstr "对于脏工作区，追加 <标记>（默认：\"-dirty\"）"
 
-#: builtin/commit.c:461
-msgid "unable to write temporary index file"
-msgstr "无法写临时索引文件"
+#: builtin/describe.c:558
+msgid "append <mark> on broken working tree (default: \"-broken\")"
+msgstr "对于损坏的工作区，追加 <标记>（默认：\"-broken\"）"
 
-#: builtin/commit.c:558
-#, c-format
-msgid "commit '%s' lacks author header"
-msgstr "提交 '%s' 缺少作者信息"
+#: builtin/describe.c:576
+msgid "--long is incompatible with --abbrev=0"
+msgstr "--long 与 --abbrev=0 不兼容"
 
-#: builtin/commit.c:560
-#, c-format
-msgid "commit '%s' has malformed author line"
-msgstr "提交 '%s' 有格式错误的作者信息"
+#: builtin/describe.c:605
+msgid "No names found, cannot describe anything."
+msgstr "没有发现名称，无法描述任何东西。"
 
-#: builtin/commit.c:579
-msgid "malformed --author parameter"
-msgstr "格式错误的 --author 参数"
+#: builtin/describe.c:656
+msgid "--dirty is incompatible with commit-ishes"
+msgstr "--dirty 与提交号不兼容"
 
-#: builtin/commit.c:631
-msgid ""
-"unable to select a comment character that is not used\n"
-"in the current commit message"
-msgstr "无法选择一个未被当前提交说明使用的注释字符"
+#: builtin/describe.c:658
+msgid "--broken is incompatible with commit-ishes"
+msgstr "--broken 与提交号不兼容"
 
-#: builtin/commit.c:668 builtin/commit.c:701 builtin/commit.c:1029
+#: builtin/diff.c:84
 #, c-format
-msgid "could not lookup commit %s"
-msgstr "不能查询提交 %s"
+msgid "'%s': not a regular file or symlink"
+msgstr "'%s'：不是一个正规文件或符号链接"
 
-#: builtin/commit.c:680 builtin/shortlog.c:316
+#: builtin/diff.c:235
 #, c-format
-msgid "(reading log message from standard input)\n"
-msgstr "（正从标准输入中读取日志信息）\n"
+msgid "invalid option: %s"
+msgstr "无效选项：%s"
 
-#: builtin/commit.c:682
-msgid "could not read log from standard input"
-msgstr "不能从标准输入中读取日志信息"
+#: builtin/diff.c:350
+msgid "Not a git repository"
+msgstr "不是一个 git 仓库"
 
-#: builtin/commit.c:686
+#: builtin/diff.c:394
 #, c-format
-msgid "could not read log file '%s'"
-msgstr "不能读取日志文件 '%s'"
+msgid "invalid object '%s' given."
+msgstr "提供了无效对象 '%s'。"
 
-#: builtin/commit.c:715 builtin/commit.c:723
-msgid "could not read SQUASH_MSG"
-msgstr "不能读取 SQUASH_MSG"
+#: builtin/diff.c:403
+#, c-format
+msgid "more than two blobs given: '%s'"
+msgstr "提供了超过两个数据对象：'%s'"
 
-#: builtin/commit.c:720
-msgid "could not read MERGE_MSG"
-msgstr "不能读取 MERGE_MSG"
+#: builtin/diff.c:408
+#, c-format
+msgid "unhandled object '%s' given."
+msgstr "无法处理的对象 '%s'。"
 
-#: builtin/commit.c:774
-msgid "could not write commit template"
-msgstr "不能写提交模版"
+#: builtin/difftool.c:30
+msgid "git difftool [<options>] [<commit> [<commit>]] [--] [<path>...]"
+msgstr "git difftool [<选项>] [<提交> [<提交>]] [--] [<路径>...]"
 
-#: builtin/commit.c:792
+#: builtin/difftool.c:260
 #, c-format
-msgid ""
-"\n"
-"It looks like you may be committing a merge.\n"
-"If this is not correct, please remove the file\n"
-"\t%s\n"
-"and try again.\n"
-msgstr ""
-"\n"
-"似乎您正在做一个合并提交。如果不对，请删除文件\n"
-"\t%s\n"
-"然后重试。\n"
+msgid "failed: %d"
+msgstr "失败：%d"
 
-#: builtin/commit.c:797
+#: builtin/difftool.c:302
 #, c-format
-msgid ""
-"\n"
-"It looks like you may be committing a cherry-pick.\n"
-"If this is not correct, please remove the file\n"
-"\t%s\n"
-"and try again.\n"
-msgstr ""
-"\n"
-"似乎您正在做一个拣选提交。如果不对，请删除文件\n"
-"\t%s\n"
-"然后重试。\n"
+msgid "could not read symlink %s"
+msgstr "无法读取符号链接 %s"
 
-#: builtin/commit.c:810
+#: builtin/difftool.c:304
 #, c-format
-msgid ""
-"Please enter the commit message for your changes. Lines starting\n"
-"with '%c' will be ignored, and an empty message aborts the commit.\n"
-msgstr ""
-"请为您的变更输入提交说明。以 '%c' 开始的行将被忽略，而一个空的提交\n"
-"说明将会终止提交。\n"
+msgid "could not read symlink file %s"
+msgstr "无法读取符号链接文件 %s"
 
-#: builtin/commit.c:818
+#: builtin/difftool.c:312
 #, c-format
+msgid "could not read object %s for symlink %s"
+msgstr "无法读取符号链接 %2$s 指向的对象 %1$s"
+
+#: builtin/difftool.c:413
 msgid ""
-"Please enter the commit message for your changes. Lines starting\n"
-"with '%c' will be kept; you may remove them yourself if you want to.\n"
-"An empty message aborts the commit.\n"
+"combined diff formats('-c' and '--cc') are not supported in\n"
+"directory diff mode('-d' and '--dir-diff')."
 msgstr ""
-"请为您的变更输入提交说明。以 '%c' 开始的行将被保留，如果您原意\n"
-"也可以删除它们。一个空的提交说明将会终止提交。\n"
+"不支持在目录比较模式（'-d' 和 '--dir-diff'）中采用组合差异格式（'-c' 和 '--"
+"cc'）。"
 
-#  译者：为保证在输出中对齐，注意调整句中空格！
-#: builtin/commit.c:835
+#: builtin/difftool.c:634
 #, c-format
-msgid "%sAuthor:    %.*s <%.*s>"
-msgstr "%s作者：  %.*s <%.*s>"
+msgid "both files modified: '%s' and '%s'."
+msgstr "两个文件都被修改：'%s' 和 '%s'。"
 
-#  译者：为保证在输出中对齐，注意调整句中空格！
-#: builtin/commit.c:843
-#, c-format
-msgid "%sDate:      %s"
-msgstr "%s日期：  %s"
+#: builtin/difftool.c:636
+msgid "working tree file has been left."
+msgstr "工作区文件被留了下来。"
 
-#  译者：为保证在输出中对齐，注意调整句中空格！
-#: builtin/commit.c:850
+#: builtin/difftool.c:647
 #, c-format
-msgid "%sCommitter: %.*s <%.*s>"
-msgstr "%s提交者：%.*s <%.*s>"
+msgid "temporary files exist in '%s'."
+msgstr "临时文件存在于 '%s'。"
 
-#: builtin/commit.c:867
-msgid "Cannot read index"
-msgstr "无法读取索引"
+#: builtin/difftool.c:648
+msgid "you may want to cleanup or recover these."
+msgstr "您可能想要清理或者恢复它们。"
 
-#: builtin/commit.c:933
-msgid "Error building trees"
-msgstr "无法创建树对象"
+#: builtin/difftool.c:697
+msgid "use `diff.guitool` instead of `diff.tool`"
+msgstr "使用 `diff.guitool` 代替 `diff.tool`"
 
-#: builtin/commit.c:947 builtin/tag.c:257
-#, c-format
-msgid "Please supply the message using either -m or -F option.\n"
-msgstr "请使用 -m 或 -F 选项提供提交说明。\n"
+#: builtin/difftool.c:699
+msgid "perform a full-directory diff"
+msgstr "执行一个全目录差异比较"
 
-#: builtin/commit.c:991
-#, c-format
-msgid "--author '%s' is not 'Name <email>' and matches no existing author"
-msgstr "--author '%s' 不是 '姓名 <邮箱>' 格式，且未能在现有作者中找到匹配"
+#: builtin/difftool.c:701
+msgid "do not prompt before launching a diff tool"
+msgstr "启动差异比较工具之前不提示"
 
-#: builtin/commit.c:1005
-#, c-format
-msgid "Invalid ignored mode '%s'"
-msgstr "无效的忽略模式 '%s'"
+#: builtin/difftool.c:706
+msgid "use symlinks in dir-diff mode"
+msgstr "在 dir-diff 模式中使用符号链接"
 
-#: builtin/commit.c:1019 builtin/commit.c:1269
-#, c-format
-msgid "Invalid untracked files mode '%s'"
-msgstr "无效的未追踪文件参数 '%s'"
+#: builtin/difftool.c:707
+msgid "tool"
+msgstr "工具"
 
-#: builtin/commit.c:1057
-msgid "--long and -z are incompatible"
-msgstr "--long 和 -z 选项不兼容"
+#: builtin/difftool.c:708
+msgid "use the specified diff tool"
+msgstr "使用指定的差异比较工具"
 
-#: builtin/commit.c:1090
-msgid "Using both --reset-author and --author does not make sense"
-msgstr "同时使用 --reset-author 和 --author 没有意义"
+#: builtin/difftool.c:710
+msgid "print a list of diff tools that may be used with `--tool`"
+msgstr "显示可以用在 `--tool` 参数后的差异工具列表"
 
-#: builtin/commit.c:1099
-msgid "You have nothing to amend."
-msgstr "您没有可修补的提交。"
+#: builtin/difftool.c:713
+msgid ""
+"make 'git-difftool' exit when an invoked diff tool returns a non - zero exit "
+"code"
+msgstr "当执行 diff 工具返回非零退出码时，使 'git-difftool' 退出"
 
-#: builtin/commit.c:1102
-msgid "You are in the middle of a merge -- cannot amend."
-msgstr "您正处于一个合并过程中 -- 无法修补提交。"
+#: builtin/difftool.c:716
+msgid "specify a custom command for viewing diffs"
+msgstr "指定一个用于查看差异的自定义命令"
 
-#: builtin/commit.c:1104
-msgid "You are in the middle of a cherry-pick -- cannot amend."
-msgstr "您正处于一个拣选过程中 -- 无法修补提交。"
+#: builtin/difftool.c:717
+msgid "passed to `diff`"
+msgstr "传递给 `diff`"
+
+#: builtin/difftool.c:732
+msgid "difftool requires worktree or --no-index"
+msgstr "difftool 要求工作区或者 --no-index"
+
+#: builtin/difftool.c:739
+msgid "--dir-diff is incompatible with --no-index"
+msgstr "--dir-diff 和 --no-index 不兼容"
+
+#: builtin/difftool.c:742
+msgid "--gui, --tool and --extcmd are mutually exclusive"
+msgstr "--gui、--tool 和 --extcmd 互斥"
 
-#: builtin/commit.c:1107
-msgid "Options --squash and --fixup cannot be used together"
-msgstr "选项 --squash 和 --fixup 不能同时使用"
+#: builtin/difftool.c:750
+msgid "no <tool> given for --tool=<tool>"
+msgstr "没有为 --tool=<工具> 参数提供 <工具>"
 
-#: builtin/commit.c:1117
-msgid "Only one of -c/-C/-F/--fixup can be used."
-msgstr "只能用一个 -c/-C/-F/--fixup 选项。"
+#: builtin/difftool.c:757
+msgid "no <cmd> given for --extcmd=<cmd>"
+msgstr "没有为 --extcmd=<命令> 参数提供 <命令>"
 
-#: builtin/commit.c:1119
-msgid "Option -m cannot be combined with -c/-C/-F."
-msgstr "选项 -m 不能和 -c/-C/-F 同时使用。"
+#: builtin/env--helper.c:6
+msgid "git env--helper --type=[bool|ulong] <options> <env-var>"
+msgstr "git env--helper --type=[bool|ulong] <选项> <环境变量>"
 
-#: builtin/commit.c:1127
-msgid "--reset-author can be used only with -C, -c or --amend."
-msgstr "--reset-author 只能和 -C、-c 或 --amend 同时使用。"
+#: builtin/env--helper.c:37 builtin/hash-object.c:98
+msgid "type"
+msgstr "类型"
 
-#: builtin/commit.c:1144
-msgid "Only one of --include/--only/--all/--interactive/--patch can be used."
-msgstr "只能用一个 --include/--only/--all/--interactive/--patch 选项。"
+#: builtin/env--helper.c:41
+msgid "default for git_env_*(...) to fall back on"
+msgstr "git_env_*(...) 的默认值"
 
-#: builtin/commit.c:1146
-msgid "No paths with --include/--only does not make sense."
-msgstr "参数 --include/--only 不跟路径没有意义。"
+#: builtin/env--helper.c:43
+msgid "be quiet only use git_env_*() value as exit code"
+msgstr "安静模式，只使用 git_env_*() 的值作为退出码"
 
-#: builtin/commit.c:1160 builtin/tag.c:543
+#: builtin/env--helper.c:62
 #, c-format
-msgid "Invalid cleanup mode %s"
-msgstr "无效的清理模式 %s"
+msgid "option `--default' expects a boolean value with `--type=bool`, not `%s`"
+msgstr "选项 `--default' 和 `type=bool` 期望一个布尔值，不是 `%s`"
 
-#: builtin/commit.c:1165
-msgid "Paths with -a does not make sense."
-msgstr "路径和 -a 选项同时使用没有意义。"
+#: builtin/env--helper.c:77
+#, c-format
+msgid ""
+"option `--default' expects an unsigned long value with `--type=ulong`, not `"
+"%s`"
+msgstr "选项 `--default' 和 `type=ulong` 期望一个无符号长整型，不是 `%s`"
 
-#: builtin/commit.c:1303 builtin/commit.c:1480
-msgid "show status concisely"
-msgstr "以简洁的格式显示状态"
+#: builtin/fast-export.c:29
+msgid "git fast-export [rev-list-opts]"
+msgstr "git fast-export [rev-list-opts]"
 
-#: builtin/commit.c:1305 builtin/commit.c:1482
-msgid "show branch information"
-msgstr "显示分支信息"
+#: builtin/fast-export.c:852
+msgid "Error: Cannot export nested tags unless --mark-tags is specified."
+msgstr "错误：除非指定 --mark-tags，否则无法导出嵌套标签。"
 
-#: builtin/commit.c:1307
-msgid "show stash information"
-msgstr "显示贮藏区信息"
+#: builtin/fast-export.c:1152
+msgid "show progress after <n> objects"
+msgstr "在 <n> 个对象之后显示进度"
 
-#: builtin/commit.c:1309 builtin/commit.c:1484
-msgid "compute full ahead/behind values"
-msgstr "计算完整的领先/落后值"
+#: builtin/fast-export.c:1154
+msgid "select handling of signed tags"
+msgstr "选择如何处理签名标签"
 
-#: builtin/commit.c:1311
-msgid "version"
-msgstr "版本"
+#: builtin/fast-export.c:1157
+msgid "select handling of tags that tag filtered objects"
+msgstr "选择当标签指向被过滤对象时该标签的处理方式"
 
-#: builtin/commit.c:1311 builtin/commit.c:1486 builtin/push.c:558
-#: builtin/worktree.c:581
-msgid "machine-readable output"
-msgstr "机器可读的输出"
+#: builtin/fast-export.c:1160
+msgid "select handling of commit messages in an alternate encoding"
+msgstr "选择使用备用编码处理提交说明"
 
-#: builtin/commit.c:1314 builtin/commit.c:1488
-msgid "show status in long format (default)"
-msgstr "以长格式显示状态（默认）"
+#: builtin/fast-export.c:1163
+msgid "Dump marks to this file"
+msgstr "把标记存储到这个文件"
+
+#: builtin/fast-export.c:1165
+msgid "Import marks from this file"
+msgstr "从这个文件导入标记"
+
+#: builtin/fast-export.c:1169
+msgid "Import marks from this file if it exists"
+msgstr "从该文件导入标记（如果存在的话）"
+
+#: builtin/fast-export.c:1171
+msgid "Fake a tagger when tags lack one"
+msgstr "当标签缺少标记者字段时，假装提供一个"
+
+#: builtin/fast-export.c:1173
+msgid "Output full tree for each commit"
+msgstr "每次提交都输出整个树"
+
+#: builtin/fast-export.c:1175
+msgid "Use the done feature to terminate the stream"
+msgstr "使用 done 功能来终止流"
+
+#: builtin/fast-export.c:1176
+msgid "Skip output of blob data"
+msgstr "跳过数据对象的输出"
+
+#: builtin/fast-export.c:1177 builtin/log.c:1705
+msgid "refspec"
+msgstr "引用规格"
+
+#: builtin/fast-export.c:1178
+msgid "Apply refspec to exported refs"
+msgstr "对导出的引用应用引用规格"
+
+#: builtin/fast-export.c:1179
+msgid "anonymize output"
+msgstr "匿名输出"
 
-#: builtin/commit.c:1317 builtin/commit.c:1491
-msgid "terminate entries with NUL"
-msgstr "条目以 NUL 字符结尾"
+#: builtin/fast-export.c:1181
+msgid "Reference parents which are not in fast-export stream by object id"
+msgstr "引用父对象 ID 不在 fast-export 流中"
+
+#: builtin/fast-export.c:1183
+msgid "Show original object ids of blobs/commits"
+msgstr "显示数据对象/提交的原始对象 ID"
+
+#: builtin/fast-export.c:1185
+msgid "Label tags with mark ids"
+msgstr "对带有标记 ID 的标签做标记"
+
+#: builtin/fast-export.c:1220
+msgid "Cannot pass both --import-marks and --import-marks-if-exists"
+msgstr "不能同时传递参数 --import-marks 和 --import-marks-if-exists"
 
-#: builtin/commit.c:1319 builtin/commit.c:1323 builtin/commit.c:1494
-#: builtin/fast-export.c:1001 builtin/fast-export.c:1004 builtin/tag.c:397
-msgid "mode"
-msgstr "模式"
+#: builtin/fetch.c:34
+msgid "git fetch [<options>] [<repository> [<refspec>...]]"
+msgstr "git fetch [<选项>] [<仓库> [<引用规格>...]]"
 
-#: builtin/commit.c:1320 builtin/commit.c:1494
-msgid "show untracked files, optional modes: all, normal, no. (Default: all)"
-msgstr "显示未跟踪的文件，“模式”的可选参数：all、normal、no。（默认：all）"
+#: builtin/fetch.c:35
+msgid "git fetch [<options>] <group>"
+msgstr "git fetch [<选项>] <组>"
 
-#: builtin/commit.c:1324
-msgid ""
-"show ignored files, optional modes: traditional, matching, no. (Default: "
-"traditional)"
-msgstr ""
-"显示已忽略的文件，可选模式：traditional、matching、no。（默认：traditional）"
+#: builtin/fetch.c:36
+msgid "git fetch --multiple [<options>] [(<repository> | <group>)...]"
+msgstr "git fetch --multiple [<选项>] [(<仓库> | <组>)...]"
 
-#: builtin/commit.c:1326 parse-options.h:167
-msgid "when"
-msgstr "何时"
+#: builtin/fetch.c:37
+msgid "git fetch --all [<options>]"
+msgstr "git fetch --all [<选项>]"
 
-#: builtin/commit.c:1327
-msgid ""
-"ignore changes to submodules, optional when: all, dirty, untracked. "
-"(Default: all)"
-msgstr ""
-"忽略子模组的更改，“何时”的可选参数：all、dirty、untracked。（默认：all）"
+#: builtin/fetch.c:116
+msgid "fetch.parallel cannot be negative"
+msgstr "fetch.parallel 不能为负数"
 
-#: builtin/commit.c:1329
-msgid "list untracked files in columns"
-msgstr "以列的方式显示未跟踪的文件"
+#: builtin/fetch.c:139 builtin/pull.c:204
+msgid "fetch from all remotes"
+msgstr "从所有的远程抓取"
 
-#: builtin/commit.c:1330
-msgid "do not detect renames"
-msgstr "不检测重命名"
+#: builtin/fetch.c:141 builtin/pull.c:248
+msgid "set upstream for git pull/fetch"
+msgstr "为 git pull/fetch 设置上游"
 
-#: builtin/commit.c:1332
-msgid "detect renames, optionally set similarity index"
-msgstr "检测重命名，可以设置索引相似度"
+#: builtin/fetch.c:143 builtin/pull.c:207
+msgid "append to .git/FETCH_HEAD instead of overwriting"
+msgstr "追加到 .git/FETCH_HEAD 而不是覆盖它"
 
-#: builtin/commit.c:1352
-msgid "Unsupported combination of ignored and untracked-files arguments"
-msgstr "不支持已忽略和未跟踪文件参数的组合"
+#: builtin/fetch.c:145 builtin/pull.c:210
+msgid "path to upload pack on remote end"
+msgstr "上传包到远程的路径"
 
-#: builtin/commit.c:1450
-msgid "suppress summary after successful commit"
-msgstr "提交成功后不显示概述信息"
+#: builtin/fetch.c:146
+msgid "force overwrite of local reference"
+msgstr "强制覆盖本地引用"
 
-#: builtin/commit.c:1451
-msgid "show diff in commit message template"
-msgstr "在提交说明模板里显示差异"
+#: builtin/fetch.c:148
+msgid "fetch from multiple remotes"
+msgstr "从多个远程抓取"
 
-#: builtin/commit.c:1453
-msgid "Commit message options"
-msgstr "提交说明选项"
+#: builtin/fetch.c:150 builtin/pull.c:214
+msgid "fetch all tags and associated objects"
+msgstr "抓取所有的标签和关联对象"
 
-#: builtin/commit.c:1454 builtin/tag.c:394
-msgid "read message from file"
-msgstr "从文件中读取提交说明"
+#: builtin/fetch.c:152
+msgid "do not fetch all tags (--no-tags)"
+msgstr "不抓取任何标签(--no-tags)"
 
-#: builtin/commit.c:1455
-msgid "author"
-msgstr "作者"
+#: builtin/fetch.c:154
+msgid "number of submodules fetched in parallel"
+msgstr "子模组获取的并发数"
 
-#: builtin/commit.c:1455
-msgid "override author for commit"
-msgstr "提交时覆盖作者"
+#: builtin/fetch.c:156 builtin/pull.c:217
+msgid "prune remote-tracking branches no longer on remote"
+msgstr "清除远程已经不存在的分支的跟踪分支"
 
-#: builtin/commit.c:1456 builtin/gc.c:501
-msgid "date"
-msgstr "日期"
+#: builtin/fetch.c:158
+msgid "prune local tags no longer on remote and clobber changed tags"
+msgstr "清除远程不存在的本地标签，并且替换变更标签"
 
-#: builtin/commit.c:1456
-msgid "override date for commit"
-msgstr "提交时覆盖日期"
+#  译者：可选值，不能翻译
+#: builtin/fetch.c:159 builtin/fetch.c:182 builtin/pull.c:141
+msgid "on-demand"
+msgstr "on-demand"
 
-#: builtin/commit.c:1457 builtin/merge.c:228 builtin/notes.c:402
-#: builtin/notes.c:565 builtin/tag.c:392
-msgid "message"
-msgstr "说明"
+#: builtin/fetch.c:160
+msgid "control recursive fetching of submodules"
+msgstr "控制子模组的递归抓取"
 
-#: builtin/commit.c:1457
-msgid "commit message"
-msgstr "提交说明"
+#: builtin/fetch.c:164 builtin/pull.c:225
+msgid "keep downloaded pack"
+msgstr "保持下载包"
 
-#: builtin/commit.c:1458 builtin/commit.c:1459 builtin/commit.c:1460
-#: builtin/commit.c:1461 parse-options.h:270 ref-filter.h:92
-msgid "commit"
-msgstr "提交"
+#: builtin/fetch.c:166
+msgid "allow updating of HEAD ref"
+msgstr "允许更新 HEAD 引用"
 
-#: builtin/commit.c:1458
-msgid "reuse and edit message from specified commit"
-msgstr "重用并编辑指定提交的提交说明"
+#: builtin/fetch.c:169 builtin/fetch.c:175 builtin/pull.c:228
+msgid "deepen history of shallow clone"
+msgstr "深化浅克隆的历史"
 
-#: builtin/commit.c:1459
-msgid "reuse message from specified commit"
-msgstr "重用指定提交的提交说明"
+#: builtin/fetch.c:171
+msgid "deepen history of shallow repository based on time"
+msgstr "基于时间来深化浅克隆的历史"
 
-#: builtin/commit.c:1460
-msgid "use autosquash formatted message to fixup specified commit"
-msgstr "使用 autosquash 格式的提交说明用以修正指定的提交"
+#: builtin/fetch.c:177 builtin/pull.c:231
+msgid "convert to a complete repository"
+msgstr "转换为一个完整的仓库"
 
-#: builtin/commit.c:1461
-msgid "use autosquash formatted message to squash specified commit"
-msgstr "使用 autosquash 格式的提交说明用以压缩至指定的提交"
+#: builtin/fetch.c:180
+msgid "prepend this to submodule path output"
+msgstr "在子模组路径输出的前面加上此目录"
 
-#: builtin/commit.c:1462
-msgid "the commit is authored by me now (used with -C/-c/--amend)"
-msgstr "现在将该提交的作者改为我（和 -C/-c/--amend 参数共用）"
+#: builtin/fetch.c:183
+msgid ""
+"default for recursive fetching of submodules (lower priority than config "
+"files)"
+msgstr "递归获取子模组的缺省值（比配置文件优先级低）"
 
-#: builtin/commit.c:1463 builtin/log.c:1446 builtin/merge.c:242
-#: builtin/pull.c:154 builtin/revert.c:105
-msgid "add Signed-off-by:"
-msgstr "添加 Signed-off-by: 签名"
+#: builtin/fetch.c:187 builtin/pull.c:234
+msgid "accept refs that update .git/shallow"
+msgstr "接受更新 .git/shallow 的引用"
 
-#: builtin/commit.c:1464
-msgid "use specified template file"
-msgstr "使用指定的模板文件"
+#: builtin/fetch.c:188 builtin/pull.c:236
+msgid "refmap"
+msgstr "引用映射"
 
-#: builtin/commit.c:1465
-msgid "force edit of commit"
-msgstr "强制编辑提交"
+#: builtin/fetch.c:189 builtin/pull.c:237
+msgid "specify fetch refmap"
+msgstr "指定获取操作的引用映射"
 
-#  译者：可选值，不能翻译（或是原文中笔误，应为 mode）
-#: builtin/commit.c:1466
-msgid "default"
-msgstr "default"
+#: builtin/fetch.c:196
+msgid "report that we have only objects reachable from this object"
+msgstr "报告我们只拥有从该对象开始可达的对象"
+
+#: builtin/fetch.c:199
+msgid "run 'gc --auto' after fetching"
+msgstr "获取后执行 'gc --auto'"
+
+#: builtin/fetch.c:201 builtin/pull.c:246
+msgid "check for forced-updates on all updated branches"
+msgstr "在所有更新分支上检查强制更新"
+
+#: builtin/fetch.c:203
+msgid "write the commit-graph after fetching"
+msgstr "抓取后写提交图"
 
-#: builtin/commit.c:1466 builtin/tag.c:398
-msgid "how to strip spaces and #comments from message"
-msgstr "设置如何删除提交说明里的空格和#注释"
+#: builtin/fetch.c:513
+msgid "Couldn't find remote ref HEAD"
+msgstr "无法发现远程 HEAD 引用"
 
-#: builtin/commit.c:1467
-msgid "include status in commit message template"
-msgstr "在提交说明模板里包含状态信息"
+#: builtin/fetch.c:653
+#, c-format
+msgid "configuration fetch.output contains invalid value %s"
+msgstr "配置变量 fetch.output 包含无效值 %s"
 
-#: builtin/commit.c:1469 builtin/merge.c:240 builtin/pull.c:184
-#: builtin/revert.c:113
-msgid "GPG sign commit"
-msgstr "GPG 提交签名"
+#: builtin/fetch.c:751
+#, c-format
+msgid "object %s not found"
+msgstr "对象 %s 未发现"
 
-#: builtin/commit.c:1472
-msgid "Commit contents options"
-msgstr "提交内容选项"
+#: builtin/fetch.c:755
+msgid "[up to date]"
+msgstr "[最新]"
 
-#: builtin/commit.c:1473
-msgid "commit all changed files"
-msgstr "提交所有改动的文件"
+#: builtin/fetch.c:768 builtin/fetch.c:784 builtin/fetch.c:856
+msgid "[rejected]"
+msgstr "[已拒绝]"
 
-#: builtin/commit.c:1474
-msgid "add specified files to index for commit"
-msgstr "添加指定的文件到索引区等待提交"
+#: builtin/fetch.c:769
+msgid "can't fetch in current branch"
+msgstr "当前分支下不能执行获取操作"
 
-#: builtin/commit.c:1475
-msgid "interactively add files"
-msgstr "交互式添加文件"
+#: builtin/fetch.c:779
+msgid "[tag update]"
+msgstr "[标签更新]"
 
-#: builtin/commit.c:1476
-msgid "interactively add changes"
-msgstr "交互式添加变更"
+#: builtin/fetch.c:780 builtin/fetch.c:817 builtin/fetch.c:839
+#: builtin/fetch.c:851
+msgid "unable to update local ref"
+msgstr "不能更新本地引用"
 
-#: builtin/commit.c:1477
-msgid "commit only specified files"
-msgstr "只提交指定的文件"
+#: builtin/fetch.c:784
+msgid "would clobber existing tag"
+msgstr "会破坏现有的标签"
 
-#: builtin/commit.c:1478
-msgid "bypass pre-commit and commit-msg hooks"
-msgstr "绕过 pre-commit 和 commit-msg 钩子"
+#: builtin/fetch.c:806
+msgid "[new tag]"
+msgstr "[新标签]"
 
-#: builtin/commit.c:1479
-msgid "show what would be committed"
-msgstr "显示将要提交的内容"
+#: builtin/fetch.c:809
+msgid "[new branch]"
+msgstr "[新分支]"
 
-#: builtin/commit.c:1492
-msgid "amend previous commit"
-msgstr "修改先前的提交"
+#: builtin/fetch.c:812
+msgid "[new ref]"
+msgstr "[新引用]"
 
-#: builtin/commit.c:1493
-msgid "bypass post-rewrite hook"
-msgstr "绕过 post-rewrite 钩子"
+#: builtin/fetch.c:851
+msgid "forced update"
+msgstr "强制更新"
 
-#: builtin/commit.c:1498
-msgid "ok to record an empty change"
-msgstr "允许一个空提交"
+#: builtin/fetch.c:856
+msgid "non-fast-forward"
+msgstr "非快进"
 
-#: builtin/commit.c:1500
-msgid "ok to record a change with an empty message"
-msgstr "允许空的提交说明"
+#: builtin/fetch.c:877
+msgid ""
+"Fetch normally indicates which branches had a forced update,\n"
+"but that check has been disabled. To re-enable, use '--show-forced-updates'\n"
+"flag or run 'git config fetch.showForcedUpdates true'."
+msgstr ""
+"获取操作通常显示哪些分支发生了强制更新，但该检查已被禁用。\n"
+"要重新启用，请使用 '--show-forced-updates' 选项或运行\n"
+"'git config fetch.showForcedUpdates true'。"
 
-#: builtin/commit.c:1573
+#: builtin/fetch.c:881
 #, c-format
-msgid "Corrupt MERGE_HEAD file (%s)"
-msgstr "损坏的 MERGE_HEAD 文件（%s）"
-
-#: builtin/commit.c:1580
-msgid "could not read MERGE_MODE"
-msgstr "不能读取 MERGE_MODE"
+msgid ""
+"It took %.2f seconds to check forced updates. You can use\n"
+"'--no-show-forced-updates' or run 'git config fetch.showForcedUpdates "
+"false'\n"
+" to avoid this check.\n"
+msgstr ""
+"花了 %.2f 秒来检查强制更新。您可以使用 '--no-show-forced-updates'\n"
+"或运行 'git config fetch.showForcedUpdates false' 以避免此项检查。\n"
 
-#: builtin/commit.c:1599
+#: builtin/fetch.c:911
 #, c-format
-msgid "could not read commit message: %s"
-msgstr "不能读取提交说明：%s"
+msgid "%s did not send all necessary objects\n"
+msgstr "%s 未发送所有必需的对象\n"
 
-#: builtin/commit.c:1610
+#: builtin/fetch.c:932
 #, c-format
-msgid "Aborting commit due to empty commit message.\n"
-msgstr "终止提交因为提交说明为空。\n"
+msgid "reject %s because shallow roots are not allowed to be updated"
+msgstr "拒绝 %s 因为浅克隆不允许被更新"
 
-#: builtin/commit.c:1615
+#: builtin/fetch.c:1017 builtin/fetch.c:1155
 #, c-format
-msgid "Aborting commit; you did not edit the message.\n"
-msgstr "终止提交；您未更改来自模版的提交说明。\n"
+msgid "From %.*s\n"
+msgstr "来自 %.*s\n"
 
-#: builtin/commit.c:1650
+#: builtin/fetch.c:1028
+#, c-format
 msgid ""
-"Repository has been updated, but unable to write\n"
-"new_index file. Check that disk is not full and quota is\n"
-"not exceeded, and then \"git reset HEAD\" to recover."
+"some local refs could not be updated; try running\n"
+" 'git remote prune %s' to remove any old, conflicting branches"
 msgstr ""
-"仓库已更新，但无法写 new_index 文件。检查是否磁盘已满\n"
-"或磁盘配额已耗尽，然后执行 \"git reset HEAD\" 恢复。"
+"一些本地引用不能被更新；尝试运行\n"
+" 'git remote prune %s' 来删除旧的、有冲突的分支"
 
-#: builtin/commit-graph.c:9
-msgid "git commit-graph [--object-dir <objdir>]"
-msgstr "git commit-graph [--object-dir <对象目录>]"
+#  译者：注意保持前导空格
+#: builtin/fetch.c:1125
+#, c-format
+msgid "   (%s will become dangling)"
+msgstr "   （%s 将成为悬空状态）"
 
-#: builtin/commit-graph.c:10 builtin/commit-graph.c:16
-msgid "git commit-graph read [--object-dir <objdir>]"
-msgstr "git commit-graph read [--object-dir <对象目录>]"
+#  译者：注意保持前导空格
+#: builtin/fetch.c:1126
+#, c-format
+msgid "   (%s has become dangling)"
+msgstr "   （%s 已成为悬空状态）"
 
-#: builtin/commit-graph.c:11 builtin/commit-graph.c:21
-msgid ""
-"git commit-graph write [--object-dir <objdir>] [--append] [--stdin-packs|--"
-"stdin-commits]"
-msgstr ""
-"git commit-graph write [--object-dir <对象目录>] [--append] [--stdin-packs|--"
-"stdin-commits]"
+#: builtin/fetch.c:1158
+msgid "[deleted]"
+msgstr "[已删除]"
 
-#: builtin/commit-graph.c:39 builtin/commit-graph.c:92
-#: builtin/commit-graph.c:147 builtin/fetch.c:161 builtin/log.c:1466
-msgid "dir"
-msgstr "目录"
+#: builtin/fetch.c:1159 builtin/remote.c:1035
+msgid "(none)"
+msgstr "（无）"
 
-#: builtin/commit-graph.c:40 builtin/commit-graph.c:93
-#: builtin/commit-graph.c:148
-msgid "The object directory to store the graph"
-msgstr "保存图形的对象目录"
+#: builtin/fetch.c:1182
+#, c-format
+msgid "Refusing to fetch into current branch %s of non-bare repository"
+msgstr "拒绝获取到非纯仓库的当前分支 %s"
 
-#: builtin/commit-graph.c:95
-msgid "scan pack-indexes listed by stdin for commits"
-msgstr "从标准输入中的包索引文件列表中扫描提交"
+#: builtin/fetch.c:1201
+#, c-format
+msgid "Option \"%s\" value \"%s\" is not valid for %s"
+msgstr "选项 \"%s\" 的值 \"%s\" 对于 %s 是无效的"
 
-#: builtin/commit-graph.c:97
-msgid "start walk at commits listed by stdin"
-msgstr "从标准输入中的提交开始扫描"
+#: builtin/fetch.c:1204
+#, c-format
+msgid "Option \"%s\" is ignored for %s\n"
+msgstr "选项 \"%s\" 为 %s 所忽略\n"
 
-#: builtin/commit-graph.c:99
-msgid "include all commits already in the commit-graph file"
-msgstr "包含 commit-graph 文件中已有所有提交"
+#: builtin/fetch.c:1412
+msgid "multiple branches detected, incompatible with --set-upstream"
+msgstr "检测到多分支，和 --set-upstream 不兼容"
 
-#: builtin/commit-graph.c:108
-msgid "cannot use both --stdin-commits and --stdin-packs"
-msgstr "不能同时使用 --stdin-commits 和 --stdin-packs 选项"
+#: builtin/fetch.c:1427
+msgid "not setting upstream for a remote remote-tracking branch"
+msgstr "没有为一个远程跟踪分支设置上游"
 
-#: builtin/config.c:10
-msgid "git config [<options>]"
-msgstr "git config [<选项>]"
+#: builtin/fetch.c:1429
+msgid "not setting upstream for a remote tag"
+msgstr "没有为一个远程标签设置上游"
+
+#: builtin/fetch.c:1431
+msgid "unknown branch type"
+msgstr "未知的分支类型"
+
+#: builtin/fetch.c:1433
+msgid ""
+"no source branch found.\n"
+"you need to specify exactly one branch with the --set-upstream option."
+msgstr ""
+"未发现源分支。\n"
+"您需要使用 --set-upstream 选项指定一个分支。"
 
-#: builtin/config.c:101
+#: builtin/fetch.c:1559 builtin/fetch.c:1622
 #, c-format
-msgid "unrecognized --type argument, %s"
-msgstr "未能识别的 --type 参数，%s"
+msgid "Fetching %s\n"
+msgstr "正在获取 %s\n"
 
-#: builtin/config.c:123
-msgid "Config file location"
-msgstr "配置文件位置"
+#: builtin/fetch.c:1569 builtin/fetch.c:1624 builtin/remote.c:100
+#, c-format
+msgid "Could not fetch %s"
+msgstr "不能获取 %s"
+
+#: builtin/fetch.c:1581
+#, c-format
+msgid "could not fetch '%s' (exit code: %d)\n"
+msgstr "无法获取 '%s'（退出码：%d）\n"
 
-#: builtin/config.c:124
-msgid "use global config file"
-msgstr "使用全局配置文件"
+#: builtin/fetch.c:1684
+msgid ""
+"No remote repository specified.  Please, specify either a URL or a\n"
+"remote name from which new revisions should be fetched."
+msgstr "未指定远程仓库。请通过一个 URL 或远程仓库名指定，用以获取新提交。"
 
-#: builtin/config.c:125
-msgid "use system config file"
-msgstr "使用系统级配置文件"
+#: builtin/fetch.c:1721
+msgid "You need to specify a tag name."
+msgstr "您需要指定一个标签名称。"
 
-#: builtin/config.c:126
-msgid "use repository config file"
-msgstr "使用仓库级配置文件"
+#: builtin/fetch.c:1771
+msgid "Negative depth in --deepen is not supported"
+msgstr "--deepen 不支持负数深度"
 
-#: builtin/config.c:127
-msgid "use given config file"
-msgstr "使用指定的配置文件"
+#: builtin/fetch.c:1773
+msgid "--deepen and --depth are mutually exclusive"
+msgstr "--deepen 和 --depth 是互斥的"
 
-#: builtin/config.c:128
-msgid "blob-id"
-msgstr "数据对象 ID"
+#: builtin/fetch.c:1778
+msgid "--depth and --unshallow cannot be used together"
+msgstr "--depth 和 --unshallow 不能同时使用"
 
-#: builtin/config.c:128
-msgid "read config from given blob object"
-msgstr "从给定的数据对象读取配置"
+#: builtin/fetch.c:1780
+msgid "--unshallow on a complete repository does not make sense"
+msgstr "对于一个完整的仓库，参数 --unshallow 没有意义"
 
-#: builtin/config.c:129
-msgid "Action"
-msgstr "操作"
+#: builtin/fetch.c:1796
+msgid "fetch --all does not take a repository argument"
+msgstr "fetch --all 不能带一个仓库参数"
 
-#: builtin/config.c:130
-msgid "get value: name [value-regex]"
-msgstr "获取值：name [value-regex]"
+#: builtin/fetch.c:1798
+msgid "fetch --all does not make sense with refspecs"
+msgstr "fetch --all 带引用规格没有任何意义"
 
-#: builtin/config.c:131
-msgid "get all values: key [value-regex]"
-msgstr "获得所有的值：key [value-regex]"
+#: builtin/fetch.c:1807
+#, c-format
+msgid "No such remote or remote group: %s"
+msgstr "没有这样的远程或远程组：%s"
 
-#: builtin/config.c:132
-msgid "get values for regexp: name-regex [value-regex]"
-msgstr "根据正则表达式获得值：name-regex [value-regex]"
+#: builtin/fetch.c:1814
+msgid "Fetching a group and specifying refspecs does not make sense"
+msgstr "获取组并指定引用规格没有意义"
 
-#: builtin/config.c:133
-msgid "get value specific for the URL: section[.var] URL"
-msgstr "获得 URL 取值：section[.var] URL"
+#: builtin/fetch.c:1832
+msgid ""
+"--filter can only be used with the remote configured in extensions."
+"partialclone"
+msgstr "只可以将 --filter 用于在 extensions.partialClone 中配置的远程仓库"
 
-#: builtin/config.c:134
-msgid "replace all matching variables: name value [value_regex]"
-msgstr "替换所有匹配的变量：name value [value_regex]"
+#: builtin/fmt-merge-msg.c:18
+msgid ""
+"git fmt-merge-msg [-m <message>] [--log[=<n>] | --no-log] [--file <file>]"
+msgstr "git fmt-merge-msg [-m <说明>] [--log[=<n>] | --no-log] [--file <文件>]"
 
-#: builtin/config.c:135
-msgid "add a new variable: name value"
-msgstr "添加一个新的变量：name value"
+#: builtin/fmt-merge-msg.c:674
+msgid "populate log with at most <n> entries from shortlog"
+msgstr "向提交说明中最多复制指定条目（合并而来的提交）的简短说明"
 
-#: builtin/config.c:136
-msgid "remove a variable: name [value-regex]"
-msgstr "删除一个变量：name [value-regex]"
+#: builtin/fmt-merge-msg.c:677
+msgid "alias for --log (deprecated)"
+msgstr "参数 --log 的别名（已弃用）"
 
-#: builtin/config.c:137
-msgid "remove all matches: name [value-regex]"
-msgstr "删除所有匹配项：name [value-regex]"
+#: builtin/fmt-merge-msg.c:680
+msgid "text"
+msgstr "文本"
 
-#: builtin/config.c:138
-msgid "rename section: old-name new-name"
-msgstr "重命名小节：old-name new-name"
+#: builtin/fmt-merge-msg.c:681
+msgid "use <text> as start of message"
+msgstr "使用 <文本> 作为提交说明的开始"
 
-#: builtin/config.c:139
-msgid "remove a section: name"
-msgstr "删除一个小节：name"
+#: builtin/fmt-merge-msg.c:682
+msgid "file to read from"
+msgstr "从文件中读取"
 
-#: builtin/config.c:140
-msgid "list all"
-msgstr "列出所有"
+#: builtin/for-each-ref.c:10
+msgid "git for-each-ref [<options>] [<pattern>]"
+msgstr "git for-each-ref [<选项>] [<模式>]"
 
-#: builtin/config.c:141
-msgid "open an editor"
-msgstr "打开一个编辑器"
+#: builtin/for-each-ref.c:11
+msgid "git for-each-ref [--points-at <object>]"
+msgstr "git for-each-ref [--points-at <对象>]"
 
-#: builtin/config.c:142
-msgid "find the color configured: slot [default]"
-msgstr "获得配置的颜色：配置 [默认]"
+#: builtin/for-each-ref.c:12
+msgid "git for-each-ref [(--merged | --no-merged) [<commit>]]"
+msgstr "git for-each-ref [(--merged | --no-merged) [<提交>]]"
 
-#: builtin/config.c:143
-msgid "find the color setting: slot [stdout-is-tty]"
-msgstr "获得颜色设置：配置 [stdout-is-tty]"
+#: builtin/for-each-ref.c:13
+msgid "git for-each-ref [--contains [<commit>]] [--no-contains [<commit>]]"
+msgstr "git for-each-ref [--contains [<提交>]] [--no-contains [<提交>]]"
 
-#: builtin/config.c:144
-msgid "Type"
-msgstr "类型"
+#: builtin/for-each-ref.c:28
+msgid "quote placeholders suitably for shells"
+msgstr "引用占位符适用于 shells"
 
-#: builtin/config.c:145
-msgid "value is given this type"
-msgstr "取值为该类型"
+#: builtin/for-each-ref.c:30
+msgid "quote placeholders suitably for perl"
+msgstr "引用占位符适用于 perl"
 
-#: builtin/config.c:146
-msgid "value is \"true\" or \"false\""
-msgstr "值是 \"true\" 或 \"false\""
+#: builtin/for-each-ref.c:32
+msgid "quote placeholders suitably for python"
+msgstr "引用占位符适用于 python"
 
-#: builtin/config.c:147
-msgid "value is decimal number"
-msgstr "值是十进制数"
+#: builtin/for-each-ref.c:34
+msgid "quote placeholders suitably for Tcl"
+msgstr "引用占位符适用于 Tcl"
 
-#: builtin/config.c:148
-msgid "value is --bool or --int"
-msgstr "值是 --bool or --int"
+#: builtin/for-each-ref.c:37
+msgid "show only <n> matched refs"
+msgstr "只显示 <n> 个匹配的引用"
 
-#: builtin/config.c:149
-msgid "value is a path (file or directory name)"
-msgstr "值是一个路径（文件或目录名）"
+#: builtin/for-each-ref.c:39 builtin/tag.c:439
+msgid "respect format colors"
+msgstr "遵照格式中的颜色输出"
 
-#: builtin/config.c:150
-msgid "value is an expiry date"
-msgstr "值是一个到期日期"
+#: builtin/for-each-ref.c:42
+msgid "print only refs which points at the given object"
+msgstr "只打印指向给定对象的引用"
 
-#: builtin/config.c:151
-msgid "Other"
-msgstr "其它"
+#: builtin/for-each-ref.c:44
+msgid "print only refs that are merged"
+msgstr "只打印已经合并的引用"
 
-#: builtin/config.c:152
-msgid "terminate values with NUL byte"
-msgstr "终止值是 NUL 字节"
+#: builtin/for-each-ref.c:45
+msgid "print only refs that are not merged"
+msgstr "只打印没有合并的引用"
 
-#: builtin/config.c:153
-msgid "show variable names only"
-msgstr "只显示变量名"
+#: builtin/for-each-ref.c:46
+msgid "print only refs which contain the commit"
+msgstr "只打印包含该提交的引用"
 
-#: builtin/config.c:154
-msgid "respect include directives on lookup"
-msgstr "查询时参照 include 指令递归查找"
+#: builtin/for-each-ref.c:47
+msgid "print only refs which don't contain the commit"
+msgstr "只打印不包含该提交的引用"
 
-#: builtin/config.c:155
-msgid "show origin of config (file, standard input, blob, command line)"
-msgstr "显示配置的来源（文件、标准输入、数据对象，或命令行）"
+#: builtin/fsck.c:68 builtin/fsck.c:147 builtin/fsck.c:148
+msgid "unknown"
+msgstr "未知"
 
-#: builtin/config.c:156
-msgid "value"
-msgstr "取值"
+#. TRANSLATORS: e.g. error in tree 01bfda: <more explanation>
+#: builtin/fsck.c:100 builtin/fsck.c:120
+#, c-format
+msgid "error in %s %s: %s"
+msgstr "%s %s 错误：%s"
 
-#: builtin/config.c:156
-msgid "with --get, use default value when missing entry"
-msgstr "使用 --get 参数，当缺少设置时使用默认值"
+#. TRANSLATORS: e.g. warning in tree 01bfda: <more explanation>
+#: builtin/fsck.c:114
+#, c-format
+msgid "warning in %s %s: %s"
+msgstr "%s %s 警告：%s"
 
-#: builtin/config.c:332
+#: builtin/fsck.c:143 builtin/fsck.c:146
 #, c-format
-msgid "failed to format default config value: %s"
-msgstr "无法格式化默认配置取值：%s"
+msgid "broken link from %7s %s"
+msgstr "来自 %7s %s 的损坏的链接"
 
-#: builtin/config.c:431
-msgid "unable to parse default color value"
-msgstr "不能解析默认颜色值"
+#: builtin/fsck.c:155
+msgid "wrong object type in link"
+msgstr "链接中错误的对象类型"
 
-#: builtin/config.c:575
+#: builtin/fsck.c:171
 #, c-format
 msgid ""
-"# This is Git's per-user configuration file.\n"
-"[user]\n"
-"# Please adapt and uncomment the following lines:\n"
-"#\tname = %s\n"
-"#\temail = %s\n"
+"broken link from %7s %s\n"
+"              to %7s %s"
 msgstr ""
-"# This is Git's per-user configuration file.\n"
-"[user]\n"
-"# Please adapt and uncomment the following lines:\n"
-"#\tname = %s\n"
-"#\temail = %s\n"
+"损坏的链接来自于 %7s %s\n"
+"              到 %7s %s"
 
-#: builtin/config.c:603
-msgid "--local can only be used inside a git repository"
-msgstr "--local 只能在一个仓库内使用"
+#: builtin/fsck.c:282
+#, c-format
+msgid "missing %s %s"
+msgstr "缺失 %s %s"
 
-#: builtin/config.c:606
-msgid "--blob can only be used inside a git repository"
-msgstr "--blob 只能在一个仓库内使用"
+#: builtin/fsck.c:309
+#, c-format
+msgid "unreachable %s %s"
+msgstr "不可达 %s %s"
 
-#: builtin/config.c:735
+#: builtin/fsck.c:329
 #, c-format
-msgid "cannot create configuration file %s"
-msgstr "不能创建配置文件 %s"
+msgid "dangling %s %s"
+msgstr "悬空 %s %s"
+
+#: builtin/fsck.c:339
+msgid "could not create lost-found"
+msgstr "不能创建 lost-found"
 
-#: builtin/config.c:748
+#: builtin/fsck.c:350
 #, c-format
-msgid ""
-"cannot overwrite multiple values with a single value\n"
-"       Use a regexp, --add or --replace-all to change %s."
-msgstr ""
-"无法用一个值覆盖多个值\n"
-"       使用一个正则表达式、--add 或 --replace-all 来修改 %s。"
+msgid "could not finish '%s'"
+msgstr "不能完成 '%s'"
 
-#: builtin/count-objects.c:90
-msgid "git count-objects [-v] [-H | --human-readable]"
-msgstr "git count-objects [-v] [-H | --human-readable]"
+#: builtin/fsck.c:367
+#, c-format
+msgid "Checking %s"
+msgstr "正在检查 %s"
 
-#: builtin/count-objects.c:100
-msgid "print sizes in human readable format"
-msgstr "以用户可读的格式显示大小"
+#: builtin/fsck.c:405
+#, c-format
+msgid "Checking connectivity (%d objects)"
+msgstr "正在检查连通性（%d 个对象）"
 
-#: builtin/describe.c:22
-msgid "git describe [<options>] [<commit-ish>...]"
-msgstr "git describe [<选项>] [<提交号>...]"
+#: builtin/fsck.c:424
+#, c-format
+msgid "Checking %s %s"
+msgstr "正在检查 %s %s"
 
-#: builtin/describe.c:23
-msgid "git describe [<options>] --dirty"
-msgstr "git describe [<选项>] --dirty"
+#: builtin/fsck.c:429
+msgid "broken links"
+msgstr "损坏的链接"
 
-#: builtin/describe.c:57
-msgid "head"
-msgstr "头"
+#: builtin/fsck.c:438
+#, c-format
+msgid "root %s"
+msgstr "根 %s"
 
-#: builtin/describe.c:57
-msgid "lightweight"
-msgstr "轻量级的"
+#: builtin/fsck.c:446
+#, c-format
+msgid "tagged %s %s (%s) in %s"
+msgstr "标记 %s %s (%s) 于 %s"
 
-#: builtin/describe.c:57
-msgid "annotated"
-msgstr "附注的"
+#: builtin/fsck.c:475
+#, c-format
+msgid "%s: object corrupt or missing"
+msgstr "%s：对象损坏或丢失"
 
-#: builtin/describe.c:267
+#: builtin/fsck.c:500
 #, c-format
-msgid "annotated tag %s not available"
-msgstr "附注标签 %s 无效"
+msgid "%s: invalid reflog entry %s"
+msgstr "%s：无效的引用日志条目 %s"
 
-#: builtin/describe.c:271
+#: builtin/fsck.c:514
 #, c-format
-msgid "annotated tag %s has no embedded name"
-msgstr "附注标签 %s 没有嵌入名称"
+msgid "Checking reflog %s->%s"
+msgstr "正在检查引用日志 %s->%s"
 
-#: builtin/describe.c:273
+#: builtin/fsck.c:548
 #, c-format
-msgid "tag '%s' is really '%s' here"
-msgstr "标签 '%s' 的确是在 '%s'"
+msgid "%s: invalid sha1 pointer %s"
+msgstr "%s：无效的 sha1 指针 %s"
 
-#: builtin/describe.c:317
+#: builtin/fsck.c:555
 #, c-format
-msgid "no tag exactly matches '%s'"
-msgstr "没有标签准确匹配 '%s'"
+msgid "%s: not a commit"
+msgstr "%s：不是一个提交"
 
-#: builtin/describe.c:319
+#: builtin/fsck.c:609
+msgid "notice: No default references"
+msgstr "注意：无默认引用"
+
+#: builtin/fsck.c:624
 #, c-format
-msgid "No exact match on refs or tags, searching to describe\n"
-msgstr "没有精确匹配到引用或标签，继续搜索进行描述\n"
+msgid "%s: object corrupt or missing: %s"
+msgstr "%s：对象损坏或丢失：%s"
 
-#: builtin/describe.c:366
+#: builtin/fsck.c:637
 #, c-format
-msgid "finished search at %s\n"
-msgstr "完成搜索 %s\n"
+msgid "%s: object could not be parsed: %s"
+msgstr "%s：不能解析对象：%s"
 
-#: builtin/describe.c:392
+#: builtin/fsck.c:657
 #, c-format
-msgid ""
-"No annotated tags can describe '%s'.\n"
-"However, there were unannotated tags: try --tags."
-msgstr ""
-"没有附注标签能描述 '%s'。\n"
-"然而，存在未附注标签：尝试 --tags。"
+msgid "bad sha1 file: %s"
+msgstr "坏的 sha1 文件：%s"
+
+#: builtin/fsck.c:672
+msgid "Checking object directory"
+msgstr "正在检查对象目录"
 
-#: builtin/describe.c:396
-#, c-format
-msgid ""
-"No tags can describe '%s'.\n"
-"Try --always, or create some tags."
-msgstr ""
-"没有标签能描述 '%s'。\n"
-"尝试 --always，或者创建一些标签。"
+#: builtin/fsck.c:675
+msgid "Checking object directories"
+msgstr "正在检查对象目录"
 
-#: builtin/describe.c:426
+#: builtin/fsck.c:690
 #, c-format
-msgid "traversed %lu commits\n"
-msgstr "已遍历 %lu 个提交\n"
+msgid "Checking %s link"
+msgstr "正在检查 %s 链接"
 
-#: builtin/describe.c:429
+#: builtin/fsck.c:695 builtin/index-pack.c:842
 #, c-format
-msgid ""
-"more than %i tags found; listed %i most recent\n"
-"gave up search at %s\n"
-msgstr ""
-"发现多于 %i 个标签，列出最近的 %i 个\n"
-"在 %s 放弃搜索\n"
+msgid "invalid %s"
+msgstr "无效的 %s"
 
-#: builtin/describe.c:497
+#: builtin/fsck.c:702
 #, c-format
-msgid "describe %s\n"
-msgstr "描述 %s\n"
+msgid "%s points to something strange (%s)"
+msgstr "%s 指向奇怪的东西（%s）"
 
-#: builtin/describe.c:500 builtin/log.c:502
+#: builtin/fsck.c:708
 #, c-format
-msgid "Not a valid object name %s"
-msgstr "不是一个有效的对象名 %s"
+msgid "%s: detached HEAD points at nothing"
+msgstr "%s：分离头指针的指向不存在"
 
-#: builtin/describe.c:508
+#: builtin/fsck.c:712
 #, c-format
-msgid "%s is neither a commit nor blob"
-msgstr "%s 既不是提交也不是数据对象"
+msgid "notice: %s points to an unborn branch (%s)"
+msgstr "注意：%s 指向一个尚未诞生的分支（%s）"
 
-#: builtin/describe.c:522
-msgid "find the tag that comes after the commit"
-msgstr "寻找该提交之后的标签"
+#: builtin/fsck.c:724
+msgid "Checking cache tree"
+msgstr "正在检查缓存树"
 
-#: builtin/describe.c:523
-msgid "debug search strategy on stderr"
-msgstr "在标准错误上调试搜索策略"
+#: builtin/fsck.c:729
+#, c-format
+msgid "%s: invalid sha1 pointer in cache-tree"
+msgstr "%s：cache-tree 中无效的 sha1 指针"
 
-#: builtin/describe.c:524
-msgid "use any ref"
-msgstr "使用任意引用"
+#: builtin/fsck.c:738
+msgid "non-tree in cache-tree"
+msgstr "cache-tree 中非树对象"
 
-#: builtin/describe.c:525
-msgid "use any tag, even unannotated"
-msgstr "使用任意标签，即使未附带注释"
+#: builtin/fsck.c:769
+msgid "git fsck [<options>] [<object>...]"
+msgstr "git fsck [<选项>] [<对象>...]"
 
-#: builtin/describe.c:526
-msgid "always use long format"
-msgstr "始终使用长提交号格式"
+#: builtin/fsck.c:775
+msgid "show unreachable objects"
+msgstr "显示不可达的对象"
 
-#: builtin/describe.c:527
-msgid "only follow first parent"
-msgstr "只跟随第一个父提交"
+#: builtin/fsck.c:776
+msgid "show dangling objects"
+msgstr "显示悬空的对象"
 
-#: builtin/describe.c:530
-msgid "only output exact matches"
-msgstr "只输出精确匹配"
+#: builtin/fsck.c:777
+msgid "report tags"
+msgstr "报告标签"
 
-#: builtin/describe.c:532
-msgid "consider <n> most recent tags (default: 10)"
-msgstr "考虑最近 <n> 个标签（默认：10）"
+#: builtin/fsck.c:778
+msgid "report root nodes"
+msgstr "报告根节点"
 
-#: builtin/describe.c:534
-msgid "only consider tags matching <pattern>"
-msgstr "只考虑匹配 <模式> 的标签"
+#: builtin/fsck.c:779
+msgid "make index objects head nodes"
+msgstr "将索引亦作为检查的头节点"
 
-#: builtin/describe.c:536
-msgid "do not consider tags matching <pattern>"
-msgstr "不考虑匹配 <模式> 的标签"
+#: builtin/fsck.c:780
+msgid "make reflogs head nodes (default)"
+msgstr "将引用日志作为检查的头节点（默认）"
 
-#: builtin/describe.c:538 builtin/name-rev.c:406
-msgid "show abbreviated commit object as fallback"
-msgstr "显示简写的提交号作为后备"
+#: builtin/fsck.c:781
+msgid "also consider packs and alternate objects"
+msgstr "也考虑包和备用对象"
 
-#: builtin/describe.c:539 builtin/describe.c:542
-msgid "mark"
-msgstr "标记"
+#: builtin/fsck.c:782
+msgid "check only connectivity"
+msgstr "仅检查连通性"
 
-#: builtin/describe.c:540
-msgid "append <mark> on dirty working tree (default: \"-dirty\")"
-msgstr "对于脏工作区，追加 <标记>（默认：\"-dirty\"）"
+#: builtin/fsck.c:783
+msgid "enable more strict checking"
+msgstr "启用更严格的检查"
 
-#: builtin/describe.c:543
-msgid "append <mark> on broken working tree (default: \"-broken\")"
-msgstr "对于损坏的工作区，追加 <标记>（默认：\"-broken\"）"
+#: builtin/fsck.c:785
+msgid "write dangling objects in .git/lost-found"
+msgstr "将悬空对象写入 .git/lost-found 中"
 
-#: builtin/describe.c:561
-msgid "--long is incompatible with --abbrev=0"
-msgstr "--long 与 --abbrev=0 不兼容"
+#: builtin/fsck.c:786 builtin/prune.c:132
+msgid "show progress"
+msgstr "显示进度"
 
-#: builtin/describe.c:590
-msgid "No names found, cannot describe anything."
-msgstr "没有发现名称，无法描述任何东西。"
+#: builtin/fsck.c:787
+msgid "show verbose names for reachable objects"
+msgstr "显示可达对象的详细名称"
 
-#: builtin/describe.c:640
-msgid "--dirty is incompatible with commit-ishes"
-msgstr "--dirty 与提交号不兼容"
+#: builtin/fsck.c:846 builtin/index-pack.c:225
+msgid "Checking objects"
+msgstr "正在检查对象"
 
-#: builtin/describe.c:642
-msgid "--broken is incompatible with commit-ishes"
-msgstr "--broken 与提交号不兼容"
+#: builtin/fsck.c:874
+#, c-format
+msgid "%s: object missing"
+msgstr "%s：对象缺失"
 
-#: builtin/diff.c:83
+#: builtin/fsck.c:885
 #, c-format
-msgid "'%s': not a regular file or symlink"
-msgstr "'%s'：不是一个正规文件或符号链接"
+msgid "invalid parameter: expected sha1, got '%s'"
+msgstr "无效的参数：期望 sha1，得到 '%s'"
+
+#: builtin/gc.c:35
+msgid "git gc [<options>]"
+msgstr "git gc [<选项>]"
 
-#: builtin/diff.c:234
+#: builtin/gc.c:90
 #, c-format
-msgid "invalid option: %s"
-msgstr "无效选项：%s"
+msgid "Failed to fstat %s: %s"
+msgstr "对 %s 调用 fstat 失败：%s"
 
-#: builtin/diff.c:356
-msgid "Not a git repository"
-msgstr "不是一个 git 仓库"
+#: builtin/gc.c:126
+#, c-format
+msgid "failed to parse '%s' value '%s'"
+msgstr "无法解析 '%s' 值 '%s'"
 
-#: builtin/diff.c:399
+#: builtin/gc.c:475 builtin/init-db.c:55
 #, c-format
-msgid "invalid object '%s' given."
-msgstr "提供了无效对象 '%s'。"
+msgid "cannot stat '%s'"
+msgstr "不能对 '%s' 调用 stat"
 
-#: builtin/diff.c:408
+#: builtin/gc.c:484 builtin/notes.c:240 builtin/tag.c:529
 #, c-format
-msgid "more than two blobs given: '%s'"
-msgstr "提供了超过两个数据对象：'%s'"
+msgid "cannot read '%s'"
+msgstr "不能读取 '%s'"
 
-#: builtin/diff.c:413
+#: builtin/gc.c:491
 #, c-format
-msgid "unhandled object '%s' given."
-msgstr "无法处理的对象 '%s'。"
+msgid ""
+"The last gc run reported the following. Please correct the root cause\n"
+"and remove %s.\n"
+"Automatic cleanup will not be performed until the file is removed.\n"
+"\n"
+"%s"
+msgstr ""
+"最后一次 gc 操作报告如下信息。请检查原因并删除 %s。\n"
+"在该文件被删除之前，自动清理将不会执行。\n"
+"\n"
+"%s"
 
-#: builtin/difftool.c:29
-msgid "git difftool [<options>] [<commit> [<commit>]] [--] [<path>...]"
-msgstr "git difftool [<选项>] [<提交> [<提交>]] [--] [<路径>...]"
+#: builtin/gc.c:539
+msgid "prune unreferenced objects"
+msgstr "清除未引用的对象"
+
+#: builtin/gc.c:541
+msgid "be more thorough (increased runtime)"
+msgstr "更彻底（增加运行时间）"
+
+#: builtin/gc.c:542
+msgid "enable auto-gc mode"
+msgstr "启用自动垃圾回收模式"
 
-#: builtin/difftool.c:259
+#: builtin/gc.c:545
+msgid "force running gc even if there may be another gc running"
+msgstr "强制执行 gc 即使另外一个 gc 正在执行"
+
+#: builtin/gc.c:548
+msgid "repack all other packs except the largest pack"
+msgstr "除了最大的包之外，对所有其它包文件重新打包"
+
+#: builtin/gc.c:565
 #, c-format
-msgid "failed: %d"
-msgstr "失败：%d"
+msgid "failed to parse gc.logexpiry value %s"
+msgstr "解析 gc.logexpiry 的值 %s 失败"
 
-#: builtin/difftool.c:301
+#: builtin/gc.c:576
 #, c-format
-msgid "could not read symlink %s"
-msgstr "无法读取符号链接 %s"
+msgid "failed to parse prune expiry value %s"
+msgstr "解析清除期限值 %s 失败"
 
-#: builtin/difftool.c:303
+#: builtin/gc.c:596
 #, c-format
-msgid "could not read symlink file %s"
-msgstr "无法读取符号链接文件 %s"
+msgid "Auto packing the repository in background for optimum performance.\n"
+msgstr "自动在后台执行仓库打包以求最佳性能。\n"
 
-#: builtin/difftool.c:311
+#: builtin/gc.c:598
 #, c-format
-msgid "could not read object %s for symlink %s"
-msgstr "无法读取符号链接 %2$s 指向的对象 %1$s"
+msgid "Auto packing the repository for optimum performance.\n"
+msgstr "自动打包仓库以求最佳性能。\n"
+
+#: builtin/gc.c:599
+#, c-format
+msgid "See \"git help gc\" for manual housekeeping.\n"
+msgstr "手工维护参见 \"git help gc\"。\n"
 
-#: builtin/difftool.c:412
+#: builtin/gc.c:639
+#, c-format
 msgid ""
-"combined diff formats('-c' and '--cc') are not supported in\n"
-"directory diff mode('-d' and '--dir-diff')."
+"gc is already running on machine '%s' pid %<PRIuMAX> (use --force if not)"
 msgstr ""
-"不支持在目录比较模式（'-d' 和 '--dir-diff'）中采用组合差异格式（'-c' 和 '--"
-"cc'）。"
+"已经有一个 gc 正运行在机器 '%s' pid %<PRIuMAX>（如果不是，使用 --force）"
 
-#: builtin/difftool.c:632
+#: builtin/gc.c:694
+msgid ""
+"There are too many unreachable loose objects; run 'git prune' to remove them."
+msgstr "有太多不可达的松散对象，运行 'git prune' 删除它们。"
+
+#: builtin/grep.c:29
+msgid "git grep [<options>] [-e] <pattern> [<rev>...] [[--] <path>...]"
+msgstr "git grep [<选项>] [-e] <模式> [<版本>...] [[--] <路径>...]"
+
+#: builtin/grep.c:225
 #, c-format
-msgid "both files modified: '%s' and '%s'."
-msgstr "两个文件都被修改：'%s' 和 '%s'。"
+msgid "grep: failed to create thread: %s"
+msgstr "grep：无法创建线程：%s"
 
-#: builtin/difftool.c:634
-msgid "working tree file has been left."
-msgstr "工作区文件被留了下来。"
+#: builtin/grep.c:279
+#, c-format
+msgid "invalid number of threads specified (%d) for %s"
+msgstr "为 %2$s 设定的线程数 (%1$d) 无效"
 
-#: builtin/difftool.c:645
+#. TRANSLATORS: %s is the configuration
+#. variable for tweaking threads, currently
+#. grep.threads
+#.
+#: builtin/grep.c:287 builtin/index-pack.c:1534 builtin/index-pack.c:1727
+#: builtin/pack-objects.c:2708
 #, c-format
-msgid "temporary files exist in '%s'."
-msgstr "临时文件存在于 '%s'。"
+msgid "no threads support, ignoring %s"
+msgstr "没有线程支持，忽略 %s"
 
-#: builtin/difftool.c:646
-msgid "you may want to cleanup or recover these."
-msgstr "您可能想要清理或者恢复它们。"
+#: builtin/grep.c:467 builtin/grep.c:592 builtin/grep.c:635
+#, c-format
+msgid "unable to read tree (%s)"
+msgstr "无法读取树（%s）"
 
-#: builtin/difftool.c:695
-msgid "use `diff.guitool` instead of `diff.tool`"
-msgstr "使用 `diff.guitool` 代替 `diff.tool`"
+#: builtin/grep.c:650
+#, c-format
+msgid "unable to grep from object of type %s"
+msgstr "无法抓取来自于 %s 类型的对象"
 
-#: builtin/difftool.c:697
-msgid "perform a full-directory diff"
-msgstr "执行一个全目录差异比较"
+#: builtin/grep.c:716
+#, c-format
+msgid "switch `%c' expects a numerical value"
+msgstr "开关 `%c' 期望一个数字值"
 
-#: builtin/difftool.c:699
-msgid "do not prompt before launching a diff tool"
-msgstr "启动差异比较工具之前不提示"
+#: builtin/grep.c:815
+msgid "search in index instead of in the work tree"
+msgstr "在索引区搜索而不是在工作区"
 
-#: builtin/difftool.c:704
-msgid "use symlinks in dir-diff mode"
-msgstr "在 dir-diff 模式中使用符号链接"
+#: builtin/grep.c:817
+msgid "find in contents not managed by git"
+msgstr "在未被 git 管理的内容中查找"
 
-#: builtin/difftool.c:705
-msgid "<tool>"
-msgstr "<工具>"
+#  译者：中文字符串拼接，可删除前导空格
+#: builtin/grep.c:819
+msgid "search in both tracked and untracked files"
+msgstr "在跟踪和未跟踪的文件中搜索"
 
-#: builtin/difftool.c:706
-msgid "use the specified diff tool"
-msgstr "使用指定的差异比较工具"
+#: builtin/grep.c:821
+msgid "ignore files specified via '.gitignore'"
+msgstr "忽略 '.gitignore' 包含的文件"
+
+#: builtin/grep.c:823
+msgid "recursively search in each submodule"
+msgstr "在每一个子模组中递归搜索"
+
+#: builtin/grep.c:826
+msgid "show non-matching lines"
+msgstr "显示未匹配的行"
+
+#: builtin/grep.c:828
+msgid "case insensitive matching"
+msgstr "不区分大小写匹配"
+
+#: builtin/grep.c:830
+msgid "match patterns only at word boundaries"
+msgstr "只在单词边界匹配模式"
+
+#: builtin/grep.c:832
+msgid "process binary files as text"
+msgstr "把二进制文件当做文本处理"
+
+#: builtin/grep.c:834
+msgid "don't match patterns in binary files"
+msgstr "不在二进制文件中匹配模式"
+
+#: builtin/grep.c:837
+msgid "process binary files with textconv filters"
+msgstr "用 textconv 过滤器处理二进制文件"
+
+#: builtin/grep.c:839
+msgid "search in subdirectories (default)"
+msgstr "在子目录中寻找（默认）"
+
+#: builtin/grep.c:841
+msgid "descend at most <depth> levels"
+msgstr "最多以指定的深度向下寻找"
 
-#: builtin/difftool.c:708
-msgid "print a list of diff tools that may be used with `--tool`"
-msgstr "显示可以用在 `--tool` 参数后的差异工具列表"
+#: builtin/grep.c:845
+msgid "use extended POSIX regular expressions"
+msgstr "使用扩展的 POSIX 正则表达式"
 
-#: builtin/difftool.c:711
-msgid ""
-"make 'git-difftool' exit when an invoked diff tool returns a non - zero exit "
-"code"
-msgstr "当执行 diff 工具返回非零退出码时，使 'git-difftool' 退出"
+#: builtin/grep.c:848
+msgid "use basic POSIX regular expressions (default)"
+msgstr "使用基本的 POSIX 正则表达式（默认）"
 
-#: builtin/difftool.c:713
-msgid "<command>"
-msgstr "<命令>"
+#: builtin/grep.c:851
+msgid "interpret patterns as fixed strings"
+msgstr "把模式解析为固定的字符串"
 
-#: builtin/difftool.c:714
-msgid "specify a custom command for viewing diffs"
-msgstr "指定一个用于查看差异的自定义命令"
+#: builtin/grep.c:854
+msgid "use Perl-compatible regular expressions"
+msgstr "使用 Perl 兼容的正则表达式"
 
-#: builtin/difftool.c:738
-msgid "no <tool> given for --tool=<tool>"
-msgstr "没有为 --tool=<工具> 参数提供 <工具>"
+#: builtin/grep.c:857
+msgid "show line numbers"
+msgstr "显示行号"
 
-#: builtin/difftool.c:745
-msgid "no <cmd> given for --extcmd=<cmd>"
-msgstr "没有为 --extcmd=<命令> 参数提供 <命令>"
+#: builtin/grep.c:858
+msgid "show column number of first match"
+msgstr "显示第一个匹配的列号"
 
-#: builtin/fast-export.c:27
-msgid "git fast-export [rev-list-opts]"
-msgstr "git fast-export [rev-list-opts]"
+#: builtin/grep.c:859
+msgid "don't show filenames"
+msgstr "不显示文件名"
 
-#: builtin/fast-export.c:1000
-msgid "show progress after <n> objects"
-msgstr "在 <n> 个对象之后显示进度"
+#: builtin/grep.c:860
+msgid "show filenames"
+msgstr "显示文件名"
 
-#: builtin/fast-export.c:1002
-msgid "select handling of signed tags"
-msgstr "选择如何处理签名标签"
+#: builtin/grep.c:862
+msgid "show filenames relative to top directory"
+msgstr "显示相对于顶级目录的文件名"
 
-#: builtin/fast-export.c:1005
-msgid "select handling of tags that tag filtered objects"
-msgstr "选择当标签指向被过滤对象时该标签的处理方式"
+#: builtin/grep.c:864
+msgid "show only filenames instead of matching lines"
+msgstr "只显示文件名而不显示匹配的行"
 
-#: builtin/fast-export.c:1008
-msgid "Dump marks to this file"
-msgstr "把标记存储到这个文件"
+#: builtin/grep.c:866
+msgid "synonym for --files-with-matches"
+msgstr "和 --files-with-matches 同义"
 
-#: builtin/fast-export.c:1010
-msgid "Import marks from this file"
-msgstr "从这个文件导入标记"
+#: builtin/grep.c:869
+msgid "show only the names of files without match"
+msgstr "只显示未匹配的文件名"
 
-#: builtin/fast-export.c:1012
-msgid "Fake a tagger when tags lack one"
-msgstr "当标签缺少标记者字段时，假装提供一个"
+#: builtin/grep.c:871
+msgid "print NUL after filenames"
+msgstr "在文件名后输出 NUL 字符"
 
-#: builtin/fast-export.c:1014
-msgid "Output full tree for each commit"
-msgstr "每次提交都输出整个树"
+#: builtin/grep.c:874
+msgid "show only matching parts of a line"
+msgstr "只显示行中的匹配的部分"
 
-#: builtin/fast-export.c:1016
-msgid "Use the done feature to terminate the stream"
-msgstr "使用 done 功能来终止流"
+#: builtin/grep.c:876
+msgid "show the number of matches instead of matching lines"
+msgstr "显示总匹配行数，而不显示匹配的行"
 
-#: builtin/fast-export.c:1017
-msgid "Skip output of blob data"
-msgstr "跳过数据对象的输出"
+#: builtin/grep.c:877
+msgid "highlight matches"
+msgstr "高亮显示匹配项"
 
-#: builtin/fast-export.c:1018
-msgid "refspec"
-msgstr "引用规格"
+#: builtin/grep.c:879
+msgid "print empty line between matches from different files"
+msgstr "在不同文件的匹配项之间打印空行"
 
-#: builtin/fast-export.c:1019
-msgid "Apply refspec to exported refs"
-msgstr "对导出的引用应用引用规格"
+#: builtin/grep.c:881
+msgid "show filename only once above matches from same file"
+msgstr "只在同一文件的匹配项的上面显示一次文件名"
 
-#: builtin/fast-export.c:1020
-msgid "anonymize output"
-msgstr "匿名输出"
+#: builtin/grep.c:884
+msgid "show <n> context lines before and after matches"
+msgstr "显示匹配项前后的 <n> 行上下文"
 
-#: builtin/fetch.c:26
-msgid "git fetch [<options>] [<repository> [<refspec>...]]"
-msgstr "git fetch [<选项>] [<仓库> [<引用规格>...]]"
+#: builtin/grep.c:887
+msgid "show <n> context lines before matches"
+msgstr "显示匹配项前 <n> 行上下文"
 
-#: builtin/fetch.c:27
-msgid "git fetch [<options>] <group>"
-msgstr "git fetch [<选项>] <组>"
+#: builtin/grep.c:889
+msgid "show <n> context lines after matches"
+msgstr "显示匹配项后 <n> 行上下文"
 
-#: builtin/fetch.c:28
-msgid "git fetch --multiple [<options>] [(<repository> | <group>)...]"
-msgstr "git fetch --multiple [<选项>] [(<仓库> | <组>)...]"
+#: builtin/grep.c:891
+msgid "use <n> worker threads"
+msgstr "使用 <n> 个工作线程"
 
-#: builtin/fetch.c:29
-msgid "git fetch --all [<options>]"
-msgstr "git fetch --all [<选项>]"
+#: builtin/grep.c:892
+msgid "shortcut for -C NUM"
+msgstr "快捷键 -C 数字"
 
-#: builtin/fetch.c:123 builtin/pull.c:193
-msgid "fetch from all remotes"
-msgstr "从所有的远程抓取"
+#: builtin/grep.c:895
+msgid "show a line with the function name before matches"
+msgstr "在匹配的前面显示一行函数名"
 
-#: builtin/fetch.c:125 builtin/pull.c:196
-msgid "append to .git/FETCH_HEAD instead of overwriting"
-msgstr "追加到 .git/FETCH_HEAD 而不是覆盖它"
+#: builtin/grep.c:897
+msgid "show the surrounding function"
+msgstr "显示所在函数的前后内容"
 
-#: builtin/fetch.c:127 builtin/pull.c:199
-msgid "path to upload pack on remote end"
-msgstr "上传包到远程的路径"
+#: builtin/grep.c:900
+msgid "read patterns from file"
+msgstr "从文件读取模式"
 
-#: builtin/fetch.c:128 builtin/pull.c:201
-msgid "force overwrite of local branch"
-msgstr "强制覆盖本地分支"
+#: builtin/grep.c:902
+msgid "match <pattern>"
+msgstr "匹配 <模式>"
 
-#: builtin/fetch.c:130
-msgid "fetch from multiple remotes"
-msgstr "从多个远程抓取"
+#: builtin/grep.c:904
+msgid "combine patterns specified with -e"
+msgstr "组合用 -e 参数设定的模式"
 
-#: builtin/fetch.c:132 builtin/pull.c:203
-msgid "fetch all tags and associated objects"
-msgstr "抓取所有的标签和关联对象"
+#: builtin/grep.c:916
+msgid "indicate hit with exit status without output"
+msgstr "不输出，而用退出码标识命中状态"
 
-#: builtin/fetch.c:134
-msgid "do not fetch all tags (--no-tags)"
-msgstr "不抓取任何标签(--no-tags)"
+#: builtin/grep.c:918
+msgid "show only matches from files that match all patterns"
+msgstr "只显示匹配所有模式的文件中的匹配"
 
-#: builtin/fetch.c:136
-msgid "number of submodules fetched in parallel"
-msgstr "子模组获取的并发数"
+#: builtin/grep.c:920
+msgid "show parse tree for grep expression"
+msgstr "显示 grep 表达式的解析树"
 
-#: builtin/fetch.c:138 builtin/pull.c:206
-msgid "prune remote-tracking branches no longer on remote"
-msgstr "清除远程已经不存在的分支的跟踪分支"
+#: builtin/grep.c:924
+msgid "pager"
+msgstr "分页"
 
-#: builtin/fetch.c:140
-msgid "prune local tags no longer on remote and clobber changed tags"
-msgstr "清除远程不存在的本地标签，并且替换变更标签"
+#: builtin/grep.c:924
+msgid "show matching files in the pager"
+msgstr "分页显示匹配的文件"
 
-#  译者：可选值，不能翻译
-#: builtin/fetch.c:141 builtin/fetch.c:164 builtin/pull.c:131
-msgid "on-demand"
-msgstr "on-demand"
+#: builtin/grep.c:928
+msgid "allow calling of grep(1) (ignored by this build)"
+msgstr "允许调用 grep(1)（本次构建忽略）"
 
-#: builtin/fetch.c:142
-msgid "control recursive fetching of submodules"
-msgstr "控制子模组的递归抓取"
+#: builtin/grep.c:992
+msgid "no pattern given"
+msgstr "未提供匹配模式"
 
-#: builtin/fetch.c:146 builtin/pull.c:214
-msgid "keep downloaded pack"
-msgstr "保持下载包"
+#: builtin/grep.c:1028
+msgid "--no-index or --untracked cannot be used with revs"
+msgstr "--no-index 或 --untracked 不能和版本同时使用"
 
-#: builtin/fetch.c:148
-msgid "allow updating of HEAD ref"
-msgstr "允许更新 HEAD 引用"
+#: builtin/grep.c:1036
+#, c-format
+msgid "unable to resolve revision: %s"
+msgstr "不能解析版本：%s"
 
-#: builtin/fetch.c:151 builtin/fetch.c:157 builtin/pull.c:217
-msgid "deepen history of shallow clone"
-msgstr "深化浅克隆的历史"
+#: builtin/grep.c:1067
+msgid "invalid option combination, ignoring --threads"
+msgstr "无效的选项组合，忽略 --threads"
 
-#: builtin/fetch.c:153
-msgid "deepen history of shallow repository based on time"
-msgstr "基于时间来深化浅克隆的历史"
+#: builtin/grep.c:1070 builtin/pack-objects.c:3400
+msgid "no threads support, ignoring --threads"
+msgstr "没有线程支持，忽略 --threads"
 
-#: builtin/fetch.c:159 builtin/pull.c:220
-msgid "convert to a complete repository"
-msgstr "转换为一个完整的仓库"
+#: builtin/grep.c:1073 builtin/index-pack.c:1531 builtin/pack-objects.c:2705
+#, c-format
+msgid "invalid number of threads specified (%d)"
+msgstr "指定的线程数无效（%d）"
 
-#: builtin/fetch.c:162
-msgid "prepend this to submodule path output"
-msgstr "在子模组路径输出的前面加上此目录"
+#: builtin/grep.c:1096
+msgid "--open-files-in-pager only works on the worktree"
+msgstr "--open-files-in-pager 仅用于工作区"
 
-#: builtin/fetch.c:165
+#: builtin/grep.c:1119
+msgid "option not supported with --recurse-submodules"
+msgstr "选项不支持和 --recurse-submodules 共用"
+
+#: builtin/grep.c:1125
+msgid "--cached or --untracked cannot be used with --no-index"
+msgstr "--cached 或 --untracked 不能与 --no-index 同时使用"
+
+#: builtin/grep.c:1131
+msgid "--[no-]exclude-standard cannot be used for tracked contents"
+msgstr "--[no-]exclude-standard 不能用于已跟踪内容"
+
+#: builtin/grep.c:1139
+msgid "both --cached and trees are given"
+msgstr "同时给出了 --cached 和树对象"
+
+#: builtin/hash-object.c:85
 msgid ""
-"default for recursive fetching of submodules (lower priority than config "
-"files)"
-msgstr "递归获取子模组的缺省值（比配置文件优先级低）"
+"git hash-object [-t <type>] [-w] [--path=<file> | --no-filters] [--stdin] "
+"[--] <file>..."
+msgstr ""
+"git hash-object [-t <类型>] [-w] [--path=<文件> | --no-filters] [--stdin] "
+"[--] <文件>..."
 
-#: builtin/fetch.c:169 builtin/pull.c:223
-msgid "accept refs that update .git/shallow"
-msgstr "接受更新 .git/shallow 的引用"
+#: builtin/hash-object.c:86
+msgid "git hash-object  --stdin-paths"
+msgstr "git hash-object  --stdin-paths"
 
-#: builtin/fetch.c:170 builtin/pull.c:225
-msgid "refmap"
-msgstr "引用映射"
+#: builtin/hash-object.c:98
+msgid "object type"
+msgstr "对象类型"
 
-#: builtin/fetch.c:171 builtin/pull.c:226
-msgid "specify fetch refmap"
-msgstr "指定获取操作的引用映射"
+#: builtin/hash-object.c:99
+msgid "write the object into the object database"
+msgstr "将对象写入对象数据库"
 
-#: builtin/fetch.c:172 builtin/ls-remote.c:77 builtin/push.c:582
-#: builtin/send-pack.c:172
-msgid "server-specific"
-msgstr "server-specific"
+#: builtin/hash-object.c:101
+msgid "read the object from stdin"
+msgstr "从标准输入读取对象"
 
-#: builtin/fetch.c:172 builtin/ls-remote.c:77 builtin/push.c:582
-#: builtin/send-pack.c:173
-msgid "option to transmit"
-msgstr "传输选项"
+#: builtin/hash-object.c:103
+msgid "store file as is without filters"
+msgstr "原样存储文件不使用过滤器"
 
-#: builtin/fetch.c:442
-msgid "Couldn't find remote ref HEAD"
-msgstr "无法发现远程 HEAD 引用"
+#: builtin/hash-object.c:104
+msgid ""
+"just hash any random garbage to create corrupt objects for debugging Git"
+msgstr "允许对任意随机垃圾数据做散列来创建损坏的对象以便调试 Git"
 
-#: builtin/fetch.c:560
-#, c-format
-msgid "configuration fetch.output contains invalid value %s"
-msgstr "配置变量 fetch.output 包含无效值 %s"
+#: builtin/hash-object.c:105
+msgid "process file as it were from this path"
+msgstr "处理文件并假设其来自于此路径"
 
-#: builtin/fetch.c:653
-#, c-format
-msgid "object %s not found"
-msgstr "对象 %s 未发现"
+#: builtin/help.c:46
+msgid "print all available commands"
+msgstr "打印所有可用的命令"
 
-#: builtin/fetch.c:657
-msgid "[up to date]"
-msgstr "[最新]"
+#: builtin/help.c:47
+msgid "exclude guides"
+msgstr "排除向导"
 
-#: builtin/fetch.c:670 builtin/fetch.c:750
-msgid "[rejected]"
-msgstr "[已拒绝]"
+#: builtin/help.c:48
+msgid "print list of useful guides"
+msgstr "显示有用的指南列表"
 
-#: builtin/fetch.c:671
-msgid "can't fetch in current branch"
-msgstr "当前分支下不能执行获取操作"
+#: builtin/help.c:49
+msgid "print all configuration variable names"
+msgstr "打印所有配置变量名称"
 
-#: builtin/fetch.c:680
-msgid "[tag update]"
-msgstr "[标签更新]"
+#: builtin/help.c:51
+msgid "show man page"
+msgstr "显示 man 手册"
 
-#: builtin/fetch.c:681 builtin/fetch.c:714 builtin/fetch.c:730
-#: builtin/fetch.c:745
-msgid "unable to update local ref"
-msgstr "不能更新本地引用"
+#: builtin/help.c:52
+msgid "show manual in web browser"
+msgstr "在 web 浏览器中显示手册"
 
-#: builtin/fetch.c:700
-msgid "[new tag]"
-msgstr "[新标签]"
+#: builtin/help.c:54
+msgid "show info page"
+msgstr "显示 info 手册"
 
-#: builtin/fetch.c:703
-msgid "[new branch]"
-msgstr "[新分支]"
+#: builtin/help.c:56
+msgid "print command description"
+msgstr "打印命令描述"
 
-#: builtin/fetch.c:706
-msgid "[new ref]"
-msgstr "[新引用]"
+#: builtin/help.c:61
+msgid "git help [--all] [--guides] [--man | --web | --info] [<command>]"
+msgstr "git help [--all] [--guides] [--man | --web | --info] [<命令>]"
 
-#: builtin/fetch.c:745
-msgid "forced update"
-msgstr "强制更新"
+#: builtin/help.c:77
+#, c-format
+msgid "unrecognized help format '%s'"
+msgstr "未能识别的帮助格式 '%s'"
 
-#: builtin/fetch.c:750
-msgid "non-fast-forward"
-msgstr "非快进"
+#: builtin/help.c:104
+msgid "Failed to start emacsclient."
+msgstr "无法启动 emacsclient。"
 
-#: builtin/fetch.c:795
-#, c-format
-msgid "%s did not send all necessary objects\n"
-msgstr "%s 未发送所有必须的对象\n"
+#: builtin/help.c:117
+msgid "Failed to parse emacsclient version."
+msgstr "无法解析 emacsclient 版本。"
 
-#: builtin/fetch.c:815
+#: builtin/help.c:125
 #, c-format
-msgid "reject %s because shallow roots are not allowed to be updated"
-msgstr "拒绝 %s 因为浅克隆不允许被更新"
+msgid "emacsclient version '%d' too old (< 22)."
+msgstr "emacsclient 版本 '%d' 太老（< 22）。"
 
-#: builtin/fetch.c:903 builtin/fetch.c:999
+#: builtin/help.c:143 builtin/help.c:165 builtin/help.c:175 builtin/help.c:183
 #, c-format
-msgid "From %.*s\n"
-msgstr "来自 %.*s\n"
+msgid "failed to exec '%s'"
+msgstr "执行 '%s' 失败"
 
-#: builtin/fetch.c:914
+#: builtin/help.c:221
 #, c-format
 msgid ""
-"some local refs could not be updated; try running\n"
-" 'git remote prune %s' to remove any old, conflicting branches"
+"'%s': path for unsupported man viewer.\n"
+"Please consider using 'man.<tool>.cmd' instead."
 msgstr ""
-"一些本地引用不能被更新；尝试运行\n"
-" 'git remote prune %s' 来删除旧的、有冲突的分支"
+"'%s'：不支持的 man 手册查看器的路径。\n"
+"请使用 'man.<工具>.cmd'。"
 
-#  译者：注意保持前导空格
-#: builtin/fetch.c:969
+#: builtin/help.c:233
 #, c-format
-msgid "   (%s will become dangling)"
-msgstr "   （%s 将成为摇摆状态）"
+msgid ""
+"'%s': cmd for supported man viewer.\n"
+"Please consider using 'man.<tool>.path' instead."
+msgstr ""
+"'%s': 支持的 man 手册查看器命令。\n"
+"请使用 'man.<工具>.path'。"
 
-#  译者：注意保持前导空格
-#: builtin/fetch.c:970
+#: builtin/help.c:350
 #, c-format
-msgid "   (%s has become dangling)"
-msgstr "   （%s 已成为摇摆状态）"
+msgid "'%s': unknown man viewer."
+msgstr "'%s'：未知的 man 查看器。"
 
-#: builtin/fetch.c:1002
-msgid "[deleted]"
-msgstr "[已删除]"
+#: builtin/help.c:367
+msgid "no man viewer handled the request"
+msgstr "没有 man 查看器处理此请求"
 
-#: builtin/fetch.c:1003 builtin/remote.c:1033
-msgid "(none)"
-msgstr "（无）"
+#: builtin/help.c:375
+msgid "no info viewer handled the request"
+msgstr "没有 info 查看器处理此请求"
 
-#: builtin/fetch.c:1026
+#: builtin/help.c:434 builtin/help.c:445 git.c:336
 #, c-format
-msgid "Refusing to fetch into current branch %s of non-bare repository"
-msgstr "拒绝获取到非纯仓库的当前分支 %s"
+msgid "'%s' is aliased to '%s'"
+msgstr "'%s' 是 '%s' 的别名"
 
-#: builtin/fetch.c:1045
+#: builtin/help.c:448 git.c:365
 #, c-format
-msgid "Option \"%s\" value \"%s\" is not valid for %s"
-msgstr "选项 \"%s\" 的值 \"%s\" 对于 %s 是无效的"
+msgid "bad alias.%s string: %s"
+msgstr "坏的 alias.%s 字符串：%s"
 
-#: builtin/fetch.c:1048
+#: builtin/help.c:477 builtin/help.c:507
 #, c-format
-msgid "Option \"%s\" is ignored for %s\n"
-msgstr "选项 \"%s\" 为 %s 所忽略\n"
+msgid "usage: %s%s"
+msgstr "用法：%s%s"
 
-#: builtin/fetch.c:1287
-#, c-format
-msgid "Fetching %s\n"
-msgstr "正在获取 %s\n"
+#: builtin/help.c:491
+msgid "'git help config' for more information"
+msgstr "'git help config' 获取更多信息"
 
-#: builtin/fetch.c:1289 builtin/remote.c:98
+#: builtin/index-pack.c:185
 #, c-format
-msgid "Could not fetch %s"
-msgstr "不能获取 %s"
-
-#: builtin/fetch.c:1335 builtin/fetch.c:1503
-msgid ""
-"--filter can only be used with the remote configured in core.partialClone"
-msgstr "只可以将 --filter 用于在 core.partialClone 中配置的远程仓库"
-
-#: builtin/fetch.c:1358
-msgid ""
-"No remote repository specified.  Please, specify either a URL or a\n"
-"remote name from which new revisions should be fetched."
-msgstr "未指定远程仓库。请通过一个 URL 或远程仓库名指定，用以获取新提交。"
-
-#: builtin/fetch.c:1395
-msgid "You need to specify a tag name."
-msgstr "您需要指定一个标签名称。"
-
-#: builtin/fetch.c:1444
-msgid "Negative depth in --deepen is not supported"
-msgstr "--deepen 不支持负数深度"
-
-#: builtin/fetch.c:1446
-msgid "--deepen and --depth are mutually exclusive"
-msgstr "--deepen 和 --depth 是互斥的"
-
-#: builtin/fetch.c:1451
-msgid "--depth and --unshallow cannot be used together"
-msgstr "--depth 和 --unshallow 不能同时使用"
-
-#: builtin/fetch.c:1453
-msgid "--unshallow on a complete repository does not make sense"
-msgstr "对于一个完整的仓库，参数 --unshallow 没有意义"
-
-#: builtin/fetch.c:1469
-msgid "fetch --all does not take a repository argument"
-msgstr "fetch --all 不能带一个仓库参数"
-
-#: builtin/fetch.c:1471
-msgid "fetch --all does not make sense with refspecs"
-msgstr "fetch --all 带引用规格没有任何意义"
+msgid "object type mismatch at %s"
+msgstr "%s 的对象类型不匹配"
 
-#: builtin/fetch.c:1480
+#: builtin/index-pack.c:205
 #, c-format
-msgid "No such remote or remote group: %s"
-msgstr "没有这样的远程或远程组：%s"
+msgid "did not receive expected object %s"
+msgstr "未能获取预期的对象 %s"
 
-#: builtin/fetch.c:1487
-msgid "Fetching a group and specifying refspecs does not make sense"
-msgstr "获取组并指定引用规格没有意义"
+#: builtin/index-pack.c:208
+#, c-format
+msgid "object %s: expected type %s, found %s"
+msgstr "对象 %s：应为类型 %s，却是 %s"
 
-#: builtin/fmt-merge-msg.c:15
-msgid ""
-"git fmt-merge-msg [-m <message>] [--log[=<n>] | --no-log] [--file <file>]"
-msgstr "git fmt-merge-msg [-m <说明>] [--log[=<n>] | --no-log] [--file <文件>]"
+#: builtin/index-pack.c:258
+#, c-format
+msgid "cannot fill %d byte"
+msgid_plural "cannot fill %d bytes"
+msgstr[0] "无法填充 %d 字节"
+msgstr[1] "无法填充 %d 字节"
 
-#: builtin/fmt-merge-msg.c:666
-msgid "populate log with at most <n> entries from shortlog"
-msgstr "向提交说明中最多复制指定条目（合并而来的提交）的简短说明"
+#: builtin/index-pack.c:268
+msgid "early EOF"
+msgstr "过早的文件结束符（EOF）"
 
-#: builtin/fmt-merge-msg.c:669
-msgid "alias for --log (deprecated)"
-msgstr "参数 --log 的别名（已弃用）"
+#: builtin/index-pack.c:269
+msgid "read error on input"
+msgstr "输入上的读错误"
 
-#: builtin/fmt-merge-msg.c:672
-msgid "text"
-msgstr "文本"
+#: builtin/index-pack.c:281
+msgid "used more bytes than were available"
+msgstr "用掉了超过可用的字节"
 
-#: builtin/fmt-merge-msg.c:673
-msgid "use <text> as start of message"
-msgstr "使用 <文本> 作为提交说明的开始"
+#: builtin/index-pack.c:288 builtin/pack-objects.c:604
+msgid "pack too large for current definition of off_t"
+msgstr "包太大超过了当前 off_t 的定义"
 
-#: builtin/fmt-merge-msg.c:674
-msgid "file to read from"
-msgstr "从文件中读取"
+#: builtin/index-pack.c:291 builtin/unpack-objects.c:95
+msgid "pack exceeds maximum allowed size"
+msgstr "包超过了最大允许值"
 
-#: builtin/for-each-ref.c:10
-msgid "git for-each-ref [<options>] [<pattern>]"
-msgstr "git for-each-ref [<选项>] [<模式>]"
+#: builtin/index-pack.c:312
+#, c-format
+msgid "cannot open packfile '%s'"
+msgstr "无法打开包文件 '%s'"
 
-#: builtin/for-each-ref.c:11
-msgid "git for-each-ref [--points-at <object>]"
-msgstr "git for-each-ref [--points-at <对象>]"
+#: builtin/index-pack.c:326
+msgid "pack signature mismatch"
+msgstr "包签名不匹配"
 
-#: builtin/for-each-ref.c:12
-msgid "git for-each-ref [(--merged | --no-merged) [<commit>]]"
-msgstr "git for-each-ref [(--merged | --no-merged) [<提交>]]"
+#: builtin/index-pack.c:328
+#, c-format
+msgid "pack version %<PRIu32> unsupported"
+msgstr "不支持包版本 %<PRIu32>"
 
-#: builtin/for-each-ref.c:13
-msgid "git for-each-ref [--contains [<commit>]] [--no-contains [<commit>]]"
-msgstr "git for-each-ref [--contains [<提交>]] [--no-contains [<提交>]]"
+#: builtin/index-pack.c:346
+#, c-format
+msgid "pack has bad object at offset %<PRIuMAX>: %s"
+msgstr "包中有错误的对象位于偏移量 %<PRIuMAX>：%s"
 
-#: builtin/for-each-ref.c:28
-msgid "quote placeholders suitably for shells"
-msgstr "引用占位符适用于 shells"
+#: builtin/index-pack.c:466
+#, c-format
+msgid "inflate returned %d"
+msgstr "解压缩返回 %d"
 
-#: builtin/for-each-ref.c:30
-msgid "quote placeholders suitably for perl"
-msgstr "引用占位符适用于 perl"
+#: builtin/index-pack.c:515
+msgid "offset value overflow for delta base object"
+msgstr "偏移值覆盖了 delta 基准对象"
 
-#: builtin/for-each-ref.c:32
-msgid "quote placeholders suitably for python"
-msgstr "引用占位符适用于 python"
+#: builtin/index-pack.c:523
+msgid "delta base offset is out of bound"
+msgstr "delta 基准偏移越界"
 
-#: builtin/for-each-ref.c:34
-msgid "quote placeholders suitably for Tcl"
-msgstr "引用占位符适用于 Tcl"
+#: builtin/index-pack.c:531
+#, c-format
+msgid "unknown object type %d"
+msgstr "未知对象类型 %d"
 
-#: builtin/for-each-ref.c:37
-msgid "show only <n> matched refs"
-msgstr "只显示 <n> 个匹配的引用"
+#: builtin/index-pack.c:562
+msgid "cannot pread pack file"
+msgstr "无法读取包文件"
 
-#: builtin/for-each-ref.c:39 builtin/tag.c:421
-msgid "respect format colors"
-msgstr "遵照格式中的颜色输出"
+#: builtin/index-pack.c:564
+#, c-format
+msgid "premature end of pack file, %<PRIuMAX> byte missing"
+msgid_plural "premature end of pack file, %<PRIuMAX> bytes missing"
+msgstr[0] "包文件过早结束，缺少 %<PRIuMAX> 字节"
+msgstr[1] "包文件过早结束，缺少 %<PRIuMAX> 字节"
 
-#: builtin/for-each-ref.c:43
-msgid "print only refs which points at the given object"
-msgstr "只打印指向给定对象的引用"
+#: builtin/index-pack.c:590
+msgid "serious inflate inconsistency"
+msgstr "解压缩严重的不一致"
 
-#: builtin/for-each-ref.c:45
-msgid "print only refs that are merged"
-msgstr "只打印已经合并的引用"
+#: builtin/index-pack.c:735 builtin/index-pack.c:741 builtin/index-pack.c:764
+#: builtin/index-pack.c:803 builtin/index-pack.c:812
+#, c-format
+msgid "SHA1 COLLISION FOUND WITH %s !"
+msgstr "发现 %s 出现 SHA1 冲突！"
 
-#: builtin/for-each-ref.c:46
-msgid "print only refs that are not merged"
-msgstr "只打印没有合并的引用"
+#: builtin/index-pack.c:738 builtin/pack-objects.c:157
+#: builtin/pack-objects.c:217 builtin/pack-objects.c:311
+#, c-format
+msgid "unable to read %s"
+msgstr "不能读 %s"
 
-#: builtin/for-each-ref.c:47
-msgid "print only refs which contain the commit"
-msgstr "只打印包含该提交的引用"
+#: builtin/index-pack.c:801
+#, c-format
+msgid "cannot read existing object info %s"
+msgstr "不能读取现存对象信息 %s"
 
-#: builtin/for-each-ref.c:48
-msgid "print only refs which don't contain the commit"
-msgstr "只打印不包含该提交的引用"
+#: builtin/index-pack.c:809
+#, c-format
+msgid "cannot read existing object %s"
+msgstr "不能读取现存对象 %s"
 
-#: builtin/fsck.c:569
-msgid "Checking object directories"
-msgstr "检查对象目录中"
+#: builtin/index-pack.c:823
+#, c-format
+msgid "invalid blob object %s"
+msgstr "无效的数据对象 %s"
 
-#: builtin/fsck.c:661
-msgid "git fsck [<options>] [<object>...]"
-msgstr "git fsck [<选项>] [<对象>...]"
+#: builtin/index-pack.c:826 builtin/index-pack.c:845
+msgid "fsck error in packed object"
+msgstr "对打包对象 fsck 检查出错"
 
-#: builtin/fsck.c:667
-msgid "show unreachable objects"
-msgstr "显示不可达的对象"
+#: builtin/index-pack.c:847
+#, c-format
+msgid "Not all child objects of %s are reachable"
+msgstr "%s 的所有子对象并非都可达"
 
-#: builtin/fsck.c:668
-msgid "show dangling objects"
-msgstr "显示摇摆的对象"
+#: builtin/index-pack.c:919 builtin/index-pack.c:950
+msgid "failed to apply delta"
+msgstr "应用 delta 失败"
 
-#: builtin/fsck.c:669
-msgid "report tags"
-msgstr "报告标签"
+#: builtin/index-pack.c:1118
+msgid "Receiving objects"
+msgstr "接收对象中"
 
-#: builtin/fsck.c:670
-msgid "report root nodes"
-msgstr "报告根节点"
+#: builtin/index-pack.c:1118
+msgid "Indexing objects"
+msgstr "索引对象中"
 
-#: builtin/fsck.c:671
-msgid "make index objects head nodes"
-msgstr "将索引亦作为检查的头节点"
+#: builtin/index-pack.c:1152
+msgid "pack is corrupted (SHA1 mismatch)"
+msgstr "包冲突（SHA1 不匹配）"
 
-#: builtin/fsck.c:672
-msgid "make reflogs head nodes (default)"
-msgstr "将引用日志作为检查的头节点（默认）"
+#: builtin/index-pack.c:1157
+msgid "cannot fstat packfile"
+msgstr "不能对包文件调用 fstat"
 
-#: builtin/fsck.c:673
-msgid "also consider packs and alternate objects"
-msgstr "也考虑包和备用对象"
+#: builtin/index-pack.c:1160
+msgid "pack has junk at the end"
+msgstr "包的结尾有垃圾数据"
 
-#: builtin/fsck.c:674
-msgid "check only connectivity"
-msgstr "仅检查连通性"
+#: builtin/index-pack.c:1172
+msgid "confusion beyond insanity in parse_pack_objects()"
+msgstr "parse_pack_objects() 中遇到不可理喻的问题"
 
-#: builtin/fsck.c:675
-msgid "enable more strict checking"
-msgstr "启用更严格的检查"
+#: builtin/index-pack.c:1195
+msgid "Resolving deltas"
+msgstr "处理 delta 中"
 
-#: builtin/fsck.c:677
-msgid "write dangling objects in .git/lost-found"
-msgstr "将摇摆对象写入 .git/lost-found 中"
+#: builtin/index-pack.c:1205 builtin/pack-objects.c:2481
+#, c-format
+msgid "unable to create thread: %s"
+msgstr "不能创建线程：%s"
 
-#: builtin/fsck.c:678 builtin/prune.c:109
-msgid "show progress"
-msgstr "显示进度"
+#: builtin/index-pack.c:1246
+msgid "confusion beyond insanity"
+msgstr "不可理喻"
 
-#: builtin/fsck.c:679
-msgid "show verbose names for reachable objects"
-msgstr "显示可达对象的详细名称"
+#: builtin/index-pack.c:1252
+#, c-format
+msgid "completed with %d local object"
+msgid_plural "completed with %d local objects"
+msgstr[0] "完成 %d 个本地对象"
+msgstr[1] "完成 %d 个本地对象"
 
-#: builtin/fsck.c:745
-msgid "Checking objects"
-msgstr "检查对象中"
+#: builtin/index-pack.c:1264
+#, c-format
+msgid "Unexpected tail checksum for %s (disk corruption?)"
+msgstr "对 %s 的尾部校验出现意外（磁盘损坏？）"
 
-#: builtin/gc.c:33
-msgid "git gc [<options>]"
-msgstr "git gc [<选项>]"
+#: builtin/index-pack.c:1268
+#, c-format
+msgid "pack has %d unresolved delta"
+msgid_plural "pack has %d unresolved deltas"
+msgstr[0] "包有 %d 个未解决的 delta"
+msgstr[1] "包有 %d 个未解决的 delta"
 
-#: builtin/gc.c:88
+#: builtin/index-pack.c:1292
 #, c-format
-msgid "Failed to fstat %s: %s"
-msgstr "对 %s 调用 fstat 失败：%s"
+msgid "unable to deflate appended object (%d)"
+msgstr "不能压缩附加对象（%d）"
 
-#: builtin/gc.c:452
+#: builtin/index-pack.c:1388
 #, c-format
-msgid "Can't stat %s"
-msgstr "不能对 %s 调用 stat"
+msgid "local object %s is corrupt"
+msgstr "本地对象 %s 已损坏"
 
-#: builtin/gc.c:461
+#: builtin/index-pack.c:1402
 #, c-format
-msgid ""
-"The last gc run reported the following. Please correct the root cause\n"
-"and remove %s.\n"
-"Automatic cleanup will not be performed until the file is removed.\n"
-"\n"
-"%s"
-msgstr ""
-"最后一次 gc 操作报告如下信息。请检查原因并删除 %s。\n"
-"在该文件被删除之前，自动清理将不会执行。\n"
-"\n"
-"%s"
+msgid "packfile name '%s' does not end with '.pack'"
+msgstr "包文件名 '%s' 没有以 '.pack' 结尾"
 
-#: builtin/gc.c:502
-msgid "prune unreferenced objects"
-msgstr "清除未引用的对象"
+#: builtin/index-pack.c:1427
+#, c-format
+msgid "cannot write %s file '%s'"
+msgstr "无法写入 %s 文件 '%s'"
 
-#: builtin/gc.c:504
-msgid "be more thorough (increased runtime)"
-msgstr "更彻底（增加运行时间）"
+#: builtin/index-pack.c:1435
+#, c-format
+msgid "cannot close written %s file '%s'"
+msgstr "无法关闭已写入的 %s 文件 '%s'"
 
-#: builtin/gc.c:505
-msgid "enable auto-gc mode"
-msgstr "启用自动垃圾回收模式"
+#: builtin/index-pack.c:1459
+msgid "error while closing pack file"
+msgstr "关闭包文件时出错"
 
-#: builtin/gc.c:508
-msgid "force running gc even if there may be another gc running"
-msgstr "强制执行 gc 即使另外一个 gc 正在执行"
+#: builtin/index-pack.c:1473
+msgid "cannot store pack file"
+msgstr "无法存储包文件"
 
-#: builtin/gc.c:511
-msgid "repack all other packs except the largest pack"
-msgstr "除了最大的包之外，对所有其它包文件重新打包"
+#: builtin/index-pack.c:1481
+msgid "cannot store index file"
+msgstr "无法存储索引文件"
 
-#: builtin/gc.c:528
+#: builtin/index-pack.c:1525 builtin/pack-objects.c:2716
 #, c-format
-msgid "failed to parse gc.logexpiry value %s"
-msgstr "无法解析 gc.logexpiry 的值 %s"
+msgid "bad pack.indexversion=%<PRIu32>"
+msgstr "坏的 pack.indexversion=%<PRIu32>"
 
-#: builtin/gc.c:539
+#: builtin/index-pack.c:1593
 #, c-format
-msgid "failed to parse prune expiry value %s"
-msgstr "无法解析 gc.logexpiry 的值 %s"
+msgid "Cannot open existing pack file '%s'"
+msgstr "无法打开现存包文件 '%s'"
 
-#: builtin/gc.c:559
+#: builtin/index-pack.c:1595
 #, c-format
-msgid "Auto packing the repository in background for optimum performance.\n"
-msgstr "自动在后台执行仓库打包以求最佳性能。\n"
+msgid "Cannot open existing pack idx file for '%s'"
+msgstr "无法为 %s 打开包索引文件"
 
-#: builtin/gc.c:561
+#: builtin/index-pack.c:1643
 #, c-format
-msgid "Auto packing the repository for optimum performance.\n"
-msgstr "自动打包仓库以求最佳性能。\n"
+msgid "non delta: %d object"
+msgid_plural "non delta: %d objects"
+msgstr[0] "非 delta：%d 个对象"
+msgstr[1] "非 delta：%d 个对象"
 
-#: builtin/gc.c:562
+#: builtin/index-pack.c:1650
 #, c-format
-msgid "See \"git help gc\" for manual housekeeping.\n"
-msgstr "手工维护参见 \"git help gc\"。\n"
+msgid "chain length = %d: %lu object"
+msgid_plural "chain length = %d: %lu objects"
+msgstr[0] "链长 = %d: %lu 对象"
+msgstr[1] "链长 = %d: %lu 对象"
 
-#: builtin/gc.c:598
+#: builtin/index-pack.c:1689
+msgid "Cannot come back to cwd"
+msgstr "无法返回当前工作目录"
+
+#: builtin/index-pack.c:1738 builtin/index-pack.c:1741
+#: builtin/index-pack.c:1757 builtin/index-pack.c:1761
 #, c-format
-msgid ""
-"gc is already running on machine '%s' pid %<PRIuMAX> (use --force if not)"
-msgstr ""
-"已经有一个 gc 正运行在机器 '%s' pid %<PRIuMAX>（如果不是，使用 --force）"
+msgid "bad %s"
+msgstr "错误选项 %s"
 
-#: builtin/gc.c:645
-msgid ""
-"There are too many unreachable loose objects; run 'git prune' to remove them."
-msgstr "有太多不可达的松散对象，运行 'git prune' 删除它们。"
+#: builtin/index-pack.c:1777
+msgid "--fix-thin cannot be used without --stdin"
+msgstr "--fix-thin 不能和 --stdin 同时使用"
 
-#: builtin/grep.c:28
-msgid "git grep [<options>] [-e] <pattern> [<rev>...] [[--] <path>...]"
-msgstr "git grep [<选项>] [-e] <模式> [<版本>...] [[--] <路径>...]"
+#: builtin/index-pack.c:1779
+msgid "--stdin requires a git repository"
+msgstr "--stdin 需要一个 git 仓库"
+
+#: builtin/index-pack.c:1785
+msgid "--verify with no packfile name given"
+msgstr "--verify 没有提供包文件名参数"
+
+#: builtin/index-pack.c:1833 builtin/unpack-objects.c:581
+msgid "fsck error in pack objects"
+msgstr "在打包对象中 fsck 检查出错"
 
-#: builtin/grep.c:226
+#: builtin/init-db.c:61
 #, c-format
-msgid "grep: failed to create thread: %s"
-msgstr "grep：无法创建线程：%s"
+msgid "cannot stat template '%s'"
+msgstr "不能对模版 '%s' 调用 stat"
 
-#: builtin/grep.c:284
+#: builtin/init-db.c:66
 #, c-format
-msgid "invalid number of threads specified (%d) for %s"
-msgstr "为 %2$s 设定的线程数 (%1$d) 无效"
+msgid "cannot opendir '%s'"
+msgstr "不能打开目录 '%s'"
 
-#. TRANSLATORS: %s is the configuration
-#. variable for tweaking threads, currently
-#. grep.threads
-#.
-#: builtin/grep.c:293 builtin/index-pack.c:1535 builtin/index-pack.c:1727
+#: builtin/init-db.c:78
 #, c-format
-msgid "no threads support, ignoring %s"
-msgstr "没有线程支持，忽略 %s"
+msgid "cannot readlink '%s'"
+msgstr "不能读取链接 '%s'"
 
-#: builtin/grep.c:461 builtin/grep.c:582 builtin/grep.c:623
+#: builtin/init-db.c:80
 #, c-format
-msgid "unable to read tree (%s)"
-msgstr "无法读取树（%s）"
+msgid "cannot symlink '%s' '%s'"
+msgstr "不能自 '%s' 到 '%s' 创建符号链接"
 
-#: builtin/grep.c:638
+#: builtin/init-db.c:86
 #, c-format
-msgid "unable to grep from object of type %s"
-msgstr "无法抓取来自于 %s 类型的对象"
+msgid "cannot copy '%s' to '%s'"
+msgstr "不能拷贝 '%s' 至 '%s'"
 
-#: builtin/grep.c:703
+#: builtin/init-db.c:90
 #, c-format
-msgid "switch `%c' expects a numerical value"
-msgstr "开关 `%c' 期望一个数字值"
+msgid "ignoring template %s"
+msgstr "忽略模版 %s"
 
-#: builtin/grep.c:790
-msgid "search in index instead of in the work tree"
-msgstr "在索引区搜索而不是在工作区"
+#: builtin/init-db.c:121
+#, c-format
+msgid "templates not found in %s"
+msgstr "没有在 %s 中找到模版"
 
-#: builtin/grep.c:792
-msgid "find in contents not managed by git"
-msgstr "在未被 git 管理的内容中查找"
+#: builtin/init-db.c:136
+#, c-format
+msgid "not copying templates from '%s': %s"
+msgstr "没有从 '%s' 复制模版：%s"
 
-#  译者：中文字符串拼接，可删除前导空格
-#: builtin/grep.c:794
-msgid "search in both tracked and untracked files"
-msgstr "在跟踪和未跟踪的文件中搜索"
+#: builtin/init-db.c:334
+#, c-format
+msgid "unable to handle file type %d"
+msgstr "不能处理 %d 类型的文件"
 
-#: builtin/grep.c:796
-msgid "ignore files specified via '.gitignore'"
-msgstr "忽略 '.gitignore' 包含的文件"
+#: builtin/init-db.c:337
+#, c-format
+msgid "unable to move %s to %s"
+msgstr "不能移动 %s 至 %s"
 
-#: builtin/grep.c:798
-msgid "recursively search in each submodule"
-msgstr "在每一个子模组中递归搜索"
+#: builtin/init-db.c:354 builtin/init-db.c:357
+#, c-format
+msgid "%s already exists"
+msgstr "%s 已经存在"
 
-#: builtin/grep.c:801
-msgid "show non-matching lines"
-msgstr "显示未匹配的行"
+#: builtin/init-db.c:413
+#, c-format
+msgid "Reinitialized existing shared Git repository in %s%s\n"
+msgstr "重新初始化已存在的共享 Git 仓库于 %s%s\n"
 
-#: builtin/grep.c:803
-msgid "case insensitive matching"
-msgstr "不区分大小写匹配"
+#: builtin/init-db.c:414
+#, c-format
+msgid "Reinitialized existing Git repository in %s%s\n"
+msgstr "重新初始化已存在的 Git 仓库于 %s%s\n"
 
-#: builtin/grep.c:805
-msgid "match patterns only at word boundaries"
-msgstr "只在单词边界匹配模式"
+#: builtin/init-db.c:418
+#, c-format
+msgid "Initialized empty shared Git repository in %s%s\n"
+msgstr "已初始化空的共享 Git 仓库于 %s%s\n"
 
-#: builtin/grep.c:807
-msgid "process binary files as text"
-msgstr "把二进制文件当做文本处理"
+#: builtin/init-db.c:419
+#, c-format
+msgid "Initialized empty Git repository in %s%s\n"
+msgstr "已初始化空的 Git 仓库于 %s%s\n"
 
-#: builtin/grep.c:809
-msgid "don't match patterns in binary files"
-msgstr "不在二进制文件中匹配模式"
+#: builtin/init-db.c:468
+msgid ""
+"git init [-q | --quiet] [--bare] [--template=<template-directory>] [--"
+"shared[=<permissions>]] [<directory>]"
+msgstr ""
+"git init [-q | --quiet] [--bare] [--template=<模板目录>] [--shared[=<权限>]] "
+"[<目录>]"
 
-#: builtin/grep.c:812
-msgid "process binary files with textconv filters"
-msgstr "用 textconv 过滤器处理二进制文件"
+#: builtin/init-db.c:491
+msgid "permissions"
+msgstr "权限"
 
-#: builtin/grep.c:814
-msgid "descend at most <depth> levels"
-msgstr "最多以指定的深度向下寻找"
+#: builtin/init-db.c:492
+msgid "specify that the git repository is to be shared amongst several users"
+msgstr "指定 git 仓库是多个用户之间共享的"
 
-#: builtin/grep.c:818
-msgid "use extended POSIX regular expressions"
-msgstr "使用扩展的 POSIX 正则表达式"
+#: builtin/init-db.c:529 builtin/init-db.c:534
+#, c-format
+msgid "cannot mkdir %s"
+msgstr "不能创建目录 %s"
 
-#: builtin/grep.c:821
-msgid "use basic POSIX regular expressions (default)"
-msgstr "使用基本的 POSIX 正则表达式（默认）"
+#: builtin/init-db.c:538
+#, c-format
+msgid "cannot chdir to %s"
+msgstr "不能切换目录到 %s"
 
-#: builtin/grep.c:824
-msgid "interpret patterns as fixed strings"
-msgstr "把模式解析为固定的字符串"
+#: builtin/init-db.c:559
+#, c-format
+msgid ""
+"%s (or --work-tree=<directory>) not allowed without specifying %s (or --git-"
+"dir=<directory>)"
+msgstr "不允许 %s（或 --work-tree=<目录>）而没有指定 %s（或 --git-dir=<目录>）"
 
-#: builtin/grep.c:827
-msgid "use Perl-compatible regular expressions"
-msgstr "使用 Perl 兼容的正则表达式"
+#: builtin/init-db.c:587
+#, c-format
+msgid "Cannot access work tree '%s'"
+msgstr "不能访问工作区 '%s'"
 
-#: builtin/grep.c:830
-msgid "show line numbers"
-msgstr "显示行号"
+#: builtin/interpret-trailers.c:16
+msgid ""
+"git interpret-trailers [--in-place] [--trim-empty] [(--trailer "
+"<token>[(=|:)<value>])...] [<file>...]"
+msgstr ""
+"git interpret-trailers [--in-place] [--trim-empty] [(--trailer <键>[(=|:)<值"
+">])...] [<文件>...]"
 
-#: builtin/grep.c:831
-msgid "don't show filenames"
-msgstr "不显示文件名"
+#: builtin/interpret-trailers.c:95
+msgid "edit files in place"
+msgstr "在原位编辑文件"
+
+#: builtin/interpret-trailers.c:96
+msgid "trim empty trailers"
+msgstr "删除空的尾部署名"
 
-#: builtin/grep.c:832
-msgid "show filenames"
-msgstr "显示文件名"
+#: builtin/interpret-trailers.c:99
+msgid "where to place the new trailer"
+msgstr "在哪里放置新的尾部署名"
 
-#: builtin/grep.c:834
-msgid "show filenames relative to top directory"
-msgstr "显示相对于顶级目录的文件名"
+#: builtin/interpret-trailers.c:101
+msgid "action if trailer already exists"
+msgstr "当尾部署名已经存在时所采取的动作"
 
-#: builtin/grep.c:836
-msgid "show only filenames instead of matching lines"
-msgstr "只显示文件名而不显示匹配的行"
+#: builtin/interpret-trailers.c:103
+msgid "action if trailer is missing"
+msgstr "当尾部署名缺失时所采取的动作"
 
-#: builtin/grep.c:838
-msgid "synonym for --files-with-matches"
-msgstr "和 --files-with-matches 同义"
+#: builtin/interpret-trailers.c:105
+msgid "output only the trailers"
+msgstr "只输出尾部署名"
 
-#: builtin/grep.c:841
-msgid "show only the names of files without match"
-msgstr "只显示未匹配的文件名"
+#: builtin/interpret-trailers.c:106
+msgid "do not apply config rules"
+msgstr "不要应用配置规则"
 
-#: builtin/grep.c:843
-msgid "print NUL after filenames"
-msgstr "在文件名后输出 NUL 字符"
+#: builtin/interpret-trailers.c:107
+msgid "join whitespace-continued values"
+msgstr "连接空白折行的值"
 
-#: builtin/grep.c:846
-msgid "show the number of matches instead of matching lines"
-msgstr "显示总匹配行数，而不显示匹配的行"
+#: builtin/interpret-trailers.c:108
+msgid "set parsing options"
+msgstr "设置解析选项"
 
-#: builtin/grep.c:847
-msgid "highlight matches"
-msgstr "高亮显示匹配项"
+#: builtin/interpret-trailers.c:110
+msgid "do not treat --- specially"
+msgstr "不要对 --- 特殊处理"
 
-#: builtin/grep.c:849
-msgid "print empty line between matches from different files"
-msgstr "在不同文件的匹配项之间打印空行"
+#: builtin/interpret-trailers.c:111
+msgid "trailer"
+msgstr "尾部署名"
 
-#: builtin/grep.c:851
-msgid "show filename only once above matches from same file"
-msgstr "只在同一文件的匹配项的上面显示一次文件名"
+#: builtin/interpret-trailers.c:112
+msgid "trailer(s) to add"
+msgstr "要添加的尾部署名"
 
-#: builtin/grep.c:854
-msgid "show <n> context lines before and after matches"
-msgstr "显示匹配项前后的 <n> 行上下文"
+#: builtin/interpret-trailers.c:123
+msgid "--trailer with --only-input does not make sense"
+msgstr "--trailer 和 --only-input 同时使用没有意义"
 
-#: builtin/grep.c:857
-msgid "show <n> context lines before matches"
-msgstr "显示匹配项前 <n> 行上下文"
+#: builtin/interpret-trailers.c:133
+msgid "no input file given for in-place editing"
+msgstr "没有给出要原位编辑的文件"
 
-#: builtin/grep.c:859
-msgid "show <n> context lines after matches"
-msgstr "显示匹配项后 <n> 行上下文"
+#: builtin/log.c:56
+msgid "git log [<options>] [<revision-range>] [[--] <path>...]"
+msgstr "git log [<选项>] [<版本范围>] [[--] <路径>...]"
 
-#: builtin/grep.c:861
-msgid "use <n> worker threads"
-msgstr "使用 <n> 个工作线程"
+#: builtin/log.c:57
+msgid "git show [<options>] <object>..."
+msgstr "git show [<选项>] <对象>..."
 
-#: builtin/grep.c:862
-msgid "shortcut for -C NUM"
-msgstr "快捷键 -C 数字"
+#: builtin/log.c:110
+#, c-format
+msgid "invalid --decorate option: %s"
+msgstr "无效的 --decorate 选项：%s"
 
-#: builtin/grep.c:865
-msgid "show a line with the function name before matches"
-msgstr "在匹配的前面显示一行函数名"
+#: builtin/log.c:174
+msgid "show source"
+msgstr "显示源"
 
-#: builtin/grep.c:867
-msgid "show the surrounding function"
-msgstr "显示所在函数的前后内容"
+#: builtin/log.c:175
+msgid "Use mail map file"
+msgstr "使用邮件映射文件"
 
-#: builtin/grep.c:870
-msgid "read patterns from file"
-msgstr "从文件读取模式"
+#: builtin/log.c:177
+msgid "only decorate refs that match <pattern>"
+msgstr "只修饰与 <模式> 匹配的引用"
 
-#: builtin/grep.c:872
-msgid "match <pattern>"
-msgstr "匹配 <模式>"
+#: builtin/log.c:179
+msgid "do not decorate refs that match <pattern>"
+msgstr "不修饰和 <模式> 匹配的引用"
 
-#: builtin/grep.c:874
-msgid "combine patterns specified with -e"
-msgstr "组合用 -e 参数设定的模式"
+#: builtin/log.c:180
+msgid "decorate options"
+msgstr "修饰选项"
 
-#: builtin/grep.c:886
-msgid "indicate hit with exit status without output"
-msgstr "不输出，而用退出码标识命中状态"
+#: builtin/log.c:183
+msgid "Process line range n,m in file, counting from 1"
+msgstr "处理文件中第 n 到 m 之间的行，从 1 开始"
 
-#: builtin/grep.c:888
-msgid "show only matches from files that match all patterns"
-msgstr "只显示匹配所有模式的文件中的匹配"
+#: builtin/log.c:281
+#, c-format
+msgid "Final output: %d %s\n"
+msgstr "最终输出：%d %s\n"
 
-#: builtin/grep.c:890
-msgid "show parse tree for grep expression"
-msgstr "显示 grep 表达式的解析树"
+#: builtin/log.c:535
+#, c-format
+msgid "git show %s: bad file"
+msgstr "git show %s: 损坏的文件"
 
-#: builtin/grep.c:894
-msgid "pager"
-msgstr "分页"
+#: builtin/log.c:550 builtin/log.c:645
+#, c-format
+msgid "could not read object %s"
+msgstr "不能读取对象 %s"
 
-#: builtin/grep.c:894
-msgid "show matching files in the pager"
-msgstr "分页显示匹配的文件"
+#: builtin/log.c:670
+#, c-format
+msgid "unknown type: %d"
+msgstr "未知类型：%d"
 
-#: builtin/grep.c:898
-msgid "allow calling of grep(1) (ignored by this build)"
-msgstr "允许调用 grep(1)（本次构建忽略）"
+#: builtin/log.c:814
+#, c-format
+msgid "%s: invalid cover from description mode"
+msgstr "%s：从描述生成附函的模式无效"
 
-#: builtin/grep.c:962
-msgid "no pattern given."
-msgstr "未提供模式匹配。"
+#: builtin/log.c:821
+msgid "format.headers without value"
+msgstr "format.headers 没有值"
 
-#: builtin/grep.c:994
-msgid "--no-index or --untracked cannot be used with revs"
-msgstr "--no-index 或 --untracked 不能和版本同时使用"
+#: builtin/log.c:936
+msgid "name of output directory is too long"
+msgstr "输出目录名太长"
 
-#: builtin/grep.c:1001
+#: builtin/log.c:952
 #, c-format
-msgid "unable to resolve revision: %s"
-msgstr "不能解析版本：%s"
+msgid "cannot open patch file %s"
+msgstr "无法打开补丁文件 %s"
 
-#: builtin/grep.c:1036 builtin/index-pack.c:1531
+#: builtin/log.c:969
+msgid "need exactly one range"
+msgstr "只需要一个范围"
+
+#: builtin/log.c:979
+msgid "not a range"
+msgstr "不是一个范围"
+
+#: builtin/log.c:1143
+msgid "cover letter needs email format"
+msgstr "附函需要邮件地址格式"
+
+#: builtin/log.c:1149
+msgid "failed to create cover-letter file"
+msgstr "无法创建附函文件"
+
+#: builtin/log.c:1228
 #, c-format
-msgid "invalid number of threads specified (%d)"
-msgstr "指定的线程数无效（%d）"
+msgid "insane in-reply-to: %s"
+msgstr "不正常的 in-reply-to：%s"
 
-#: builtin/grep.c:1041
-msgid "no threads support, ignoring --threads"
-msgstr "没有线程支持，忽略 --threads"
+#: builtin/log.c:1255
+msgid "git format-patch [<options>] [<since> | <revision-range>]"
+msgstr "git format-patch [<选项>] [<从> | <版本范围>]"
 
-#: builtin/grep.c:1065
-msgid "--open-files-in-pager only works on the worktree"
-msgstr "--open-files-in-pager 仅用于工作区"
+#: builtin/log.c:1313
+msgid "two output directories?"
+msgstr "两个输出目录？"
+
+#: builtin/log.c:1424 builtin/log.c:2197 builtin/log.c:2199 builtin/log.c:2211
+#, c-format
+msgid "unknown commit %s"
+msgstr "未知提交 %s"
+
+#: builtin/log.c:1434 builtin/replace.c:58 builtin/replace.c:207
+#: builtin/replace.c:210
+#, c-format
+msgid "failed to resolve '%s' as a valid ref"
+msgstr "无法将 '%s' 解析为一个有效引用"
 
-#: builtin/grep.c:1088
-msgid "option not supported with --recurse-submodules."
-msgstr "选项不支持和 --recurse-submodules 共用。"
-
-#: builtin/grep.c:1094
-msgid "--cached or --untracked cannot be used with --no-index."
-msgstr "--cached 或 --untracked 不能与 --no-index 同时使用。"
-
-#: builtin/grep.c:1100
-msgid "--[no-]exclude-standard cannot be used for tracked contents."
-msgstr "--[no-]exclude-standard 不能用于已跟踪内容。"
-
-#: builtin/grep.c:1108
-msgid "both --cached and trees are given."
-msgstr "同时给出了 --cached 和树对象。"
+#: builtin/log.c:1439
+msgid "could not find exact merge base"
+msgstr "不能找到准确的合并基线"
 
-#: builtin/hash-object.c:83
+#: builtin/log.c:1443
 msgid ""
-"git hash-object [-t <type>] [-w] [--path=<file> | --no-filters] [--stdin] "
-"[--] <file>..."
+"failed to get upstream, if you want to record base commit automatically,\n"
+"please use git branch --set-upstream-to to track a remote branch.\n"
+"Or you could specify base commit by --base=<base-commit-id> manually"
 msgstr ""
-"git hash-object [-t <类型>] [-w] [--path=<文件> | --no-filters] [--stdin] "
-"[--] <文件>..."
+"无法得到上游地址，如果你想自动记录基线提交，请使用命令\n"
+"git branch --set-upstream-to 来跟踪一个远程分支。或者你可以通过\n"
+"参数 --base=<基线提交> 手动指定一个基线提交"
 
-#: builtin/hash-object.c:84
-msgid "git hash-object  --stdin-paths"
-msgstr "git hash-object  --stdin-paths"
+#: builtin/log.c:1463
+msgid "failed to find exact merge base"
+msgstr "无法找到准确的合并基线"
 
-#: builtin/hash-object.c:96
-msgid "type"
-msgstr "类型"
+#: builtin/log.c:1474
+msgid "base commit should be the ancestor of revision list"
+msgstr "基线提交应该是版本列表的祖先"
 
-#: builtin/hash-object.c:96
-msgid "object type"
-msgstr "对象类型"
+#: builtin/log.c:1478
+msgid "base commit shouldn't be in revision list"
+msgstr "基线提交不应该出现在版本列表中"
 
-#: builtin/hash-object.c:97
-msgid "write the object into the object database"
-msgstr "将对象写入对象数据库"
+#: builtin/log.c:1531
+msgid "cannot get patch id"
+msgstr "无法得到补丁 id"
 
-#: builtin/hash-object.c:99
-msgid "read the object from stdin"
-msgstr "从标准输入读取对象"
+#: builtin/log.c:1583
+msgid "failed to infer range-diff ranges"
+msgstr "无法推断 range-diff 范围"
 
-#: builtin/hash-object.c:101
-msgid "store file as is without filters"
-msgstr "原样存储文件不使用过滤器"
+#: builtin/log.c:1629
+msgid "use [PATCH n/m] even with a single patch"
+msgstr "使用 [PATCH n/m]，即使只有一个补丁"
 
-#: builtin/hash-object.c:102
-msgid ""
-"just hash any random garbage to create corrupt objects for debugging Git"
-msgstr "允许对任意随机垃圾数据做散列来创建损坏的对象以便调试 Git"
+#: builtin/log.c:1632
+msgid "use [PATCH] even with multiple patches"
+msgstr "使用 [PATCH]，即使有多个补丁"
 
-#: builtin/hash-object.c:103
-msgid "process file as it were from this path"
-msgstr "处理文件并假设其来自于此路径"
+#: builtin/log.c:1636
+msgid "print patches to standard out"
+msgstr "打印补丁到标准输出"
 
-#: builtin/help.c:45
-msgid "print all available commands"
-msgstr "打印所有可用的命令"
+#: builtin/log.c:1638
+msgid "generate a cover letter"
+msgstr "生成一封附函"
 
-#: builtin/help.c:46
-msgid "exclude guides"
-msgstr "排除向导"
+#: builtin/log.c:1640
+msgid "use simple number sequence for output file names"
+msgstr "使用简单的数字序列作为输出文件名"
 
-#: builtin/help.c:47
-msgid "print list of useful guides"
-msgstr "显示有用的指南列表"
+#: builtin/log.c:1641
+msgid "sfx"
+msgstr "后缀"
 
-#: builtin/help.c:48
-msgid "show man page"
-msgstr "显示 man 手册"
+#: builtin/log.c:1642
+msgid "use <sfx> instead of '.patch'"
+msgstr "使用 <后缀> 代替 '.patch'"
 
-#: builtin/help.c:49
-msgid "show manual in web browser"
-msgstr "在 web 浏览器中显示手册"
+#: builtin/log.c:1644
+msgid "start numbering patches at <n> instead of 1"
+msgstr "补丁以 <n> 开始编号，而不是1"
 
-#: builtin/help.c:51
-msgid "show info page"
-msgstr "显示 info 手册"
+#: builtin/log.c:1646
+msgid "mark the series as Nth re-roll"
+msgstr "标记补丁系列是第几次重制"
 
-#: builtin/help.c:53
-msgid "print command description"
-msgstr "打印命令描述"
+#: builtin/log.c:1648
+msgid "Use [RFC PATCH] instead of [PATCH]"
+msgstr "使用 [RFC PATCH] 代替 [PATCH]"
 
-#: builtin/help.c:58
-msgid "git help [--all] [--guides] [--man | --web | --info] [<command>]"
-msgstr "git help [--all] [--guides] [--man | --web | --info] [<命令>]"
+#: builtin/log.c:1651
+msgid "cover-from-description-mode"
+msgstr "从分支描述获取附函的模式"
+
+#: builtin/log.c:1652
+msgid "generate parts of a cover letter based on a branch's description"
+msgstr "基于一个分支描述生成部分附函"
 
-#: builtin/help.c:70
-#, c-format
-msgid "unrecognized help format '%s'"
-msgstr "未能识别的帮助格式 '%s'"
+#: builtin/log.c:1654
+msgid "Use [<prefix>] instead of [PATCH]"
+msgstr "使用 [<前缀>] 代替 [PATCH]"
 
-#: builtin/help.c:97
-msgid "Failed to start emacsclient."
-msgstr "无法启动 emacsclient。"
+#: builtin/log.c:1657
+msgid "store resulting files in <dir>"
+msgstr "把结果文件存储在 <目录>"
 
-#: builtin/help.c:110
-msgid "Failed to parse emacsclient version."
-msgstr "无法解析 emacsclient 版本。"
+#: builtin/log.c:1660
+msgid "don't strip/add [PATCH]"
+msgstr "不删除/添加 [PATCH]"
 
-#: builtin/help.c:118
-#, c-format
-msgid "emacsclient version '%d' too old (< 22)."
-msgstr "emacsclient 版本 '%d' 太老（< 22）。"
+#: builtin/log.c:1663
+msgid "don't output binary diffs"
+msgstr "不输出二进制差异"
 
-#: builtin/help.c:136 builtin/help.c:158 builtin/help.c:168 builtin/help.c:176
-#, c-format
-msgid "failed to exec '%s'"
-msgstr "无法执行 '%s'"
+#: builtin/log.c:1665
+msgid "output all-zero hash in From header"
+msgstr "在 From 头信息中输出全为零的哈希值"
+
+#: builtin/log.c:1667
+msgid "don't include a patch matching a commit upstream"
+msgstr "不包含已在上游提交中的补丁"
+
+#: builtin/log.c:1669
+msgid "show patch format instead of default (patch + stat)"
+msgstr "显示纯补丁格式而非默认的（补丁+状态）"
+
+#: builtin/log.c:1671
+msgid "Messaging"
+msgstr "邮件发送"
+
+#: builtin/log.c:1672
+msgid "header"
+msgstr "header"
 
-#: builtin/help.c:214
-#, c-format
-msgid ""
-"'%s': path for unsupported man viewer.\n"
-"Please consider using 'man.<tool>.cmd' instead."
-msgstr ""
-"'%s'：不支持的 man 手册查看器的路径。\n"
-"请使用 'man.<工具>.cmd'。"
+#: builtin/log.c:1673
+msgid "add email header"
+msgstr "添加邮件头"
 
-#: builtin/help.c:226
-#, c-format
-msgid ""
-"'%s': cmd for supported man viewer.\n"
-"Please consider using 'man.<tool>.path' instead."
-msgstr ""
-"'%s': 支持的 man 手册查看器命令。\n"
-"请使用 'man.<工具>.path'。"
+#: builtin/log.c:1674 builtin/log.c:1676
+msgid "email"
+msgstr "邮件地址"
 
-#: builtin/help.c:343
-#, c-format
-msgid "'%s': unknown man viewer."
-msgstr "'%s'：未知的 man 查看器。"
+#: builtin/log.c:1674
+msgid "add To: header"
+msgstr "添加收件人"
 
-#: builtin/help.c:360
-msgid "no man viewer handled the request"
-msgstr "没有 man 查看器处理此请求"
+#: builtin/log.c:1676
+msgid "add Cc: header"
+msgstr "添加抄送"
 
-#: builtin/help.c:368
-msgid "no info viewer handled the request"
-msgstr "没有 info 查看器处理此请求"
+#: builtin/log.c:1678
+msgid "ident"
+msgstr "标识"
 
-#: builtin/help.c:415
-#, c-format
-msgid "'%s' is aliased to '%s'"
-msgstr "'%s' 是 '%s' 的别名"
+#: builtin/log.c:1679
+msgid "set From address to <ident> (or committer ident if absent)"
+msgstr "将 From 地址设置为 <标识>（如若不提供，则用提交者 ID 做为地址）"
 
-#: builtin/help.c:442 builtin/help.c:459
-#, c-format
-msgid "usage: %s%s"
-msgstr "用法：%s%s"
+#: builtin/log.c:1681
+msgid "message-id"
+msgstr "邮件标识"
 
-#: builtin/index-pack.c:158
-#, c-format
-msgid "unable to open %s"
-msgstr "不能打开 %s"
+#: builtin/log.c:1682
+msgid "make first mail a reply to <message-id>"
+msgstr "使第一封邮件作为对 <邮件标识> 的回复"
 
-#: builtin/index-pack.c:208
-#, c-format
-msgid "object type mismatch at %s"
-msgstr "%s 的对象类型不匹配"
+#: builtin/log.c:1683 builtin/log.c:1686
+msgid "boundary"
+msgstr "边界"
 
-#: builtin/index-pack.c:228
-#, c-format
-msgid "did not receive expected object %s"
-msgstr "未能获取预期的对象 %s"
+#: builtin/log.c:1684
+msgid "attach the patch"
+msgstr "附件方式添加补丁"
 
-#: builtin/index-pack.c:231
-#, c-format
-msgid "object %s: expected type %s, found %s"
-msgstr "对象 %s：应为类型 %s，却是 %s"
+#: builtin/log.c:1687
+msgid "inline the patch"
+msgstr "内联显示补丁"
 
-#: builtin/index-pack.c:273
-#, c-format
-msgid "cannot fill %d byte"
-msgid_plural "cannot fill %d bytes"
-msgstr[0] "无法填充 %d 字节"
-msgstr[1] "无法填充 %d 字节"
+#: builtin/log.c:1691
+msgid "enable message threading, styles: shallow, deep"
+msgstr "启用邮件线索，风格：浅，深"
 
-#: builtin/index-pack.c:283
-msgid "early EOF"
-msgstr "过早的文件结束符（EOF）"
+#: builtin/log.c:1693
+msgid "signature"
+msgstr "签名"
 
-#: builtin/index-pack.c:284
-msgid "read error on input"
-msgstr "输入上的读错误"
+#: builtin/log.c:1694
+msgid "add a signature"
+msgstr "添加一个签名"
 
-#: builtin/index-pack.c:296
-msgid "used more bytes than were available"
-msgstr "用掉了超过可用的字节"
+#: builtin/log.c:1695
+msgid "base-commit"
+msgstr "基线提交"
 
-#: builtin/index-pack.c:303
-msgid "pack too large for current definition of off_t"
-msgstr "包太大超过了当前 off_t 的定义"
+#: builtin/log.c:1696
+msgid "add prerequisite tree info to the patch series"
+msgstr "为补丁列表添加前置树信息"
 
-#: builtin/index-pack.c:306 builtin/unpack-objects.c:93
-msgid "pack exceeds maximum allowed size"
-msgstr "包超过了最大允许值"
+#: builtin/log.c:1698
+msgid "add a signature from a file"
+msgstr "从文件添加一个签名"
 
-#: builtin/index-pack.c:321
-#, c-format
-msgid "unable to create '%s'"
-msgstr "不能创建 '%s'"
+#: builtin/log.c:1699
+msgid "don't print the patch filenames"
+msgstr "不要打印补丁文件名"
 
-#: builtin/index-pack.c:327
-#, c-format
-msgid "cannot open packfile '%s'"
-msgstr "无法打开包文件 '%s'"
+#: builtin/log.c:1701
+msgid "show progress while generating patches"
+msgstr "在生成补丁时显示进度"
 
-#: builtin/index-pack.c:341
-msgid "pack signature mismatch"
-msgstr "包签名不匹配"
+#: builtin/log.c:1703
+msgid "show changes against <rev> in cover letter or single patch"
+msgstr "在附函或单个补丁中显示和 <rev> 的差异"
+
+#: builtin/log.c:1706
+msgid "show changes against <refspec> in cover letter or single patch"
+msgstr "在附函或单个补丁中显示和 <refspec> 的差异"
+
+#: builtin/log.c:1708
+msgid "percentage by which creation is weighted"
+msgstr "创建权重的百分比"
 
-#: builtin/index-pack.c:343
+#: builtin/log.c:1792
 #, c-format
-msgid "pack version %<PRIu32> unsupported"
-msgstr "不支持包版本 %<PRIu32>"
+msgid "invalid ident line: %s"
+msgstr "包含无效的身份标识：%s"
 
-#: builtin/index-pack.c:361
-#, c-format
-msgid "pack has bad object at offset %<PRIuMAX>: %s"
-msgstr "包中有错误的对象位于偏移量 %<PRIuMAX>：%s"
+#: builtin/log.c:1807
+msgid "-n and -k are mutually exclusive"
+msgstr "-n 和 -k 互斥"
+
+#: builtin/log.c:1809
+msgid "--subject-prefix/--rfc and -k are mutually exclusive"
+msgstr "--subject-prefix/--rfc 和 -k 互斥"
 
-#: builtin/index-pack.c:482
-#, c-format
-msgid "inflate returned %d"
-msgstr "解压缩返回 %d"
+#: builtin/log.c:1817
+msgid "--name-only does not make sense"
+msgstr "--name-only 无意义"
 
-#: builtin/index-pack.c:531
-msgid "offset value overflow for delta base object"
-msgstr "偏移值覆盖了 delta 基准对象"
+#: builtin/log.c:1819
+msgid "--name-status does not make sense"
+msgstr "--name-status 无意义"
 
-#: builtin/index-pack.c:539
-msgid "delta base offset is out of bound"
-msgstr "delta 基准偏移越界"
+#: builtin/log.c:1821
+msgid "--check does not make sense"
+msgstr "--check 无意义"
 
-#: builtin/index-pack.c:547
-#, c-format
-msgid "unknown object type %d"
-msgstr "未知对象类型 %d"
+#: builtin/log.c:1854
+msgid "standard output, or directory, which one?"
+msgstr "标准输出或目录，哪一个？"
 
-#: builtin/index-pack.c:578
-msgid "cannot pread pack file"
-msgstr "无法读取包文件"
+#: builtin/log.c:1958
+msgid "--interdiff requires --cover-letter or single patch"
+msgstr "--interdiff 需要 --cover-letter 或单一补丁"
 
-#: builtin/index-pack.c:580
+#: builtin/log.c:1962
+msgid "Interdiff:"
+msgstr "版本间差异："
+
+#: builtin/log.c:1963
 #, c-format
-msgid "premature end of pack file, %<PRIuMAX> byte missing"
-msgid_plural "premature end of pack file, %<PRIuMAX> bytes missing"
-msgstr[0] "包文件过早结束，缺少 %<PRIuMAX> 字节"
-msgstr[1] "包文件过早结束，缺少 %<PRIuMAX> 字节"
+msgid "Interdiff against v%d:"
+msgstr "对 v%d 的版本差异："
 
-#: builtin/index-pack.c:606
-msgid "serious inflate inconsistency"
-msgstr "解压缩严重的不一致"
+#: builtin/log.c:1969
+msgid "--creation-factor requires --range-diff"
+msgstr "--creation-factor 需要 --range-diff"
 
-#: builtin/index-pack.c:751 builtin/index-pack.c:757 builtin/index-pack.c:780
-#: builtin/index-pack.c:819 builtin/index-pack.c:828
-#, c-format
-msgid "SHA1 COLLISION FOUND WITH %s !"
-msgstr "发现 %s 出现 SHA1 冲突！"
+#: builtin/log.c:1973
+msgid "--range-diff requires --cover-letter or single patch"
+msgstr "--range-diff 需要 --cover-letter 或单一补丁"
 
-#: builtin/index-pack.c:754 builtin/pack-objects.c:198
-#: builtin/pack-objects.c:292
-#, c-format
-msgid "unable to read %s"
-msgstr "不能读 %s"
+#: builtin/log.c:1981
+msgid "Range-diff:"
+msgstr "范围差异："
 
-#: builtin/index-pack.c:817
+#: builtin/log.c:1982
 #, c-format
-msgid "cannot read existing object info %s"
-msgstr "不能读取现存对象信息 %s"
+msgid "Range-diff against v%d:"
+msgstr "对 v%d 的范围差异："
 
-#: builtin/index-pack.c:825
+#: builtin/log.c:1993
 #, c-format
-msgid "cannot read existing object %s"
-msgstr "不能读取现存对象 %s"
+msgid "unable to read signature file '%s'"
+msgstr "无法读取签名文件 '%s'"
 
-#: builtin/index-pack.c:839
-#, c-format
-msgid "invalid blob object %s"
-msgstr "无效的数据对象 %s"
+#: builtin/log.c:2029
+msgid "Generating patches"
+msgstr "生成补丁"
 
-#: builtin/index-pack.c:842 builtin/index-pack.c:860
-msgid "fsck error in packed object"
-msgstr "对打包对象 fsck 检查出错"
+#: builtin/log.c:2073
+msgid "failed to create output files"
+msgstr "无法创建输出文件"
 
-#: builtin/index-pack.c:857
-#, c-format
-msgid "invalid %s"
-msgstr "无效的 %s"
+#: builtin/log.c:2132
+msgid "git cherry [-v] [<upstream> [<head> [<limit>]]]"
+msgstr "git cherry [-v] [<上游> [<头> [<限制>]]]"
 
-#: builtin/index-pack.c:862
+#: builtin/log.c:2186
 #, c-format
-msgid "Not all child objects of %s are reachable"
-msgstr "%s 的所有子对象并非都可达"
+msgid ""
+"Could not find a tracked remote branch, please specify <upstream> manually.\n"
+msgstr "不能找到跟踪的远程分支，请手工指定 <上游>。\n"
 
-#: builtin/index-pack.c:934 builtin/index-pack.c:965
-msgid "failed to apply delta"
-msgstr "无法应用 delta"
+#: builtin/ls-files.c:470
+msgid "git ls-files [<options>] [<file>...]"
+msgstr "git ls-files [<选项>] [<文件>...]"
 
-#: builtin/index-pack.c:1135
-msgid "Receiving objects"
-msgstr "接收对象中"
+#: builtin/ls-files.c:526
+msgid "identify the file status with tags"
+msgstr "用标签标识文件的状态"
 
-#: builtin/index-pack.c:1135
-msgid "Indexing objects"
-msgstr "索引对象中"
+#: builtin/ls-files.c:528
+msgid "use lowercase letters for 'assume unchanged' files"
+msgstr "使用小写字母表示 '假设未改变的' 文件"
 
-#: builtin/index-pack.c:1169
-msgid "pack is corrupted (SHA1 mismatch)"
-msgstr "包冲突（SHA1 不匹配）"
+#: builtin/ls-files.c:530
+msgid "use lowercase letters for 'fsmonitor clean' files"
+msgstr "使用小写字母表示 'fsmonitor clean' 文件"
 
-#: builtin/index-pack.c:1174
-msgid "cannot fstat packfile"
-msgstr "不能对包文件调用 fstat"
+#: builtin/ls-files.c:532
+msgid "show cached files in the output (default)"
+msgstr "显示缓存的文件（默认）"
 
-#: builtin/index-pack.c:1177
-msgid "pack has junk at the end"
-msgstr "包的结尾有垃圾数据"
+#: builtin/ls-files.c:534
+msgid "show deleted files in the output"
+msgstr "显示已删除的文件"
 
-#: builtin/index-pack.c:1189
-msgid "confusion beyond insanity in parse_pack_objects()"
-msgstr "parse_pack_objects() 中遇到不可理喻的问题"
+#: builtin/ls-files.c:536
+msgid "show modified files in the output"
+msgstr "显示已修改的文件"
 
-#: builtin/index-pack.c:1212
-msgid "Resolving deltas"
-msgstr "处理 delta 中"
+#: builtin/ls-files.c:538
+msgid "show other files in the output"
+msgstr "显示其它文件"
 
-#: builtin/index-pack.c:1223
-#, c-format
-msgid "unable to create thread: %s"
-msgstr "不能创建线程：%s"
+#: builtin/ls-files.c:540
+msgid "show ignored files in the output"
+msgstr "显示忽略的文件"
 
-#: builtin/index-pack.c:1265
-msgid "confusion beyond insanity"
-msgstr "不可理喻"
+#: builtin/ls-files.c:543
+msgid "show staged contents' object name in the output"
+msgstr "显示暂存区内容的对象名称"
 
-#: builtin/index-pack.c:1271
-#, c-format
-msgid "completed with %d local object"
-msgid_plural "completed with %d local objects"
-msgstr[0] "完成 %d 个本地对象"
-msgstr[1] "完成 %d 个本地对象"
+#: builtin/ls-files.c:545
+msgid "show files on the filesystem that need to be removed"
+msgstr "显示文件系统需要删除的文件"
 
-#: builtin/index-pack.c:1283
-#, c-format
-msgid "Unexpected tail checksum for %s (disk corruption?)"
-msgstr "对 %s 的尾部校验出现意外（磁盘损坏？）"
+#: builtin/ls-files.c:547
+msgid "show 'other' directories' names only"
+msgstr "只显示“其他”目录的名称"
 
-#: builtin/index-pack.c:1287
-#, c-format
-msgid "pack has %d unresolved delta"
-msgid_plural "pack has %d unresolved deltas"
-msgstr[0] "包有 %d 个未解决的 delta"
-msgstr[1] "包有 %d 个未解决的 delta"
+#: builtin/ls-files.c:549
+msgid "show line endings of files"
+msgstr "显示文件换行符格式"
 
-#: builtin/index-pack.c:1311
-#, c-format
-msgid "unable to deflate appended object (%d)"
-msgstr "不能压缩附加对象（%d）"
+#: builtin/ls-files.c:551
+msgid "don't show empty directories"
+msgstr "不显示空目录"
 
-#: builtin/index-pack.c:1388
-#, c-format
-msgid "local object %s is corrupt"
-msgstr "本地对象 %s 已损坏"
+#: builtin/ls-files.c:554
+msgid "show unmerged files in the output"
+msgstr "显示未合并的文件"
 
-#: builtin/index-pack.c:1402
-#, c-format
-msgid "packfile name '%s' does not end with '.pack'"
-msgstr "包文件名 '%s' 没有以 '.pack' 结尾"
+#: builtin/ls-files.c:556
+msgid "show resolve-undo information"
+msgstr "显示 resolve-undo 信息"
 
-#: builtin/index-pack.c:1427
-#, c-format
-msgid "cannot write %s file '%s'"
-msgstr "无法写入 %s 文件 '%s'"
+#: builtin/ls-files.c:558
+msgid "skip files matching pattern"
+msgstr "匹配排除文件的模式"
 
-#: builtin/index-pack.c:1435
-#, c-format
-msgid "cannot close written %s file '%s'"
-msgstr "无法关闭已写入的 %s 文件 '%s'"
+#: builtin/ls-files.c:561
+msgid "exclude patterns are read from <file>"
+msgstr "从 <文件> 中读取排除模式"
 
-#: builtin/index-pack.c:1459
-msgid "error while closing pack file"
-msgstr "关闭包文件时出错"
+#: builtin/ls-files.c:564
+msgid "read additional per-directory exclude patterns in <file>"
+msgstr "从 <文件> 读取额外的每个目录的排除模式"
 
-#: builtin/index-pack.c:1473
-msgid "cannot store pack file"
-msgstr "无法存储包文件"
+#: builtin/ls-files.c:566
+msgid "add the standard git exclusions"
+msgstr "添加标准的 git 排除"
 
-#: builtin/index-pack.c:1481
-msgid "cannot store index file"
-msgstr "无法存储索引文件"
+#: builtin/ls-files.c:570
+msgid "make the output relative to the project top directory"
+msgstr "显示相对于顶级目录的文件名"
 
-#: builtin/index-pack.c:1525
-#, c-format
-msgid "bad pack.indexversion=%<PRIu32>"
-msgstr "坏的 pack.indexversion=%<PRIu32>"
+#: builtin/ls-files.c:573
+msgid "recurse through submodules"
+msgstr "在子模组中递归"
 
-#: builtin/index-pack.c:1594
-#, c-format
-msgid "Cannot open existing pack file '%s'"
-msgstr "无法打开现存包文件 '%s'"
+#: builtin/ls-files.c:575
+msgid "if any <file> is not in the index, treat this as an error"
+msgstr "如果任何 <文件> 都不在索引区，视为错误"
 
-#: builtin/index-pack.c:1596
-#, c-format
-msgid "Cannot open existing pack idx file for '%s'"
-msgstr "无法为 %s 打开包索引文件"
+#: builtin/ls-files.c:576
+msgid "tree-ish"
+msgstr "树对象"
 
-#: builtin/index-pack.c:1644
-#, c-format
-msgid "non delta: %d object"
-msgid_plural "non delta: %d objects"
-msgstr[0] "非 delta：%d 个对象"
-msgstr[1] "非 delta：%d 个对象"
+#: builtin/ls-files.c:577
+msgid "pretend that paths removed since <tree-ish> are still present"
+msgstr "假装自从 <树对象> 之后删除的路径仍然存在"
 
-#: builtin/index-pack.c:1651
-#, c-format
-msgid "chain length = %d: %lu object"
-msgid_plural "chain length = %d: %lu objects"
-msgstr[0] "链长 = %d: %lu 对象"
-msgstr[1] "链长 = %d: %lu 对象"
+#: builtin/ls-files.c:579
+msgid "show debugging data"
+msgstr "显示调试数据"
 
-#: builtin/index-pack.c:1688
-msgid "Cannot come back to cwd"
-msgstr "无法返回当前工作目录"
+#: builtin/ls-remote.c:9
+msgid ""
+"git ls-remote [--heads] [--tags] [--refs] [--upload-pack=<exec>]\n"
+"                     [-q | --quiet] [--exit-code] [--get-url]\n"
+"                     [--symref] [<repository> [<refs>...]]"
+msgstr ""
+"git ls-remote [--heads] [--tags] [--refs] [--upload-pack=<exec>]\n"
+"                     [-q | --quiet] [--exit-code] [--get-url]\n"
+"                     [--symref] [<仓库> [<引用>...]]"
 
-#: builtin/index-pack.c:1739 builtin/index-pack.c:1742
-#: builtin/index-pack.c:1758 builtin/index-pack.c:1762
-#, c-format
-msgid "bad %s"
-msgstr "错误选项 %s"
+#: builtin/ls-remote.c:59
+msgid "do not print remote URL"
+msgstr "不打印远程 URL"
 
-#: builtin/index-pack.c:1778
-msgid "--fix-thin cannot be used without --stdin"
-msgstr "--fix-thin 不能和 --stdin 同时使用"
+#: builtin/ls-remote.c:60 builtin/ls-remote.c:62 builtin/rebase.c:1518
+msgid "exec"
+msgstr "exec"
 
-#: builtin/index-pack.c:1780
-msgid "--stdin requires a git repository"
-msgstr "--stdin 需要一个 git 仓库"
+#: builtin/ls-remote.c:61 builtin/ls-remote.c:63
+msgid "path of git-upload-pack on the remote host"
+msgstr "远程主机上的 git-upload-pack 路径"
 
-#: builtin/index-pack.c:1786
-msgid "--verify with no packfile name given"
-msgstr "--verify 没有提供包文件名参数"
+#: builtin/ls-remote.c:65
+msgid "limit to tags"
+msgstr "仅限于标签"
 
-#: builtin/index-pack.c:1836 builtin/unpack-objects.c:578
-msgid "fsck error in pack objects"
-msgstr "在打包对象中 fsck 检查出错"
+#: builtin/ls-remote.c:66
+msgid "limit to heads"
+msgstr "仅限于分支"
 
-#: builtin/init-db.c:55
-#, c-format
-msgid "cannot stat '%s'"
-msgstr "不能对 '%s' 调用 stat"
+#: builtin/ls-remote.c:67
+msgid "do not show peeled tags"
+msgstr "不显示已解析的标签"
 
-#: builtin/init-db.c:61
-#, c-format
-msgid "cannot stat template '%s'"
-msgstr "不能对模版 '%s' 调用 stat"
+#: builtin/ls-remote.c:69
+msgid "take url.<base>.insteadOf into account"
+msgstr "参考 url.<base>.insteadOf 设置"
 
-#: builtin/init-db.c:66
-#, c-format
-msgid "cannot opendir '%s'"
-msgstr "不能打开目录 '%s'"
+#: builtin/ls-remote.c:72
+msgid "exit with exit code 2 if no matching refs are found"
+msgstr "若未找到匹配的引用则以退出码2退出"
 
-#: builtin/init-db.c:77
-#, c-format
-msgid "cannot readlink '%s'"
-msgstr "不能读取链接 '%s'"
+#: builtin/ls-remote.c:75
+msgid "show underlying ref in addition to the object pointed by it"
+msgstr "除了显示指向的对象外，显示指向的引用名"
 
-#: builtin/init-db.c:79
-#, c-format
-msgid "cannot symlink '%s' '%s'"
-msgstr "不能自 '%s' 到 '%s' 创建符号链接"
+#: builtin/ls-tree.c:30
+msgid "git ls-tree [<options>] <tree-ish> [<path>...]"
+msgstr "git ls-tree [<选项>] <树对象> [<路径>...]"
 
-#: builtin/init-db.c:85
-#, c-format
-msgid "cannot copy '%s' to '%s'"
-msgstr "不能拷贝 '%s' 至 '%s'"
+#: builtin/ls-tree.c:128
+msgid "only show trees"
+msgstr "只显示树"
 
-#: builtin/init-db.c:89
-#, c-format
-msgid "ignoring template %s"
-msgstr "忽略模版 %s"
+#: builtin/ls-tree.c:130
+msgid "recurse into subtrees"
+msgstr "递归到子树"
 
-#: builtin/init-db.c:120
-#, c-format
-msgid "templates not found in %s"
-msgstr "没有在 %s 中找到模版"
+#: builtin/ls-tree.c:132
+msgid "show trees when recursing"
+msgstr "当递归时显示树"
 
-#: builtin/init-db.c:135
-#, c-format
-msgid "not copying templates from '%s': %s"
-msgstr "没有从 '%s' 复制模版：%s"
+#: builtin/ls-tree.c:135
+msgid "terminate entries with NUL byte"
+msgstr "条目以 NUL 字符终止"
 
-#: builtin/init-db.c:328
-#, c-format
-msgid "unable to handle file type %d"
-msgstr "不能处理 %d 类型的文件"
+#: builtin/ls-tree.c:136
+msgid "include object size"
+msgstr "包括对象大小"
 
-#: builtin/init-db.c:331
-#, c-format
-msgid "unable to move %s to %s"
-msgstr "不能移动 %s 至 %s"
+#: builtin/ls-tree.c:138 builtin/ls-tree.c:140
+msgid "list only filenames"
+msgstr "只列出文件名"
 
-#: builtin/init-db.c:348 builtin/init-db.c:351
-#, c-format
-msgid "%s already exists"
-msgstr "%s 已经存在"
+#: builtin/ls-tree.c:143
+msgid "use full path names"
+msgstr "使用文件的全路径"
 
-#: builtin/init-db.c:404
-#, c-format
-msgid "Reinitialized existing shared Git repository in %s%s\n"
-msgstr "重新初始化已存在的共享 Git 仓库于 %s%s\n"
+#: builtin/ls-tree.c:145
+msgid "list entire tree; not just current directory (implies --full-name)"
+msgstr "列出整个树；不仅仅当前目录（隐含 --full-name）"
 
-#: builtin/init-db.c:405
+#: builtin/mailsplit.c:241
 #, c-format
-msgid "Reinitialized existing Git repository in %s%s\n"
-msgstr "重新初始化已存在的 Git 仓库于 %s%s\n"
+msgid "empty mbox: '%s'"
+msgstr "空的 mbox：'%s'"
 
-#: builtin/init-db.c:409
-#, c-format
-msgid "Initialized empty shared Git repository in %s%s\n"
-msgstr "已初始化空的共享 Git 仓库于 %s%s\n"
+#: builtin/merge.c:55
+msgid "git merge [<options>] [<commit>...]"
+msgstr "git merge [<选项>] [<提交>...]"
 
-#: builtin/init-db.c:410
-#, c-format
-msgid "Initialized empty Git repository in %s%s\n"
-msgstr "已初始化空的 Git 仓库于 %s%s\n"
+#: builtin/merge.c:56
+msgid "git merge --abort"
+msgstr "git merge --abort"
 
-#: builtin/init-db.c:458
-msgid ""
-"git init [-q | --quiet] [--bare] [--template=<template-directory>] [--"
-"shared[=<permissions>]] [<directory>]"
-msgstr ""
-"git init [-q | --quiet] [--bare] [--template=<模板目录>] [--shared[=<权限>]] "
-"[<目录>]"
+#: builtin/merge.c:57
+msgid "git merge --continue"
+msgstr "git merge --continue"
 
-#: builtin/init-db.c:481
-msgid "permissions"
-msgstr "权限"
+#: builtin/merge.c:118
+msgid "switch `m' requires a value"
+msgstr "开关 `m' 需要一个值"
 
-#: builtin/init-db.c:482
-msgid "specify that the git repository is to be shared amongst several users"
-msgstr "指定 git 仓库是多个用户之间共享的"
+#: builtin/merge.c:141
+#, c-format
+msgid "option `%s' requires a value"
+msgstr "选项 `%s' 需要一个值"
 
-#: builtin/init-db.c:525
+#: builtin/merge.c:187
 #, c-format
-msgid "cannot chdir to %s"
-msgstr "不能切换目录到 %s"
+msgid "Could not find merge strategy '%s'.\n"
+msgstr "不能找到合并策略 '%s'。\n"
 
-#: builtin/init-db.c:546
+#: builtin/merge.c:188
 #, c-format
-msgid ""
-"%s (or --work-tree=<directory>) not allowed without specifying %s (or --git-"
-"dir=<directory>)"
-msgstr "不允许 %s（或 --work-tree=<目录>）而没有指定 %s（或 --git-dir=<目录>）"
+msgid "Available strategies are:"
+msgstr "可用的策略有："
 
-#: builtin/init-db.c:574
+#: builtin/merge.c:193
 #, c-format
-msgid "Cannot access work tree '%s'"
-msgstr "不能访问工作区 '%s'"
+msgid "Available custom strategies are:"
+msgstr "可用的自定义策略有："
 
-#: builtin/interpret-trailers.c:15
-msgid ""
-"git interpret-trailers [--in-place] [--trim-empty] [(--trailer "
-"<token>[(=|:)<value>])...] [<file>...]"
-msgstr ""
-"git interpret-trailers [--in-place] [--trim-empty] [(--trailer <键>[(=|:)<值"
-">])...] [<文件>...]"
+#: builtin/merge.c:244 builtin/pull.c:152
+msgid "do not show a diffstat at the end of the merge"
+msgstr "在合并的最后不显示差异统计"
 
-#: builtin/interpret-trailers.c:92
-msgid "edit files in place"
-msgstr "在原位编辑文件"
+#: builtin/merge.c:247 builtin/pull.c:155
+msgid "show a diffstat at the end of the merge"
+msgstr "在合并的最后显示差异统计"
 
-#: builtin/interpret-trailers.c:93
-msgid "trim empty trailers"
-msgstr "删除空的尾部署名"
+#: builtin/merge.c:248 builtin/pull.c:158
+msgid "(synonym to --stat)"
+msgstr "（和 --stat 同义）"
 
-#: builtin/interpret-trailers.c:96
-msgid "where to place the new trailer"
-msgstr "在哪里放置新的尾部署名"
+#: builtin/merge.c:250 builtin/pull.c:161
+msgid "add (at most <n>) entries from shortlog to merge commit message"
+msgstr "在合并提交信息中添加（最多 <n> 条）精简提交记录"
 
-#: builtin/interpret-trailers.c:98
-msgid "action if trailer already exists"
-msgstr "当尾部署名已经存在时所采取的动作"
+#: builtin/merge.c:253 builtin/pull.c:167
+msgid "create a single commit instead of doing a merge"
+msgstr "创建一个单独的提交而不是做一次合并"
 
-#: builtin/interpret-trailers.c:100
-msgid "action if trailer is missing"
-msgstr "当尾部署名缺失时所采取的动作"
+#: builtin/merge.c:255 builtin/pull.c:170
+msgid "perform a commit if the merge succeeds (default)"
+msgstr "如果合并成功，执行一次提交（默认）"
 
-#: builtin/interpret-trailers.c:102
-msgid "output only the trailers"
-msgstr "只输出尾部署名"
+#: builtin/merge.c:257 builtin/pull.c:173
+msgid "edit message before committing"
+msgstr "在提交前编辑提交说明"
 
-#: builtin/interpret-trailers.c:103
-msgid "do not apply config rules"
-msgstr "不要应用配置规则"
+#: builtin/merge.c:259
+msgid "allow fast-forward (default)"
+msgstr "允许快进（默认）"
 
-#: builtin/interpret-trailers.c:104
-msgid "join whitespace-continued values"
-msgstr "连接空白折行的值"
+#: builtin/merge.c:261 builtin/pull.c:180
+msgid "abort if fast-forward is not possible"
+msgstr "如果不能快进就放弃合并"
 
-#: builtin/interpret-trailers.c:105
-msgid "set parsing options"
-msgstr "设置解析选项"
+#: builtin/merge.c:265 builtin/pull.c:183
+msgid "verify that the named commit has a valid GPG signature"
+msgstr "验证指定的提交是否包含一个有效的 GPG 签名"
 
-#: builtin/interpret-trailers.c:107
-msgid "trailer"
-msgstr "尾部署名"
+#: builtin/merge.c:266 builtin/notes.c:787 builtin/pull.c:187
+#: builtin/rebase.c:512 builtin/rebase.c:1531 builtin/revert.c:114
+msgid "strategy"
+msgstr "策略"
 
-#: builtin/interpret-trailers.c:108
-msgid "trailer(s) to add"
-msgstr "要添加的尾部署名"
+#: builtin/merge.c:267 builtin/pull.c:188
+msgid "merge strategy to use"
+msgstr "要使用的合并策略"
+
+#: builtin/merge.c:268 builtin/pull.c:191
+msgid "option=value"
+msgstr "option=value"
 
-#: builtin/interpret-trailers.c:117
-msgid "--trailer with --only-input does not make sense"
-msgstr "--trailer 和 --only-input 同时使用没有意义"
+#: builtin/merge.c:269 builtin/pull.c:192
+msgid "option for selected merge strategy"
+msgstr "所选的合并策略的选项"
 
-#: builtin/interpret-trailers.c:127
-msgid "no input file given for in-place editing"
-msgstr "没有给出要原位编辑的文件"
+#: builtin/merge.c:271
+msgid "merge commit message (for a non-fast-forward merge)"
+msgstr "合并的提交说明（针对非快进式合并）"
 
-#: builtin/log.c:48
-msgid "git log [<options>] [<revision-range>] [[--] <path>...]"
-msgstr "git log [<选项>] [<版本范围>] [[--] <路径>...]"
+#: builtin/merge.c:278
+msgid "abort the current in-progress merge"
+msgstr "放弃当前正在进行的合并"
 
-#: builtin/log.c:49
-msgid "git show [<options>] <object>..."
-msgstr "git show [<选项>] <对象>..."
+#
+#: builtin/merge.c:280
+msgid "--abort but leave index and working tree alone"
+msgstr "--abort，但是保留索引和工作区"
 
-#: builtin/log.c:93
-#, c-format
-msgid "invalid --decorate option: %s"
-msgstr "无效的 --decorate 选项：%s"
+#: builtin/merge.c:282
+msgid "continue the current in-progress merge"
+msgstr "继续当前正在进行的合并"
 
-#: builtin/log.c:153
-msgid "suppress diff output"
-msgstr "不显示差异输出"
+#: builtin/merge.c:284 builtin/pull.c:199
+msgid "allow merging unrelated histories"
+msgstr "允许合并不相关的历史"
 
-#: builtin/log.c:154
-msgid "show source"
-msgstr "显示源"
+#: builtin/merge.c:290
+msgid "bypass pre-merge-commit and commit-msg hooks"
+msgstr "绕过 pre-merge-commit 和 commit-msg 钩子"
 
-#: builtin/log.c:155
-msgid "Use mail map file"
-msgstr "使用邮件映射文件"
+#: builtin/merge.c:307
+msgid "could not run stash."
+msgstr "不能运行贮藏。"
 
-#: builtin/log.c:157
-msgid "only decorate refs that match <pattern>"
-msgstr "只修饰与 <模式> 匹配的引用"
+#: builtin/merge.c:312
+msgid "stash failed"
+msgstr "贮藏失败"
 
-#: builtin/log.c:159
-msgid "do not decorate refs that match <pattern>"
-msgstr "不修饰和 <模式> 匹配的引用"
+#: builtin/merge.c:317
+#, c-format
+msgid "not a valid object: %s"
+msgstr "不是一个有效对象：%s"
 
-#: builtin/log.c:160
-msgid "decorate options"
-msgstr "修饰选项"
+#: builtin/merge.c:339 builtin/merge.c:356
+msgid "read-tree failed"
+msgstr "读取树失败"
 
-#: builtin/log.c:163
-msgid "Process line range n,m in file, counting from 1"
-msgstr "处理文件中第 n 到 m 之间的行，从 1 开始"
+#  译者：注意保持前导空格
+#: builtin/merge.c:386
+msgid " (nothing to squash)"
+msgstr " （无可压缩）"
 
-#: builtin/log.c:259
+#: builtin/merge.c:397
 #, c-format
-msgid "Final output: %d %s\n"
-msgstr "最终输出：%d %s\n"
+msgid "Squash commit -- not updating HEAD\n"
+msgstr "压缩提交 -- 未更新 HEAD\n"
 
-#: builtin/log.c:510
+#: builtin/merge.c:447
 #, c-format
-msgid "git show %s: bad file"
-msgstr "git show %s: 损坏的文件"
+msgid "No merge message -- not updating HEAD\n"
+msgstr "无合并信息 -- 未更新 HEAD\n"
 
-#: builtin/log.c:525 builtin/log.c:619
+#: builtin/merge.c:498
 #, c-format
-msgid "Could not read object %s"
-msgstr "不能读取对象 %s"
+msgid "'%s' does not point to a commit"
+msgstr "'%s' 没有指向一个提交"
 
-#: builtin/log.c:643
+#: builtin/merge.c:585
 #, c-format
-msgid "Unknown type: %d"
-msgstr "未知类型：%d"
-
-#: builtin/log.c:764
-msgid "format.headers without value"
-msgstr "format.headers 没有值"
+msgid "Bad branch.%s.mergeoptions string: %s"
+msgstr "坏的 branch.%s.mergeoptions 字符串：%s"
 
-#: builtin/log.c:865
-msgid "name of output directory is too long"
-msgstr "输出目录名太长"
+#: builtin/merge.c:705
+msgid "Not handling anything other than two heads merge."
+msgstr "未处理两个头合并之外的任何操作。"
 
-#: builtin/log.c:881
+#: builtin/merge.c:719
 #, c-format
-msgid "Cannot open patch file %s"
-msgstr "无法打开补丁文件 %s"
-
-#: builtin/log.c:898
-msgid "Need exactly one range."
-msgstr "只需要一个范围。"
-
-#: builtin/log.c:908
-msgid "Not a range."
-msgstr "不是一个范围。"
-
-#: builtin/log.c:1014
-msgid "Cover letter needs email format"
-msgstr "信封需要邮件地址格式"
+msgid "Unknown option for merge-recursive: -X%s"
+msgstr "merge-recursive 的未知选项：-X%s"
 
-#: builtin/log.c:1095
+#: builtin/merge.c:734
 #, c-format
-msgid "insane in-reply-to: %s"
-msgstr "不正常的 in-reply-to：%s"
-
-#: builtin/log.c:1122
-msgid "git format-patch [<options>] [<since> | <revision-range>]"
-msgstr "git format-patch [<选项>] [<从> | <版本范围>]"
-
-#: builtin/log.c:1172
-msgid "Two output directories?"
-msgstr "两个输出目录？"
+msgid "unable to write %s"
+msgstr "不能写 %s"
 
-#: builtin/log.c:1279 builtin/log.c:1932 builtin/log.c:1934 builtin/log.c:1946
+#: builtin/merge.c:786
 #, c-format
-msgid "Unknown commit %s"
-msgstr "未知提交 %s"
+msgid "Could not read from '%s'"
+msgstr "不能从 '%s' 读取"
 
-#: builtin/log.c:1289 builtin/notes.c:887 builtin/tag.c:523
+#: builtin/merge.c:795
 #, c-format
-msgid "Failed to resolve '%s' as a valid ref."
-msgstr "无法解析 '%s' 为一个有效引用。"
-
-#: builtin/log.c:1294
-msgid "Could not find exact merge base."
-msgstr "不能找到准确的合并基线。"
+msgid "Not committing merge; use 'git commit' to complete the merge.\n"
+msgstr "未提交合并，使用 'git commit' 完成此次合并。\n"
 
-#: builtin/log.c:1298
+#: builtin/merge.c:801
 msgid ""
-"Failed to get upstream, if you want to record base commit automatically,\n"
-"please use git branch --set-upstream-to to track a remote branch.\n"
-"Or you could specify base commit by --base=<base-commit-id> manually."
+"Please enter a commit message to explain why this merge is necessary,\n"
+"especially if it merges an updated upstream into a topic branch.\n"
+"\n"
 msgstr ""
-"无法得到上游地址，如果你想自动记录基线提交，请使用命令\n"
-"git branch --set-upstream-to 来跟踪一个远程分支。或者你可以通过\n"
-"参数 --base=<基线提交> 手动指定一个基线提交。"
-
-#: builtin/log.c:1318
-msgid "Failed to find exact merge base"
-msgstr "无法找到准确的合并基线"
-
-#: builtin/log.c:1329
-msgid "base commit should be the ancestor of revision list"
-msgstr "基线提交应该是版本列表的祖先"
-
-#: builtin/log.c:1333
-msgid "base commit shouldn't be in revision list"
-msgstr "基线提交不应该出现在版本列表中"
-
-#: builtin/log.c:1382
-msgid "cannot get patch id"
-msgstr "无法得到补丁 id"
-
-#: builtin/log.c:1441
-msgid "use [PATCH n/m] even with a single patch"
-msgstr "使用 [PATCH n/m]，即使只有一个补丁"
-
-#: builtin/log.c:1444
-msgid "use [PATCH] even with multiple patches"
-msgstr "使用 [PATCH]，即使有多个补丁"
-
-#: builtin/log.c:1448
-msgid "print patches to standard out"
-msgstr "打印补丁到标准输出"
-
-#: builtin/log.c:1450
-msgid "generate a cover letter"
-msgstr "生成一封附信"
-
-#: builtin/log.c:1452
-msgid "use simple number sequence for output file names"
-msgstr "使用简单的数字序列作为输出文件名"
-
-#: builtin/log.c:1453
-msgid "sfx"
-msgstr "后缀"
-
-#: builtin/log.c:1454
-msgid "use <sfx> instead of '.patch'"
-msgstr "使用 <后缀> 代替 '.patch'"
+"请输入一个提交信息以解释此合并的必要性，尤其是将一个更新后的上游分支\n"
+"合并到主题分支。\n"
+"\n"
 
-#: builtin/log.c:1456
-msgid "start numbering patches at <n> instead of 1"
-msgstr "补丁以 <n> 开始编号，而不是1"
+#: builtin/merge.c:806
+msgid "An empty message aborts the commit.\n"
+msgstr "空的提交说明会终止提交。\n"
 
-#: builtin/log.c:1458
-msgid "mark the series as Nth re-roll"
-msgstr "标记补丁系列是第几次重制"
+#: builtin/merge.c:809
+#, c-format
+msgid ""
+"Lines starting with '%c' will be ignored, and an empty message aborts\n"
+"the commit.\n"
+msgstr "以 '%c' 开始的行将被忽略，而空的提交说明将终止提交。\n"
 
-#: builtin/log.c:1460
-msgid "Use [RFC PATCH] instead of [PATCH]"
-msgstr "使用 [RFC PATCH] 代替 [PATCH]"
+#: builtin/merge.c:862
+msgid "Empty commit message."
+msgstr "空提交信息。"
 
-#: builtin/log.c:1463
-msgid "Use [<prefix>] instead of [PATCH]"
-msgstr "使用 [<前缀>] 代替 [PATCH]"
+#: builtin/merge.c:877
+#, c-format
+msgid "Wonderful.\n"
+msgstr "太棒了。\n"
 
-#: builtin/log.c:1466
-msgid "store resulting files in <dir>"
-msgstr "把结果文件存储在 <目录>"
+#: builtin/merge.c:938
+#, c-format
+msgid "Automatic merge failed; fix conflicts and then commit the result.\n"
+msgstr "自动合并失败，修正冲突然后提交修正的结果。\n"
 
-#: builtin/log.c:1469
-msgid "don't strip/add [PATCH]"
-msgstr "不删除/添加 [PATCH]"
+#: builtin/merge.c:977
+msgid "No current branch."
+msgstr "没有当前分支。"
 
-#: builtin/log.c:1472
-msgid "don't output binary diffs"
-msgstr "不输出二进制差异"
+#: builtin/merge.c:979
+msgid "No remote for the current branch."
+msgstr "当前分支没有对应的远程仓库。"
 
-#: builtin/log.c:1474
-msgid "output all-zero hash in From header"
-msgstr "在 From 头信息中输出全为零的哈希值"
+#: builtin/merge.c:981
+msgid "No default upstream defined for the current branch."
+msgstr "当前分支没有定义默认的上游分支。"
 
-#: builtin/log.c:1476
-msgid "don't include a patch matching a commit upstream"
-msgstr "不包含已在上游提交中的补丁"
+#: builtin/merge.c:986
+#, c-format
+msgid "No remote-tracking branch for %s from %s"
+msgstr "对于 %s 没有来自 %s 的远程跟踪分支"
 
-#: builtin/log.c:1478
-msgid "show patch format instead of default (patch + stat)"
-msgstr "显示纯补丁格式而非默认的（补丁+状态）"
+#: builtin/merge.c:1043
+#, c-format
+msgid "Bad value '%s' in environment '%s'"
+msgstr "环境 '%2$s' 中存在坏的取值 '%1$s'"
 
-#: builtin/log.c:1480
-msgid "Messaging"
-msgstr "邮件发送"
+#: builtin/merge.c:1146
+#, c-format
+msgid "not something we can merge in %s: %s"
+msgstr "不能在 %s 中合并：%s"
 
-#: builtin/log.c:1481
-msgid "header"
-msgstr "header"
+#: builtin/merge.c:1180
+msgid "not something we can merge"
+msgstr "不能合并"
 
-#: builtin/log.c:1482
-msgid "add email header"
-msgstr "添加邮件头"
+#: builtin/merge.c:1283
+msgid "--abort expects no arguments"
+msgstr "--abort 不带参数"
 
-#: builtin/log.c:1483 builtin/log.c:1485
-msgid "email"
-msgstr "邮件地址"
+#: builtin/merge.c:1287
+msgid "There is no merge to abort (MERGE_HEAD missing)."
+msgstr "没有要终止的合并（MERGE_HEAD 丢失）。"
 
-#: builtin/log.c:1483
-msgid "add To: header"
-msgstr "添加收件人"
+#: builtin/merge.c:1296
+msgid "--quit expects no arguments"
+msgstr "--quit 不带参数"
 
-#: builtin/log.c:1485
-msgid "add Cc: header"
-msgstr "添加抄送"
+#: builtin/merge.c:1309
+msgid "--continue expects no arguments"
+msgstr "--continue 不带参数"
 
-#: builtin/log.c:1487
-msgid "ident"
-msgstr "标识"
+#: builtin/merge.c:1313
+msgid "There is no merge in progress (MERGE_HEAD missing)."
+msgstr "没有进行中的合并（MERGE_HEAD 丢失）。"
 
-#: builtin/log.c:1488
-msgid "set From address to <ident> (or committer ident if absent)"
-msgstr "将 From 地址设置为 <标识>（如若不提供，则用提交者 ID 做为地址）"
+#: builtin/merge.c:1329
+msgid ""
+"You have not concluded your merge (MERGE_HEAD exists).\n"
+"Please, commit your changes before you merge."
+msgstr ""
+"您尚未结束您的合并（存在 MERGE_HEAD）。\n"
+"请在合并前先提交您的修改。"
 
-#: builtin/log.c:1490
-msgid "message-id"
-msgstr "邮件标识"
+#: builtin/merge.c:1336
+msgid ""
+"You have not concluded your cherry-pick (CHERRY_PICK_HEAD exists).\n"
+"Please, commit your changes before you merge."
+msgstr ""
+"您尚未结束您的拣选（存在 CHERRY_PICK_HEAD）。\n"
+"请在合并前先提交您的修改。"
 
-#: builtin/log.c:1491
-msgid "make first mail a reply to <message-id>"
-msgstr "使第一封邮件作为对 <邮件标识> 的回复"
+#: builtin/merge.c:1339
+msgid "You have not concluded your cherry-pick (CHERRY_PICK_HEAD exists)."
+msgstr "您尚未结束您的拣选（存在 CHERRY_PICK_HEAD）。"
 
-#: builtin/log.c:1492 builtin/log.c:1495
-msgid "boundary"
-msgstr "边界"
+#: builtin/merge.c:1353
+msgid "You cannot combine --squash with --no-ff."
+msgstr "您不能将 --squash 和 --no-ff 组合使用。"
 
-#: builtin/log.c:1493
-msgid "attach the patch"
-msgstr "附件方式添加补丁"
+#: builtin/merge.c:1355
+msgid "You cannot combine --squash with --commit."
+msgstr "您不能将 --squash 和 --commit 组合使用。"
 
-#: builtin/log.c:1496
-msgid "inline the patch"
-msgstr "内联显示补丁"
+#: builtin/merge.c:1371
+msgid "No commit specified and merge.defaultToUpstream not set."
+msgstr "未指定提交并且 merge.defaultToUpstream 未设置。"
 
-#: builtin/log.c:1500
-msgid "enable message threading, styles: shallow, deep"
-msgstr "启用邮件线索，风格：浅，深"
+#: builtin/merge.c:1388
+msgid "Squash commit into empty head not supported yet"
+msgstr "尚不支持到空分支的压缩提交"
 
-#: builtin/log.c:1502
-msgid "signature"
-msgstr "签名"
+#: builtin/merge.c:1390
+msgid "Non-fast-forward commit does not make sense into an empty head"
+msgstr "到空分支的非快进式提交没有意义"
 
-#: builtin/log.c:1503
-msgid "add a signature"
-msgstr "添加一个签名"
+#: builtin/merge.c:1395
+#, c-format
+msgid "%s - not something we can merge"
+msgstr "%s - 不能被合并"
 
-#: builtin/log.c:1504
-msgid "base-commit"
-msgstr "基线提交"
+#: builtin/merge.c:1397
+msgid "Can merge only exactly one commit into empty head"
+msgstr "只能将一个提交合并到空分支上"
 
-#: builtin/log.c:1505
-msgid "add prerequisite tree info to the patch series"
-msgstr "为补丁列表添加前置树信息"
+#: builtin/merge.c:1476
+msgid "refusing to merge unrelated histories"
+msgstr "拒绝合并无关的历史"
 
-#: builtin/log.c:1507
-msgid "add a signature from a file"
-msgstr "从文件添加一个签名"
+#: builtin/merge.c:1485
+msgid "Already up to date."
+msgstr "已经是最新的。"
 
-#: builtin/log.c:1508
-msgid "don't print the patch filenames"
-msgstr "不要打印补丁文件名"
+#: builtin/merge.c:1495
+#, c-format
+msgid "Updating %s..%s\n"
+msgstr "更新 %s..%s\n"
 
-#: builtin/log.c:1510
-msgid "show progress while generating patches"
-msgstr "在生成补丁时显示进度"
+#: builtin/merge.c:1537
+#, c-format
+msgid "Trying really trivial in-index merge...\n"
+msgstr "尝试非常小的索引内合并...\n"
 
-#: builtin/log.c:1585
+#: builtin/merge.c:1544
 #, c-format
-msgid "invalid ident line: %s"
-msgstr "包含无效的身份标识：%s"
+msgid "Nope.\n"
+msgstr "无。\n"
 
-#: builtin/log.c:1600
-msgid "-n and -k are mutually exclusive."
-msgstr "-n 和 -k 互斥。"
-
-#: builtin/log.c:1602
-msgid "--subject-prefix/--rfc and -k are mutually exclusive."
-msgstr "--subject-prefix/--rfc 和 -k 互斥。"
+#: builtin/merge.c:1569
+msgid "Already up to date. Yeeah!"
+msgstr "已经是最新的。耶！"
 
-#: builtin/log.c:1610
-msgid "--name-only does not make sense"
-msgstr "--name-only 无意义"
+#: builtin/merge.c:1575
+msgid "Not possible to fast-forward, aborting."
+msgstr "无法快进，终止。"
 
-#: builtin/log.c:1612
-msgid "--name-status does not make sense"
-msgstr "--name-status 无意义"
+#: builtin/merge.c:1598 builtin/merge.c:1663
+#, c-format
+msgid "Rewinding the tree to pristine...\n"
+msgstr "将树回滚至原始状态...\n"
 
-#: builtin/log.c:1614
-msgid "--check does not make sense"
-msgstr "--check 无意义"
+#: builtin/merge.c:1602
+#, c-format
+msgid "Trying merge strategy %s...\n"
+msgstr "尝试合并策略 %s...\n"
 
-#: builtin/log.c:1646
-msgid "standard output, or directory, which one?"
-msgstr "标准输出或目录，哪一个？"
+#: builtin/merge.c:1654
+#, c-format
+msgid "No merge strategy handled the merge.\n"
+msgstr "没有合并策略处理此合并。\n"
 
-#: builtin/log.c:1648
+#: builtin/merge.c:1656
 #, c-format
-msgid "Could not create directory '%s'"
-msgstr "不能创建目录 '%s'"
+msgid "Merge with strategy %s failed.\n"
+msgstr "使用策略 %s 合并失败。\n"
 
-#: builtin/log.c:1741
+#: builtin/merge.c:1665
 #, c-format
-msgid "unable to read signature file '%s'"
-msgstr "无法读取签名文件 '%s'"
+msgid "Using the %s to prepare resolving by hand.\n"
+msgstr "使用 %s 以准备手工解决。\n"
 
-#: builtin/log.c:1773
-msgid "Generating patches"
-msgstr "生成补丁"
+#: builtin/merge.c:1677
+#, c-format
+msgid "Automatic merge went well; stopped before committing as requested\n"
+msgstr "自动合并进展顺利，按要求在提交前停止\n"
 
-#: builtin/log.c:1817
-msgid "Failed to create output files"
-msgstr "无法创建输出文件"
+#: builtin/merge-base.c:32
+msgid "git merge-base [-a | --all] <commit> <commit>..."
+msgstr "git merge-base [-a | --all] <提交> <提交>..."
 
-#: builtin/log.c:1867
-msgid "git cherry [-v] [<upstream> [<head> [<limit>]]]"
-msgstr "git cherry [-v] [<上游> [<头> [<限制>]]]"
+#: builtin/merge-base.c:33
+msgid "git merge-base [-a | --all] --octopus <commit>..."
+msgstr "git merge-base [-a | --all] --octopus <提交>..."
 
-#: builtin/log.c:1921
-#, c-format
-msgid ""
-"Could not find a tracked remote branch, please specify <upstream> manually.\n"
-msgstr "不能找到跟踪的远程分支，请手工指定 <上游>。\n"
+#: builtin/merge-base.c:34
+msgid "git merge-base --independent <commit>..."
+msgstr "git merge-base --independent <提交>..."
 
-#: builtin/ls-files.c:468
-msgid "git ls-files [<options>] [<file>...]"
-msgstr "git ls-files [<选项>] [<文件>...]"
+#: builtin/merge-base.c:35
+msgid "git merge-base --is-ancestor <commit> <commit>"
+msgstr "git merge-base --is-ancestor <提交> <提交>"
 
-#: builtin/ls-files.c:517
-msgid "identify the file status with tags"
-msgstr "用标签标识文件的状态"
+#: builtin/merge-base.c:36
+msgid "git merge-base --fork-point <ref> [<commit>]"
+msgstr "git merge-base --fork-point <引用> [<提交>]"
 
-#: builtin/ls-files.c:519
-msgid "use lowercase letters for 'assume unchanged' files"
-msgstr "使用小写字母表示 '假设未改变的' 文件"
+#: builtin/merge-base.c:153
+msgid "output all common ancestors"
+msgstr "输出所有共同的祖先"
 
-#: builtin/ls-files.c:521
-msgid "use lowercase letters for 'fsmonitor clean' files"
-msgstr "使用小写字母表示 'fsmonitor clean' 文件"
+#: builtin/merge-base.c:155
+msgid "find ancestors for a single n-way merge"
+msgstr "查找一个多路合并的祖先提交"
 
-#: builtin/ls-files.c:523
-msgid "show cached files in the output (default)"
-msgstr "显示缓存的文件（默认）"
+#: builtin/merge-base.c:157
+msgid "list revs not reachable from others"
+msgstr "显示不能被其他访问到的版本"
 
-#: builtin/ls-files.c:525
-msgid "show deleted files in the output"
-msgstr "显示已删除的文件"
+#: builtin/merge-base.c:159
+msgid "is the first one ancestor of the other?"
+msgstr "第一个是其他的祖先提交么？"
 
-#: builtin/ls-files.c:527
-msgid "show modified files in the output"
-msgstr "显示已修改的文件"
+#: builtin/merge-base.c:161
+msgid "find where <commit> forked from reflog of <ref>"
+msgstr "根据 <引用> 的引用日志查找 <提交> 的派生处"
 
-#: builtin/ls-files.c:529
-msgid "show other files in the output"
-msgstr "显示其它文件"
+#: builtin/merge-file.c:9
+msgid ""
+"git merge-file [<options>] [-L <name1> [-L <orig> [-L <name2>]]] <file1> "
+"<orig-file> <file2>"
+msgstr ""
+"git merge-file [<选项>] [-L <文件1> [-L <初始> [-L <名字2>]]] <文件1> <初始文"
+"件> <文件2>"
 
-#: builtin/ls-files.c:531
-msgid "show ignored files in the output"
-msgstr "显示忽略的文件"
+#: builtin/merge-file.c:35
+msgid "send results to standard output"
+msgstr "将结果发送到标准输出"
 
-#: builtin/ls-files.c:534
-msgid "show staged contents' object name in the output"
-msgstr "显示暂存区内容的对象名称"
+#: builtin/merge-file.c:36
+msgid "use a diff3 based merge"
+msgstr "使用基于 diff3 的合并"
 
-#: builtin/ls-files.c:536
-msgid "show files on the filesystem that need to be removed"
-msgstr "显示文件系统需要删除的文件"
+#: builtin/merge-file.c:37
+msgid "for conflicts, use our version"
+msgstr "如果冲突，使用我们的版本"
 
-#: builtin/ls-files.c:538
-msgid "show 'other' directories' names only"
-msgstr "只显示“其他”目录的名称"
+#: builtin/merge-file.c:39
+msgid "for conflicts, use their version"
+msgstr "如果冲突，使用他们的版本"
 
-#: builtin/ls-files.c:540
-msgid "show line endings of files"
-msgstr "显示文件换行符格式"
+#: builtin/merge-file.c:41
+msgid "for conflicts, use a union version"
+msgstr "如果冲突，使用联合版本"
 
-#: builtin/ls-files.c:542
-msgid "don't show empty directories"
-msgstr "不显示空目录"
+#: builtin/merge-file.c:44
+msgid "for conflicts, use this marker size"
+msgstr "如果冲突，使用指定长度的标记"
 
-#: builtin/ls-files.c:545
-msgid "show unmerged files in the output"
-msgstr "显示未合并的文件"
+#: builtin/merge-file.c:45
+msgid "do not warn about conflicts"
+msgstr "不要警告冲突"
 
-#: builtin/ls-files.c:547
-msgid "show resolve-undo information"
-msgstr "显示 resolve-undo 信息"
+#: builtin/merge-file.c:47
+msgid "set labels for file1/orig-file/file2"
+msgstr "为 文件1/初始文件/文件2 设置标签"
 
-#: builtin/ls-files.c:549
-msgid "skip files matching pattern"
-msgstr "匹配排除文件的模式"
+#: builtin/merge-recursive.c:47
+#, c-format
+msgid "unknown option %s"
+msgstr "未知选项 %s"
 
-#: builtin/ls-files.c:552
-msgid "exclude patterns are read from <file>"
-msgstr "从 <文件> 中读取排除模式"
+#: builtin/merge-recursive.c:53
+#, c-format
+msgid "could not parse object '%s'"
+msgstr "不能解析对象 '%s'"
 
-#: builtin/ls-files.c:555
-msgid "read additional per-directory exclude patterns in <file>"
-msgstr "从 <文件> 读取额外的每个目录的排除模式"
+#: builtin/merge-recursive.c:57
+#, c-format
+msgid "cannot handle more than %d base. Ignoring %s."
+msgid_plural "cannot handle more than %d bases. Ignoring %s."
+msgstr[0] "无法处理 %d 条以上的基线。忽略 %s。"
+msgstr[1] "无法处理 %d 条以上的基线。忽略 %s。"
 
-#: builtin/ls-files.c:557
-msgid "add the standard git exclusions"
-msgstr "添加标准的 git 排除"
+#: builtin/merge-recursive.c:65
+msgid "not handling anything other than two heads merge."
+msgstr "不能处理两个头合并之外的任何操作。"
 
-#: builtin/ls-files.c:560
-msgid "make the output relative to the project top directory"
-msgstr "显示相对于顶级目录的文件名"
+#: builtin/merge-recursive.c:74 builtin/merge-recursive.c:76
+#, c-format
+msgid "could not resolve ref '%s'"
+msgstr "无法解析引用 '%s'"
 
-#: builtin/ls-files.c:563
-msgid "recurse through submodules"
-msgstr "在子模组中递归"
+#: builtin/merge-recursive.c:82
+#, c-format
+msgid "Merging %s with %s\n"
+msgstr "合并 %s 和 %s\n"
 
-#: builtin/ls-files.c:565
-msgid "if any <file> is not in the index, treat this as an error"
-msgstr "如果任何 <文件> 都不在索引区，视为错误"
+#: builtin/mktree.c:66
+msgid "git mktree [-z] [--missing] [--batch]"
+msgstr "git mktree [-z] [--missing] [--batch]"
 
-#: builtin/ls-files.c:566
-msgid "tree-ish"
-msgstr "树或提交"
+#: builtin/mktree.c:154
+msgid "input is NUL terminated"
+msgstr "输入以 NUL 字符终止"
 
-#: builtin/ls-files.c:567
-msgid "pretend that paths removed since <tree-ish> are still present"
-msgstr "假装自从 <树或提交> 之后删除的路径仍然存在"
+#: builtin/mktree.c:155 builtin/write-tree.c:26
+msgid "allow missing objects"
+msgstr "允许丢失的对象"
 
-#: builtin/ls-files.c:569
-msgid "show debugging data"
-msgstr "显示调试数据"
+#: builtin/mktree.c:156
+msgid "allow creation of more than one tree"
+msgstr "允许创建一个以上的树"
 
-#: builtin/ls-remote.c:9
+#: builtin/multi-pack-index.c:9
 msgid ""
-"git ls-remote [--heads] [--tags] [--refs] [--upload-pack=<exec>]\n"
-"                     [-q | --quiet] [--exit-code] [--get-url]\n"
-"                     [--symref] [<repository> [<refs>...]]"
-msgstr ""
-"git ls-remote [--heads] [--tags] [--refs] [--upload-pack=<exec>]\n"
-"                     [-q | --quiet] [--exit-code] [--get-url]\n"
-"                     [--symref] [<仓库> [<引用>...]]"
+"git multi-pack-index [<options>] (write|verify|expire|repack --batch-"
+"size=<size>)"
+msgstr "git multi-pack-index [<选项>] (write|verify|expire|repack --batch-size=<大小>)"
 
-#: builtin/ls-remote.c:59
-msgid "do not print remote URL"
-msgstr "不打印远程 URL"
+#: builtin/multi-pack-index.c:26
+msgid "object directory containing set of packfile and pack-index pairs"
+msgstr "包含成对包文件和包索引的对象目录"
 
-#: builtin/ls-remote.c:60 builtin/ls-remote.c:62
-msgid "exec"
-msgstr "exec"
+#: builtin/multi-pack-index.c:29
+msgid ""
+"during repack, collect pack-files of smaller size into a batch that is "
+"larger than this size"
+msgstr "在 repack 期间，将较小尺寸的包文件收集到大于此大小的批次中"
 
-#: builtin/ls-remote.c:61 builtin/ls-remote.c:63
-msgid "path of git-upload-pack on the remote host"
-msgstr "远程主机上的 git-upload-pack 路径"
+#: builtin/multi-pack-index.c:50 builtin/prune-packed.c:67
+msgid "too many arguments"
+msgstr "太多参数"
 
-#: builtin/ls-remote.c:65
-msgid "limit to tags"
-msgstr "仅限于标签"
+#: builtin/multi-pack-index.c:60
+msgid "--batch-size option is only for 'repack' subcommand"
+msgstr "--batch-size 选项仅用于 'repack' 子命令"
 
-#: builtin/ls-remote.c:66
-msgid "limit to heads"
-msgstr "仅限于分支"
+#: builtin/multi-pack-index.c:69
+#, c-format
+msgid "unrecognized subcommand: %s"
+msgstr "未识别的子命令：%s"
 
-#: builtin/ls-remote.c:67
-msgid "do not show peeled tags"
-msgstr "不显示已解析的标签"
+#: builtin/mv.c:18
+msgid "git mv [<options>] <source>... <destination>"
+msgstr "git mv [<选项>] <源>... <目标>"
 
-#: builtin/ls-remote.c:69
-msgid "take url.<base>.insteadOf into account"
-msgstr "参考 url.<base>.insteadOf 设置"
+#: builtin/mv.c:83
+#, c-format
+msgid "Directory %s is in index and no submodule?"
+msgstr "目录 %s 在索引中并且不是子模组？"
 
-#: builtin/ls-remote.c:73
-msgid "exit with exit code 2 if no matching refs are found"
-msgstr "若未找到匹配的引用则以退出码2退出"
+#: builtin/mv.c:85
+msgid "Please stage your changes to .gitmodules or stash them to proceed"
+msgstr "请将您的修改暂存到 .gitmodules 中或贮藏后再继续"
 
-#: builtin/ls-remote.c:76
-msgid "show underlying ref in addition to the object pointed by it"
-msgstr "除了显示指向的对象外，显示指向的引用名"
+#: builtin/mv.c:103
+#, c-format
+msgid "%.*s is in index"
+msgstr "%.*s 在索引中"
 
-#: builtin/ls-tree.c:29
-msgid "git ls-tree [<options>] <tree-ish> [<path>...]"
-msgstr "git ls-tree [<选项>] <树或提交> [<路径>...]"
+#: builtin/mv.c:125
+msgid "force move/rename even if target exists"
+msgstr "强制移动/重命令，即使目标存在"
 
-#: builtin/ls-tree.c:127
-msgid "only show trees"
-msgstr "只显示树"
+#: builtin/mv.c:127
+msgid "skip move/rename errors"
+msgstr "跳过移动/重命名错误"
 
-#: builtin/ls-tree.c:129
-msgid "recurse into subtrees"
-msgstr "递归到子树"
+#: builtin/mv.c:169
+#, c-format
+msgid "destination '%s' is not a directory"
+msgstr "目标 '%s' 不是一个目录"
+
+#: builtin/mv.c:180
+#, c-format
+msgid "Checking rename of '%s' to '%s'\n"
+msgstr "检查 '%s' 到 '%s' 的重命名\n"
 
-#: builtin/ls-tree.c:131
-msgid "show trees when recursing"
-msgstr "当递归时显示树"
+#: builtin/mv.c:184
+msgid "bad source"
+msgstr "坏的源"
 
-#: builtin/ls-tree.c:134
-msgid "terminate entries with NUL byte"
-msgstr "条目以 NUL 字符终止"
+#: builtin/mv.c:187
+msgid "can not move directory into itself"
+msgstr "不能将目录移动到自身"
 
-#: builtin/ls-tree.c:135
-msgid "include object size"
-msgstr "包括对象大小"
+#: builtin/mv.c:190
+msgid "cannot move directory over file"
+msgstr "不能将目录移动到文件"
 
-#: builtin/ls-tree.c:137 builtin/ls-tree.c:139
-msgid "list only filenames"
-msgstr "只列出文件名"
+#: builtin/mv.c:199
+msgid "source directory is empty"
+msgstr "源目录为空"
 
-#: builtin/ls-tree.c:142
-msgid "use full path names"
-msgstr "使用文件的全路径"
+#: builtin/mv.c:224
+msgid "not under version control"
+msgstr "不在版本控制之下"
 
-#: builtin/ls-tree.c:144
-msgid "list entire tree; not just current directory (implies --full-name)"
-msgstr "列出整个树；不仅仅当前目录（隐含 --full-name）"
+#: builtin/mv.c:227
+msgid "destination exists"
+msgstr "目标已存在"
 
-#: builtin/mailsplit.c:241
+#: builtin/mv.c:235
 #, c-format
-msgid "empty mbox: '%s'"
-msgstr "空的 mbox：'%s'"
-
-#: builtin/merge.c:51
-msgid "git merge [<options>] [<commit>...]"
-msgstr "git merge [<选项>] [<提交>...]"
+msgid "overwriting '%s'"
+msgstr "覆盖 '%s'"
 
-#: builtin/merge.c:52
-msgid "git merge --abort"
-msgstr "git merge --abort"
+#: builtin/mv.c:238
+msgid "Cannot overwrite"
+msgstr "不能覆盖"
 
-#: builtin/merge.c:53
-msgid "git merge --continue"
-msgstr "git merge --continue"
+#: builtin/mv.c:241
+msgid "multiple sources for the same target"
+msgstr "同一目标具有多个源"
 
-#: builtin/merge.c:110
-msgid "switch `m' requires a value"
-msgstr "开关 `m' 需要一个值"
+#: builtin/mv.c:243
+msgid "destination directory does not exist"
+msgstr "目标目录不存在"
 
-#: builtin/merge.c:147
+#: builtin/mv.c:250
 #, c-format
-msgid "Could not find merge strategy '%s'.\n"
-msgstr "不能找到合并策略 '%s'。\n"
+msgid "%s, source=%s, destination=%s"
+msgstr "%s，源=%s，目标=%s"
 
-#: builtin/merge.c:148
+#: builtin/mv.c:271
 #, c-format
-msgid "Available strategies are:"
-msgstr "可用的策略有："
+msgid "Renaming %s to %s\n"
+msgstr "重命名 %s 至 %s\n"
 
-#: builtin/merge.c:153
+#: builtin/mv.c:277 builtin/remote.c:716 builtin/repack.c:518
 #, c-format
-msgid "Available custom strategies are:"
-msgstr "可用的自定义策略有："
+msgid "renaming '%s' failed"
+msgstr "重命名 '%s' 失败"
 
-#: builtin/merge.c:203 builtin/pull.c:142
-msgid "do not show a diffstat at the end of the merge"
-msgstr "在合并的最后不显示差异统计"
+#: builtin/name-rev.c:403
+msgid "git name-rev [<options>] <commit>..."
+msgstr "git name-rev [<选项>] <提交>..."
 
-#: builtin/merge.c:206 builtin/pull.c:145
-msgid "show a diffstat at the end of the merge"
-msgstr "在合并的最后显示差异统计"
+#: builtin/name-rev.c:404
+msgid "git name-rev [<options>] --all"
+msgstr "git name-rev [<选项>] --all"
 
-#: builtin/merge.c:207 builtin/pull.c:148
-msgid "(synonym to --stat)"
-msgstr "（和 --stat 同义）"
+#: builtin/name-rev.c:405
+msgid "git name-rev [<options>] --stdin"
+msgstr "git name-rev [<选项>] --stdin"
 
-#: builtin/merge.c:209 builtin/pull.c:151
-msgid "add (at most <n>) entries from shortlog to merge commit message"
-msgstr "在合并提交信息中添加（最多 <n> 条）精简提交记录"
+#: builtin/name-rev.c:462
+msgid "print only names (no SHA-1)"
+msgstr "只打印名称（无 SHA-1）"
 
-#: builtin/merge.c:212 builtin/pull.c:157
-msgid "create a single commit instead of doing a merge"
-msgstr "创建一个单独的提交而不是做一次合并"
+#: builtin/name-rev.c:463
+msgid "only use tags to name the commits"
+msgstr "只使用标签来命名提交"
 
-#: builtin/merge.c:214 builtin/pull.c:160
-msgid "perform a commit if the merge succeeds (default)"
-msgstr "如果合并成功，执行一次提交（默认）"
+#: builtin/name-rev.c:465
+msgid "only use refs matching <pattern>"
+msgstr "只使用和 <模式> 相匹配的引用"
 
-#: builtin/merge.c:216 builtin/pull.c:163
-msgid "edit message before committing"
-msgstr "在提交前编辑提交说明"
+#: builtin/name-rev.c:467
+msgid "ignore refs matching <pattern>"
+msgstr "忽略和 <模式> 相匹配的引用"
 
-#: builtin/merge.c:217
-msgid "allow fast-forward (default)"
-msgstr "允许快进（默认）"
+#: builtin/name-rev.c:469
+msgid "list all commits reachable from all refs"
+msgstr "列出可以从所有引用访问的提交"
 
-#: builtin/merge.c:219 builtin/pull.c:169
-msgid "abort if fast-forward is not possible"
-msgstr "如果不能快进就放弃合并"
+#: builtin/name-rev.c:470
+msgid "read from stdin"
+msgstr "从标准输入读取"
 
-#: builtin/merge.c:223 builtin/pull.c:172
-msgid "verify that the named commit has a valid GPG signature"
-msgstr "验证指定的提交是否包含一个有效的 GPG 签名"
+#: builtin/name-rev.c:471
+msgid "allow to print `undefined` names (default)"
+msgstr "允许打印 `未定义` 的名称（默认）"
 
-#: builtin/merge.c:224 builtin/notes.c:777 builtin/pull.c:176
-#: builtin/revert.c:109
-msgid "strategy"
-msgstr "策略"
+#: builtin/name-rev.c:477
+msgid "dereference tags in the input (internal use)"
+msgstr "反向解析输入中的标签（内部使用）"
 
-#: builtin/merge.c:225 builtin/pull.c:177
-msgid "merge strategy to use"
-msgstr "要使用的合并策略"
+#: builtin/notes.c:28
+msgid "git notes [--ref <notes-ref>] [list [<object>]]"
+msgstr "git notes [--ref <注解引用>] [list [<对象>]]"
 
-#: builtin/merge.c:226 builtin/pull.c:180
-msgid "option=value"
-msgstr "option=value"
+#: builtin/notes.c:29
+msgid ""
+"git notes [--ref <notes-ref>] add [-f] [--allow-empty] [-m <msg> | -F <file> "
+"| (-c | -C) <object>] [<object>]"
+msgstr ""
+"git notes [--ref <注解引用>] add [-f] [--allow-empty] [-m <说明> | -F <文件> "
+"| (-c | -C) <对象>] [<对象>]"
 
-#: builtin/merge.c:227 builtin/pull.c:181
-msgid "option for selected merge strategy"
-msgstr "所选的合并策略的选项"
+#: builtin/notes.c:30
+msgid "git notes [--ref <notes-ref>] copy [-f] <from-object> <to-object>"
+msgstr "git notes [--ref <注解引用>] copy [-f] <源对象> <目标对象>"
 
-#: builtin/merge.c:229
-msgid "merge commit message (for a non-fast-forward merge)"
-msgstr "合并的提交说明（针对非快进式合并）"
+#: builtin/notes.c:31
+msgid ""
+"git notes [--ref <notes-ref>] append [--allow-empty] [-m <msg> | -F <file> | "
+"(-c | -C) <object>] [<object>]"
+msgstr ""
+"git notes [--ref <注解引用>] append [--allow-empty] [-m <说明> | -F <文件> | "
+"(-c | -C) <对象>] [<对象>]"
 
-#: builtin/merge.c:233
-msgid "abort the current in-progress merge"
-msgstr "放弃当前正在进行的合并"
+#: builtin/notes.c:32
+msgid "git notes [--ref <notes-ref>] edit [--allow-empty] [<object>]"
+msgstr "git notes [--ref <注解引用>] edit [--allow-empty] [<对象>]"
 
-#: builtin/merge.c:235
-msgid "continue the current in-progress merge"
-msgstr "继续当前正在进行的合并"
+#: builtin/notes.c:33
+msgid "git notes [--ref <notes-ref>] show [<object>]"
+msgstr "git notes [--ref <注解引用>] show [<对象>]"
 
-#: builtin/merge.c:237 builtin/pull.c:188
-msgid "allow merging unrelated histories"
-msgstr "允许合并不相关的历史"
+#: builtin/notes.c:34
+msgid ""
+"git notes [--ref <notes-ref>] merge [-v | -q] [-s <strategy>] <notes-ref>"
+msgstr "git notes [--ref <注解引用>] merge [-v | -q] [-s <策略> ] <注解引用>"
 
-#: builtin/merge.c:243
-msgid "verify commit-msg hook"
-msgstr "校验 commit-msg 钩子"
+#: builtin/notes.c:35
+msgid "git notes merge --commit [-v | -q]"
+msgstr "git notes merge --commit [-v | -q]"
 
-#: builtin/merge.c:268
-msgid "could not run stash."
-msgstr "不能运行贮藏。"
+#: builtin/notes.c:36
+msgid "git notes merge --abort [-v | -q]"
+msgstr "git notes merge --abort [-v | -q]"
 
-#: builtin/merge.c:273
-msgid "stash failed"
-msgstr "贮藏失败"
+#: builtin/notes.c:37
+msgid "git notes [--ref <notes-ref>] remove [<object>...]"
+msgstr "git notes [--ref <注解引用>] remove [<对象>...]"
 
-#: builtin/merge.c:278
-#, c-format
-msgid "not a valid object: %s"
-msgstr "不是一个有效对象：%s"
+#: builtin/notes.c:38
+msgid "git notes [--ref <notes-ref>] prune [-n] [-v]"
+msgstr "git notes [--ref <注解引用>] prune [-n] [-v]"
 
-#: builtin/merge.c:300 builtin/merge.c:317
-msgid "read-tree failed"
-msgstr "读取树失败"
+#: builtin/notes.c:39
+msgid "git notes [--ref <notes-ref>] get-ref"
+msgstr "git notes [--ref <注解引用>] get-ref"
 
-#  译者：注意保持前导空格
-#: builtin/merge.c:347
-msgid " (nothing to squash)"
-msgstr " （无可压缩）"
+#: builtin/notes.c:44
+msgid "git notes [list [<object>]]"
+msgstr "git notes [list [<对象>]]"
 
-#: builtin/merge.c:358
-#, c-format
-msgid "Squash commit -- not updating HEAD\n"
-msgstr "压缩提交 -- 未更新 HEAD\n"
+#: builtin/notes.c:49
+msgid "git notes add [<options>] [<object>]"
+msgstr "git notes add [<选项>] [<对象>]"
 
-#: builtin/merge.c:408
-#, c-format
-msgid "No merge message -- not updating HEAD\n"
-msgstr "无合并信息 -- 未更新 HEAD\n"
+#: builtin/notes.c:54
+msgid "git notes copy [<options>] <from-object> <to-object>"
+msgstr "git notes copy [<选项>] <源对象> <目标对象>"
 
-#: builtin/merge.c:458
-#, c-format
-msgid "'%s' does not point to a commit"
-msgstr "'%s' 没有指向一个提交"
+#: builtin/notes.c:55
+msgid "git notes copy --stdin [<from-object> <to-object>]..."
+msgstr "git notes copy --stdin [<源对象> <目标对象>]..."
 
-#: builtin/merge.c:548
-#, c-format
-msgid "Bad branch.%s.mergeoptions string: %s"
-msgstr "坏的 branch.%s.mergeoptions 字符串：%s"
+#: builtin/notes.c:60
+msgid "git notes append [<options>] [<object>]"
+msgstr "git notes append [<选项>] [<对象>]"
 
-#: builtin/merge.c:669
-msgid "Not handling anything other than two heads merge."
-msgstr "未处理两个头合并之外的任何操作。"
+#: builtin/notes.c:65
+msgid "git notes edit [<object>]"
+msgstr "git notes edit [<对象>]"
 
-#: builtin/merge.c:683
-#, c-format
-msgid "Unknown option for merge-recursive: -X%s"
-msgstr "merge-recursive 的未知选项：-X%s"
+#: builtin/notes.c:70
+msgid "git notes show [<object>]"
+msgstr "git notes show [<对象>]"
 
-#: builtin/merge.c:698
-#, c-format
-msgid "unable to write %s"
-msgstr "不能写 %s"
+#: builtin/notes.c:75
+msgid "git notes merge [<options>] <notes-ref>"
+msgstr "git notes merge [<选项>] <注解引用>"
 
-#: builtin/merge.c:749
-#, c-format
-msgid "Could not read from '%s'"
-msgstr "不能从 '%s' 读取"
+#: builtin/notes.c:76
+msgid "git notes merge --commit [<options>]"
+msgstr "git notes merge --commit [<选项>]"
 
-#: builtin/merge.c:758
-#, c-format
-msgid "Not committing merge; use 'git commit' to complete the merge.\n"
-msgstr "未提交合并，使用 'git commit' 完成此次合并。\n"
+#: builtin/notes.c:77
+msgid "git notes merge --abort [<options>]"
+msgstr "git notes merge --abort [<选项>]"
 
-#: builtin/merge.c:764
-#, c-format
-msgid ""
-"Please enter a commit message to explain why this merge is necessary,\n"
-"especially if it merges an updated upstream into a topic branch.\n"
-"\n"
-"Lines starting with '%c' will be ignored, and an empty message aborts\n"
-"the commit.\n"
-msgstr ""
-"请输入一个提交信息以解释此合并的必要性，尤其是将一个更新后的上游分支\n"
-"合并到主题分支。\n"
-"\n"
-"以 '%c' 开头的行将被忽略，而且空提交说明将会终止提交。\n"
+#: builtin/notes.c:82
+msgid "git notes remove [<object>]"
+msgstr "git notes remove [<对象>]"
 
-#: builtin/merge.c:800
-msgid "Empty commit message."
-msgstr "空提交信息。"
+#: builtin/notes.c:87
+msgid "git notes prune [<options>]"
+msgstr "git notes prune [<选项>]"
 
-#: builtin/merge.c:819
-#, c-format
-msgid "Wonderful.\n"
-msgstr "太棒了。\n"
+#: builtin/notes.c:92
+msgid "git notes get-ref"
+msgstr "git notes get-ref"
 
-#: builtin/merge.c:872
+#: builtin/notes.c:97
+msgid "Write/edit the notes for the following object:"
+msgstr "为下面的对象写/编辑说明："
+
+#: builtin/notes.c:150
 #, c-format
-msgid "Automatic merge failed; fix conflicts and then commit the result.\n"
-msgstr "自动合并失败，修正冲突然后提交修正的结果。\n"
+msgid "unable to start 'show' for object '%s'"
+msgstr "不能为对象 '%s' 开始 'show'"
 
-#: builtin/merge.c:911
-msgid "No current branch."
-msgstr "没有当前分支。"
+#: builtin/notes.c:154
+msgid "could not read 'show' output"
+msgstr "不能读取 'show' 的输出"
+
+#: builtin/notes.c:162
+#, c-format
+msgid "failed to finish 'show' for object '%s'"
+msgstr "无法为对象 '%s' 完成 'show'"
 
-#: builtin/merge.c:913
-msgid "No remote for the current branch."
-msgstr "当前分支没有对应的远程仓库。"
+#: builtin/notes.c:197
+msgid "please supply the note contents using either -m or -F option"
+msgstr "请通过 -m 或 -F 选项为注解提供内容"
 
-#: builtin/merge.c:915
-msgid "No default upstream defined for the current branch."
-msgstr "当前分支没有定义默认的上游分支。"
+#: builtin/notes.c:206
+msgid "unable to write note object"
+msgstr "不能写注解对象"
 
-#: builtin/merge.c:920
+#: builtin/notes.c:208
 #, c-format
-msgid "No remote-tracking branch for %s from %s"
-msgstr "对于 %s 没有来自 %s 的远程跟踪分支"
+msgid "the note contents have been left in %s"
+msgstr "注解内容被留在 %s 中"
 
-#: builtin/merge.c:973
+#: builtin/notes.c:242 builtin/tag.c:532
 #, c-format
-msgid "Bad value '%s' in environment '%s'"
-msgstr "环境 '%2$s' 中存在坏的取值 '%1$s'"
+msgid "could not open or read '%s'"
+msgstr "不能打开或读取 '%s'"
 
-#: builtin/merge.c:1075
+#: builtin/notes.c:263 builtin/notes.c:313 builtin/notes.c:315
+#: builtin/notes.c:383 builtin/notes.c:438 builtin/notes.c:526
+#: builtin/notes.c:531 builtin/notes.c:610 builtin/notes.c:672
 #, c-format
-msgid "not something we can merge in %s: %s"
-msgstr "不能在 %s 中合并：%s"
-
-#: builtin/merge.c:1109
-msgid "not something we can merge"
-msgstr "不能合并"
+msgid "failed to resolve '%s' as a valid ref."
+msgstr "无法解析 '%s' 为一个有效引用。"
 
-#: builtin/merge.c:1211
-msgid "--abort expects no arguments"
-msgstr "--abort 不带参数"
+#: builtin/notes.c:265
+#, c-format
+msgid "failed to read object '%s'."
+msgstr "读取对象 '%s' 失败。"
 
-#: builtin/merge.c:1215
-msgid "There is no merge to abort (MERGE_HEAD missing)."
-msgstr "没有要终止的合并（MERGE_HEAD 丢失）。"
+#: builtin/notes.c:268
+#, c-format
+msgid "cannot read note data from non-blob object '%s'."
+msgstr "不能从非数据对象 '%s' 中读取注解数据。"
 
-#: builtin/merge.c:1227
-msgid "--continue expects no arguments"
-msgstr "--continue 不带参数"
+#: builtin/notes.c:309
+#, c-format
+msgid "malformed input line: '%s'."
+msgstr "格式错误的输入行：'%s'。"
 
-#: builtin/merge.c:1231
-msgid "There is no merge in progress (MERGE_HEAD missing)."
-msgstr "没有进行中的合并（MERGE_HEAD 丢失）。"
+#: builtin/notes.c:324
+#, c-format
+msgid "failed to copy notes from '%s' to '%s'"
+msgstr "从 '%s' 拷贝注解到 '%s' 时失败"
 
-#: builtin/merge.c:1247
-msgid ""
-"You have not concluded your merge (MERGE_HEAD exists).\n"
-"Please, commit your changes before you merge."
-msgstr ""
-"您尚未结束您的合并（存在 MERGE_HEAD）。\n"
-"请在合并前先提交您的修改。"
+#. TRANSLATORS: the first %s will be replaced by a git
+#. notes command: 'add', 'merge', 'remove', etc.
+#.
+#: builtin/notes.c:356
+#, c-format
+msgid "refusing to %s notes in %s (outside of refs/notes/)"
+msgstr "拒绝向 %2$s（在 refs/notes/ 之外）%1$s注解"
 
-#: builtin/merge.c:1254
-msgid ""
-"You have not concluded your cherry-pick (CHERRY_PICK_HEAD exists).\n"
-"Please, commit your changes before you merge."
-msgstr ""
-"您尚未结束您的拣选（存在 CHERRY_PICK_HEAD）。\n"
-"请在合并前先提交您的修改。"
+#: builtin/notes.c:376 builtin/notes.c:431 builtin/notes.c:509
+#: builtin/notes.c:521 builtin/notes.c:598 builtin/notes.c:665
+#: builtin/notes.c:815 builtin/notes.c:963 builtin/notes.c:985
+msgid "too many parameters"
+msgstr "参数太多"
 
-#: builtin/merge.c:1257
-msgid "You have not concluded your cherry-pick (CHERRY_PICK_HEAD exists)."
-msgstr "您尚未结束您的拣选（存在 CHERRY_PICK_HEAD）。"
+#: builtin/notes.c:389 builtin/notes.c:678
+#, c-format
+msgid "no note found for object %s."
+msgstr "未发现对象 %s 的注解。"
 
-#: builtin/merge.c:1266
-msgid "You cannot combine --squash with --no-ff."
-msgstr "您不能将 --squash 与 --no-ff 同时使用。"
+#: builtin/notes.c:410 builtin/notes.c:576
+msgid "note contents as a string"
+msgstr "注解内容作为一个字符串"
 
-#: builtin/merge.c:1274
-msgid "No commit specified and merge.defaultToUpstream not set."
-msgstr "未指定提交并且 merge.defaultToUpstream 未设置。"
+#: builtin/notes.c:413 builtin/notes.c:579
+msgid "note contents in a file"
+msgstr "注解内容到一个文件中"
 
-#: builtin/merge.c:1291
-msgid "Squash commit into empty head not supported yet"
-msgstr "尚不支持到空分支的压缩提交"
+#: builtin/notes.c:416 builtin/notes.c:582
+msgid "reuse and edit specified note object"
+msgstr "重用和编辑指定的注解对象"
 
-#: builtin/merge.c:1293
-msgid "Non-fast-forward commit does not make sense into an empty head"
-msgstr "到空分支的非快进式提交没有意义"
+#: builtin/notes.c:419 builtin/notes.c:585
+msgid "reuse specified note object"
+msgstr "重用指定的注解对象"
 
-#: builtin/merge.c:1298
-#, c-format
-msgid "%s - not something we can merge"
-msgstr "%s - 不能被合并"
+#: builtin/notes.c:422 builtin/notes.c:588
+msgid "allow storing empty note"
+msgstr "允许保存空白注释"
 
-#: builtin/merge.c:1300
-msgid "Can merge only exactly one commit into empty head"
-msgstr "只能将一个提交合并到空分支上"
+#: builtin/notes.c:423 builtin/notes.c:496
+msgid "replace existing notes"
+msgstr "替换已存在的注解"
 
-#: builtin/merge.c:1334
+#: builtin/notes.c:448
 #, c-format
-msgid "Commit %s has an untrusted GPG signature, allegedly by %s."
-msgstr "提交 %s 有一个非可信的声称来自 %s 的 GPG 签名。"
+msgid ""
+"Cannot add notes. Found existing notes for object %s. Use '-f' to overwrite "
+"existing notes"
+msgstr "不能添加注解。发现对象 %s 已存在注解。使用 '-f' 覆盖现存注解"
 
-#: builtin/merge.c:1337
+#: builtin/notes.c:463 builtin/notes.c:544
 #, c-format
-msgid "Commit %s has a bad GPG signature allegedly by %s."
-msgstr "提交 %s 有一个错误的声称来自 %s 的 GPG 签名。"
+msgid "Overwriting existing notes for object %s\n"
+msgstr "覆盖对象 %s 现存注解\n"
 
-#: builtin/merge.c:1340
+#: builtin/notes.c:475 builtin/notes.c:637 builtin/notes.c:902
 #, c-format
-msgid "Commit %s does not have a GPG signature."
-msgstr "提交 %s 没有一个 GPG 签名。"
+msgid "Removing note for object %s\n"
+msgstr "删除对象 %s 的注解\n"
 
-#: builtin/merge.c:1343
-#, c-format
-msgid "Commit %s has a good GPG signature by %s\n"
-msgstr "提交 %s 有一个来自 %s 的好的 GPG 签名。\n"
+#: builtin/notes.c:497
+msgid "read objects from stdin"
+msgstr "从标准输入读取对象"
 
-#: builtin/merge.c:1402
-msgid "refusing to merge unrelated histories"
-msgstr "拒绝合并无关的历史"
+#: builtin/notes.c:499
+msgid "load rewriting config for <command> (implies --stdin)"
+msgstr "重新加载 <命令> 的配置（隐含 --stdin）"
 
-#: builtin/merge.c:1411
-msgid "Already up to date."
-msgstr "已经是最新的。"
+#: builtin/notes.c:517
+msgid "too few parameters"
+msgstr "参数太少"
 
-#: builtin/merge.c:1421
+#: builtin/notes.c:538
 #, c-format
-msgid "Updating %s..%s\n"
-msgstr "更新 %s..%s\n"
+msgid ""
+"Cannot copy notes. Found existing notes for object %s. Use '-f' to overwrite "
+"existing notes"
+msgstr "不能拷贝注解。发现对象 %s 已存在注解。使用 '-f' 覆盖现存注解"
 
-#: builtin/merge.c:1462
+#: builtin/notes.c:550
 #, c-format
-msgid "Trying really trivial in-index merge...\n"
-msgstr "尝试非常小的索引内合并...\n"
+msgid "missing notes on source object %s. Cannot copy."
+msgstr "源对象 %s 缺少注解。不能拷贝。"
 
-#: builtin/merge.c:1469
+#: builtin/notes.c:603
 #, c-format
-msgid "Nope.\n"
-msgstr "无。\n"
+msgid ""
+"The -m/-F/-c/-C options have been deprecated for the 'edit' subcommand.\n"
+"Please use 'git notes add -f -m/-F/-c/-C' instead.\n"
+msgstr ""
+"子命令 'edit' 的选项 -m/-F/-c/-C 已弃用。\n"
+"请换用 'git notes add -f -m/-F/-c/-C'。\n"
 
-#: builtin/merge.c:1494
-msgid "Already up to date. Yeeah!"
-msgstr "已经是最新的。耶！"
+#: builtin/notes.c:698
+msgid "failed to delete ref NOTES_MERGE_PARTIAL"
+msgstr "删除引用 NOTES_MERGE_PARTIAL 失败"
 
-#: builtin/merge.c:1500
-msgid "Not possible to fast-forward, aborting."
-msgstr "无法快进，终止。"
+#: builtin/notes.c:700
+msgid "failed to delete ref NOTES_MERGE_REF"
+msgstr "删除引用 NOTES_MERGE_REF 失败"
 
-#: builtin/merge.c:1523 builtin/merge.c:1602
-#, c-format
-msgid "Rewinding the tree to pristine...\n"
-msgstr "将树回滚至原始状态...\n"
+#: builtin/notes.c:702
+msgid "failed to remove 'git notes merge' worktree"
+msgstr "删除 'git notes merge' 工作区失败"
 
-#: builtin/merge.c:1527
-#, c-format
-msgid "Trying merge strategy %s...\n"
-msgstr "尝试合并策略 %s...\n"
+#: builtin/notes.c:722
+msgid "failed to read ref NOTES_MERGE_PARTIAL"
+msgstr "读取引用 NOTES_MERGE_PARTIAL 失败"
 
-#: builtin/merge.c:1593
-#, c-format
-msgid "No merge strategy handled the merge.\n"
-msgstr "没有合并策略处理此合并。\n"
+#: builtin/notes.c:724
+msgid "could not find commit from NOTES_MERGE_PARTIAL."
+msgstr "无法从 NOTES_MERGE_PARTIAL 中找到提交。"
 
-#: builtin/merge.c:1595
-#, c-format
-msgid "Merge with strategy %s failed.\n"
-msgstr "使用策略 %s 合并失败。\n"
+#: builtin/notes.c:726
+msgid "could not parse commit from NOTES_MERGE_PARTIAL."
+msgstr "无法从 NOTES_MERGE_PARTIAL 中解析提交。"
 
-#: builtin/merge.c:1604
-#, c-format
-msgid "Using the %s to prepare resolving by hand.\n"
-msgstr "使用 %s 以准备手工解决。\n"
+#: builtin/notes.c:739
+msgid "failed to resolve NOTES_MERGE_REF"
+msgstr "解析 NOTES_MERGE_REF 失败"
+
+#: builtin/notes.c:742
+msgid "failed to finalize notes merge"
+msgstr "无法完成注解合并"
 
-#: builtin/merge.c:1616
+#: builtin/notes.c:768
 #, c-format
-msgid "Automatic merge went well; stopped before committing as requested\n"
-msgstr "自动合并进展顺利，按要求在提交前停止\n"
+msgid "unknown notes merge strategy %s"
+msgstr "未知的注解合并策略 %s"
 
-#: builtin/merge-base.c:30
-msgid "git merge-base [-a | --all] <commit> <commit>..."
-msgstr "git merge-base [-a | --all] <提交> <提交>..."
+#: builtin/notes.c:784
+msgid "General options"
+msgstr "通用选项"
 
-#: builtin/merge-base.c:31
-msgid "git merge-base [-a | --all] --octopus <commit>..."
-msgstr "git merge-base [-a | --all] --octopus <提交>..."
+#: builtin/notes.c:786
+msgid "Merge options"
+msgstr "合并选项"
 
-#: builtin/merge-base.c:32
-msgid "git merge-base --independent <commit>..."
-msgstr "git merge-base --independent <提交>..."
+#: builtin/notes.c:788
+msgid ""
+"resolve notes conflicts using the given strategy (manual/ours/theirs/union/"
+"cat_sort_uniq)"
+msgstr "使用指定的策略解决注解冲突 (manual/ours/theirs/union/cat_sort_uniq)"
 
-#: builtin/merge-base.c:33
-msgid "git merge-base --is-ancestor <commit> <commit>"
-msgstr "git merge-base --is-ancestor <提交> <提交>"
+#: builtin/notes.c:790
+msgid "Committing unmerged notes"
+msgstr "提交未合并的注解"
 
-#: builtin/merge-base.c:34
-msgid "git merge-base --fork-point <ref> [<commit>]"
-msgstr "git merge-base --fork-point <引用> [<提交>]"
+#: builtin/notes.c:792
+msgid "finalize notes merge by committing unmerged notes"
+msgstr "通过提交未合并的注解来完成注解合并"
 
-#: builtin/merge-base.c:220
-msgid "output all common ancestors"
-msgstr "输出所有共同的祖先"
+#: builtin/notes.c:794
+msgid "Aborting notes merge resolution"
+msgstr "中止注解合并的方案"
 
-#: builtin/merge-base.c:222
-msgid "find ancestors for a single n-way merge"
-msgstr "查找一个多路合并的祖先提交"
+#: builtin/notes.c:796
+msgid "abort notes merge"
+msgstr "中止注解合并"
 
-#: builtin/merge-base.c:224
-msgid "list revs not reachable from others"
-msgstr "显示不能被其他访问到的版本"
+#: builtin/notes.c:807
+msgid "cannot mix --commit, --abort or -s/--strategy"
+msgstr "不能混用 --commit、--abort 或 -s/--strategy"
 
-#: builtin/merge-base.c:226
-msgid "is the first one ancestor of the other?"
-msgstr "第一个是其他的祖先提交么？"
+#: builtin/notes.c:812
+msgid "must specify a notes ref to merge"
+msgstr "必须指定一个注解引用来合并"
 
-#: builtin/merge-base.c:228
-msgid "find where <commit> forked from reflog of <ref>"
-msgstr "根据 <引用> 的引用日志查找 <提交> 的派生处"
+#: builtin/notes.c:836
+#, c-format
+msgid "unknown -s/--strategy: %s"
+msgstr "未知的 -s/--strategy：%s"
 
-#: builtin/merge-file.c:9
+#: builtin/notes.c:873
+#, c-format
+msgid "a notes merge into %s is already in-progress at %s"
+msgstr "位于 %2$s 的一个到 %1$s 中的注解合并正在执行中"
+
+#: builtin/notes.c:876
+#, c-format
+msgid "failed to store link to current notes ref (%s)"
+msgstr "无法存储链接到当前的注解引用（%s）"
+
+#: builtin/notes.c:878
+#, c-format
 msgid ""
-"git merge-file [<options>] [-L <name1> [-L <orig> [-L <name2>]]] <file1> "
-"<orig-file> <file2>"
+"Automatic notes merge failed. Fix conflicts in %s and commit the result with "
+"'git notes merge --commit', or abort the merge with 'git notes merge --"
+"abort'.\n"
 msgstr ""
-"git merge-file [<选项>] [-L <文件1> [-L <初始> [-L <名字2>]]] <文件1> <初始文"
-"件> <文件2>"
+"自动合并说明失败。修改 %s 中的冲突并且使用命令 'git notes merge --commit' 提"
+"交结果，或者使用命令 'git notes merge --abort' 终止合并。\n"
 
-#: builtin/merge-file.c:33
-msgid "send results to standard output"
-msgstr "将结果发送到标准输出"
+#: builtin/notes.c:897 builtin/tag.c:545
+#, c-format
+msgid "Failed to resolve '%s' as a valid ref."
+msgstr "无法解析 '%s' 为一个有效引用。"
 
-#: builtin/merge-file.c:34
-msgid "use a diff3 based merge"
-msgstr "使用基于 diff3 的合并"
+#: builtin/notes.c:900
+#, c-format
+msgid "Object %s has no note\n"
+msgstr "对象 %s 没有注解\n"
 
-#: builtin/merge-file.c:35
-msgid "for conflicts, use our version"
-msgstr "如果冲突，使用我们的版本"
+#: builtin/notes.c:912
+msgid "attempt to remove non-existent note is not an error"
+msgstr "尝试删除不存在的注解不是一个错误"
 
-#: builtin/merge-file.c:37
-msgid "for conflicts, use their version"
-msgstr "如果冲突，使用他们的版本"
+#: builtin/notes.c:915
+msgid "read object names from the standard input"
+msgstr "从标准输入读取对象名称"
 
-#: builtin/merge-file.c:39
-msgid "for conflicts, use a union version"
-msgstr "如果冲突，使用联合版本"
+#: builtin/notes.c:954 builtin/prune.c:130 builtin/worktree.c:164
+msgid "do not remove, show only"
+msgstr "不删除，只显示"
 
-#: builtin/merge-file.c:42
-msgid "for conflicts, use this marker size"
-msgstr "如果冲突，使用指定长度的标记"
+#: builtin/notes.c:955
+msgid "report pruned notes"
+msgstr "报告清除的注解"
 
-#: builtin/merge-file.c:43
-msgid "do not warn about conflicts"
-msgstr "不要警告冲突"
+#: builtin/notes.c:998
+msgid "notes-ref"
+msgstr "注解引用"
 
-#: builtin/merge-file.c:45
-msgid "set labels for file1/orig-file/file2"
-msgstr "为 文件1/初始文件/文件2 设置标签"
+#: builtin/notes.c:999
+msgid "use notes from <notes-ref>"
+msgstr "从 <注解引用> 使用注解"
 
-#: builtin/merge-recursive.c:45
+#: builtin/notes.c:1034 builtin/stash.c:1607
 #, c-format
-msgid "unknown option %s"
-msgstr "未知选项 %s"
+msgid "unknown subcommand: %s"
+msgstr "未知子命令：%s"
+
+#: builtin/pack-objects.c:52
+msgid ""
+"git pack-objects --stdout [<options>...] [< <ref-list> | < <object-list>]"
+msgstr "git pack-objects --stdout [<选项>...] [< <引用列表> | < <对象列表>]"
+
+#: builtin/pack-objects.c:53
+msgid ""
+"git pack-objects [<options>...] <base-name> [< <ref-list> | < <object-list>]"
+msgstr "git pack-objects [<选项>...] <前缀名称> [< <引用列表> | < <对象列表>]"
 
-#: builtin/merge-recursive.c:51
+#: builtin/pack-objects.c:428
 #, c-format
-msgid "could not parse object '%s'"
-msgstr "不能解析对象 '%s'"
+msgid "bad packed object CRC for %s"
+msgstr "%s 错的包对象 CRC"
 
-#: builtin/merge-recursive.c:55
+#: builtin/pack-objects.c:439
 #, c-format
-msgid "cannot handle more than %d base. Ignoring %s."
-msgid_plural "cannot handle more than %d bases. Ignoring %s."
-msgstr[0] "无法处理 %d 条以上的基线。忽略 %s。"
-msgstr[1] "无法处理 %d 条以上的基线。忽略 %s。"
+msgid "corrupt packed object for %s"
+msgstr "%s 损坏的包对象"
 
-#: builtin/merge-recursive.c:63
-msgid "not handling anything other than two heads merge."
-msgstr "不能处理两个头合并之外的任何操作。"
+#: builtin/pack-objects.c:570
+#, c-format
+msgid "recursive delta detected for object %s"
+msgstr "发现对象 %s 递归 delta"
 
-#: builtin/merge-recursive.c:69 builtin/merge-recursive.c:71
+#: builtin/pack-objects.c:781
 #, c-format
-msgid "could not resolve ref '%s'"
-msgstr "无法解析引用 '%s'"
+msgid "ordered %u objects, expected %<PRIu32>"
+msgstr "排序了 %u 个对象，预期 %<PRIu32> 个"
 
-#: builtin/merge-recursive.c:77
+#: builtin/pack-objects.c:794
 #, c-format
-msgid "Merging %s with %s\n"
-msgstr "合并 %s 和 %s\n"
+msgid "packfile is invalid: %s"
+msgstr "无效的包文件：%s"
 
-#: builtin/mktree.c:65
-msgid "git mktree [-z] [--missing] [--batch]"
-msgstr "git mktree [-z] [--missing] [--batch]"
+#: builtin/pack-objects.c:798
+#, c-format
+msgid "unable to open packfile for reuse: %s"
+msgstr "无法为重用打开包文件：%s"
 
-#: builtin/mktree.c:153
-msgid "input is NUL terminated"
-msgstr "输入以 NUL 字符终止"
+#: builtin/pack-objects.c:802
+msgid "unable to seek in reused packfile"
+msgstr "无法在重用的包文件中查找"
 
-#: builtin/mktree.c:154 builtin/write-tree.c:25
-msgid "allow missing objects"
-msgstr "允许丢失的对象"
+#: builtin/pack-objects.c:813
+msgid "unable to read from reused packfile"
+msgstr "无法读取索引文件"
 
-#: builtin/mktree.c:155
-msgid "allow creation of more than one tree"
-msgstr "允许创建一个以上的树"
+#: builtin/pack-objects.c:841
+msgid "disabling bitmap writing, packs are split due to pack.packSizeLimit"
+msgstr "禁用 bitmap 写入，因为 pack.packSizeLimit 设置使得包被切分为多个"
 
-#: builtin/mv.c:17
-msgid "git mv [<options>] <source>... <destination>"
-msgstr "git mv [<选项>] <源>... <目标>"
+#: builtin/pack-objects.c:854
+msgid "Writing objects"
+msgstr "写入对象中"
 
-#: builtin/mv.c:82
+#: builtin/pack-objects.c:917 builtin/update-index.c:90
 #, c-format
-msgid "Directory %s is in index and no submodule?"
-msgstr "目录 %s 在索引中并且不是子模组？"
-
-#: builtin/mv.c:84 builtin/rm.c:288
-msgid "Please stage your changes to .gitmodules or stash them to proceed"
-msgstr "请将您的修改暂存到 .gitmodules 中或贮藏后再继续"
+msgid "failed to stat %s"
+msgstr "对 %s 调用 stat 失败"
 
-#: builtin/mv.c:102
+#: builtin/pack-objects.c:970
 #, c-format
-msgid "%.*s is in index"
-msgstr "%.*s 在索引中"
-
-#: builtin/mv.c:124
-msgid "force move/rename even if target exists"
-msgstr "强制移动/重命令，即使目标存在"
+msgid "wrote %<PRIu32> objects while expecting %<PRIu32>"
+msgstr "写入 %<PRIu32> 个对象而预期 %<PRIu32> 个"
 
-#: builtin/mv.c:126
-msgid "skip move/rename errors"
-msgstr "跳过移动/重命名错误"
+#: builtin/pack-objects.c:1164
+msgid "disabling bitmap writing, as some objects are not being packed"
+msgstr "禁用 bitmap 写入，因为一些对象将不会被打包"
 
-#: builtin/mv.c:168
+#: builtin/pack-objects.c:1592
 #, c-format
-msgid "destination '%s' is not a directory"
-msgstr "目标 '%s' 不是一个目录"
+msgid "delta base offset overflow in pack for %s"
+msgstr "%s 压缩中 delta 基准偏移越界"
 
-#: builtin/mv.c:179
+#: builtin/pack-objects.c:1601
 #, c-format
-msgid "Checking rename of '%s' to '%s'\n"
-msgstr "检查 '%s' 到 '%s' 的重命名\n"
+msgid "delta base offset out of bound for %s"
+msgstr "%s 的 delta 基准偏移越界"
 
-#: builtin/mv.c:183
-msgid "bad source"
-msgstr "坏的源"
+#: builtin/pack-objects.c:1870
+msgid "Counting objects"
+msgstr "对象计数中"
 
-#: builtin/mv.c:186
-msgid "can not move directory into itself"
-msgstr "不能将目录移动到自身"
+#: builtin/pack-objects.c:2000
+#, c-format
+msgid "unable to get size of %s"
+msgstr "不能得到 %s 的大小"
 
-#: builtin/mv.c:189
-msgid "cannot move directory over file"
-msgstr "不能将目录移动到文件"
+#: builtin/pack-objects.c:2015
+#, c-format
+msgid "unable to parse object header of %s"
+msgstr "无法解析对象 %s 头信息"
 
-#: builtin/mv.c:198
-msgid "source directory is empty"
-msgstr "源目录为空"
+#: builtin/pack-objects.c:2085 builtin/pack-objects.c:2101
+#: builtin/pack-objects.c:2111
+#, c-format
+msgid "object %s cannot be read"
+msgstr "对象 %s 无法读取"
 
-#: builtin/mv.c:223
-msgid "not under version control"
-msgstr "不在版本控制之下"
+#: builtin/pack-objects.c:2088 builtin/pack-objects.c:2115
+#, c-format
+msgid "object %s inconsistent object length (%<PRIuMAX> vs %<PRIuMAX>)"
+msgstr "对象 %s 不一致的对象长度（%<PRIuMAX> vs %<PRIuMAX>）"
 
-#: builtin/mv.c:226
-msgid "destination exists"
-msgstr "目标已存在"
+#: builtin/pack-objects.c:2125
+msgid "suboptimal pack - out of memory"
+msgstr "次优（suboptimal）打包 - 内存不足"
 
-#: builtin/mv.c:234
+#: builtin/pack-objects.c:2440
 #, c-format
-msgid "overwriting '%s'"
-msgstr "覆盖 '%s'"
+msgid "Delta compression using up to %d threads"
+msgstr "使用 %d 个线程进行压缩"
 
-#: builtin/mv.c:237
-msgid "Cannot overwrite"
-msgstr "不能覆盖"
+#: builtin/pack-objects.c:2572
+#, c-format
+msgid "unable to pack objects reachable from tag %s"
+msgstr "无法为标签 %s 压缩对象"
 
-#: builtin/mv.c:240
-msgid "multiple sources for the same target"
-msgstr "同一目标具有多个源"
+#: builtin/pack-objects.c:2659
+msgid "Compressing objects"
+msgstr "压缩对象中"
 
-#: builtin/mv.c:242
-msgid "destination directory does not exist"
-msgstr "目标目录不存在"
+#: builtin/pack-objects.c:2665
+msgid "inconsistency with delta count"
+msgstr "不一致的差异计数"
 
-#: builtin/mv.c:249
+#: builtin/pack-objects.c:2742
 #, c-format
-msgid "%s, source=%s, destination=%s"
-msgstr "%s，源=%s，目标=%s"
+msgid ""
+"expected edge object ID, got garbage:\n"
+" %s"
+msgstr ""
+"预期边界对象（edge object）ID，却得到垃圾数据：\n"
+" %s"
 
-#: builtin/mv.c:270
+#: builtin/pack-objects.c:2748
 #, c-format
-msgid "Renaming %s to %s\n"
-msgstr "重命名 %s 至 %s\n"
+msgid ""
+"expected object ID, got garbage:\n"
+" %s"
+msgstr ""
+"预期对象 ID，却得到垃圾数据：\n"
+" %s"
 
-#: builtin/mv.c:276 builtin/remote.c:715 builtin/repack.c:409
-#, c-format
-msgid "renaming '%s' failed"
-msgstr "重命名 '%s' 失败"
+#: builtin/pack-objects.c:2846
+msgid "invalid value for --missing"
+msgstr "选项 --missing 的值无效"
 
-#: builtin/name-rev.c:338
-msgid "git name-rev [<options>] <commit>..."
-msgstr "git name-rev [<选项>] <提交>..."
+#: builtin/pack-objects.c:2905 builtin/pack-objects.c:3013
+msgid "cannot open pack index"
+msgstr "无法打开包文件索引"
 
-#: builtin/name-rev.c:339
-msgid "git name-rev [<options>] --all"
-msgstr "git name-rev [<选项>] --all"
+#: builtin/pack-objects.c:2936
+#, c-format
+msgid "loose object at %s could not be examined"
+msgstr "无法检查 %s 处的松散对象"
 
-#: builtin/name-rev.c:340
-msgid "git name-rev [<options>] --stdin"
-msgstr "git name-rev [<选项>] --stdin"
+#: builtin/pack-objects.c:3021
+msgid "unable to force loose object"
+msgstr "无法强制松散对象"
 
-#: builtin/name-rev.c:395
-msgid "print only names (no SHA-1)"
-msgstr "只打印名称（无 SHA-1）"
+#: builtin/pack-objects.c:3113
+#, c-format
+msgid "not a rev '%s'"
+msgstr "不是一个版本 '%s'"
 
-#: builtin/name-rev.c:396
-msgid "only use tags to name the commits"
-msgstr "只使用标签来命名提交"
+#: builtin/pack-objects.c:3116
+#, c-format
+msgid "bad revision '%s'"
+msgstr "坏的版本 '%s'"
 
-#: builtin/name-rev.c:398
-msgid "only use refs matching <pattern>"
-msgstr "只使用和 <模式> 相匹配的引用"
+#: builtin/pack-objects.c:3141
+msgid "unable to add recent objects"
+msgstr "无法添加最近的对象"
 
-#: builtin/name-rev.c:400
-msgid "ignore refs matching <pattern>"
-msgstr "忽略和 <模式> 相匹配的引用"
+#: builtin/pack-objects.c:3194
+#, c-format
+msgid "unsupported index version %s"
+msgstr "不支持的索引版本 %s"
 
-#: builtin/name-rev.c:402
-msgid "list all commits reachable from all refs"
-msgstr "列出可以从所有引用访问的提交"
+#: builtin/pack-objects.c:3198
+#, c-format
+msgid "bad index version '%s'"
+msgstr "坏的索引版本 '%s'"
 
-#: builtin/name-rev.c:403
-msgid "read from stdin"
-msgstr "从标准输入读取"
+#: builtin/pack-objects.c:3236
+msgid "<version>[,<offset>]"
+msgstr "<版本>[,<偏移>]"
 
-#: builtin/name-rev.c:404
-msgid "allow to print `undefined` names (default)"
-msgstr "允许打印 `未定义` 的名称（默认）"
+#: builtin/pack-objects.c:3237
+msgid "write the pack index file in the specified idx format version"
+msgstr "用指定的 idx 格式版本来写包索引文件"
 
-#: builtin/name-rev.c:410
-msgid "dereference tags in the input (internal use)"
-msgstr "反向解析输入中的标签（内部使用）"
+#: builtin/pack-objects.c:3240
+msgid "maximum size of each output pack file"
+msgstr "每个输出包的最大尺寸"
 
-#: builtin/notes.c:26
-msgid "git notes [--ref <notes-ref>] [list [<object>]]"
-msgstr "git notes [--ref <注解引用>] [list [<对象>]]"
+#: builtin/pack-objects.c:3242
+msgid "ignore borrowed objects from alternate object store"
+msgstr "忽略从备用对象存储里借用对象"
 
-#: builtin/notes.c:27
-msgid ""
-"git notes [--ref <notes-ref>] add [-f] [--allow-empty] [-m <msg> | -F <file> "
-"| (-c | -C) <object>] [<object>]"
-msgstr ""
-"git notes [--ref <注解引用>] add [-f] [--allow-empty] [-m <说明> | -F <文件> "
-"| (-c | -C) <对象>] [<对象>]"
+#: builtin/pack-objects.c:3244
+msgid "ignore packed objects"
+msgstr "忽略包对象"
 
-#: builtin/notes.c:28
-msgid "git notes [--ref <notes-ref>] copy [-f] <from-object> <to-object>"
-msgstr "git notes [--ref <注解引用>] copy [-f] <源对象> <目标对象>"
+#: builtin/pack-objects.c:3246
+msgid "limit pack window by objects"
+msgstr "限制打包窗口的对象数"
 
-#: builtin/notes.c:29
-msgid ""
-"git notes [--ref <notes-ref>] append [--allow-empty] [-m <msg> | -F <file> | "
-"(-c | -C) <object>] [<object>]"
-msgstr ""
-"git notes [--ref <注解引用>] append [--allow-empty] [-m <说明> | -F <文件> | "
-"(-c | -C) <对象>] [<对象>]"
+#: builtin/pack-objects.c:3248
+msgid "limit pack window by memory in addition to object limit"
+msgstr "除对象数量限制外设置打包窗口的内存限制"
 
-#: builtin/notes.c:30
-msgid "git notes [--ref <notes-ref>] edit [--allow-empty] [<object>]"
-msgstr "git notes [--ref <注解引用>] edit [--allow-empty] [<对象>]"
+#: builtin/pack-objects.c:3250
+msgid "maximum length of delta chain allowed in the resulting pack"
+msgstr "打包允许的 delta 链的最大长度"
 
-#: builtin/notes.c:31
-msgid "git notes [--ref <notes-ref>] show [<object>]"
-msgstr "git notes [--ref <注解引用>] show [<对象>]"
+#: builtin/pack-objects.c:3252
+msgid "reuse existing deltas"
+msgstr "重用已存在的 deltas"
 
-#: builtin/notes.c:32
-msgid ""
-"git notes [--ref <notes-ref>] merge [-v | -q] [-s <strategy>] <notes-ref>"
-msgstr "git notes [--ref <注解引用>] merge [-v | -q] [-s <策略> ] <注解引用>"
+#: builtin/pack-objects.c:3254
+msgid "reuse existing objects"
+msgstr "重用已存在的对象"
 
-#: builtin/notes.c:33
-msgid "git notes merge --commit [-v | -q]"
-msgstr "git notes merge --commit [-v | -q]"
+#: builtin/pack-objects.c:3256
+msgid "use OFS_DELTA objects"
+msgstr "使用 OFS_DELTA 对象"
 
-#: builtin/notes.c:34
-msgid "git notes merge --abort [-v | -q]"
-msgstr "git notes merge --abort [-v | -q]"
+#: builtin/pack-objects.c:3258
+msgid "use threads when searching for best delta matches"
+msgstr "使用线程查询最佳 delta 匹配"
 
-#: builtin/notes.c:35
-msgid "git notes [--ref <notes-ref>] remove [<object>...]"
-msgstr "git notes [--ref <注解引用>] remove [<对象>...]"
+#: builtin/pack-objects.c:3260
+msgid "do not create an empty pack output"
+msgstr "不创建空的包输出"
 
-#: builtin/notes.c:36
-msgid "git notes [--ref <notes-ref>] prune [-n] [-v]"
-msgstr "git notes [--ref <注解引用>] prune [-n] [-v]"
+#: builtin/pack-objects.c:3262
+msgid "read revision arguments from standard input"
+msgstr "从标准输入读取版本号参数"
 
-#: builtin/notes.c:37
-msgid "git notes [--ref <notes-ref>] get-ref"
-msgstr "git notes [--ref <注解引用>] get-ref"
+#: builtin/pack-objects.c:3264
+msgid "limit the objects to those that are not yet packed"
+msgstr "限制那些尚未打包的对象"
 
-#: builtin/notes.c:42
-msgid "git notes [list [<object>]]"
-msgstr "git notes [list [<对象>]]"
+#: builtin/pack-objects.c:3267
+msgid "include objects reachable from any reference"
+msgstr "包括可以从任何引用访问到的对象"
 
-#: builtin/notes.c:47
-msgid "git notes add [<options>] [<object>]"
-msgstr "git notes add [<选项>] [<对象>]"
+#: builtin/pack-objects.c:3270
+msgid "include objects referred by reflog entries"
+msgstr "包括被引用日志引用到的对象"
 
-#: builtin/notes.c:52
-msgid "git notes copy [<options>] <from-object> <to-object>"
-msgstr "git notes copy [<选项>] <源对象> <目标对象>"
+#: builtin/pack-objects.c:3273
+msgid "include objects referred to by the index"
+msgstr "包括被索引引用到的对象"
 
-#: builtin/notes.c:53
-msgid "git notes copy --stdin [<from-object> <to-object>]..."
-msgstr "git notes copy --stdin [<源对象> <目标对象>]..."
+#: builtin/pack-objects.c:3276
+msgid "output pack to stdout"
+msgstr "输出包到标准输出"
 
-#: builtin/notes.c:58
-msgid "git notes append [<options>] [<object>]"
-msgstr "git notes append [<选项>] [<对象>]"
+#: builtin/pack-objects.c:3278
+msgid "include tag objects that refer to objects to be packed"
+msgstr "包括那些引用了待打包对象的标签对象"
 
-#: builtin/notes.c:63
-msgid "git notes edit [<object>]"
-msgstr "git notes edit [<对象>]"
+#: builtin/pack-objects.c:3280
+msgid "keep unreachable objects"
+msgstr "维持不可达的对象"
 
-#: builtin/notes.c:68
-msgid "git notes show [<object>]"
-msgstr "git notes show [<对象>]"
+#: builtin/pack-objects.c:3282
+msgid "pack loose unreachable objects"
+msgstr "打包松散的不可达对象"
 
-#: builtin/notes.c:73
-msgid "git notes merge [<options>] <notes-ref>"
-msgstr "git notes merge [<选项>] <注解引用>"
+#: builtin/pack-objects.c:3284
+msgid "unpack unreachable objects newer than <time>"
+msgstr "将比给定 <时间> 新的无法访问的对象解包"
 
-#: builtin/notes.c:74
-msgid "git notes merge --commit [<options>]"
-msgstr "git notes merge --commit [<选项>]"
+#: builtin/pack-objects.c:3287
+msgid "use the sparse reachability algorithm"
+msgstr "使用稀疏可达性算法"
 
-#: builtin/notes.c:75
-msgid "git notes merge --abort [<options>]"
-msgstr "git notes merge --abort [<选项>]"
+#: builtin/pack-objects.c:3289
+msgid "create thin packs"
+msgstr "创建精简包"
 
-#: builtin/notes.c:80
-msgid "git notes remove [<object>]"
-msgstr "git notes remove [<对象>]"
+#: builtin/pack-objects.c:3291
+msgid "create packs suitable for shallow fetches"
+msgstr "创建适合浅克隆仓库获取的包"
 
-#: builtin/notes.c:85
-msgid "git notes prune [<options>]"
-msgstr "git notes prune [<选项>]"
+#: builtin/pack-objects.c:3293
+msgid "ignore packs that have companion .keep file"
+msgstr "忽略配有 .keep 文件的包"
 
-#: builtin/notes.c:90
-msgid "git notes get-ref"
-msgstr "git notes get-ref"
+#: builtin/pack-objects.c:3295
+msgid "ignore this pack"
+msgstr "忽略该 pack"
 
-#: builtin/notes.c:95
-msgid "Write/edit the notes for the following object:"
-msgstr "为下面的对象写/编辑说明："
+#: builtin/pack-objects.c:3297
+msgid "pack compression level"
+msgstr "打包压缩级别"
 
-#: builtin/notes.c:148
-#, c-format
-msgid "unable to start 'show' for object '%s'"
-msgstr "不能为对象 '%s' 开始 'show'"
+#: builtin/pack-objects.c:3299
+msgid "do not hide commits by grafts"
+msgstr "显示被移植隐藏的提交"
 
-#: builtin/notes.c:152
-msgid "could not read 'show' output"
-msgstr "不能读取 'show' 的输出"
+#: builtin/pack-objects.c:3301
+msgid "use a bitmap index if available to speed up counting objects"
+msgstr "使用 bitmap 索引（如果有的话）以提高对象计数时的速度"
 
-#: builtin/notes.c:160
-#, c-format
-msgid "failed to finish 'show' for object '%s'"
-msgstr "无法为对象 '%s' 完成 'show'"
+#: builtin/pack-objects.c:3303
+msgid "write a bitmap index together with the pack index"
+msgstr "在建立包索引的同时创建 bitmap 索引"
 
-#: builtin/notes.c:195
-msgid "please supply the note contents using either -m or -F option"
-msgstr "请通过 -m 或 -F 选项为注解提供内容"
+#: builtin/pack-objects.c:3307
+msgid "write a bitmap index if possible"
+msgstr "如果可能，写 bitmap 索引"
 
-#: builtin/notes.c:204
-msgid "unable to write note object"
-msgstr "不能写注解对象"
+#: builtin/pack-objects.c:3311
+msgid "handling for missing objects"
+msgstr "处理丢失的对象"
 
-#: builtin/notes.c:206
-#, c-format
-msgid "the note contents have been left in %s"
-msgstr "注解内容被留在 %s 中"
+#: builtin/pack-objects.c:3314
+msgid "do not pack objects in promisor packfiles"
+msgstr "不要打包 promisor 包文件中的对象"
 
-#: builtin/notes.c:234 builtin/tag.c:507
-#, c-format
-msgid "cannot read '%s'"
-msgstr "不能读取 '%s'"
+#: builtin/pack-objects.c:3316
+msgid "respect islands during delta compression"
+msgstr "在增量压缩时参考数据岛"
 
-#: builtin/notes.c:236 builtin/tag.c:510
+#: builtin/pack-objects.c:3345
 #, c-format
-msgid "could not open or read '%s'"
-msgstr "不能打开或读取 '%s'"
+msgid "delta chain depth %d is too deep, forcing %d"
+msgstr "增量链深度 %d 太深了，强制为 %d"
 
-#: builtin/notes.c:255 builtin/notes.c:306 builtin/notes.c:308
-#: builtin/notes.c:376 builtin/notes.c:431 builtin/notes.c:517
-#: builtin/notes.c:522 builtin/notes.c:600 builtin/notes.c:662
+#: builtin/pack-objects.c:3350
 #, c-format
-msgid "failed to resolve '%s' as a valid ref."
-msgstr "无法解析 '%s' 为一个有效引用。"
+msgid "pack.deltaCacheLimit is too high, forcing %d"
+msgstr "配置 pack.deltaCacheLimit 太高了，强制为 %d"
 
-#: builtin/notes.c:258
-#, c-format
-msgid "failed to read object '%s'."
-msgstr "无法读取对象 '%s'。"
+#: builtin/pack-objects.c:3404
+msgid "--max-pack-size cannot be used to build a pack for transfer"
+msgstr "不能使用 --max-pack-size 来构建传输用的包文件"
+
+#: builtin/pack-objects.c:3406
+msgid "minimum pack size limit is 1 MiB"
+msgstr "最小的包文件大小是 1 MiB"
+
+#: builtin/pack-objects.c:3411
+msgid "--thin cannot be used to build an indexable pack"
+msgstr "--thin 不能用于创建一个可索引包"
+
+#: builtin/pack-objects.c:3414
+msgid "--keep-unreachable and --unpack-unreachable are incompatible"
+msgstr "--keep-unreachable 和 --unpack-unreachable 不兼容"
+
+#: builtin/pack-objects.c:3420
+msgid "cannot use --filter without --stdout"
+msgstr "不能在没有 --stdout 的情况下使用 --filter"
 
-#: builtin/notes.c:262
-#, c-format
-msgid "cannot read note data from non-blob object '%s'."
-msgstr "不能从非数据对象 '%s' 中读取注解数据。"
+#: builtin/pack-objects.c:3481
+msgid "Enumerating objects"
+msgstr "枚举对象"
 
-#: builtin/notes.c:302
+#: builtin/pack-objects.c:3511
 #, c-format
-msgid "malformed input line: '%s'."
-msgstr "格式错误的输入行：'%s'。"
+msgid "Total %<PRIu32> (delta %<PRIu32>), reused %<PRIu32> (delta %<PRIu32>)"
+msgstr "总共 %<PRIu32> （差异 %<PRIu32>），复用 %<PRIu32> （差异 %<PRIu32>）"
 
-#: builtin/notes.c:317
-#, c-format
-msgid "failed to copy notes from '%s' to '%s'"
-msgstr "从 '%s' 拷贝注解到 '%s' 时失败"
+#: builtin/pack-refs.c:8
+msgid "git pack-refs [<options>]"
+msgstr "git pack-refs [<选项>]"
 
-#. TRANSLATORS: the first %s will be replaced by a git
-#. notes command: 'add', 'merge', 'remove', etc.
-#.
-#: builtin/notes.c:349
-#, c-format
-msgid "refusing to %s notes in %s (outside of refs/notes/)"
-msgstr "拒绝向 %2$s（在 refs/notes/ 之外）%1$s注解"
+#: builtin/pack-refs.c:16
+msgid "pack everything"
+msgstr "打包一切"
 
-#: builtin/notes.c:369 builtin/notes.c:424 builtin/notes.c:500
-#: builtin/notes.c:512 builtin/notes.c:588 builtin/notes.c:655
-#: builtin/notes.c:805 builtin/notes.c:952 builtin/notes.c:973
-msgid "too many parameters"
-msgstr "参数太多"
+#: builtin/pack-refs.c:17
+msgid "prune loose refs (default)"
+msgstr "清除松散的引用（默认）"
 
-#: builtin/notes.c:382 builtin/notes.c:668
-#, c-format
-msgid "no note found for object %s."
-msgstr "未发现对象 %s 的注解。"
+#: builtin/prune-packed.c:9
+msgid "git prune-packed [-n | --dry-run] [-q | --quiet]"
+msgstr "git prune-packed [-n | --dry-run] [-q | --quiet]"
 
-#: builtin/notes.c:403 builtin/notes.c:566
-msgid "note contents as a string"
-msgstr "注解内容作为一个字符串"
+#: builtin/prune-packed.c:42
+msgid "Removing duplicate objects"
+msgstr "正在删除重复对象"
 
-#: builtin/notes.c:406 builtin/notes.c:569
-msgid "note contents in a file"
-msgstr "注解内容到一个文件中"
+#: builtin/prune.c:12
+msgid "git prune [-n] [-v] [--progress] [--expire <time>] [--] [<head>...]"
+msgstr "git prune [-n] [-v] [--progress] [--expire <时间>] [--] [<head>...]"
 
-#: builtin/notes.c:409 builtin/notes.c:572
-msgid "reuse and edit specified note object"
-msgstr "重用和编辑指定的注解对象"
+#: builtin/prune.c:131
+msgid "report pruned objects"
+msgstr "报告清除的对象"
 
-#: builtin/notes.c:412 builtin/notes.c:575
-msgid "reuse specified note object"
-msgstr "重用指定的注解对象"
+#: builtin/prune.c:134
+msgid "expire objects older than <time>"
+msgstr "使早于给定时间的对象过期"
 
-#: builtin/notes.c:415 builtin/notes.c:578
-msgid "allow storing empty note"
-msgstr "允许保存空白注释"
+#: builtin/prune.c:136
+msgid "limit traversal to objects outside promisor packfiles"
+msgstr "限制遍历 promisor 包以外的对象"
 
-#: builtin/notes.c:416 builtin/notes.c:487
-msgid "replace existing notes"
-msgstr "替换已存在的注解"
+#: builtin/prune.c:150
+msgid "cannot prune in a precious-objects repo"
+msgstr "不能在珍品仓库中执行清理操作"
 
-#: builtin/notes.c:441
+#: builtin/pull.c:66 builtin/pull.c:68
 #, c-format
-msgid ""
-"Cannot add notes. Found existing notes for object %s. Use '-f' to overwrite "
-"existing notes"
-msgstr "不能添加注解。发现对象 %s 已存在注解。使用 '-f' 覆盖现存注解"
+msgid "Invalid value for %s: %s"
+msgstr "%s 的值无效：%s"
 
-#: builtin/notes.c:456 builtin/notes.c:535
-#, c-format
-msgid "Overwriting existing notes for object %s\n"
-msgstr "覆盖对象 %s 现存注解\n"
+#: builtin/pull.c:88
+msgid "git pull [<options>] [<repository> [<refspec>...]]"
+msgstr "git pull [<选项>] [<仓库> [<引用规格>...]]"
 
-#: builtin/notes.c:467 builtin/notes.c:627 builtin/notes.c:892
-#, c-format
-msgid "Removing note for object %s\n"
-msgstr "删除对象 %s 的注解\n"
+#: builtin/pull.c:142
+msgid "control for recursive fetching of submodules"
+msgstr "控制子模组的递归获取"
 
-#: builtin/notes.c:488
-msgid "read objects from stdin"
-msgstr "从标准输入读取对象"
+#: builtin/pull.c:146
+msgid "Options related to merging"
+msgstr "和合并相关的选项"
 
-#: builtin/notes.c:490
-msgid "load rewriting config for <command> (implies --stdin)"
-msgstr "重新加载 <命令> 的配置（隐含 --stdin）"
+#: builtin/pull.c:149
+msgid "incorporate changes by rebasing rather than merging"
+msgstr "使用变基操作取代合并操作以合入修改"
 
-#: builtin/notes.c:508
-msgid "too few parameters"
-msgstr "参数太少"
+#: builtin/pull.c:177 builtin/rebase.c:467 builtin/revert.c:126
+msgid "allow fast-forward"
+msgstr "允许快进式"
+
+#: builtin/pull.c:186
+msgid "automatically stash/stash pop before and after rebase"
+msgstr "变基操作前后执行自动贮藏和弹出贮藏"
+
+#: builtin/pull.c:202
+msgid "Options related to fetching"
+msgstr "和获取相关的参数"
+
+#: builtin/pull.c:212
+msgid "force overwrite of local branch"
+msgstr "强制覆盖本地分支"
+
+#: builtin/pull.c:220
+msgid "number of submodules pulled in parallel"
+msgstr "并发拉取的子模组的数量"
 
-#: builtin/notes.c:529
+#: builtin/pull.c:320
 #, c-format
+msgid "Invalid value for pull.ff: %s"
+msgstr "pull.ff 的取值无效：%s"
+
+#: builtin/pull.c:437
 msgid ""
-"Cannot copy notes. Found existing notes for object %s. Use '-f' to overwrite "
-"existing notes"
-msgstr "不能拷贝注解。发现对象 %s 已存在注解。使用 '-f' 覆盖现存注解"
+"There is no candidate for rebasing against among the refs that you just "
+"fetched."
+msgstr "在您刚刚获取到的引用中没有变基操作的候选。"
 
-#: builtin/notes.c:541
-#, c-format
-msgid "missing notes on source object %s. Cannot copy."
-msgstr "源对象 %s 缺少注解。不能拷贝。"
+#: builtin/pull.c:439
+msgid ""
+"There are no candidates for merging among the refs that you just fetched."
+msgstr "在您刚刚获取到的引用中没有合并操作的候选。"
+
+#: builtin/pull.c:440
+msgid ""
+"Generally this means that you provided a wildcard refspec which had no\n"
+"matches on the remote end."
+msgstr "通常这意味着您提供了一个通配符引用规格但未能和远端匹配。"
 
-#: builtin/notes.c:593
+#: builtin/pull.c:443
 #, c-format
 msgid ""
-"The -m/-F/-c/-C options have been deprecated for the 'edit' subcommand.\n"
-"Please use 'git notes add -f -m/-F/-c/-C' instead.\n"
+"You asked to pull from the remote '%s', but did not specify\n"
+"a branch. Because this is not the default configured remote\n"
+"for your current branch, you must specify a branch on the command line."
 msgstr ""
-"子命令 'edit' 的选项 -m/-F/-c/-C 已弃用。\n"
-"请换用 'git notes add -f -m/-F/-c/-C'。\n"
+"您要求从远程 '%s' 拉取，但是未指定一个分支。因为这不是当前\n"
+"分支默认的远程仓库，您必须在命令行中指定一个分支名。"
 
-#: builtin/notes.c:688
-msgid "failed to delete ref NOTES_MERGE_PARTIAL"
-msgstr "无法删除引用 NOTES_MERGE_PARTIAL"
+#: builtin/pull.c:448 builtin/rebase.c:1375 git-parse-remote.sh:73
+msgid "You are not currently on a branch."
+msgstr "您当前不在一个分支上。"
 
-#: builtin/notes.c:690
-msgid "failed to delete ref NOTES_MERGE_REF"
-msgstr "无法删除引用 NOTES_MERGE_REF"
+#: builtin/pull.c:450 builtin/pull.c:465 git-parse-remote.sh:79
+msgid "Please specify which branch you want to rebase against."
+msgstr "请指定您要变基到哪一个分支。"
 
-#: builtin/notes.c:692
-msgid "failed to remove 'git notes merge' worktree"
-msgstr "无法删除 'git notes merge' 工作区"
+#: builtin/pull.c:452 builtin/pull.c:467 git-parse-remote.sh:82
+msgid "Please specify which branch you want to merge with."
+msgstr "请指定您要合并哪一个分支。"
 
-#: builtin/notes.c:712
-msgid "failed to read ref NOTES_MERGE_PARTIAL"
-msgstr "无法读取引用 NOTES_MERGE_PARTIAL"
+#: builtin/pull.c:453 builtin/pull.c:468
+msgid "See git-pull(1) for details."
+msgstr "详见 git-pull(1)。"
 
-#: builtin/notes.c:714
-msgid "could not find commit from NOTES_MERGE_PARTIAL."
-msgstr "无法从 NOTES_MERGE_PARTIAL 中找到提交。"
+#: builtin/pull.c:455 builtin/pull.c:461 builtin/pull.c:470
+#: builtin/rebase.c:1381 git-parse-remote.sh:64
+msgid "<remote>"
+msgstr "<远程>"
 
-#: builtin/notes.c:716
-msgid "could not parse commit from NOTES_MERGE_PARTIAL."
-msgstr "无法从 NOTES_MERGE_PARTIAL 中解析提交。"
+#: builtin/pull.c:455 builtin/pull.c:470 builtin/pull.c:475
+#: git-parse-remote.sh:65
+msgid "<branch>"
+msgstr "<分支>"
 
-#: builtin/notes.c:729
-msgid "failed to resolve NOTES_MERGE_REF"
-msgstr "无法解析 NOTES_MERGE_REF"
+#: builtin/pull.c:463 builtin/rebase.c:1373 git-parse-remote.sh:75
+msgid "There is no tracking information for the current branch."
+msgstr "当前分支没有跟踪信息。"
 
-#: builtin/notes.c:732
-msgid "failed to finalize notes merge"
-msgstr "无法完成注解合并"
+#: builtin/pull.c:472 git-parse-remote.sh:95
+msgid ""
+"If you wish to set tracking information for this branch you can do so with:"
+msgstr "如果您想要为此分支创建跟踪信息，您可以执行："
 
-#: builtin/notes.c:758
+#: builtin/pull.c:477
 #, c-format
-msgid "unknown notes merge strategy %s"
-msgstr "未知的注解合并策略 %s"
-
-#: builtin/notes.c:774
-msgid "General options"
-msgstr "通用选项"
-
-#: builtin/notes.c:776
-msgid "Merge options"
-msgstr "合并选项"
-
-#: builtin/notes.c:778
 msgid ""
-"resolve notes conflicts using the given strategy (manual/ours/theirs/union/"
-"cat_sort_uniq)"
-msgstr "使用指定的策略解决注解冲突 (manual/ours/theirs/union/cat_sort_uniq)"
-
-#: builtin/notes.c:780
-msgid "Committing unmerged notes"
-msgstr "提交未合并的注解"
-
-#: builtin/notes.c:782
-msgid "finalize notes merge by committing unmerged notes"
-msgstr "通过提交未合并的注解来完成注解合并"
+"Your configuration specifies to merge with the ref '%s'\n"
+"from the remote, but no such ref was fetched."
+msgstr ""
+"您的配置中指定要合并远程的引用 '%s'，\n"
+"但是没有获取到这个引用。"
 
-#: builtin/notes.c:784
-msgid "Aborting notes merge resolution"
-msgstr "中止注解合并的方案"
+#: builtin/pull.c:587
+#, c-format
+msgid "unable to access commit %s"
+msgstr "无法访问提交 %s"
 
-#: builtin/notes.c:786
-msgid "abort notes merge"
-msgstr "中止注解合并"
+#: builtin/pull.c:867
+msgid "ignoring --verify-signatures for rebase"
+msgstr "为变基操作忽略 --verify-signatures"
 
-#: builtin/notes.c:797
-msgid "cannot mix --commit, --abort or -s/--strategy"
-msgstr "不能混用 --commit、--abort 或 -s/--strategy"
+#: builtin/pull.c:922
+msgid "--[no-]autostash option is only valid with --rebase."
+msgstr "--[no-]autostash 选项只在使用 --rebase 时有效。"
 
-#: builtin/notes.c:802
-msgid "must specify a notes ref to merge"
-msgstr "必须指定一个注解引用来合并"
+#: builtin/pull.c:930
+msgid "Updating an unborn branch with changes added to the index."
+msgstr "更新尚未诞生的分支，变更添加至索引。"
 
-#: builtin/notes.c:826
-#, c-format
-msgid "unknown -s/--strategy: %s"
-msgstr "未知的 -s/--strategy：%s"
+#: builtin/pull.c:934
+msgid "pull with rebase"
+msgstr "变基式拉取"
 
-#: builtin/notes.c:863
-#, c-format
-msgid "a notes merge into %s is already in-progress at %s"
-msgstr "位于 %2$s 的一个到 %1$s 中的注解合并正在执行中"
+#: builtin/pull.c:935
+msgid "please commit or stash them."
+msgstr "请提交或贮藏它们。"
 
-#: builtin/notes.c:866
+#: builtin/pull.c:960
 #, c-format
-msgid "failed to store link to current notes ref (%s)"
-msgstr "无法存储链接到当前的注解引用（%s）"
+msgid ""
+"fetch updated the current branch head.\n"
+"fast-forwarding your working tree from\n"
+"commit %s."
+msgstr ""
+"fetch 更新了当前的分支。快进您的工作区\n"
+"至提交 %s。"
 
-#: builtin/notes.c:868
+#: builtin/pull.c:966
 #, c-format
 msgid ""
-"Automatic notes merge failed. Fix conflicts in %s and commit the result with "
-"'git notes merge --commit', or abort the merge with 'git notes merge --"
-"abort'.\n"
+"Cannot fast-forward your working tree.\n"
+"After making sure that you saved anything precious from\n"
+"$ git diff %s\n"
+"output, run\n"
+"$ git reset --hard\n"
+"to recover."
 msgstr ""
-"自动合并说明失败。修改 %s 中的冲突并且使用命令 'git notes merge --commit' 提"
-"交结果，或者使用命令 'git notes merge --abort' 终止合并。\n"
+"您当前的工作区无法执行快进操作。\n"
+"首先执行如下命令：\n"
+"$ git diff %s\n"
+"以确认所有有用的数据均已保存。然后执行下面的命令\n"
+"$ git reset --hard\n"
+"恢复之前的状态。"
 
-#: builtin/notes.c:890
-#, c-format
-msgid "Object %s has no note\n"
-msgstr "对象 %s 没有注解\n"
+#: builtin/pull.c:981
+msgid "Cannot merge multiple branches into empty head."
+msgstr "无法将多个分支合并到空分支。"
 
-#: builtin/notes.c:902
-msgid "attempt to remove non-existent note is not an error"
-msgstr "尝试删除不存在的注解不是一个错误"
+#: builtin/pull.c:985
+msgid "Cannot rebase onto multiple branches."
+msgstr "无法变基到多个分支。"
 
-#: builtin/notes.c:905
-msgid "read object names from the standard input"
-msgstr "从标准输入读取对象名称"
+#: builtin/pull.c:992
+msgid "cannot rebase with locally recorded submodule modifications"
+msgstr "本地子模组中有修改，无法变基"
 
-#: builtin/notes.c:943 builtin/prune.c:107 builtin/worktree.c:151
-msgid "do not remove, show only"
-msgstr "不删除，只显示"
+#: builtin/push.c:19
+msgid "git push [<options>] [<repository> [<refspec>...]]"
+msgstr "git push [<选项>] [<仓库> [<引用规格>...]]"
 
-#: builtin/notes.c:944
-msgid "report pruned notes"
-msgstr "报告清除的注解"
+#: builtin/push.c:112
+msgid "tag shorthand without <tag>"
+msgstr "标签后面未提供 <标签> 参数"
 
-#: builtin/notes.c:986
-msgid "notes-ref"
-msgstr "注解引用"
+#: builtin/push.c:122
+msgid "--delete only accepts plain target ref names"
+msgstr "--delete 只接受简单的目标引用名"
 
-#: builtin/notes.c:987
-msgid "use notes from <notes-ref>"
-msgstr "从 <注解引用> 使用注解"
+#: builtin/push.c:168
+msgid ""
+"\n"
+"To choose either option permanently, see push.default in 'git help config'."
+msgstr ""
+"\n"
+"为了永久地选择任一选项，参见 'git help config' 中的 push.default。"
 
-#: builtin/notes.c:1022
+#: builtin/push.c:171
 #, c-format
-msgid "unknown subcommand: %s"
-msgstr "未知子命令：%s"
-
-#: builtin/pack-objects.c:48
 msgid ""
-"git pack-objects --stdout [<options>...] [< <ref-list> | < <object-list>]"
-msgstr "git pack-objects --stdout [<选项>...] [< <引用列表> | < <对象列表>]"
+"The upstream branch of your current branch does not match\n"
+"the name of your current branch.  To push to the upstream branch\n"
+"on the remote, use\n"
+"\n"
+"    git push %s HEAD:%s\n"
+"\n"
+"To push to the branch of the same name on the remote, use\n"
+"\n"
+"    git push %s HEAD\n"
+"%s"
+msgstr ""
+"您当前分支的上游分支和您当前分支名不匹配，为推送到远程的上游分支，\n"
+"使用\n"
+"\n"
+"    git push %s HEAD:%s\n"
+"\n"
+"为推送至远程同名分支，使用\n"
+"\n"
+"    git push %s HEAD\n"
+"%s"
 
-#: builtin/pack-objects.c:49
+#: builtin/push.c:186
+#, c-format
 msgid ""
-"git pack-objects [<options>...] <base-name> [< <ref-list> | < <object-list>]"
-msgstr "git pack-objects [<选项>...] <前缀名称> [< <引用列表> | < <对象列表>]"
+"You are not currently on a branch.\n"
+"To push the history leading to the current (detached HEAD)\n"
+"state now, use\n"
+"\n"
+"    git push %s HEAD:<name-of-remote-branch>\n"
+msgstr ""
+"您当前不在一个分支上。\n"
+"现在为推送当前（分离头指针）的历史，使用\n"
+"\n"
+"    git push %s HEAD:<远程分支名字>\n"
 
-#: builtin/pack-objects.c:211 builtin/pack-objects.c:214
+#: builtin/push.c:200
 #, c-format
-msgid "deflate error (%d)"
-msgstr "压缩错误 (%d)"
-
-#: builtin/pack-objects.c:810
-msgid "disabling bitmap writing, packs are split due to pack.packSizeLimit"
-msgstr "禁用 bitmap 写入，因为 pack.packSizeLimit 设置使得包被切分为多个"
-
-#: builtin/pack-objects.c:823
-msgid "Writing objects"
-msgstr "写入对象中"
-
-#: builtin/pack-objects.c:1106
-msgid "disabling bitmap writing, as some objects are not being packed"
-msgstr "禁用 bitmap 写入，因为一些对象将不会被打包"
-
-#: builtin/pack-objects.c:1765
-msgid "Counting objects"
-msgstr "对象计数中"
+msgid ""
+"The current branch %s has no upstream branch.\n"
+"To push the current branch and set the remote as upstream, use\n"
+"\n"
+"    git push --set-upstream %s %s\n"
+msgstr ""
+"当前分支 %s 没有对应的上游分支。\n"
+"为推送当前分支并建立与远程上游的跟踪，使用\n"
+"\n"
+"    git push --set-upstream %s %s\n"
 
-#: builtin/pack-objects.c:1895
+#: builtin/push.c:208
 #, c-format
-msgid "unable to get size of %s"
-msgstr "不能得到 %s 的大小"
+msgid "The current branch %s has multiple upstream branches, refusing to push."
+msgstr "当前分支 %s 有多个上游分支，拒绝推送。"
 
-#: builtin/pack-objects.c:1910
+#: builtin/push.c:211
 #, c-format
-msgid "unable to parse object header of %s"
-msgstr "无法解析对象 %s 头信息"
-
-#: builtin/pack-objects.c:2564
-msgid "Compressing objects"
-msgstr "压缩对象中"
+msgid ""
+"You are pushing to remote '%s', which is not the upstream of\n"
+"your current branch '%s', without telling me what to push\n"
+"to update which remote branch."
+msgstr ""
+"您正推送至远程 '%s'（其并非当前分支 '%s' 的上游），\n"
+"而没有告诉我要推送什么、更新哪个远程分支。"
 
-#: builtin/pack-objects.c:2735
-msgid "invalid value for --missing"
-msgstr "选项 --missing 的值无效"
+#: builtin/push.c:270
+msgid ""
+"You didn't specify any refspecs to push, and push.default is \"nothing\"."
+msgstr "您没有为推送指定任何引用规格，并且 push.default 为 \"nothing\"。"
 
-#: builtin/pack-objects.c:3067
-#, c-format
-msgid "unsupported index version %s"
-msgstr "不支持的索引版本 %s"
+#: builtin/push.c:277
+msgid ""
+"Updates were rejected because the tip of your current branch is behind\n"
+"its remote counterpart. Integrate the remote changes (e.g.\n"
+"'git pull ...') before pushing again.\n"
+"See the 'Note about fast-forwards' in 'git push --help' for details."
+msgstr ""
+"更新被拒绝，因为您当前分支的最新提交落后于其对应的远程分支。\n"
+"再次推送前，先与远程变更合并（如 'git pull ...'）。详见\n"
+"'git push --help' 中的 'Note about fast-forwards' 小节。"
 
-#: builtin/pack-objects.c:3071
-#, c-format
-msgid "bad index version '%s'"
-msgstr "坏的索引版本 '%s'"
+#: builtin/push.c:283
+msgid ""
+"Updates were rejected because a pushed branch tip is behind its remote\n"
+"counterpart. Check out this branch and integrate the remote changes\n"
+"(e.g. 'git pull ...') before pushing again.\n"
+"See the 'Note about fast-forwards' in 'git push --help' for details."
+msgstr ""
+"更新被拒绝，因为推送的一个分支的最新提交落后于其对应的远程分支。\n"
+"检出该分支并整合远程变更（如 'git pull ...'），然后再推送。详见\n"
+"'git push --help' 中的 'Note about fast-forwards' 小节。"
 
-#: builtin/pack-objects.c:3102
-msgid "do not show progress meter"
-msgstr "不显示进度表"
+#: builtin/push.c:289
+msgid ""
+"Updates were rejected because the remote contains work that you do\n"
+"not have locally. This is usually caused by another repository pushing\n"
+"to the same ref. You may want to first integrate the remote changes\n"
+"(e.g., 'git pull ...') before pushing again.\n"
+"See the 'Note about fast-forwards' in 'git push --help' for details."
+msgstr ""
+"更新被拒绝，因为远程仓库包含您本地尚不存在的提交。这通常是因为另外\n"
+"一个仓库已向该引用进行了推送。再次推送前，您可能需要先整合远程变更\n"
+"（如 'git pull ...'）。\n"
+"详见 'git push --help' 中的 'Note about fast-forwards' 小节。"
 
-#: builtin/pack-objects.c:3104
-msgid "show progress meter"
-msgstr "显示进度表"
+#: builtin/push.c:296
+msgid "Updates were rejected because the tag already exists in the remote."
+msgstr "更新被拒绝，因为该标签在远程已经存在。"
 
-#: builtin/pack-objects.c:3106
-msgid "show progress meter during object writing phase"
-msgstr "在对象写入阶段显示进度表"
+#: builtin/push.c:299
+msgid ""
+"You cannot update a remote ref that points at a non-commit object,\n"
+"or update a remote ref to make it point at a non-commit object,\n"
+"without using the '--force' option.\n"
+msgstr ""
+"如果不使用 '--force' 参数，您不能更新一个指向非提交对象的远程引用，\n"
+"也不能更新远程引用让其指向一个非提交对象。\n"
 
-#: builtin/pack-objects.c:3109
-msgid "similar to --all-progress when progress meter is shown"
-msgstr "当进度表显示时类似于 --all-progress"
+#: builtin/push.c:360
+#, c-format
+msgid "Pushing to %s\n"
+msgstr "推送到 %s\n"
 
-#: builtin/pack-objects.c:3110
-msgid "version[,offset]"
-msgstr "版本[,偏移]"
+#: builtin/push.c:367
+#, c-format
+msgid "failed to push some refs to '%s'"
+msgstr "推送一些引用到 '%s' 失败"
 
-#: builtin/pack-objects.c:3111
-msgid "write the pack index file in the specified idx format version"
-msgstr "用指定的 idx 格式版本来写包索引文件"
+#: builtin/push.c:542
+msgid "repository"
+msgstr "仓库"
 
-#: builtin/pack-objects.c:3114
-msgid "maximum size of each output pack file"
-msgstr "每个输出包的最大尺寸"
+#: builtin/push.c:543 builtin/send-pack.c:164
+msgid "push all refs"
+msgstr "推送所有引用"
 
-#: builtin/pack-objects.c:3116
-msgid "ignore borrowed objects from alternate object store"
-msgstr "忽略从备用对象存储里借用对象"
+#: builtin/push.c:544 builtin/send-pack.c:166
+msgid "mirror all refs"
+msgstr "镜像所有引用"
 
-#: builtin/pack-objects.c:3118
-msgid "ignore packed objects"
-msgstr "忽略包对象"
+#: builtin/push.c:546
+msgid "delete refs"
+msgstr "删除引用"
 
-#: builtin/pack-objects.c:3120
-msgid "limit pack window by objects"
-msgstr "限制打包窗口的对象数"
+#: builtin/push.c:547
+msgid "push tags (can't be used with --all or --mirror)"
+msgstr "推送标签（不能使用 --all or --mirror）"
 
-#: builtin/pack-objects.c:3122
-msgid "limit pack window by memory in addition to object limit"
-msgstr "除对象数量限制外设置打包窗口的内存限制"
+#: builtin/push.c:550 builtin/send-pack.c:167
+msgid "force updates"
+msgstr "强制更新"
 
-#: builtin/pack-objects.c:3124
-msgid "maximum length of delta chain allowed in the resulting pack"
-msgstr "打包允许的 delta 链的最大长度"
+#: builtin/push.c:552 builtin/send-pack.c:181
+msgid "<refname>:<expect>"
+msgstr "<引用名>:<期望值>"
 
-#: builtin/pack-objects.c:3126
-msgid "reuse existing deltas"
-msgstr "重用已存在的 deltas"
+#: builtin/push.c:553 builtin/send-pack.c:182
+msgid "require old value of ref to be at this value"
+msgstr "要求引用旧的取值为设定值"
 
-#: builtin/pack-objects.c:3128
-msgid "reuse existing objects"
-msgstr "重用已存在的对象"
+#: builtin/push.c:556
+msgid "control recursive pushing of submodules"
+msgstr "控制子模组的递归推送"
 
-#: builtin/pack-objects.c:3130
-msgid "use OFS_DELTA objects"
-msgstr "使用 OFS_DELTA 对象"
+#: builtin/push.c:558 builtin/send-pack.c:175
+msgid "use thin pack"
+msgstr "使用精简打包"
 
-#: builtin/pack-objects.c:3132
-msgid "use threads when searching for best delta matches"
-msgstr "使用线程查询最佳 delta 匹配"
+#: builtin/push.c:559 builtin/push.c:560 builtin/send-pack.c:161
+#: builtin/send-pack.c:162
+msgid "receive pack program"
+msgstr "接收包程序"
 
-#: builtin/pack-objects.c:3134
-msgid "do not create an empty pack output"
-msgstr "不创建空的包输出"
+#: builtin/push.c:561
+msgid "set upstream for git pull/status"
+msgstr "设置 git pull/status 的上游"
 
-#: builtin/pack-objects.c:3136
-msgid "read revision arguments from standard input"
-msgstr "从标准输入读取版本号参数"
+#: builtin/push.c:564
+msgid "prune locally removed refs"
+msgstr "清除本地删除的引用"
 
-#: builtin/pack-objects.c:3138
-msgid "limit the objects to those that are not yet packed"
-msgstr "限制那些尚未打包的对象"
+#: builtin/push.c:566
+msgid "bypass pre-push hook"
+msgstr "绕过 pre-push 钩子"
 
-#: builtin/pack-objects.c:3141
-msgid "include objects reachable from any reference"
-msgstr "包括可以从任何引用访问到的对象"
+#: builtin/push.c:567
+msgid "push missing but relevant tags"
+msgstr "推送缺失但有关的标签"
 
-#: builtin/pack-objects.c:3144
-msgid "include objects referred by reflog entries"
-msgstr "包括被引用日志引用到的对象"
+#: builtin/push.c:570 builtin/send-pack.c:169
+msgid "GPG sign the push"
+msgstr "用 GPG 为推送签名"
 
-#: builtin/pack-objects.c:3147
-msgid "include objects referred to by the index"
-msgstr "包括被索引引用到的对象"
+#: builtin/push.c:572 builtin/send-pack.c:176
+msgid "request atomic transaction on remote side"
+msgstr "需要远端支持原子事务"
 
-#: builtin/pack-objects.c:3150
-msgid "output pack to stdout"
-msgstr "输出包到标准输出"
+#: builtin/push.c:590
+msgid "--delete is incompatible with --all, --mirror and --tags"
+msgstr "--delete 与 --all、--mirror 及 --tags 不兼容"
 
-#: builtin/pack-objects.c:3152
-msgid "include tag objects that refer to objects to be packed"
-msgstr "包括那些引用了待打包对象的标签对象"
+#: builtin/push.c:592
+msgid "--delete doesn't make sense without any refs"
+msgstr "--delete 未接任何引用没有意义"
 
-#: builtin/pack-objects.c:3154
-msgid "keep unreachable objects"
-msgstr "维持不可达的对象"
+#: builtin/push.c:612
+#, c-format
+msgid "bad repository '%s'"
+msgstr "坏的仓库 '%s'"
 
-#: builtin/pack-objects.c:3156
-msgid "pack loose unreachable objects"
-msgstr "打包松散的不可达对象"
+#: builtin/push.c:613
+msgid ""
+"No configured push destination.\n"
+"Either specify the URL from the command-line or configure a remote "
+"repository using\n"
+"\n"
+"    git remote add <name> <url>\n"
+"\n"
+"and then push using the remote name\n"
+"\n"
+"    git push <name>\n"
+msgstr ""
+"没有配置推送目标。\n"
+"或通过命令行指定 URL，或用下面命令配置一个远程仓库\n"
+"\n"
+"    git remote add <名称> <地址>\n"
+"\n"
+"然后使用该远程仓库名执行推送\n"
+"\n"
+"    git push <名称>\n"
 
-#: builtin/pack-objects.c:3158
-msgid "unpack unreachable objects newer than <time>"
-msgstr "将比给定 <时间> 新的无法访问的对象解包"
+#: builtin/push.c:628
+msgid "--all and --tags are incompatible"
+msgstr "--all 和 --tags 不兼容"
 
-#: builtin/pack-objects.c:3161
-msgid "create thin packs"
-msgstr "创建精简包"
+#: builtin/push.c:630
+msgid "--all can't be combined with refspecs"
+msgstr "--all 不能和引用规格同时使用"
 
-#: builtin/pack-objects.c:3163
-msgid "create packs suitable for shallow fetches"
-msgstr "创建适合浅克隆仓库获取的包"
+#: builtin/push.c:634
+msgid "--mirror and --tags are incompatible"
+msgstr "--mirror 和 --tags 不兼容"
 
-#: builtin/pack-objects.c:3165
-msgid "ignore packs that have companion .keep file"
-msgstr "忽略配有 .keep 文件的包"
+#: builtin/push.c:636
+msgid "--mirror can't be combined with refspecs"
+msgstr "--mirror 不能和引用规格同时使用"
 
-#: builtin/pack-objects.c:3167
-msgid "ignore this pack"
-msgstr "忽略该 pack"
+#: builtin/push.c:639
+msgid "--all and --mirror are incompatible"
+msgstr "--all 和 --mirror 不兼容"
 
-#: builtin/pack-objects.c:3169
-msgid "pack compression level"
-msgstr "打包压缩级别"
+#: builtin/push.c:643
+msgid "push options must not have new line characters"
+msgstr "推送选项不能有换行符"
 
-#: builtin/pack-objects.c:3171
-msgid "do not hide commits by grafts"
-msgstr "显示被移植隐藏的提交"
+#: builtin/range-diff.c:8
+msgid "git range-diff [<options>] <old-base>..<old-tip> <new-base>..<new-tip>"
+msgstr "git range-diff [<选项>] <old-base>..<old-tip> <new-base>..<new-tip>"
 
-#: builtin/pack-objects.c:3173
-msgid "use a bitmap index if available to speed up counting objects"
-msgstr "使用 bitmap 索引（如果有的话）以提高对象计数时的速度"
+#: builtin/range-diff.c:9
+msgid "git range-diff [<options>] <old-tip>...<new-tip>"
+msgstr "git range-diff [<选项>] <old-tip>...<new-tip>"
 
-#: builtin/pack-objects.c:3175
-msgid "write a bitmap index together with the pack index"
-msgstr "在建立包索引的同时创建 bitmap 索引"
+#: builtin/range-diff.c:10
+msgid "git range-diff [<options>] <base> <old-tip> <new-tip>"
+msgstr "git range-diff [<选项>] <base> <old-tip> <new-tip>"
 
-#: builtin/pack-objects.c:3178
-msgid "handling for missing objects"
-msgstr "处理丢失的对象"
+#: builtin/range-diff.c:22
+msgid "Percentage by which creation is weighted"
+msgstr "创建权重的百分比"
 
-#: builtin/pack-objects.c:3181
-msgid "do not pack objects in promisor packfiles"
-msgstr "不要打包 promisor 包文件中的对象"
+#: builtin/range-diff.c:24
+msgid "use simple diff colors"
+msgstr "使用简单差异颜色"
 
-#: builtin/pack-objects.c:3205
-#, c-format
-msgid "delta chain depth %d is too deep, forcing %d"
-msgstr "增量链深度 %d 太深了，强制为 %d"
+#: builtin/range-diff.c:26
+msgid "notes"
+msgstr "注解"
+
+#: builtin/range-diff.c:26
+msgid "passed to 'git log'"
+msgstr "传递给 'git log'"
 
-#: builtin/pack-objects.c:3210
+#: builtin/range-diff.c:50 builtin/range-diff.c:54
 #, c-format
-msgid "pack.deltaCacheLimit is too high, forcing %d"
-msgstr "配置 pack.deltaCacheLimit 太高了，强制为 %d"
+msgid "no .. in range: '%s'"
+msgstr "没有在范围中使用 ..：'%s'"
 
-#: builtin/pack-objects.c:3338
-msgid "Enumerating objects"
-msgstr "枚举对象"
+#: builtin/range-diff.c:64
+msgid "single arg format must be symmetric range"
+msgstr "单个参数格式必须是对称范围（即包含...）"
 
-#: builtin/pack-refs.c:7
-msgid "git pack-refs [<options>]"
-msgstr "git pack-refs [<选项>]"
+#: builtin/range-diff.c:79
+msgid "need two commit ranges"
+msgstr "需要两个提交范围"
 
-#: builtin/pack-refs.c:15
-msgid "pack everything"
-msgstr "打包一切"
+#: builtin/read-tree.c:41
+msgid ""
+"git read-tree [(-m [--trivial] [--aggressive] | --reset | --prefix=<prefix>) "
+"[-u [--exclude-per-directory=<gitignore>] | -i]] [--no-sparse-checkout] [--"
+"index-output=<file>] (--empty | <tree-ish1> [<tree-ish2> [<tree-ish3>]])"
+msgstr ""
+"git read-tree [(-m [--trivial] [--aggressive] | --reset | --prefix=<前缀>) [-"
+"u [--exclude-per-directory=<gitignore>] | -i]] [--no-sparse-checkout] [--"
+"index-output=<文件>] (--empty | <树对象1> [<树对象2> [<树对象3>]])"
 
-#: builtin/pack-refs.c:16
-msgid "prune loose refs (default)"
-msgstr "清除松散的引用（默认）"
+#: builtin/read-tree.c:124
+msgid "write resulting index to <file>"
+msgstr "将索引结果写入 <文件>"
 
-#: builtin/prune-packed.c:8
-msgid "git prune-packed [-n | --dry-run] [-q | --quiet]"
-msgstr "git prune-packed [-n | --dry-run] [-q | --quiet]"
+#: builtin/read-tree.c:127
+msgid "only empty the index"
+msgstr "只是清空索引"
 
-#: builtin/prune-packed.c:41
-msgid "Removing duplicate objects"
-msgstr "正在删除重复对象"
+#: builtin/read-tree.c:129
+msgid "Merging"
+msgstr "合并"
 
-#: builtin/prune.c:11
-msgid "git prune [-n] [-v] [--progress] [--expire <time>] [--] [<head>...]"
-msgstr "git prune [-n] [-v] [--progress] [--expire <时间>] [--] [<head>...]"
+#: builtin/read-tree.c:131
+msgid "perform a merge in addition to a read"
+msgstr "读取之余再执行一个合并"
 
-#: builtin/prune.c:108
-msgid "report pruned objects"
-msgstr "报告清除的对象"
+#: builtin/read-tree.c:133
+msgid "3-way merge if no file level merging required"
+msgstr "如果没有文件级合并需要，执行三方合并"
 
-#: builtin/prune.c:111
-msgid "expire objects older than <time>"
-msgstr "使早于给定时间的对象过期"
+#: builtin/read-tree.c:135
+msgid "3-way merge in presence of adds and removes"
+msgstr "存在添加和删除时，也执行三方合并"
 
-#: builtin/prune.c:113
-msgid "limit traversal to objects outside promisor packfiles"
-msgstr "限制遍历 promisor 包以外的对象"
+#: builtin/read-tree.c:137
+msgid "same as -m, but discard unmerged entries"
+msgstr "类似于 -m，但丢弃未合并的条目"
 
-#: builtin/prune.c:127
-msgid "cannot prune in a precious-objects repo"
-msgstr "不能在珍品仓库中执行清理操作"
+#: builtin/read-tree.c:138
+msgid "<subdirectory>/"
+msgstr "<子目录>/"
 
-#: builtin/pull.c:59 builtin/pull.c:61
-#, c-format
-msgid "Invalid value for %s: %s"
-msgstr "%s 的值无效：%s"
+#: builtin/read-tree.c:139
+msgid "read the tree into the index under <subdirectory>/"
+msgstr "读取树对象到索引的 <子目录>/ 下"
 
-#: builtin/pull.c:81
-msgid "git pull [<options>] [<repository> [<refspec>...]]"
-msgstr "git pull [<选项>] [<仓库> [<引用规格>...]]"
+#: builtin/read-tree.c:142
+msgid "update working tree with merge result"
+msgstr "用合并的结果更新工作区"
 
-#: builtin/pull.c:132
-msgid "control for recursive fetching of submodules"
-msgstr "控制子模组的递归获取"
+#: builtin/read-tree.c:144
+msgid "gitignore"
+msgstr "gitignore"
 
-#: builtin/pull.c:136
-msgid "Options related to merging"
-msgstr "和合并相关的选项"
+#: builtin/read-tree.c:145
+msgid "allow explicitly ignored files to be overwritten"
+msgstr "允许忽略文件中设定的文件可以被覆盖"
 
-#: builtin/pull.c:139
-msgid "incorporate changes by rebasing rather than merging"
-msgstr "使用变基操作取代合并操作以合入修改"
+#: builtin/read-tree.c:148
+msgid "don't check the working tree after merging"
+msgstr "合并后不检查工作区"
 
-#: builtin/pull.c:166 builtin/rebase--helper.c:23 builtin/revert.c:121
-msgid "allow fast-forward"
-msgstr "允许快进式"
+#: builtin/read-tree.c:149
+msgid "don't update the index or the work tree"
+msgstr "不更新索引区和工作区"
 
-#: builtin/pull.c:175
-msgid "automatically stash/stash pop before and after rebase"
-msgstr "变基操作前后执行自动贮藏和弹出贮藏"
+#: builtin/read-tree.c:151
+msgid "skip applying sparse checkout filter"
+msgstr "跳过应用稀疏检出过滤器"
 
-#: builtin/pull.c:191
-msgid "Options related to fetching"
-msgstr "和获取相关的参数"
+#: builtin/read-tree.c:153
+msgid "debug unpack-trees"
+msgstr "调试 unpack-trees"
 
-#: builtin/pull.c:209
-msgid "number of submodules pulled in parallel"
-msgstr "并发拉取的子模组的数量"
+#: builtin/read-tree.c:157
+msgid "suppress feedback messages"
+msgstr "抑制反馈信息"
 
-#: builtin/pull.c:304
-#, c-format
-msgid "Invalid value for pull.ff: %s"
-msgstr "pull.ff 的取值无效：%s"
+#: builtin/read-tree.c:188
+msgid "You need to resolve your current index first"
+msgstr "您需要先解决当前索引的冲突"
 
-#: builtin/pull.c:420
+#: builtin/rebase.c:32
 msgid ""
-"There is no candidate for rebasing against among the refs that you just "
-"fetched."
-msgstr "在您刚刚获取到的引用中没有变基操作的候选。"
+"git rebase [-i] [options] [--exec <cmd>] [--onto <newbase> | --keep-base] "
+"[<upstream> [<branch>]]"
+msgstr ""
+"git rebase [-i] [options] [--exec <命令>] [--onto <新基线> | --keep-base] [<"
+"上游> [<分支>]]"
 
-#: builtin/pull.c:422
+#: builtin/rebase.c:34
 msgid ""
-"There are no candidates for merging among the refs that you just fetched."
-msgstr "在您刚刚获取到的引用中没有合并操作的候选。"
+"git rebase [-i] [options] [--exec <cmd>] [--onto <newbase>] --root [<branch>]"
+msgstr ""
+"git rebase [-i] [选项] [--exec <命令>] [--onto <新基线>] --root [<分支>]"
 
-#: builtin/pull.c:423
-msgid ""
-"Generally this means that you provided a wildcard refspec which had no\n"
-"matches on the remote end."
-msgstr "通常这意味着您提供了一个通配符引用规格但未能和远端匹配。"
+#: builtin/rebase.c:36
+msgid "git rebase --continue | --abort | --skip | --edit-todo"
+msgstr "git rebase --continue | --abort | --skip | --edit-todo"
 
-#: builtin/pull.c:426
+#: builtin/rebase.c:177 builtin/rebase.c:201 builtin/rebase.c:228
 #, c-format
-msgid ""
-"You asked to pull from the remote '%s', but did not specify\n"
-"a branch. Because this is not the default configured remote\n"
-"for your current branch, you must specify a branch on the command line."
-msgstr ""
-"您要求从远程 '%s' 拉取，但是未指定一个分支。因为这不是当前\n"
-"分支默认的远程仓库，您必须在命令行中指定一个分支名。"
+msgid "unusable todo list: '%s'"
+msgstr "不可用的待办列表：'%s'"
 
-#: builtin/pull.c:431 git-parse-remote.sh:73
-msgid "You are not currently on a branch."
-msgstr "您当前不在一个分支上。"
+#: builtin/rebase.c:186 builtin/rebase.c:212 builtin/rebase.c:236
+#, c-format
+msgid "could not write '%s'."
+msgstr "不能写入 '%s'。"
 
-#: builtin/pull.c:433 builtin/pull.c:448 git-parse-remote.sh:79
-msgid "Please specify which branch you want to rebase against."
-msgstr "请指定您要变基到哪一个分支。"
+#: builtin/rebase.c:271
+msgid "no HEAD?"
+msgstr "没有 HEAD？"
 
-#: builtin/pull.c:435 builtin/pull.c:450 git-parse-remote.sh:82
-msgid "Please specify which branch you want to merge with."
-msgstr "请指定您要合并哪一个分支。"
+#: builtin/rebase.c:298
+#, c-format
+msgid "could not create temporary %s"
+msgstr "无法创建临时的 %s"
 
-#: builtin/pull.c:436 builtin/pull.c:451
-msgid "See git-pull(1) for details."
-msgstr "详见 git-pull(1)。"
+#: builtin/rebase.c:304
+msgid "could not mark as interactive"
+msgstr "无法标记为交互式"
 
-#: builtin/pull.c:438 builtin/pull.c:444 builtin/pull.c:453
-#: git-parse-remote.sh:64
-msgid "<remote>"
-msgstr "<远程>"
+#: builtin/rebase.c:362
+msgid "could not generate todo list"
+msgstr "无法生成待办列表"
 
-#: builtin/pull.c:438 builtin/pull.c:453 builtin/pull.c:458 git-rebase.sh:523
-#: git-parse-remote.sh:65
-msgid "<branch>"
-msgstr "<分支>"
+#: builtin/rebase.c:402
+msgid "a base commit must be provided with --upstream or --onto"
+msgstr "使用 --upstream 或 --onto 必须提供一个基线提交"
+
+#: builtin/rebase.c:457
+msgid "git rebase--interactive [<options>]"
+msgstr "git rebase--interactive [<选项>]"
+
+#: builtin/rebase.c:469
+msgid "keep empty commits"
+msgstr "保持空提交"
+
+#: builtin/rebase.c:471 builtin/revert.c:128
+msgid "allow commits with empty messages"
+msgstr "允许提交说明为空"
+
+#: builtin/rebase.c:472
+msgid "rebase merge commits"
+msgstr "对合并提交变基"
+
+#: builtin/rebase.c:474
+msgid "keep original branch points of cousins"
+msgstr "保持兄弟提交的原始分支点"
+
+#: builtin/rebase.c:476
+msgid "move commits that begin with squash!/fixup!"
+msgstr "移动以 squash!/fixup! 开头的提交"
+
+#: builtin/rebase.c:477
+msgid "sign commits"
+msgstr "签名提交"
+
+#: builtin/rebase.c:479 builtin/rebase.c:1455
+msgid "display a diffstat of what changed upstream"
+msgstr "显示上游变化的差异统计"
+
+#: builtin/rebase.c:481
+msgid "continue rebase"
+msgstr "继续变基"
 
-#: builtin/pull.c:446 git-parse-remote.sh:75
-msgid "There is no tracking information for the current branch."
-msgstr "当前分支没有跟踪信息。"
+#: builtin/rebase.c:483
+msgid "skip commit"
+msgstr "跳过提交"
+
+#: builtin/rebase.c:484
+msgid "edit the todo list"
+msgstr "变基待办列表"
+
+#: builtin/rebase.c:486
+msgid "show the current patch"
+msgstr "显示当前补丁"
 
-#: builtin/pull.c:455 git-parse-remote.sh:95
-msgid ""
-"If you wish to set tracking information for this branch you can do so with:"
-msgstr "如果您想要为此分支创建跟踪信息，您可以执行："
+#: builtin/rebase.c:489
+msgid "shorten commit ids in the todo list"
+msgstr "缩短待办列表中的提交号"
 
-#: builtin/pull.c:460
-#, c-format
-msgid ""
-"Your configuration specifies to merge with the ref '%s'\n"
-"from the remote, but no such ref was fetched."
-msgstr ""
-"您的配置中指定要合并远程的引用 '%s'，\n"
-"但是没有获取到这个引用。"
+#: builtin/rebase.c:491
+msgid "expand commit ids in the todo list"
+msgstr "扩展待办列表中的提交号"
 
-#: builtin/pull.c:826
-msgid "ignoring --verify-signatures for rebase"
-msgstr "为变基操作忽略 --verify-signatures"
+#: builtin/rebase.c:493
+msgid "check the todo list"
+msgstr "检查待办列表"
 
-#: builtin/pull.c:874
-msgid "--[no-]autostash option is only valid with --rebase."
-msgstr "--[no-]autostash 选项只在使用 --rebase 时有效。"
+#: builtin/rebase.c:495
+msgid "rearrange fixup/squash lines"
+msgstr "重新排列 fixup/squash 行"
 
-#: builtin/pull.c:882
-msgid "Updating an unborn branch with changes added to the index."
-msgstr "更新尚未诞生的分支，变更添加至索引。"
+#: builtin/rebase.c:497
+msgid "insert exec commands in todo list"
+msgstr "在待办列表中插入 exec 执行命令"
 
-#: builtin/pull.c:885
-msgid "pull with rebase"
-msgstr "变基式拉取"
+#: builtin/rebase.c:498
+msgid "onto"
+msgstr "onto"
+
+#: builtin/rebase.c:501
+msgid "restrict-revision"
+msgstr "restrict-revision"
+
+#: builtin/rebase.c:501
+msgid "restrict revision"
+msgstr "限制版本"
+
+#: builtin/rebase.c:503
+msgid "squash-onto"
+msgstr "squash-onto"
+
+#: builtin/rebase.c:504
+msgid "squash onto"
+msgstr "squash onto"
+
+#: builtin/rebase.c:506
+msgid "the upstream commit"
+msgstr "上游提交"
+
+#: builtin/rebase.c:508
+msgid "head-name"
+msgstr "head-name"
+
+#: builtin/rebase.c:508
+msgid "head name"
+msgstr "head 名称"
+
+#: builtin/rebase.c:513
+msgid "rebase strategy"
+msgstr "变基策略"
+
+#: builtin/rebase.c:514
+msgid "strategy-opts"
+msgstr "strategy-opts"
+
+#: builtin/rebase.c:515
+msgid "strategy options"
+msgstr "策略选项"
+
+#: builtin/rebase.c:516
+msgid "switch-to"
+msgstr "切换到"
+
+#: builtin/rebase.c:517
+msgid "the branch or commit to checkout"
+msgstr "要检出的分支或提交"
+
+#: builtin/rebase.c:518
+msgid "onto-name"
+msgstr "onto-name"
+
+#: builtin/rebase.c:518
+msgid "onto name"
+msgstr "onto name"
+
+#: builtin/rebase.c:519
+msgid "cmd"
+msgstr "cmd"
+
+#: builtin/rebase.c:519
+msgid "the command to run"
+msgstr "要执行的命令"
+
+#: builtin/rebase.c:522 builtin/rebase.c:1540
+msgid "automatically re-schedule any `exec` that fails"
+msgstr "自动重新安排任何失败的 `exec`"
 
-#: builtin/pull.c:886
-msgid "please commit or stash them."
-msgstr "请提交或贮藏它们。"
+#: builtin/rebase.c:540
+msgid "--[no-]rebase-cousins has no effect without --rebase-merges"
+msgstr "不使用 --rebase-merges，则 --[no-]rebase-cousins 没有效果"
 
-#: builtin/pull.c:911
+#: builtin/rebase.c:556
 #, c-format
-msgid ""
-"fetch updated the current branch head.\n"
-"fast-forwarding your working tree from\n"
-"commit %s."
-msgstr ""
-"fetch 更新了当前的分支。快进您的工作区\n"
-"至提交 %s。"
+msgid "%s requires an interactive rebase"
+msgstr "%s 需要交互式变基"
 
-#: builtin/pull.c:916
+#: builtin/rebase.c:608
 #, c-format
-msgid ""
-"Cannot fast-forward your working tree.\n"
-"After making sure that you saved anything precious from\n"
-"$ git diff %s\n"
-"output, run\n"
-"$ git reset --hard\n"
-"to recover."
-msgstr ""
-"您当前的工作区无法执行快进操作。\n"
-"首先执行如下命令：\n"
-"$ git diff %s\n"
-"以确认所有有用的数据均已保存。然后执行下面的命令\n"
-"$ git reset --hard\n"
-"恢复之前的状态。"
-
-#: builtin/pull.c:931
-msgid "Cannot merge multiple branches into empty head."
-msgstr "无法将多个分支合并到空分支。"
+msgid "could not get 'onto': '%s'"
+msgstr "无法获取 'onto'：'%s'"
 
-#: builtin/pull.c:935
-msgid "Cannot rebase onto multiple branches."
-msgstr "无法变基到多个分支。"
+#: builtin/rebase.c:623
+#, c-format
+msgid "invalid orig-head: '%s'"
+msgstr "无效的原始 head：'%s'"
 
-#: builtin/pull.c:942
-msgid "cannot rebase with locally recorded submodule modifications"
-msgstr "本地子模组中有修改，无法变基"
+#: builtin/rebase.c:648
+#, c-format
+msgid "ignoring invalid allow_rerere_autoupdate: '%s'"
+msgstr "忽略无效的 allow_rerere_autoupdate：'%s'"
 
-#: builtin/push.c:19
-msgid "git push [<options>] [<repository> [<refspec>...]]"
-msgstr "git push [<选项>] [<仓库> [<引用规格>...]]"
+#: builtin/rebase.c:724
+#, c-format
+msgid "Could not read '%s'"
+msgstr "不能读取 '%s'"
 
-#: builtin/push.c:111
-msgid "tag shorthand without <tag>"
-msgstr "标签后面未提供 <标签> 参数"
+#: builtin/rebase.c:742
+#, c-format
+msgid "Cannot store %s"
+msgstr "不能存储 %s"
 
-#: builtin/push.c:121
-msgid "--delete only accepts plain target ref names"
-msgstr "--delete 只接受简单的目标引用名"
+#: builtin/rebase.c:849
+msgid "could not determine HEAD revision"
+msgstr "不能确定 HEAD 版本"
 
-#: builtin/push.c:165
+#: builtin/rebase.c:972 git-rebase--preserve-merges.sh:81
 msgid ""
-"\n"
-"To choose either option permanently, see push.default in 'git help config'."
+"Resolve all conflicts manually, mark them as resolved with\n"
+"\"git add/rm <conflicted_files>\", then run \"git rebase --continue\".\n"
+"You can instead skip this commit: run \"git rebase --skip\".\n"
+"To abort and get back to the state before \"git rebase\", run \"git rebase --"
+"abort\"."
 msgstr ""
-"\n"
-"为了永久地选择任一选项，参见 'git help config' 中的 push.default。"
+"手工解决所有冲突，执行 \"git add/rm <冲突的文件>\" 标记\n"
+"冲突已解决，然后执行 \"git rebase --continue\"。您也可以执行\n"
+"\"git rebase --skip\" 命令跳过这个提交。如果想要终止执行并回到\n"
+"\"git rebase\" 执行之前的状态，执行 \"git rebase --abort\"。"
 
-#: builtin/push.c:168
+#: builtin/rebase.c:1060
 #, c-format
 msgid ""
-"The upstream branch of your current branch does not match\n"
-"the name of your current branch.  To push to the upstream branch\n"
-"on the remote, use\n"
 "\n"
-"    git push %s HEAD:%s\n"
+"git encountered an error while preparing the patches to replay\n"
+"these revisions:\n"
 "\n"
-"To push to the branch of the same name on the remote, use\n"
+"    %s\n"
 "\n"
-"    git push %s %s\n"
-"%s"
+"As a result, git cannot rebase them."
 msgstr ""
-"如果您当前分支的上游分支和您当前分支名不匹配，为推送到远程的\n"
-"上游分支，使用\n"
 "\n"
-"    git push %s HEAD:%s\n"
+"在为重放这些版本而准备补丁时，git 遇到了一个错误：\n"
 "\n"
-"为推送至远程同名分支，使用\n"
+"    %s\n"
 "\n"
-"    git push %s %s\n"
-"%s"
+"因此 git 无法对其变基。"
 
-#: builtin/push.c:183
+#: builtin/rebase.c:1367
 #, c-format
 msgid ""
-"You are not currently on a branch.\n"
-"To push the history leading to the current (detached HEAD)\n"
-"state now, use\n"
+"%s\n"
+"Please specify which branch you want to rebase against.\n"
+"See git-rebase(1) for details.\n"
+"\n"
+"    git rebase '<branch>'\n"
 "\n"
-"    git push %s HEAD:<name-of-remote-branch>\n"
 msgstr ""
-"您当前不在一个分支上。\n"
-"现在为推送当前（分离头指针）的历史，使用\n"
+"%s\n"
+"请指定您要变基到哪个分支。\n"
+"详见 git-rebase(1)。\n"
+"\n"
+"    git rebase '<branch>'\n"
 "\n"
-"    git push %s HEAD:<远程分支名字>\n"
 
-#: builtin/push.c:197
+#: builtin/rebase.c:1383
 #, c-format
 msgid ""
-"The current branch %s has no upstream branch.\n"
-"To push the current branch and set the remote as upstream, use\n"
+"If you wish to set tracking information for this branch you can do so with:\n"
 "\n"
-"    git push --set-upstream %s %s\n"
-msgstr ""
-"当前分支 %s 没有对应的上游分支。\n"
-"为推送当前分支并建立与远程上游的跟踪，使用\n"
+"    git branch --set-upstream-to=%s/<branch> %s\n"
 "\n"
-"    git push --set-upstream %s %s\n"
-
-#: builtin/push.c:205
-#, c-format
-msgid "The current branch %s has multiple upstream branches, refusing to push."
-msgstr "当前分支 %s 有多个上游分支，拒绝推送。"
-
-#: builtin/push.c:208
-#, c-format
-msgid ""
-"You are pushing to remote '%s', which is not the upstream of\n"
-"your current branch '%s', without telling me what to push\n"
-"to update which remote branch."
-msgstr ""
-"您正推送至远程 '%s'（其并非当前分支 '%s' 的上游），\n"
-"而没有告诉我要推送什么、更新哪个远程分支。"
-
-#: builtin/push.c:267
-msgid ""
-"You didn't specify any refspecs to push, and push.default is \"nothing\"."
-msgstr "您没有为推送指定任何引用规格，并且 push.default 为 \"nothing\"。"
-
-#: builtin/push.c:274
-msgid ""
-"Updates were rejected because the tip of your current branch is behind\n"
-"its remote counterpart. Integrate the remote changes (e.g.\n"
-"'git pull ...') before pushing again.\n"
-"See the 'Note about fast-forwards' in 'git push --help' for details."
-msgstr ""
-"更新被拒绝，因为您当前分支的最新提交落后于其对应的远程分支。\n"
-"再次推送前，先与远程变更合并（如 'git pull ...'）。详见\n"
-"'git push --help' 中的 'Note about fast-forwards' 小节。"
-
-#: builtin/push.c:280
-msgid ""
-"Updates were rejected because a pushed branch tip is behind its remote\n"
-"counterpart. Check out this branch and integrate the remote changes\n"
-"(e.g. 'git pull ...') before pushing again.\n"
-"See the 'Note about fast-forwards' in 'git push --help' for details."
-msgstr ""
-"更新被拒绝，因为推送的一个分支的最新提交落后于其对应的远程分支。\n"
-"检出该分支并整合远程变更（如 'git pull ...'），然后再推送。详见\n"
-"'git push --help' 中的 'Note about fast-forwards' 小节。"
-
-#: builtin/push.c:286
-msgid ""
-"Updates were rejected because the remote contains work that you do\n"
-"not have locally. This is usually caused by another repository pushing\n"
-"to the same ref. You may want to first integrate the remote changes\n"
-"(e.g., 'git pull ...') before pushing again.\n"
-"See the 'Note about fast-forwards' in 'git push --help' for details."
 msgstr ""
-"更新被拒绝，因为远程仓库包含您本地尚不存在的提交。这通常是因为另外\n"
-"一个仓库已向该引用进行了推送。再次推送前，您可能需要先整合远程变更\n"
-"（如 'git pull ...'）。\n"
-"详见 'git push --help' 中的 'Note about fast-forwards' 小节。"
+"如果您想要为此分支创建跟踪信息，您可以执行：\n"
+"\n"
+"    git branch --set-upstream-to=%s/<branch> %s\n"
+"\n"
 
-#: builtin/push.c:293
-msgid "Updates were rejected because the tag already exists in the remote."
-msgstr "更新被拒绝，因为该标签在远程已经存在。"
+#: builtin/rebase.c:1413
+msgid "exec commands cannot contain newlines"
+msgstr "exec 命令不能包含换行符"
 
-#: builtin/push.c:296
-msgid ""
-"You cannot update a remote ref that points at a non-commit object,\n"
-"or update a remote ref to make it point at a non-commit object,\n"
-"without using the '--force' option.\n"
-msgstr ""
-"如果不使用 '--force' 参数，您不能更新一个指向非提交对象的远程引用，\n"
-"也不能更新远程引用让其指向一个非提交对象。\n"
+#: builtin/rebase.c:1417
+msgid "empty exec command"
+msgstr "空的 exec 命令"
 
-#: builtin/push.c:357
-#, c-format
-msgid "Pushing to %s\n"
-msgstr "推送到 %s\n"
+#: builtin/rebase.c:1446
+msgid "rebase onto given branch instead of upstream"
+msgstr "变基到给定的分支而非上游"
 
-#: builtin/push.c:361
-#, c-format
-msgid "failed to push some refs to '%s'"
-msgstr "无法推送一些引用到 '%s'"
+#: builtin/rebase.c:1448
+msgid "use the merge-base of upstream and branch as the current base"
+msgstr "使用上游和分支的合并基线做为当前基线"
 
-#: builtin/push.c:395
-#, c-format
-msgid "bad repository '%s'"
-msgstr "坏的仓库 '%s'"
+#: builtin/rebase.c:1450
+msgid "allow pre-rebase hook to run"
+msgstr "允许执行 pre-rebase 钩子"
 
-#: builtin/push.c:396
-msgid ""
-"No configured push destination.\n"
-"Either specify the URL from the command-line or configure a remote "
-"repository using\n"
-"\n"
-"    git remote add <name> <url>\n"
-"\n"
-"and then push using the remote name\n"
-"\n"
-"    git push <name>\n"
-msgstr ""
-"没有配置推送目标。\n"
-"或通过命令行指定 URL，或用下面命令配置一个远程仓库\n"
-"\n"
-"    git remote add <名称> <地址>\n"
-"\n"
-"然后使用该远程仓库名执行推送\n"
-"\n"
-"    git push <名称>\n"
+#: builtin/rebase.c:1452
+msgid "be quiet. implies --no-stat"
+msgstr "安静。暗示 --no-stat"
 
-#: builtin/push.c:551
-msgid "repository"
-msgstr "仓库"
+#: builtin/rebase.c:1458
+msgid "do not show diffstat of what changed upstream"
+msgstr "不显示上游变化的差异统计"
 
-#: builtin/push.c:552 builtin/send-pack.c:164
-msgid "push all refs"
-msgstr "推送所有引用"
+#: builtin/rebase.c:1461
+msgid "add a Signed-off-by: line to each commit"
+msgstr "为每一个提交添加一个 Signed-off-by: 签名"
 
-#: builtin/push.c:553 builtin/send-pack.c:166
-msgid "mirror all refs"
-msgstr "镜像所有引用"
+#: builtin/rebase.c:1464
+msgid "make committer date match author date"
+msgstr "让提交者日期匹配作者日期"
 
-#: builtin/push.c:555
-msgid "delete refs"
-msgstr "删除引用"
+#: builtin/rebase.c:1466
+msgid "ignore author date and use current date"
+msgstr "忽略作者日期并使用当前日期"
 
-#: builtin/push.c:556
-msgid "push tags (can't be used with --all or --mirror)"
-msgstr "推送标签（不能使用 --all or --mirror）"
+#: builtin/rebase.c:1468
+msgid "synonym of --reset-author-date"
+msgstr "--reset-author-date 的同义词"
 
-#: builtin/push.c:559 builtin/send-pack.c:167
-msgid "force updates"
-msgstr "强制更新"
+#: builtin/rebase.c:1470 builtin/rebase.c:1474
+msgid "passed to 'git apply'"
+msgstr "传递给 'git apply'"
 
-#: builtin/push.c:561 builtin/send-pack.c:181
-msgid "refname>:<expect"
-msgstr "引用名>:<期望值"
+#: builtin/rebase.c:1472
+msgid "ignore changes in whitespace"
+msgstr "忽略空白字符的变更"
 
-#: builtin/push.c:562 builtin/send-pack.c:182
-msgid "require old value of ref to be at this value"
-msgstr "要求引用旧的取值为设定值"
+#: builtin/rebase.c:1476 builtin/rebase.c:1479
+msgid "cherry-pick all commits, even if unchanged"
+msgstr "拣选所有提交，即使未修改"
 
-#: builtin/push.c:565
-msgid "control recursive pushing of submodules"
-msgstr "控制子模组的递归推送"
+#: builtin/rebase.c:1481
+msgid "continue"
+msgstr "继续"
 
-#: builtin/push.c:567 builtin/send-pack.c:175
-msgid "use thin pack"
-msgstr "使用精简打包"
+#: builtin/rebase.c:1484
+msgid "skip current patch and continue"
+msgstr "跳过当前补丁并继续"
 
-#: builtin/push.c:568 builtin/push.c:569 builtin/send-pack.c:161
-#: builtin/send-pack.c:162
-msgid "receive pack program"
-msgstr "接收包程序"
+#  译者：注意保持前导空格
+#: builtin/rebase.c:1486
+msgid "abort and check out the original branch"
+msgstr "终止并检出原有分支"
+
+#: builtin/rebase.c:1489
+msgid "abort but keep HEAD where it is"
+msgstr "终止但保持 HEAD 不变"
+
+#: builtin/rebase.c:1490
+msgid "edit the todo list during an interactive rebase"
+msgstr "在交互式变基中编辑待办列表"
+
+#: builtin/rebase.c:1493
+msgid "show the patch file being applied or merged"
+msgstr "显示正在应用或合并的补丁文件"
+
+#: builtin/rebase.c:1496
+msgid "use merging strategies to rebase"
+msgstr "使用合并策略进行变基"
+
+#: builtin/rebase.c:1500
+msgid "let the user edit the list of commits to rebase"
+msgstr "让用户编辑要变基的提交列表"
+
+#: builtin/rebase.c:1504
+msgid "(DEPRECATED) try to recreate merges instead of ignoring them"
+msgstr "（已弃用）尝试重建合并提交而非忽略它们"
+
+#: builtin/rebase.c:1509
+msgid "preserve empty commits during rebase"
+msgstr "变基时保留空提交"
+
+#: builtin/rebase.c:1511
+msgid "move commits that begin with squash!/fixup! under -i"
+msgstr "在 -i 交互模式下，移动以 squash!/fixup! 开头的提交"
+
+#: builtin/rebase.c:1517
+msgid "automatically stash/stash pop before and after"
+msgstr "在操作前后执行自动贮藏和弹出贮藏"
+
+#: builtin/rebase.c:1519
+msgid "add exec lines after each commit of the editable list"
+msgstr "可编辑列表的每一个提交下面增加一行 exec"
+
+#: builtin/rebase.c:1523
+msgid "allow rebasing commits with empty messages"
+msgstr "允许针对空提交说明的提交变基"
+
+#: builtin/rebase.c:1526
+msgid "try to rebase merges instead of skipping them"
+msgstr "尝试对合并提交变基而不是忽略它们"
+
+#: builtin/rebase.c:1529
+msgid "use 'merge-base --fork-point' to refine upstream"
+msgstr "使用 'merge-base --fork-point' 来优化上游"
+
+#: builtin/rebase.c:1531
+msgid "use the given merge strategy"
+msgstr "使用给定的合并策略"
 
-#: builtin/push.c:570
-msgid "set upstream for git pull/status"
-msgstr "设置 git pull/status 的上游"
+#: builtin/rebase.c:1533 builtin/revert.c:115
+msgid "option"
+msgstr "选项"
 
-#: builtin/push.c:573
-msgid "prune locally removed refs"
-msgstr "清除本地删除的引用"
+#: builtin/rebase.c:1534
+msgid "pass the argument through to the merge strategy"
+msgstr "将参数传递给合并策略"
 
-#: builtin/push.c:575
-msgid "bypass pre-push hook"
-msgstr "绕过 pre-push 钩子"
+#: builtin/rebase.c:1537
+msgid "rebase all reachable commits up to the root(s)"
+msgstr "将所有可达的提交变基到根提交"
 
-#: builtin/push.c:576
-msgid "push missing but relevant tags"
-msgstr "推送缺失但有关的标签"
+#: builtin/rebase.c:1554
+msgid ""
+"the rebase.useBuiltin support has been removed!\n"
+"See its entry in 'git help config' for details."
+msgstr ""
+"对 rebase.useBuiltin 的支持已被删除！\n"
+"详见 'git help config' 中的条目。"
 
-#: builtin/push.c:579 builtin/send-pack.c:169
-msgid "GPG sign the push"
-msgstr "用 GPG 为推送签名"
+#: builtin/rebase.c:1560
+msgid "It looks like 'git am' is in progress. Cannot rebase."
+msgstr "看起来 'git-am' 正在执行中。无法变基。"
 
-#: builtin/push.c:581 builtin/send-pack.c:176
-msgid "request atomic transaction on remote side"
-msgstr "需要远端支持原子事务"
+#: builtin/rebase.c:1601
+msgid ""
+"git rebase --preserve-merges is deprecated. Use --rebase-merges instead."
+msgstr "git rebase --preserve-merges 被弃用。用 --rebase-merges 代替。"
 
-#: builtin/push.c:599
-msgid "--delete is incompatible with --all, --mirror and --tags"
-msgstr "--delete 与 --all、--mirror 及 --tags 不兼容"
+#: builtin/rebase.c:1606
+msgid "cannot combine '--keep-base' with '--onto'"
+msgstr "不能将 '--keep-base' 和 '--onto' 组合使用"
 
-#: builtin/push.c:601
-msgid "--delete doesn't make sense without any refs"
-msgstr "--delete 未接任何引用没有意义"
+#: builtin/rebase.c:1608
+msgid "cannot combine '--keep-base' with '--root'"
+msgstr "不能将 '--keep-base' 和 '--root' 组合使用"
 
-#: builtin/push.c:604
-msgid "--all and --tags are incompatible"
-msgstr "--all 和 --tags 不兼容"
+#: builtin/rebase.c:1612
+msgid "No rebase in progress?"
+msgstr "没有正在进行的变基？"
 
-#: builtin/push.c:606
-msgid "--all can't be combined with refspecs"
-msgstr "--all 不能和引用规格同时使用"
+#: builtin/rebase.c:1616
+msgid "The --edit-todo action can only be used during interactive rebase."
+msgstr "动作 --edit-todo 只能用在交互式变基过程中。"
 
-#: builtin/push.c:610
-msgid "--mirror and --tags are incompatible"
-msgstr "--mirror 和 --tags 不兼容"
+#: builtin/rebase.c:1639
+msgid "Cannot read HEAD"
+msgstr "不能读取 HEAD"
 
-#: builtin/push.c:612
-msgid "--mirror can't be combined with refspecs"
-msgstr "--mirror 不能和引用规格同时使用"
+#: builtin/rebase.c:1651
+msgid ""
+"You must edit all merge conflicts and then\n"
+"mark them as resolved using git add"
+msgstr ""
+"您必须编辑所有的合并冲突，然后通过 git add\n"
+"命令将它们标记为已解决"
 
-#: builtin/push.c:615
-msgid "--all and --mirror are incompatible"
-msgstr "--all 和 --mirror 不兼容"
+#: builtin/rebase.c:1670
+msgid "could not discard worktree changes"
+msgstr "无法丢弃工作区变更"
 
-#: builtin/push.c:634
-msgid "push options must not have new line characters"
-msgstr "推送选项不能有换行符"
+#: builtin/rebase.c:1689
+#, c-format
+msgid "could not move back to %s"
+msgstr "无法移回 %s"
 
-#: builtin/read-tree.c:40
+#: builtin/rebase.c:1734
+#, c-format
 msgid ""
-"git read-tree [(-m [--trivial] [--aggressive] | --reset | --prefix=<prefix>) "
-"[-u [--exclude-per-directory=<gitignore>] | -i]] [--no-sparse-checkout] [--"
-"index-output=<file>] (--empty | <tree-ish1> [<tree-ish2> [<tree-ish3>]])"
+"It seems that there is already a %s directory, and\n"
+"I wonder if you are in the middle of another rebase.  If that is the\n"
+"case, please try\n"
+"\t%s\n"
+"If that is not the case, please\n"
+"\t%s\n"
+"and run me again.  I am stopping in case you still have something\n"
+"valuable there.\n"
 msgstr ""
-"git read-tree [(-m [--trivial] [--aggressive] | --reset | --prefix=<前缀>) [-"
-"u [--exclude-per-directory=<gitignore>] | -i]] [--no-sparse-checkout] [--"
-"index-output=<文件>] (--empty | <树对象1> [<树对象2> [<树对象3>]])"
+"似乎已有一个 %s 目录，我怀疑您正处于另外一个变基操作过程中。\n"
+"如果是这样，请执行\n"
+"\t%s\n"
+"如果不是这样，请执行\n"
+"\t%s\n"
+"然后再重新执行。 为避免丢失重要数据，我已经停止当前操作。\n"
 
-#: builtin/read-tree.c:120
-msgid "write resulting index to <file>"
-msgstr "将索引结果写入 <文件>"
+#: builtin/rebase.c:1757
+msgid "switch `C' expects a numerical value"
+msgstr "开关 `C' 期望一个数字值"
 
-#: builtin/read-tree.c:123
-msgid "only empty the index"
-msgstr "只是清空索引"
+#: builtin/rebase.c:1798
+#, c-format
+msgid "Unknown mode: %s"
+msgstr "未知模式：%s"
 
-#: builtin/read-tree.c:125
-msgid "Merging"
-msgstr "合并"
+#: builtin/rebase.c:1820
+msgid "--strategy requires --merge or --interactive"
+msgstr "--strategy 需要 --merge 或 --interactive"
 
-#: builtin/read-tree.c:127
-msgid "perform a merge in addition to a read"
-msgstr "读取之余再执行一个合并"
+#: builtin/rebase.c:1860
+msgid "--reschedule-failed-exec requires --exec or --interactive"
+msgstr "--reschedule-failed-exec 需要 --exec 或 --interactive"
 
-#: builtin/read-tree.c:129
-msgid "3-way merge if no file level merging required"
-msgstr "如果没有文件级合并需要，执行三方合并"
+#: builtin/rebase.c:1872
+msgid "cannot combine am options with either interactive or merge options"
+msgstr "不能将 am 选项与交互或合并选项同时使用"
 
-#: builtin/read-tree.c:131
-msgid "3-way merge in presence of adds and removes"
-msgstr "存在添加和删除时，也执行三方合并"
+#: builtin/rebase.c:1891
+msgid "cannot combine '--preserve-merges' with '--rebase-merges'"
+msgstr "不能将 '--preserve-merges' 和 '--rebase-merges' 同时使用"
 
-#: builtin/read-tree.c:133
-msgid "same as -m, but discard unmerged entries"
-msgstr "类似于 -m，但丢弃未合并的条目"
+#: builtin/rebase.c:1895
+msgid ""
+"error: cannot combine '--preserve-merges' with '--reschedule-failed-exec'"
+msgstr ""
+"错误：不能将 '--preserve-merges' 和 '--reschedule-failed-exec' 同时使用"
 
-#: builtin/read-tree.c:134
-msgid "<subdirectory>/"
-msgstr "<子目录>/"
+#: builtin/rebase.c:1919
+#, c-format
+msgid "invalid upstream '%s'"
+msgstr "无效的上游 '%s'"
 
-#: builtin/read-tree.c:135
-msgid "read the tree into the index under <subdirectory>/"
-msgstr "读取树对象到索引的 <子目录>/ 下"
+#: builtin/rebase.c:1925
+msgid "Could not create new root commit"
+msgstr "不能创建新的根提交"
 
-#: builtin/read-tree.c:138
-msgid "update working tree with merge result"
-msgstr "用合并的结果更新工作区"
+#: builtin/rebase.c:1951
+#, c-format
+msgid "'%s': need exactly one merge base with branch"
+msgstr "'%s'：只需要与分支的一个合并基线"
 
-#: builtin/read-tree.c:140
-msgid "gitignore"
-msgstr "gitignore"
+#: builtin/rebase.c:1954
+#, c-format
+msgid "'%s': need exactly one merge base"
+msgstr "'%s'：只需要一个合并基线"
 
-#: builtin/read-tree.c:141
-msgid "allow explicitly ignored files to be overwritten"
-msgstr "允许忽略文件中设定的文件可以被覆盖"
+#: builtin/rebase.c:1962
+#, c-format
+msgid "Does not point to a valid commit '%s'"
+msgstr "没有指向一个有效的提交 '%s'"
 
-#: builtin/read-tree.c:144
-msgid "don't check the working tree after merging"
-msgstr "合并后不检查工作区"
+#: builtin/rebase.c:1987
+#, c-format
+msgid "fatal: no such branch/commit '%s'"
+msgstr "致命错误：无此分支/提交 '%s'"
 
-#: builtin/read-tree.c:145
-msgid "don't update the index or the work tree"
-msgstr "不更新索引区和工作区"
+#: builtin/rebase.c:1995 builtin/submodule--helper.c:40
+#: builtin/submodule--helper.c:1961
+#, c-format
+msgid "No such ref: %s"
+msgstr "没有这样的引用：%s"
 
-#: builtin/read-tree.c:147
-msgid "skip applying sparse checkout filter"
-msgstr "跳过应用稀疏检出过滤器"
+#: builtin/rebase.c:2006
+msgid "Could not resolve HEAD to a revision"
+msgstr "无法将 HEAD 解析为一个版本"
 
-#: builtin/read-tree.c:149
-msgid "debug unpack-trees"
-msgstr "调试 unpack-trees"
+#: builtin/rebase.c:2044
+msgid "Cannot autostash"
+msgstr "无法 autostash"
 
-#: builtin/rebase--helper.c:8
-msgid "git rebase--helper [<options>]"
-msgstr "git rebase--helper [<选项>]"
+#: builtin/rebase.c:2047
+#, c-format
+msgid "Unexpected stash response: '%s'"
+msgstr "意外的 stash 响应：'%s'"
 
-#: builtin/rebase--helper.c:24
-msgid "keep empty commits"
-msgstr "保持空提交"
+#: builtin/rebase.c:2053
+#, c-format
+msgid "Could not create directory for '%s'"
+msgstr "不能为 '%s' 创建目录"
 
-#: builtin/rebase--helper.c:26 builtin/revert.c:123
-msgid "allow commits with empty messages"
-msgstr "允许提交说明为空"
+#: builtin/rebase.c:2056
+#, c-format
+msgid "Created autostash: %s\n"
+msgstr "创建了 autostash：%s\n"
 
-#: builtin/rebase--helper.c:27
-msgid "rebase merge commits"
-msgstr "对合并提交变基"
+#: builtin/rebase.c:2059
+msgid "could not reset --hard"
+msgstr "无法 reset --hard"
 
-#: builtin/rebase--helper.c:29
-msgid "keep original branch points of cousins"
-msgstr "保持兄弟提交的原始分支点"
+#: builtin/rebase.c:2068
+msgid "Please commit or stash them."
+msgstr "请提交或贮藏修改。"
 
-#: builtin/rebase--helper.c:30
-msgid "continue rebase"
-msgstr "继续变基"
+#: builtin/rebase.c:2095
+#, c-format
+msgid "could not parse '%s'"
+msgstr "无法解析 '%s'"
 
-#: builtin/rebase--helper.c:32
-msgid "abort rebase"
-msgstr "中止变基"
-
-#: builtin/rebase--helper.c:35
-msgid "make rebase script"
-msgstr "制作变基脚本"
+#: builtin/rebase.c:2108
+#, c-format
+msgid "could not switch to %s"
+msgstr "无法切换到 %s"
 
-#: builtin/rebase--helper.c:37
-msgid "shorten commit ids in the todo list"
-msgstr "缩短待办列表中的提交号"
+#: builtin/rebase.c:2119
+msgid "HEAD is up to date."
+msgstr "HEAD 是最新的。"
 
-#: builtin/rebase--helper.c:39
-msgid "expand commit ids in the todo list"
-msgstr "扩展待办列表中的提交号"
+#: builtin/rebase.c:2121
+#, c-format
+msgid "Current branch %s is up to date.\n"
+msgstr "当前分支 %s 是最新的。\n"
 
-#: builtin/rebase--helper.c:41
-msgid "check the todo list"
-msgstr "检查待办列表"
+#: builtin/rebase.c:2129
+msgid "HEAD is up to date, rebase forced."
+msgstr "HEAD 是最新的，强制变基。"
 
-#: builtin/rebase--helper.c:43
-msgid "skip unnecessary picks"
-msgstr "跳过不必要的拣选"
+#: builtin/rebase.c:2131
+#, c-format
+msgid "Current branch %s is up to date, rebase forced.\n"
+msgstr "当前分支 %s 是最新的，强制变基。\n"
 
-#: builtin/rebase--helper.c:45
-msgid "rearrange fixup/squash lines"
-msgstr "重新排列 fixup/squash 行"
+#: builtin/rebase.c:2139
+msgid "The pre-rebase hook refused to rebase."
+msgstr "pre-rebase 钩子拒绝了变基操作。"
 
-#: builtin/rebase--helper.c:47
-msgid "insert exec commands in todo list"
-msgstr "在待办列表中插入 exec 执行命令"
+#: builtin/rebase.c:2146
+#, c-format
+msgid "Changes to %s:\n"
+msgstr "到 %s 的变更：\n"
 
-#: builtin/rebase--helper.c:68
-msgid "--[no-]rebase-cousins has no effect without --rebase-merges"
-msgstr "不使用 --rebase-merges，则 --[no-]rebase-cousins 没有效果"
+#: builtin/rebase.c:2149
+#, c-format
+msgid "Changes from %s to %s:\n"
+msgstr "从 %s 到 %s 的变更：\n"
+
+#: builtin/rebase.c:2174
+#, c-format
+msgid "First, rewinding head to replay your work on top of it...\n"
+msgstr "首先，回退头指针以便在其上重放您的工作...\n"
 
-#: builtin/receive-pack.c:31
+#: builtin/rebase.c:2183
+msgid "Could not detach HEAD"
+msgstr "无法分离头指针"
+
+#: builtin/rebase.c:2192
+#, c-format
+msgid "Fast-forwarded %s to %s.\n"
+msgstr "快进 %s 到 %s。\n"
+
+#: builtin/receive-pack.c:32
 msgid "git receive-pack <git-dir>"
 msgstr "git receive-pack <仓库目录>"
 
-#: builtin/receive-pack.c:842
+#: builtin/receive-pack.c:830
 msgid ""
 "By default, updating the current branch in a non-bare repository\n"
 "is denied, because it will make the index and work tree inconsistent\n"
@@ -12668,7 +18118,7 @@ msgstr ""
 "若要屏蔽此信息且保持默认行为，设置 'receive.denyCurrentBranch'\n"
 "配置变量为 'refuse'。"
 
-#: builtin/receive-pack.c:862
+#: builtin/receive-pack.c:850
 msgid ""
 "By default, deleting the current branch is denied, because the next\n"
 "'git clone' won't result in any file checked out, causing confusion.\n"
@@ -12687,24 +18137,79 @@ msgstr ""
 "\n"
 "若要屏蔽此信息，您可以设置它为 'refuse'。"
 
-#: builtin/receive-pack.c:1935
+#: builtin/receive-pack.c:1936
 msgid "quiet"
 msgstr "静默模式"
 
-#: builtin/receive-pack.c:1949
+#: builtin/receive-pack.c:1950
 msgid "You must specify a directory."
 msgstr "您必须指定一个目录。"
 
-#: builtin/reflog.c:532 builtin/reflog.c:537
+#: builtin/reflog.c:17
+msgid ""
+"git reflog expire [--expire=<time>] [--expire-unreachable=<time>] [--"
+"rewrite] [--updateref] [--stale-fix] [--dry-run | -n] [--verbose] [--all] "
+"<refs>..."
+msgstr ""
+"git reflog expire [--expire=<时间>] [--expire-unreachable=<时间>] [--"
+"rewrite] [--updateref] [--stale-fix] [--dry-run | -n] [--verbose] [--all] <引"
+"用>..."
+
+#: builtin/reflog.c:22
+msgid ""
+"git reflog delete [--rewrite] [--updateref] [--dry-run | -n] [--verbose] "
+"<refs>..."
+msgstr ""
+"git reflog delete [--rewrite] [--updateref] [--dry-run | -n] [--verbose] <引"
+"用>..."
+
+#: builtin/reflog.c:25
+msgid "git reflog exists <ref>"
+msgstr "git reflog exists <引用>"
+
+#: builtin/reflog.c:567 builtin/reflog.c:572
 #, c-format
 msgid "'%s' is not a valid timestamp"
 msgstr "'%s' 不是一个有效的时间戳"
 
-#: builtin/remote.c:14
+#: builtin/reflog.c:605
+#, c-format
+msgid "Marking reachable objects..."
+msgstr "正在标记可达对象..."
+
+#: builtin/reflog.c:643
+#, c-format
+msgid "%s points nowhere!"
+msgstr "%s 指向不存在！"
+
+#: builtin/reflog.c:695
+msgid "no reflog specified to delete"
+msgstr "未指定要删除的引用日志"
+
+#: builtin/reflog.c:704
+#, c-format
+msgid "not a reflog: %s"
+msgstr "不是一个引用日志：%s"
+
+#: builtin/reflog.c:709
+#, c-format
+msgid "no reflog for '%s'"
+msgstr "没有 '%s' 的引用日志"
+
+#: builtin/reflog.c:755
+#, c-format
+msgid "invalid ref format: %s"
+msgstr "无效的引用格式：%s"
+
+#: builtin/reflog.c:764
+msgid "git reflog [ show | expire | delete | exists ]"
+msgstr "git reflog [ show | expire | delete | exists ]"
+
+#: builtin/remote.c:16
 msgid "git remote [-v | --verbose]"
 msgstr "git remote [-v | --verbose]"
 
-#: builtin/remote.c:15
+#: builtin/remote.c:17
 msgid ""
 "git remote add [-t <branch>] [-m <master>] [-f] [--tags | --no-tags] [--"
 "mirror=<fetch|push>] <name> <url>"
@@ -12712,81 +18217,81 @@ msgstr ""
 "git remote add [-t <分支>] [-m <master>] [-f] [--tags | --no-tags] [--"
 "mirror=<fetch|push>] <名称> <地址>"
 
-#: builtin/remote.c:16 builtin/remote.c:36
+#: builtin/remote.c:18 builtin/remote.c:38
 msgid "git remote rename <old> <new>"
 msgstr "git remote rename <旧名称> <新名称>"
 
-#: builtin/remote.c:17 builtin/remote.c:41
+#: builtin/remote.c:19 builtin/remote.c:43
 msgid "git remote remove <name>"
 msgstr "git remote remove <名称>"
 
-#: builtin/remote.c:18 builtin/remote.c:46
+#: builtin/remote.c:20 builtin/remote.c:48
 msgid "git remote set-head <name> (-a | --auto | -d | --delete | <branch>)"
 msgstr "git remote set-head <名称> (-a | --auto | -d | --delete | <分支>)"
 
-#: builtin/remote.c:19
+#: builtin/remote.c:21
 msgid "git remote [-v | --verbose] show [-n] <name>"
 msgstr "git remote [-v | --verbose] show [-n] <名称>"
 
-#: builtin/remote.c:20
+#: builtin/remote.c:22
 msgid "git remote prune [-n | --dry-run] <name>"
 msgstr "git remote prune [-n | --dry-run] <名称>"
 
-#: builtin/remote.c:21
+#: builtin/remote.c:23
 msgid ""
 "git remote [-v | --verbose] update [-p | --prune] [(<group> | <remote>)...]"
 msgstr "git remote [-v | --verbose] update [-p | --prune] [(<组> | <远程>)...]"
 
-#: builtin/remote.c:22
+#: builtin/remote.c:24
 msgid "git remote set-branches [--add] <name> <branch>..."
 msgstr "git remote set-branches [--add] <名称> <分支>..."
 
-#: builtin/remote.c:23 builtin/remote.c:72
+#: builtin/remote.c:25 builtin/remote.c:74
 msgid "git remote get-url [--push] [--all] <name>"
 msgstr "git remote get-url [--push] [--all] <名称>"
 
-#: builtin/remote.c:24 builtin/remote.c:77
+#: builtin/remote.c:26 builtin/remote.c:79
 msgid "git remote set-url [--push] <name> <newurl> [<oldurl>]"
 msgstr "git remote set-url [--push] <名称> <新的地址> [<旧的地址>]"
 
-#: builtin/remote.c:25 builtin/remote.c:78
+#: builtin/remote.c:27 builtin/remote.c:80
 msgid "git remote set-url --add <name> <newurl>"
 msgstr "git remote set-url --add <名称> <新的地址>"
 
-#: builtin/remote.c:26 builtin/remote.c:79
+#: builtin/remote.c:28 builtin/remote.c:81
 msgid "git remote set-url --delete <name> <url>"
 msgstr "git remote set-url --delete <名称> <地址>"
 
-#: builtin/remote.c:31
+#: builtin/remote.c:33
 msgid "git remote add [<options>] <name> <url>"
 msgstr "git remote add [<选项>] <名称> <地址>"
 
-#: builtin/remote.c:51
+#: builtin/remote.c:53
 msgid "git remote set-branches <name> <branch>..."
 msgstr "git remote set-branches <名称> <分支>..."
 
-#: builtin/remote.c:52
+#: builtin/remote.c:54
 msgid "git remote set-branches --add <name> <branch>..."
 msgstr "git remote set-branches --add <名称> <分支>..."
 
-#: builtin/remote.c:57
+#: builtin/remote.c:59
 msgid "git remote show [<options>] <name>"
 msgstr "git remote show [<选项>] <名称>"
 
-#: builtin/remote.c:62
+#: builtin/remote.c:64
 msgid "git remote prune [<options>] <name>"
 msgstr "git remote prune [<选项>] <名称>"
 
-#: builtin/remote.c:67
+#: builtin/remote.c:69
 msgid "git remote update [<options>] [<group> | <remote>]..."
 msgstr "git remote update [<选项>] [<组> | <远程>]..."
 
-#: builtin/remote.c:96
+#: builtin/remote.c:98
 #, c-format
 msgid "Updating %s"
 msgstr "更新 %s 中"
 
-#: builtin/remote.c:128
+#: builtin/remote.c:130
 msgid ""
 "--mirror is dangerous and deprecated; please\n"
 "\t use --mirror=fetch or --mirror=push instead"
@@ -12794,86 +18299,82 @@ msgstr ""
 "--mirror 选项危险且过时，请使用 --mirror=fetch\n"
 "\t 或 --mirror=push"
 
-#: builtin/remote.c:145
+#: builtin/remote.c:147
 #, c-format
 msgid "unknown mirror argument: %s"
 msgstr "未知的镜像参数：%s"
 
-#: builtin/remote.c:161
+#: builtin/remote.c:163
 msgid "fetch the remote branches"
 msgstr "抓取远程的分支"
 
-#: builtin/remote.c:163
+#: builtin/remote.c:165
 msgid "import all tags and associated objects when fetching"
 msgstr "抓取时导入所有的标签和关联对象"
 
-#: builtin/remote.c:166
+#: builtin/remote.c:168
 msgid "or do not fetch any tag at all (--no-tags)"
 msgstr "或不抓取任何标签（--no-tags）"
 
-#: builtin/remote.c:168
+#: builtin/remote.c:170
 msgid "branch(es) to track"
 msgstr "跟踪的分支"
 
-#: builtin/remote.c:169
+#: builtin/remote.c:171
 msgid "master branch"
 msgstr "主线分支"
 
-#: builtin/remote.c:170
-msgid "push|fetch"
-msgstr "push|fetch"
-
-#: builtin/remote.c:171
+#: builtin/remote.c:173
 msgid "set up remote as a mirror to push to or fetch from"
 msgstr "把远程设置为用以推送或抓取的镜像"
 
-#: builtin/remote.c:183
+#: builtin/remote.c:185
 msgid "specifying a master branch makes no sense with --mirror"
 msgstr "指定一个 master 分支并使用 --mirror 选项没有意义"
 
-#: builtin/remote.c:185
+#: builtin/remote.c:187
 msgid "specifying branches to track makes sense only with fetch mirrors"
 msgstr "指定要跟踪的分支只在与获取镜像同时使用才有意义"
 
-#: builtin/remote.c:192 builtin/remote.c:634
+#: builtin/remote.c:194 builtin/remote.c:636
 #, c-format
 msgid "remote %s already exists."
 msgstr "远程 %s 已经存在。"
 
-#: builtin/remote.c:196 builtin/remote.c:638
+#: builtin/remote.c:198 builtin/remote.c:640
 #, c-format
 msgid "'%s' is not a valid remote name"
 msgstr "'%s' 不是一个有效的远程名称"
 
-#: builtin/remote.c:236
+#: builtin/remote.c:238
 #, c-format
 msgid "Could not setup master '%s'"
 msgstr "无法设置 master '%s'"
 
-#: builtin/remote.c:342
+#: builtin/remote.c:344
 #, c-format
 msgid "Could not get fetch map for refspec %s"
 msgstr "无法得到引用规格 %s 的获取列表"
 
-#: builtin/remote.c:441 builtin/remote.c:449
+#: builtin/remote.c:443 builtin/remote.c:451
 msgid "(matching)"
 msgstr "（匹配）"
 
-#: builtin/remote.c:453
+#: builtin/remote.c:455
 msgid "(delete)"
 msgstr "（删除）"
 
-#: builtin/remote.c:627 builtin/remote.c:762 builtin/remote.c:861
+#: builtin/remote.c:629 builtin/remote.c:764 builtin/remote.c:863
 #, c-format
-msgid "No such remote: %s"
-msgstr "没有这样的远程：%s"
+msgid "No such remote: '%s'"
+msgstr "没有此远程仓库：'%s'"
 
-#: builtin/remote.c:644
+#: builtin/remote.c:646
 #, c-format
 msgid "Could not rename config section '%s' to '%s'"
 msgstr "不能重命名配置小节 '%s' 到 '%s'"
 
-#: builtin/remote.c:664
+#: builtin/remote.c:666
 #, c-format
 msgid ""
 "Not updating non-default fetch refspec\n"
@@ -12884,17 +18385,17 @@ msgstr ""
 "\t%s\n"
 "\t如果必要请手动更新配置。"
 
-#: builtin/remote.c:700
+#: builtin/remote.c:701
 #, c-format
 msgid "deleting '%s' failed"
 msgstr "删除 '%s' 失败"
 
-#: builtin/remote.c:734
+#: builtin/remote.c:735
 #, c-format
 msgid "creating '%s' failed"
 msgstr "创建 '%s' 失败"
 
-#: builtin/remote.c:799
+#: builtin/remote.c:801
 msgid ""
 "Note: A branch outside the refs/remotes/ hierarchy was not removed;\n"
 "to delete it, use:"
@@ -12904,118 +18405,118 @@ msgid_plural ""
 msgstr[0] "注意：ref/remotes 层级之外的一个分支未被移除。要删除它，使用："
 msgstr[1] "注意：ref/remotes 层级之外的一些分支未被移除。要删除它们，使用："
 
-#: builtin/remote.c:813
+#: builtin/remote.c:815
 #, c-format
 msgid "Could not remove config section '%s'"
 msgstr "不能移除配置小节 '%s'"
 
-#: builtin/remote.c:914
+#: builtin/remote.c:916
 #, c-format
 msgid " new (next fetch will store in remotes/%s)"
 msgstr " 新的（下一次获取将存储于 remotes/%s）"
 
-#: builtin/remote.c:917
+#: builtin/remote.c:919
 msgid " tracked"
 msgstr " 已跟踪"
 
-#: builtin/remote.c:919
+#: builtin/remote.c:921
 msgid " stale (use 'git remote prune' to remove)"
 msgstr " 过时（使用 'git remote prune' 来移除）"
 
-#: builtin/remote.c:921
+#: builtin/remote.c:923
 msgid " ???"
 msgstr " ???"
 
-#: builtin/remote.c:962
+#: builtin/remote.c:964
 #, c-format
 msgid "invalid branch.%s.merge; cannot rebase onto > 1 branch"
 msgstr "无效的 branch.%s.merge，不能变基到一个以上的分支"
 
-#: builtin/remote.c:971
+#: builtin/remote.c:973
 #, c-format
 msgid "rebases interactively onto remote %s"
 msgstr "交互式变基到远程 %s"
 
-#: builtin/remote.c:973
+#: builtin/remote.c:975
 #, c-format
 msgid "rebases interactively (with merges) onto remote %s"
 msgstr "交互式变基（含合并提交）到远程 %s"
 
-#: builtin/remote.c:976
+#: builtin/remote.c:978
 #, c-format
 msgid "rebases onto remote %s"
 msgstr "变基到远程 %s"
 
-#: builtin/remote.c:980
+#: builtin/remote.c:982
 #, c-format
 msgid " merges with remote %s"
 msgstr " 与远程 %s 合并"
 
-#: builtin/remote.c:983
+#: builtin/remote.c:985
 #, c-format
 msgid "merges with remote %s"
 msgstr "与远程 %s 合并"
 
-#: builtin/remote.c:986
+#: builtin/remote.c:988
 #, c-format
 msgid "%-*s    and with remote %s\n"
 msgstr "%-*s    以及和远程 %s\n"
 
-#: builtin/remote.c:1029
+#: builtin/remote.c:1031
 msgid "create"
 msgstr "创建"
 
-#: builtin/remote.c:1032
+#: builtin/remote.c:1034
 msgid "delete"
 msgstr "删除"
 
-#: builtin/remote.c:1036
+#: builtin/remote.c:1038
 msgid "up to date"
 msgstr "最新"
 
-#: builtin/remote.c:1039
+#: builtin/remote.c:1041
 msgid "fast-forwardable"
 msgstr "可快进"
 
-#: builtin/remote.c:1042
+#: builtin/remote.c:1044
 msgid "local out of date"
 msgstr "本地已过时"
 
-#: builtin/remote.c:1049
+#: builtin/remote.c:1051
 #, c-format
 msgid "    %-*s forces to %-*s (%s)"
 msgstr "    %-*s 强制推送至 %-*s (%s)"
 
-#: builtin/remote.c:1052
+#: builtin/remote.c:1054
 #, c-format
 msgid "    %-*s pushes to %-*s (%s)"
 msgstr "    %-*s 推送至 %-*s (%s)"
 
-#: builtin/remote.c:1056
+#: builtin/remote.c:1058
 #, c-format
 msgid "    %-*s forces to %s"
 msgstr "    %-*s 强制推送至 %s"
 
-#: builtin/remote.c:1059
+#: builtin/remote.c:1061
 #, c-format
 msgid "    %-*s pushes to %s"
 msgstr "    %-*s 推送至 %s"
 
-#: builtin/remote.c:1127
+#: builtin/remote.c:1129
 msgid "do not query remotes"
 msgstr "不查询远程"
 
-#: builtin/remote.c:1154
+#: builtin/remote.c:1156
 #, c-format
 msgid "* remote %s"
 msgstr "* 远程 %s"
 
-#: builtin/remote.c:1155
+#: builtin/remote.c:1157
 #, c-format
 msgid "  Fetch URL: %s"
 msgstr "  获取地址：%s"
 
-#: builtin/remote.c:1156 builtin/remote.c:1172 builtin/remote.c:1311
+#: builtin/remote.c:1158 builtin/remote.c:1174 builtin/remote.c:1313
 msgid "(no URL)"
 msgstr "(无 URL)"
 
@@ -13023,32 +18524,32 @@ msgstr "(无 URL)"
 #. with the one in " Fetch URL: %s"
 #. translation.
 #.
-#: builtin/remote.c:1170 builtin/remote.c:1172
+#: builtin/remote.c:1172 builtin/remote.c:1174
 #, c-format
 msgid "  Push  URL: %s"
 msgstr "  推送地址：%s"
 
-#: builtin/remote.c:1174 builtin/remote.c:1176 builtin/remote.c:1178
+#: builtin/remote.c:1176 builtin/remote.c:1178 builtin/remote.c:1180
 #, c-format
 msgid "  HEAD branch: %s"
 msgstr "  HEAD 分支：%s"
 
 #  译者：中文字符串拼接，可删除前导空格
-#: builtin/remote.c:1174
+#: builtin/remote.c:1176
 msgid "(not queried)"
 msgstr "（未查询）"
 
-#: builtin/remote.c:1176
+#: builtin/remote.c:1178
 msgid "(unknown)"
 msgstr "（未知）"
 
-#: builtin/remote.c:1180
+#: builtin/remote.c:1182
 #, c-format
 msgid ""
 "  HEAD branch (remote HEAD is ambiguous, may be one of the following):\n"
 msgstr "  HEAD 分支（远程 HEAD 模糊，可能是下列中的一个）：\n"
 
-#: builtin/remote.c:1192
+#: builtin/remote.c:1194
 #, c-format
 msgid "  Remote branch:%s"
 msgid_plural "  Remote branches:%s"
@@ -13056,164 +18557,155 @@ msgstr[0] "  远程分支：%s"
 msgstr[1] "  远程分支：%s"
 
 #  译者：中文字符串拼接，可删除前导空格
-#: builtin/remote.c:1195 builtin/remote.c:1221
+#: builtin/remote.c:1197 builtin/remote.c:1223
 msgid " (status not queried)"
 msgstr "（状态未查询）"
 
-#: builtin/remote.c:1204
+#: builtin/remote.c:1206
 msgid "  Local branch configured for 'git pull':"
 msgid_plural "  Local branches configured for 'git pull':"
 msgstr[0] "  为 'git pull' 配置的本地分支："
 msgstr[1] "  为 'git pull' 配置的本地分支："
 
-#: builtin/remote.c:1212
+#: builtin/remote.c:1214
 msgid "  Local refs will be mirrored by 'git push'"
 msgstr "  本地引用将在 'git push' 时被镜像"
 
-#: builtin/remote.c:1218
+#: builtin/remote.c:1220
 #, c-format
 msgid "  Local ref configured for 'git push'%s:"
 msgid_plural "  Local refs configured for 'git push'%s:"
 msgstr[0] "  为 'git push' 配置的本地引用%s："
 msgstr[1] "  为 'git push' 配置的本地引用%s："
 
-#: builtin/remote.c:1239
+#: builtin/remote.c:1241
 msgid "set refs/remotes/<name>/HEAD according to remote"
 msgstr "根据远程设置 refs/remotes/<名称>/HEAD"
 
-#: builtin/remote.c:1241
+#: builtin/remote.c:1243
 msgid "delete refs/remotes/<name>/HEAD"
 msgstr "删除 refs/remotes/<名称>/HEAD"
 
-#: builtin/remote.c:1256
+#: builtin/remote.c:1258
 msgid "Cannot determine remote HEAD"
 msgstr "无法确定远程 HEAD"
 
-#: builtin/remote.c:1258
+#: builtin/remote.c:1260
 msgid "Multiple remote HEAD branches. Please choose one explicitly with:"
 msgstr "多个远程 HEAD 分支。请明确地选择一个用命令："
 
-#: builtin/remote.c:1268
+#: builtin/remote.c:1270
 #, c-format
 msgid "Could not delete %s"
 msgstr "无法删除 %s"
 
-#: builtin/remote.c:1276
+#: builtin/remote.c:1278
 #, c-format
 msgid "Not a valid ref: %s"
 msgstr "不是一个有效引用：%s"
 
-#: builtin/remote.c:1278
+#: builtin/remote.c:1280
 #, c-format
 msgid "Could not setup %s"
 msgstr "不能设置 %s"
 
 #  译者：注意保持前导空格
-#: builtin/remote.c:1296
+#: builtin/remote.c:1298
 #, c-format
 msgid " %s will become dangling!"
-msgstr " %s 将成为摇摆状态！"
+msgstr " %s 将成为悬空状态！"
 
 #  译者：注意保持前导空格
-#: builtin/remote.c:1297
+#: builtin/remote.c:1299
 #, c-format
 msgid " %s has become dangling!"
-msgstr " %s 已成为摇摆状态！"
+msgstr " %s 已成为悬空状态！"
 
-#: builtin/remote.c:1307
+#: builtin/remote.c:1309
 #, c-format
 msgid "Pruning %s"
 msgstr "修剪 %s"
 
-#: builtin/remote.c:1308
+#: builtin/remote.c:1310
 #, c-format
 msgid "URL: %s"
 msgstr "URL：%s"
 
-#: builtin/remote.c:1324
+#: builtin/remote.c:1326
 #, c-format
 msgid " * [would prune] %s"
 msgstr " * [将删除] %s"
 
-#: builtin/remote.c:1327
+#: builtin/remote.c:1329
 #, c-format
 msgid " * [pruned] %s"
 msgstr " * [已删除] %s"
 
-#: builtin/remote.c:1372
+#: builtin/remote.c:1374
 msgid "prune remotes after fetching"
 msgstr "抓取后清除远程"
 
-#: builtin/remote.c:1435 builtin/remote.c:1489 builtin/remote.c:1557
+#: builtin/remote.c:1437 builtin/remote.c:1491 builtin/remote.c:1559
 #, c-format
 msgid "No such remote '%s'"
 msgstr "没有此远程 '%s'"
 
-#: builtin/remote.c:1451
+#: builtin/remote.c:1453
 msgid "add branch"
 msgstr "添加分支"
 
-#: builtin/remote.c:1458
+#: builtin/remote.c:1460
 msgid "no remote specified"
 msgstr "未指定远程"
 
-#: builtin/remote.c:1475
+#: builtin/remote.c:1477
 msgid "query push URLs rather than fetch URLs"
 msgstr "查询推送 URL 地址，而非获取 URL 地址"
 
-#: builtin/remote.c:1477
+#: builtin/remote.c:1479
 msgid "return all URLs"
 msgstr "返回所有 URL 地址"
 
-#: builtin/remote.c:1505
+#: builtin/remote.c:1507
 #, c-format
 msgid "no URLs configured for remote '%s'"
 msgstr "没有给远程仓库 '%s' 设定 URL"
 
-#: builtin/remote.c:1531
+#: builtin/remote.c:1533
 msgid "manipulate push URLs"
 msgstr "操作推送 URLS"
 
-#: builtin/remote.c:1533
+#: builtin/remote.c:1535
 msgid "add URL"
 msgstr "添加 URL"
 
-#: builtin/remote.c:1535
+#: builtin/remote.c:1537
 msgid "delete URLs"
 msgstr "删除 URLS"
 
-#: builtin/remote.c:1542
+#: builtin/remote.c:1544
 msgid "--add --delete doesn't make sense"
 msgstr "--add --delete 无意义"
 
-#: builtin/remote.c:1581
+#: builtin/remote.c:1583
 #, c-format
 msgid "Invalid old URL pattern: %s"
 msgstr "无效的旧 URL 匹配模版：%s"
 
-#: builtin/remote.c:1589
+#: builtin/remote.c:1591
 #, c-format
 msgid "No such URL found: %s"
 msgstr "未找到此 URL：%s"
 
-#: builtin/remote.c:1591
+#: builtin/remote.c:1593
 msgid "Will not delete all non-push URLs"
 msgstr "将不会删除所有非推送 URL 地址"
 
-#: builtin/remote.c:1607
-msgid "be verbose; must be placed before a subcommand"
-msgstr "冗长输出；必须置于子命令之前"
-
-#: builtin/remote.c:1638
-#, c-format
-msgid "Unknown subcommand: %s"
-msgstr "未知子命令：%s"
-
-#: builtin/repack.c:18
+#: builtin/repack.c:23
 msgid "git repack [<options>]"
 msgstr "git repack [<选项>]"
 
-#: builtin/repack.c:23
+#: builtin/repack.c:28
 msgid ""
 "Incremental repacks are incompatible with bitmap indexes.  Use\n"
 "--no-write-bitmap-index or disable the pack.writebitmaps configuration."
@@ -13221,156 +18713,301 @@ msgstr ""
 "增量 repack 和 bitmap 索引不兼容。  使用 --no-write-bitmap-index\n"
 "或禁用 pack.writebitmaps 配置。"
 
-#: builtin/repack.c:180
+#: builtin/repack.c:191
+msgid "could not start pack-objects to repack promisor objects"
+msgstr "无法开始 pack-objects 来重新打包 promisor 对象"
+
+#: builtin/repack.c:230 builtin/repack.c:416
+msgid "repack: Expecting full hex object ID lines only from pack-objects."
+msgstr "repack：期望来自 pack-objects 的完整十六进制对象 ID。"
+
+#: builtin/repack.c:254
+msgid "could not finish pack-objects to repack promisor objects"
+msgstr "无法完成 pack-objects 来重新打包 promisor 对象"
+
+#: builtin/repack.c:292
 msgid "pack everything in a single pack"
 msgstr "所有内容打包到一个包文件中"
 
-#: builtin/repack.c:182
+#: builtin/repack.c:294
 msgid "same as -a, and turn unreachable objects loose"
 msgstr "和 -a 相同，并将不可达的对象设为松散对象"
 
-#: builtin/repack.c:185
+#: builtin/repack.c:297
 msgid "remove redundant packs, and run git-prune-packed"
 msgstr "删除多余的包，运行 git-prune-packed"
 
-#: builtin/repack.c:187
+#: builtin/repack.c:299
 msgid "pass --no-reuse-delta to git-pack-objects"
 msgstr "向 git-pack-objects 传递参数 --no-reuse-delta"
 
-#: builtin/repack.c:189
+#: builtin/repack.c:301
 msgid "pass --no-reuse-object to git-pack-objects"
 msgstr "向 git-pack-objects 传递参数 --no-reuse-object"
 
-#: builtin/repack.c:191
+#: builtin/repack.c:303
 msgid "do not run git-update-server-info"
 msgstr "不运行 git-update-server-info"
 
-#: builtin/repack.c:194
+#: builtin/repack.c:306
 msgid "pass --local to git-pack-objects"
 msgstr "向 git-pack-objects 传递参数 --local"
 
-#: builtin/repack.c:196
+#: builtin/repack.c:308
 msgid "write bitmap index"
 msgstr "写 bitmap 索引"
 
-#: builtin/repack.c:197
+#: builtin/repack.c:310
+msgid "pass --delta-islands to git-pack-objects"
+msgstr "向 git-pack-objects 传递参数 --delta-islands"
+
+#: builtin/repack.c:311
 msgid "approxidate"
 msgstr "近似日期"
 
-#: builtin/repack.c:198
+#: builtin/repack.c:312
 msgid "with -A, do not loosen objects older than this"
 msgstr "使用 -A，不要将早于给定时间的对象过期"
 
-#: builtin/repack.c:200
+#: builtin/repack.c:314
 msgid "with -a, repack unreachable objects"
 msgstr "使用 -a ，重新对不可达对象打包"
 
-#: builtin/repack.c:202
+#: builtin/repack.c:316
 msgid "size of the window used for delta compression"
 msgstr "用于增量压缩的窗口值"
 
-#: builtin/repack.c:203 builtin/repack.c:209
+#: builtin/repack.c:317 builtin/repack.c:323
 msgid "bytes"
 msgstr "字节"
 
-#: builtin/repack.c:204
+#: builtin/repack.c:318
 msgid "same as the above, but limit memory size instead of entries count"
 msgstr "和上面的相似，但限制内存大小而非条目数"
 
-#: builtin/repack.c:206
+#: builtin/repack.c:320
 msgid "limits the maximum delta depth"
 msgstr "限制最大增量深度"
 
-#: builtin/repack.c:208
+#: builtin/repack.c:322
 msgid "limits the maximum number of threads"
 msgstr "限制最大线程数"
 
-#: builtin/repack.c:210
+#: builtin/repack.c:324
 msgid "maximum size of each packfile"
 msgstr "每个包文件的最大尺寸"
 
-#: builtin/repack.c:212
+#: builtin/repack.c:326
 msgid "repack objects in packs marked with .keep"
 msgstr "对标记为 .keep 的包中的对象重新打包"
 
-#: builtin/repack.c:214
+#: builtin/repack.c:328
 msgid "do not repack this pack"
 msgstr "不要对该包文件重新打包"
 
-#: builtin/repack.c:224
+#: builtin/repack.c:338
 msgid "cannot delete packs in a precious-objects repo"
 msgstr "不能删除珍品仓库中的打包文件"
 
-#: builtin/repack.c:228
+#: builtin/repack.c:342
 msgid "--keep-unreachable and -A are incompatible"
 msgstr "--keep-unreachable 和 -A 不兼容"
 
-#: builtin/repack.c:425 builtin/worktree.c:139
+#: builtin/repack.c:425
+msgid "Nothing new to pack."
+msgstr "没有新的要打包。"
+
+#: builtin/repack.c:486
+#, c-format
+msgid ""
+"WARNING: Some packs in use have been renamed by\n"
+"WARNING: prefixing old- to their name, in order to\n"
+"WARNING: replace them with the new version of the\n"
+"WARNING: file.  But the operation failed, and the\n"
+"WARNING: attempt to rename them back to their\n"
+"WARNING: original names also failed.\n"
+"WARNING: Please rename them in %s manually:\n"
+msgstr ""
+"警告：为了将包文件替换为新版本，一些使用中的包已经\n"
+"警告：通过添加 old- 前缀的方式重命名。但是操作失败，\n"
+"警告：并且尝试重命名改回原有文件名的操作也失败。\n"
+"警告：请手动将 %s 下的这些文件重命名：\n"
+
+#: builtin/repack.c:534
 #, c-format
 msgid "failed to remove '%s'"
-msgstr "无法删除 '%s'"
+msgstr "删除 '%s' 失败"
 
 #: builtin/replace.c:22
 msgid "git replace [-f] <object> <replacement>"
 msgstr "git replace [-f] <对象> <替换物>"
 
-#: builtin/replace.c:23
-msgid "git replace [-f] --edit <object>"
-msgstr "git replace [-f] --edit <对象>"
+#: builtin/replace.c:23
+msgid "git replace [-f] --edit <object>"
+msgstr "git replace [-f] --edit <对象>"
+
+#: builtin/replace.c:24
+msgid "git replace [-f] --graft <commit> [<parent>...]"
+msgstr "git replace [-f] --graft <提交> [<父提交>...]"
+
+#: builtin/replace.c:25
+msgid "git replace [-f] --convert-graft-file"
+msgstr "git replace [-f] --convert-graft-file"
+
+#: builtin/replace.c:26
+msgid "git replace -d <object>..."
+msgstr "git replace -d <对象>..."
+
+#: builtin/replace.c:27
+msgid "git replace [--format=<format>] [-l [<pattern>]]"
+msgstr "git replace [--format=<格式>] [-l [<模式>]]"
+
+#: builtin/replace.c:90
+#, c-format
+msgid ""
+"invalid replace format '%s'\n"
+"valid formats are 'short', 'medium' and 'long'"
+msgstr ""
+"无效的替换格式 '%s'\n"
+"有效的格式有 'short'、'medium' 和 'long'"
+
+#: builtin/replace.c:125
+#, c-format
+msgid "replace ref '%s' not found"
+msgstr "未发现替换引用 '%s'"
+
+#: builtin/replace.c:141
+#, c-format
+msgid "Deleted replace ref '%s'"
+msgstr "已删除替换引用 '%s'"
+
+#: builtin/replace.c:153
+#, c-format
+msgid "'%s' is not a valid ref name"
+msgstr "'%s' 不是一个有效的引用名"
+
+#: builtin/replace.c:158
+#, c-format
+msgid "replace ref '%s' already exists"
+msgstr "替换引用 '%s' 已经存在"
+
+#: builtin/replace.c:178
+#, c-format
+msgid ""
+"Objects must be of the same type.\n"
+"'%s' points to a replaced object of type '%s'\n"
+"while '%s' points to a replacement object of type '%s'."
+msgstr ""
+"对象必须属于同一类型。\n"
+"'%s' 指向 '%s' 类型的替换对象\n"
+"而 '%s' 指向 '%s' 类型的替换对象。"
+
+#: builtin/replace.c:229
+#, c-format
+msgid "unable to open %s for writing"
+msgstr "无法为写入打开 %s"
+
+#: builtin/replace.c:242
+msgid "cat-file reported failure"
+msgstr "cat-file 报告失败"
+
+#: builtin/replace.c:258
+#, c-format
+msgid "unable to open %s for reading"
+msgstr "无法为读取打开 %s"
+
+#: builtin/replace.c:272
+msgid "unable to spawn mktree"
+msgstr "无法启动 mktree"
+
+#: builtin/replace.c:276
+msgid "unable to read from mktree"
+msgstr "无法从 mktree 读取"
 
-#: builtin/replace.c:24
-msgid "git replace [-f] --graft <commit> [<parent>...]"
-msgstr "git replace [-f] --graft <提交> [<父提交>...]"
+#: builtin/replace.c:285
+msgid "mktree reported failure"
+msgstr "mktree 报告失败"
 
-#: builtin/replace.c:25
-msgid "git replace [-f] --convert-graft-file"
-msgstr "git replace [-f] --convert-graft-file"
+#: builtin/replace.c:289
+msgid "mktree did not return an object name"
+msgstr "mktree 没有返回一个对象名"
 
-#: builtin/replace.c:26
-msgid "git replace -d <object>..."
-msgstr "git replace -d <对象>..."
+#: builtin/replace.c:298
+#, c-format
+msgid "unable to fstat %s"
+msgstr "无法对 %s 执行 fstat"
 
-#: builtin/replace.c:27
-msgid "git replace [--format=<format>] [-l [<pattern>]]"
-msgstr "git replace [--format=<格式>] [-l [<模式>]]"
+#: builtin/replace.c:303
+msgid "unable to write object to database"
+msgstr "无法向数据库写入对象"
 
-#: builtin/replace.c:371 builtin/replace.c:415 builtin/replace.c:445
+#: builtin/replace.c:322 builtin/replace.c:378 builtin/replace.c:423
+#: builtin/replace.c:453
 #, c-format
-msgid "Not a valid object name: '%s'"
+msgid "not a valid object name: '%s'"
 msgstr "不是一个有效的对象名：'%s'"
 
-#: builtin/replace.c:407
+#: builtin/replace.c:326
+#, c-format
+msgid "unable to get object type for %s"
+msgstr "无法得到 %s 的对象类型"
+
+#: builtin/replace.c:342
+msgid "editing object file failed"
+msgstr "编辑对象文件失败"
+
+#: builtin/replace.c:351
+#, c-format
+msgid "new object is the same as the old one: '%s'"
+msgstr "新对象和旧对象相同：'%s'"
+
+#: builtin/replace.c:384
+#, c-format
+msgid "could not parse %s as a commit"
+msgstr "无法将 %s 解析为一个提交"
+
+#: builtin/replace.c:415
 #, c-format
 msgid "bad mergetag in commit '%s'"
 msgstr "提交 '%s' 中含有损坏的合并标签"
 
-#: builtin/replace.c:409
+#: builtin/replace.c:417
 #, c-format
 msgid "malformed mergetag in commit '%s'"
 msgstr "提交 '%s' 中含有格式错误的合并标签"
 
-#: builtin/replace.c:421
+#: builtin/replace.c:429
 #, c-format
 msgid ""
 "original commit '%s' contains mergetag '%s' that is discarded; use --edit "
 "instead of --graft"
 msgstr "原始提交 '%s' 包含已经丢弃的合并标签 '%s'，使用 --edit 代替 --graft"
 
-#: builtin/replace.c:460
+#: builtin/replace.c:468
 #, c-format
-msgid "the original commit '%s' has a gpg signature."
-msgstr "原始提交 '%s' 中包含一个 GPG 签名"
+msgid "the original commit '%s' has a gpg signature"
+msgstr "原始提交 '%s' 中有一个 gpg 签名"
 
-#: builtin/replace.c:461
+#: builtin/replace.c:469
 msgid "the signature will be removed in the replacement commit!"
 msgstr "在替换的提交中签名将被移除！"
 
-#: builtin/replace.c:471
+#: builtin/replace.c:479
 #, c-format
 msgid "could not write replacement commit for: '%s'"
 msgstr "不能为 '%s' 写替换提交"
 
-#: builtin/replace.c:514
+#: builtin/replace.c:487
+#, c-format
+msgid "graft for '%s' unnecessary"
+msgstr "对 '%s' 移植没有必要"
+
+#: builtin/replace.c:491
+#, c-format
+msgid "new commit is the same as the old one: '%s'"
+msgstr "新提交和旧的一样：'%s'"
+
+#: builtin/replace.c:526
 #, c-format
 msgid ""
 "could not convert the following graft(s):\n"
@@ -13379,212 +19016,271 @@ msgstr ""
 "不能转换下列移植：\n"
 "%s"
 
-#: builtin/replace.c:535
+#: builtin/replace.c:547
 msgid "list replace refs"
 msgstr "列出替换的引用"
 
-#: builtin/replace.c:536
+#: builtin/replace.c:548
 msgid "delete replace refs"
 msgstr "删除替换的引用"
 
-#: builtin/replace.c:537
+#: builtin/replace.c:549
 msgid "edit existing object"
 msgstr "编辑现存的对象"
 
-#: builtin/replace.c:538
+#: builtin/replace.c:550
 msgid "change a commit's parents"
 msgstr "修改一个提交的父提交"
 
-#: builtin/replace.c:539
+#: builtin/replace.c:551
 msgid "convert existing graft file"
 msgstr "转换现存的移植文件"
 
-#: builtin/replace.c:540
+#: builtin/replace.c:552
 msgid "replace the ref if it exists"
 msgstr "如果存在则替换引用"
 
-#: builtin/replace.c:542
+#: builtin/replace.c:554
 msgid "do not pretty-print contents for --edit"
 msgstr "不要为 --edit 操作美观显示内容"
 
-#: builtin/replace.c:543
+#: builtin/replace.c:555
 msgid "use this format"
 msgstr "使用此格式"
 
+#: builtin/replace.c:568
+msgid "--format cannot be used when not listing"
+msgstr "不列出时不能使用 --format"
+
+#: builtin/replace.c:576
+msgid "-f only makes sense when writing a replacement"
+msgstr "只有写一个替换时 -f 才有意义"
+
+#: builtin/replace.c:580
+msgid "--raw only makes sense with --edit"
+msgstr "--raw 只有和 --edit 共用才有意义"
+
+#: builtin/replace.c:586
+msgid "-d needs at least one argument"
+msgstr "-d 需要至少一个参数"
+
+#: builtin/replace.c:592
+msgid "bad number of arguments"
+msgstr "错误的参数个数"
+
+#: builtin/replace.c:598
+msgid "-e needs exactly one argument"
+msgstr "-e 需要且仅需要一个参数"
+
+#: builtin/replace.c:604
+msgid "-g needs at least one argument"
+msgstr "-g 需要至少一个参数"
+
+#: builtin/replace.c:610
+msgid "--convert-graft-file takes no argument"
+msgstr "--convert-graft-file 不带参数"
+
+#: builtin/replace.c:616
+msgid "only one pattern can be given with -l"
+msgstr "只能为 -l 提供一个模式"
+
 #: builtin/rerere.c:13
 msgid "git rerere [clear | forget <path>... | status | remaining | diff | gc]"
 msgstr "git rerere [clear | forget <路径>... | status | remaining | diff | gc]"
 
-#: builtin/rerere.c:59
+#: builtin/rerere.c:60
 msgid "register clean resolutions in index"
 msgstr "在索引中注册干净的解决方案"
 
-#: builtin/reset.c:29
+#: builtin/rerere.c:79
+msgid "'git rerere forget' without paths is deprecated"
+msgstr "没有路径的 'git rerere forget' 已经过时"
+
+#: builtin/rerere.c:113
+#, c-format
+msgid "unable to generate diff for '%s'"
+msgstr "无法为 '%s' 生成差异"
+
+#: builtin/reset.c:32
 msgid ""
 "git reset [--mixed | --soft | --hard | --merge | --keep] [-q] [<commit>]"
 msgstr "git reset [--mixed | --soft | --hard | --merge | --keep] [-q] [<提交>]"
 
-#: builtin/reset.c:30
-msgid "git reset [-q] [<tree-ish>] [--] <paths>..."
-msgstr "git reset [-q] [<树或提交>] [--] <路径>..."
-
-#: builtin/reset.c:31
-msgid "git reset --patch [<tree-ish>] [--] [<paths>...]"
-msgstr "git reset --patch [<树或提交>] [--] [<路径>...]"
+#: builtin/reset.c:33
+msgid "git reset [-q] [<tree-ish>] [--] <pathspec>..."
+msgstr "git reset [-q] [<树对象>] [--] <路径表达式>..."
+
+#: builtin/reset.c:34
+msgid ""
+"git reset [-q] [--pathspec-from-file [--pathspec-file-nul]] [<tree-ish>]"
+msgstr ""
+"git reset [-q] [--pathspec-from-file [--pathspec-file-nul]] [<树对象>]"
 
-#: builtin/reset.c:37
+#: builtin/reset.c:35
+msgid "git reset --patch [<tree-ish>] [--] [<pathspec>...]"
+msgstr "git reset --patch [<树对象>] [--] [<路径表达式>...]"
+
+#: builtin/reset.c:41
 msgid "mixed"
 msgstr "混杂"
 
-#: builtin/reset.c:37
+#: builtin/reset.c:41
 msgid "soft"
 msgstr "软性"
 
-#: builtin/reset.c:37
+#: builtin/reset.c:41
 msgid "hard"
 msgstr "硬性"
 
-#: builtin/reset.c:37
+#: builtin/reset.c:41
 msgid "merge"
 msgstr "合并"
 
-#: builtin/reset.c:37
+#: builtin/reset.c:41
 msgid "keep"
 msgstr "保持"
 
-#: builtin/reset.c:78
+#: builtin/reset.c:82
 msgid "You do not have a valid HEAD."
 msgstr "您没有一个有效的 HEAD。"
 
-#: builtin/reset.c:80
+#: builtin/reset.c:84
 msgid "Failed to find tree of HEAD."
 msgstr "无法找到 HEAD 指向的树。"
 
-#: builtin/reset.c:86
+#: builtin/reset.c:90
 #, c-format
 msgid "Failed to find tree of %s."
 msgstr "无法找到 %s 指向的树。"
 
-#: builtin/reset.c:111
+#: builtin/reset.c:115
 #, c-format
 msgid "HEAD is now at %s"
 msgstr "HEAD 现在位于 %s"
 
 #  译者：汉字之间无空格，故删除%s前后空格
-#: builtin/reset.c:189
+#: builtin/reset.c:194
 #, c-format
 msgid "Cannot do a %s reset in the middle of a merge."
 msgstr "在合并过程中不能做%s重置操作。"
 
-#: builtin/reset.c:289
+#: builtin/reset.c:294 builtin/stash.c:519 builtin/stash.c:594
+#: builtin/stash.c:618
 msgid "be quiet, only report errors"
 msgstr "安静模式，只报告错误"
 
-#: builtin/reset.c:291
+#: builtin/reset.c:296
 msgid "reset HEAD and index"
 msgstr "重置 HEAD 和索引"
 
-#: builtin/reset.c:292
+#: builtin/reset.c:297
 msgid "reset only HEAD"
 msgstr "只重置 HEAD"
 
-#: builtin/reset.c:294 builtin/reset.c:296
+#: builtin/reset.c:299 builtin/reset.c:301
 msgid "reset HEAD, index and working tree"
 msgstr "重置 HEAD、索引和工作区"
 
-#: builtin/reset.c:298
+#: builtin/reset.c:303
 msgid "reset HEAD but keep local changes"
 msgstr "重置 HEAD 但保存本地变更"
 
-#: builtin/reset.c:304
+#: builtin/reset.c:309
 msgid "record only the fact that removed paths will be added later"
 msgstr "将删除的路径标记为稍后添加"
 
-#: builtin/reset.c:321
+#: builtin/reset.c:343
 #, c-format
 msgid "Failed to resolve '%s' as a valid revision."
 msgstr "无法将 '%s' 解析为一个有效的版本。"
 
-#: builtin/reset.c:329
+#: builtin/reset.c:351
 #, c-format
 msgid "Failed to resolve '%s' as a valid tree."
 msgstr "无法将 '%s' 解析为一个有效的树对象。"
 
-#: builtin/reset.c:338
+#: builtin/reset.c:360
 msgid "--patch is incompatible with --{hard,mixed,soft}"
 msgstr "--patch 与 --{hard、mixed、soft} 选项不兼容"
 
-#: builtin/reset.c:347
+#: builtin/reset.c:370
 msgid "--mixed with paths is deprecated; use 'git reset -- <paths>' instead."
 msgstr "--mixed 带路径已弃用，而是用 'git reset -- <路径>'。"
 
 #  译者：汉字之间无空格，故删除%s前后空格
-#: builtin/reset.c:349
+#: builtin/reset.c:372
 #, c-format
 msgid "Cannot do %s reset with paths."
 msgstr "不能带路径进行%s重置。"
 
 #  译者：汉字之间无空格，故删除%s前后空格
-#: builtin/reset.c:359
+#: builtin/reset.c:387
 #, c-format
 msgid "%s reset is not allowed in a bare repository"
 msgstr "不能对纯仓库进行%s重置"
 
-#: builtin/reset.c:363
+#: builtin/reset.c:391
 msgid "-N can only be used with --mixed"
 msgstr "-N 只能和 --mixed 同时使用"
 
-#: builtin/reset.c:380
+#: builtin/reset.c:412
 msgid "Unstaged changes after reset:"
 msgstr "重置后取消暂存的变更："
 
-#: builtin/reset.c:386
+#: builtin/reset.c:415
+#, c-format
+msgid ""
+"\n"
+"It took %.2f seconds to enumerate unstaged changes after reset.  You can\n"
+"use '--quiet' to avoid this.  Set the config setting reset.quiet to true\n"
+"to make this the default.\n"
+msgstr ""
+"\n"
+"重置后，枚举未暂存变更花费了 %.2f 秒。 您可以使用 '--quiet' 避免此情况。\n"
+"将配置变量 reset.quiet 设置为 true 可使其成为默认值。\n"
+
+#: builtin/reset.c:425
 #, c-format
 msgid "Could not reset index file to revision '%s'."
 msgstr "不能重置索引文件至版本 '%s'。"
 
-#: builtin/reset.c:390
+#: builtin/reset.c:429
 msgid "Could not write new index file."
 msgstr "不能写入新的索引文件。"
 
-#: builtin/rev-list.c:397
+#: builtin/rev-list.c:411
 msgid "cannot combine --exclude-promisor-objects and --missing"
 msgstr "不能同时使用 --exclude-promisor-objects 和 --missing 选项"
 
-#: builtin/rev-list.c:455
+#: builtin/rev-list.c:472
 msgid "object filtering requires --objects"
 msgstr "对象过滤需要 --objects"
 
-#: builtin/rev-list.c:458
-#, c-format
-msgid "invalid sparse value '%s'"
-msgstr "无效的稀疏值 '%s'"
-
-#: builtin/rev-list.c:499
+#: builtin/rev-list.c:522
 msgid "rev-list does not support display of notes"
 msgstr "rev-list 不支持显示注解"
 
-#: builtin/rev-list.c:502
+#: builtin/rev-list.c:525
 msgid "cannot combine --use-bitmap-index with object filtering"
 msgstr "不能将 --use-bitmap-index 和对象过滤组合使用"
 
-#: builtin/rev-parse.c:406
+#: builtin/rev-parse.c:408
 msgid "git rev-parse --parseopt [<options>] -- [<args>...]"
 msgstr "git rev-parse --parseopt [<选项>] -- [<参数>...]"
 
-#: builtin/rev-parse.c:411
+#: builtin/rev-parse.c:413
 msgid "keep the `--` passed as an arg"
 msgstr "保持 `--` 作为一个参数传递"
 
-#: builtin/rev-parse.c:413
+#: builtin/rev-parse.c:415
 msgid "stop parsing after the first non-option argument"
 msgstr "遇到第一个非选项参数后停止解析"
 
-#: builtin/rev-parse.c:416
+#: builtin/rev-parse.c:418
 msgid "output in stuck long form"
 msgstr "以固定长格式输出"
 
-#: builtin/rev-parse.c:549
+#: builtin/rev-parse.c:551
 msgid ""
 "git rev-parse --parseopt [<options>] -- [<args>...]\n"
 "   or: git rev-parse --sq-quote [<arg>...]\n"
@@ -13598,92 +19294,97 @@ msgstr ""
 "\n"
 "初次使用时执行 \"git rev-parse --parseopt -h\" 来获得更多信息。"
 
-#: builtin/revert.c:23
+#: builtin/revert.c:24
 msgid "git revert [<options>] <commit-ish>..."
 msgstr "git revert [<选项>] <提交号>..."
 
-#: builtin/revert.c:24
+#: builtin/revert.c:25
 msgid "git revert <subcommand>"
 msgstr "git revert <子命令>"
 
-#: builtin/revert.c:29
+#: builtin/revert.c:30
 msgid "git cherry-pick [<options>] <commit-ish>..."
 msgstr "git cherry-pick [<选项>] <提交号>..."
 
-#: builtin/revert.c:30
+#: builtin/revert.c:31
 msgid "git cherry-pick <subcommand>"
 msgstr "git cherry-pick <子命令>"
 
-#: builtin/revert.c:90
+#: builtin/revert.c:72
+#, c-format
+msgid "option `%s' expects a number greater than zero"
+msgstr "选项 `%s' 期望一个大于零的数字"
+
+#: builtin/revert.c:92
 #, c-format
 msgid "%s: %s cannot be used with %s"
 msgstr "%s：%s 不能和 %s 同时使用"
 
-#: builtin/revert.c:99
+#: builtin/revert.c:102
 msgid "end revert or cherry-pick sequence"
 msgstr "终止反转或拣选操作"
 
-#: builtin/revert.c:100
+#: builtin/revert.c:103
 msgid "resume revert or cherry-pick sequence"
 msgstr "继续反转或拣选操作"
 
-#: builtin/revert.c:101
+#: builtin/revert.c:104
 msgid "cancel revert or cherry-pick sequence"
 msgstr "取消反转或拣选操作"
 
-#: builtin/revert.c:102
+#: builtin/revert.c:105
+msgid "skip current commit and continue"
+msgstr "跳过当前提交并继续"
+
+#: builtin/revert.c:107
 msgid "don't automatically commit"
 msgstr "不要自动提交"
 
-#: builtin/revert.c:103
+#: builtin/revert.c:108
 msgid "edit the commit message"
 msgstr "编辑提交说明"
 
-#: builtin/revert.c:106
+#: builtin/revert.c:111
 msgid "parent-number"
 msgstr "父编号"
 
-#: builtin/revert.c:107
+#: builtin/revert.c:112
 msgid "select mainline parent"
 msgstr "选择主干父提交编号"
 
-#: builtin/revert.c:109
+#: builtin/revert.c:114
 msgid "merge strategy"
 msgstr "合并策略"
 
-#: builtin/revert.c:110
-msgid "option"
-msgstr "选项"
-
-#: builtin/revert.c:111
+#: builtin/revert.c:116
 msgid "option for merge strategy"
 msgstr "合并策略的选项"
 
-#: builtin/revert.c:120
+#: builtin/revert.c:125
 msgid "append commit name"
 msgstr "追加提交名称"
 
-#: builtin/revert.c:122
+#: builtin/revert.c:127
 msgid "preserve initially empty commits"
 msgstr "保留初始化的空提交"
 
-#: builtin/revert.c:124
+#: builtin/revert.c:129
 msgid "keep redundant, empty commits"
 msgstr "保持多余的、空的提交"
 
-#: builtin/revert.c:214
+#: builtin/revert.c:232
 msgid "revert failed"
 msgstr "还原失败"
 
-#: builtin/revert.c:227
+#: builtin/revert.c:245
 msgid "cherry-pick failed"
 msgstr "拣选失败"
 
-#: builtin/rm.c:18
+#: builtin/rm.c:19
 msgid "git rm [<options>] [--] <file>..."
 msgstr "git rm [<选项>] [--] <文件>..."
 
-#: builtin/rm.c:206
+#: builtin/rm.c:207
 msgid ""
 "the following file has staged content different from both the\n"
 "file and the HEAD:"
@@ -13693,7 +19394,7 @@ msgid_plural ""
 msgstr[0] "如下文件其暂存的内容和工作区及 HEAD 中的都不一样："
 msgstr[1] "如下文件其暂存的内容和工作区及 HEAD 中的都不一样："
 
-#: builtin/rm.c:211
+#: builtin/rm.c:212
 msgid ""
 "\n"
 "(use -f to force removal)"
@@ -13701,13 +19402,13 @@ msgstr ""
 "\n"
 "（使用 -f 强制删除）"
 
-#: builtin/rm.c:215
+#: builtin/rm.c:216
 msgid "the following file has changes staged in the index:"
 msgid_plural "the following files have changes staged in the index:"
 msgstr[0] "下列文件索引中有变更"
 msgstr[1] "下列文件索引中有变更"
 
-#: builtin/rm.c:219 builtin/rm.c:228
+#: builtin/rm.c:220 builtin/rm.c:229
 msgid ""
 "\n"
 "(use --cached to keep the file, or -f to force removal)"
@@ -13715,47 +19416,46 @@ msgstr ""
 "\n"
 "（使用 --cached 保留本地文件，或用 -f 强制删除）"
 
-#: builtin/rm.c:225
+#: builtin/rm.c:226
 msgid "the following file has local modifications:"
 msgid_plural "the following files have local modifications:"
 msgstr[0] "如下文件有本地修改："
 msgstr[1] "如下文件有本地修改："
 
-#: builtin/rm.c:241
+#: builtin/rm.c:242
 msgid "do not list removed files"
 msgstr "不列出删除的文件"
 
-#: builtin/rm.c:242
+#: builtin/rm.c:243
 msgid "only remove from the index"
 msgstr "只从索引区删除"
 
-#: builtin/rm.c:243
+#: builtin/rm.c:244
 msgid "override the up-to-date check"
 msgstr "忽略文件更新状态检查"
 
-#: builtin/rm.c:244
+#: builtin/rm.c:245
 msgid "allow recursive removal"
 msgstr "允许递归删除"
 
-#: builtin/rm.c:246
+#: builtin/rm.c:247
 msgid "exit with a zero status even if nothing matched"
 msgstr "即使没有匹配，也以零状态退出"
 
-#: builtin/rm.c:306
+#: builtin/rm.c:289
+msgid "please stage your changes to .gitmodules or stash them to proceed"
+msgstr "请将您的修改暂存到 .gitmodules 中或贮藏后再继续"
+
+#: builtin/rm.c:307
 #, c-format
 msgid "not removing '%s' recursively without -r"
 msgstr "未提供 -r 选项不会递归删除 '%s'"
 
-#: builtin/rm.c:345
+#: builtin/rm.c:346
 #, c-format
 msgid "git rm: unable to remove %s"
 msgstr "git rm：不能删除 %s"
 
-#: builtin/rm.c:368
-#, c-format
-msgid "could not remove '%s'"
-msgstr "无法删除 '%s'"
-
 #: builtin/send-pack.c:20
 msgid ""
 "git send-pack [--all | --mirror] [--dry-run] [--force] [--receive-pack=<git-"
@@ -13783,18 +19483,6 @@ msgstr "从标准输入读取引用"
 msgid "print status from remote helper"
 msgstr "打印来自远程 helper 的状态"
 
-#: builtin/serve.c:7
-msgid "git serve [<options>]"
-msgstr "git serve [<选项>]"
-
-#: builtin/serve.c:17 builtin/upload-pack.c:23
-msgid "quit after a single request/response exchange"
-msgstr "在一次单独的请求/响应之后退出"
-
-#: builtin/serve.c:19
-msgid "exit immediately after advertising capabilities"
-msgstr "在广告功能后立即退出"
-
 #: builtin/shortlog.c:14
 msgid "git shortlog [<options>] [<revision-range>] [[--] <path>...]"
 msgstr "git shortlog [<选项>] [<版本范围>] [[--] <路径>...]"
@@ -13820,18 +19508,18 @@ msgid "Show the email address of each au
 msgstr "显示每个作者的电子邮件地址"
 
 #: builtin/shortlog.c:271
-msgid "w[,i1[,i2]]"
-msgstr "w[,i1[,i2]]"
+msgid "<w>[,<i1>[,<i2>]]"
+msgstr "<w>[,<i1>[,<i2>]]"
 
 #: builtin/shortlog.c:272
 msgid "Linewrap output"
 msgstr "折行输出"
 
-#: builtin/shortlog.c:298
+#: builtin/shortlog.c:301
 msgid "too many arguments given outside repository"
 msgstr "仓库外执行提供了太多的参数"
 
-#: builtin/show-branch.c:12
+#: builtin/show-branch.c:13
 msgid ""
 "git show-branch [-a | --all] [-r | --remotes] [--topo-order | --date-order]\n"
 "\t\t[--current] [--color[=<when>] | --no-color] [--sparse]\n"
@@ -13843,129 +19531,129 @@ msgstr ""
 "\t\t[--more=<n> | --list | --independent | --merge-base]\n"
 "\t\t[--no-name | --sha1-name] [--topics] [(<版本> | <通配符>)...]"
 
-#: builtin/show-branch.c:16
+#: builtin/show-branch.c:17
 msgid "git show-branch (-g | --reflog)[=<n>[,<base>]] [--list] [<ref>]"
 msgstr "git show-branch (-g | --reflog)[=<n>[,<起始点>]] [--list] [<引用>]"
 
-#: builtin/show-branch.c:376
+#: builtin/show-branch.c:395
 #, c-format
 msgid "ignoring %s; cannot handle more than %d ref"
 msgid_plural "ignoring %s; cannot handle more than %d refs"
 msgstr[0] "忽略 %s，无法处理 %d 个以上的引用"
 msgstr[1] "忽略 %s，无法处理 %d 个以上的引用"
 
-#: builtin/show-branch.c:530
+#: builtin/show-branch.c:548
 #, c-format
 msgid "no matching refs with %s"
 msgstr "没有和 %s 匹配的引用"
 
-#: builtin/show-branch.c:626
+#: builtin/show-branch.c:645
 msgid "show remote-tracking and local branches"
 msgstr "显示远程跟踪的和本地的分支"
 
-#: builtin/show-branch.c:628
+#: builtin/show-branch.c:647
 msgid "show remote-tracking branches"
 msgstr "显示远程跟踪的分支"
 
-#: builtin/show-branch.c:630
+#: builtin/show-branch.c:649
 msgid "color '*!+-' corresponding to the branch"
 msgstr "着色 '*!+-' 到相应的分支"
 
-#: builtin/show-branch.c:632
+#: builtin/show-branch.c:651
 msgid "show <n> more commits after the common ancestor"
 msgstr "显示共同祖先后的 <n> 个提交"
 
-#: builtin/show-branch.c:634
+#: builtin/show-branch.c:653
 msgid "synonym to more=-1"
 msgstr "和 more=-1 同义"
 
-#: builtin/show-branch.c:635
+#: builtin/show-branch.c:654
 msgid "suppress naming strings"
 msgstr "不显示字符串命名"
 
-#: builtin/show-branch.c:637
+#: builtin/show-branch.c:656
 msgid "include the current branch"
 msgstr "包括当前分支"
 
-#: builtin/show-branch.c:639
+#: builtin/show-branch.c:658
 msgid "name commits with their object names"
 msgstr "以对象名字命名提交"
 
-#: builtin/show-branch.c:641
+#: builtin/show-branch.c:660
 msgid "show possible merge bases"
 msgstr "显示可能合并的基线"
 
-#: builtin/show-branch.c:643
+#: builtin/show-branch.c:662
 msgid "show refs unreachable from any other ref"
 msgstr "显示没有任何引用的的引用"
 
-#: builtin/show-branch.c:645
+#: builtin/show-branch.c:664
 msgid "show commits in topological order"
 msgstr "以拓扑顺序显示提交"
 
-#: builtin/show-branch.c:648
+#: builtin/show-branch.c:667
 msgid "show only commits not on the first branch"
 msgstr "只显示不在第一个分支上的提交"
 
-#: builtin/show-branch.c:650
+#: builtin/show-branch.c:669
 msgid "show merges reachable from only one tip"
 msgstr "显示仅一个分支可访问的合并提交"
 
-#: builtin/show-branch.c:652
+#: builtin/show-branch.c:671
 msgid "topologically sort, maintaining date order where possible"
 msgstr "拓扑方式排序，并尽可能地保持日期顺序"
 
-#: builtin/show-branch.c:655
+#: builtin/show-branch.c:674
 msgid "<n>[,<base>]"
 msgstr "<n>[,<base>]"
 
-#: builtin/show-branch.c:656
+#: builtin/show-branch.c:675
 msgid "show <n> most recent ref-log entries starting at base"
 msgstr "显示从起始点开始的 <n> 条最近的引用日志记录"
 
-#: builtin/show-branch.c:690
+#: builtin/show-branch.c:711
 msgid ""
 "--reflog is incompatible with --all, --remotes, --independent or --merge-base"
 msgstr "--reflog 和 --all、--remotes、--independent 或 --merge-base 不兼容"
 
-#: builtin/show-branch.c:714
+#: builtin/show-branch.c:735
 msgid "no branches given, and HEAD is not valid"
 msgstr "未提供分支，且 HEAD 无效"
 
-#: builtin/show-branch.c:717
+#: builtin/show-branch.c:738
 msgid "--reflog option needs one branch name"
 msgstr "选项 --reflog 需要一个分支名"
 
-#: builtin/show-branch.c:720
+#: builtin/show-branch.c:741
 #, c-format
 msgid "only %d entry can be shown at one time."
 msgid_plural "only %d entries can be shown at one time."
 msgstr[0] "一次只能显示 %d 个条目。"
 msgstr[1] "一次只能显示 %d 个条目。"
 
-#: builtin/show-branch.c:724
+#: builtin/show-branch.c:745
 #, c-format
 msgid "no such ref %s"
 msgstr "无此引用 %s"
 
-#: builtin/show-branch.c:808
+#: builtin/show-branch.c:831
 #, c-format
 msgid "cannot handle more than %d rev."
 msgid_plural "cannot handle more than %d revs."
 msgstr[0] "不能处理 %d 个以上的版本。"
 msgstr[1] "不能处理 %d 个以上的版本。"
 
-#: builtin/show-branch.c:812
+#: builtin/show-branch.c:835
 #, c-format
 msgid "'%s' is not a valid ref."
 msgstr "'%s' 不是一个有效的引用。"
 
-#: builtin/show-branch.c:815
+#: builtin/show-branch.c:838
 #, c-format
 msgid "cannot find commit %s (%s)"
 msgstr "不能找到提交 %s（%s）"
 
-#: builtin/show-ref.c:10
+#: builtin/show-ref.c:12
 msgid ""
 "git show-ref [-q | --quiet] [--verify] [--head] [-d | --dereference] [-s | --"
 "hash[=<n>]] [--abbrev[=<n>]] [--tags] [--heads] [--] [<pattern>...]"
@@ -13973,42 +19661,317 @@ msgstr ""
 "git show-ref [-q | --quiet] [--verify] [--head] [-d | --dereference] [-s | --"
 "hash[=<n>]] [--abbrev[=<n>]] [--tags] [--heads] [--] [<模式>...]"
 
-#: builtin/show-ref.c:11
+#: builtin/show-ref.c:13
 msgid "git show-ref --exclude-existing[=<pattern>]"
 msgstr "git show-ref --exclude-existing[=<模式>]"
 
-#: builtin/show-ref.c:159
+#: builtin/show-ref.c:162
 msgid "only show tags (can be combined with heads)"
 msgstr "只显示标签（可以和头共用）"
 
-#: builtin/show-ref.c:160
+#: builtin/show-ref.c:163
 msgid "only show heads (can be combined with tags)"
 msgstr "只显示头（可以和标签共用）"
 
-#: builtin/show-ref.c:161
+#: builtin/show-ref.c:164
 msgid "stricter reference checking, requires exact ref path"
 msgstr "更严格的引用检测，需要精确的引用路径"
 
-#: builtin/show-ref.c:164 builtin/show-ref.c:166
+#: builtin/show-ref.c:167 builtin/show-ref.c:169
 msgid "show the HEAD reference, even if it would be filtered out"
 msgstr "显示 HEAD 引用，即使被过滤掉"
 
-#: builtin/show-ref.c:168
+#: builtin/show-ref.c:171
 msgid "dereference tags into object IDs"
 msgstr "转换标签到对象 ID"
 
-#: builtin/show-ref.c:170
+#: builtin/show-ref.c:173
 msgid "only show SHA1 hash using <n> digits"
 msgstr "只显示使用 <n> 个数字的 SHA1 哈希"
 
-#: builtin/show-ref.c:174
+#: builtin/show-ref.c:177
 msgid "do not print results to stdout (useful with --verify)"
 msgstr "不打印结果到标准输出（例如与 --verify 参数共用）"
 
-#: builtin/show-ref.c:176
+#: builtin/show-ref.c:179
 msgid "show refs from stdin that aren't in local repository"
 msgstr "显示从标准输入中读入的不在本地仓库中的引用"
 
+#: builtin/sparse-checkout.c:20
+msgid "git sparse-checkout (init|list|set|disable) <options>"
+msgstr "git sparse-checkout (init|list|set|disable) <选项>"
+
+#: builtin/sparse-checkout.c:61
+msgid "this worktree is not sparse (sparse-checkout file may not exist)"
+msgstr "本工作区不是稀疏模式（稀疏检出文件可能不存在）"
+
+#: builtin/sparse-checkout.c:220
+msgid "failed to set extensions.worktreeConfig setting"
+msgstr "无法设置 extensions.worktreeConfig"
+
+#: builtin/sparse-checkout.c:237
+msgid "git sparse-checkout init [--cone]"
+msgstr "git sparse-checkout init [--cone]"
+
+#: builtin/sparse-checkout.c:256
+msgid "initialize the sparse-checkout in cone mode"
+msgstr "初始化稀疏检出为 cone 模式"
+
+#: builtin/sparse-checkout.c:262
+msgid "initialize sparse-checkout"
+msgstr "初始化稀疏检出"
+
+#: builtin/sparse-checkout.c:295
+#, c-format
+msgid "failed to open '%s'"
+msgstr "无法打开 '%s'"
+
+#: builtin/sparse-checkout.c:361
+msgid "git sparse-checkout set (--stdin | <patterns>)"
+msgstr "git sparse-checkout set (--stdin | <模式>)"
+
+#: builtin/sparse-checkout.c:378
+msgid "read patterns from standard in"
+msgstr "从标准输入读取模式"
+
+#: builtin/sparse-checkout.c:384
+msgid "set sparse-checkout patterns"
+msgstr "设置稀疏检出模式"
+
+#: builtin/sparse-checkout.c:447
+msgid "disable sparse-checkout"
+msgstr "禁用稀疏检出"
+
+#: builtin/sparse-checkout.c:459
+msgid "error while refreshing working directory"
+msgstr "刷新工作目录时出错"
+
+#: builtin/stash.c:22 builtin/stash.c:37
+msgid "git stash list [<options>]"
+msgstr "git stash list [<选项>]"
+
+#: builtin/stash.c:23 builtin/stash.c:42
+msgid "git stash show [<options>] [<stash>]"
+msgstr "git stash show [<选项>] [<stash>]"
+
+#: builtin/stash.c:24 builtin/stash.c:47
+msgid "git stash drop [-q|--quiet] [<stash>]"
+msgstr "git stash drop [-q|--quiet] [<stash>]"
+
+#: builtin/stash.c:25
+msgid "git stash ( pop | apply ) [--index] [-q|--quiet] [<stash>]"
+msgstr "git stash ( pop | apply ) [--index] [-q|--quiet] [<stash>]"
+
+#: builtin/stash.c:26 builtin/stash.c:62
+msgid "git stash branch <branchname> [<stash>]"
+msgstr "git stash branch <分支名> [<stash>]"
+
+#: builtin/stash.c:27 builtin/stash.c:67
+msgid "git stash clear"
+msgstr "git stash clear"
+
+#: builtin/stash.c:28 builtin/stash.c:77
+msgid ""
+"git stash [push [-p|--patch] [-k|--[no-]keep-index] [-q|--quiet]\n"
+"          [-u|--include-untracked] [-a|--all] [-m|--message <message>]\n"
+"          [--] [<pathspec>...]]"
+msgstr ""
+"git stash [push [-p|--patch] [-k|--[no-]keep-index] [-q|--quiet]\n"
+"          [-u|--include-untracked] [-a|--all] [-m|--message <消息>]\n"
+"          [--] [<路径规格>...]]"
+
+#: builtin/stash.c:31 builtin/stash.c:84
+msgid ""
+"git stash save [-p|--patch] [-k|--[no-]keep-index] [-q|--quiet]\n"
+"          [-u|--include-untracked] [-a|--all] [<message>]"
+msgstr ""
+"git stash save [-p|--patch] [-k|--[no-]keep-index] [-q|--quiet]\n"
+"          [-u|--include-untracked] [-a|--all] [<消息>]"
+
+#: builtin/stash.c:52
+msgid "git stash pop [--index] [-q|--quiet] [<stash>]"
+msgstr "git stash pop [--index] [-q|--quiet] [<stash>]"
+
+#: builtin/stash.c:57
+msgid "git stash apply [--index] [-q|--quiet] [<stash>]"
+msgstr "git stash apply [--index] [-q|--quiet] [<stash>]"
+
+#: builtin/stash.c:72
+msgid "git stash store [-m|--message <message>] [-q|--quiet] <commit>"
+msgstr "git stash store [-m|--message <消息>] [-q|--quiet] <提交>"
+
+#: builtin/stash.c:127
+#, c-format
+msgid "'%s' is not a stash-like commit"
+msgstr "'%s' 不像是一个贮藏提交"
+
+#: builtin/stash.c:147
+#, c-format
+msgid "Too many revisions specified:%s"
+msgstr "指定了太多的版本：%s"
+
+#: builtin/stash.c:161 git-legacy-stash.sh:549
+msgid "No stash entries found."
+msgstr "未发现贮藏条目。"
+
+#: builtin/stash.c:175
+#, c-format
+msgid "%s is not a valid reference"
+msgstr "%s 不是一个有效的引用名"
+
+#: builtin/stash.c:224 git-legacy-stash.sh:75
+msgid "git stash clear with parameters is unimplemented"
+msgstr "git stash clear 不支持参数"
+
+#: builtin/stash.c:403
+msgid "cannot apply a stash in the middle of a merge"
+msgstr "无法在合并过程应用贮藏"
+
+#: builtin/stash.c:414
+#, c-format
+msgid "could not generate diff %s^!."
+msgstr "无法生成差异 %s^!."
+
+#: builtin/stash.c:421
+msgid "conflicts in index.Try without --index."
+msgstr "索引中有冲突。尝试不用 --index。"
+
+#: builtin/stash.c:427
+msgid "could not save index tree"
+msgstr "不能保存索引树"
+
+#: builtin/stash.c:436
+msgid "could not restore untracked files from stash"
+msgstr "无法从贮藏条目中恢复未跟踪文件"
+
+#: builtin/stash.c:450
+#, c-format
+msgid "Merging %s with %s"
+msgstr "正在合并 %s 和 %s"
+
+#: builtin/stash.c:460 git-legacy-stash.sh:681
+msgid "Index was not unstashed."
+msgstr "索引未从贮藏中恢复。"
+
+#: builtin/stash.c:521 builtin/stash.c:620
+msgid "attempt to recreate the index"
+msgstr "尝试重建索引"
+
+#: builtin/stash.c:554
+#, c-format
+msgid "Dropped %s (%s)"
+msgstr "丢弃了 %s（%s）"
+
+#: builtin/stash.c:557
+#, c-format
+msgid "%s: Could not drop stash entry"
+msgstr "%s：无法丢弃贮藏条目"
+
+#: builtin/stash.c:582
+#, c-format
+msgid "'%s' is not a stash reference"
+msgstr "'%s' 不是一个贮藏引用"
+
+#: builtin/stash.c:632 git-legacy-stash.sh:695
+msgid "The stash entry is kept in case you need it again."
+msgstr "贮藏条目被保留以备您再次需要。"
+
+#: builtin/stash.c:655 git-legacy-stash.sh:713
+msgid "No branch name specified"
+msgstr "未指定分支名"
+
+#: builtin/stash.c:795 builtin/stash.c:832
+#, c-format
+msgid "Cannot update %s with %s"
+msgstr "无法用 %2$s 更新 %1$s"
+
+#: builtin/stash.c:813 builtin/stash.c:1470 builtin/stash.c:1506
+msgid "stash message"
+msgstr "贮藏说明"
+
+#: builtin/stash.c:823
+msgid "\"git stash store\" requires one <commit> argument"
+msgstr "\"git stash store\" 需要一个 <提交> 参数"
+
+#: builtin/stash.c:1045 git-legacy-stash.sh:218
+msgid "No changes selected"
+msgstr "没有选择变更"
+
+#: builtin/stash.c:1145 git-legacy-stash.sh:150
+msgid "You do not have the initial commit yet"
+msgstr "您尚未建立初始提交"
+
+#: builtin/stash.c:1172 git-legacy-stash.sh:165
+msgid "Cannot save the current index state"
+msgstr "无法保存当前索引状态"
+
+#: builtin/stash.c:1181 git-legacy-stash.sh:180
+msgid "Cannot save the untracked files"
+msgstr "无法保存未跟踪文件"
+
+#: builtin/stash.c:1192 builtin/stash.c:1201 git-legacy-stash.sh:201
+#: git-legacy-stash.sh:214
+msgid "Cannot save the current worktree state"
+msgstr "无法保存当前工作区状态"
+
+#: builtin/stash.c:1229 git-legacy-stash.sh:234
+msgid "Cannot record working tree state"
+msgstr "不能记录工作区状态"
+
+#: builtin/stash.c:1278 git-legacy-stash.sh:338
+msgid "Can't use --patch and --include-untracked or --all at the same time"
+msgstr "不能同时使用参数 --patch 和 --include-untracked 或 --all"
+
+#: builtin/stash.c:1294
+msgid "Did you forget to 'git add'?"
+msgstr "您是否忘了执行 'git add'？"
+
+#: builtin/stash.c:1309 git-legacy-stash.sh:346
+msgid "No local changes to save"
+msgstr "没有要保存的本地修改"
+
+#: builtin/stash.c:1316 git-legacy-stash.sh:351
+msgid "Cannot initialize stash"
+msgstr "无法初始化贮藏"
+
+#: builtin/stash.c:1331 git-legacy-stash.sh:355
+msgid "Cannot save the current status"
+msgstr "无法保存当前状态"
+
+#: builtin/stash.c:1336
+#, c-format
+msgid "Saved working directory and index state %s"
+msgstr "保存工作目录和索引状态 %s"
+
+#: builtin/stash.c:1426 git-legacy-stash.sh:385
+msgid "Cannot remove worktree changes"
+msgstr "无法删除工作区变更"
+
+#: builtin/stash.c:1461 builtin/stash.c:1497
+msgid "keep index"
+msgstr "保持索引"
+
+#: builtin/stash.c:1463 builtin/stash.c:1499
+msgid "stash in patch mode"
+msgstr "以补丁模式贮藏"
+
+#: builtin/stash.c:1464 builtin/stash.c:1500
+msgid "quiet mode"
+msgstr "静默模式"
+
+#: builtin/stash.c:1466 builtin/stash.c:1502
+msgid "include untracked files in stash"
+msgstr "贮藏中包含未跟踪文件"
+
+#: builtin/stash.c:1468 builtin/stash.c:1504
+msgid "include ignore files"
+msgstr "包含忽略的文件"
+
+#: builtin/stash.c:1564
+#, c-format
+msgid "could not exec %s"
+msgstr "不能执行 %s"
+
 #: builtin/stripspace.c:18
 msgid "git stripspace [-s | --strip-comments]"
 msgstr "git stripspace [-s | --strip-comments]"
@@ -14017,152 +19980,179 @@ msgstr "git stripspace [-s | --strip-com
 msgid "git stripspace [-c | --comment-lines]"
 msgstr "git stripspace [-c | --comment-lines]"
 
-#: builtin/stripspace.c:36
+#: builtin/stripspace.c:37
 msgid "skip and remove all lines starting with comment character"
 msgstr "跳过和移除所有的注释行"
 
-#: builtin/stripspace.c:39
+#: builtin/stripspace.c:40
 msgid "prepend comment character and space to each line"
 msgstr "为每一行的行首添加注释符和空格"
 
-#: builtin/submodule--helper.c:37 builtin/submodule--helper.c:1688
-#, c-format
-msgid "No such ref: %s"
-msgstr "没有这样的引用：%s"
-
-#: builtin/submodule--helper.c:44 builtin/submodule--helper.c:1697
+#: builtin/submodule--helper.c:47 builtin/submodule--helper.c:1970
 #, c-format
 msgid "Expecting a full ref name, got %s"
 msgstr "期望一个完整的引用名称，却得到 %s"
 
-#: builtin/submodule--helper.c:61
+#: builtin/submodule--helper.c:64
 msgid "submodule--helper print-default-remote takes no arguments"
 msgstr "submodule--helper print-default-remote 不带参数"
 
-#: builtin/submodule--helper.c:98
+#: builtin/submodule--helper.c:102
 #, c-format
 msgid "cannot strip one component off url '%s'"
 msgstr "无法从 url '%s' 剥离一个组件"
 
-#: builtin/submodule--helper.c:406 builtin/submodule--helper.c:1211
+#: builtin/submodule--helper.c:410 builtin/submodule--helper.c:1380
 msgid "alternative anchor for relative paths"
 msgstr "相对路径的替代锚记（anchor）"
 
-#: builtin/submodule--helper.c:411
+#: builtin/submodule--helper.c:415
 msgid "git submodule--helper list [--prefix=<path>] [<path>...]"
 msgstr "git submodule--helper list [--prefix=<路径>] [<路径>...]"
 
-#: builtin/submodule--helper.c:462 builtin/submodule--helper.c:485
+#: builtin/submodule--helper.c:472 builtin/submodule--helper.c:630
+#: builtin/submodule--helper.c:653
 #, c-format
 msgid "No url found for submodule path '%s' in .gitmodules"
 msgstr "在 .gitmodules 中未找到子模组 '%s' 的 url"
 
-#: builtin/submodule--helper.c:500
+#: builtin/submodule--helper.c:524
+#, c-format
+msgid "Entering '%s'\n"
+msgstr "进入 '%s'\n"
+
+#: builtin/submodule--helper.c:527
+#, c-format
+msgid ""
+"run_command returned non-zero status for %s\n"
+"."
+msgstr ""
+"对 %s 执行 run_command 返回非零值。\n"
+"."
+
+#: builtin/submodule--helper.c:549
+#, c-format
+msgid ""
+"run_command returned non-zero status while recursing in the nested "
+"submodules of %s\n"
+"."
+msgstr ""
+"在递归 %s 的子模组执行 run_command 时返回非零值。\n"
+"."
+
+#: builtin/submodule--helper.c:565
+msgid "Suppress output of entering each submodule command"
+msgstr "阻止进入每一个子模组命令的输出"
+
+#: builtin/submodule--helper.c:567 builtin/submodule--helper.c:1053
+msgid "Recurse into nested submodules"
+msgstr "递归进入嵌套子模组中"
+
+#: builtin/submodule--helper.c:572
+msgid "git submodule--helper foreach [--quiet] [--recursive] [--] <command>"
+msgstr "git submodule--helper foreach [--quiet] [--recursive] [--] <命令>"
+
+#: builtin/submodule--helper.c:599
 #, c-format
 msgid ""
-"could not lookup configuration '%s'. Assuming this repository is its own "
+"could not look up configuration '%s'. Assuming this repository is its own "
 "authoritative upstream."
 msgstr "无法找到配置 '%s'。假定这个仓库是其自身的官方上游。"
 
-#: builtin/submodule--helper.c:511
+#: builtin/submodule--helper.c:667
 #, c-format
 msgid "Failed to register url for submodule path '%s'"
 msgstr "无法为子模组 '%s' 注册 url"
 
-#: builtin/submodule--helper.c:515
+#: builtin/submodule--helper.c:671
 #, c-format
 msgid "Submodule '%s' (%s) registered for path '%s'\n"
-msgstr "子模组 '%s'（%s）未对路径 '%s' 注册\n"
+msgstr "子模组 '%s'（%s）已对路径 '%s' 注册\n"
 
-#
-#: builtin/submodule--helper.c:525
+#: builtin/submodule--helper.c:681
 #, c-format
 msgid "warning: command update mode suggested for submodule '%s'\n"
 msgstr "警告：建议子模组 '%s' 使用命令更新模式\n"
 
-#: builtin/submodule--helper.c:532
+#: builtin/submodule--helper.c:688
 #, c-format
 msgid "Failed to register update mode for submodule path '%s'"
 msgstr "无法为子模组 '%s' 注册更新模式"
 
-#: builtin/submodule--helper.c:554
+#: builtin/submodule--helper.c:710
 msgid "Suppress output for initializing a submodule"
 msgstr "阻止子模组初始化的输出"
 
-#: builtin/submodule--helper.c:559
-msgid "git submodule--helper init [<path>]"
-msgstr "git submodule--helper init [<路径>]"
+#: builtin/submodule--helper.c:715
+msgid "git submodule--helper init [<options>] [<path>]"
+msgstr "git submodule--helper init [<选项>] [<路径>]"
 
-#: builtin/submodule--helper.c:631 builtin/submodule--helper.c:757
+#: builtin/submodule--helper.c:787 builtin/submodule--helper.c:914
 #, c-format
 msgid "no submodule mapping found in .gitmodules for path '%s'"
 msgstr "在 .gitmodules 中没有发现路径 '%s' 的子模组映射"
 
-#: builtin/submodule--helper.c:670
+#: builtin/submodule--helper.c:827
 #, c-format
 msgid "could not resolve HEAD ref inside the submodule '%s'"
 msgstr "无法解析子模组 '%s' 的 HEAD 引用"
 
-#: builtin/submodule--helper.c:697 builtin/submodule--helper.c:866
+#: builtin/submodule--helper.c:854 builtin/submodule--helper.c:1023
 #, c-format
 msgid "failed to recurse into submodule '%s'"
-msgstr "无法递归子模组 '%s'"
+msgstr "递归子模组 '%s' 失败"
 
-#: builtin/submodule--helper.c:721 builtin/submodule--helper.c:1031
+#: builtin/submodule--helper.c:878 builtin/submodule--helper.c:1189
 msgid "Suppress submodule status output"
 msgstr "阻止子模组状态输出"
 
-#: builtin/submodule--helper.c:722
+#: builtin/submodule--helper.c:879
 msgid ""
 "Use commit stored in the index instead of the one stored in the submodule "
 "HEAD"
 msgstr "使用存储在索引中的提交，而非存储在子模组 HEAD 中的提交"
 
-#: builtin/submodule--helper.c:723
+#: builtin/submodule--helper.c:880
 msgid "recurse into nested submodules"
 msgstr "递归进入嵌套子模组中"
 
-#: builtin/submodule--helper.c:728
+#: builtin/submodule--helper.c:885
 msgid "git submodule status [--quiet] [--cached] [--recursive] [<path>...]"
 msgstr "git submodule status [--quiet] [--cached] [--recursive] [<路径>...]"
 
-#: builtin/submodule--helper.c:752
+#: builtin/submodule--helper.c:909
 msgid "git submodule--helper name <path>"
 msgstr "git submodule--helper name <路径>"
 
-#: builtin/submodule--helper.c:816
+#: builtin/submodule--helper.c:973
 #, c-format
 msgid "Synchronizing submodule url for '%s'\n"
 msgstr "为 '%s' 同步子模组 url\n"
 
-#: builtin/submodule--helper.c:822
+#: builtin/submodule--helper.c:979
 #, c-format
 msgid "failed to register url for submodule path '%s'"
 msgstr "无法为子模组路径 '%s' 注册 url"
 
-#: builtin/submodule--helper.c:836
+#: builtin/submodule--helper.c:993
 #, c-format
 msgid "failed to get the default remote for submodule '%s'"
 msgstr "无法得到子模组 '%s' 的默认远程关联"
 
-#: builtin/submodule--helper.c:847
+#: builtin/submodule--helper.c:1004
 #, c-format
 msgid "failed to update remote for submodule '%s'"
 msgstr "无法为子模组 '%s' 更新远程关联"
 
-#: builtin/submodule--helper.c:895
+#: builtin/submodule--helper.c:1051
 msgid "Suppress output of synchronizing submodule url"
 msgstr "阻止子模组 url 同步的输出"
 
-#: builtin/submodule--helper.c:897
-msgid "Recurse into nested submodules"
-msgstr "递归进入嵌套子模组中"
-
-#: builtin/submodule--helper.c:902
+#: builtin/submodule--helper.c:1058
 msgid "git submodule--helper sync [--quiet] [--recursive] [<path>]"
 msgstr "git submodule--helper sync [--quiet] [--recursive] [<路径>]"
 
-#: builtin/submodule--helper.c:956
+#: builtin/submodule--helper.c:1112
 #, c-format
 msgid ""
 "Submodule work tree '%s' contains a .git directory (use 'rm -rf' if you "
@@ -14171,87 +20161,103 @@ msgstr ""
 "子模组工作区 '%s' 包含一个 .git 目录（如果您确需删除它及其全部历史，使用 'rm "
 "-rf' 命令）"
 
-#: builtin/submodule--helper.c:968
+#: builtin/submodule--helper.c:1124
 #, c-format
 msgid ""
 "Submodule work tree '%s' contains local modifications; use '-f' to discard "
 "them"
 msgstr "子模组工作区 '%s' 包含本地修改；使用 '-f' 丢弃它们"
 
-#: builtin/submodule--helper.c:976
+#: builtin/submodule--helper.c:1132
 #, c-format
 msgid "Cleared directory '%s'\n"
 msgstr "已清除目录 '%s'\n"
 
-#: builtin/submodule--helper.c:978
+#: builtin/submodule--helper.c:1134
 #, c-format
 msgid "Could not remove submodule work tree '%s'\n"
 msgstr "无法移除子模组工作区 '%s'\n"
 
-#: builtin/submodule--helper.c:987
+#: builtin/submodule--helper.c:1145
 #, c-format
 msgid "could not create empty submodule directory %s"
 msgstr "不能创建空的子模组目录 %s"
 
-#: builtin/submodule--helper.c:1003
+#: builtin/submodule--helper.c:1161
 #, c-format
 msgid "Submodule '%s' (%s) unregistered for path '%s'\n"
 msgstr "子模组 '%s'（%s）未对路径 '%s' 注册\n"
 
-#: builtin/submodule--helper.c:1032
+#: builtin/submodule--helper.c:1190
 msgid "Remove submodule working trees even if they contain local changes"
 msgstr "删除子模组工作区，即使包含本地修改"
 
-#: builtin/submodule--helper.c:1033
+#: builtin/submodule--helper.c:1191
 msgid "Unregister all submodules"
 msgstr "将所有子模组取消注册"
 
-#: builtin/submodule--helper.c:1038
+#: builtin/submodule--helper.c:1196
 msgid ""
 "git submodule deinit [--quiet] [-f | --force] [--all | [--] [<path>...]]"
 msgstr ""
 "git submodule deinit [--quiet] [-f | --force] [--all | [--] [<路径>...]]"
 
-#: builtin/submodule--helper.c:1052
+#: builtin/submodule--helper.c:1210
 msgid "Use '--all' if you really want to deinitialize all submodules"
 msgstr "如果您确实想要对所有子模组执行取消初始化，请使用 '--all'"
 
-#: builtin/submodule--helper.c:1145 builtin/submodule--helper.c:1148
+#: builtin/submodule--helper.c:1275
+msgid ""
+"An alternate computed from a superproject's alternate is invalid.\n"
+"To allow Git to clone without an alternate in such a case, set\n"
+"submodule.alternateErrorStrategy to 'info' or, equivalently, clone with\n"
+"'--reference-if-able' instead of '--reference'."
+msgstr ""
+"从一个父项目的备用仓库中计算出的备用仓库无效。\n"
+"此场景下，设置 submodule.alternateErrorStrategy 为 'info'，以允许\n"
+"Git 不使用备用仓库克隆，或者等效地使用 '--reference-if-able' 而非\n"
+"'--reference' 来克隆。"
+
+#: builtin/submodule--helper.c:1314 builtin/submodule--helper.c:1317
 #, c-format
 msgid "submodule '%s' cannot add alternate: %s"
 msgstr "子模组 '%s' 不能添加仓库备选：%s"
 
-#: builtin/submodule--helper.c:1184
+#: builtin/submodule--helper.c:1353
 #, c-format
 msgid "Value '%s' for submodule.alternateErrorStrategy is not recognized"
 msgstr "不能识别 submodule.alternateErrorStrategy 的取值 '%s'"
 
-#: builtin/submodule--helper.c:1191
+#: builtin/submodule--helper.c:1360
 #, c-format
 msgid "Value '%s' for submodule.alternateLocation is not recognized"
 msgstr "不能识别 submodule.alternateLocaion 的取值 '%s'"
 
-#: builtin/submodule--helper.c:1214
+#: builtin/submodule--helper.c:1383
 msgid "where the new submodule will be cloned to"
 msgstr "新的子模组将要克隆的路径"
 
-#: builtin/submodule--helper.c:1217
+#: builtin/submodule--helper.c:1386
 msgid "name of the new submodule"
 msgstr "新子模组的名称"
 
-#: builtin/submodule--helper.c:1220
+#: builtin/submodule--helper.c:1389
 msgid "url where to clone the submodule from"
 msgstr "克隆子模组的 url 地址"
 
-#: builtin/submodule--helper.c:1228
+#: builtin/submodule--helper.c:1397
 msgid "depth for shallow clones"
 msgstr "浅克隆的深度"
 
-#: builtin/submodule--helper.c:1231 builtin/submodule--helper.c:1606
+#: builtin/submodule--helper.c:1400 builtin/submodule--helper.c:1897
 msgid "force cloning progress"
 msgstr "强制显示克隆进度"
 
-#: builtin/submodule--helper.c:1236
+#: builtin/submodule--helper.c:1402 builtin/submodule--helper.c:1899
+msgid "disallow cloning into non-empty directory"
+msgstr "不允许克隆到一个非空目录"
+
+#: builtin/submodule--helper.c:1407
 msgid ""
 "git submodule--helper clone [--prefix=<path>] [--quiet] [--reference "
 "<repository>] [--name <name>] [--depth <depth>] --url <url> --path <path>"
@@ -14259,102 +20265,152 @@ msgstr ""
 "git submodule--helper clone [--prefix=<路径>] [--quiet] [--reference <仓库>] "
 "[--name <名字>] [--depth <深度>] --url <url> --path <路径>"
 
-#: builtin/submodule--helper.c:1267
+#: builtin/submodule--helper.c:1431
+#, c-format
+msgid "refusing to create/use '%s' in another submodule's git dir"
+msgstr "拒绝在另一个子模组的 git dir 中创建/使用 '%s'"
+
+#: builtin/submodule--helper.c:1442
 #, c-format
 msgid "clone of '%s' into submodule path '%s' failed"
 msgstr "无法克隆 '%s' 到子模组路径 '%s'"
 
-#: builtin/submodule--helper.c:1281
+#: builtin/submodule--helper.c:1446
+#, c-format
+msgid "directory not empty: '%s'"
+msgstr "目录非空：'%s'"
+
+#: builtin/submodule--helper.c:1458
 #, c-format
 msgid "could not get submodule directory for '%s'"
 msgstr "无法得到 '%s' 的子模组目录"
 
-#: builtin/submodule--helper.c:1347
+#: builtin/submodule--helper.c:1494
+#, c-format
+msgid "Invalid update mode '%s' for submodule path '%s'"
+msgstr "子模组 '%2$s' 的更新模式 '%1$s' 无效"
+
+#: builtin/submodule--helper.c:1498
+#, c-format
+msgid "Invalid update mode '%s' configured for submodule path '%s'"
+msgstr "为子模组 '%2$s' 配置的更新模式 '%1$s' 无效"
+
+#: builtin/submodule--helper.c:1594
 #, c-format
 msgid "Submodule path '%s' not initialized"
 msgstr "子模组 '%s' 尚未初始化"
 
-#: builtin/submodule--helper.c:1351
+#: builtin/submodule--helper.c:1598
 msgid "Maybe you want to use 'update --init'?"
 msgstr "也许您想要执行 'update --init'？"
 
-#: builtin/submodule--helper.c:1380
+#: builtin/submodule--helper.c:1628
 #, c-format
 msgid "Skipping unmerged submodule %s"
 msgstr "略过未合并的子模组 %s"
 
-#: builtin/submodule--helper.c:1409
+#: builtin/submodule--helper.c:1657
 #, c-format
 msgid "Skipping submodule '%s'"
 msgstr "略过子模组 '%s'"
 
-#: builtin/submodule--helper.c:1544
+#: builtin/submodule--helper.c:1803
 #, c-format
 msgid "Failed to clone '%s'. Retry scheduled"
 msgstr "克隆 '%s' 失败。按计划重试"
 
-#: builtin/submodule--helper.c:1555
+#: builtin/submodule--helper.c:1814
 #, c-format
 msgid "Failed to clone '%s' a second time, aborting"
 msgstr "第二次尝试克隆 '%s' 失败，退出"
 
-#: builtin/submodule--helper.c:1585 builtin/submodule--helper.c:1808
+#: builtin/submodule--helper.c:1876 builtin/submodule--helper.c:2120
 msgid "path into the working tree"
 msgstr "到工作区的路径"
 
-#: builtin/submodule--helper.c:1588
+#: builtin/submodule--helper.c:1879
 msgid "path into the working tree, across nested submodule boundaries"
 msgstr "工作区中的路径，递归嵌套子模组"
 
-#: builtin/submodule--helper.c:1592
+#: builtin/submodule--helper.c:1883
 msgid "rebase, merge, checkout or none"
 msgstr "rebase、merge、checkout 或 none"
 
-#: builtin/submodule--helper.c:1598
+#: builtin/submodule--helper.c:1889
 msgid "Create a shallow clone truncated to the specified number of revisions"
 msgstr "创建一个指定深度的浅克隆"
 
-#: builtin/submodule--helper.c:1601
+#: builtin/submodule--helper.c:1892
 msgid "parallel jobs"
 msgstr "并发任务"
 
-#: builtin/submodule--helper.c:1603
+#: builtin/submodule--helper.c:1894
 msgid "whether the initial clone should follow the shallow recommendation"
 msgstr "初始克隆是否应该遵守推荐的浅克隆选项"
 
-#: builtin/submodule--helper.c:1604
+#: builtin/submodule--helper.c:1895
 msgid "don't print cloning progress"
 msgstr "不要输出克隆进度"
 
-#: builtin/submodule--helper.c:1611
-msgid "git submodule--helper update_clone [--prefix=<path>] [<path>...]"
-msgstr "git submodule--helper update_clone [--prefix=<路径>] [<路径>...]"
+#: builtin/submodule--helper.c:1904
+msgid "git submodule--helper update-clone [--prefix=<path>] [<path>...]"
+msgstr "git submodule--helper update-clone [--prefix=<路径>] [<路径>...]"
 
-#: builtin/submodule--helper.c:1624
+#: builtin/submodule--helper.c:1917
 msgid "bad value for update parameter"
 msgstr "update 参数取值错误"
 
-#: builtin/submodule--helper.c:1692
+#: builtin/submodule--helper.c:1965
 #, c-format
 msgid ""
 "Submodule (%s) branch configured to inherit branch from superproject, but "
 "the superproject is not on any branch"
 msgstr "子模组（%s）的分支配置为继承上级项目的分支，但是上级项目不在任何分支上"
 
-#: builtin/submodule--helper.c:1809
+#: builtin/submodule--helper.c:2088
+#, c-format
+msgid "could not get a repository handle for submodule '%s'"
+msgstr "无法获得子模组 '%s' 的仓库句柄"
+
+#: builtin/submodule--helper.c:2121
 msgid "recurse into submodules"
 msgstr "在子模组中递归"
 
-#: builtin/submodule--helper.c:1815
-msgid "git submodule--helper embed-git-dir [<path>...]"
-msgstr "git submodule--helper embed-git-dir [<路径>...]"
+#: builtin/submodule--helper.c:2127
+msgid "git submodule--helper absorb-git-dirs [<options>] [<path>...]"
+msgstr "git submodule--helper absorb-git-dirs [<选项>] [<路径>...]"
+
+#: builtin/submodule--helper.c:2183
+msgid "check if it is safe to write to the .gitmodules file"
+msgstr "检查写入 .gitmodules 文件是否安全"
+
+#: builtin/submodule--helper.c:2186
+msgid "unset the config in the .gitmodules file"
+msgstr "取消 .gitmodules 文件中的设置"
+
+#: builtin/submodule--helper.c:2191
+msgid "git submodule--helper config <name> [<value>]"
+msgstr "git submodule--helper config <名称> [<值>]"
 
-#: builtin/submodule--helper.c:1901
+#: builtin/submodule--helper.c:2192
+msgid "git submodule--helper config --unset <name>"
+msgstr "git submodule--helper config --unset <名称>"
+
+#: builtin/submodule--helper.c:2193
+msgid "git submodule--helper config --check-writeable"
+msgstr "git submodule--helper config --check-writeable"
+
+#: builtin/submodule--helper.c:2212 git-submodule.sh:173
+#, sh-format
+msgid "please make sure that the .gitmodules file is in the working tree"
+msgstr "请确认 .gitmodules 文件在工作区里"
+
+#: builtin/submodule--helper.c:2262 git.c:433 git.c:684
 #, c-format
 msgid "%s doesn't support --super-prefix"
 msgstr "%s 不支持 --super-prefix"
 
-#: builtin/submodule--helper.c:1907
+#: builtin/submodule--helper.c:2268
 #, c-format
 msgid "'%s' is not a valid submodule--helper subcommand"
 msgstr "'%s' 不是一个有效的 submodule--helper 子命令"
@@ -14379,26 +20435,27 @@ msgstr "删除符号引用"
 msgid "shorten ref output"
 msgstr "缩短引用输出"
 
-#: builtin/symbolic-ref.c:43 builtin/update-ref.c:362
+#: builtin/symbolic-ref.c:43 builtin/update-ref.c:363
 msgid "reason"
 msgstr "原因"
 
-#: builtin/symbolic-ref.c:43 builtin/update-ref.c:362
+#: builtin/symbolic-ref.c:43 builtin/update-ref.c:363
 msgid "reason of the update"
 msgstr "更新的原因"
 
-#: builtin/tag.c:24
+#: builtin/tag.c:25
 msgid ""
-"git tag [-a | -s | -u <key-id>] [-f] [-m <msg> | -F <file>] <tagname> "
-"[<head>]"
+"git tag [-a | -s | -u <key-id>] [-f] [-m <msg> | -F <file>]\n"
+"\t\t<tagname> [<head>]"
 msgstr ""
-"git tag [-a | -s | -u <key-id>] [-f] [-m <说明> | -F <文件>] <标签名> [<头>]"
+"git tag [-a | -s | -u <key-id>] [-f] [-m <消息> | -F <文件>]\n"
+"\t\t<标签名> [<头>]"
 
-#: builtin/tag.c:25
+#: builtin/tag.c:27
 msgid "git tag -d <tagname>..."
 msgstr "git tag -d <标签名>..."
 
-#: builtin/tag.c:26
+#: builtin/tag.c:28
 msgid ""
 "git tag -l [-n[<num>]] [--contains <commit>] [--no-contains <commit>] [--"
 "points-at <object>]\n"
@@ -14408,21 +20465,21 @@ msgstr ""
 "at <对象>]\n"
 "\t\t[--format=<格式>] [--[no-]merged [<提交>]] [<模式>...]"
 
-#: builtin/tag.c:28
+#: builtin/tag.c:30
 msgid "git tag -v [--format=<format>] <tagname>..."
 msgstr "git tag -v [--format=<格式>] <标签名>..."
 
-#: builtin/tag.c:86
+#: builtin/tag.c:89
 #, c-format
 msgid "tag '%s' not found."
 msgstr "未发现标签 '%s'。"
 
-#: builtin/tag.c:102
+#: builtin/tag.c:105
 #, c-format
 msgid "Deleted tag '%s' (was %s)\n"
 msgstr "已删除标签 '%s'（曾为 %s）\n"
 
-#: builtin/tag.c:132
+#: builtin/tag.c:135
 #, c-format
 msgid ""
 "\n"
@@ -14435,7 +20492,7 @@ msgstr ""
 "  %s\n"
 "以 '%c' 开头的行将被忽略。\n"
 
-#: builtin/tag.c:136
+#: builtin/tag.c:139
 #, c-format
 msgid ""
 "\n"
@@ -14449,363 +20506,375 @@ msgstr ""
 "  %s\n"
 "以 '%c' 开头的行将被保留，如果您愿意也可以删除它们。\n"
 
-#: builtin/tag.c:190
+#: builtin/tag.c:198
 msgid "unable to sign the tag"
 msgstr "无法签署标签"
 
-#: builtin/tag.c:192
+#: builtin/tag.c:200
 msgid "unable to write tag file"
 msgstr "无法写标签文件"
 
-#: builtin/tag.c:217
+#: builtin/tag.c:216
+#, c-format
+msgid ""
+"You have created a nested tag. The object referred to by your new tag is\n"
+"already a tag. If you meant to tag the object that it points to, use:\n"
+"\n"
+"\tgit tag -f %s %s^{}"
+msgstr ""
+"您创建了一个嵌套的标签。您的新标签指向的对象已经是一个标签。如果您想要\n"
+"对其指向的目标创建标签，使用：\n"
+"\n"
+"\tgit tag -f %s %s^{}"
+
+#: builtin/tag.c:232
 msgid "bad object type."
 msgstr "坏的对象类型。"
 
-#: builtin/tag.c:266
+#: builtin/tag.c:284
 msgid "no tag message?"
 msgstr "无标签说明？"
 
-#: builtin/tag.c:273
+#: builtin/tag.c:291
 #, c-format
 msgid "The tag message has been left in %s\n"
 msgstr "标签说明被保留在 %s\n"
 
-#: builtin/tag.c:382
+#: builtin/tag.c:402
 msgid "list tag names"
 msgstr "列出标签名称"
 
-#: builtin/tag.c:384
+#: builtin/tag.c:404
 msgid "print <n> lines of each tag message"
 msgstr "每个标签信息打印 <n> 行"
 
-#: builtin/tag.c:386
+#: builtin/tag.c:406
 msgid "delete tags"
 msgstr "删除标签"
 
-#: builtin/tag.c:387
+#: builtin/tag.c:407
 msgid "verify tags"
 msgstr "验证标签"
 
-#: builtin/tag.c:389
+#: builtin/tag.c:409
 msgid "Tag creation options"
 msgstr "标签创建选项"
 
-#: builtin/tag.c:391
+#: builtin/tag.c:411
 msgid "annotated tag, needs a message"
 msgstr "附注标签，需要一个说明"
 
-#: builtin/tag.c:393
+#: builtin/tag.c:413
 msgid "tag message"
 msgstr "标签说明"
 
-#: builtin/tag.c:395
+#: builtin/tag.c:415
 msgid "force edit of tag message"
 msgstr "强制编辑标签说明"
 
-#: builtin/tag.c:396
+#: builtin/tag.c:416
 msgid "annotated and GPG-signed tag"
 msgstr "附注并附加 GPG 签名的标签"
 
-#: builtin/tag.c:400
+#: builtin/tag.c:419
 msgid "use another key to sign the tag"
 msgstr "使用另外的私钥签名该标签"
 
-#: builtin/tag.c:401
+#: builtin/tag.c:420
 msgid "replace the tag if exists"
 msgstr "如果存在，替换现有的标签"
 
-#: builtin/tag.c:402 builtin/update-ref.c:368
+#: builtin/tag.c:421 builtin/update-ref.c:369
 msgid "create a reflog"
 msgstr "创建引用日志"
 
-#: builtin/tag.c:404
+#: builtin/tag.c:423
 msgid "Tag listing options"
 msgstr "标签列表选项"
 
-#: builtin/tag.c:405
+#: builtin/tag.c:424
 msgid "show tag list in columns"
 msgstr "以列的方式显示标签列表"
 
-#: builtin/tag.c:406 builtin/tag.c:408
+#: builtin/tag.c:425 builtin/tag.c:427
 msgid "print only tags that contain the commit"
 msgstr "只打印包含该提交的标签"
 
-#: builtin/tag.c:407 builtin/tag.c:409
+#: builtin/tag.c:426 builtin/tag.c:428
 msgid "print only tags that don't contain the commit"
 msgstr "只打印不包含该提交的标签"
 
-#: builtin/tag.c:410
+#: builtin/tag.c:429
 msgid "print only tags that are merged"
 msgstr "只打印已经合并的标签"
 
-#: builtin/tag.c:411
+#: builtin/tag.c:430
 msgid "print only tags that are not merged"
 msgstr "只打印尚未合并的标签"
 
-#: builtin/tag.c:416
+#: builtin/tag.c:434
 msgid "print only tags of the object"
 msgstr "只打印指向该对象的标签"
 
-#: builtin/tag.c:460
+#: builtin/tag.c:482
 msgid "--column and -n are incompatible"
 msgstr "--column 和 -n 不兼容"
 
-#: builtin/tag.c:482
+#: builtin/tag.c:504
 msgid "-n option is only allowed in list mode"
 msgstr "-n 选项只允许用在列表显示模式"
 
-#: builtin/tag.c:484
+#: builtin/tag.c:506
 msgid "--contains option is only allowed in list mode"
 msgstr "--contains 选项只允许用在列表显示模式"
 
-#: builtin/tag.c:486
+#: builtin/tag.c:508
 msgid "--no-contains option is only allowed in list mode"
 msgstr "--no-contains 选项只允许用在列表显示模式"
 
-#: builtin/tag.c:488
+#: builtin/tag.c:510
 msgid "--points-at option is only allowed in list mode"
 msgstr "--points-at 选项只允许用在列表显示模式"
 
-#: builtin/tag.c:490
+#: builtin/tag.c:512
 msgid "--merged and --no-merged options are only allowed in list mode"
 msgstr "--merged 和 --no-merged 选项只允许用在列表显示模式"
 
-#: builtin/tag.c:501
+#: builtin/tag.c:523
 msgid "only one -F or -m option is allowed."
 msgstr "只允许一个 -F 或 -m 选项。"
 
-#: builtin/tag.c:520
+#: builtin/tag.c:542
 msgid "too many params"
 msgstr "太多参数"
 
-#: builtin/tag.c:526
+#: builtin/tag.c:548
 #, c-format
 msgid "'%s' is not a valid tag name."
 msgstr "'%s' 不是一个有效的标签名称。"
 
-#: builtin/tag.c:531
+#: builtin/tag.c:553
 #, c-format
 msgid "tag '%s' already exists"
 msgstr "标签 '%s' 已存在"
 
-#: builtin/tag.c:562
+#: builtin/tag.c:584
 #, c-format
 msgid "Updated tag '%s' (was %s)\n"
 msgstr "已更新标签 '%s'（曾为 %s）\n"
 
-#: builtin/unpack-objects.c:498
+#: builtin/unpack-objects.c:501
 msgid "Unpacking objects"
 msgstr "展开对象中"
 
-#: builtin/update-index.c:82
+#: builtin/update-index.c:84
 #, c-format
 msgid "failed to create directory %s"
-msgstr "无法创建目录 %s"
+msgstr "创建目录 %s 失败"
 
-#: builtin/update-index.c:88
-#, c-format
-msgid "failed to stat %s"
-msgstr "对 %s 调用 stat 失败"
-
-#: builtin/update-index.c:98
+#: builtin/update-index.c:100
 #, c-format
 msgid "failed to create file %s"
-msgstr "无法创建文件 %s"
+msgstr "创建文件 %s 失败"
 
-#: builtin/update-index.c:106
+#: builtin/update-index.c:108
 #, c-format
 msgid "failed to delete file %s"
-msgstr "无法删除文件 %s"
+msgstr "删除文件 %s 失败"
 
-#: builtin/update-index.c:113 builtin/update-index.c:219
+#: builtin/update-index.c:115 builtin/update-index.c:221
 #, c-format
 msgid "failed to delete directory %s"
-msgstr "无法删除目录 %s"
+msgstr "删除目录 %s 失败"
 
-#: builtin/update-index.c:138
+#: builtin/update-index.c:140
 #, c-format
 msgid "Testing mtime in '%s' "
 msgstr "在 '%s' 中测试 mtime "
 
-#: builtin/update-index.c:152
+#: builtin/update-index.c:154
 msgid "directory stat info does not change after adding a new file"
 msgstr "添加一个新文件后，目录的状态信息未改变"
 
-#: builtin/update-index.c:165
+#: builtin/update-index.c:167
 msgid "directory stat info does not change after adding a new directory"
 msgstr "添加一个新目录后，目录的状态信息未改变"
 
-#: builtin/update-index.c:178
+#: builtin/update-index.c:180
 msgid "directory stat info changes after updating a file"
 msgstr "更新一个文件后，目录的状态信息被修改"
 
-#: builtin/update-index.c:189
+#: builtin/update-index.c:191
 msgid "directory stat info changes after adding a file inside subdirectory"
 msgstr "在子目录中添加文件后，目录的状态信息被修改"
 
-#: builtin/update-index.c:200
+#: builtin/update-index.c:202
 msgid "directory stat info does not change after deleting a file"
 msgstr "删除一个文件后，目录的状态信息未改变"
 
-#: builtin/update-index.c:213
+#: builtin/update-index.c:215
 msgid "directory stat info does not change after deleting a directory"
 msgstr "删除一个目录后，目录的状态信息未改变"
 
-#: builtin/update-index.c:220
+#: builtin/update-index.c:222
 msgid " OK"
 msgstr " OK"
 
-#: builtin/update-index.c:589
+#: builtin/update-index.c:591
 msgid "git update-index [<options>] [--] [<file>...]"
 msgstr "git update-index [<选项>] [--] [<文件>...]"
 
-#: builtin/update-index.c:946
+#: builtin/update-index.c:974
 msgid "continue refresh even when index needs update"
 msgstr "当索引需要更新时继续刷新"
 
-#: builtin/update-index.c:949
+#: builtin/update-index.c:977
 msgid "refresh: ignore submodules"
 msgstr "刷新：忽略子模组"
 
-#: builtin/update-index.c:952
+#: builtin/update-index.c:980
 msgid "do not ignore new files"
 msgstr "不忽略新的文件"
 
-#: builtin/update-index.c:954
+#: builtin/update-index.c:982
 msgid "let files replace directories and vice-versa"
 msgstr "让文件替换目录（反之亦然）"
 
-#: builtin/update-index.c:956
+#: builtin/update-index.c:984
 msgid "notice files missing from worktree"
 msgstr "通知文件从工作区丢失"
 
-#: builtin/update-index.c:958
+#: builtin/update-index.c:986
 msgid "refresh even if index contains unmerged entries"
 msgstr "即使索引区包含未合并的条目也执行刷新"
 
-#: builtin/update-index.c:961
+#: builtin/update-index.c:989
 msgid "refresh stat information"
 msgstr "刷新统计信息"
 
-#: builtin/update-index.c:965
+#: builtin/update-index.c:993
 msgid "like --refresh, but ignore assume-unchanged setting"
 msgstr "类似于 --refresh，但是忽略 assume-unchanged 设置"
 
-#: builtin/update-index.c:969
+#: builtin/update-index.c:997
 msgid "<mode>,<object>,<path>"
 msgstr "<存取模式>,<对象>,<路径>"
 
-#: builtin/update-index.c:970
+#: builtin/update-index.c:998
 msgid "add the specified entry to the index"
 msgstr "添加指定的条目到索引区"
 
-#: builtin/update-index.c:979
+#: builtin/update-index.c:1008
 msgid "mark files as \"not changing\""
 msgstr "把文件标记为 \"没有变更\""
 
-#: builtin/update-index.c:982
+#: builtin/update-index.c:1011
 msgid "clear assumed-unchanged bit"
 msgstr "清除 assumed-unchanged 位"
 
-#: builtin/update-index.c:985
+#: builtin/update-index.c:1014
 msgid "mark files as \"index-only\""
 msgstr "把文件标记为 \"仅索引\""
 
-#: builtin/update-index.c:988
+#: builtin/update-index.c:1017
 msgid "clear skip-worktree bit"
 msgstr "清除 skip-worktree 位"
 
-#: builtin/update-index.c:991
+#: builtin/update-index.c:1020
+msgid "do not touch index-only entries"
+msgstr "不要触碰仅索引条目"
+
+#: builtin/update-index.c:1022
 msgid "add to index only; do not add content to object database"
 msgstr "只添加到索引区；不添加对象到对象库"
 
-#: builtin/update-index.c:993
+#: builtin/update-index.c:1024
 msgid "remove named paths even if present in worktree"
 msgstr "即使存在工作区里，也删除路径"
 
-#: builtin/update-index.c:995
+#: builtin/update-index.c:1026
 msgid "with --stdin: input lines are terminated by null bytes"
 msgstr "携带 --stdin：输入的行以 null 字符终止"
 
-#: builtin/update-index.c:997
+#: builtin/update-index.c:1028
 msgid "read list of paths to be updated from standard input"
 msgstr "从标准输入中读取需要更新的路径列表"
 
-#: builtin/update-index.c:1001
+#: builtin/update-index.c:1032
 msgid "add entries from standard input to the index"
 msgstr "从标准输入添加条目到索引区"
 
-#: builtin/update-index.c:1005
+#: builtin/update-index.c:1036
 msgid "repopulate stages #2 and #3 for the listed paths"
 msgstr "为指定文件重新生成第2和第3暂存区"
 
-#: builtin/update-index.c:1009
+#: builtin/update-index.c:1040
 msgid "only update entries that differ from HEAD"
 msgstr "只更新与 HEAD 不同的条目"
 
-#: builtin/update-index.c:1013
+#: builtin/update-index.c:1044
 msgid "ignore files missing from worktree"
 msgstr "忽略工作区丢失的文件"
 
-#: builtin/update-index.c:1016
+#: builtin/update-index.c:1047
 msgid "report actions to standard output"
 msgstr "在标准输出显示操作"
 
-#: builtin/update-index.c:1018
+#: builtin/update-index.c:1049
 msgid "(for porcelains) forget saved unresolved conflicts"
 msgstr "(for porcelains) 忘记保存的未解决的冲突"
 
-#: builtin/update-index.c:1022
+#: builtin/update-index.c:1053
 msgid "write index in this format"
 msgstr "以这种格式写入索引区"
 
-#: builtin/update-index.c:1024
+#: builtin/update-index.c:1055
 msgid "enable or disable split index"
 msgstr "启用或禁用索引拆分"
 
-#: builtin/update-index.c:1026
+#: builtin/update-index.c:1057
 msgid "enable/disable untracked cache"
 msgstr "启用/禁用对未跟踪文件的缓存"
 
-#: builtin/update-index.c:1028
+#: builtin/update-index.c:1059
 msgid "test if the filesystem supports untracked cache"
 msgstr "测试文件系统是否支持未跟踪文件缓存"
 
-#: builtin/update-index.c:1030
+#: builtin/update-index.c:1061
 msgid "enable untracked cache without testing the filesystem"
 msgstr "无需检测文件系统，启用对未跟踪文件的缓存"
 
-#: builtin/update-index.c:1032
+#: builtin/update-index.c:1063
 msgid "write out the index even if is not flagged as changed"
 msgstr "即使没有被标记为已更改，也要写出索引"
 
-#: builtin/update-index.c:1034
+#: builtin/update-index.c:1065
 msgid "enable or disable file system monitor"
 msgstr "启用或禁用文件系统监控"
 
-#: builtin/update-index.c:1036
+#: builtin/update-index.c:1067
 msgid "mark files as fsmonitor valid"
 msgstr "标记文件为 fsmonitor 有效"
 
-#: builtin/update-index.c:1039
+#: builtin/update-index.c:1070
 msgid "clear fsmonitor valid bit"
 msgstr "清除 fsmonitor 有效位"
 
-#: builtin/update-index.c:1138
+#: builtin/update-index.c:1173
 msgid ""
 "core.splitIndex is set to false; remove or change it, if you really want to "
 "enable split index"
 msgstr ""
 "core.splitIndex 被设置为 false。如果您确实要启用索引拆分，请删除或修改它。"
 
-#: builtin/update-index.c:1147
+#: builtin/update-index.c:1182
 msgid ""
 "core.splitIndex is set to true; remove or change it, if you really want to "
 "disable split index"
 msgstr ""
 "core.splitIndex 被设置为 true。如果您确实要禁用索引拆分，请删除或修改它。"
 
-#: builtin/update-index.c:1158
+#: builtin/update-index.c:1194
 msgid ""
 "core.untrackedCache is set to true; remove or change it, if you really want "
 "to disable the untracked cache"
@@ -14813,11 +20882,11 @@ msgstr ""
 "core.untrackedCache 被设置为 true。如果您确实要禁用未跟踪文件缓存，请删除或修"
 "改它。"
 
-#: builtin/update-index.c:1162
+#: builtin/update-index.c:1198
 msgid "Untracked cache disabled"
 msgstr "缓存未跟踪文件被禁用"
 
-#: builtin/update-index.c:1170
+#: builtin/update-index.c:1206
 msgid ""
 "core.untrackedCache is set to false; remove or change it, if you really want "
 "to enable the untracked cache"
@@ -14825,25 +20894,25 @@ msgstr ""
 "core.untrackedCache 被设置为 false。如果您确实要启用未跟踪文件缓存，请删除或"
 "修改它。"
 
-#: builtin/update-index.c:1174
+#: builtin/update-index.c:1210
 #, c-format
 msgid "Untracked cache enabled for '%s'"
 msgstr "缓存未跟踪文件在 '%s' 启用"
 
-#: builtin/update-index.c:1182
+#: builtin/update-index.c:1218
 msgid "core.fsmonitor is unset; set it if you really want to enable fsmonitor"
 msgstr "core.fsmonitor 未设置；如果想要启用 fsmonitor 请设置该选项"
 
-#: builtin/update-index.c:1186
+#: builtin/update-index.c:1222
 msgid "fsmonitor enabled"
 msgstr "fsmonitor 被启用"
 
-#: builtin/update-index.c:1189
+#: builtin/update-index.c:1225
 msgid ""
 "core.fsmonitor is set; remove it if you really want to disable fsmonitor"
 msgstr "core.fsmonitor 已设置；如果想要禁用 fsmonitor 请移除该选项"
 
-#: builtin/update-index.c:1193
+#: builtin/update-index.c:1229
 msgid "fsmonitor disabled"
 msgstr "fsmonitor 被禁用"
 
@@ -14859,19 +20928,19 @@ msgstr "git update-ref [<选项>]    <
 msgid "git update-ref [<options>] --stdin [-z]"
 msgstr "git update-ref [<选项>] --stdin [-z]"
 
-#: builtin/update-ref.c:363
+#: builtin/update-ref.c:364
 msgid "delete the reference"
 msgstr "删除引用"
 
-#: builtin/update-ref.c:365
+#: builtin/update-ref.c:366
 msgid "update <refname> not the one it points to"
 msgstr "更新 <引用名> 本身而不是它指向的引用"
 
-#: builtin/update-ref.c:366
+#: builtin/update-ref.c:367
 msgid "stdin has NUL-terminated arguments"
 msgstr "标准输入有以 NUL 字符终止的参数"
 
-#: builtin/update-ref.c:367
+#: builtin/update-ref.c:368
 msgid "read updates from stdin"
 msgstr "从标准输入读取更新"
 
@@ -14887,6 +20956,10 @@ msgstr "从头开始更新文件信息"
 msgid "git upload-pack [<options>] <dir>"
 msgstr "git upload-pack [<选项>] <目录>"
 
+#: builtin/upload-pack.c:23 t/helper/test-serve-v2.c:17
+msgid "quit after a single request/response exchange"
+msgstr "在一次单独的请求/响应之后退出"
+
 #: builtin/upload-pack.c:25
 msgid "exit immediately after initial ref advertisement"
 msgstr "在初始的引用广告后立即退出"
@@ -14899,15 +20972,15 @@ msgstr "如果 <目录> 不是一个 Git
 msgid "interrupt transfer after <n> seconds of inactivity"
 msgstr "不活动 <n> 秒钟后终止传输"
 
-#: builtin/verify-commit.c:18
+#: builtin/verify-commit.c:19
 msgid "git verify-commit [-v | --verbose] <commit>..."
 msgstr "git verify-commit [-v | --verbose] <提交>..."
 
-#: builtin/verify-commit.c:73
+#: builtin/verify-commit.c:68
 msgid "print commit contents"
 msgstr "打印提交内容"
 
-#: builtin/verify-commit.c:74 builtin/verify-tag.c:38
+#: builtin/verify-commit.c:69 builtin/verify-tag.c:37
 msgid "print raw gpg status output"
 msgstr "打印原始 gpg 状态输出"
 
@@ -14923,11 +20996,11 @@ msgstr "冗长输出"
 msgid "show statistics only"
 msgstr "只显示统计"
 
-#: builtin/verify-tag.c:19
+#: builtin/verify-tag.c:18
 msgid "git verify-tag [-v | --verbose] [--format=<format>] <tag>..."
 msgstr "git verify-tag [-v | --verbose] [--format=<格式>] <标签>..."
 
-#: builtin/verify-tag.c:37
+#: builtin/verify-tag.c:36
 msgid "print tag contents"
 msgstr "打印标签内容"
 
@@ -14959,226 +21032,269 @@ msgstr "git worktree remove [<选项>] <
 msgid "git worktree unlock <path>"
 msgstr "git worktree unlock <路径>"
 
-#: builtin/worktree.c:58
+#: builtin/worktree.c:60 builtin/worktree.c:898
+#, c-format
+msgid "failed to delete '%s'"
+msgstr "删除 '%s' 失败"
+
+#: builtin/worktree.c:79
 #, c-format
 msgid "Removing worktrees/%s: not a valid directory"
 msgstr "删除工作区/%s：不是一个有效的目录"
 
-#: builtin/worktree.c:64
+#: builtin/worktree.c:85
 #, c-format
 msgid "Removing worktrees/%s: gitdir file does not exist"
 msgstr "删除 worktrees/%s：gitdir 文件不存在"
 
-#: builtin/worktree.c:69 builtin/worktree.c:78
+#: builtin/worktree.c:90 builtin/worktree.c:99
 #, c-format
 msgid "Removing worktrees/%s: unable to read gitdir file (%s)"
 msgstr "删除 worktrees/%s：无法读取 gitdir 文件 (%s)"
 
-#: builtin/worktree.c:88
+#: builtin/worktree.c:109
 #, c-format
 msgid ""
 "Removing worktrees/%s: short read (expected %<PRIuMAX> bytes, read "
 "%<PRIuMAX>)"
 msgstr "删除工作树/%s：读取过短（期望 %<PRIuMAX> 字节，读取 %<PRIuMAX>）"
 
-#: builtin/worktree.c:96
+#: builtin/worktree.c:117
 #, c-format
 msgid "Removing worktrees/%s: invalid gitdir file"
 msgstr "删除 worktrees/%s：无效的 gitdir 文件"
 
-#: builtin/worktree.c:105
+#: builtin/worktree.c:126
 #, c-format
 msgid "Removing worktrees/%s: gitdir file points to non-existent location"
 msgstr "删除 worktrees/%s：gitdir 文件的指向不存在"
 
-#: builtin/worktree.c:152
+#: builtin/worktree.c:165
 msgid "report pruned working trees"
 msgstr "报告清除的工作区"
 
-#: builtin/worktree.c:154
+#: builtin/worktree.c:167
 msgid "expire working trees older than <time>"
 msgstr "将早于 <时间> 的工作区过期"
 
-#: builtin/worktree.c:229
+#: builtin/worktree.c:234
 #, c-format
 msgid "'%s' already exists"
 msgstr "'%s' 已经存在"
 
-#: builtin/worktree.c:260
+#: builtin/worktree.c:251
+#, c-format
+msgid "unable to re-add worktree '%s'"
+msgstr "无法再次添加工作区 '%s'"
+
+#: builtin/worktree.c:256
+#, c-format
+msgid ""
+"'%s' is a missing but locked worktree;\n"
+"use 'add -f -f' to override, or 'unlock' and 'prune' or 'remove' to clear"
+msgstr ""
+"'%s' 是一个丢失但锁定的工作区，使用\n"
+"'add -f -f' 覆盖，或 'unlock' 和 'prune' 或 'remove' 清除"
+
+#: builtin/worktree.c:258
+#, c-format
+msgid ""
+"'%s' is a missing but already registered worktree;\n"
+"use 'add -f' to override, or 'prune' or 'remove' to clear"
+msgstr ""
+"'%s' 是一个丢失但已经注册的工作区，使用\n"
+"'add -f' 覆盖，或 'prune' 或 'remove' 清除"
+
+#: builtin/worktree.c:308
 #, c-format
 msgid "could not create directory of '%s'"
 msgstr "不能创建目录 '%s'"
 
-#: builtin/worktree.c:373 builtin/worktree.c:379
+#: builtin/worktree.c:439 builtin/worktree.c:445
 #, c-format
 msgid "Preparing worktree (new branch '%s')"
 msgstr "准备工作区（新分支 '%s'）"
 
-#: builtin/worktree.c:375
+#: builtin/worktree.c:441
 #, c-format
 msgid "Preparing worktree (resetting branch '%s'; was at %s)"
 msgstr "准备工作区（重置分支 '%s'，之前为 %s）"
 
-#: builtin/worktree.c:384
+#: builtin/worktree.c:450
 #, c-format
 msgid "Preparing worktree (checking out '%s')"
 msgstr "准备工作区（检出 '%s'）"
 
-#: builtin/worktree.c:390
+#: builtin/worktree.c:456
 #, c-format
 msgid "Preparing worktree (detached HEAD %s)"
 msgstr "准备工作区（分离头指针 %s）"
 
-#: builtin/worktree.c:431
+#: builtin/worktree.c:497
 msgid "checkout <branch> even if already checked out in other worktree"
 msgstr "检出 <分支>，即使已经被检出到其它工作区"
 
-#: builtin/worktree.c:434
+#: builtin/worktree.c:500
 msgid "create a new branch"
 msgstr "创建一个新分支"
 
-#: builtin/worktree.c:436
+#: builtin/worktree.c:502
 msgid "create or reset a branch"
 msgstr "创建或重置一个分支"
 
-#: builtin/worktree.c:438
+#: builtin/worktree.c:504
 msgid "populate the new working tree"
 msgstr "生成新的工作区"
 
-#: builtin/worktree.c:439
+#: builtin/worktree.c:505
 msgid "keep the new working tree locked"
 msgstr "锁定新工作区"
 
-#: builtin/worktree.c:441
+#: builtin/worktree.c:508
 msgid "set up tracking mode (see git-branch(1))"
 msgstr "设置跟踪模式（参见 git-branch(1)）"
 
-#: builtin/worktree.c:444
+#: builtin/worktree.c:511
 msgid "try to match the new branch name with a remote-tracking branch"
 msgstr "尝试为新分支名匹配一个远程跟踪分支"
 
-#: builtin/worktree.c:452
+#: builtin/worktree.c:519
 msgid "-b, -B, and --detach are mutually exclusive"
 msgstr "-b、-B 和 --detach 是互斥的"
 
-#: builtin/worktree.c:511
+#: builtin/worktree.c:580
 msgid "--[no-]track can only be used if a new branch is created"
 msgstr "只能在创建新分支时使用选项 --[no-]track "
 
-#: builtin/worktree.c:611
+#: builtin/worktree.c:680
 msgid "reason for locking"
 msgstr "锁定原因"
 
-#: builtin/worktree.c:623 builtin/worktree.c:656 builtin/worktree.c:710
-#: builtin/worktree.c:850
+#: builtin/worktree.c:692 builtin/worktree.c:725 builtin/worktree.c:799
+#: builtin/worktree.c:926
 #, c-format
 msgid "'%s' is not a working tree"
 msgstr "'%s' 不是一个工作区"
 
-#: builtin/worktree.c:625 builtin/worktree.c:658
+#: builtin/worktree.c:694 builtin/worktree.c:727
 msgid "The main working tree cannot be locked or unlocked"
 msgstr "主工作区无法被加锁或解锁"
 
-#: builtin/worktree.c:630
+#: builtin/worktree.c:699
 #, c-format
 msgid "'%s' is already locked, reason: %s"
 msgstr "'%s' 已被锁定，原因：%s"
 
-#: builtin/worktree.c:632
+#: builtin/worktree.c:701
 #, c-format
 msgid "'%s' is already locked"
 msgstr "'%s' 已被锁定"
 
-#: builtin/worktree.c:660
+#: builtin/worktree.c:729
 #, c-format
 msgid "'%s' is not locked"
 msgstr "'%s' 未被锁定"
 
-#: builtin/worktree.c:685
+#: builtin/worktree.c:770
 msgid "working trees containing submodules cannot be moved or removed"
 msgstr "不能移动或删除包含子模组的工作区"
 
-#: builtin/worktree.c:712 builtin/worktree.c:852
+#: builtin/worktree.c:778
+msgid "force move even if worktree is dirty or locked"
+msgstr "强制移动，即使工作区是脏的或已锁定"
+
+#: builtin/worktree.c:801 builtin/worktree.c:928
 #, c-format
 msgid "'%s' is a main working tree"
 msgstr "'%s' 是一个主工作区"
 
-#: builtin/worktree.c:717
+#: builtin/worktree.c:806
 #, c-format
 msgid "could not figure out destination name from '%s'"
 msgstr "无法从 '%s' 算出目标名称"
 
-#: builtin/worktree.c:723
+#: builtin/worktree.c:812
 #, c-format
 msgid "target '%s' already exists"
 msgstr "目标 '%s' 已存在"
 
-#: builtin/worktree.c:730
+#: builtin/worktree.c:820
 #, c-format
-msgid "cannot move a locked working tree, lock reason: %s"
-msgstr "无法移动一个锁定的工作区，锁定原因：%s"
+msgid ""
+"cannot move a locked working tree, lock reason: %s\n"
+"use 'move -f -f' to override or unlock first"
+msgstr ""
+"无法移动一个锁定的工作区，锁定原因：%s\n"
+"使用 'move -f -f' 覆盖或先解锁"
 
-#: builtin/worktree.c:732
-msgid "cannot move a locked working tree"
-msgstr "无法移动一个锁定的工作区"
+#: builtin/worktree.c:822
+msgid ""
+"cannot move a locked working tree;\n"
+"use 'move -f -f' to override or unlock first"
+msgstr ""
+"无法移动一个锁定的工作区，\n"
+"使用 'move -f -f' 覆盖或先解锁"
 
-#: builtin/worktree.c:735
+#: builtin/worktree.c:825
 #, c-format
 msgid "validation failed, cannot move working tree: %s"
 msgstr "验证失败，无法移动工作区：%s"
 
-#: builtin/worktree.c:740
+#: builtin/worktree.c:830
 #, c-format
 msgid "failed to move '%s' to '%s'"
-msgstr "无法移动 '%s' 到 '%s'"
+msgstr "移动 '%s' 到 '%s' 失败"
 
-#: builtin/worktree.c:788
+#: builtin/worktree.c:878
 #, c-format
 msgid "failed to run 'git status' on '%s'"
-msgstr "无法在 '%s' 中执行 'git status'"
+msgstr "在 '%s' 中执行 'git status' 失败"
 
-#: builtin/worktree.c:792
+#: builtin/worktree.c:882
 #, c-format
-msgid "'%s' is dirty, use --force to delete it"
-msgstr "'%s' 是脏的，使用 --force 删除"
+msgid "'%s' contains modified or untracked files, use --force to delete it"
+msgstr "'%s' 包含修改或未跟踪的文件，使用 --force 删除"
 
-#: builtin/worktree.c:797
+#: builtin/worktree.c:887
 #, c-format
 msgid "failed to run 'git status' on '%s', code %d"
-msgstr "无法在 '%s' 中执行 'git status'，退出码 %d"
-
-#: builtin/worktree.c:808 builtin/worktree.c:822
-#, c-format
-msgid "failed to delete '%s'"
-msgstr "无法删除 '%s'"
+msgstr "在 '%s' 中执行 'git status' 失败，退出码 %d"
 
-#: builtin/worktree.c:834
-msgid "force removing even if the worktree is dirty"
-msgstr "强制删除，即使工作区是脏的"
+#: builtin/worktree.c:910
+msgid "force removal even if worktree is dirty or locked"
+msgstr "强制删除，即使工作区是脏的或已锁定"
 
-#: builtin/worktree.c:856
+#: builtin/worktree.c:933
 #, c-format
-msgid "cannot remove a locked working tree, lock reason: %s"
-msgstr "无法删除一个锁定的工作区，锁定原因：%s"
+msgid ""
+"cannot remove a locked working tree, lock reason: %s\n"
+"use 'remove -f -f' to override or unlock first"
+msgstr ""
+"无法删除一个锁定的工作区，锁定原因：%s\n"
+"使用 'remove -f -f' 覆盖或先解锁"
 
-#: builtin/worktree.c:858
-msgid "cannot remove a locked working tree"
-msgstr "无法删除一个锁定的工作区"
+#: builtin/worktree.c:935
+msgid ""
+"cannot remove a locked working tree;\n"
+"use 'remove -f -f' to override or unlock first"
+msgstr ""
+"无法删除一个锁定的工作区，\n"
+"使用 'remove -f -f' 覆盖或先解锁"
 
-#: builtin/worktree.c:861
+#: builtin/worktree.c:938
 #, c-format
 msgid "validation failed, cannot remove working tree: %s"
 msgstr "验证失败，无法删除工作区：%s"
 
-#: builtin/write-tree.c:14
+#: builtin/write-tree.c:15
 msgid "git write-tree [--missing-ok] [--prefix=<prefix>/]"
 msgstr "git write-tree [--missing-ok] [--prefix=<前缀>/]"
 
-#: builtin/write-tree.c:27
+#: builtin/write-tree.c:28
 msgid "<prefix>/"
 msgstr "<前缀>/"
 
-#: builtin/write-tree.c:28
+#: builtin/write-tree.c:29
 msgid "write tree object for a subdirectory <prefix>"
 msgstr "将 <前缀> 子目录内容写到一个树对象"
 
@@ -15186,7 +21302,22 @@ msgstr "将 <前缀> 子目录内容写
 msgid "only useful for debugging"
 msgstr "只对调试有用"
 
-#: credential-cache--daemon.c:222
+#: fast-import.c:3125
+#, c-format
+msgid "Expected 'mark' command, got %s"
+msgstr "预期 'mark' 命令，得到 %s"
+
+#: fast-import.c:3130
+#, c-format
+msgid "Expected 'to' command, got %s"
+msgstr "预期 'to' 命令，得到 %s"
+
+#: fast-import.c:3254
+#, c-format
+msgid "feature '%s' forbidden in input without --allow-unsafe-features"
+msgstr "不带 --allow-unsafe-features 的输入中禁止使用功能 '%s'"
+
+#: credential-cache--daemon.c:223
 #, c-format
 msgid ""
 "The permissions on your socket directory are too loose; other\n"
@@ -15199,10 +21330,27 @@ msgstr ""
 "\n"
 "\tchmod 0700 %s"
 
-#: credential-cache--daemon.c:271
+#: credential-cache--daemon.c:272
 msgid "print debugging messages to stderr"
 msgstr "调试信息输出到标准错误"
 
+#: t/helper/test-reach.c:152
+#, c-format
+msgid "commit %s is not marked reachable"
+msgstr "提交 %s 没有标记为可达"
+
+#: t/helper/test-reach.c:162
+msgid "too many commits marked reachable"
+msgstr "太多提交标记为可达"
+
+#: t/helper/test-serve-v2.c:7
+msgid "test-tool serve-v2 [<options>]"
+msgstr "test-tool serve-v2 [<选项>]"
+
+#: t/helper/test-serve-v2.c:19
+msgid "exit immediately after advertising capabilities"
+msgstr "对能力广告之后立即退出"
+
 #: git.c:27
 msgid ""
 "git [--version] [--help] [-C <path>] [-c <name>=<value>]\n"
@@ -15223,71 +21371,151 @@ msgstr ""
 msgid ""
 "'git help -a' and 'git help -g' list available subcommands and some\n"
 "concept guides. See 'git help <command>' or 'git help <concept>'\n"
-"to read about a specific subcommand or concept."
+"to read about a specific subcommand or concept.\n"
+"See 'git help git' for an overview of the system."
 msgstr ""
 "命令 'git help -a' 和 'git help -g' 显示可用的子命令和一些概念帮助。\n"
 "查看 'git help <命令>' 或 'git help <概念>' 以获取给定子命令或概念的\n"
-"帮助。"
+"帮助。\n"
+"有关系统的概述，查看 'git help git'。"
 
-#: git.c:173
+#: git.c:186
 #, c-format
 msgid "no directory given for --git-dir\n"
 msgstr "没有为 --git-dir 提供目录\n"
 
-#: git.c:187
+#: git.c:200
 #, c-format
 msgid "no namespace given for --namespace\n"
 msgstr "没有为 --namespace 提供命名空间\n"
 
-#: git.c:201
+#: git.c:214
 #, c-format
 msgid "no directory given for --work-tree\n"
 msgstr "没有为 --work-tree 提供目录\n"
 
-#: git.c:215
+#: git.c:228
 #, c-format
 msgid "no prefix given for --super-prefix\n"
 msgstr "没有为 --super-prefix 提供前缀\n"
 
-#: git.c:237
+#: git.c:250
 #, c-format
 msgid "-c expects a configuration string\n"
 msgstr "应为 -c 提供一个配置字符串\n"
 
-#: git.c:275
+#: git.c:288
 #, c-format
 msgid "no directory given for -C\n"
 msgstr "没有为 -C 提供目录\n"
 
-#: git.c:300
+#: git.c:314
 #, c-format
 msgid "unknown option: %s\n"
 msgstr "未知选项：%s\n"
 
-#: git.c:765
+#: git.c:360
+#, c-format
+msgid "while expanding alias '%s': '%s'"
+msgstr "在扩展别名 '%s' 时：'%s'"
+
+#: git.c:369
+#, c-format
+msgid ""
+"alias '%s' changes environment variables.\n"
+"You can use '!git' in the alias to do this"
+msgstr ""
+"别名 '%s' 修改环境变量。您可以使用在别名中\n"
+"使用 '!git'"
+
+#: git.c:376
+#, c-format
+msgid "empty alias for %s"
+msgstr "%s 的空别名"
+
+#: git.c:379
+#, c-format
+msgid "recursive alias: %s"
+msgstr "递归的别名：%s"
+
+#: git.c:459
+msgid "write failure on standard output"
+msgstr "在标准输出写入失败"
+
+#: git.c:461
+msgid "unknown write failure on standard output"
+msgstr "到标准输出的未知写入错误"
+
+#: git.c:463
+msgid "close failed on standard output"
+msgstr "标准输出关闭失败"
+
+#: git.c:793
+#, c-format
+msgid "alias loop detected: expansion of '%s' does not terminate:%s"
+msgstr "检测到别名循环：'%s'的扩展未终止：%s"
+
+#: git.c:843
+#, c-format
+msgid "cannot handle %s as a builtin"
+msgstr "不能作为内置命令处理 %s"
+
+#: git.c:856
+#, c-format
+msgid ""
+"usage: %s\n"
+"\n"
+msgstr ""
+"用法：%s\n"
+"\n"
+
+#: git.c:876
 #, c-format
 msgid "expansion of alias '%s' failed; '%s' is not a git command\n"
 msgstr "展开别名命令 '%s' 失败，'%s' 不是一个 git 命令\n"
 
-#: git.c:777
+#: git.c:888
 #, c-format
 msgid "failed to run command '%s': %s\n"
-msgstr "无法运行命令 '%s'：%s\n"
+msgstr "运行命令 '%s' 失败：%s\n"
 
-#: http.c:348
+#: http.c:378
 #, c-format
 msgid "negative value for http.postbuffer; defaulting to %d"
 msgstr "http.postbuffer 为负值，默认为 %d"
 
-#: http.c:369
+#: http.c:399
 msgid "Delegation control is not supported with cURL < 7.22.0"
-msgstr "当 cURL < 7.22.0 时，不支持委托控制"
+msgstr "不支持委托控制，因为 cURL < 7.22.0"
 
-#: http.c:378
+#: http.c:408
 msgid "Public key pinning not supported with cURL < 7.44.0"
 msgstr "不支持公钥文件锁定，因为 cURL < 7.44.0"
 
-#: http.c:1854
+#: http.c:876
+msgid "CURLSSLOPT_NO_REVOKE not supported with cURL < 7.44.0"
+msgstr "不支持 CURLSSLOPT_NO_REVOKE，因为 cURL < 7.44.0"
+
+#: http.c:949
+msgid "Protocol restrictions not supported with cURL < 7.19.4"
+msgstr "不支持协议限制，因为 cURL < 7.19.4"
+
+#: http.c:1086
+#, c-format
+msgid "Unsupported SSL backend '%s'. Supported SSL backends:"
+msgstr "不支持的 SSL 后端 '%s'。支持的 SSL 后端："
+
+#: http.c:1093
+#, c-format
+msgid "Could not set SSL backend to '%s': cURL was built without SSL backends"
+msgstr "无法设置 SSL 后端为 '%s'：cURL: cURL 没有使用 SSL 后端构建"
+
+#: http.c:1097
+#, c-format
+msgid "Could not set SSL backend to '%s': already set"
+msgstr "无法将 SSL 后端设置为 '%s'：已经设置"
+
+#: http.c:1966
 #, c-format
 msgid ""
 "unable to update url base from redirection:\n"
@@ -15298,39 +21526,176 @@ msgstr ""
 "     请求：%s\n"
 "   重定向：%s"
 
-#: remote-curl.c:401
+#: remote-curl.c:166
+#, c-format
+msgid "invalid quoting in push-option value: '%s'"
+msgstr "在 push-option 取值中无效的引号：'%s'"
+
+#: remote-curl.c:263
+#, c-format
+msgid "%sinfo/refs not valid: is this a git repository?"
+msgstr "%sinfo/refs 无效：这是一个 git 仓库么？"
+
+#: remote-curl.c:364
+msgid "invalid server response; expected service, got flush packet"
+msgstr "无效的服务端响应。预期服务，得到 flush 包"
+
+#: remote-curl.c:395
+#, c-format
+msgid "invalid server response; got '%s'"
+msgstr "无效的服务端响应，得到 '%s'"
+
+#: remote-curl.c:455
+#, c-format
+msgid "repository '%s' not found"
+msgstr "仓库 '%s' 未找到"
+
+#: remote-curl.c:459
+#, c-format
+msgid "Authentication failed for '%s'"
+msgstr "'%s' 鉴权失败"
+
+#: remote-curl.c:463
+#, c-format
+msgid "unable to access '%s': %s"
+msgstr "无法访问 '%s'：%s"
+
+#: remote-curl.c:469
 #, c-format
 msgid "redirecting to %s"
 msgstr "重定向到 %s"
 
-#: list-objects-filter-options.h:59
+#: remote-curl.c:593
+msgid "shouldn't have EOF when not gentle on EOF"
+msgstr "当没有设置温和处理文件结束符（EOF）时，不应该有文件结束符"
+
+#: remote-curl.c:673
+msgid "unable to rewind rpc post data - try increasing http.postBuffer"
+msgstr "无法倒回 rpc post 数据 - 尝试增加 http.postBuffer"
+
+#: remote-curl.c:733
+#, c-format
+msgid "RPC failed; %s"
+msgstr "RPC 失败。%s"
+
+#: remote-curl.c:773
+msgid "cannot handle pushes this big"
+msgstr "不能处理这么大的推送"
+
+#: remote-curl.c:888
+#, c-format
+msgid "cannot deflate request; zlib deflate error %d"
+msgstr "不能压缩请求，zlib 压缩错误 %d"
+
+#: remote-curl.c:892
+#, c-format
+msgid "cannot deflate request; zlib end error %d"
+msgstr "不能压缩请求，zlib 结束错误 %d"
+
+#: remote-curl.c:1023
+msgid "dumb http transport does not support shallow capabilities"
+msgstr "哑 http 传输不支持 shalllow 能力"
+
+#: remote-curl.c:1037
+msgid "fetch failed."
+msgstr "获取失败。"
+
+#: remote-curl.c:1085
+msgid "cannot fetch by sha1 over smart http"
+msgstr "无法通过智能 HTTP 获取 sha1"
+
+#: remote-curl.c:1129 remote-curl.c:1135
+#, c-format
+msgid "protocol error: expected sha/ref, got '%s'"
+msgstr "协议错误：期望 sha/ref，却得到 '%s'"
+
+#: remote-curl.c:1147 remote-curl.c:1261
+#, c-format
+msgid "http transport does not support %s"
+msgstr "http 传输协议不支持 %s"
+
+#: remote-curl.c:1183
+msgid "git-http-push failed"
+msgstr "git-http-push 失败"
+
+#: remote-curl.c:1367
+msgid "remote-curl: usage: git remote-curl <remote> [<url>]"
+msgstr "remote-curl：用法：git remote-curl <远程> [<url>]"
+
+#: remote-curl.c:1399
+msgid "remote-curl: error reading command stream from git"
+msgstr "remote-curl：错误读取来自 git 的命令流"
+
+#: remote-curl.c:1406
+msgid "remote-curl: fetch attempted without a local repo"
+msgstr "remote-curl：尝试没有本地仓库下获取"
+
+#: remote-curl.c:1446
+#, c-format
+msgid "remote-curl: unknown command '%s' from git"
+msgstr "remote-curl：未知的来自 git 的命令 '%s'"
+
+#: list-objects-filter-options.h:85
 msgid "args"
 msgstr "参数"
 
-#: list-objects-filter-options.h:60
+#: list-objects-filter-options.h:86
 msgid "object filtering"
 msgstr "对象过滤"
 
-#: parse-options.h:157
+#: parse-options.h:183
 msgid "expiry-date"
 msgstr "到期时间"
 
-#: parse-options.h:172
+#: parse-options.h:197
 msgid "no-op (backward compatibility)"
 msgstr "空操作（向后兼容）"
 
-#: parse-options.h:251
+#: parse-options.h:309
 msgid "be more verbose"
 msgstr "更加详细"
 
-#: parse-options.h:253
+#: parse-options.h:311
 msgid "be more quiet"
 msgstr "更加安静"
 
-#: parse-options.h:259
+#: parse-options.h:317
 msgid "use <n> digits to display SHA-1s"
 msgstr "用 <n> 位数字显示 SHA-1 哈希值"
 
+#: parse-options.h:336
+msgid "how to strip spaces and #comments from message"
+msgstr "设置如何删除提交说明里的空格和#注释"
+
+#: parse-options.h:337
+msgid "read pathspec from file"
+msgstr "从文件读取路径表达式"
+
+#: parse-options.h:338
+msgid ""
+"with --pathspec-from-file, pathspec elements are separated with NUL character"
+msgstr "使用 --pathspec-from-file，路径表达式用空字符分隔"
+
+#: ref-filter.h:101
+msgid "key"
+msgstr "key"
+
+#: ref-filter.h:101
+msgid "field name to sort on"
+msgstr "排序的字段名"
+
+#: rerere.h:44
+msgid "update the index with reused conflict resolution if possible"
+msgstr "如果可能，重用冲突解决更新索引"
+
+#: wt-status.h:67
+msgid "HEAD detached at "
+msgstr "头指针分离于 "
+
+#: wt-status.h:68
+msgid "HEAD detached from "
+msgstr "头指针分离自 "
+
 #: command-list.h:50
 msgid "Add file contents to the index"
 msgstr "添加文件内容至索引"
@@ -15348,8 +21713,8 @@ msgid "Apply a patch to files and/or to
 msgstr "应用一个补丁到文件和/或索引区"
 
 #: command-list.h:54
-msgid "Import an Arch repository into Git"
-msgstr "将一个 Arch 仓库导入到 Git"
+msgid "Import a GNU Arch repository into Git"
+msgstr "将一个 GNU Arch 仓库导入到 Git"
 
 #: command-list.h:55
 msgid "Create an archive of files from a named tree"
@@ -15417,7 +21782,7 @@ msgstr "从工作区中删除未跟踪
 
 #: command-list.h:71
 msgid "Clone a repository into a new directory"
-msgstr "克隆一个仓库到一个新目录"
+msgstr "克隆仓库到一个新目录"
 
 #: command-list.h:72
 msgid "Display data in columns"
@@ -15428,8 +21793,8 @@ msgid "Record changes to the repository"
 msgstr "记录变更到仓库"
 
 #: command-list.h:74
-msgid "Write and verify Git commit graph files"
-msgstr "写入和校验 Git 提交图形文件"
+msgid "Write and verify Git commit-graph files"
+msgstr "写入和校验 Git 提交图文件"
 
 #: command-list.h:75
 msgid "Create a new commit object"
@@ -15537,7 +21902,7 @@ msgstr "清除不必要的文件和优
 
 #: command-list.h:101
 msgid "Extract commit ID from an archive created using git-archive"
-msgstr "从 git-archive 创建的归档文件中提取提交ID"
+msgstr "从 git-archive 创建的归档文件中提取提交 ID"
 
 #: command-list.h:102
 msgid "Print lines matching a pattern"
@@ -15549,7 +21914,7 @@ msgstr "一个便携的 Git 图形客户
 
 #: command-list.h:104
 msgid "Compute object ID and optionally creates a blob from a file"
-msgstr "从一个文件计算对象ID，并可以创建 blob 数据对象"
+msgstr "从一个文件计算对象 ID，并可以创建 blob 数据对象"
 
 #: command-list.h:105
 msgid "Display help information about Git"
@@ -15584,7 +21949,7 @@ msgid "Instantly browse your working rep
 msgstr "在 gitweb 中即时浏览您的工作仓库"
 
 #: command-list.h:113
-msgid "add or parse structured information in commit messages"
+msgid "Add or parse structured information in commit messages"
 msgstr "添加或解析提交说明中的结构化信息"
 
 #: command-list.h:114
@@ -15644,326 +22009,346 @@ msgid "Show three-way merge without touc
 msgstr "显示三路合并而不动索引"
 
 #: command-list.h:128
+msgid "Write and verify multi-pack-indexes"
+msgstr "写入和校验多包索引"
+
+#: command-list.h:129
 msgid "Creates a tag object"
 msgstr "创建一个标签对象"
 
-#: command-list.h:129
+#: command-list.h:130
 msgid "Build a tree-object from ls-tree formatted text"
 msgstr "基于 ls-tree 的格式化文本创建一个树对象"
 
-#: command-list.h:130
+#: command-list.h:131
 msgid "Move or rename a file, a directory, or a symlink"
 msgstr "移动或重命名一个文件、目录或符号链接"
 
 # 查找给定版本的符号名称
-#: command-list.h:131
+#: command-list.h:132
 msgid "Find symbolic names for given revs"
 msgstr "查找给定版本的符号名称"
 
-#: command-list.h:132
+#: command-list.h:133
 msgid "Add or inspect object notes"
 msgstr "添加或检查对象注释"
 
-#: command-list.h:133
+#: command-list.h:134
 msgid "Import from and submit to Perforce repositories"
 msgstr "导入和提交到 Perforce 仓库中"
 
-#: command-list.h:134
+#: command-list.h:135
 msgid "Create a packed archive of objects"
 msgstr "创建对象的存档包"
 
-#: command-list.h:135
+#: command-list.h:136
 msgid "Find redundant pack files"
 msgstr "查找冗余的包文件"
 
-#: command-list.h:136
+#: command-list.h:137
 msgid "Pack heads and tags for efficient repository access"
 msgstr "打包头和标签以实现高效的仓库访问"
 
-#: command-list.h:137
+#: command-list.h:138
 msgid "Routines to help parsing remote repository access parameters"
 msgstr "帮助解析远程仓库访问参数的例程"
 
-#: command-list.h:138
+#: command-list.h:139
 msgid "Compute unique ID for a patch"
-msgstr "计算一个补丁的唯一ID"
+msgstr "计算一个补丁的唯一 ID"
 
-#: command-list.h:139
+#: command-list.h:140
 msgid "Prune all unreachable objects from the object database"
 msgstr "删除对象库中所有不可达对象"
 
-#: command-list.h:140
+#: command-list.h:141
 msgid "Remove extra objects that are already in pack files"
 msgstr "删除已经在包文件中的多余对象"
 
-#: command-list.h:141
+#: command-list.h:142
 msgid "Fetch from and integrate with another repository or a local branch"
 msgstr "获取并整合另外的仓库或一个本地分支"
 
-#: command-list.h:142
+#: command-list.h:143
 msgid "Update remote refs along with associated objects"
 msgstr "更新远程引用和相关的对象"
 
-#: command-list.h:143
+#: command-list.h:144
 msgid "Applies a quilt patchset onto the current branch"
 msgstr "将一个 quilt 补丁集应用到当前分支。"
 
-#: command-list.h:144
+#: command-list.h:145
+msgid "Compare two commit ranges (e.g. two versions of a branch)"
+msgstr "比较两个提交范围（如一个分支的两个版本）"
+
+#: command-list.h:146
 msgid "Reads tree information into the index"
 msgstr "将树信息读取到索引"
 
-#: command-list.h:145
+#: command-list.h:147
 msgid "Reapply commits on top of another base tip"
 msgstr "在另一个分支上重新应用提交"
 
-#: command-list.h:146
+#: command-list.h:148
 msgid "Receive what is pushed into the repository"
 msgstr "接收推送到仓库中的对象"
 
-#: command-list.h:147
+#: command-list.h:149
 msgid "Manage reflog information"
 msgstr "管理 reflog 信息"
 
-#: command-list.h:148
+#: command-list.h:150
 msgid "Manage set of tracked repositories"
 msgstr "管理已跟踪仓库"
 
-#: command-list.h:149
+#: command-list.h:151
 msgid "Pack unpacked objects in a repository"
 msgstr "打包仓库中未打包对象"
 
-#: command-list.h:150
+#: command-list.h:152
 msgid "Create, list, delete refs to replace objects"
 msgstr "创建、列出、删除对象替换引用"
 
-#: command-list.h:151
+#: command-list.h:153
 msgid "Generates a summary of pending changes"
 msgstr "生成待定更改的摘要"
 
-#: command-list.h:152
+#: command-list.h:154
 msgid "Reuse recorded resolution of conflicted merges"
 msgstr "重用冲突合并的解决方案记录"
 
-#: command-list.h:153
+#: command-list.h:155
 msgid "Reset current HEAD to the specified state"
 msgstr "重置当前 HEAD 到指定状态"
 
-#: command-list.h:154
+#: command-list.h:156
+msgid "Restore working tree files"
+msgstr "恢复工作区文件"
+
+#: command-list.h:157
 msgid "Revert some existing commits"
 msgstr "回退一些现存提交"
 
-#: command-list.h:155
+#: command-list.h:158
 msgid "Lists commit objects in reverse chronological order"
 msgstr "按时间顺序列出提交对象"
 
-#: command-list.h:156
+#: command-list.h:159
 msgid "Pick out and massage parameters"
 msgstr "选出并处理参数"
 
-#: command-list.h:157
+#: command-list.h:160
 msgid "Remove files from the working tree and from the index"
 msgstr "从工作区和索引中删除文件"
 
-#: command-list.h:158
+#: command-list.h:161
 msgid "Send a collection of patches as emails"
 msgstr "通过电子邮件发送一组补丁"
 
-#: command-list.h:159
+#: command-list.h:162
 msgid "Push objects over Git protocol to another repository"
 msgstr "使用 Git 协议推送对象到另一个仓库"
 
-#: command-list.h:160
+#: command-list.h:163
 msgid "Restricted login shell for Git-only SSH access"
 msgstr "只允许 Git SSH 访问的受限登录shell"
 
-#: command-list.h:161
+#: command-list.h:164
 msgid "Summarize 'git log' output"
 msgstr "'git log' 输出摘要"
 
-#: command-list.h:162
+#: command-list.h:165
 msgid "Show various types of objects"
 msgstr "显示各种类型的对象"
 
-#: command-list.h:163
+#: command-list.h:166
 msgid "Show branches and their commits"
 msgstr "显示分支和提交"
 
-#: command-list.h:164
+#: command-list.h:167
 msgid "Show packed archive index"
 msgstr "显示打包归档索引"
 
-#: command-list.h:165
+#: command-list.h:168
 msgid "List references in a local repository"
 msgstr "显示本地仓库中的引用"
 
-#: command-list.h:166
+#: command-list.h:169
 msgid "Git's i18n setup code for shell scripts"
 msgstr "为 shell 脚本准备的 Git 国际化设置代码"
 
-#: command-list.h:167
+#: command-list.h:170
 msgid "Common Git shell script setup code"
 msgstr "常用的 Git shell 脚本设置代码"
 
-#: command-list.h:168
+#: command-list.h:171
+msgid "Initialize and modify the sparse-checkout"
+msgstr "初始化及修改稀疏检出"
+
+#: command-list.h:172
 msgid "Stash the changes in a dirty working directory away"
 msgstr "贮藏脏工作区中的修改"
 
-#: command-list.h:169
+#: command-list.h:173
 msgid "Add file contents to the staging area"
 msgstr "将文件内容添加到索引"
 
-#: command-list.h:170
+#: command-list.h:174
 msgid "Show the working tree status"
 msgstr "显示工作区状态"
 
-#: command-list.h:171
+#: command-list.h:175
 msgid "Remove unnecessary whitespace"
 msgstr "删除不必要的空白字符"
 
-#: command-list.h:172
+#: command-list.h:176
 msgid "Initialize, update or inspect submodules"
 msgstr "初始化、更新或检查子模组"
 
-#: command-list.h:173
+#: command-list.h:177
 msgid "Bidirectional operation between a Subversion repository and Git"
 msgstr "Subersion 仓库和 Git 之间的双向操作"
 
-#: command-list.h:174
+#: command-list.h:178
+msgid "Switch branches"
+msgstr "切换分支"
+
+#: command-list.h:179
 msgid "Read, modify and delete symbolic refs"
 msgstr "读取、修改和删除符号引用"
 
-#: command-list.h:175
+#: command-list.h:180
 msgid "Create, list, delete or verify a tag object signed with GPG"
 msgstr "创建、列出、删除或校验一个 GPG 签名的标签对象"
 
-#: command-list.h:176
+#: command-list.h:181
 msgid "Creates a temporary file with a blob's contents"
 msgstr "用 blob 数据对象的内容创建一个临时文件"
 
-#: command-list.h:177
+#: command-list.h:182
 msgid "Unpack objects from a packed archive"
 msgstr "从打包文件中解压缩对象"
 
-#: command-list.h:178
+#: command-list.h:183
 msgid "Register file contents in the working tree to the index"
 msgstr "将工作区的文件内容注册到索引"
 
-#: command-list.h:179
+#: command-list.h:184
 msgid "Update the object name stored in a ref safely"
 msgstr "安全地更新存储于引用中的对象名称"
 
-#: command-list.h:180
+#: command-list.h:185
 msgid "Update auxiliary info file to help dumb servers"
 msgstr "更新辅助信息文件以帮助哑协议服务"
 
-#: command-list.h:181
+#: command-list.h:186
 msgid "Send archive back to git-archive"
 msgstr "将存档发送回 git-archive"
 
-#: command-list.h:182
+#: command-list.h:187
 msgid "Send objects packed back to git-fetch-pack"
 msgstr "将对象压缩包发送回 git-fetch-pack"
 
-#: command-list.h:183
+#: command-list.h:188
 msgid "Show a Git logical variable"
 msgstr "显示一个Git逻辑变量"
 
-#: command-list.h:184
+#: command-list.h:189
 msgid "Check the GPG signature of commits"
 msgstr "检查 GPG 提交签名"
 
-#: command-list.h:185
+#: command-list.h:190
 msgid "Validate packed Git archive files"
 msgstr "校验打包的Git存仓文件"
 
-#: command-list.h:186
+#: command-list.h:191
 msgid "Check the GPG signature of tags"
 msgstr "检查标签的 GPG 签名"
 
-#: command-list.h:187
+#: command-list.h:192
 msgid "Git web interface (web frontend to Git repositories)"
 msgstr "Git web 界面（Git 仓库的 web 前端）"
 
-#: command-list.h:188
+#: command-list.h:193
 msgid "Show logs with difference each commit introduces"
 msgstr "显示每一个提交引入的差异日志"
 
-#: command-list.h:189
+#: command-list.h:194
 msgid "Manage multiple working trees"
 msgstr "管理多个工作区"
 
-#: command-list.h:190
+#: command-list.h:195
 msgid "Create a tree object from the current index"
 msgstr "从当前索引创建一个树对象"
 
-#: command-list.h:191
+#: command-list.h:196
 msgid "Defining attributes per path"
 msgstr "定义路径的属性"
 
-#: command-list.h:192
+#: command-list.h:197
 msgid "Git command-line interface and conventions"
 msgstr "Git 命令行界面和约定"
 
-#: command-list.h:193
+#: command-list.h:198
 msgid "A Git core tutorial for developers"
 msgstr "面向开发人员的 Git 核心教程"
 
-#: command-list.h:194
+#: command-list.h:199
 msgid "Git for CVS users"
 msgstr "适合 CVS 用户的 Git 帮助"
 
-#: command-list.h:195
+#: command-list.h:200
 msgid "Tweaking diff output"
 msgstr "调整差异输出"
 
-#: command-list.h:196
+#: command-list.h:201
 msgid "A useful minimum set of commands for Everyday Git"
 msgstr "每一天 Git 的一组有用的最小命令集合"
 
-#: command-list.h:197
+#: command-list.h:202
 msgid "A Git Glossary"
 msgstr "Git 词汇表"
 
-#: command-list.h:198
+#: command-list.h:203
 msgid "Hooks used by Git"
 msgstr "Git 使用的钩子"
 
-#: command-list.h:199
+#: command-list.h:204
 msgid "Specifies intentionally untracked files to ignore"
 msgstr "忽略指定的未跟踪文件"
 
-#: command-list.h:200
+#: command-list.h:205
 msgid "Defining submodule properties"
 msgstr "定义子模组属性"
 
-#: command-list.h:201
+#: command-list.h:206
 msgid "Git namespaces"
 msgstr "Git 名字空间"
 
-#: command-list.h:202
+#: command-list.h:207
 msgid "Git Repository Layout"
 msgstr "Git 仓库布局"
 
-#: command-list.h:203
+#: command-list.h:208
 msgid "Specifying revisions and ranges for Git"
 msgstr "指定 Git 的版本和版本范围"
 
-#: command-list.h:204
+#: command-list.h:209
+msgid "Mounting one repository inside another"
+msgstr "将一个仓库安装到另外一个仓库中"
+
+#: command-list.h:210
 msgid "A tutorial introduction to Git: part two"
 msgstr "一个 Git 教程：第二部分"
 
-#: command-list.h:205
+#: command-list.h:211
 msgid "A tutorial introduction to Git"
 msgstr "一个 Git 教程"
 
-#: command-list.h:206
+#: command-list.h:212
 msgid "An overview of recommended workflows with Git"
 msgstr "Git 推荐的工作流概览"
 
-#: rerere.h:40
-msgid "update the index with reused conflict resolution if possible"
-msgstr "如果可能，重用冲突解决更新索引"
-
 #: git-bisect.sh:54
 msgid "You need to start by \"git bisect start\""
 msgstr "您需要执行 \"git bisect start\" 来开始"
@@ -15976,133 +22361,49 @@ msgstr "您需要执行 \"git bisect sta
 msgid "Do you want me to do it for you [Y/n]? "
 msgstr "您想让我为您这样做么[Y/n]？ "
 
-#: git-bisect.sh:121
-#, sh-format
-msgid "unrecognised option: '$arg'"
-msgstr "未能识别的选项：'$arg'"
-
-#: git-bisect.sh:125
-#, sh-format
-msgid "'$arg' does not appear to be a valid revision"
-msgstr "'$arg' 看起来不像是一个有效的版本"
-
-#: git-bisect.sh:154
-msgid "Bad HEAD - I need a HEAD"
-msgstr "坏的 HEAD - 我需要一个 HEAD"
-
-#: git-bisect.sh:167
-#, sh-format
-msgid ""
-"Checking out '$start_head' failed. Try 'git bisect reset <valid-branch>'."
-msgstr "检出 '$start_head' 失败。尝试 'git bisect reset <有效分支>'。"
-
-#: git-bisect.sh:177
-msgid "won't bisect on cg-seek'ed tree"
-msgstr "不会在做了 cg-seek 的树上做二分查找"
-
-#: git-bisect.sh:181
-msgid "Bad HEAD - strange symbolic ref"
-msgstr "坏的 HEAD - 奇怪的符号引用"
-
-#: git-bisect.sh:233
-#, sh-format
-msgid "Bad bisect_write argument: $state"
-msgstr "坏的 bisect_write 参数：$state"
-
-#: git-bisect.sh:246
+#: git-bisect.sh:101
 #, sh-format
 msgid "Bad rev input: $arg"
 msgstr "坏的输入版本：$arg"
 
-#: git-bisect.sh:265
+#: git-bisect.sh:121
 #, sh-format
 msgid "Bad rev input: $bisected_head"
 msgstr "坏的输入版本：$bisected_head"
 
-#: git-bisect.sh:274
+#: git-bisect.sh:130
 #, sh-format
 msgid "Bad rev input: $rev"
 msgstr "坏的输入版本：$rev"
 
-#: git-bisect.sh:283
+#: git-bisect.sh:139
 #, sh-format
 msgid "'git bisect $TERM_BAD' can take only one argument."
 msgstr "'git bisect $TERM_BAD' 只能带一个参数。"
 
-#: git-bisect.sh:306
-#, sh-format
-msgid "Warning: bisecting only with a $TERM_BAD commit."
-msgstr "警告：在仅有一个坏（$TERM_BAD）提交下进行二分查找。"
-
-#  译者：注意保持句尾空格
-#. TRANSLATORS: Make sure to include [Y] and [n] in your
-#. translation. The program will only accept English input
-#. at this point.
-#: git-bisect.sh:312
-msgid "Are you sure [Y/n]? "
-msgstr "您确认么[Y/n]？ "
-
-#: git-bisect.sh:324
-#, sh-format
-msgid ""
-"You need to give me at least one $bad_syn and one $good_syn revision.\n"
-"(You can use \"git bisect $bad_syn\" and \"git bisect $good_syn\" for that.)"
-msgstr ""
-"您需要给我至少一个好版本和一个坏版本。\n"
-"（为此您可以用 \"git bisect $bad_syn\" 和 \"git bisect $good_syn\" 命令。）"
-
-#: git-bisect.sh:327
-#, sh-format
-msgid ""
-"You need to start by \"git bisect start\".\n"
-"You then need to give me at least one $good_syn and one $bad_syn revision.\n"
-"(You can use \"git bisect $bad_syn\" and \"git bisect $good_syn\" for that.)"
-msgstr ""
-"您需要执行 \"git bisect start\" 来开始。\n"
-"然后需要提供我至少一个好版本和一个坏版本。\n"
-"（为此您可以用 \"git bisect $bad_syn\" 和 \"git bisect $good_syn\" 命令。）"
-
-#: git-bisect.sh:398 git-bisect.sh:512
-msgid "We are not bisecting."
-msgstr "我们没有在二分查找。"
-
-#: git-bisect.sh:405
-#, sh-format
-msgid "'$invalid' is not a valid commit"
-msgstr "'$invalid' 不是一个有效的提交"
-
-#: git-bisect.sh:414
-#, sh-format
-msgid ""
-"Could not check out original HEAD '$branch'.\n"
-"Try 'git bisect reset <commit>'."
-msgstr ""
-"不能检出原始 HEAD '$branch'。\n"
-"尝试 'git bisect reset <提交>'。"
-
-#: git-bisect.sh:422
+#: git-bisect.sh:209
 msgid "No logfile given"
 msgstr "未提供日志文件"
 
-#: git-bisect.sh:423
+#: git-bisect.sh:210
 #, sh-format
 msgid "cannot read $file for replaying"
 msgstr "不能读取 $file 来重放"
 
-#: git-bisect.sh:444
+#: git-bisect.sh:232
 msgid "?? what are you talking about?"
 msgstr "?? 您在说什么?"
 
-#: git-bisect.sh:453
+#: git-bisect.sh:241
 msgid "bisect run failed: no command provided."
 msgstr "二分查找运行失败：没有提供命令。"
 
-#: git-bisect.sh:458
+#: git-bisect.sh:246
 #, sh-format
 msgid "running $command"
 msgstr "运行 $command"
 
-#: git-bisect.sh:465
+#: git-bisect.sh:253
 #, sh-format
 msgid ""
 "bisect run failed:\n"
@@ -16111,11 +22412,11 @@ msgstr ""
 "二分查找运行失败：\n"
 "命令 '$command' 的退出码 $res 小于 0 或大于等于 128"
 
-#: git-bisect.sh:491
+#: git-bisect.sh:279
 msgid "bisect run cannot continue any more"
 msgstr "二分查找不能继续运行"
 
-#: git-bisect.sh:497
+#: git-bisect.sh:285
 #, sh-format
 msgid ""
 "bisect run failed:\n"
@@ -16124,27 +22425,13 @@ msgstr ""
 "二分查找运行失败：\n"
 "'bisect_state $state' 退出码为 $res"
 
-#: git-bisect.sh:504
+#: git-bisect.sh:292
 msgid "bisect run success"
 msgstr "二分查找运行成功"
 
-#: git-bisect.sh:533
-#, sh-format
-msgid "Invalid command: you're currently in a $TERM_BAD/$TERM_GOOD bisect."
-msgstr "无效的命令：您当前正处于一个 $TERM_BAD/$TERM_GOOD 二分查找。"
-
-#: git-bisect.sh:567
-msgid "no terms defined"
-msgstr "未定义术语"
-
-#: git-bisect.sh:584
-#, sh-format
-msgid ""
-"invalid argument $arg for 'git bisect terms'.\n"
-"Supported options are: --term-good|--term-old and --term-bad|--term-new."
-msgstr ""
-"参数 $arg 对命令 'git bisect terms' 无效。\n"
-"支持的选项有：--term-good|--term-old 和 --term-bad|--term-new。"
+#: git-bisect.sh:300
+msgid "We are not bisecting."
+msgstr "我们没有在二分查找。"
 
 #: git-merge-octopus.sh:46
 msgid ""
@@ -16161,345 +22448,136 @@ msgid "Should not be doing an octopus."
 msgstr "不应该执行章鱼式合并。"
 
 #: git-merge-octopus.sh:73
-#, sh-format
-msgid "Unable to find common commit with $pretty_name"
-msgstr "无法找到和 $pretty_name 的基线提交"
-
-#: git-merge-octopus.sh:77
-#, sh-format
-msgid "Already up to date with $pretty_name"
-msgstr "已经和 $pretty_name 保持一致"
-
-#: git-merge-octopus.sh:89
-#, sh-format
-msgid "Fast-forwarding to: $pretty_name"
-msgstr "快进至：$pretty_name"
-
-#: git-merge-octopus.sh:97
-#, sh-format
-msgid "Trying simple merge with $pretty_name"
-msgstr "尝试和 $pretty_name 的简单合并"
-
-#: git-merge-octopus.sh:102
-msgid "Simple merge did not work, trying automatic merge."
-msgstr "简单合并未生效，尝试自动合并。"
-
-#: git-rebase.sh:61
-msgid ""
-"Resolve all conflicts manually, mark them as resolved with\n"
-"\"git add/rm <conflicted_files>\", then run \"git rebase --continue\".\n"
-"You can instead skip this commit: run \"git rebase --skip\".\n"
-"To abort and get back to the state before \"git rebase\", run \"git rebase --"
-"abort\"."
-msgstr ""
-"手工解决所有冲突，执行 \"git add/rm <冲突的文件>\" 标记\n"
-"冲突已解决，然后执行 \"git rebase --continue\"。您也可以执行\n"
-"\"git rebase --skip\" 命令跳过这个提交。如果想要终止执行并回到\n"
-"\"git rebase\" 执行之前的状态，执行 \"git rebase --abort\"。"
-
-#: git-rebase.sh:173 git-rebase.sh:442
-#, sh-format
-msgid "Could not move back to $head_name"
-msgstr "无法移回 $head_name"
-
-#: git-rebase.sh:184
-msgid "Applied autostash."
-msgstr "成功应用 autostash。"
-
-#: git-rebase.sh:187
-#, sh-format
-msgid "Cannot store $stash_sha1"
-msgstr "无法保存 $stash_sha1"
-
-#: git-rebase.sh:229
-msgid "The pre-rebase hook refused to rebase."
-msgstr "钩子 pre-rebase 拒绝变基操作。"
-
-#: git-rebase.sh:234
-msgid "It looks like 'git am' is in progress. Cannot rebase."
-msgstr "看起来 'git-am' 正在执行中。无法变基。"
-
-#: git-rebase.sh:403
-msgid "No rebase in progress?"
-msgstr "没有正在进行的变基？"
-
-#: git-rebase.sh:414
-msgid "The --edit-todo action can only be used during interactive rebase."
-msgstr "动作 --edit-todo 只能用在交互式变基过程中。"
-
-#: git-rebase.sh:421
-msgid "Cannot read HEAD"
-msgstr "不能读取 HEAD"
-
-#: git-rebase.sh:424
-msgid ""
-"You must edit all merge conflicts and then\n"
-"mark them as resolved using git add"
-msgstr ""
-"您必须编辑所有的合并冲突，然后通过 git add\n"
-"命令将它们标记为已解决"
-
-#: git-rebase.sh:468
-#, sh-format
-msgid ""
-"It seems that there is already a $state_dir_base directory, and\n"
-"I wonder if you are in the middle of another rebase.  If that is the\n"
-"case, please try\n"
-"\t$cmd_live_rebase\n"
-"If that is not the case, please\n"
-"\t$cmd_clear_stale_rebase\n"
-"and run me again.  I am stopping in case you still have something\n"
-"valuable there."
-msgstr ""
-"好像已有 $state_dir_base 目录，我怀疑您正处于另外一个变基操作\n"
-"过程中。 如果是这样，请执行\n"
-"\t$cmd_live_rebase\n"
-"如果不是这样，请执行\n"
-"\t$cmd_clear_stale_rebase\n"
-"然后再重新执行变基操作。 为避免丢失重要数据，我已经停止当前操作。"
-
-#: git-rebase.sh:509
-msgid "error: cannot combine '--signoff' with '--preserve-merges'"
-msgstr "错误：不能组合参数 '--signoff' 和 '--preserve-merges'"
-
-#: git-rebase.sh:537
-#, sh-format
-msgid "invalid upstream '$upstream_name'"
-msgstr "无效的上游 '$upstream_name'"
-
-#: git-rebase.sh:561
-#, sh-format
-msgid "$onto_name: there are more than one merge bases"
-msgstr "$onto_name: 有一个以上的合并基准"
-
-#: git-rebase.sh:564 git-rebase.sh:568
-#, sh-format
-msgid "$onto_name: there is no merge base"
-msgstr "$onto_name: 没有合并基准"
-
-#: git-rebase.sh:573
-#, sh-format
-msgid "Does not point to a valid commit: $onto_name"
-msgstr "没有指向一个有效的提交：$onto_name"
-
-#: git-rebase.sh:599
-#, sh-format
-msgid "fatal: no such branch/commit '$branch_name'"
-msgstr "严重错误：无此分支/提交 '$branch_name'"
-
-#: git-rebase.sh:632
-msgid "Cannot autostash"
-msgstr "无法 autostash"
-
-#: git-rebase.sh:637
-#, sh-format
-msgid "Created autostash: $stash_abbrev"
-msgstr "创建了 autostash: $stash_abbrev"
-
-#: git-rebase.sh:641
-msgid "Please commit or stash them."
-msgstr "请提交或贮藏修改。"
-
-#: git-rebase.sh:664
-#, sh-format
-msgid "HEAD is up to date."
-msgstr "HEAD 是最新的。"
-
-#: git-rebase.sh:666
-#, sh-format
-msgid "Current branch $branch_name is up to date."
-msgstr "当前分支 $branch_name 是最新的。"
-
-#: git-rebase.sh:674
-#, sh-format
-msgid "HEAD is up to date, rebase forced."
-msgstr "HEAD 是最新的，强制变基。"
-
-#: git-rebase.sh:676
-#, sh-format
-msgid "Current branch $branch_name is up to date, rebase forced."
-msgstr "当前分支 $branch_name 是最新的，强制变基。"
-
-#: git-rebase.sh:688
-#, sh-format
-msgid "Changes from $mb to $onto:"
-msgstr "变更从 $mb 到 $onto："
-
-#: git-rebase.sh:697
-msgid "First, rewinding head to replay your work on top of it..."
-msgstr "首先，回退分支以便在上面重放您的工作..."
-
-#: git-rebase.sh:707
-#, sh-format
-msgid "Fast-forwarded $branch_name to $onto_name."
-msgstr "快进 $branch_name 至 $onto_name。"
-
-#: git-stash.sh:61
-msgid "git stash clear with parameters is unimplemented"
-msgstr "git stash clear 不支持参数"
-
-#: git-stash.sh:108
-msgid "You do not have the initial commit yet"
-msgstr "您尚未建立初始提交"
+#, sh-format
+msgid "Unable to find common commit with $pretty_name"
+msgstr "无法找到和 $pretty_name 的基线提交"
 
-#: git-stash.sh:123
-msgid "Cannot save the current index state"
-msgstr "无法保存当前索引状态"
+#: git-merge-octopus.sh:77
+#, sh-format
+msgid "Already up to date with $pretty_name"
+msgstr "已经和 $pretty_name 保持一致"
 
-#: git-stash.sh:138
-msgid "Cannot save the untracked files"
-msgstr "无法保存未跟踪文件"
+#: git-merge-octopus.sh:89
+#, sh-format
+msgid "Fast-forwarding to: $pretty_name"
+msgstr "快进至：$pretty_name"
 
-#: git-stash.sh:158 git-stash.sh:171
-msgid "Cannot save the current worktree state"
-msgstr "无法保存当前工作区状态"
+#: git-merge-octopus.sh:97
+#, sh-format
+msgid "Trying simple merge with $pretty_name"
+msgstr "尝试和 $pretty_name 的简单合并"
 
-#: git-stash.sh:175
-msgid "No changes selected"
-msgstr "没有选择变更"
+#: git-merge-octopus.sh:102
+msgid "Simple merge did not work, trying automatic merge."
+msgstr "简单合并未生效，尝试自动合并。"
 
-#: git-stash.sh:178
+#: git-legacy-stash.sh:221
 msgid "Cannot remove temporary index (can't happen)"
 msgstr "无法删除临时索引（不应发生）"
 
-#: git-stash.sh:191
-msgid "Cannot record working tree state"
-msgstr "不能记录工作区状态"
-
-#: git-stash.sh:229
+#: git-legacy-stash.sh:272
 #, sh-format
 msgid "Cannot update $ref_stash with $w_commit"
 msgstr "无法用 $w_commit 更新 $ref_stash"
 
-#: git-stash.sh:281
+#: git-legacy-stash.sh:324
 #, sh-format
 msgid "error: unknown option for 'stash push': $option"
 msgstr "错误：'stash push' 的未知选项：$option"
 
-#: git-stash.sh:295
-msgid "Can't use --patch and --include-untracked or --all at the same time"
-msgstr "不能同时使用参数 --patch 和 --include-untracked 或 --all"
-
-#: git-stash.sh:303
-msgid "No local changes to save"
-msgstr "没有要保存的本地修改"
-
-#: git-stash.sh:308
-msgid "Cannot initialize stash"
-msgstr "无法初始化贮藏"
-
-#: git-stash.sh:312
-msgid "Cannot save the current status"
-msgstr "无法保存当前状态"
-
-#: git-stash.sh:313
+#: git-legacy-stash.sh:356
 #, sh-format
 msgid "Saved working directory and index state $stash_msg"
 msgstr "保存工作目录和索引状态 $stash_msg"
 
-#: git-stash.sh:342
-msgid "Cannot remove worktree changes"
-msgstr "无法删除工作区变更"
-
-#: git-stash.sh:490
+#: git-legacy-stash.sh:536
 #, sh-format
 msgid "unknown option: $opt"
 msgstr "未知选项: $opt"
 
-#: git-stash.sh:503
-msgid "No stash entries found."
-msgstr "未发现贮藏条目。"
-
-#: git-stash.sh:510
+#: git-legacy-stash.sh:556
 #, sh-format
 msgid "Too many revisions specified: $REV"
 msgstr "指定了太多的版本：$REV"
 
-#: git-stash.sh:525
+#: git-legacy-stash.sh:571
 #, sh-format
 msgid "$reference is not a valid reference"
 msgstr "$reference 不是一个有效的引用"
 
-#: git-stash.sh:553
+#: git-legacy-stash.sh:599
 #, sh-format
 msgid "'$args' is not a stash-like commit"
 msgstr "'$args' 不是贮藏式提交"
 
-#: git-stash.sh:564
+#: git-legacy-stash.sh:610
 #, sh-format
 msgid "'$args' is not a stash reference"
 msgstr "'$args' 不是一个贮藏引用"
 
-#: git-stash.sh:572
+#: git-legacy-stash.sh:618
 msgid "unable to refresh index"
 msgstr "无法刷新索引"
 
-#: git-stash.sh:576
+#: git-legacy-stash.sh:622
 msgid "Cannot apply a stash in the middle of a merge"
 msgstr "无法在合并过程应用贮藏"
 
-#: git-stash.sh:584
+#: git-legacy-stash.sh:630
 msgid "Conflicts in index. Try without --index."
 msgstr "索引中有冲突。尝试不使用 --index。"
 
-#: git-stash.sh:586
+#: git-legacy-stash.sh:632
 msgid "Could not save index tree"
 msgstr "不能保存索引树"
 
-#: git-stash.sh:595
+#: git-legacy-stash.sh:641
 msgid "Could not restore untracked files from stash entry"
 msgstr "无法从贮藏条目中恢复未跟踪文件"
 
-#: git-stash.sh:620
+#: git-legacy-stash.sh:666
 msgid "Cannot unstage modified files"
 msgstr "无法将修改的文件取消暂存"
 
-#: git-stash.sh:635
-msgid "Index was not unstashed."
-msgstr "索引未从贮藏中恢复。"
-
-#: git-stash.sh:649
-msgid "The stash entry is kept in case you need it again."
-msgstr "贮藏条目被保留以备您再次需要。"
-
-#: git-stash.sh:658
+#: git-legacy-stash.sh:704
 #, sh-format
 msgid "Dropped ${REV} ($s)"
 msgstr "丢弃了 ${REV} ($s)"
 
-#: git-stash.sh:659
+#: git-legacy-stash.sh:705
 #, sh-format
 msgid "${REV}: Could not drop stash entry"
 msgstr "${REV}：无法丢弃贮藏条目"
 
-#: git-stash.sh:667
-msgid "No branch name specified"
-msgstr "未指定分支名"
-
-#: git-stash.sh:746
+#: git-legacy-stash.sh:792
 msgid "(To restore them type \"git stash apply\")"
 msgstr "（为恢复数据输入 \"git stash apply\"）"
 
-#: git-submodule.sh:188
+#: git-submodule.sh:202
 msgid "Relative path can only be used from the toplevel of the working tree"
 msgstr "只能在工作区的顶级目录中使用相对路径"
 
-#: git-submodule.sh:198
+#: git-submodule.sh:212
 #, sh-format
 msgid "repo URL: '$repo' must be absolute or begin with ./|../"
 msgstr "仓库 URL：'$repo' 必须是绝对路径或以 ./|../ 起始"
 
-#: git-submodule.sh:217
+#: git-submodule.sh:231
 #, sh-format
 msgid "'$sm_path' already exists in the index"
 msgstr "'$sm_path' 已经存在于索引中"
 
-#: git-submodule.sh:220
+#: git-submodule.sh:234
 #, sh-format
 msgid "'$sm_path' already exists in the index and is not a submodule"
 msgstr "'$sm_path' 已经存在于索引中且不是一个子模组"
 
-#: git-submodule.sh:226
+#: git-submodule.sh:241
+#, sh-format
+msgid "'$sm_path' does not have a commit checked out"
+msgstr "'$sm_path' 没有检出的提交"
+
+#: git-submodule.sh:247
 #, sh-format
 msgid ""
 "The following path is ignored by one of your .gitignore files:\n"
@@ -16510,22 +22588,22 @@ msgstr ""
 "$sm_path\n"
 "如果您确实想添加它，使用 -f 参数。"
 
-#: git-submodule.sh:249
+#: git-submodule.sh:270
 #, sh-format
 msgid "Adding existing repo at '$sm_path' to the index"
 msgstr "添加位于 '$sm_path' 的现存仓库到索引"
 
-#: git-submodule.sh:251
+#: git-submodule.sh:272
 #, sh-format
 msgid "'$sm_path' already exists and is not a valid git repo"
 msgstr "'$sm_path' 已存在且不是一个有效的 git 仓库"
 
-#: git-submodule.sh:259
+#: git-submodule.sh:280
 #, sh-format
 msgid "A git directory for '$sm_name' is found locally with remote(s):"
 msgstr "本地发现 '$sm_name' 的一个 git 目录，与其对应的远程仓库："
 
-#: git-submodule.sh:261
+#: git-submodule.sh:282
 #, sh-format
 msgid ""
 "If you want to reuse this local git directory instead of cloning again from\n"
@@ -16540,59 +22618,51 @@ msgstr ""
 "使用 '--force' 选项。如果本地 git 目录不是正确的仓库\n"
 "或者您不确定这里的含义，使用 '--name' 选项选择另外的名称。"
 
-#: git-submodule.sh:267
+#: git-submodule.sh:288
 #, sh-format
 msgid "Reactivating local git directory for submodule '$sm_name'."
 msgstr "激活本地 git 目录到子模组 '$sm_name'。"
 
-#: git-submodule.sh:279
+#: git-submodule.sh:300
 #, sh-format
 msgid "Unable to checkout submodule '$sm_path'"
 msgstr "不能检出子模组 '$sm_path'"
 
-#: git-submodule.sh:284
+#: git-submodule.sh:305
 #, sh-format
 msgid "Failed to add submodule '$sm_path'"
 msgstr "无法添加子模组 '$sm_path'"
 
-#: git-submodule.sh:293
+#: git-submodule.sh:314
 #, sh-format
 msgid "Failed to register submodule '$sm_path'"
 msgstr "无法注册子模组 '$sm_path'"
 
-#: git-submodule.sh:354
-#, sh-format
-msgid "Entering '$displaypath'"
-msgstr "正在进入 '$displaypath'"
-
-#: git-submodule.sh:374
-#, sh-format
-msgid "Stopping at '$displaypath'; script returned non-zero status."
-msgstr "停止于 '$displaypath'；脚本返回非零值。"
-
-#: git-submodule.sh:600
+#: git-submodule.sh:580
 #, sh-format
 msgid "Unable to find current revision in submodule path '$displaypath'"
 msgstr "无法在子模组路径 '$displaypath' 中找到当前版本"
 
-#: git-submodule.sh:610
+#: git-submodule.sh:590
 #, sh-format
 msgid "Unable to fetch in submodule path '$sm_path'"
 msgstr "无法在子模组路径 '$sm_path' 中获取"
 
-#: git-submodule.sh:615
+#: git-submodule.sh:595
 #, sh-format
 msgid ""
 "Unable to find current ${remote_name}/${branch} revision in submodule path "
 "'$sm_path'"
 msgstr "无法在子模组路径 '$sm_path' 中找到当前版本 ${remote_name}/${branch}"
 
-#: git-submodule.sh:633
+#: git-submodule.sh:613
 #, sh-format
-msgid "Unable to fetch in submodule path '$displaypath'"
-msgstr "无法在子模组路径 '$displaypath' 中获取"
+msgid ""
+"Unable to fetch in submodule path '$displaypath'; trying to directly fetch "
+"$sha1:"
+msgstr "无法在子模组路径 '$displaypath' 中获取，尝试直接获取 $sha1："
 
-#: git-submodule.sh:639
+#: git-submodule.sh:619
 #, sh-format
 msgid ""
 "Fetched in submodule path '$displaypath', but it did not contain $sha1. "
@@ -16600,74 +22670,74 @@ msgid ""
 msgstr ""
 "获取了子模组路径 '$displaypath'，但是它没有包含 $sha1。直接获取该提交失败。"
 
-#: git-submodule.sh:646
+#: git-submodule.sh:626
 #, sh-format
 msgid "Unable to checkout '$sha1' in submodule path '$displaypath'"
 msgstr "无法在子模组路径 '$displaypath' 中检出 '$sha1'"
 
-#: git-submodule.sh:647
+#: git-submodule.sh:627
 #, sh-format
 msgid "Submodule path '$displaypath': checked out '$sha1'"
 msgstr "子模组路径 '$displaypath'：检出 '$sha1'"
 
-#: git-submodule.sh:651
+#: git-submodule.sh:631
 #, sh-format
 msgid "Unable to rebase '$sha1' in submodule path '$displaypath'"
 msgstr "无法在子模组路径 '$displaypath' 中变基 '$sha1'"
 
-#: git-submodule.sh:652
+#: git-submodule.sh:632
 #, sh-format
 msgid "Submodule path '$displaypath': rebased into '$sha1'"
 msgstr "子模组路径 '$displaypath'：变基至 '$sha1'"
 
-#: git-submodule.sh:657
+#: git-submodule.sh:637
 #, sh-format
 msgid "Unable to merge '$sha1' in submodule path '$displaypath'"
 msgstr "无法合并 '$sha1' 到子模组路径 '$displaypath' 中"
 
-#: git-submodule.sh:658
+#: git-submodule.sh:638
 #, sh-format
 msgid "Submodule path '$displaypath': merged in '$sha1'"
 msgstr "子模组路径 '$displaypath'：已合并入 '$sha1'"
 
-#: git-submodule.sh:663
+#: git-submodule.sh:643
 #, sh-format
 msgid "Execution of '$command $sha1' failed in submodule path '$displaypath'"
 msgstr "在子模组 '$displaypath' 中执行 '$command $sha1' 失败"
 
-#: git-submodule.sh:664
+#: git-submodule.sh:644
 #, sh-format
 msgid "Submodule path '$displaypath': '$command $sha1'"
 msgstr "子模组 '$displaypath'：'$command $sha1'"
 
-#: git-submodule.sh:695
+#: git-submodule.sh:675
 #, sh-format
 msgid "Failed to recurse into submodule path '$displaypath'"
 msgstr "无法递归进子模组路径 '$displaypath'"
 
-#: git-submodule.sh:791
+#: git-submodule.sh:886
 msgid "The --cached option cannot be used with the --files option"
 msgstr "选项 --cached 不能和选项 --files 同时使用"
 
-#: git-submodule.sh:843
+#: git-submodule.sh:938
 #, sh-format
 msgid "unexpected mode $mod_dst"
 msgstr "意外的模式 $mod_dst"
 
 #  译者：注意保持前导空格
-#: git-submodule.sh:863
+#: git-submodule.sh:958
 #, sh-format
 msgid "  Warn: $display_name doesn't contain commit $sha1_src"
 msgstr "  警告：$display_name 未包含提交 $sha1_src"
 
 #  译者：注意保持前导空格
-#: git-submodule.sh:866
+#: git-submodule.sh:961
 #, sh-format
 msgid "  Warn: $display_name doesn't contain commit $sha1_dst"
 msgstr "  警告：$display_name 未包含提交 $sha1_dst"
 
 #  译者：注意保持前导空格
-#: git-submodule.sh:869
+#: git-submodule.sh:964
 #, sh-format
 msgid "  Warn: $display_name doesn't contain commits $sha1_src and $sha1_dst"
 msgstr "  警告：$display_name 未包含提交 $sha1_src 和 $sha1_dst"
@@ -16677,12 +22747,21 @@ msgstr "  警告：$display_name 未包
 msgid "See git-${cmd}(1) for details."
 msgstr "详见 git-${cmd}(1)。"
 
-#: git-rebase--interactive.sh:142
+#: git-rebase--preserve-merges.sh:109
+msgid "Applied autostash."
+msgstr "已应用 autostash。"
+
+#: git-rebase--preserve-merges.sh:112
+#, sh-format
+msgid "Cannot store $stash_sha1"
+msgstr "不能存储 $stash_sha1"
+
+#: git-rebase--preserve-merges.sh:191
 #, sh-format
 msgid "Rebasing ($new_count/$total)"
 msgstr "变基中（$new_count/$total）"
 
-#: git-rebase--interactive.sh:158
+#: git-rebase--preserve-merges.sh:207
 msgid ""
 "\n"
 "Commands:\n"
@@ -16691,7 +22770,7 @@ msgid ""
 "e, edit <commit> = use commit, but stop for amending\n"
 "s, squash <commit> = use commit, but meld into previous commit\n"
 "f, fixup <commit> = like \"squash\", but discard this commit's log message\n"
-"x, exec <command> = run command (the rest of the line) using shell\n"
+"x, exec <commit> = run command (the rest of the line) using shell\n"
 "d, drop <commit> = remove commit\n"
 "l, label <label> = label current HEAD with a name\n"
 "t, reset <label> = reset HEAD to a label\n"
@@ -16706,37 +22785,21 @@ msgstr ""
 "命令:\n"
 "p, pick <提交> = 使用提交\n"
 "r, reword <提交> = 使用提交，但修改提交说明\n"
-"e, edit <提交> = 使用提交，进入 shell 以便进行提交修补\n"
+"e, edit <提交> = 使用提交，但停下来修补\n"
 "s, squash <提交> = 使用提交，但融合到前一个提交\n"
 "f, fixup <提交> = 类似于 \"squash\"，但丢弃提交说明日志\n"
 "x, exec <命令> = 使用 shell 运行命令（此行剩余部分）\n"
 "d, drop <提交> = 删除提交\n"
-"l, label <label> = 为当前 HEAD 打上标记\n"
-"t, reset <label> = 重置 HEAD 到该标记\n"
-"m, merge [-C <commit> | -c <commit>] <label> [# <oneline>]\n"
+"l, label <标签> = 为当前 HEAD 打上标签\n"
+"t, reset <标签> = 重置 HEAD 到该标签\n"
+"m, merge [-C <提交> | -c <提交>] <标签> [# <oneline>]\n"
 ".       创建一个合并提交，并使用原始的合并提交说明（如果没有指定\n"
 ".       原始提交，使用注释部分的 oneline 作为提交说明）。使用\n"
 ".       -c <提交> 可以编辑提交说明。\n"
 "\n"
 "可以对这些行重新排序，将从上至下执行。\n"
 
-#: git-rebase--interactive.sh:179
-msgid ""
-"\n"
-"Do not remove any line. Use 'drop' explicitly to remove a commit.\n"
-msgstr ""
-"\n"
-"不要删除任意一行。使用 'drop' 显式地删除一个提交。\n"
-
-#: git-rebase--interactive.sh:183
-msgid ""
-"\n"
-"If you remove a line here THAT COMMIT WILL BE LOST.\n"
-msgstr ""
-"\n"
-"如果您在这里删除一行，对应的提交将会丢失。\n"
-
-#: git-rebase--interactive.sh:221
+#: git-rebase--preserve-merges.sh:270
 #, sh-format
 msgid ""
 "You can amend the commit now, with\n"
@@ -16755,83 +22818,83 @@ msgstr ""
 "\n"
 "\tgit rebase --continue"
 
-#: git-rebase--interactive.sh:246
+#: git-rebase--preserve-merges.sh:295
 #, sh-format
 msgid "$sha1: not a commit that can be picked"
 msgstr "$sha1：不是一个可以被拣选的提交"
 
-#: git-rebase--interactive.sh:285
+#: git-rebase--preserve-merges.sh:334
 #, sh-format
 msgid "Invalid commit name: $sha1"
 msgstr "无效的提交名：$sha1"
 
-#: git-rebase--interactive.sh:325
+#: git-rebase--preserve-merges.sh:364
 msgid "Cannot write current commit's replacement sha1"
 msgstr "不能写入当前提交的替代 sha1"
 
-#: git-rebase--interactive.sh:376
+#: git-rebase--preserve-merges.sh:415
 #, sh-format
 msgid "Fast-forward to $sha1"
 msgstr "快进到 $sha1"
 
-#: git-rebase--interactive.sh:378
+#: git-rebase--preserve-merges.sh:417
 #, sh-format
 msgid "Cannot fast-forward to $sha1"
 msgstr "不能快进到 $sha1"
 
-#: git-rebase--interactive.sh:387
+#: git-rebase--preserve-merges.sh:426
 #, sh-format
 msgid "Cannot move HEAD to $first_parent"
 msgstr "不能移动 HEAD 到 $first_parent"
 
-#: git-rebase--interactive.sh:392
+#: git-rebase--preserve-merges.sh:431
 #, sh-format
 msgid "Refusing to squash a merge: $sha1"
 msgstr "拒绝压缩一个合并：$sha1"
 
-#: git-rebase--interactive.sh:410
+#: git-rebase--preserve-merges.sh:449
 #, sh-format
 msgid "Error redoing merge $sha1"
 msgstr "无法重做合并 $sha1"
 
-#: git-rebase--interactive.sh:419
+#: git-rebase--preserve-merges.sh:458
 #, sh-format
 msgid "Could not pick $sha1"
 msgstr "不能拣选 $sha1"
 
-#: git-rebase--interactive.sh:428
+#: git-rebase--preserve-merges.sh:467
 #, sh-format
 msgid "This is the commit message #${n}:"
 msgstr "这是提交说明 #${n}："
 
-#: git-rebase--interactive.sh:433
+#: git-rebase--preserve-merges.sh:472
 #, sh-format
 msgid "The commit message #${n} will be skipped:"
 msgstr "提交说明 #${n} 将被跳过："
 
-#: git-rebase--interactive.sh:444
+#: git-rebase--preserve-merges.sh:483
 #, sh-format
 msgid "This is a combination of $count commit."
 msgid_plural "This is a combination of $count commits."
 msgstr[0] "这是一个 $count 个提交的组合。"
 msgstr[1] "这是一个 $count 个提交的组合。"
 
-#: git-rebase--interactive.sh:453
+#: git-rebase--preserve-merges.sh:492
 #, sh-format
 msgid "Cannot write $fixup_msg"
 msgstr "不能写入 $fixup_msg"
 
-#: git-rebase--interactive.sh:456
+#: git-rebase--preserve-merges.sh:495
 msgid "This is a combination of 2 commits."
 msgstr "这是一个 2 个提交的组合。"
 
-#: git-rebase--interactive.sh:497 git-rebase--interactive.sh:540
-#: git-rebase--interactive.sh:543
+#: git-rebase--preserve-merges.sh:536 git-rebase--preserve-merges.sh:579
+#: git-rebase--preserve-merges.sh:582
 #, sh-format
 msgid "Could not apply $sha1... $rest"
 msgstr "不能应用 $sha1... $rest"
 
-#: git-rebase--interactive.sh:572
+#: git-rebase--preserve-merges.sh:611
 #, sh-format
 msgid ""
 "Could not amend commit after successfully picking $sha1... $rest\n"
@@ -16844,32 +22907,32 @@ msgstr ""
 "这通常是因为空的提交说明，或者 pre-commit 钩子执行失败。如果是 pre-commit\n"
 "钩子执行失败，你可能需要在重写提交说明前解决这个问题。"
 
-#: git-rebase--interactive.sh:587
+#: git-rebase--preserve-merges.sh:626
 #, sh-format
 msgid "Stopped at $sha1_abbrev... $rest"
 msgstr "停止在 $sha1_abbrev... $rest"
 
-#: git-rebase--interactive.sh:602
+#: git-rebase--preserve-merges.sh:641
 #, sh-format
 msgid "Cannot '$squash_style' without a previous commit"
 msgstr "没有父提交的情况下不能 '$squash_style'"
 
-#: git-rebase--interactive.sh:644
+#: git-rebase--preserve-merges.sh:683
 #, sh-format
 msgid "Executing: $rest"
 msgstr "执行：$rest"
 
-#: git-rebase--interactive.sh:652
+#: git-rebase--preserve-merges.sh:691
 #, sh-format
 msgid "Execution failed: $rest"
 msgstr "执行失败：$rest"
 
-#: git-rebase--interactive.sh:654
+#: git-rebase--preserve-merges.sh:693
 msgid "and made changes to the index and/or the working tree"
 msgstr "并且修改索引和/或工作区"
 
 #  译者：注意保持前导空格
-#: git-rebase--interactive.sh:656
+#: git-rebase--preserve-merges.sh:695
 msgid ""
 "You can fix the problem, and then run\n"
 "\n"
@@ -16880,7 +22943,7 @@ msgstr ""
 "\tgit rebase --continue"
 
 #. TRANSLATORS: after these lines is a command to be issued by the user
-#: git-rebase--interactive.sh:669
+#: git-rebase--preserve-merges.sh:708
 #, sh-format
 msgid ""
 "Execution succeeded: $rest\n"
@@ -16894,29 +22957,25 @@ msgstr ""
 "\n"
 "\tgit rebase --continue"
 
-#: git-rebase--interactive.sh:680
+#: git-rebase--preserve-merges.sh:719
 #, sh-format
 msgid "Unknown command: $command $sha1 $rest"
 msgstr "未知命令：$command $sha1 $rest"
 
-#: git-rebase--interactive.sh:681
+#: git-rebase--preserve-merges.sh:720
 msgid "Please fix this using 'git rebase --edit-todo'."
 msgstr "要修改请使用命令 'git rebase --edit-todo'。"
 
-#: git-rebase--interactive.sh:716
+#: git-rebase--preserve-merges.sh:755
 #, sh-format
 msgid "Successfully rebased and updated $head_name."
 msgstr "成功变基并更新 $head_name。"
 
-#: git-rebase--interactive.sh:740
-msgid "could not detach HEAD"
-msgstr "不能检出为分离头指针"
-
-#: git-rebase--interactive.sh:778
+#: git-rebase--preserve-merges.sh:812
 msgid "Could not remove CHERRY_PICK_HEAD"
 msgstr "不能删除 CHERRY_PICK_HEAD"
 
-#: git-rebase--interactive.sh:783
+#: git-rebase--preserve-merges.sh:817
 #, sh-format
 msgid ""
 "You have staged changes in your working tree.\n"
@@ -16945,85 +23004,51 @@ msgstr ""
 "\n"
 "  git rebase --continue\n"
 
-#: git-rebase--interactive.sh:800
+#: git-rebase--preserve-merges.sh:834
 msgid "Error trying to find the author identity to amend commit"
 msgstr "在修补提交中查找作者信息时遇到错误"
 
-#: git-rebase--interactive.sh:805
+#: git-rebase--preserve-merges.sh:839
 msgid ""
 "You have uncommitted changes in your working tree. Please commit them\n"
 "first and then run 'git rebase --continue' again."
 msgstr ""
 "您的工作区中有未提交的变更。请先提交然后再次运行 'git rebase --continue'。"
 
-#: git-rebase--interactive.sh:810 git-rebase--interactive.sh:814
+#: git-rebase--preserve-merges.sh:844 git-rebase--preserve-merges.sh:848
 msgid "Could not commit staged changes."
 msgstr "不能提交暂存的修改。"
 
-#: git-rebase--interactive.sh:843
-msgid ""
-"\n"
-"You are editing the todo file of an ongoing interactive rebase.\n"
-"To continue rebase after editing, run:\n"
-"    git rebase --continue\n"
-"\n"
-msgstr ""
-"\n"
-"您正在修改运行中的交互式变基待办列表。若要在编辑结束后继续变基，\n"
-"请执行：\n"
-"    git rebase --continue\n"
-"\n"
-
-#: git-rebase--interactive.sh:851 git-rebase--interactive.sh:937
+#: git-rebase--preserve-merges.sh:879 git-rebase--preserve-merges.sh:965
 msgid "Could not execute editor"
 msgstr "无法运行编辑器"
 
-#: git-rebase--interactive.sh:872
+#: git-rebase--preserve-merges.sh:900
 #, sh-format
 msgid "Could not checkout $switch_to"
 msgstr "不能检出 $switch_to"
 
-#: git-rebase--interactive.sh:879
+#: git-rebase--preserve-merges.sh:907
 msgid "No HEAD?"
 msgstr "没有 HEAD？"
 
-#: git-rebase--interactive.sh:880
+#: git-rebase--preserve-merges.sh:908
 #, sh-format
 msgid "Could not create temporary $state_dir"
 msgstr "不能创建临时 $state_dir"
 
-#: git-rebase--interactive.sh:883
+#: git-rebase--preserve-merges.sh:911
 msgid "Could not mark as interactive"
 msgstr "不能标记为交互式"
 
-#: git-rebase--interactive.sh:915
+#: git-rebase--preserve-merges.sh:943
 #, sh-format
 msgid "Rebase $shortrevisions onto $shortonto ($todocount command)"
 msgid_plural "Rebase $shortrevisions onto $shortonto ($todocount commands)"
 msgstr[0] "变基 $shortrevisions 到 $shortonto（$todocount 个提交）"
 msgstr[1] "变基 $shortrevisions 到 $shortonto（$todocount 个提交）"
 
-#: git-rebase--interactive.sh:920
-msgid ""
-"\n"
-"\tHowever, if you remove everything, the rebase will be aborted.\n"
-"\n"
-"\t"
-msgstr ""
-"\n"
-"\t然而，如果您删除全部内容，变基操作将会终止。\n"
-"\n"
-"\t"
-
-#: git-rebase--interactive.sh:927
-msgid "Note that empty commits are commented out"
-msgstr "注意空提交已被注释掉"
-
-#: git-rebase--interactive.sh:980
-msgid "Could not generate todo list"
-msgstr "无法生成待办列表"
-
-#: git-rebase--interactive.sh:1001 git-rebase--interactive.sh:1006
+#: git-rebase--preserve-merges.sh:997 git-rebase--preserve-merges.sh:1002
 msgid "Could not init rewritten commits"
 msgstr "不能对重写提交进行初始化"
 
@@ -17032,173 +23057,109 @@ msgstr "不能对重写提交进行初
 msgid "usage: $dashless $USAGE"
 msgstr "用法：$dashless $USAGE"
 
-#: git-sh-setup.sh:190
+#: git-sh-setup.sh:191
 #, sh-format
 msgid "Cannot chdir to $cdup, the toplevel of the working tree"
 msgstr "不能切换目录到 $cdup，工作区的顶级目录"
 
-#: git-sh-setup.sh:199 git-sh-setup.sh:206
+#: git-sh-setup.sh:200 git-sh-setup.sh:207
 #, sh-format
 msgid "fatal: $program_name cannot be used without a working tree."
-msgstr "严重错误：$program_name 不能在没有工作区的情况下使用"
+msgstr "致命错误：$program_name 不能在没有工作区的情况下使用"
 
-#: git-sh-setup.sh:220
+#: git-sh-setup.sh:221
 msgid "Cannot rebase: You have unstaged changes."
 msgstr "不能变基：您有未暂存的变更。"
 
-#: git-sh-setup.sh:223
+#: git-sh-setup.sh:224
 msgid "Cannot rewrite branches: You have unstaged changes."
 msgstr "不能重写分支：您有未暂存的变更。"
 
-#: git-sh-setup.sh:226
+#: git-sh-setup.sh:227
 msgid "Cannot pull with rebase: You have unstaged changes."
 msgstr "无法通过变基方式拉取：您有未暂存的变更。"
 
-#: git-sh-setup.sh:229
+#: git-sh-setup.sh:230
 #, sh-format
 msgid "Cannot $action: You have unstaged changes."
 msgstr "不能 $action：您有未暂存的变更。"
 
-#: git-sh-setup.sh:242
+#: git-sh-setup.sh:243
 msgid "Cannot rebase: Your index contains uncommitted changes."
 msgstr "不能变基：您的索引中包含未提交的变更。"
 
-#: git-sh-setup.sh:245
+#: git-sh-setup.sh:246
 msgid "Cannot pull with rebase: Your index contains uncommitted changes."
 msgstr "无法通过变基方式拉取：您的索引中包含未提交的变更。"
 
-#: git-sh-setup.sh:248
+#: git-sh-setup.sh:249
 #, sh-format
 msgid "Cannot $action: Your index contains uncommitted changes."
 msgstr "不能 $action：您的索引中包含未提交的变更。"
 
-#: git-sh-setup.sh:252
+#: git-sh-setup.sh:253
 msgid "Additionally, your index contains uncommitted changes."
 msgstr "而且您的索引中包含未提交的变更。"
 
-#: git-sh-setup.sh:372
+#: git-sh-setup.sh:373
 msgid "You need to run this command from the toplevel of the working tree."
 msgstr "您需要在工作区的顶级目录中运行这个命令。"
 
-#: git-sh-setup.sh:377
+#: git-sh-setup.sh:378
 msgid "Unable to determine absolute path of git directory"
 msgstr "不能确定 git 目录的绝对路径"
 
 #. TRANSLATORS: you can adjust this to align "git add -i" status menu
-#: git-add--interactive.perl:196
+#: git-add--interactive.perl:212
 #, perl-format
 msgid "%12s %12s %s"
 msgstr "%12s %12s %s"
 
-#: git-add--interactive.perl:197
-msgid "staged"
-msgstr "缓存"
-
-#: git-add--interactive.perl:197
-msgid "unstaged"
-msgstr "未缓存"
-
-#: git-add--interactive.perl:253 git-add--interactive.perl:278
-msgid "binary"
-msgstr "二进制"
-
-#: git-add--interactive.perl:262 git-add--interactive.perl:316
-msgid "nothing"
-msgstr "无"
-
-#: git-add--interactive.perl:298 git-add--interactive.perl:313
-msgid "unchanged"
-msgstr "没有修改"
-
-#: git-add--interactive.perl:609
-#, perl-format
-msgid "added %d path\n"
-msgid_plural "added %d paths\n"
-msgstr[0] "增加了 %d 个路径\n"
-msgstr[1] "增加了 %d 个路径\n"
-
-#: git-add--interactive.perl:612
-#, perl-format
-msgid "updated %d path\n"
-msgid_plural "updated %d paths\n"
-msgstr[0] "更新了 %d 个路径\n"
-msgstr[1] "更新了 %d 个路径\n"
-
-#: git-add--interactive.perl:615
-#, perl-format
-msgid "reverted %d path\n"
-msgid_plural "reverted %d paths\n"
-msgstr[0] "还原了 %d 个路径\n"
-msgstr[1] "还原了 %d 个路径\n"
-
-#: git-add--interactive.perl:618
+#: git-add--interactive.perl:634
 #, perl-format
 msgid "touched %d path\n"
 msgid_plural "touched %d paths\n"
 msgstr[0] "触碰了 %d 个路径\n"
 msgstr[1] "触碰了 %d 个路径\n"
 
-#: git-add--interactive.perl:627
-msgid "Update"
-msgstr "更新"
-
-#: git-add--interactive.perl:639
-msgid "Revert"
-msgstr "还原"
-
-#: git-add--interactive.perl:662
-#, perl-format
-msgid "note: %s is untracked now.\n"
-msgstr "说明：%s 现已成为未跟踪的。\n"
-
-#: git-add--interactive.perl:673
-msgid "Add untracked"
-msgstr "添加未跟踪的"
-
-#: git-add--interactive.perl:679
-msgid "No untracked files.\n"
-msgstr "没有未跟踪的文件。\n"
-
-#: git-add--interactive.perl:1033
+#: git-add--interactive.perl:1053
 msgid ""
 "If the patch applies cleanly, the edited hunk will immediately be\n"
 "marked for staging."
 msgstr "如果补丁能干净地应用，编辑块将立即标记为暂存。"
 
-#: git-add--interactive.perl:1036
+#: git-add--interactive.perl:1056
 msgid ""
 "If the patch applies cleanly, the edited hunk will immediately be\n"
 "marked for stashing."
 msgstr "如果补丁能干净地应用，编辑块将立即标记为贮藏。"
 
-#: git-add--interactive.perl:1039
+#: git-add--interactive.perl:1059
 msgid ""
 "If the patch applies cleanly, the edited hunk will immediately be\n"
 "marked for unstaging."
 msgstr "如果补丁能干净地应用，编辑块将立即标记为未暂存。"
 
-#: git-add--interactive.perl:1042 git-add--interactive.perl:1051
+#: git-add--interactive.perl:1062 git-add--interactive.perl:1071
+#: git-add--interactive.perl:1077
 msgid ""
 "If the patch applies cleanly, the edited hunk will immediately be\n"
 "marked for applying."
 msgstr "如果补丁能干净地应用，编辑块将立即标记为应用。"
 
-#: git-add--interactive.perl:1045 git-add--interactive.perl:1048
+#: git-add--interactive.perl:1065 git-add--interactive.perl:1068
+#: git-add--interactive.perl:1074
 msgid ""
 "If the patch applies cleanly, the edited hunk will immediately be\n"
 "marked for discarding."
 msgstr "如果补丁能干净地应用，编辑块将立即标记为丢弃。"
 
-#: git-add--interactive.perl:1085
+#: git-add--interactive.perl:1111
 #, perl-format
 msgid "failed to open hunk edit file for writing: %s"
-msgstr "无法写入块编辑文件：%s"
-
-#: git-add--interactive.perl:1086
-msgid "Manual hunk edit mode -- see bottom for a quick guide.\n"
-msgstr "手动块编辑模式 -- 查看底部的快速指南。\n"
+msgstr "为写入打开块编辑文件失败：%s"
 
-#: git-add--interactive.perl:1092
+#: git-add--interactive.perl:1118
 #, perl-format
 msgid ""
 "---\n"
@@ -17211,33 +23172,12 @@ msgstr ""
 "要删除 '%s' 开始的行，删除它们。\n"
 "以 %s 开始的行将被删除。\n"
 
-#. TRANSLATORS: 'it' refers to the patch mentioned in the previous messages.
-#: git-add--interactive.perl:1100
-msgid ""
-"If it does not apply cleanly, you will be given an opportunity to\n"
-"edit again.  If all lines of the hunk are removed, then the edit is\n"
-"aborted and the hunk is left unchanged.\n"
-msgstr ""
-"如果不能干净地应用，您将有机会重新编辑。如果该块的全部内容删除，则\n"
-"此次编辑被终止，该块不会被修改。\n"
-
-#: git-add--interactive.perl:1114
+#: git-add--interactive.perl:1140
 #, perl-format
 msgid "failed to open hunk edit file for reading: %s"
 msgstr "无法读取块编辑文件：%s"
 
-#. TRANSLATORS: do not translate [y/n]
-#. The program will only accept that input
-#. at this point.
-#. Consider translating (saying "no" discards!) as
-#. (saying "n" for "no" discards!) if the translation
-#. of the word "no" does not start with n.
-#: git-add--interactive.perl:1213
-msgid ""
-"Your edited hunk does not apply. Edit again (saying \"no\" discards!) [y/n]? "
-msgstr "您的编辑块不能被应用。重新编辑（选择 \"no\" 丢弃！） [y/n]? "
-
-#: git-add--interactive.perl:1222
+#: git-add--interactive.perl:1248
 msgid ""
 "y - stage this hunk\n"
 "n - do not stage this hunk\n"
@@ -17251,7 +23191,7 @@ msgstr ""
 "a - 暂存该块和本文件中后面的全部块\n"
 "d - 不暂存该块和本文件中后面的全部块"
 
-#: git-add--interactive.perl:1228
+#: git-add--interactive.perl:1254
 msgid ""
 "y - stash this hunk\n"
 "n - do not stash this hunk\n"
@@ -17265,7 +23205,7 @@ msgstr ""
 "a - 贮藏该块和本文件中后面的全部块\n"
 "d - 不贮藏该块和本文件中后面的全部块"
 
-#: git-add--interactive.perl:1234
+#: git-add--interactive.perl:1260
 msgid ""
 "y - unstage this hunk\n"
 "n - do not unstage this hunk\n"
@@ -17279,7 +23219,7 @@ msgstr ""
 "a - 不暂存该块和本文件中后面的全部块\n"
 "d - 不要不暂存该块和本文件中后面的全部块"
 
-#: git-add--interactive.perl:1240
+#: git-add--interactive.perl:1266
 msgid ""
 "y - apply this hunk to index\n"
 "n - do not apply this hunk to index\n"
@@ -17293,7 +23233,7 @@ msgstr ""
 "a - 应用该块和本文件中后面的全部块\n"
 "d - 不要应用该块和本文件中后面的全部块"
 
-#: git-add--interactive.perl:1246
+#: git-add--interactive.perl:1272 git-add--interactive.perl:1290
 msgid ""
 "y - discard this hunk from worktree\n"
 "n - do not discard this hunk from worktree\n"
@@ -17307,7 +23247,7 @@ msgstr ""
 "a - 丢弃该块和本文件中后面的全部块\n"
 "d - 不要丢弃该块和本文件中后面的全部块"
 
-#: git-add--interactive.perl:1252
+#: git-add--interactive.perl:1278
 msgid ""
 "y - discard this hunk from index and worktree\n"
 "n - do not discard this hunk from index and worktree\n"
@@ -17321,7 +23261,7 @@ msgstr ""
 "a - 丢弃该块和本文件中后面的全部块\n"
 "d - 不要丢弃该块和本文件中后面的全部块"
 
-#: git-add--interactive.perl:1258
+#: git-add--interactive.perl:1284
 msgid ""
 "y - apply this hunk to index and worktree\n"
 "n - do not apply this hunk to index and worktree\n"
@@ -17335,7 +23275,21 @@ msgstr ""
 "a - 应用该块和本文件中后面的全部块\n"
 "d - 不要应用该块和本文件中后面的全部块"
 
-#: git-add--interactive.perl:1273
+#: git-add--interactive.perl:1296
+msgid ""
+"y - apply this hunk to worktree\n"
+"n - do not apply this hunk to worktree\n"
+"q - quit; do not apply this hunk or any of the remaining ones\n"
+"a - apply this hunk and all later hunks in the file\n"
+"d - do not apply this hunk or any of the later hunks in the file"
+msgstr ""
+"y - 在工作区中应用该块\n"
+"n - 不要在工作区中应用该块\n"
+"q - 退出。不要应用该块及后面的全部块\n"
+"a - 应用该块和本文件中后面的全部块\n"
+"d - 不要应用该块和本文件中后面的全部块"
+
+#: git-add--interactive.perl:1311
 msgid ""
 "g - select a hunk to go to\n"
 "/ - search for a hunk matching the given regex\n"
@@ -17357,211 +23311,198 @@ msgstr ""
 "e - 手动编辑当前块\n"
 "? - 显示帮助\n"
 
-#: git-add--interactive.perl:1304
+#: git-add--interactive.perl:1342
 msgid "The selected hunks do not apply to the index!\n"
 msgstr "选中的块不能应用到索引！\n"
 
-#: git-add--interactive.perl:1305
+#: git-add--interactive.perl:1343
 msgid "Apply them to the worktree anyway? "
 msgstr "无论如何都要应用到工作区么？"
 
-#: git-add--interactive.perl:1308
+#: git-add--interactive.perl:1346
 msgid "Nothing was applied.\n"
 msgstr "未应用。\n"
 
-#: git-add--interactive.perl:1319
+#: git-add--interactive.perl:1357
 #, perl-format
 msgid "ignoring unmerged: %s\n"
 msgstr "忽略未合入的：%s\n"
 
-#: git-add--interactive.perl:1328
-msgid "Only binary files changed.\n"
-msgstr "只有二进制文件被修改。\n"
-
-#: git-add--interactive.perl:1330
-msgid "No changes.\n"
-msgstr "没有修改。\n"
-
-#: git-add--interactive.perl:1338
-msgid "Patch update"
-msgstr "补丁更新"
-
-#: git-add--interactive.perl:1390
+#: git-add--interactive.perl:1428
 #, perl-format
 msgid "Stage mode change [y,n,q,a,d%s,?]? "
 msgstr "暂存模式变更 [y,n,q,a,d%s,?]? "
 
-#: git-add--interactive.perl:1391
+#: git-add--interactive.perl:1429
 #, perl-format
 msgid "Stage deletion [y,n,q,a,d%s,?]? "
 msgstr "暂存删除动作 [y,n,q,a,d%s,?]? "
 
-#: git-add--interactive.perl:1392
+#: git-add--interactive.perl:1430
 #, perl-format
 msgid "Stage this hunk [y,n,q,a,d%s,?]? "
 msgstr "暂存该块 [y,n,q,a,d%s,?]? "
 
-#: git-add--interactive.perl:1395
+#: git-add--interactive.perl:1433
 #, perl-format
 msgid "Stash mode change [y,n,q,a,d%s,?]? "
 msgstr "贮藏模式变更 [y,n,q,a,d%s,?]? "
 
-#: git-add--interactive.perl:1396
+#: git-add--interactive.perl:1434
 #, perl-format
 msgid "Stash deletion [y,n,q,a,d%s,?]? "
 msgstr "贮藏删除动作 [y,n,q,a,d%s,?]? "
 
-#: git-add--interactive.perl:1397
+#: git-add--interactive.perl:1435
 #, perl-format
 msgid "Stash this hunk [y,n,q,a,d%s,?]? "
 msgstr "贮藏该块 [y,n,q,a,d%s,?]? "
 
-#: git-add--interactive.perl:1400
+#: git-add--interactive.perl:1438
 #, perl-format
 msgid "Unstage mode change [y,n,q,a,d%s,?]? "
 msgstr "取消暂存模式变更 [y,n,q,a,d%s,?]? "
 
-#: git-add--interactive.perl:1401
+#: git-add--interactive.perl:1439
 #, perl-format
 msgid "Unstage deletion [y,n,q,a,d%s,?]? "
 msgstr "取消暂存删除动作 [y,n,q,a,d%s,?]? "
 
-#: git-add--interactive.perl:1402
+#: git-add--interactive.perl:1440
 #, perl-format
 msgid "Unstage this hunk [y,n,q,a,d%s,?]? "
 msgstr "取消暂存该块 [y,n,q,a,d%s,?]? "
 
-#: git-add--interactive.perl:1405
+#: git-add--interactive.perl:1443
 #, perl-format
 msgid "Apply mode change to index [y,n,q,a,d%s,?]? "
 msgstr "将模式变更应用到索引 [y,n,q,a,d%s,?]? "
 
-#: git-add--interactive.perl:1406
+#: git-add--interactive.perl:1444
 #, perl-format
 msgid "Apply deletion to index [y,n,q,a,d%s,?]? "
-msgstr "将删除应用到索引 [y,n,q,a,d%s,?]? "
+msgstr "将删除操作应用到索引 [y,n,q,a,d%s,?]? "
 
-#: git-add--interactive.perl:1407
+#: git-add--interactive.perl:1445
 #, perl-format
 msgid "Apply this hunk to index [y,n,q,a,d%s,?]? "
 msgstr "将该块应用到索引 [y,n,q,a,d%s,?]? "
 
-#: git-add--interactive.perl:1410
+#: git-add--interactive.perl:1448 git-add--interactive.perl:1463
 #, perl-format
 msgid "Discard mode change from worktree [y,n,q,a,d%s,?]? "
 msgstr "从工作区中丢弃模式变更 [y,n,q,a,d%s,?]? "
 
-#: git-add--interactive.perl:1411
+#: git-add--interactive.perl:1449 git-add--interactive.perl:1464
 #, perl-format
 msgid "Discard deletion from worktree [y,n,q,a,d%s,?]? "
 msgstr "从工作区中丢弃删除动作 [y,n,q,a,d%s,?]? "
 
-#: git-add--interactive.perl:1412
+#: git-add--interactive.perl:1450 git-add--interactive.perl:1465
 #, perl-format
 msgid "Discard this hunk from worktree [y,n,q,a,d%s,?]? "
 msgstr "从工作区中丢弃该块 [y,n,q,a,d%s,?]? "
 
-#: git-add--interactive.perl:1415
+#: git-add--interactive.perl:1453
 #, perl-format
 msgid "Discard mode change from index and worktree [y,n,q,a,d%s,?]? "
 msgstr "从索引和工作区中丢弃模式变更 [y,n,q,a,d%s,?]? "
 
-#: git-add--interactive.perl:1416
+#: git-add--interactive.perl:1454
 #, perl-format
 msgid "Discard deletion from index and worktree [y,n,q,a,d%s,?]? "
 msgstr "从索引和工作区中丢弃删除 [y,n,q,a,d%s,?]? "
 
-#: git-add--interactive.perl:1417
+#: git-add--interactive.perl:1455
 #, perl-format
 msgid "Discard this hunk from index and worktree [y,n,q,a,d%s,?]? "
 msgstr "从索引和工作区中丢弃该块 [y,n,q,a,d%s,?]? "
 
-#: git-add--interactive.perl:1420
+#: git-add--interactive.perl:1458
 #, perl-format
 msgid "Apply mode change to index and worktree [y,n,q,a,d%s,?]? "
 msgstr "将模式变更应用到索引和工作区 [y,n,q,a,d%s,?]? "
 
-#: git-add--interactive.perl:1421
+#: git-add--interactive.perl:1459
 #, perl-format
 msgid "Apply deletion to index and worktree [y,n,q,a,d%s,?]? "
-msgstr "将删除应用到索引和工作区 [y,n,q,a,d%s,?]? "
+msgstr "将删除操作应用到索引和工作区 [y,n,q,a,d%s,?]? "
 
-#: git-add--interactive.perl:1422
+#: git-add--interactive.perl:1460
 #, perl-format
 msgid "Apply this hunk to index and worktree [y,n,q,a,d%s,?]? "
 msgstr "将该块应用到索引和工作区 [y,n,q,a,d%s,?]? "
 
-#: git-add--interactive.perl:1522
-msgid "No other hunks to goto\n"
-msgstr "没有其它可供跳转的块\n"
+#: git-add--interactive.perl:1468
+#, perl-format
+msgid "Apply mode change to worktree [y,n,q,a,d%s,?]? "
+msgstr "将模式变更应用到工作区 [y,n,q,a,d%s,?]? "
 
-#: git-add--interactive.perl:1529
-msgid "go to which hunk (<ret> to see more)? "
-msgstr "跳转到哪个块（<回车> 查看更多）？ "
+#: git-add--interactive.perl:1469
+#, perl-format
+msgid "Apply deletion to worktree [y,n,q,a,d%s,?]? "
+msgstr "将删除操作应用到工作区 [y,n,q,a,d%s,?]? "
 
-#: git-add--interactive.perl:1531
-msgid "go to which hunk? "
-msgstr "跳转到哪个块？"
+#: git-add--interactive.perl:1470
+#, perl-format
+msgid "Apply this hunk to worktree [y,n,q,a,d%s,?]? "
+msgstr "将该块应用到工作区 [y,n,q,a,d%s,?]? "
+
+#: git-add--interactive.perl:1570
+msgid "No other hunks to goto\n"
+msgstr "没有其它可供跳转的块\n"
 
-#: git-add--interactive.perl:1540
+#: git-add--interactive.perl:1588
 #, perl-format
 msgid "Invalid number: '%s'\n"
 msgstr "无效数字：'%s'\n"
 
-#: git-add--interactive.perl:1545
+#: git-add--interactive.perl:1593
 #, perl-format
 msgid "Sorry, only %d hunk available.\n"
 msgid_plural "Sorry, only %d hunks available.\n"
 msgstr[0] "对不起，只有 %d 个可用块。\n"
 msgstr[1] "对不起，只有 %d 个可用块。\n"
 
-#: git-add--interactive.perl:1571
+#: git-add--interactive.perl:1619
 msgid "No other hunks to search\n"
 msgstr "没有其它可供查找的块\n"
 
-#: git-add--interactive.perl:1575
-msgid "search for regex? "
-msgstr "使用正则表达式搜索？"
-
-#: git-add--interactive.perl:1588
+#: git-add--interactive.perl:1636
 #, perl-format
 msgid "Malformed search regexp %s: %s\n"
 msgstr "错误的正则表达式 %s：%s\n"
 
-#: git-add--interactive.perl:1598
+#: git-add--interactive.perl:1646
 msgid "No hunk matches the given pattern\n"
-msgstr "没有和给定模式相匹配的快\n"
+msgstr "没有和给定模式相匹配的块\n"
 
-#: git-add--interactive.perl:1610 git-add--interactive.perl:1632
+#: git-add--interactive.perl:1658 git-add--interactive.perl:1680
 msgid "No previous hunk\n"
 msgstr "没有前一个块\n"
 
-#: git-add--interactive.perl:1619 git-add--interactive.perl:1638
+#: git-add--interactive.perl:1667 git-add--interactive.perl:1686
 msgid "No next hunk\n"
 msgstr "没有下一个块\n"
 
-#: git-add--interactive.perl:1644
+#: git-add--interactive.perl:1692
 msgid "Sorry, cannot split this hunk\n"
 msgstr "对不起，不能拆分这个块\n"
 
-#: git-add--interactive.perl:1650
+#: git-add--interactive.perl:1698
 #, perl-format
 msgid "Split into %d hunk.\n"
 msgid_plural "Split into %d hunks.\n"
 msgstr[0] "拆分为 %d 块。\n"
 msgstr[1] "拆分为 %d 块。\n"
 
-#: git-add--interactive.perl:1660
+#: git-add--interactive.perl:1708
 msgid "Sorry, cannot edit this hunk\n"
 msgstr "对不起，不能编辑这个块\n"
 
-#: git-add--interactive.perl:1706
-msgid "Review diff"
-msgstr "检视 diff"
-
 #. TRANSLATORS: please do not translate the command names
 #. 'status', 'update', 'revert', etc.
-#: git-add--interactive.perl:1725
+#: git-add--interactive.perl:1773
 msgid ""
 "status        - show paths with changes\n"
 "update        - add working tree state to the staged set of changes\n"
@@ -17578,90 +23519,91 @@ msgstr ""
 "diff          - 显示 HEAD 和索引间差异\n"
 "add untracked - 添加未跟踪文件的内容至暂存列表\n"
 
-#: git-add--interactive.perl:1742 git-add--interactive.perl:1747
-#: git-add--interactive.perl:1750 git-add--interactive.perl:1757
-#: git-add--interactive.perl:1761 git-add--interactive.perl:1767
+#: git-add--interactive.perl:1790 git-add--interactive.perl:1795
+#: git-add--interactive.perl:1798 git-add--interactive.perl:1805
+#: git-add--interactive.perl:1808 git-add--interactive.perl:1815
+#: git-add--interactive.perl:1819 git-add--interactive.perl:1825
 msgid "missing --"
 msgstr "缺失 --"
 
-#: git-add--interactive.perl:1763
+#: git-add--interactive.perl:1821
 #, perl-format
 msgid "unknown --patch mode: %s"
 msgstr "未知的 --patch 模式：%s"
 
-#: git-add--interactive.perl:1769 git-add--interactive.perl:1775
+#: git-add--interactive.perl:1827 git-add--interactive.perl:1833
 #, perl-format
 msgid "invalid argument %s, expecting --"
 msgstr "无效的参数 %s，期望是 --"
 
-#: git-send-email.perl:130
+#: git-send-email.perl:138
 msgid "local zone differs from GMT by a non-minute interval\n"
 msgstr "本地时间和 GMT 有不到一分钟间隔\n"
 
-#: git-send-email.perl:137 git-send-email.perl:143
+#: git-send-email.perl:145 git-send-email.perl:151
 msgid "local time offset greater than or equal to 24 hours\n"
 msgstr "本地时间偏移量大于等于 24 小时\n"
 
-#: git-send-email.perl:211 git-send-email.perl:217
+#: git-send-email.perl:223 git-send-email.perl:229
 msgid "the editor exited uncleanly, aborting everything"
 msgstr "编辑器非正常退出，终止所有操作"
 
-#: git-send-email.perl:294
+#: git-send-email.perl:310
 #, perl-format
 msgid ""
 "'%s' contains an intermediate version of the email you were composing.\n"
 msgstr "'%s' 包含您正在编写的一个中间版本的邮件。\n"
 
-#: git-send-email.perl:299
+#: git-send-email.perl:315
 #, perl-format
 msgid "'%s.final' contains the composed email.\n"
 msgstr "'%s.final' 包含编辑的邮件。\n"
 
-#: git-send-email.perl:317
+#: git-send-email.perl:408
 msgid "--dump-aliases incompatible with other options\n"
 msgstr "--dump-aliases 和其它选项不兼容\n"
 
-#: git-send-email.perl:383 git-send-email.perl:638
+#: git-send-email.perl:481 git-send-email.perl:683
 msgid "Cannot run git format-patch from outside a repository\n"
 msgstr "不能在仓库之外运行 git format-patch\n"
 
-#: git-send-email.perl:386
+#: git-send-email.perl:484
 msgid ""
 "`batch-size` and `relogin` must be specified together (via command-line or "
 "configuration option)\n"
 msgstr "`batch-size` 和 `relogin` 必须同时定义（通过命令行或者配置选项）\n"
 
-#: git-send-email.perl:456
+#: git-send-email.perl:497
 #, perl-format
 msgid "Unknown --suppress-cc field: '%s'\n"
 msgstr "未知的 --suppress-cc 字段：'%s'\n"
 
-#: git-send-email.perl:485
+#: git-send-email.perl:528
 #, perl-format
 msgid "Unknown --confirm setting: '%s'\n"
 msgstr "未知的 --confirm 设置：'%s'\n"
 
-#: git-send-email.perl:513
+#: git-send-email.perl:556
 #, perl-format
 msgid "warning: sendmail alias with quotes is not supported: %s\n"
 msgstr "警告：不支持带引号的 sendmail 别名：%s\n"
 
-#: git-send-email.perl:515
+#: git-send-email.perl:558
 #, perl-format
 msgid "warning: `:include:` not supported: %s\n"
 msgstr "警告：不支持 `:include:`：%s\n"
 
-#: git-send-email.perl:517
+#: git-send-email.perl:560
 #, perl-format
 msgid "warning: `/file` or `|pipe` redirection not supported: %s\n"
 msgstr "警告：不支持 `/file` 或 `|pipe` 重定向：%s\n"
 
-#: git-send-email.perl:522
+#: git-send-email.perl:565
 #, perl-format
 msgid "warning: sendmail line is not recognized: %s\n"
 msgstr "警告：不能识别的 sendmail 行：%s\n"
 
-#: git-send-email.perl:604
+#: git-send-email.perl:649
 #, perl-format
 msgid ""
 "File '%s' exists but it could also be the range of commits\n"
@@ -17676,21 +23618,21 @@ msgstr ""
 "    * 如果含义为一个文件，使用 \"./%s\"，或者\n"
 "    * 如果含义为一个范围，使用 --format-patch 选项。\n"
 
-#: git-send-email.perl:625
+#: git-send-email.perl:670
 #, perl-format
 msgid "Failed to opendir %s: %s"
 msgstr "无法打开目录 %s: %s"
 
-#: git-send-email.perl:649
+#: git-send-email.perl:694
 #, perl-format
 msgid ""
 "fatal: %s: %s\n"
 "warning: no patches were sent\n"
 msgstr ""
-"严重：%s：%s\n"
+"致命错误：%s：%s\n"
 "警告：补丁未能发送\n"
 
-#: git-send-email.perl:660
+#: git-send-email.perl:705
 msgid ""
 "\n"
 "No patch files specified!\n"
@@ -17700,17 +23642,17 @@ msgstr ""
 "未指定补丁文件！\n"
 "\n"
 
-#: git-send-email.perl:673
+#: git-send-email.perl:718
 #, perl-format
 msgid "No subject line in %s?"
 msgstr "在 %s 中没有标题行？"
 
-#: git-send-email.perl:683
+#: git-send-email.perl:728
 #, perl-format
 msgid "Failed to open for writing %s: %s"
-msgstr "无法写入 %s: %s"
+msgstr "为写入打开 %s 失败: %s"
 
-#: git-send-email.perl:694
+#: git-send-email.perl:739
 msgid ""
 "Lines beginning in \"GIT:\" will be removed.\n"
 "Consider including an overall diffstat or table of contents\n"
@@ -17719,41 +23661,41 @@ msgid ""
 "Clear the body content if you don't wish to send a summary.\n"
 msgstr ""
 "以 \"GIT:\" 开头的行将被删除。\n"
-"考虑包含一个整体的 diffstat 或者您正在写的补丁的目录。\n"
+"考虑包含一个整体的差异统计或者您正在写的补丁的目录。\n"
 "\n"
 "如果您不想发送摘要，清除内容。\n"
 
-#: git-send-email.perl:718
+#: git-send-email.perl:763
 #, perl-format
 msgid "Failed to open %s: %s"
 msgstr "无法打开 %s: %s"
 
-#: git-send-email.perl:735
+#: git-send-email.perl:780
 #, perl-format
 msgid "Failed to open %s.final: %s"
 msgstr "无法打开 %s.final: %s"
 
-#: git-send-email.perl:778
+#: git-send-email.perl:823
 msgid "Summary email is empty, skipping it\n"
 msgstr "摘要邮件为空，跳过\n"
 
 #. TRANSLATORS: please keep [y/N] as is.
-#: git-send-email.perl:813
+#: git-send-email.perl:858
 #, perl-format
 msgid "Are you sure you want to use <%s> [y/N]? "
 msgstr "您确认要使用 <%s> [y/N]？"
 
-#: git-send-email.perl:868
+#: git-send-email.perl:913
 msgid ""
 "The following files are 8bit, but do not declare a Content-Transfer-"
 "Encoding.\n"
 msgstr "如下文件含 8bit 内容，但没有声明一个 Content-Transfer-Encoding。\n"
 
-#: git-send-email.perl:873
+#: git-send-email.perl:918
 msgid "Which 8bit encoding should I declare [UTF-8]? "
 msgstr "要声明 8bit 为什么样的编码格式 [UTF-8]？"
 
-#: git-send-email.perl:881
+#: git-send-email.perl:926
 #, perl-format
 msgid ""
 "Refusing to send because the patch\n"
@@ -17765,20 +23707,20 @@ msgstr ""
 "\t%s\n"
 "包含模版标题 '*** SUBJECT HERE ***'。如果确实想要发送，使用参数 --force。\n"
 
-#: git-send-email.perl:900
+#: git-send-email.perl:945
 msgid "To whom should the emails be sent (if anyone)?"
 msgstr "邮件将要发送给谁？"
 
-#: git-send-email.perl:918
+#: git-send-email.perl:963
 #, perl-format
 msgid "fatal: alias '%s' expands to itself\n"
-msgstr "严重：别名 '%s' 扩展为它自己\n"
+msgstr "致命错误：别名 '%s' 扩展为它自己\n"
 
-#: git-send-email.perl:930
+#: git-send-email.perl:975
 msgid "Message-ID to be used as In-Reply-To for the first email (if any)? "
 msgstr "Message-ID 被用作第一封邮件的 In-Reply-To ？"
 
-#: git-send-email.perl:988 git-send-email.perl:996
+#: git-send-email.perl:1033 git-send-email.perl:1041
 #, perl-format
 msgid "error: unable to extract a valid address from: %s\n"
 msgstr "错误：不能从 %s 中提取一个有效的邮件地址\n"
@@ -17786,16 +23728,16 @@ msgstr "错误：不能从 %s 中提取
 #. TRANSLATORS: Make sure to include [q] [d] [e] in your
 #. translation. The program will only accept English input
 #. at this point.
-#: git-send-email.perl:1000
+#: git-send-email.perl:1045
 msgid "What to do with this address? ([q]uit|[d]rop|[e]dit): "
 msgstr "如何处理这个地址？([q]uit|[d]rop|[e]dit)："
 
-#: git-send-email.perl:1317
+#: git-send-email.perl:1362
 #, perl-format
 msgid "CA path \"%s\" does not exist"
 msgstr "CA 路径 \"%s\" 不存在"
 
-#: git-send-email.perl:1400
+#: git-send-email.perl:1445
 msgid ""
 "    The Cc list above has been expanded by additional\n"
 "    addresses found in the patch commit message. By default\n"
@@ -17820,227 +23762,128 @@ msgstr ""
 #. TRANSLATORS: Make sure to include [y] [n] [e] [q] [a] in your
 #. translation. The program will only accept English input
 #. at this point.
-#: git-send-email.perl:1415
+#: git-send-email.perl:1460
 msgid "Send this email? ([y]es|[n]o|[e]dit|[q]uit|[a]ll): "
 msgstr "发送这封邮件？([y]es|[n]o|[e]dit|[q]uit|[a]ll): "
 
-#: git-send-email.perl:1418
+#: git-send-email.perl:1463
 msgid "Send this email reply required"
 msgstr "发送要求的邮件回复"
 
-#: git-send-email.perl:1446
+#: git-send-email.perl:1491
 msgid "The required SMTP server is not properly defined."
 msgstr "要求的 SMTP 服务器未被正确定义。"
 
-#: git-send-email.perl:1493
+#: git-send-email.perl:1538
 #, perl-format
 msgid "Server does not support STARTTLS! %s"
 msgstr "服务器不支持 STARTTLS！%s"
 
-#: git-send-email.perl:1498 git-send-email.perl:1502
+#: git-send-email.perl:1543 git-send-email.perl:1547
 #, perl-format
 msgid "STARTTLS failed! %s"
 msgstr "STARTTLS 失败！%s"
 
-#: git-send-email.perl:1512
+#: git-send-email.perl:1556
 msgid "Unable to initialize SMTP properly. Check config and use --smtp-debug."
 msgstr "无法正确地初始化 SMTP。检查配置并使用 --smtp-debug。"
 
-#: git-send-email.perl:1530
+#: git-send-email.perl:1574
 #, perl-format
 msgid "Failed to send %s\n"
 msgstr "无法发送 %s\n"
 
-#: git-send-email.perl:1533
+#: git-send-email.perl:1577
 #, perl-format
 msgid "Dry-Sent %s\n"
 msgstr "演习发送 %s\n"
 
-#: git-send-email.perl:1533
+#: git-send-email.perl:1577
 #, perl-format
 msgid "Sent %s\n"
 msgstr "正发送 %s\n"
 
-#: git-send-email.perl:1535
+#: git-send-email.perl:1579
 msgid "Dry-OK. Log says:\n"
 msgstr "演习成功。日志说：\n"
 
-#: git-send-email.perl:1535
+#: git-send-email.perl:1579
 msgid "OK. Log says:\n"
 msgstr "OK。日志说：\n"
 
-#: git-send-email.perl:1547
+#: git-send-email.perl:1591
 msgid "Result: "
 msgstr "结果："
 
-#: git-send-email.perl:1550
+#: git-send-email.perl:1594
 msgid "Result: OK\n"
 msgstr "结果：OK\n"
 
-#: git-send-email.perl:1568
+#: git-send-email.perl:1612
 #, perl-format
 msgid "can't open file %s"
 msgstr "无法打开文件 %s"
 
-#: git-send-email.perl:1615 git-send-email.perl:1635
+#: git-send-email.perl:1659 git-send-email.perl:1679
 #, perl-format
 msgid "(mbox) Adding cc: %s from line '%s'\n"
 msgstr "(mbox) 添加 cc：%s 自行 '%s'\n"
 
-#: git-send-email.perl:1621
+#: git-send-email.perl:1665
 #, perl-format
 msgid "(mbox) Adding to: %s from line '%s'\n"
 msgstr "(mbox) 添加 to：%s 自行 '%s'\n"
 
-#: git-send-email.perl:1674
+#: git-send-email.perl:1718
 #, perl-format
 msgid "(non-mbox) Adding cc: %s from line '%s'\n"
 msgstr "(non-mbox) 添加 cc：%s 自行 '%s'\n"
 
-#: git-send-email.perl:1699
+#: git-send-email.perl:1753
 #, perl-format
 msgid "(body) Adding cc: %s from line '%s'\n"
 msgstr "(body) 添加 cc: %s 自行 '%s'\n"
 
-#: git-send-email.perl:1817
+#: git-send-email.perl:1864
 #, perl-format
 msgid "(%s) Could not execute '%s'"
 msgstr "(%s) 不能执行 '%s'"
 
-#: git-send-email.perl:1824
+#: git-send-email.perl:1871
 #, perl-format
 msgid "(%s) Adding %s: %s from: '%s'\n"
 msgstr "(%s) 添加 %s: %s 自：'%s'\n"
 
-#: git-send-email.perl:1828
+#: git-send-email.perl:1875
 #, perl-format
 msgid "(%s) failed to close pipe to '%s'"
 msgstr "(%s) 无法关闭管道至 '%s'"
 
-#: git-send-email.perl:1855
+#: git-send-email.perl:1905
 msgid "cannot send message as 7bit"
 msgstr "不能以 7bit 形式发送信息"
 
-#: git-send-email.perl:1863
+#: git-send-email.perl:1913
 msgid "invalid transfer encoding"
 msgstr "无效的传送编码"
 
-#: git-send-email.perl:1901 git-send-email.perl:1952 git-send-email.perl:1962
+#: git-send-email.perl:1954 git-send-email.perl:2006 git-send-email.perl:2016
 #, perl-format
 msgid "unable to open %s: %s\n"
 msgstr "不能打开 %s：%s\n"
 
-#: git-send-email.perl:1904
+#: git-send-email.perl:1957
 #, perl-format
 msgid "%s: patch contains a line longer than 998 characters"
 msgstr "%s：补丁包含一个超过 998 字符的行"
 
-#: git-send-email.perl:1920
+#: git-send-email.perl:1974
 #, perl-format
 msgid "Skipping %s with backup suffix '%s'.\n"
 msgstr "略过 %s 含备份后缀 '%s'。\n"
 
 #. TRANSLATORS: please keep "[y|N]" as is.
-#: git-send-email.perl:1924
+#: git-send-email.perl:1978
 #, perl-format
 msgid "Do you really want to send %s? [y|N]: "
 msgstr "您真的要发送 %s？[y|N]："
-
-#~ msgid "Everyday Git With 20 Commands Or So"
-#~ msgstr "每一天 Git 常用的约 20 条命令"
-
-#~ msgid "Could not open '%s' for writing"
-#~ msgstr "无法打开 '%s' 进行写入"
-
-#~ msgid "BUG: returned path string doesn't match cwd?"
-#~ msgstr "BUG：返回的路径和当前路径不匹配？"
-
-#~ msgid "Error in object"
-#~ msgstr "对象中出错"
-
-#~ msgid ""
-#~ "unexpected 1st line of squash message:\n"
-#~ "\n"
-#~ "\t%.*s"
-#~ msgstr ""
-#~ "意外的压缩提交首行提交信息：\n"
-#~ "\n"
-#~ "\t%.*s"
-
-#~ msgid ""
-#~ "invalid 1st line of squash message:\n"
-#~ "\n"
-#~ "\t%.*s"
-#~ msgstr ""
-#~ "压缩提交的首行提交信息无效：\n"
-#~ "\n"
-#~ "\t%.*s"
-
-#~ msgid "To/Cc/Bcc fields are not interpreted yet, they have been ignored\n"
-#~ msgstr "To/Cc/Bcc 字段不解析，它们被忽略\n"
-
-#~ msgid "git fetch-pack: expected ACK/NAK, got EOF"
-#~ msgstr "git fetch-pack：应为 ACK/NAK，却得到 EOF"
-
-#~ msgid "The copy of the patch that failed is found in: %s"
-#~ msgstr "失败的补丁文件副本位于：%s"
-
-#~ msgid "invalid filter-spec expression '%s'"
-#~ msgstr "无效的 filter-spec 表达式 '%s'"
-
-#~ msgid "pathspec and --all are incompatible"
-#~ msgstr "pathspec 和 --all 不兼容"
-
-#~ msgid "Submodule '$name' ($url) unregistered for path '$displaypath'"
-#~ msgstr "子模组 '$name' ($url) 未对路径 '$displaypath' 注册"
-
-#~ msgid ""
-#~ "empty strings as pathspecs will be made invalid in upcoming releases. "
-#~ "please use . instead if you meant to match all paths"
-#~ msgstr ""
-#~ "在下一个版本中，使用空字符串作为路径规格将被视作非法。如果要匹配所有路"
-#~ "径，\n"
-#~ "请代之以 ."
-
-#~ msgid "unable to open '%s' for writing"
-#~ msgstr "无法以写入方式打开 '%s'"
-
-#~ msgid "could not truncate '%s'"
-#~ msgstr "无法截断 '%s'"
-
-#~ msgid "could not finish '%s'"
-#~ msgstr "无法结束 '%s'"
-
-#~ msgid "could not close %s"
-#~ msgstr "不能关闭 %s"
-
-#~ msgid "Copied a misnamed branch '%s' away"
-#~ msgstr "已将错误命名的分支 '%s' 复制"
-
-#~ msgid "it does not make sense to create 'HEAD' manually"
-#~ msgstr "手工创建 'HEAD' 没有意义"
-
-#~ msgid "Don't know how to clone %s"
-#~ msgstr "不知道如何克隆 %s"
-
-#~ msgid "show ignored files"
-#~ msgstr "显示忽略的文件"
-
-#~ msgid "%s is not a valid '%s' object"
-#~ msgstr "%s 不是一个有效的 '%s' 对象"
-
-#~ msgid "Don't know how to fetch from %s"
-#~ msgstr "不知道如何从 %s 获取"
-
-#~ msgid "'$term' is not a valid term"
-#~ msgstr "'$term' 不是一个有效的名称"
-
-#~ msgid ""
-#~ "error: unknown option for 'stash save': $option\n"
-#~ "       To provide a message, use git stash save -- '$option'"
-#~ msgstr ""
-#~ "错误：'stash save' 的未知选项：$option\n"
-#~ "      要提供一个描述信息，使用 git stash save -- '$option'"
-
-#~ msgid "Failed to recurse into submodule path '$sm_path'"
-#~ msgstr "无法递归进子模组路径 '$sm_path'"
diff -pruN 1.2.1+git2.18.0-1/git/po/zh_TW.po 1.2.3+git2.25.1-1/git/po/zh_TW.po
--- 1.2.1+git2.18.0-1/git/po/zh_TW.po	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/po/zh_TW.po	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,24000 @@
+# Chinese (traditional) translations for Git package
+# Git 套裝軟體的繁體中文翻譯.
+# Copyright (C) 2012,2013 Jiang Xin <worldhello.net AT gmail.com>
+# Copyright (C) 2019,2019 Yi-Jyun Pan <pan93412@gmail.com>
+# This file is distributed under the same license as the Git package.
+# Contributors (CN):
+#   - Fangyi Zhou <me AT fangyi.io>
+#   - Jiang Xin <worldhello.net AT gmail.com>
+#   - Lian Cheng <rhythm.mail AT gmail.com>
+#   - Ray Chen <oldsharp AT gmail.com>
+#   - Riku <lu.riku AT gmail.com>
+#   - Thynson <lanxingcan AT gmail.com>
+#   - ws3389 <willsmith3389 AT gmail.com>
+#   - Wang Sheng <wangsheng2008love AT 163.com>
+#   - 依云 <lilydjwg AT gmail.com>
+#   - Yichao Yu <yyc1992 AT gmail.com>
+#   - Zhuang Ya <zhuangya AT me.com>
+# Contributors (TW):
+#
+#  Git glossary for Chinese translators
+#
+#   English                          |  Chinese
+#   ---------------------------------+--------------------------------------
+#   3-way merge                      |  三方合併
+#   abbreviate                       |  簡寫（的 SHA-1 值）
+#   alternate object database        |  備用物件庫
+#   amend                            |  修補
+#   ancestor                         |  祖先，祖先提交
+#   annotated tag                    |  附註標籤
+#   bare repository                  |  純版本庫
+#   bisect                           |  二分尋找
+#   blob object                      |  資料物件
+#   branch                           |  分支
+#   bundle                           |  包
+#   bypass                           |  繞過
+#   cache                            |  索引（的別稱）
+#   chain                            |  （提交）鏈
+#   changeset                        |  變更集
+#   checkout                         |  簽出
+#   checksum                         |  校驗，校驗和
+#   cherry-picking                   |  揀選
+#   clean                            |  乾淨（的工作區）
+#   clone                            |  複製
+#   commit                           |  提交
+#   commit message                   |  提交說明
+#   commit object                    |  提交物件
+#   commit-ish (also committish)     |  提交號
+#   conflict                         |  衝突
+#   core Git                         |  核心 Git 工具
+#   cover letter                     |  附函
+#   DAG                              |  有向無環圖
+#   dangling object                  |  懸空物件
+#   detached HEAD                    |  分離開頭指標
+#   directory                        |  目錄
+#   dirty                            |  髒（的工作區）
+#   dumb HTTP protocol               |  啞 HTTP 協定
+#   evil merge                       |  壞合併（合併引入了父提交沒有的修改）
+#   fast-forward                     |  快轉
+#   fetch                            |  取得
+#   file system                      |  檔案系統
+#   fork                             |  衍生
+#   Git archive                      |  版本庫（對於 arch 使用者）
+#   gitfile                          |  gitfile（版本庫連結檔案）
+#   grafts                           |  （提交）移植
+#   hash                             |  雜湊值
+#   HEAD                             |  HEAD（開頭指標，亦即目前分支）
+#   head                             |  頭、分支
+#   head ref                         |  分支
+#   header                           |  標頭訊息
+#   hook                             |  掛鉤
+#   hunk                             |  修補檔片段
+#   index                            |  索引
+#   index entry                      |  索引條目
+#   loose object                     |  鬆散物件
+#   loose refs                       |  鬆散引用
+#   master                           |  master（預設分支名）
+#   merge                            |  合併
+#   object                           |  物件
+#   object database                  |  物件庫
+#   object identifier                |  物件識別元
+#   object name                      |  物件名稱
+#   object type                      |  物件類型
+#   octopus                          |  章魚式合併（兩分支以上的合併）
+#   origin                           |  origin（預設的遠端名稱）
+#   pack                             |  包
+#   pack index                       |  包索引
+#   packfile                         |  包檔案
+#   parent                           |  父提交
+#   patch                            |  修補檔
+#   pathspec                         |  路徑規格
+#   pattern                          |  模式
+#   pickaxe                          |  挖掘
+#   plumbing                         |  管件（Git 底層核心指令的別稱）
+#   porcelain                        |  瓷件（Git 上層封裝指令的別稱）
+#   precious-objects repo            |  珍品版本庫
+#   prune                            |  清除
+#   pull                             |  拉，拉取
+#   push                             |  推，推送
+#   reachable                        |  可以取得
+#   rebase                           |  重定基底
+#   ref                              |  引用
+#   reflog                           |  引用日誌
+#   refspec                          |  引用規格
+#   remote                           |  遠端，遠端版本庫
+#   remote-tracking branch           |  遠端追蹤分支
+#   replay                           |  重放
+#   repo                             |  版本庫
+#   repository                       |  版本庫
+#   resolve                          |  （衝突）解決
+#   revert                           |  還原提交
+#   revision                         |  版本
+#   rewind                           |  還原 (Fuzzy)
+#   SCM                              |  原始碼管理（工具）
+#   SHA-1                            |  SHA-1（安全雜湊演算法1）
+#   shallow repository               |  淺（複製）版本庫
+#   signed tag                       |  簽名標籤
+#   smart HTTP protocol              |  智慧 HTTP 協定
+#   squash                           |  壓縮
+#   stage                            |  n. 暫存區（即索引）; v. 暫存
+#   stash                            |  n. 儲藏區; v. 儲藏
+#   submodule                        |  子模組
+#   symref                           |  符號引用
+#   tag                              |  n. 標籤; v. 打標籤
+#   tag object                       |  標籤物件
+#   tagger                           |  打標籤者
+#   topic branch                     |  主題分支
+#   track                            |  追蹤
+#   trailer                          |  尾部署名
+#   tree                             |  樹（工作區或樹狀物件）
+#   tree object                      |  樹狀物件
+#   tree-ish (also treeish)          |  樹狀物件（或可以解析為一樹狀物件）
+#   unmerged index                   |  未合併索引
+#   unpack                           |  解包
+#   unreachable object               |  無法取得物件
+#   unstage                          |  取消暫存
+#   upstream                         |  上游
+#   upstream branch                  |  上游分支
+#   working tree                     |  工作區
+#
+# pan93412 <pan93412@gmail.com>, 2019.
+msgid ""
+msgstr ""
+"Project-Id-Version: Git\n"
+"Report-Msgid-Bugs-To: Git Mailing List <git@vger.kernel.org>\n"
+"POT-Creation-Date: 2019-12-30 08:48+0800\n"
+"PO-Revision-Date: 2019-12-31 21:06+0800\n"
+"Last-Translator: pan93412 <pan93412@gmail.com>\n"
+"Language-Team: Chinese <chinese-l10n@googlegroups.com>\n"
+"Language: zh_CN\n"
+"MIME-Version: 1.0\n"
+"Content-Type: text/plain; charset=UTF-8\n"
+"Content-Transfer-Encoding: 8bit\n"
+"X-ZhConverter: 繁化姬 dict-f4bc617e-r910 @ 2019/11/16 20:23:12 |"
+" https://zhconvert.org\n"
+"Plural-Forms: nplurals=2; plural=(n != 1);\n"
+"X-Generator: Lokalize 19.12.0\n"
+
+#: add-interactive.c:347
+#, c-format
+#| msgid "Huh (%s)?\n"
+msgid "Huh (%s)?"
+msgstr "嗯（%s）？"
+
+#: add-interactive.c:500 add-interactive.c:801 sequencer.c:3216
+#: sequencer.c:3656 builtin/rebase.c:871 builtin/rebase.c:1643
+#: builtin/rebase.c:2019 builtin/rebase.c:2063
+msgid "could not read index"
+msgstr "不能讀取索引"
+
+#: add-interactive.c:555 git-add--interactive.perl:269
+#: git-add--interactive.perl:294
+msgid "binary"
+msgstr "二進位"
+
+#: add-interactive.c:613 git-add--interactive.perl:278
+#: git-add--interactive.perl:332
+msgid "nothing"
+msgstr "無"
+
+#: add-interactive.c:614 git-add--interactive.perl:314
+#: git-add--interactive.perl:329
+msgid "unchanged"
+msgstr "沒有修改"
+
+#: add-interactive.c:651 git-add--interactive.perl:643
+msgid "Update"
+msgstr "更新"
+
+#: add-interactive.c:668 add-interactive.c:856
+#, c-format
+#| msgid "could not stat '%s'"
+msgid "could not stage '%s'"
+msgstr "不能暫存 '%s'"
+
+#: add-interactive.c:674 add-interactive.c:863 sequencer.c:3409
+#: builtin/rebase.c:895
+msgid "could not write index"
+msgstr "不能寫入索引"
+
+#: add-interactive.c:677 git-add--interactive.perl:628
+#, c-format, perl-format
+msgid "updated %d path\n"
+msgid_plural "updated %d paths\n"
+msgstr[0] "更新了 %d 個路徑\n"
+msgstr[1] "更新了 %d 個路徑\n"
+
+#: add-interactive.c:695 git-add--interactive.perl:678
+#, c-format, perl-format
+msgid "note: %s is untracked now.\n"
+msgstr "說明：%s 現已成為未追蹤的。\n"
+
+#: add-interactive.c:700 apply.c:4108 builtin/checkout.c:281
+#: builtin/reset.c:144
+#, c-format
+msgid "make_cache_entry failed for path '%s'"
+msgstr "對路徑 '%s' 的 make_cache_entry 動作失敗"
+
+#: add-interactive.c:730 git-add--interactive.perl:655
+msgid "Revert"
+msgstr "還原"
+
+#: add-interactive.c:746
+#| msgid "could not parse HEAD"
+msgid "Could not parse HEAD^{tree}"
+msgstr "不能解析 HEAD^{樹}"
+
+#: add-interactive.c:784 git-add--interactive.perl:631
+#, c-format, perl-format
+msgid "reverted %d path\n"
+msgid_plural "reverted %d paths\n"
+msgstr[0] "還原了 %d 個路徑\n"
+msgstr[1] "還原了 %d 個路徑\n"
+
+#: add-interactive.c:835 git-add--interactive.perl:695
+#, c-format
+msgid "No untracked files.\n"
+msgstr "沒有未追蹤的檔案。\n"
+
+#: add-interactive.c:839 git-add--interactive.perl:689
+msgid "Add untracked"
+msgstr "新增未追蹤的"
+
+#: add-interactive.c:866 git-add--interactive.perl:625
+#, c-format, perl-format
+msgid "added %d path\n"
+msgid_plural "added %d paths\n"
+msgstr[0] "增加了 %d 個路徑\n"
+msgstr[1] "增加了 %d 個路徑\n"
+
+#: add-interactive.c:896
+#, c-format
+#| msgid "ignoring unmerged: %s\n"
+msgid "ignoring unmerged: %s"
+msgstr "忽略未合併：%s"
+
+#: add-interactive.c:908 add-patch.c:1331 git-add--interactive.perl:1366
+#, c-format
+msgid "Only binary files changed.\n"
+msgstr "只有二進位檔案被修改。\n"
+
+#: add-interactive.c:910 add-patch.c:1329 git-add--interactive.perl:1368
+#, c-format
+msgid "No changes.\n"
+msgstr "沒有修改。\n"
+
+#: add-interactive.c:914 git-add--interactive.perl:1376
+msgid "Patch update"
+msgstr "修補檔更新"
+
+#: add-interactive.c:953 git-add--interactive.perl:1754
+msgid "Review diff"
+msgstr "檢視 diff"
+
+#: add-interactive.c:981
+#| msgid "show matching files in the pager"
+msgid "show paths with changes"
+msgstr "顯示有變更的路徑"
+
+#: add-interactive.c:983
+msgid "add working tree state to the staged set of changes"
+msgstr "加入工作區狀態至暫存列表"
+
+#: add-interactive.c:985
+msgid "revert staged set of changes back to the HEAD version"
+msgstr "還原修改的暫存集至 HEAD 版本"
+
+#: add-interactive.c:987
+#| msgid "select hunks interactively"
+msgid "pick hunks and update selectively"
+msgstr "挑選區塊並選擇性更新"
+
+#: add-interactive.c:989
+#| msgid "reset HEAD and index"
+msgid "view diff between HEAD and index"
+msgstr "檢視 HEAD 及索引之間的差異"
+
+#: add-interactive.c:991
+msgid "add contents of untracked files to the staged set of changes"
+msgstr "加入未追蹤檔案的內容至暫存列表"
+
+#: add-interactive.c:999 add-interactive.c:1048
+msgid "Prompt help:"
+msgstr "提示說明："
+
+#: add-interactive.c:1001
+#| msgid "select mainline parent"
+msgid "select a single item"
+msgstr "選擇單一項目"
+
+#: add-interactive.c:1003
+#| msgid "select handling of signed tags"
+msgid "select a range of items"
+msgstr "選擇項目範圍"
+
+#: add-interactive.c:1005
+#| msgid "%s has multiple values"
+msgid "select multiple ranges"
+msgstr "選擇多個範圍"
+
+#: add-interactive.c:1007 add-interactive.c:1052
+msgid "select item based on unique prefix"
+msgstr "基於唯一前綴選擇項目"
+
+#: add-interactive.c:1009
+#| msgid "use specified template file"
+msgid "unselect specified items"
+msgstr "取消選擇指定項目"
+
+#: add-interactive.c:1011
+#| msgid "choose a diff algorithm"
+msgid "choose all items"
+msgstr "選擇所有項目"
+
+#: add-interactive.c:1013
+msgid "(empty) finish selecting"
+msgstr "（空）完成選取"
+
+#: add-interactive.c:1050
+#| msgid "%s expects a numerical value"
+msgid "select a numbered item"
+msgstr "選擇編號過的項目"
+
+#: add-interactive.c:1054
+#| msgid "empty exec command"
+msgid "(empty) select nothing"
+msgstr "（空）全不選取"
+
+#: add-interactive.c:1062 builtin/clean.c:822 git-add--interactive.perl:1851
+msgid "*** Commands ***"
+msgstr "*** 指令 ***"
+
+#: add-interactive.c:1063 builtin/clean.c:823 git-add--interactive.perl:1848
+msgid "What now"
+msgstr "請選擇"
+
+#: add-interactive.c:1115 git-add--interactive.perl:213
+msgid "staged"
+msgstr "快取"
+
+#: add-interactive.c:1115 git-add--interactive.perl:213
+msgid "unstaged"
+msgstr "未快取"
+
+#: add-interactive.c:1115 apply.c:4965 apply.c:4968 builtin/am.c:2197
+#: builtin/am.c:2200 builtin/clone.c:123 builtin/fetch.c:144
+#: builtin/merge.c:273 builtin/pull.c:209 builtin/submodule--helper.c:409
+#: builtin/submodule--helper.c:1379 builtin/submodule--helper.c:1382
+#: builtin/submodule--helper.c:1875 builtin/submodule--helper.c:1878
+#: builtin/submodule--helper.c:2119 git-add--interactive.perl:213
+msgid "path"
+msgstr "路徑"
+
+#: add-interactive.c:1122
+#| msgid "could not read index"
+msgid "could not refresh index"
+msgstr "無法重新整理索引"
+
+#: add-interactive.c:1136 builtin/clean.c:787 git-add--interactive.perl:1765
+#, c-format
+msgid "Bye.\n"
+msgstr "再見。\n"
+
+#: add-patch.c:15
+#, c-format
+#| msgid "Stage mode change [y,n,q,a,d%s,?]? "
+msgid "Stage mode change [y,n,a,q,d%s,?]? "
+msgstr "暫存模式變更 [y,n,a,q,d%s,?]？"
+
+#: add-patch.c:16
+#, c-format
+#| msgid "Stage deletion [y,n,q,a,d%s,?]? "
+msgid "Stage deletion [y,n,a,q,d%s,?]? "
+msgstr "暫存刪除動作 [y,n,a,q,d%s,?]？"
+
+#: add-patch.c:17
+#, c-format
+#| msgid "Stage this hunk [y,n,q,a,d%s,?]? "
+msgid "Stage this hunk [y,n,a,q,d%s,?]? "
+msgstr "暫存此區塊 [y,n,a,q,d%s,?]？"
+
+#: add-patch.c:111
+#, c-format
+#| msgid "could not parse git header '%.*s'"
+msgid "could not parse hunk header '%.*s'"
+msgstr "無法解析區塊標頭 '%.*s'"
+
+#: add-patch.c:130 add-patch.c:134
+#, c-format
+#| msgid "could not parse git header '%.*s'"
+msgid "could not parse colored hunk header '%.*s'"
+msgstr "無法解析上色過的區塊標頭 '%.*s'"
+
+#: add-patch.c:176
+#| msgid "could not parse %s"
+msgid "could not parse diff"
+msgstr "無法解析差異 (diff)"
+
+#: add-patch.c:194
+#| msgid "could not parse commit %s"
+msgid "could not parse colored diff"
+msgstr "無法解析上色過的差異 (diff)"
+
+#: add-patch.c:508
+#, c-format
+#| msgid "bad config line %d in %s"
+msgid ""
+"expected context line #%d in\n"
+"%.*s"
+msgstr ""
+"應有上下文行 #%d 於\n"
+"%.*s"
+
+#: add-patch.c:523
+#, c-format
+msgid ""
+"hunks do not overlap:\n"
+"%.*s\n"
+"\tdoes not end with:\n"
+"%.*s"
+msgstr ""
+"區塊未重疊：\n"
+"%.*s\n"
+"\t不以下述結尾：\n"
+"%.*s"
+
+#: add-patch.c:799 git-add--interactive.perl:1112
+msgid "Manual hunk edit mode -- see bottom for a quick guide.\n"
+msgstr "手動區塊編輯模式 -- 檢視底部的快速指南。\n"
+
+#: add-patch.c:803
+#, c-format
+#| msgid ""
+#| "---\n"
+#| "To remove '%s' lines, make them ' ' lines (context).\n"
+#| "To remove '%s' lines, delete them.\n"
+#| "Lines starting with %s will be removed.\n"
+msgid ""
+"---\n"
+"To remove '%c' lines, make them ' ' lines (context).\n"
+"To remove '%c' lines, delete them.\n"
+"Lines starting with %c will be removed.\n"
+msgstr ""
+"---\n"
+"要刪除 '%c' 開始的行，使其成為 ' ' 開始的行（上下文）。\n"
+"要刪除 '%c' 開始的行，刪除它們。\n"
+"以 %c 開始的行將被刪除。\n"
+
+#: add-patch.c:810
+#| msgid ""
+#| "If the patch applies cleanly, the edited hunk will immediately be\n"
+#| "marked for staging."
+msgid ""
+"If the patch applies cleanly, the edited hunk will immediately be\n"
+"marked for staging.\n"
+msgstr "如果修補檔能乾淨地套用，編輯塊將立即標記為暫存。\n"
+
+#. TRANSLATORS: 'it' refers to the patch mentioned in the previous messages.
+#: add-patch.c:818 git-add--interactive.perl:1126
+msgid ""
+"If it does not apply cleanly, you will be given an opportunity to\n"
+"edit again.  If all lines of the hunk are removed, then the edit is\n"
+"aborted and the hunk is left unchanged.\n"
+msgstr ""
+"如果不能乾淨地套用，您將有機會重新編輯。如果此區塊的全部內容刪除，則\n"
+"此次編輯被終止，此區塊不會被修改。\n"
+
+#: add-patch.c:851
+#| msgid "could not parse git header '%.*s'"
+msgid "could not parse hunk header"
+msgstr "無法解析區塊標頭"
+
+#: add-patch.c:895 add-patch.c:1294
+msgid "'git apply --cached' failed"
+msgstr "「git apply --cached」失敗"
+
+#. TRANSLATORS: do not translate [y/n]
+#. The program will only accept that input at this point.
+#. Consider translating (saying "no" discards!) as
+#. (saying "n" for "no" discards!) if the translation
+#. of the word "no" does not start with n.
+#.
+#. TRANSLATORS: do not translate [y/n]
+#. The program will only accept that input
+#. at this point.
+#. Consider translating (saying "no" discards!) as
+#. (saying "n" for "no" discards!) if the translation
+#. of the word "no" does not start with n.
+#: add-patch.c:952 git-add--interactive.perl:1239
+msgid ""
+"Your edited hunk does not apply. Edit again (saying \"no\" discards!) [y/n]? "
+msgstr "您的編輯塊不能被應用。重新編輯（選擇 \"no\" 捨棄！） [y/n]? "
+
+#: add-patch.c:1009
+#| msgid ""
+#| "y - stage this hunk\n"
+#| "n - do not stage this hunk\n"
+#| "q - quit; do not stage this hunk or any of the remaining ones\n"
+#| "a - stage this hunk and all later hunks in the file\n"
+#| "d - do not stage this hunk or any of the later hunks in the file"
+msgid ""
+"y - stage this hunk\n"
+"n - do not stage this hunk\n"
+"q - quit; do not stage this hunk or any of the remaining ones\n"
+"a - stage this and all the remaining hunks\n"
+"d - do not stage this hunk nor any of the remaining hunks\n"
+msgstr ""
+"y - 暫存此區塊\n"
+"n - 不要暫存此區塊\n"
+"q - 離開。不暫存此區塊及後面的全部區塊\n"
+"a - 暫存這個區塊及所有剩餘區塊\n"
+"d - 不暫存這個區塊及任何剩餘區塊\n"
+
+#: add-patch.c:1016
+#| msgid ""
+#| "g - select a hunk to go to\n"
+#| "/ - search for a hunk matching the given regex\n"
+#| "j - leave this hunk undecided, see next undecided hunk\n"
+#| "J - leave this hunk undecided, see next hunk\n"
+#| "k - leave this hunk undecided, see previous undecided hunk\n"
+#| "K - leave this hunk undecided, see previous hunk\n"
+#| "s - split the current hunk into smaller hunks\n"
+#| "e - manually edit the current hunk\n"
+#| "? - print help\n"
+msgid ""
+"j - leave this hunk undecided, see next undecided hunk\n"
+"J - leave this hunk undecided, see next hunk\n"
+"k - leave this hunk undecided, see previous undecided hunk\n"
+"K - leave this hunk undecided, see previous hunk\n"
+"g - select a hunk to go to\n"
+"/ - search for a hunk matching the given regex\n"
+"s - split the current hunk into smaller hunks\n"
+"e - manually edit the current hunk\n"
+"? - print help\n"
+msgstr ""
+"j - 維持此區塊未決狀態，檢視下一個未決定區塊\n"
+"J - 維持此區塊未決狀態，檢視下一個區塊\n"
+"k - 維持此區塊未決狀態，檢視上一個未決定區塊\n"
+"K - 維持此區塊未決狀態，檢視上一個區塊\n"
+"g - 選擇要跳轉至的區塊\n"
+"/ - 尋找符合提供之正規表示式的區塊\n"
+"s - 分割目前區塊為更小的區塊\n"
+"e - 手動編輯目前區塊\n"
+"? - 顯示說明\n"
+
+#: add-patch.c:1137 add-patch.c:1147
+#| msgid "No previous hunk\n"
+msgid "No previous hunk"
+msgstr "沒有上一個區塊"
+
+#: add-patch.c:1142 add-patch.c:1152
+#| msgid "No next hunk\n"
+msgid "No next hunk"
+msgstr "沒有下一個區塊"
+
+#: add-patch.c:1158
+#| msgid "No other hunks to goto\n"
+msgid "No other hunks to goto"
+msgstr "沒有其它可供跳轉的區塊"
+
+#: add-patch.c:1169 git-add--interactive.perl:1577
+msgid "go to which hunk (<ret> to see more)? "
+msgstr "跳轉到哪個區塊（<Enter> 檢視更多）？ "
+
+#: add-patch.c:1170 git-add--interactive.perl:1579
+msgid "go to which hunk? "
+msgstr "跳轉到哪個區塊？"
+
+#: add-patch.c:1181
+#, c-format
+#| msgid "Invalid number: '%s'\n"
+msgid "Invalid number: '%s'"
+msgstr "無效數字：'%s'"
+
+#: add-patch.c:1186
+#, c-format
+#| msgid "Sorry, only %d hunk available.\n"
+#| msgid_plural "Sorry, only %d hunks available.\n"
+msgid "Sorry, only %d hunk available."
+msgid_plural "Sorry, only %d hunks available."
+msgstr[0] "對不起，只有 %d 個可用區塊。"
+msgstr[1] "對不起，只有 %d 個可用區塊。"
+
+#: add-patch.c:1195
+#| msgid "No other hunks to search\n"
+msgid "No other hunks to search"
+msgstr "沒有其它可供尋找的區塊"
+
+#: add-patch.c:1201 git-add--interactive.perl:1623
+msgid "search for regex? "
+msgstr "使用正規表示式搜尋？"
+
+#: add-patch.c:1216
+#, c-format
+#| msgid "Malformed search regexp %s: %s\n"
+msgid "Malformed search regexp %s: %s"
+msgstr "錯誤的正規表示式 %s：%s"
+
+#: add-patch.c:1233
+#| msgid "No hunk matches the given pattern\n"
+msgid "No hunk matches the given pattern"
+msgstr "沒有和提供模式相符合的區塊"
+
+#: add-patch.c:1240
+#| msgid "Sorry, cannot split this hunk\n"
+msgid "Sorry, cannot split this hunk"
+msgstr "對不起，不能分割這個區塊"
+
+#: add-patch.c:1244
+#, c-format
+#| msgid "Split into %d hunk.\n"
+#| msgid_plural "Split into %d hunks.\n"
+msgid "Split into %d hunks."
+msgstr "分割為 %d 塊。"
+
+#: add-patch.c:1248
+#| msgid "Sorry, cannot edit this hunk\n"
+msgid "Sorry, cannot edit this hunk"
+msgstr "對不起，不能編輯這個區塊"
+
+#: advice.c:111
+#, c-format
+msgid "%shint: %.*s%s\n"
+msgstr "%s提示：%.*s%s\n"
+
+#: advice.c:164
+msgid "Cherry-picking is not possible because you have unmerged files."
+msgstr "無法揀選，因為您有未合併的檔案。"
+
+#: advice.c:166
+msgid "Committing is not possible because you have unmerged files."
+msgstr "無法提交，因為您有未合併的檔案。"
+
+#: advice.c:168
+msgid "Merging is not possible because you have unmerged files."
+msgstr "無法合併，因為您有未合併的檔案。"
+
+#: advice.c:170
+msgid "Pulling is not possible because you have unmerged files."
+msgstr "無法拉取，因為您有未合併的檔案。"
+
+#: advice.c:172
+msgid "Reverting is not possible because you have unmerged files."
+msgstr "無法還原提交，因為您有未合併的檔案。"
+
+#: advice.c:174
+#, c-format
+msgid "It is not possible to %s because you have unmerged files."
+msgstr "無法 %s，因為您有未合併的檔案。"
+
+#: advice.c:182
+msgid ""
+"Fix them up in the work tree, and then use 'git add/rm <file>'\n"
+"as appropriate to mark resolution and make a commit."
+msgstr ""
+"請在工作區改正檔案，然後酌情使用 'git add/rm <檔案>' 指令標記\n"
+"解決方案並提交。"
+
+#: advice.c:190
+msgid "Exiting because of an unresolved conflict."
+msgstr "因為存在未解決的衝突而離開。"
+
+#: advice.c:195 builtin/merge.c:1332
+msgid "You have not concluded your merge (MERGE_HEAD exists)."
+msgstr "您尚未結束您的合併（存在 MERGE_HEAD）。"
+
+#: advice.c:197
+msgid "Please, commit your changes before merging."
+msgstr "請在合併前先提交您的修改。"
+
+#: advice.c:198
+msgid "Exiting because of unfinished merge."
+msgstr "因為存在未完成的合併而離開。"
+
+#: advice.c:204
+#, c-format
+msgid ""
+"Note: switching to '%s'.\n"
+"\n"
+"You are in 'detached HEAD' state. You can look around, make experimental\n"
+"changes and commit them, and you can discard any commits you make in this\n"
+"state without impacting any branches by switching back to a branch.\n"
+"\n"
+"If you want to create a new branch to retain commits you create, you may\n"
+"do so (now or later) by using -c with the switch command. Example:\n"
+"\n"
+"  git switch -c <new-branch-name>\n"
+"\n"
+"Or undo this operation with:\n"
+"\n"
+"  git switch -\n"
+"\n"
+"Turn off this advice by setting config variable advice.detachedHead to "
+"false\n"
+"\n"
+msgstr ""
+"注意：正在切換到 '%s'。\n"
+"\n"
+"您正處於分離開頭指標狀態。您可以檢視、做實驗性的修改及提交，並且您可以在切"
+"換\n"
+"回一個分支時，捨棄在此狀態下所做的提交而不對分支造成影響。\n"
+"\n"
+"如果您想要透過建立分支來保留在此狀態下所做的提交，您可以透過在 switch 指令\n"
+"中新增參數 -c 來實現（現在或稍後）。例如：\n"
+"\n"
+"  git switch -c <新分支名>\n"
+"\n"
+"或者復原此動作：\n"
+"\n"
+"  git switch -\n"
+"\n"
+"透過將設定變數 advice.detachedHead 設定為 false 來關閉此建議\n"
+"\n"
+
+#: alias.c:50
+msgid "cmdline ends with \\"
+msgstr "指令列以 \\ 結尾"
+
+#: alias.c:51
+msgid "unclosed quote"
+msgstr "未閉合的引號"
+
+#: apply.c:69
+#, c-format
+msgid "unrecognized whitespace option '%s'"
+msgstr "未能識別的空白字元選項 '%s'"
+
+#: apply.c:85
+#, c-format
+msgid "unrecognized whitespace ignore option '%s'"
+msgstr "未能識別的空白字元忽略選項 '%s'"
+
+#: apply.c:135
+msgid "--reject and --3way cannot be used together."
+msgstr "--reject 和 --3way 不能同時使用。"
+
+#: apply.c:137
+msgid "--cached and --3way cannot be used together."
+msgstr "--cached 和 --3way 不能同時使用。"
+
+#: apply.c:140
+msgid "--3way outside a repository"
+msgstr "--3way 在版本庫之外"
+
+#: apply.c:151
+msgid "--index outside a repository"
+msgstr "--index 在版本庫之外"
+
+#: apply.c:154
+msgid "--cached outside a repository"
+msgstr "--cached 在版本庫之外"
+
+#: apply.c:801
+#, c-format
+msgid "Cannot prepare timestamp regexp %s"
+msgstr "無法準備時間戳正規表示式 %s"
+
+#: apply.c:810
+#, c-format
+msgid "regexec returned %d for input: %s"
+msgstr "regexec 返回 %d，輸入為：%s"
+
+#: apply.c:884
+#, c-format
+msgid "unable to find filename in patch at line %d"
+msgstr "不能在修補檔的第 %d 行找到檔案名"
+
+#: apply.c:922
+#, c-format
+msgid "git apply: bad git-diff - expected /dev/null, got %s on line %d"
+msgstr "git apply：錯誤的 git-diff - 應為 /dev/null，但在第 %2$d 行得到 %1$s"
+
+#: apply.c:928
+#, c-format
+msgid "git apply: bad git-diff - inconsistent new filename on line %d"
+msgstr "git apply：錯誤的 git-diff - 第 %d 行上新檔案名不一致"
+
+#: apply.c:929
+#, c-format
+msgid "git apply: bad git-diff - inconsistent old filename on line %d"
+msgstr "git apply：錯誤的 git-diff - 第 %d 行上舊檔案名不一致"
+
+#: apply.c:934
+#, c-format
+msgid "git apply: bad git-diff - expected /dev/null on line %d"
+msgstr "git apply：錯誤的 git-diff - 第 %d 行處應為 /dev/null"
+
+#: apply.c:963
+#, c-format
+msgid "invalid mode on line %d: %s"
+msgstr "第 %d 行包含無效檔案模式：%s"
+
+#: apply.c:1282
+#, c-format
+msgid "inconsistent header lines %d and %d"
+msgstr "不一致的檔案頭，%d 行和 %d 行"
+
+#: apply.c:1372
+#, c-format
+msgid ""
+"git diff header lacks filename information when removing %d leading pathname "
+"component (line %d)"
+msgid_plural ""
+"git diff header lacks filename information when removing %d leading pathname "
+"components (line %d)"
+msgstr[0] "當移除 %d 個前導路徑後 git diff 頭缺乏檔案名訊息（第 %d 行）"
+msgstr[1] "當移除 %d 個前導路徑後 git diff 頭缺乏檔案名訊息（第 %d 行）"
+
+#: apply.c:1385
+#, c-format
+msgid "git diff header lacks filename information (line %d)"
+msgstr "git diff 的標頭訊息中缺乏檔案名訊息（第 %d 行）"
+
+#: apply.c:1481
+#, c-format
+msgid "recount: unexpected line: %.*s"
+msgstr "recount：意外的行：%.*s"
+
+#: apply.c:1550
+#, c-format
+msgid "patch fragment without header at line %d: %.*s"
+msgstr "第 %d 行的修補檔片段沒有標頭訊息：%.*s"
+
+#: apply.c:1753
+msgid "new file depends on old contents"
+msgstr "新檔案依賴舊內容"
+
+#: apply.c:1755
+msgid "deleted file still has contents"
+msgstr "刪除的檔案仍有內容"
+
+#: apply.c:1789
+#, c-format
+msgid "corrupt patch at line %d"
+msgstr "修補檔在第 %d 行發現損壞"
+
+#: apply.c:1826
+#, c-format
+msgid "new file %s depends on old contents"
+msgstr "新檔案 %s 依賴舊內容"
+
+#: apply.c:1828
+#, c-format
+msgid "deleted file %s still has contents"
+msgstr "刪除的檔案 %s 仍有內容"
+
+#: apply.c:1831
+#, c-format
+msgid "** warning: file %s becomes empty but is not deleted"
+msgstr "** 警告：檔案 %s 成為空檔案但並未刪除"
+
+#: apply.c:1978
+#, c-format
+msgid "corrupt binary patch at line %d: %.*s"
+msgstr "二進位修補檔在第 %d 行損壞：%.*s"
+
+#: apply.c:2015
+#, c-format
+msgid "unrecognized binary patch at line %d"
+msgstr "未能識別的二進位修補檔位於第 %d 行"
+
+#: apply.c:2177
+#, c-format
+msgid "patch with only garbage at line %d"
+msgstr "修補檔案的第 %d 行只有垃圾資料"
+
+#: apply.c:2263
+#, c-format
+msgid "unable to read symlink %s"
+msgstr "無法讀取符號連結 %s"
+
+#: apply.c:2267
+#, c-format
+msgid "unable to open or read %s"
+msgstr "不能開啟或讀取 %s"
+
+#: apply.c:2936
+#, c-format
+msgid "invalid start of line: '%c'"
+msgstr "無效的行首字元：'%c'"
+
+#: apply.c:3057
+#, c-format
+msgid "Hunk #%d succeeded at %d (offset %d line)."
+msgid_plural "Hunk #%d succeeded at %d (offset %d lines)."
+msgstr[0] "區塊 #%d 成功套用於 %d（位移 %d 行）"
+msgstr[1] "區塊 #%d 成功套用於 %d（位移 %d 行）"
+
+#: apply.c:3069
+#, c-format
+msgid "Context reduced to (%ld/%ld) to apply fragment at %d"
+msgstr "上下文減少到（%ld/%ld）以在第 %d 行套用修補檔片段"
+
+#: apply.c:3075
+#, c-format
+msgid ""
+"while searching for:\n"
+"%.*s"
+msgstr ""
+"當查詢：\n"
+"%.*s"
+
+#: apply.c:3097
+#, c-format
+msgid "missing binary patch data for '%s'"
+msgstr "缺少 '%s' 的二進位修補檔資料"
+
+#: apply.c:3105
+#, c-format
+msgid "cannot reverse-apply a binary patch without the reverse hunk to '%s'"
+msgstr "不能反向套用一個缺少到 '%s' 的反向資料區塊的二進位修補檔"
+
+#: apply.c:3152
+#, c-format
+msgid "cannot apply binary patch to '%s' without full index line"
+msgstr "不能在 '%s' 上套用沒有完整索引行的二進位修補檔"
+
+#: apply.c:3162
+#, c-format
+msgid ""
+"the patch applies to '%s' (%s), which does not match the current contents."
+msgstr "修補檔套用到 '%s'（%s），但是和目前內容不符合。"
+
+#: apply.c:3170
+#, c-format
+msgid "the patch applies to an empty '%s' but it is not empty"
+msgstr "修補檔套用到空檔案 '%s'，但其並非空檔案"
+
+#: apply.c:3188
+#, c-format
+msgid "the necessary postimage %s for '%s' cannot be read"
+msgstr "無法讀取 '%2$s' 必需的目標檔案 %1$s"
+
+#: apply.c:3201
+#, c-format
+msgid "binary patch does not apply to '%s'"
+msgstr "二進位修補檔未套用到 '%s'"
+
+#: apply.c:3207
+#, c-format
+msgid "binary patch to '%s' creates incorrect result (expecting %s, got %s)"
+msgstr "到 '%s' 的二進位修補檔產生了不正確的結果（應為 %s，卻為 %s）"
+
+#: apply.c:3228
+#, c-format
+msgid "patch failed: %s:%ld"
+msgstr "打修補檔失敗：%s:%ld"
+
+#: apply.c:3351
+#, c-format
+msgid "cannot checkout %s"
+msgstr "不能簽出 %s"
+
+#: apply.c:3403 apply.c:3414 apply.c:3460 midx.c:61 setup.c:280
+#, c-format
+msgid "failed to read %s"
+msgstr "無法讀取 %s"
+
+#: apply.c:3411
+#, c-format
+msgid "reading from '%s' beyond a symbolic link"
+msgstr "讀取位於符號連結中的 '%s'"
+
+#: apply.c:3440 apply.c:3683
+#, c-format
+msgid "path %s has been renamed/deleted"
+msgstr "路徑 %s 已經被重新命名/刪除"
+
+#: apply.c:3526 apply.c:3698
+#, c-format
+msgid "%s: does not exist in index"
+msgstr "%s：不存在於索引中"
+
+#: apply.c:3535 apply.c:3706
+#, c-format
+msgid "%s: does not match index"
+msgstr "%s：和索引不符合"
+
+#: apply.c:3570
+msgid "repository lacks the necessary blob to fall back on 3-way merge."
+msgstr "版本庫缺乏必要的資料物件以進行三方合併。"
+
+#: apply.c:3573
+#, c-format
+msgid "Falling back to three-way merge...\n"
+msgstr "回落到三方合併...\n"
+
+#: apply.c:3589 apply.c:3593
+#, c-format
+msgid "cannot read the current contents of '%s'"
+msgstr "無法讀取 '%s' 的目前內容"
+
+#: apply.c:3605
+#, c-format
+msgid "Failed to fall back on three-way merge...\n"
+msgstr "無法回落到三方合併...\n"
+
+#: apply.c:3619
+#, c-format
+msgid "Applied patch to '%s' with conflicts.\n"
+msgstr "套用修補檔到 '%s' 存在衝突。\n"
+
+#: apply.c:3624
+#, c-format
+msgid "Applied patch to '%s' cleanly.\n"
+msgstr "成功套用修補檔到 '%s'。\n"
+
+#: apply.c:3650
+msgid "removal patch leaves file contents"
+msgstr "移除修補檔仍留下了檔案內容"
+
+#: apply.c:3723
+#, c-format
+msgid "%s: wrong type"
+msgstr "%s：錯誤類型"
+
+#: apply.c:3725
+#, c-format
+msgid "%s has type %o, expected %o"
+msgstr "%s 的類型是 %o，應為 %o"
+
+#: apply.c:3876 apply.c:3878 read-cache.c:830 read-cache.c:856
+#: read-cache.c:1320
+#, c-format
+msgid "invalid path '%s'"
+msgstr "無效路徑 '%s'"
+
+#: apply.c:3934
+#, c-format
+msgid "%s: already exists in index"
+msgstr "%s：已經存在於索引中"
+
+#: apply.c:3937
+#, c-format
+msgid "%s: already exists in working directory"
+msgstr "%s：已經存在於工作區中"
+
+#: apply.c:3957
+#, c-format
+msgid "new mode (%o) of %s does not match old mode (%o)"
+msgstr "%2$s 的新模式（%1$o）和舊模式（%3$o）不符合"
+
+#: apply.c:3962
+#, c-format
+msgid "new mode (%o) of %s does not match old mode (%o) of %s"
+msgstr "%2$s 的新模式（%1$o）和 %4$s 的舊模式（%3$o）不符合"
+
+#: apply.c:3982
+#, c-format
+msgid "affected file '%s' is beyond a symbolic link"
+msgstr "受影響的檔案 '%s' 位於符號連結中"
+
+#: apply.c:3986
+#, c-format
+msgid "%s: patch does not apply"
+msgstr "%s：修補檔未套用"
+
+#: apply.c:4001
+#, c-format
+msgid "Checking patch %s..."
+msgstr "正在檢查修補檔 %s..."
+
+#: apply.c:4093
+#, c-format
+msgid "sha1 information is lacking or useless for submodule %s"
+msgstr "子模組 %s 的 sha1 訊息缺少或無效"
+
+#: apply.c:4100
+#, c-format
+msgid "mode change for %s, which is not in current HEAD"
+msgstr "%s 的模式變更，但它不在目前 HEAD 中"
+
+#: apply.c:4103
+#, c-format
+msgid "sha1 information is lacking or useless (%s)."
+msgstr "sha1 訊息缺少或無效（%s）。"
+
+#: apply.c:4112
+#, c-format
+msgid "could not add %s to temporary index"
+msgstr "不能在暫時索引中新增 %s"
+
+#: apply.c:4122
+#, c-format
+msgid "could not write temporary index to %s"
+msgstr "不能把暫時索引寫入到 %s"
+
+#: apply.c:4260
+#, c-format
+msgid "unable to remove %s from index"
+msgstr "不能從索引中移除 %s"
+
+#: apply.c:4294
+#, c-format
+msgid "corrupt patch for submodule %s"
+msgstr "子模組 %s 損壞的修補檔"
+
+#: apply.c:4300
+#, c-format
+msgid "unable to stat newly created file '%s'"
+msgstr "不能對建立檔案 '%s' 呼叫 stat"
+
+#: apply.c:4308
+#, c-format
+msgid "unable to create backing store for newly created file %s"
+msgstr "不能為建立檔案 %s 建立後端儲存"
+
+#: apply.c:4314 apply.c:4459
+#, c-format
+msgid "unable to add cache entry for %s"
+msgstr "無法為 %s 新增快取條目"
+
+#: apply.c:4357
+#, c-format
+msgid "failed to write to '%s'"
+msgstr "寫入 '%s' 失敗"
+
+#: apply.c:4361
+#, c-format
+msgid "closing file '%s'"
+msgstr "關閉檔案 '%s'"
+
+#: apply.c:4431
+#, c-format
+msgid "unable to write file '%s' mode %o"
+msgstr "不能寫入檔案 '%s' 權限 %o"
+
+#: apply.c:4529
+#, c-format
+msgid "Applied patch %s cleanly."
+msgstr "成功套用修補檔 %s。"
+
+#: apply.c:4537
+msgid "internal error"
+msgstr "內部錯誤"
+
+#: apply.c:4540
+#, c-format
+msgid "Applying patch %%s with %d reject..."
+msgid_plural "Applying patch %%s with %d rejects..."
+msgstr[0] "套用 %%s 個修補檔，其中 %d 個被拒絕..."
+msgstr[1] "套用 %%s 個修補檔，其中 %d 個被拒絕..."
+
+#: apply.c:4551
+#, c-format
+msgid "truncating .rej filename to %.*s.rej"
+msgstr "截短 .rej 檔案名為 %.*s.rej"
+
+#: apply.c:4559 builtin/fetch.c:901 builtin/fetch.c:1192
+#, c-format
+msgid "cannot open %s"
+msgstr "不能開啟 %s"
+
+#: apply.c:4573
+#, c-format
+msgid "Hunk #%d applied cleanly."
+msgstr "第 #%d 個片段成功應用。"
+
+#: apply.c:4577
+#, c-format
+msgid "Rejected hunk #%d."
+msgstr "拒絕第 #%d 個片段。"
+
+#: apply.c:4696
+#, c-format
+msgid "Skipped patch '%s'."
+msgstr "略過修補檔 '%s'。"
+
+#: apply.c:4704
+msgid "unrecognized input"
+msgstr "未能識別的輸入"
+
+#: apply.c:4724
+msgid "unable to read index file"
+msgstr "無法讀取索引檔案"
+
+#: apply.c:4881
+#, c-format
+msgid "can't open patch '%s': %s"
+msgstr "不能開啟修補檔 '%s'：%s"
+
+#: apply.c:4908
+#, c-format
+msgid "squelched %d whitespace error"
+msgid_plural "squelched %d whitespace errors"
+msgstr[0] "抑制下仍有 %d 個空白字元誤用"
+msgstr[1] "抑制下仍有 %d 個空白字元誤用"
+
+#: apply.c:4914 apply.c:4929
+#, c-format
+msgid "%d line adds whitespace errors."
+msgid_plural "%d lines add whitespace errors."
+msgstr[0] "%d 行新增了空白字元誤用。"
+msgstr[1] "%d 行新增了空白字元誤用。"
+
+#: apply.c:4922
+#, c-format
+msgid "%d line applied after fixing whitespace errors."
+msgid_plural "%d lines applied after fixing whitespace errors."
+msgstr[0] "修復空白錯誤後，應用了 %d 行。"
+msgstr[1] "修復空白錯誤後，應用了 %d 行。"
+
+#: apply.c:4938 builtin/add.c:579 builtin/mv.c:301 builtin/rm.c:390
+msgid "Unable to write new index file"
+msgstr "無法寫入新索引檔案"
+
+#: apply.c:4966
+msgid "don't apply changes matching the given path"
+msgstr "不要應用與給出路徑向符合的變更"
+
+#: apply.c:4969
+msgid "apply changes matching the given path"
+msgstr "應用與給出路徑向符合的變更"
+
+#: apply.c:4971 builtin/am.c:2206
+msgid "num"
+msgstr "數字"
+
+#: apply.c:4972
+msgid "remove <num> leading slashes from traditional diff paths"
+msgstr "從傳統的 diff 路徑中移除指定數量的前導斜線"
+
+#: apply.c:4975
+msgid "ignore additions made by the patch"
+msgstr "忽略修補檔中的新增的檔案"
+
+#: apply.c:4977
+msgid "instead of applying the patch, output diffstat for the input"
+msgstr "不套用修補檔，而是顯示輸入的差異統計（diffstat）"
+
+#: apply.c:4981
+msgid "show number of added and deleted lines in decimal notation"
+msgstr "以十進位數顯示新增和刪除的行數"
+
+#: apply.c:4983
+msgid "instead of applying the patch, output a summary for the input"
+msgstr "不套用修補檔，而是顯示輸入的概要"
+
+#: apply.c:4985
+msgid "instead of applying the patch, see if the patch is applicable"
+msgstr "不套用修補檔，而是檢視修補檔是否可應用"
+
+#: apply.c:4987
+msgid "make sure the patch is applicable to the current index"
+msgstr "確認修補檔可以套用到目前索引"
+
+#: apply.c:4989
+msgid "mark new files with `git add --intent-to-add`"
+msgstr "使用指令 `git add --intent-to-add` 標記新增檔案"
+
+#: apply.c:4991
+msgid "apply a patch without touching the working tree"
+msgstr "套用修補檔而不修改工作區"
+
+#: apply.c:4993
+msgid "accept a patch that touches outside the working area"
+msgstr "接受修改工作區之外檔案的修補檔"
+
+#: apply.c:4996
+msgid "also apply the patch (use with --stat/--summary/--check)"
+msgstr "還套用此修補檔（與 --stat/--summary/--check 選項同時使用）"
+
+#: apply.c:4998
+msgid "attempt three-way merge if a patch does not apply"
+msgstr "如果一個修補檔不能應用則嘗試三方合併"
+
+#: apply.c:5000
+msgid "build a temporary index based on embedded index information"
+msgstr "建立一個暫時索引基於嵌入的索引訊息"
+
+#: apply.c:5003 builtin/checkout-index.c:173 builtin/ls-files.c:524
+msgid "paths are separated with NUL character"
+msgstr "路徑以 NUL 字元分隔"
+
+#: apply.c:5005
+msgid "ensure at least <n> lines of context match"
+msgstr "確保至少符合 <n> 行上下文"
+
+#: apply.c:5006 builtin/am.c:2185 builtin/interpret-trailers.c:98
+#: builtin/interpret-trailers.c:100 builtin/interpret-trailers.c:102
+#: builtin/pack-objects.c:3310 builtin/rebase.c:1474
+msgid "action"
+msgstr "動作"
+
+#: apply.c:5007
+msgid "detect new or modified lines that have whitespace errors"
+msgstr "檢查新增和修改的行中間的空白字元濫用"
+
+#: apply.c:5010 apply.c:5013
+msgid "ignore changes in whitespace when finding context"
+msgstr "尋找上下文時忽略空白字元的變更"
+
+#: apply.c:5016
+msgid "apply the patch in reverse"
+msgstr "反向套用修補檔"
+
+#: apply.c:5018
+msgid "don't expect at least one line of context"
+msgstr "無需至少一行上下文"
+
+#: apply.c:5020
+msgid "leave the rejected hunks in corresponding *.rej files"
+msgstr "將拒絕的修補檔片段儲存在對應的 *.rej 檔案中"
+
+#: apply.c:5022
+msgid "allow overlapping hunks"
+msgstr "允許重疊的修補檔片段"
+
+#: apply.c:5023 builtin/add.c:309 builtin/check-ignore.c:22
+#: builtin/commit.c:1355 builtin/count-objects.c:98 builtin/fsck.c:774
+#: builtin/log.c:2166 builtin/mv.c:123 builtin/read-tree.c:128
+msgid "be verbose"
+msgstr "詳細輸出"
+
+#: apply.c:5025
+msgid "tolerate incorrectly detected missing new-line at the end of file"
+msgstr "允許不正確的檔案末尾換行符號"
+
+#: apply.c:5028
+msgid "do not trust the line counts in the hunk headers"
+msgstr "不信任修補檔片段的標頭訊息中的行號"
+
+#: apply.c:5030 builtin/am.c:2194
+msgid "root"
+msgstr "根目錄"
+
+#: apply.c:5031
+msgid "prepend <root> to all filenames"
+msgstr "為所有檔案名前新增 <根目錄>"
+
+#: archive.c:14
+msgid "git archive [<options>] <tree-ish> [<path>...]"
+msgstr "git archive [<選項>] <樹或提交> [<路徑>...]"
+
+#: archive.c:15
+msgid "git archive --list"
+msgstr "git archive --list"
+
+#: archive.c:16
+msgid ""
+"git archive --remote <repo> [--exec <cmd>] [<options>] <tree-ish> [<path>...]"
+msgstr "git archive --remote <版本庫> [--exec <指令>] [<選項>] <樹或提交> [<路徑>...]"
+
+#: archive.c:17
+msgid "git archive --remote <repo> [--exec <cmd>] --list"
+msgstr "git archive --remote <版本庫> [--exec <指令>] --list"
+
+#: archive.c:372 builtin/add.c:180 builtin/add.c:555 builtin/rm.c:299
+#, c-format
+msgid "pathspec '%s' did not match any files"
+msgstr "路徑規格 '%s' 未符合任何檔案"
+
+#: archive.c:396
+#, c-format
+msgid "no such ref: %.*s"
+msgstr "無此引用：%.*s"
+
+#: archive.c:401
+#, c-format
+msgid "not a valid object name: %s"
+msgstr "不是一個有效的物件名：%s"
+
+#: archive.c:414
+#, c-format
+msgid "not a tree object: %s"
+msgstr "不是一個樹狀物件：%s"
+
+#: archive.c:426
+msgid "current working directory is untracked"
+msgstr "目前工作目錄未被追蹤"
+
+#: archive.c:457
+msgid "fmt"
+msgstr "格式"
+
+#: archive.c:457
+msgid "archive format"
+msgstr "歸檔格式"
+
+#: archive.c:458 builtin/log.c:1653
+msgid "prefix"
+msgstr "前綴"
+
+#: archive.c:459
+msgid "prepend prefix to each pathname in the archive"
+msgstr "為歸檔中每個路徑名加上前綴"
+
+#: archive.c:460 builtin/blame.c:861 builtin/blame.c:865 builtin/blame.c:866
+#: builtin/commit-tree.c:117 builtin/config.c:129 builtin/fast-export.c:1162
+#: builtin/fast-export.c:1164 builtin/fast-export.c:1168 builtin/grep.c:899
+#: builtin/hash-object.c:105 builtin/ls-files.c:560 builtin/ls-files.c:563
+#: builtin/notes.c:412 builtin/notes.c:578 builtin/read-tree.c:123
+#: parse-options.h:190
+msgid "file"
+msgstr "檔案"
+
+#: archive.c:461 builtin/archive.c:90
+msgid "write the archive to this file"
+msgstr "歸檔寫入此檔案"
+
+#: archive.c:463
+msgid "read .gitattributes in working directory"
+msgstr "讀取工作區中的 .gitattributes"
+
+#: archive.c:464
+msgid "report archived files on stderr"
+msgstr "在標準錯誤上報告歸檔檔案"
+
+#: archive.c:465
+msgid "store only"
+msgstr "只儲存"
+
+#: archive.c:466
+msgid "compress faster"
+msgstr "壓縮速度更快"
+
+#: archive.c:474
+msgid "compress better"
+msgstr "壓縮效果更好"
+
+#: archive.c:477
+msgid "list supported archive formats"
+msgstr "列出支援的歸檔格式"
+
+#: archive.c:479 builtin/archive.c:91 builtin/clone.c:113 builtin/clone.c:116
+#: builtin/submodule--helper.c:1391 builtin/submodule--helper.c:1884
+msgid "repo"
+msgstr "版本庫"
+
+#: archive.c:480 builtin/archive.c:92
+msgid "retrieve the archive from remote repository <repo>"
+msgstr "從遠端版本庫（<版本庫>）擷取歸檔檔案"
+
+#: archive.c:481 builtin/archive.c:93 builtin/difftool.c:715
+#: builtin/notes.c:498
+msgid "command"
+msgstr "指令"
+
+#: archive.c:482 builtin/archive.c:94
+msgid "path to the remote git-upload-archive command"
+msgstr "遠端 git-upload-archive 指令的路徑"
+
+#: archive.c:489
+msgid "Unexpected option --remote"
+msgstr "未知參數 --remote"
+
+#: archive.c:491
+msgid "Option --exec can only be used together with --remote"
+msgstr "選項 --exec 只能和 --remote 同時使用"
+
+#: archive.c:493
+msgid "Unexpected option --output"
+msgstr "未知參數 --output"
+
+#: archive.c:515
+#, c-format
+msgid "Unknown archive format '%s'"
+msgstr "未知歸檔格式 '%s'"
+
+#: archive.c:522
+#, c-format
+msgid "Argument not supported for format '%s': -%d"
+msgstr "參數不支援此格式 '%s'：-%d"
+
+#: archive-tar.c:125 archive-zip.c:350
+#, c-format
+msgid "cannot stream blob %s"
+msgstr "不能開啟資料物件 %s"
+
+#: archive-tar.c:266 archive-zip.c:368
+#, c-format
+msgid "unsupported file mode: 0%o (SHA1: %s)"
+msgstr "不支援的檔案模式：0%o (SHA1: %s)"
+
+#: archive-tar.c:293 archive-zip.c:358
+#, c-format
+msgid "cannot read %s"
+msgstr "不能讀取 %s"
+
+#: archive-tar.c:465
+#, c-format
+msgid "unable to start '%s' filter"
+msgstr "無法啟動 '%s' 過濾器"
+
+#: archive-tar.c:468
+msgid "unable to redirect descriptor"
+msgstr "無法重定向描述符"
+
+#: archive-tar.c:475
+#, c-format
+msgid "'%s' filter reported error"
+msgstr "'%s' 過濾器報告了錯誤"
+
+#: archive-zip.c:319
+#, c-format
+msgid "path is not valid UTF-8: %s"
+msgstr "路徑不是有效的 UTF-8：%s"
+
+#: archive-zip.c:323
+#, c-format
+msgid "path too long (%d chars, SHA1: %s): %s"
+msgstr "路徑太長（%d 字元，SHA1：%s）：%s"
+
+#: archive-zip.c:479 builtin/pack-objects.c:230 builtin/pack-objects.c:233
+#, c-format
+msgid "deflate error (%d)"
+msgstr "壓縮錯誤 (%d)"
+
+#: archive-zip.c:614
+#, c-format
+msgid "timestamp too large for this system: %<PRIuMAX>"
+msgstr "對於本系統時間戳太大：%<PRIuMAX>"
+
+#: attr.c:212
+#, c-format
+msgid "%.*s is not a valid attribute name"
+msgstr "%.*s 不是一個有效的屬性名"
+
+#: attr.c:369
+#, c-format
+msgid "%s not allowed: %s:%d"
+msgstr "不允許 %s：%s:%d"
+
+#: attr.c:409
+msgid ""
+"Negative patterns are ignored in git attributes\n"
+"Use '\\!' for literal leading exclamation."
+msgstr ""
+"反向模式在 git attributes 中被忽略\n"
+"當字串確實要以驚嘆號開始時，使用 '\\!'。"
+
+#: bisect.c:468
+#, c-format
+msgid "Badly quoted content in file '%s': %s"
+msgstr "檔案 '%s' 包含錯誤的引用格式：%s"
+
+#: bisect.c:678
+#, c-format
+msgid "We cannot bisect more!\n"
+msgstr "我們無法進行更多的二分尋找！\n"
+
+#: bisect.c:733
+#, c-format
+msgid "Not a valid commit name %s"
+msgstr "不是一個有效的提交名 %s"
+
+#: bisect.c:758
+#, c-format
+msgid ""
+"The merge base %s is bad.\n"
+"This means the bug has been fixed between %s and [%s].\n"
+msgstr ""
+"合併基礎 %s 是壞的。\n"
+"這意味著介於 %s 和 [%s] 之間的 bug 已經被修復。\n"
+
+#: bisect.c:763
+#, c-format
+msgid ""
+"The merge base %s is new.\n"
+"The property has changed between %s and [%s].\n"
+msgstr ""
+"合併基礎 %s 是新的。\n"
+"介於 %s 和 [%s] 之間的屬性已經被修改。\n"
+
+#: bisect.c:768
+#, c-format
+msgid ""
+"The merge base %s is %s.\n"
+"This means the first '%s' commit is between %s and [%s].\n"
+msgstr ""
+"合併基礎 %s 是 %s。\n"
+"這意味著第一個 '%s' 提交位於 %s 和 [%s] 之間。\n"
+
+#: bisect.c:776
+#, c-format
+msgid ""
+"Some %s revs are not ancestors of the %s rev.\n"
+"git bisect cannot work properly in this case.\n"
+"Maybe you mistook %s and %s revs?\n"
+msgstr ""
+"一些 %s 版本不是 %s 版本的祖先。\n"
+"這種情況下 git 二分尋找無法正常工作。\n"
+"您可能弄錯了 %s 和 %s 版本？\n"
+
+#: bisect.c:789
+#, c-format
+msgid ""
+"the merge base between %s and [%s] must be skipped.\n"
+"So we cannot be sure the first %s commit is between %s and %s.\n"
+"We continue anyway."
+msgstr ""
+"介於 %s 和 [%s] 的合併基礎一定被忽略了。\n"
+"所以我們無法確認第一個 %s 提交是否介於 %s 和 %s 之間。\n"
+"我們仍舊繼續。"
+
+#: bisect.c:822
+#, c-format
+msgid "Bisecting: a merge base must be tested\n"
+msgstr "二分尋找中：合併基礎必須是經過測試的\n"
+
+#: bisect.c:865
+#, c-format
+msgid "a %s revision is needed"
+msgstr "需要一個 %s 版本"
+
+#: bisect.c:884 builtin/notes.c:177 builtin/tag.c:254
+#, c-format
+msgid "could not create file '%s'"
+msgstr "不能建立檔案 '%s'"
+
+#: bisect.c:928 builtin/merge.c:148
+#, c-format
+msgid "could not read file '%s'"
+msgstr "不能讀取檔案 '%s'"
+
+#: bisect.c:958
+msgid "reading bisect refs failed"
+msgstr "讀取二分尋找引用失敗"
+
+#: bisect.c:977
+#, c-format
+msgid "%s was both %s and %s\n"
+msgstr "%s 同時為 %s 和 %s\n"
+
+#: bisect.c:985
+#, c-format
+msgid ""
+"No testable commit found.\n"
+"Maybe you started with bad path parameters?\n"
+msgstr ""
+"沒有發現可測試的提交。\n"
+"可能您在執行時使用了錯誤的路徑參數？\n"
+
+#: bisect.c:1004
+#, c-format
+msgid "(roughly %d step)"
+msgid_plural "(roughly %d steps)"
+msgstr[0] "（大概 %d 步）"
+msgstr[1] "（大概 %d 步）"
+
+#. TRANSLATORS: the last %s will be replaced with "(roughly %d
+#. steps)" translation.
+#.
+#: bisect.c:1010
+#, c-format
+msgid "Bisecting: %d revision left to test after this %s\n"
+msgid_plural "Bisecting: %d revisions left to test after this %s\n"
+msgstr[0] "二分尋找中：在此之後，還剩 %d 個版本待測試 %s\n"
+msgstr[1] "二分尋找中：在此之後，還剩 %d 個版本待測試 %s\n"
+
+#: blame.c:2700
+msgid "--contents and --reverse do not blend well."
+msgstr "--contents 和 --reverse 不能混用。"
+
+#: blame.c:2714
+msgid "cannot use --contents with final commit object name"
+msgstr "不能將 --contents 和最終的提交物件名共用"
+
+#: blame.c:2735
+msgid "--reverse and --first-parent together require specified latest commit"
+msgstr "--reverse 和 --first-parent 共用，需要指定最新的提交"
+
+#: blame.c:2744 bundle.c:167 ref-filter.c:2203 remote.c:1941 sequencer.c:2093
+#: sequencer.c:4460 builtin/commit.c:1040 builtin/log.c:388 builtin/log.c:991
+#: builtin/log.c:1520 builtin/log.c:1925 builtin/log.c:2215 builtin/merge.c:411
+#: builtin/pack-objects.c:3128 builtin/pack-objects.c:3143
+#: builtin/shortlog.c:192
+msgid "revision walk setup failed"
+msgstr "版本遍歷設定失敗"
+
+#: blame.c:2762
+msgid ""
+"--reverse --first-parent together require range along first-parent chain"
+msgstr "--reverse 和 --first-parent 共用，需要第一祖先鏈上的提交範圍"
+
+#: blame.c:2773
+#, c-format
+msgid "no such path %s in %s"
+msgstr "在 %2$s 中無此路徑 %1$s"
+
+#: blame.c:2784
+#, c-format
+msgid "cannot read blob %s for path %s"
+msgstr "不能為路徑 %2$s 讀取資料物件 %1$s"
+
+#: branch.c:53
+#, c-format
+msgid ""
+"\n"
+"After fixing the error cause you may try to fix up\n"
+"the remote tracking information by invoking\n"
+"\"git branch --set-upstream-to=%s%s%s\"."
+msgstr ""
+"\n"
+"在修復錯誤後，您可以嘗試修改遠端追蹤分支，透過執行指令\n"
+"\"git branch --set-upstream-to=%s%s%s\" 。"
+
+#: branch.c:67
+#, c-format
+msgid "Not setting branch %s as its own upstream."
+msgstr "未設定分支 %s 作為它自己的上游。"
+
+#: branch.c:93
+#, c-format
+msgid "Branch '%s' set up to track remote branch '%s' from '%s' by rebasing."
+msgstr "分支 '%1$s' 設定為使用重定基底來追蹤來自 '%3$s' 的遠端分支 '%2$s'。"
+
+#: branch.c:94
+#, c-format
+msgid "Branch '%s' set up to track remote branch '%s' from '%s'."
+msgstr "分支 '%1$s' 設定為追蹤來自 '%3$s' 的遠端分支 '%2$s'。"
+
+#: branch.c:98
+#, c-format
+msgid "Branch '%s' set up to track local branch '%s' by rebasing."
+msgstr "分支 '%s' 設定為使用重定基底來追蹤本機分支 '%s'。"
+
+#: branch.c:99
+#, c-format
+msgid "Branch '%s' set up to track local branch '%s'."
+msgstr "分支 '%s' 設定為追蹤本機分支 '%s'。"
+
+#: branch.c:104
+#, c-format
+msgid "Branch '%s' set up to track remote ref '%s' by rebasing."
+msgstr "分支 '%s' 設定為使用重定基底來追蹤遠端引用 '%s'。"
+
+#: branch.c:105
+#, c-format
+msgid "Branch '%s' set up to track remote ref '%s'."
+msgstr "分支 '%s' 設定為追蹤遠端引用 '%s'。"
+
+#: branch.c:109
+#, c-format
+msgid "Branch '%s' set up to track local ref '%s' by rebasing."
+msgstr "分支 '%s' 設定為使用重定基底來追蹤本機引用 '%s'。"
+
+#: branch.c:110
+#, c-format
+msgid "Branch '%s' set up to track local ref '%s'."
+msgstr "分支 '%s' 設定為追蹤本機引用 '%s'。"
+
+#: branch.c:119
+msgid "Unable to write upstream branch configuration"
+msgstr "無法寫入上游分支設定"
+
+#: branch.c:156
+#, c-format
+msgid "Not tracking: ambiguous information for ref %s"
+msgstr "未追蹤：引用 %s 有歧義"
+
+#: branch.c:189
+#, c-format
+msgid "'%s' is not a valid branch name."
+msgstr "'%s' 不是一個有效的分支名稱。"
+
+#: branch.c:208
+#, c-format
+msgid "A branch named '%s' already exists."
+msgstr "一個分支名 '%s' 已經存在。"
+
+#: branch.c:213
+msgid "Cannot force update the current branch."
+msgstr "無法強制更新目前分支。"
+
+#: branch.c:233
+#, c-format
+msgid "Cannot setup tracking information; starting point '%s' is not a branch."
+msgstr "無法設定追蹤訊息；起始點 '%s' 不是一個分支。"
+
+#: branch.c:235
+#, c-format
+msgid "the requested upstream branch '%s' does not exist"
+msgstr "請求的上游分支 '%s' 不存在"
+
+#: branch.c:237
+msgid ""
+"\n"
+"If you are planning on basing your work on an upstream\n"
+"branch that already exists at the remote, you may need to\n"
+"run \"git fetch\" to retrieve it.\n"
+"\n"
+"If you are planning to push out a new local branch that\n"
+"will track its remote counterpart, you may want to use\n"
+"\"git push -u\" to set the upstream config as you push."
+msgstr ""
+"\n"
+"如果您正計劃基於遠端一個現存的上游分支開始你的工作，\n"
+"您可能需要執行 \"git fetch\" 來取得分支。\n"
+"\n"
+"如果您正計劃推送一個能與對應遠端分支建立追蹤的新的本機分支，\n"
+"您可能需要使用 \"git push -u\" 推送分支並設定和上游的關聯。"
+
+#: branch.c:281
+#, c-format
+msgid "Not a valid object name: '%s'."
+msgstr "不是一個有效的物件名：'%s'。"
+
+#: branch.c:301
+#, c-format
+msgid "Ambiguous object name: '%s'."
+msgstr "歧義的物件名：'%s'。"
+
+#: branch.c:306
+#, c-format
+msgid "Not a valid branch point: '%s'."
+msgstr "無效的分支點：'%s'。"
+
+#: branch.c:364
+#, c-format
+msgid "'%s' is already checked out at '%s'"
+msgstr "'%s' 已經簽出到 '%s'"
+
+#: branch.c:387
+#, c-format
+msgid "HEAD of working tree %s is not updated"
+msgstr "工作區 %s 的 HEAD 指向沒有被更新"
+
+#: bundle.c:36
+#, c-format
+msgid "'%s' does not look like a v2 bundle file"
+msgstr "'%s' 不像是一個 v2 版本的包檔案"
+
+#: bundle.c:64
+#, c-format
+msgid "unrecognized header: %s%s (%d)"
+msgstr "未能識別的包頭：%s%s (%d)"
+
+#: bundle.c:90 rerere.c:480 rerere.c:690 sequencer.c:2344 sequencer.c:3108
+#: builtin/commit.c:811
+#, c-format
+msgid "could not open '%s'"
+msgstr "不能開啟 '%s'"
+
+#: bundle.c:143
+msgid "Repository lacks these prerequisite commits:"
+msgstr "版本庫中缺少這些必備的提交："
+
+#: bundle.c:146
+msgid "need a repository to verify a bundle"
+msgstr "需要版本庫驗證一個包"
+
+#: bundle.c:197
+#, c-format
+msgid "The bundle contains this ref:"
+msgid_plural "The bundle contains these %d refs:"
+msgstr[0] "這個包中含有這個引用："
+msgstr[1] "這個包中含有 %d 個引用："
+
+#: bundle.c:204
+msgid "The bundle records a complete history."
+msgstr "這個包記錄一個完整歷史。"
+
+#: bundle.c:206
+#, c-format
+msgid "The bundle requires this ref:"
+msgid_plural "The bundle requires these %d refs:"
+msgstr[0] "這個包需要這個引用："
+msgstr[1] "這個包需要 %d 個引用："
+
+#: bundle.c:273
+msgid "unable to dup bundle descriptor"
+msgstr "無法複製 bundle 描述符"
+
+#: bundle.c:280
+msgid "Could not spawn pack-objects"
+msgstr "不能生成 pack-objects 進程"
+
+#: bundle.c:291
+msgid "pack-objects died"
+msgstr "pack-objects 終止"
+
+#: bundle.c:333
+msgid "rev-list died"
+msgstr "rev-list 終止"
+
+#: bundle.c:382
+#, c-format
+msgid "ref '%s' is excluded by the rev-list options"
+msgstr "引用 '%s' 被 rev-list 選項排除"
+
+#: bundle.c:461 builtin/log.c:203 builtin/log.c:1814 builtin/shortlog.c:306
+#, c-format
+msgid "unrecognized argument: %s"
+msgstr "未能識別的參數：%s"
+
+#: bundle.c:469
+msgid "Refusing to create empty bundle."
+msgstr "不能建立空包。"
+
+#: bundle.c:479
+#, c-format
+msgid "cannot create '%s'"
+msgstr "不能建立 '%s'"
+
+#: bundle.c:504
+msgid "index-pack died"
+msgstr "index-pack 終止"
+
+#: color.c:296
+#, c-format
+msgid "invalid color value: %.*s"
+msgstr "無效的顏色值：%.*s"
+
+#: commit.c:51 sequencer.c:2811 builtin/am.c:354 builtin/am.c:398
+#: builtin/am.c:1366 builtin/am.c:2009 builtin/replace.c:456
+#, c-format
+msgid "could not parse %s"
+msgstr "不能解析 %s"
+
+#: commit.c:53
+#, c-format
+msgid "%s %s is not a commit!"
+msgstr "%s %s 不是一個提交！"
+
+#: commit.c:193
+msgid ""
+"Support for <GIT_DIR>/info/grafts is deprecated\n"
+"and will be removed in a future Git version.\n"
+"\n"
+"Please use \"git replace --convert-graft-file\"\n"
+"to convert the grafts into replace refs.\n"
+"\n"
+"Turn this message off by running\n"
+"\"git config advice.graftFileDeprecated false\""
+msgstr ""
+"對 <GIT_DIR>/info/grafts 的支援已被棄用，並將在\n"
+"未來的Git版本中被移除。\n"
+"\n"
+"請使用 \"git replace --convert-graft-file\" 將\n"
+"grafts 轉換為取代引用。\n"
+"\n"
+"設定 \"git config advice.graftFileDeprecated false\"\n"
+"可關閉本消息"
+
+#: commit.c:1152
+#, c-format
+msgid "Commit %s has an untrusted GPG signature, allegedly by %s."
+msgstr "提交 %s 有一個非可信的聲稱來自 %s 的 GPG 簽名。"
+
+#: commit.c:1155
+#, c-format
+msgid "Commit %s has a bad GPG signature allegedly by %s."
+msgstr "提交 %s 有一個錯誤的聲稱來自 %s 的 GPG 簽名。"
+
+#: commit.c:1158
+#, c-format
+msgid "Commit %s does not have a GPG signature."
+msgstr "提交 %s 沒有 GPG 簽名。"
+
+#: commit.c:1161
+#, c-format
+msgid "Commit %s has a good GPG signature by %s\n"
+msgstr "提交 %s 有一個來自 %s 的好的 GPG 簽名。\n"
+
+#: commit.c:1415
+msgid ""
+"Warning: commit message did not conform to UTF-8.\n"
+"You may want to amend it after fixing the message, or set the config\n"
+"variable i18n.commitencoding to the encoding your project uses.\n"
+msgstr ""
+"警告：提交說明不符合 UTF-8 字元編碼。\n"
+"您可以透過修補提交來改正提交說明，或者將設定變數 i18n.commitencoding\n"
+"設定為您項目所用的字元編碼。\n"
+
+#: commit-graph.c:130
+msgid "commit-graph file is too small"
+msgstr "提交圖形檔案太小"
+
+#: commit-graph.c:195
+#, c-format
+msgid "commit-graph signature %X does not match signature %X"
+msgstr "提交圖形簽名 %X 和簽名 %X 不符合"
+
+#: commit-graph.c:202
+#, c-format
+msgid "commit-graph version %X does not match version %X"
+msgstr "提交圖形版本 %X 和版本 %X 不符合"
+
+#: commit-graph.c:209
+#, c-format
+msgid "commit-graph hash version %X does not match version %X"
+msgstr "提交圖形雜湊版本 %X 和版本 %X 不符合"
+
+#: commit-graph.c:232
+msgid "commit-graph chunk lookup table entry missing; file may be incomplete"
+msgstr "提交圖形區塊尋找表條目遺失，檔案可能不完整"
+
+#: commit-graph.c:243
+#, c-format
+msgid "commit-graph improper chunk offset %08x%08x"
+msgstr "提交圖形不正確的區塊位移 %08x%08x"
+
+#: commit-graph.c:286
+#, c-format
+msgid "commit-graph chunk id %08x appears multiple times"
+msgstr "提交圖形區塊 id %08x 出現了多次"
+
+#: commit-graph.c:350
+msgid "commit-graph has no base graphs chunk"
+msgstr "提交圖形沒有基礎圖形區塊"
+
+#: commit-graph.c:360
+msgid "commit-graph chain does not match"
+msgstr "提交圖形鏈不符合"
+
+#: commit-graph.c:407
+#, c-format
+msgid "invalid commit-graph chain: line '%s' not a hash"
+msgstr "無效的提交圖形鏈：行 '%s' 不是一個雜湊值"
+
+#: commit-graph.c:433
+msgid "unable to find all commit-graph files"
+msgstr "無法找到所有提交圖形檔案"
+
+#: commit-graph.c:564 commit-graph.c:624
+msgid "invalid commit position. commit-graph is likely corrupt"
+msgstr "無效的提交位置。提交圖形可能已損壞"
+
+#: commit-graph.c:585
+#, c-format
+msgid "could not find commit %s"
+msgstr "無法找到提交 %s"
+
+#: commit-graph.c:858 builtin/am.c:1287
+#, c-format
+msgid "unable to parse commit %s"
+msgstr "不能解析提交 %s"
+
+#: commit-graph.c:1017 builtin/pack-objects.c:2641
+#, c-format
+msgid "unable to get type of object %s"
+msgstr "無法獲得物件 %s 類型"
+
+#: commit-graph.c:1049
+msgid "Loading known commits in commit graph"
+msgstr "正在載入提交圖中的已知提交"
+
+#: commit-graph.c:1066
+msgid "Expanding reachable commits in commit graph"
+msgstr "正在擴展提交圖中的可以取得提交"
+
+#: commit-graph.c:1085
+msgid "Clearing commit marks in commit graph"
+msgstr "正在清除提交圖中的提交標記"
+
+#: commit-graph.c:1104
+msgid "Computing commit graph generation numbers"
+msgstr "正在計算提交圖世代數字"
+
+#: commit-graph.c:1179
+#, c-format
+msgid "Finding commits for commit graph in %d pack"
+msgid_plural "Finding commits for commit graph in %d packs"
+msgstr[0] "正在 %d 個包中尋找提交圖的提交"
+msgstr[1] "正在 %d 個包中尋找提交圖的提交"
+
+#: commit-graph.c:1192
+#, c-format
+msgid "error adding pack %s"
+msgstr "新增包 %s 發生錯誤"
+
+#: commit-graph.c:1196
+#, c-format
+msgid "error opening index for %s"
+msgstr "為 %s 開啟索引發生錯誤"
+
+#: commit-graph.c:1220
+#, c-format
+msgid "Finding commits for commit graph from %d ref"
+msgid_plural "Finding commits for commit graph from %d refs"
+msgstr[0] "正在從 %d 個引用中尋找提交圖的提交"
+msgstr[1] "正在從 %d 個引用中尋找提交圖的提交"
+
+#: commit-graph.c:1240
+#, c-format
+msgid "invalid commit object id: %s"
+msgstr "無效的提交物件 ID：%s"
+
+#: commit-graph.c:1255
+msgid "Finding commits for commit graph among packed objects"
+msgstr "正在打包物件中尋找提交圖的提交"
+
+#: commit-graph.c:1270
+msgid "Counting distinct commits in commit graph"
+msgstr "正在計算提交圖中不同的提交"
+
+#: commit-graph.c:1300
+msgid "Finding extra edges in commit graph"
+msgstr "正在尋找提交圖中額外的邊"
+
+#: commit-graph.c:1346
+msgid "failed to write correct number of base graph ids"
+msgstr "無法寫入正確數量的基礎圖形 ID"
+
+#: commit-graph.c:1379 midx.c:814
+#, c-format
+msgid "unable to create leading directories of %s"
+msgstr "不能為 %s 建立先導目錄"
+
+#: commit-graph.c:1391 builtin/index-pack.c:306 builtin/repack.c:248
+#, c-format
+msgid "unable to create '%s'"
+msgstr "不能建立 '%s'"
+
+#: commit-graph.c:1451
+#, c-format
+msgid "Writing out commit graph in %d pass"
+msgid_plural "Writing out commit graph in %d passes"
+msgstr[0] "正在用 %d 步寫出提交圖"
+msgstr[1] "正在用 %d 步寫出提交圖"
+
+#: commit-graph.c:1492
+msgid "unable to open commit-graph chain file"
+msgstr "無法開啟提交圖形鏈檔案"
+
+#: commit-graph.c:1504
+msgid "failed to rename base commit-graph file"
+msgstr "無法重新命名基礎提交圖形檔案"
+
+#: commit-graph.c:1524
+msgid "failed to rename temporary commit-graph file"
+msgstr "無法重新命名暫時提交圖形檔案"
+
+#: commit-graph.c:1635
+msgid "Scanning merged commits"
+msgstr "正在掃描合併提交"
+
+#: commit-graph.c:1646
+#, c-format
+msgid "unexpected duplicate commit id %s"
+msgstr "意外的重複提交 ID %s"
+
+#: commit-graph.c:1670
+msgid "Merging commit-graph"
+msgstr "正在合併提交圖形"
+
+#: commit-graph.c:1860
+#, c-format
+msgid "the commit graph format cannot write %d commits"
+msgstr "提交圖格式不能寫入 %d 個提交"
+
+#: commit-graph.c:1871
+msgid "too many commits to write graph"
+msgstr "提交太多不能畫圖"
+
+#: commit-graph.c:1961
+msgid "the commit-graph file has incorrect checksum and is likely corrupt"
+msgstr "提交圖檔案的總和檢查碼錯誤，可能已經損壞"
+
+#: commit-graph.c:1971
+#, c-format
+msgid "commit-graph has incorrect OID order: %s then %s"
+msgstr "提交圖形的物件 ID 順序不正確：%s 然後 %s"
+
+#: commit-graph.c:1981 commit-graph.c:1996
+#, c-format
+msgid "commit-graph has incorrect fanout value: fanout[%d] = %u != %u"
+msgstr "提交圖形有不正確的扇出值：fanout[%d] = %u != %u"
+
+#: commit-graph.c:1988
+#, c-format
+msgid "failed to parse commit %s from commit-graph"
+msgstr "無法從提交圖形中解析提交 %s"
+
+#: commit-graph.c:2006
+msgid "Verifying commits in commit graph"
+msgstr "正在驗證提交圖中的提交"
+
+#: commit-graph.c:2020
+#, c-format
+msgid "failed to parse commit %s from object database for commit-graph"
+msgstr "無法從提交圖形的物件庫中解析提交 %s"
+
+#: commit-graph.c:2027
+#, c-format
+msgid "root tree OID for commit %s in commit-graph is %s != %s"
+msgstr "提交圖形中的提交 %s 的根樹狀物件 ID 是 %s != %s"
+
+#: commit-graph.c:2037
+#, c-format
+msgid "commit-graph parent list for commit %s is too long"
+msgstr "提交 %s 的提交圖形父提交列表太長了"
+
+#: commit-graph.c:2046
+#, c-format
+msgid "commit-graph parent for %s is %s != %s"
+msgstr "%s 的提交圖形父提交是 %s != %s"
+
+#: commit-graph.c:2059
+#, c-format
+msgid "commit-graph parent list for commit %s terminates early"
+msgstr "提交 %s 的提交圖形父提交列表過早終止"
+
+#: commit-graph.c:2064
+#, c-format
+msgid ""
+"commit-graph has generation number zero for commit %s, but non-zero elsewhere"
+msgstr "提交圖形中提交 %s 的世代號是零，但其它地方非零"
+
+#: commit-graph.c:2068
+#, c-format
+msgid ""
+"commit-graph has non-zero generation number for commit %s, but zero elsewhere"
+msgstr "提交圖形中提交 %s 的世代號非零，但其它地方是零"
+
+#: commit-graph.c:2083
+#, c-format
+msgid "commit-graph generation for commit %s is %u != %u"
+msgstr "提交圖形中的提交 %s 的世代號是 %u != %u"
+
+#: commit-graph.c:2089
+#, c-format
+msgid "commit date for commit %s in commit-graph is %<PRIuMAX> != %<PRIuMAX>"
+msgstr "提交圖形中提交 %s 的提交日期是 %<PRIuMAX> != %<PRIuMAX>"
+
+#: compat/obstack.c:406 compat/obstack.c:408
+msgid "memory exhausted"
+msgstr "記憶體耗盡"
+
+#: config.c:124
+#, c-format
+msgid ""
+"exceeded maximum include depth (%d) while including\n"
+"\t%s\n"
+"from\n"
+"\t%s\n"
+"This might be due to circular includes."
+msgstr ""
+"超過了最大包含深度（%1$d），當從\n"
+"\t%3$s\n"
+"包含\n"
+"\t%2$s\n"
+"這可能是因為循環包含。"
+
+#: config.c:140
+#, c-format
+msgid "could not expand include path '%s'"
+msgstr "無法擴展包含路徑 '%s'"
+
+#: config.c:151
+msgid "relative config includes must come from files"
+msgstr "相對路徑的設定檔案引用必須來自於檔案"
+
+#: config.c:197
+msgid "relative config include conditionals must come from files"
+msgstr "相對路徑的設定檔案條件引用必須來自於檔案"
+
+#: config.c:376
+#, c-format
+msgid "key does not contain a section: %s"
+msgstr "鍵名沒有包含一個小節名稱：%s"
+
+#: config.c:382
+#, c-format
+msgid "key does not contain variable name: %s"
+msgstr "鍵名沒有包含變數名：%s"
+
+#: config.c:406 sequencer.c:2530
+#, c-format
+msgid "invalid key: %s"
+msgstr "無效鍵名：%s"
+
+#: config.c:412
+#, c-format
+msgid "invalid key (newline): %s"
+msgstr "無效鍵名（有換行符號）：%s"
+
+#: config.c:448 config.c:460
+#, c-format
+msgid "bogus config parameter: %s"
+msgstr "偽設定參數：%s"
+
+#: config.c:495
+#, c-format
+msgid "bogus format in %s"
+msgstr "%s 中格式錯誤"
+
+#: config.c:821
+#, c-format
+msgid "bad config line %d in blob %s"
+msgstr "資料物件 %2$s 中錯誤的設定行 %1$d"
+
+#: config.c:825
+#, c-format
+msgid "bad config line %d in file %s"
+msgstr "檔案 %2$s 中錯誤的設定行 %1$d"
+
+#: config.c:829
+#, c-format
+msgid "bad config line %d in standard input"
+msgstr "標準輸入中錯誤的設定行 %d"
+
+#: config.c:833
+#, c-format
+msgid "bad config line %d in submodule-blob %s"
+msgstr "子模組資料物件 %2$s 中錯誤的設定行 %1$d"
+
+#: config.c:837
+#, c-format
+msgid "bad config line %d in command line %s"
+msgstr "指令列 %2$s 中錯誤的設定行 %1$d"
+
+#: config.c:841
+#, c-format
+msgid "bad config line %d in %s"
+msgstr "在 %2$s 中錯誤的設定行 %1$d"
+
+#: config.c:978
+msgid "out of range"
+msgstr "超出範圍"
+
+#: config.c:978
+msgid "invalid unit"
+msgstr "無效的單位"
+
+#: config.c:979
+#, c-format
+msgid "bad numeric config value '%s' for '%s': %s"
+msgstr "設定變數 '%2$s' 的數字取值 '%1$s' 設定錯誤：%3$s"
+
+#: config.c:998
+#, c-format
+msgid "bad numeric config value '%s' for '%s' in blob %s: %s"
+msgstr "資料物件 %3$s 中設定變數 '%2$s' 錯誤的取值 '%1$s'：%4$s"
+
+#: config.c:1001
+#, c-format
+msgid "bad numeric config value '%s' for '%s' in file %s: %s"
+msgstr "檔案 %3$s 中設定變數 '%2$s' 錯誤的取值 '%1$s'：%4$s"
+
+#: config.c:1004
+#, c-format
+msgid "bad numeric config value '%s' for '%s' in standard input: %s"
+msgstr "標準輸入中設定變數 '%2$s' 錯誤的取值 '%1$s'：%3$s"
+
+#: config.c:1007
+#, c-format
+msgid "bad numeric config value '%s' for '%s' in submodule-blob %s: %s"
+msgstr "子模組資料 %3$s 中設定變數 '%2$s' 錯誤的取值 '%1$s'：%4$s"
+
+#: config.c:1010
+#, c-format
+msgid "bad numeric config value '%s' for '%s' in command line %s: %s"
+msgstr "指令列 %3$s 中設定變數 '%2$s' 錯誤的取值 '%1$s'：%4$s"
+
+#: config.c:1013
+#, c-format
+msgid "bad numeric config value '%s' for '%s' in %s: %s"
+msgstr "在 %3$s 中設定變數 '%2$s' 錯誤的取值 '%1$s'：%4$s"
+
+#: config.c:1108
+#, c-format
+msgid "failed to expand user dir in: '%s'"
+msgstr "無法擴展使用者目錄：'%s'"
+
+#: config.c:1117
+#, c-format
+msgid "'%s' for '%s' is not a valid timestamp"
+msgstr "'%2$s' 的值 '%1$s' 不是一個有效的時間戳"
+
+#: config.c:1208
+#, c-format
+msgid "abbrev length out of range: %d"
+msgstr "縮寫長度超出範圍：%d"
+
+#: config.c:1222 config.c:1233
+#, c-format
+msgid "bad zlib compression level %d"
+msgstr "錯誤的 zlib 壓縮級別 %d"
+
+#: config.c:1325
+msgid "core.commentChar should only be one character"
+msgstr "core.commentChar 應該是一個字元"
+
+#: config.c:1358
+#, c-format
+msgid "invalid mode for object creation: %s"
+msgstr "無效的物件建立模式：%s"
+
+#: config.c:1430
+#, c-format
+msgid "malformed value for %s"
+msgstr "%s 的取值格式錯誤"
+
+#: config.c:1456
+#, c-format
+msgid "malformed value for %s: %s"
+msgstr "%s 的取值格式錯誤：%s"
+
+#: config.c:1457
+msgid "must be one of nothing, matching, simple, upstream or current"
+msgstr "必須是其中之一：nothing、matching、simple、upstream 或 current"
+
+#: config.c:1518 builtin/pack-objects.c:3394
+#, c-format
+msgid "bad pack compression level %d"
+msgstr "錯誤的打包壓縮級別 %d"
+
+#: config.c:1639
+#, c-format
+msgid "unable to load config blob object '%s'"
+msgstr "無法從資料物件 '%s' 載入設定"
+
+#: config.c:1642
+#, c-format
+msgid "reference '%s' does not point to a blob"
+msgstr "引用 '%s' 沒有指向一個資料物件"
+
+#: config.c:1659
+#, c-format
+msgid "unable to resolve config blob '%s'"
+msgstr "不能解析設定物件 '%s'"
+
+#: config.c:1689
+#, c-format
+msgid "failed to parse %s"
+msgstr "解析 %s 失敗"
+
+#: config.c:1745
+msgid "unable to parse command-line config"
+msgstr "無法解析指令列中的設定"
+
+#: config.c:2096
+msgid "unknown error occurred while reading the configuration files"
+msgstr "在讀取設定檔案時遇到未知錯誤"
+
+#: config.c:2266
+#, c-format
+msgid "Invalid %s: '%s'"
+msgstr "無效 %s：'%s'"
+
+#: config.c:2311
+#, c-format
+msgid "splitIndex.maxPercentChange value '%d' should be between 0 and 100"
+msgstr "splitIndex.maxPercentChange 的取值 '%d' 應該介於 0 和 100 之間"
+
+#: config.c:2357
+#, c-format
+msgid "unable to parse '%s' from command-line config"
+msgstr "無法解析指令列設定中的 '%s'"
+
+#: config.c:2359
+#, c-format
+msgid "bad config variable '%s' in file '%s' at line %d"
+msgstr "在檔案 '%2$s' 的第 %3$d 行發現錯誤的設定變數 '%1$s'"
+
+#: config.c:2440
+#, c-format
+msgid "invalid section name '%s'"
+msgstr "無效的小節名稱 '%s'"
+
+#: config.c:2472
+#, c-format
+msgid "%s has multiple values"
+msgstr "%s 有多個取值"
+
+#: config.c:2501
+#, c-format
+msgid "failed to write new configuration file %s"
+msgstr "寫入新的設定檔案 %s 失敗"
+
+#: config.c:2753 config.c:3077
+#, c-format
+msgid "could not lock config file %s"
+msgstr "不能鎖定設定檔案 %s"
+
+#: config.c:2764
+#, c-format
+msgid "opening %s"
+msgstr "開啟 %s"
+
+#: config.c:2799 builtin/config.c:328
+#, c-format
+msgid "invalid pattern: %s"
+msgstr "無效模式：%s"
+
+#: config.c:2824
+#, c-format
+msgid "invalid config file %s"
+msgstr "無效的設定檔案 %s"
+
+#: config.c:2837 config.c:3090
+#, c-format
+msgid "fstat on %s failed"
+msgstr "對 %s 呼叫 fstat 失敗"
+
+#: config.c:2848
+#, c-format
+msgid "unable to mmap '%s'"
+msgstr "不能 mmap '%s'"
+
+#: config.c:2857 config.c:3095
+#, c-format
+msgid "chmod on %s failed"
+msgstr "對 %s 呼叫 chmod 失敗"
+
+#: config.c:2942 config.c:3192
+#, c-format
+msgid "could not write config file %s"
+msgstr "不能寫入設定檔案 %s"
+
+#: config.c:2976
+#, c-format
+msgid "could not set '%s' to '%s'"
+msgstr "不能設定 '%s' 為 '%s'"
+
+#: config.c:2978 builtin/remote.c:781
+#, c-format
+msgid "could not unset '%s'"
+msgstr "不能取消設定 '%s'"
+
+#: config.c:3068
+#, c-format
+msgid "invalid section name: %s"
+msgstr "無效的小節名稱：%s"
+
+#: config.c:3235
+#, c-format
+msgid "missing value for '%s'"
+msgstr "%s 的取值缺少"
+
+#: connect.c:61
+msgid "the remote end hung up upon initial contact"
+msgstr "遠端在初始連線時即掛斷"
+
+#: connect.c:63
+msgid ""
+"Could not read from remote repository.\n"
+"\n"
+"Please make sure you have the correct access rights\n"
+"and the repository exists."
+msgstr ""
+"無法讀取遠端版本庫。\n"
+"\n"
+"請確認您有正確的存取權限並且版本庫存在。"
+
+#: connect.c:81
+#, c-format
+msgid "server doesn't support '%s'"
+msgstr "伺服器不支援 '%s'"
+
+#: connect.c:103
+#, c-format
+msgid "server doesn't support feature '%s'"
+msgstr "伺服器不支援特性 '%s'"
+
+#: connect.c:114
+msgid "expected flush after capabilities"
+msgstr "在能力之後應為一個 flush 包"
+
+#: connect.c:233
+#, c-format
+msgid "ignoring capabilities after first line '%s'"
+msgstr "忽略第一行 '%s' 之後的能力欄位"
+
+#: connect.c:252
+msgid "protocol error: unexpected capabilities^{}"
+msgstr "協定錯誤：意外的 capabilities^{}"
+
+#: connect.c:273
+#, c-format
+msgid "protocol error: expected shallow sha-1, got '%s'"
+msgstr "協定錯誤：預期淺複製 sha-1，卻得到 '%s'"
+
+#: connect.c:275
+msgid "repository on the other end cannot be shallow"
+msgstr "另一端的版本庫不能是淺複製版本庫"
+
+#: connect.c:313
+msgid "invalid packet"
+msgstr "無效封包"
+
+#: connect.c:333
+#, c-format
+msgid "protocol error: unexpected '%s'"
+msgstr "協定錯誤：意外的 '%s'"
+
+#: connect.c:441
+#, c-format
+msgid "invalid ls-refs response: %s"
+msgstr "無效的 ls-refs 回應：%s"
+
+#: connect.c:445
+msgid "expected flush after ref listing"
+msgstr "在引用列表之後應該有一個 flush 包"
+
+#: connect.c:544
+#, c-format
+msgid "protocol '%s' is not supported"
+msgstr "不支援 '%s' 協定"
+
+#: connect.c:595
+msgid "unable to set SO_KEEPALIVE on socket"
+msgstr "無法為 socket 設定 SO_KEEPALIVE"
+
+#: connect.c:635 connect.c:698
+#, c-format
+msgid "Looking up %s ... "
+msgstr "尋找 %s ..."
+
+#: connect.c:639
+#, c-format
+msgid "unable to look up %s (port %s) (%s)"
+msgstr "無法尋找 %s（埠 %s）（%s）"
+
+#. TRANSLATORS: this is the end of "Looking up %s ... "
+#: connect.c:643 connect.c:714
+#, c-format
+msgid ""
+"done.\n"
+"Connecting to %s (port %s) ... "
+msgstr ""
+"完成。\n"
+"連線到 %s（埠 %s）... "
+
+#: connect.c:665 connect.c:742
+#, c-format
+msgid ""
+"unable to connect to %s:\n"
+"%s"
+msgstr ""
+"無法連線到 %s：\n"
+"%s"
+
+#. TRANSLATORS: this is the end of "Connecting to %s (port %s) ... "
+#: connect.c:671 connect.c:748
+msgid "done."
+msgstr "完成。"
+
+#: connect.c:702
+#, c-format
+msgid "unable to look up %s (%s)"
+msgstr "無法尋找 %s（%s）"
+
+#: connect.c:708
+#, c-format
+msgid "unknown port %s"
+msgstr "未知埠 %s"
+
+#: connect.c:845 connect.c:1175
+#, c-format
+msgid "strange hostname '%s' blocked"
+msgstr "已阻止奇怪的主機名稱 '%s'"
+
+#: connect.c:847
+#, c-format
+msgid "strange port '%s' blocked"
+msgstr "已阻止奇怪的埠號 '%s'"
+
+#: connect.c:857
+#, c-format
+msgid "cannot start proxy %s"
+msgstr "不能啟動代理 %s"
+
+#: connect.c:928
+msgid "no path specified; see 'git help pull' for valid url syntax"
+msgstr "未指定路徑，執行 'git help pull' 檢視有效的 url 語法"
+
+#: connect.c:1123
+msgid "ssh variant 'simple' does not support -4"
+msgstr "ssh 變體 'simple' 不支援 -4"
+
+#: connect.c:1135
+msgid "ssh variant 'simple' does not support -6"
+msgstr "ssh 變體 'simple' 不支援 -6"
+
+#: connect.c:1152
+msgid "ssh variant 'simple' does not support setting port"
+msgstr "ssh 變體 'simple' 不支援設定埠"
+
+#: connect.c:1264
+#, c-format
+msgid "strange pathname '%s' blocked"
+msgstr "已阻止奇怪的路徑名 '%s'"
+
+#: connect.c:1311
+msgid "unable to fork"
+msgstr "無法 fork"
+
+#: connected.c:89 builtin/fsck.c:208 builtin/prune.c:43
+msgid "Checking connectivity"
+msgstr "正在檢查連通性"
+
+#: connected.c:101
+msgid "Could not run 'git rev-list'"
+msgstr "不能執行 'git rev-list'"
+
+#: connected.c:121
+msgid "failed write to rev-list"
+msgstr "寫入 rev-list 失敗"
+
+#: connected.c:128
+msgid "failed to close rev-list's stdin"
+msgstr "關閉 rev-list 的標準輸入失敗"
+
+#: convert.c:194
+#, c-format
+msgid "illegal crlf_action %d"
+msgstr "非法的 crlf 動作 %d"
+
+#: convert.c:207
+#, c-format
+msgid "CRLF would be replaced by LF in %s"
+msgstr "%s 中的 CRLF 將被 LF 取代"
+
+#: convert.c:209
+#, c-format
+msgid ""
+"CRLF will be replaced by LF in %s.\n"
+"The file will have its original line endings in your working directory"
+msgstr ""
+"%s 中的 CRLF 將被 LF 取代。<\n"
+"在工作區中該檔案仍保持原有的換行符號。"
+
+#: convert.c:217
+#, c-format
+msgid "LF would be replaced by CRLF in %s"
+msgstr "檔案 %s 中的 LF 將被 CRLF 取代"
+
+#: convert.c:219
+#, c-format
+msgid ""
+"LF will be replaced by CRLF in %s.\n"
+"The file will have its original line endings in your working directory"
+msgstr ""
+"%s 中的 LF 將被 CRLF 取代。\n"
+"在工作區中該檔案仍保持原有的換行符號"
+
+#: convert.c:284
+#, c-format
+msgid "BOM is prohibited in '%s' if encoded as %s"
+msgstr "如果使用 %2$s 編碼，禁止在 '%1$s' 中使用 BOM"
+
+#: convert.c:291
+#, c-format
+#| msgid ""
+#| "The file '%s' contains a byte order mark (BOM). Please use UTF-%s as "
+#| "working-tree-encoding."
+msgid ""
+"The file '%s' contains a byte order mark (BOM). Please use UTF-%.*s as "
+"working-tree-encoding."
+msgstr "檔案 '%s' 包含位元組順序標記（BOM）。請使用 UTF-%.*s 作為工作區編碼。"
+
+#: convert.c:304
+#, c-format
+msgid "BOM is required in '%s' if encoded as %s"
+msgstr "如果編碼為 %2$s，需要在 '%1$s' 中使用 BOM"
+
+#: convert.c:306
+#, c-format
+msgid ""
+"The file '%s' is missing a byte order mark (BOM). Please use UTF-%sBE or UTF-"
+"%sLE (depending on the byte order) as working-tree-encoding."
+msgstr ""
+"檔案 '%s' 缺少一個位元組順序標記（BOM）。請使用 UTF-%sBE or UTF-%sLE（取決於"
+"字節序）作為工作區編碼。"
+
+#: convert.c:419 convert.c:490
+#, c-format
+msgid "failed to encode '%s' from %s to %s"
+msgstr "無法對 '%s' 進行從 %s 到 %s 的編碼"
+
+#: convert.c:462
+#, c-format
+msgid "encoding '%s' from %s to %s and back is not the same"
+msgstr "將'%s' 的編碼從 %s 到 %s 來迴轉換不一致"
+
+#: convert.c:668
+#, c-format
+msgid "cannot fork to run external filter '%s'"
+msgstr "不能 fork 以執行外部過濾器 '%s'"
+
+#: convert.c:688
+#, c-format
+msgid "cannot feed the input to external filter '%s'"
+msgstr "不能將輸入傳遞給外部過濾器 '%s'"
+
+#: convert.c:695
+#, c-format
+msgid "external filter '%s' failed %d"
+msgstr "外部過濾器 '%s' 失敗碼 %d"
+
+#: convert.c:730 convert.c:733
+#, c-format
+msgid "read from external filter '%s' failed"
+msgstr "從外部過濾器 '%s' 讀取失敗"
+
+#: convert.c:736 convert.c:791
+#, c-format
+msgid "external filter '%s' failed"
+msgstr "外部過濾器 '%s' 失敗"
+
+#: convert.c:839
+msgid "unexpected filter type"
+msgstr "意外的過濾類型"
+
+#: convert.c:850
+msgid "path name too long for external filter"
+msgstr "外部過濾器的路徑名太長"
+
+#: convert.c:924
+#, c-format
+msgid ""
+"external filter '%s' is not available anymore although not all paths have "
+"been filtered"
+msgstr "外部過濾器 '%s' 不再可用，但並非所有路徑都已過濾"
+
+#: convert.c:1223
+msgid "true/false are no valid working-tree-encodings"
+msgstr "true/false 不是有效的工作區編碼"
+
+#: convert.c:1411 convert.c:1445
+#, c-format
+msgid "%s: clean filter '%s' failed"
+msgstr "%s：clean 過濾器 '%s' 失敗"
+
+#: convert.c:1489
+#, c-format
+msgid "%s: smudge filter %s failed"
+msgstr "%s：smudge 過濾器 %s 失敗"
+
+#: date.c:138
+msgid "in the future"
+msgstr "在將來"
+
+#: date.c:144
+#, c-format
+msgid "%<PRIuMAX> second ago"
+msgid_plural "%<PRIuMAX> seconds ago"
+msgstr[0] "%<PRIuMAX> 秒鐘前"
+msgstr[1] "%<PRIuMAX> 秒鐘前"
+
+#: date.c:151
+#, c-format
+msgid "%<PRIuMAX> minute ago"
+msgid_plural "%<PRIuMAX> minutes ago"
+msgstr[0] "%<PRIuMAX> 分鐘前"
+msgstr[1] "%<PRIuMAX> 分鐘前"
+
+#: date.c:158
+#, c-format
+msgid "%<PRIuMAX> hour ago"
+msgid_plural "%<PRIuMAX> hours ago"
+msgstr[0] "%<PRIuMAX> 小時前"
+msgstr[1] "%<PRIuMAX> 小時前"
+
+#: date.c:165
+#, c-format
+msgid "%<PRIuMAX> day ago"
+msgid_plural "%<PRIuMAX> days ago"
+msgstr[0] "%<PRIuMAX> 天前"
+msgstr[1] "%<PRIuMAX> 天前"
+
+#: date.c:171
+#, c-format
+msgid "%<PRIuMAX> week ago"
+msgid_plural "%<PRIuMAX> weeks ago"
+msgstr[0] "%<PRIuMAX> 周前"
+msgstr[1] "%<PRIuMAX> 周前"
+
+#: date.c:178
+#, c-format
+msgid "%<PRIuMAX> month ago"
+msgid_plural "%<PRIuMAX> months ago"
+msgstr[0] "%<PRIuMAX> 個月前"
+msgstr[1] "%<PRIuMAX> 個月前"
+
+#: date.c:189
+#, c-format
+msgid "%<PRIuMAX> year"
+msgid_plural "%<PRIuMAX> years"
+msgstr[0] "%<PRIuMAX> 年"
+msgstr[1] "%<PRIuMAX> 年"
+
+#. TRANSLATORS: "%s" is "<n> years"
+#: date.c:192
+#, c-format
+msgid "%s, %<PRIuMAX> month ago"
+msgid_plural "%s, %<PRIuMAX> months ago"
+msgstr[0] "%s %<PRIuMAX> 個月前"
+msgstr[1] "%s %<PRIuMAX> 個月前"
+
+#: date.c:197 date.c:202
+#, c-format
+msgid "%<PRIuMAX> year ago"
+msgid_plural "%<PRIuMAX> years ago"
+msgstr[0] "%<PRIuMAX> 年前"
+msgstr[1] "%<PRIuMAX> 年前"
+
+#: delta-islands.c:272
+msgid "Propagating island marks"
+msgstr "正在傳播資料島標記"
+
+#: delta-islands.c:290
+#, c-format
+msgid "bad tree object %s"
+msgstr "壞的樹狀物件 %s"
+
+#: delta-islands.c:334
+#, c-format
+msgid "failed to load island regex for '%s': %s"
+msgstr "未能載入 '%s' 的資料島正規表示式：%s"
+
+#: delta-islands.c:390
+#, c-format
+msgid "island regex from config has too many capture groups (max=%d)"
+msgstr "來自 config 的資料島正規表示式有太多的捕獲組（最多 %d 個）"
+
+#: delta-islands.c:467
+#, c-format
+msgid "Marked %d islands, done.\n"
+msgstr "已標記 %d 個資料島，結束。\n"
+
+#: diffcore-order.c:24
+#, c-format
+msgid "failed to read orderfile '%s'"
+msgstr "讀取排序檔案 '%s' 失敗"
+
+#: diffcore-rename.c:543
+msgid "Performing inexact rename detection"
+msgstr "正在進行非精確的重新命名偵測"
+
+#: diff-no-index.c:238
+msgid "git diff --no-index [<options>] <path> <path>"
+msgstr "git diff --no-index [<選項>] <路徑> <路徑>"
+
+#: diff-no-index.c:263
+msgid ""
+"Not a git repository. Use --no-index to compare two paths outside a working "
+"tree"
+msgstr "不是一個 git 版本庫。使用 --no-index 比較工作區之外的兩個路徑"
+
+#  譯者：請維持前導空格
+#: diff.c:155
+#, c-format
+msgid "  Failed to parse dirstat cut-off percentage '%s'\n"
+msgstr "  無法解析 dirstat 截止（cut-off）百分比 '%s'\n"
+
+#  譯者：請維持前導空格
+#: diff.c:160
+#, c-format
+msgid "  Unknown dirstat parameter '%s'\n"
+msgstr "  未知的 dirstat 參數 '%s'\n"
+
+#: diff.c:296
+msgid ""
+"color moved setting must be one of 'no', 'default', 'blocks', 'zebra', "
+"'dimmed-zebra', 'plain'"
+msgstr ""
+"移動的顏色設定必須是 'no'、'default'、'blocks'、'zebra'、'dimmed_zebra' 或 "
+"'plain'"
+
+#: diff.c:324
+#, c-format
+msgid ""
+"unknown color-moved-ws mode '%s', possible values are 'ignore-space-change', "
+"'ignore-space-at-eol', 'ignore-all-space', 'allow-indentation-change'"
+msgstr ""
+"未知的 color-moved-ws 模式 '%s'，可能的取值有 'ignore-space-change'、'ignore-"
+"space-at-eol'、'ignore-all-space'、'allow-indentation-change'"
+
+#: diff.c:332
+msgid ""
+"color-moved-ws: allow-indentation-change cannot be combined with other "
+"whitespace modes"
+msgstr "color-moved-ws：allow-indentation-change 不能與其它空白字元模式共用"
+
+#: diff.c:405
+#, c-format
+msgid "Unknown value for 'diff.submodule' config variable: '%s'"
+msgstr "設定變數 'diff.submodule' 未知的取值：'%s'"
+
+#: diff.c:465
+#, c-format
+msgid ""
+"Found errors in 'diff.dirstat' config variable:\n"
+"%s"
+msgstr ""
+"發現設定變數 'diff.dirstat' 中的錯誤：\n"
+"%s"
+
+#: diff.c:4202
+#, c-format
+msgid "external diff died, stopping at %s"
+msgstr "外部 diff 離開，停止在 %s"
+
+#: diff.c:4547
+msgid "--name-only, --name-status, --check and -s are mutually exclusive"
+msgstr "--name-only、--name-status、--check 和 -s 是互斥的"
+
+#: diff.c:4550
+msgid "-G, -S and --find-object are mutually exclusive"
+msgstr "-G、-S 和 --find-object 是互斥的"
+
+#: diff.c:4628
+msgid "--follow requires exactly one pathspec"
+msgstr "--follow 明確要求只跟一個路徑規格"
+
+#: diff.c:4676
+#, c-format
+msgid "invalid --stat value: %s"
+msgstr "無效的 --stat 值：%s"
+
+#: diff.c:4681 diff.c:4686 diff.c:4691 diff.c:4696 diff.c:5209
+#: parse-options.c:199 parse-options.c:203
+#, c-format
+msgid "%s expects a numerical value"
+msgstr "%s 期望一個數字值"
+
+#: diff.c:4713
+#, c-format
+msgid ""
+"Failed to parse --dirstat/-X option parameter:\n"
+"%s"
+msgstr ""
+"無法解析 --dirstat/-X 選項的參數：\n"
+"%s"
+
+#: diff.c:4798
+#, c-format
+msgid "unknown change class '%c' in --diff-filter=%s"
+msgstr "--diff-filter=%2$s 中未知的變更類 '%1$c'"
+
+#: diff.c:4822
+#, c-format
+msgid "unknown value after ws-error-highlight=%.*s"
+msgstr "ws-error-highlight=%.*s 之後未知的值"
+
+#: diff.c:4836
+#, c-format
+msgid "unable to resolve '%s'"
+msgstr "不能解析 '%s'"
+
+#: diff.c:4886 diff.c:4892
+#, c-format
+msgid "%s expects <n>/<m> form"
+msgstr "%s 期望 <n>/<m> 格式"
+
+#: diff.c:4904
+#, c-format
+msgid "%s expects a character, got '%s'"
+msgstr "%s 期望一個字元，得到 '%s'"
+
+#: diff.c:4925
+#, c-format
+msgid "bad --color-moved argument: %s"
+msgstr "壞的 --color-moved 參數：%s"
+
+#: diff.c:4944
+#, c-format
+msgid "invalid mode '%s' in --color-moved-ws"
+msgstr "--color-moved-ws 中的無效模式 '%s' "
+
+#: diff.c:4984
+msgid ""
+"option diff-algorithm accepts \"myers\", \"minimal\", \"patience\" and "
+"\"histogram\""
+msgstr "diff-algorithm 選項有 \"myers\"、\"minimal\"、\"patience\" 和 \"histogram\""
+
+#: diff.c:5020 diff.c:5040
+#, c-format
+msgid "invalid argument to %s"
+msgstr "%s 的參數無效"
+
+#: diff.c:5178
+#, c-format
+msgid "failed to parse --submodule option parameter: '%s'"
+msgstr "無法解析 --submodule 選項的參數：'%s'"
+
+#: diff.c:5234
+#, c-format
+msgid "bad --word-diff argument: %s"
+msgstr "壞的 --word-diff 參數：%s"
+
+#: diff.c:5257
+msgid "Diff output format options"
+msgstr "差異輸出格式化選項"
+
+#: diff.c:5259 diff.c:5265
+msgid "generate patch"
+msgstr "生成修補檔"
+
+#: diff.c:5262 builtin/log.c:173
+msgid "suppress diff output"
+msgstr "不顯示差異輸出"
+
+#: diff.c:5267 diff.c:5381 diff.c:5388
+msgid "<n>"
+msgstr "<n>"
+
+#: diff.c:5268 diff.c:5271
+msgid "generate diffs with <n> lines context"
+msgstr "生成含 <n> 行上下文的差異"
+
+#: diff.c:5273
+msgid "generate the diff in raw format"
+msgstr "生成原始格式的差異"
+
+#: diff.c:5276
+msgid "synonym for '-p --raw'"
+msgstr "和 '-p --raw' 同義"
+
+#: diff.c:5280
+msgid "synonym for '-p --stat'"
+msgstr "和 '-p --stat' 同義"
+
+#: diff.c:5284
+msgid "machine friendly --stat"
+msgstr "機器友好的 --stat"
+
+#: diff.c:5287
+msgid "output only the last line of --stat"
+msgstr "只輸出 --stat 的最後一行"
+
+#: diff.c:5289 diff.c:5297
+msgid "<param1,param2>..."
+msgstr "<參數1,參數2>..."
+
+#: diff.c:5290
+msgid ""
+"output the distribution of relative amount of changes for each sub-directory"
+msgstr "輸出每個子目錄相對變更的分布"
+
+#: diff.c:5294
+msgid "synonym for --dirstat=cumulative"
+msgstr "和 --dirstat=cumulative 同義"
+
+#: diff.c:5298
+msgid "synonym for --dirstat=files,param1,param2..."
+msgstr "是 --dirstat=files,param1,param2... 的同義詞"
+
+#: diff.c:5302
+msgid "warn if changes introduce conflict markers or whitespace errors"
+msgstr "如果變更中引入衝突定界符或空白錯誤，給出警告"
+
+#: diff.c:5305
+msgid "condensed summary such as creations, renames and mode changes"
+msgstr "精簡摘要，例如建立、重新命名和模式變更"
+
+#: diff.c:5308
+msgid "show only names of changed files"
+msgstr "只顯示變更檔案的檔案名"
+
+#: diff.c:5311
+msgid "show only names and status of changed files"
+msgstr "只顯示變更檔案的檔案名和狀態"
+
+#: diff.c:5313
+msgid "<width>[,<name-width>[,<count>]]"
+msgstr "<寬度>[,<檔案名寬度>[,<次數>]]"
+
+#: diff.c:5314
+msgid "generate diffstat"
+msgstr "生成差異統計（diffstat）"
+
+#: diff.c:5316 diff.c:5319 diff.c:5322
+msgid "<width>"
+msgstr "<寬度>"
+
+#: diff.c:5317
+msgid "generate diffstat with a given width"
+msgstr "使用提供的長度生成差異統計"
+
+#: diff.c:5320
+msgid "generate diffstat with a given name width"
+msgstr "使用提供的檔案名長度生成差異統計"
+
+#: diff.c:5323
+msgid "generate diffstat with a given graph width"
+msgstr "使用提供的圖形長度生成差異統計"
+
+#: diff.c:5325
+msgid "<count>"
+msgstr "<次數>"
+
+#: diff.c:5326
+msgid "generate diffstat with limited lines"
+msgstr "生成有限行數的差異統計"
+
+#: diff.c:5329
+msgid "generate compact summary in diffstat"
+msgstr "生成差異統計的簡潔摘要"
+
+#: diff.c:5332
+msgid "output a binary diff that can be applied"
+msgstr "輸出一個可以應用的二進位差異"
+
+#: diff.c:5335
+msgid "show full pre- and post-image object names on the \"index\" lines"
+msgstr "在 \"index\" 行顯示完整的前後物件名稱"
+
+#: diff.c:5337
+msgid "show colored diff"
+msgstr "顯示帶顏色的差異"
+
+#: diff.c:5338
+msgid "<kind>"
+msgstr "<類型>"
+
+#: diff.c:5339
+msgid ""
+"highlight whitespace errors in the 'context', 'old' or 'new' lines in the "
+"diff"
+msgstr "對於差異中的上下文、舊的和新的行，加亮顯示錯誤的空白字元"
+
+#: diff.c:5342
+msgid ""
+"do not munge pathnames and use NULs as output field terminators in --raw or "
+"--numstat"
+msgstr ""
+"在 --raw 或者 --numstat 中，不對路徑字元轉檔並使用 NUL 字元做為輸出欄位的分隔"
+"符"
+
+#: diff.c:5345 diff.c:5348 diff.c:5351 diff.c:5457
+msgid "<prefix>"
+msgstr "<前綴>"
+
+#: diff.c:5346
+msgid "show the given source prefix instead of \"a/\""
+msgstr "顯示提供的源前綴取代 \"a/\""
+
+#: diff.c:5349
+msgid "show the given destination prefix instead of \"b/\""
+msgstr "顯示提供的目標前綴取代 \"b/\""
+
+#: diff.c:5352
+msgid "prepend an additional prefix to every line of output"
+msgstr "輸出的每一行附加前綴"
+
+#: diff.c:5355
+msgid "do not show any source or destination prefix"
+msgstr "不顯示任何源和目標前綴"
+
+#: diff.c:5358
+msgid "show context between diff hunks up to the specified number of lines"
+msgstr "顯示指定行數的差異區塊間的上下文"
+
+#: diff.c:5362 diff.c:5367 diff.c:5372
+msgid "<char>"
+msgstr "<字元>"
+
+#: diff.c:5363
+msgid "specify the character to indicate a new line instead of '+'"
+msgstr "指定一個字元取代 '+' 來表示新的一行"
+
+#: diff.c:5368
+msgid "specify the character to indicate an old line instead of '-'"
+msgstr "指定一個字元取代 '-' 來表示舊的一行"
+
+#: diff.c:5373
+msgid "specify the character to indicate a context instead of ' '"
+msgstr "指定一個字元取代 ' ' 來表示一行上下文"
+
+#: diff.c:5376
+msgid "Diff rename options"
+msgstr "差異重新命名選項"
+
+#: diff.c:5377
+msgid "<n>[/<m>]"
+msgstr "<n>[/<m>]"
+
+#: diff.c:5378
+msgid "break complete rewrite changes into pairs of delete and create"
+msgstr "將完全重寫的變更打破為成對的刪除和建立"
+
+#: diff.c:5382
+msgid "detect renames"
+msgstr "檢測重新命名"
+
+#: diff.c:5386
+msgid "omit the preimage for deletes"
+msgstr "省略刪除動作的差異輸出"
+
+#: diff.c:5389
+msgid "detect copies"
+msgstr "檢測複製"
+
+#: diff.c:5393
+msgid "use unmodified files as source to find copies"
+msgstr "使用未修改的檔案做為發現複製的源"
+
+#: diff.c:5395
+msgid "disable rename detection"
+msgstr "禁用重新命名偵測"
+
+#: diff.c:5398
+msgid "use empty blobs as rename source"
+msgstr "使用空的資料物件做為重新命名的源"
+
+#: diff.c:5400
+msgid "continue listing the history of a file beyond renames"
+msgstr "繼續列出檔案重新命名以外的歷史記錄"
+
+#: diff.c:5403
+msgid ""
+"prevent rename/copy detection if the number of rename/copy targets exceeds "
+"given limit"
+msgstr "如果重新命名/複製目標超過提供的限制，禁止重新命名/複製檢測"
+
+#: diff.c:5405
+msgid "Diff algorithm options"
+msgstr "差異演算法選項"
+
+#: diff.c:5407
+msgid "produce the smallest possible diff"
+msgstr "生成儘可能小的差異"
+
+#: diff.c:5410
+msgid "ignore whitespace when comparing lines"
+msgstr "行比較時忽略空白字元"
+
+#: diff.c:5413
+msgid "ignore changes in amount of whitespace"
+msgstr "忽略空白字元的變更"
+
+#: diff.c:5416
+msgid "ignore changes in whitespace at EOL"
+msgstr "忽略行尾的空白字元變更"
+
+#: diff.c:5419
+msgid "ignore carrier-return at the end of line"
+msgstr "忽略行尾的Enter符（CR）"
+
+#: diff.c:5422
+msgid "ignore changes whose lines are all blank"
+msgstr "忽略整行都是空白的變更"
+
+#: diff.c:5425
+msgid "heuristic to shift diff hunk boundaries for easy reading"
+msgstr "啟發式轉換差異邊界以便閱讀"
+
+#: diff.c:5428
+msgid "generate diff using the \"patience diff\" algorithm"
+msgstr "使用 \"patience diff\" 演算法生成差異"
+
+#: diff.c:5432
+msgid "generate diff using the \"histogram diff\" algorithm"
+msgstr "使用 \"histogram diff\" 演算法生成差異"
+
+#: diff.c:5434
+msgid "<algorithm>"
+msgstr "<演算法>"
+
+#: diff.c:5435
+msgid "choose a diff algorithm"
+msgstr "選擇一個差異演算法"
+
+#: diff.c:5437
+msgid "<text>"
+msgstr "<文字>"
+
+#: diff.c:5438
+msgid "generate diff using the \"anchored diff\" algorithm"
+msgstr "使用 \"anchored diff\" 演算法生成差異"
+
+#: diff.c:5440 diff.c:5449 diff.c:5452
+msgid "<mode>"
+msgstr "<模式>"
+
+#: diff.c:5441
+msgid "show word diff, using <mode> to delimit changed words"
+msgstr "顯示單詞差異，使用 <模式> 分隔變更的單詞"
+
+#: diff.c:5443 diff.c:5446 diff.c:5491
+msgid "<regex>"
+msgstr "<正則>"
+
+#: diff.c:5444
+msgid "use <regex> to decide what a word is"
+msgstr "使用 <正規表示式> 確定何為一個詞"
+
+#: diff.c:5447
+msgid "equivalent to --word-diff=color --word-diff-regex=<regex>"
+msgstr "相當於 --word-diff=color --word-diff-regex=<正則>"
+
+#: diff.c:5450
+msgid "moved lines of code are colored differently"
+msgstr "移動的程式碼行用不同方式著色"
+
+#: diff.c:5453
+msgid "how white spaces are ignored in --color-moved"
+msgstr "在 --color-moved 下如何忽略空白字元"
+
+#: diff.c:5456
+msgid "Other diff options"
+msgstr "其它差異選項"
+
+#: diff.c:5458
+msgid "when run from subdir, exclude changes outside and show relative paths"
+msgstr "當從子目錄執行，排除目錄之外的變更並顯示相對路徑"
+
+#: diff.c:5462
+msgid "treat all files as text"
+msgstr "把所有檔案當做文字處理"
+
+#: diff.c:5464
+msgid "swap two inputs, reverse the diff"
+msgstr "交換兩個輸入，反轉差異"
+
+#: diff.c:5466
+msgid "exit with 1 if there were differences, 0 otherwise"
+msgstr "有差異時離開碼為 1，否則為 0"
+
+#: diff.c:5468
+msgid "disable all output of the program"
+msgstr "禁用本程式的所有輸出"
+
+#: diff.c:5470
+msgid "allow an external diff helper to be executed"
+msgstr "允許執行一個外部的差異助手"
+
+#: diff.c:5472
+msgid "run external text conversion filters when comparing binary files"
+msgstr "當比較二進位檔案時，執行外部的文字轉換過濾器"
+
+#: diff.c:5474
+msgid "<when>"
+msgstr "<何時>"
+
+#: diff.c:5475
+msgid "ignore changes to submodules in the diff generation"
+msgstr "在生成差異時，忽略子模組的更改"
+
+#: diff.c:5478
+msgid "<format>"
+msgstr "<格式>"
+
+#: diff.c:5479
+msgid "specify how differences in submodules are shown"
+msgstr "指定子模組的差異如何顯示"
+
+#: diff.c:5483
+msgid "hide 'git add -N' entries from the index"
+msgstr "隱藏索引中 'git add -N' 條目"
+
+#: diff.c:5486
+msgid "treat 'git add -N' entries as real in the index"
+msgstr "將索引中 'git add -N' 條目當做真實的"
+
+#: diff.c:5488
+msgid "<string>"
+msgstr "<字串>"
+
+#: diff.c:5489
+msgid ""
+"look for differences that change the number of occurrences of the specified "
+"string"
+msgstr "尋找改變了指定字串出現次數的差異"
+
+#: diff.c:5492
+msgid ""
+"look for differences that change the number of occurrences of the specified "
+"regex"
+msgstr "尋找改變指定正則符合出現次數的差異"
+
+#: diff.c:5495
+msgid "show all changes in the changeset with -S or -G"
+msgstr "顯示使用 -S 或 -G 的變更集的所有變更"
+
+#: diff.c:5498
+msgid "treat <string> in -S as extended POSIX regular expression"
+msgstr "將 -S 的 <string> 當做擴展的 POSIX 正規表示式"
+
+#: diff.c:5501
+msgid "control the order in which files appear in the output"
+msgstr "控制輸出中的檔案顯示順序"
+
+#: diff.c:5502
+msgid "<object-id>"
+msgstr "<物件 ID>"
+
+#: diff.c:5503
+msgid ""
+"look for differences that change the number of occurrences of the specified "
+"object"
+msgstr "尋找改變指定物件出現次數的差異"
+
+#: diff.c:5505
+msgid "[(A|C|D|M|R|T|U|X|B)...[*]]"
+msgstr "[(A|C|D|M|R|T|U|X|B)...[*]]"
+
+#: diff.c:5506
+msgid "select files by diff type"
+msgstr "透過差異類型選擇檔案"
+
+#: diff.c:5508
+msgid "<file>"
+msgstr "<檔案>"
+
+#: diff.c:5509
+msgid "Output to a specific file"
+msgstr "輸出到一個指定的檔案"
+
+#: diff.c:6164
+msgid "inexact rename detection was skipped due to too many files."
+msgstr "因為檔案太多，略過不嚴格的重新命名檢查。"
+
+#: diff.c:6167
+msgid "only found copies from modified paths due to too many files."
+msgstr "因為檔案太多，只在修改的路徑中尋找複製。"
+
+#: diff.c:6170
+#, c-format
+msgid ""
+"you may want to set your %s variable to at least %d and retry the command."
+msgstr "您可能想要將變數 %s 設定為至少 %d 並再次執行此指令。"
+
+#: dir.c:554
+#, c-format
+msgid "pathspec '%s' did not match any file(s) known to git"
+msgstr "路徑規格 '%s' 未符合任何 git 已知檔案"
+
+#: dir.c:664
+#, c-format
+#| msgid "unrecognized option: '%s'"
+msgid "unrecognized pattern: '%s'"
+msgstr "無法識別樣式：「%s」"
+
+#: dir.c:682 dir.c:696
+#, c-format
+#| msgid "unrecognized option: '%s'"
+msgid "unrecognized negative pattern: '%s'"
+msgstr "無法識別反向模式：「%s」"
+
+#: dir.c:714
+#, c-format
+msgid "your sparse-checkout file may have issues: pattern '%s' is repeated"
+msgstr "您的稀疏簽出檔案可能有問題：「%s」樣式重複"
+
+#: dir.c:724
+msgid "disabling cone pattern matching"
+msgstr "停用 cone 樣式符合模式"
+
+#: dir.c:1101
+#, c-format
+msgid "cannot use %s as an exclude file"
+msgstr "不能將 %s 用作排除檔案"
+
+#: dir.c:2078
+#, c-format
+msgid "could not open directory '%s'"
+msgstr "不能開啟目錄 '%s'"
+
+#: dir.c:2415
+msgid "failed to get kernel name and information"
+msgstr "無法獲得核心名稱和訊息"
+
+#: dir.c:2539
+msgid "untracked cache is disabled on this system or location"
+msgstr "快取未追蹤檔案在本系統或位置中被禁用"
+
+#: dir.c:3343
+#, c-format
+msgid "index file corrupt in repo %s"
+msgstr "版本庫 %s 中的索引檔案損壞"
+
+#: dir.c:3388 dir.c:3393
+#, c-format
+msgid "could not create directories for %s"
+msgstr "不能為 %s 建立目錄"
+
+#: dir.c:3422
+#, c-format
+msgid "could not migrate git directory from '%s' to '%s'"
+msgstr "不能從 '%s' 遷移 git 目錄到 '%s'"
+
+#: editor.c:73
+#, c-format
+msgid "hint: Waiting for your editor to close the file...%c"
+msgstr "提示：等待您的編輯器關閉檔案...%c"
+
+#: entry.c:178
+msgid "Filtering content"
+msgstr "過濾內容"
+
+#: entry.c:476
+#, c-format
+msgid "could not stat file '%s'"
+msgstr "不能對檔案 '%s' 呼叫 stat"
+
+#: environment.c:149
+#, c-format
+msgid "bad git namespace path \"%s\""
+msgstr "錯誤的 git 名字空間路徑 \"%s\""
+
+#: environment.c:331
+#, c-format
+msgid "could not set GIT_DIR to '%s'"
+msgstr "不能設定 GIT_DIR 為 '%s'"
+
+#: exec-cmd.c:363
+#, c-format
+msgid "too many args to run %s"
+msgstr "執行 %s 的參數太多"
+
+#: fetch-pack.c:150
+msgid "git fetch-pack: expected shallow list"
+msgstr "git fetch-pack：應為 shallow 列表"
+
+#: fetch-pack.c:153
+msgid "git fetch-pack: expected a flush packet after shallow list"
+msgstr "git fetch-pack：在淺複製列表之後期望一個 flush 包"
+
+#: fetch-pack.c:164
+msgid "git fetch-pack: expected ACK/NAK, got a flush packet"
+msgstr "git fetch-pack：期望 ACK/NAK，卻得到 flush 包"
+
+#: fetch-pack.c:184
+#, c-format
+msgid "git fetch-pack: expected ACK/NAK, got '%s'"
+msgstr "git fetch-pack：應為 ACK/NAK，卻得到 '%s'"
+
+#: fetch-pack.c:195
+msgid "unable to write to remote"
+msgstr "無法寫到遠端"
+
+#: fetch-pack.c:257
+msgid "--stateless-rpc requires multi_ack_detailed"
+msgstr "--stateless-rpc 需要 multi_ack_detailed"
+
+#: fetch-pack.c:356 fetch-pack.c:1340
+#, c-format
+msgid "invalid shallow line: %s"
+msgstr "無效的 shallow 訊息：%s"
+
+#: fetch-pack.c:362 fetch-pack.c:1346
+#, c-format
+msgid "invalid unshallow line: %s"
+msgstr "無效的 unshallow 訊息：%s"
+
+#: fetch-pack.c:364 fetch-pack.c:1348
+#, c-format
+msgid "object not found: %s"
+msgstr "物件未找到：%s"
+
+#: fetch-pack.c:367 fetch-pack.c:1351
+#, c-format
+msgid "error in object: %s"
+msgstr "物件中發生錯誤：%s"
+
+#: fetch-pack.c:369 fetch-pack.c:1353
+#, c-format
+msgid "no shallow found: %s"
+msgstr "未發現 shallow：%s"
+
+#: fetch-pack.c:372 fetch-pack.c:1357
+#, c-format
+msgid "expected shallow/unshallow, got %s"
+msgstr "應為 shallow/unshallow，卻得到 %s"
+
+#: fetch-pack.c:414
+#, c-format
+msgid "got %s %d %s"
+msgstr "得到 %s %d %s"
+
+#: fetch-pack.c:431
+#, c-format
+msgid "invalid commit %s"
+msgstr "無效提交 %s"
+
+#: fetch-pack.c:462
+msgid "giving up"
+msgstr "放棄"
+
+#: fetch-pack.c:475 progress.c:323
+msgid "done"
+msgstr "完成"
+
+#: fetch-pack.c:487
+#, c-format
+msgid "got %s (%d) %s"
+msgstr "得到 %s (%d) %s"
+
+#: fetch-pack.c:533
+#, c-format
+msgid "Marking %s as complete"
+msgstr "標記 %s 為完成"
+
+#: fetch-pack.c:754
+#, c-format
+msgid "already have %s (%s)"
+msgstr "已經有 %s（%s）"
+
+#: fetch-pack.c:818
+msgid "fetch-pack: unable to fork off sideband demultiplexer"
+msgstr "fetch-pack：無法衍生 sideband 多路輸出"
+
+#: fetch-pack.c:826
+msgid "protocol error: bad pack header"
+msgstr "協定錯誤：壞的包頭"
+
+#: fetch-pack.c:900
+#, c-format
+msgid "fetch-pack: unable to fork off %s"
+msgstr "fetch-pack：無法衍生進程 %s"
+
+#: fetch-pack.c:916
+#, c-format
+msgid "%s failed"
+msgstr "%s 失敗"
+
+#: fetch-pack.c:918
+msgid "error in sideband demultiplexer"
+msgstr "sideband 多路輸出發生錯誤"
+
+#: fetch-pack.c:965
+#, c-format
+msgid "Server version is %.*s"
+msgstr "伺服器版本 %.*s"
+
+#: fetch-pack.c:970 fetch-pack.c:976 fetch-pack.c:979 fetch-pack.c:985
+#: fetch-pack.c:989 fetch-pack.c:993 fetch-pack.c:997 fetch-pack.c:1001
+#: fetch-pack.c:1005 fetch-pack.c:1009 fetch-pack.c:1013 fetch-pack.c:1017
+#: fetch-pack.c:1023 fetch-pack.c:1029 fetch-pack.c:1034 fetch-pack.c:1039
+#, c-format
+msgid "Server supports %s"
+msgstr "伺服器支援 %s"
+
+#: fetch-pack.c:972
+msgid "Server does not support shallow clients"
+msgstr "伺服器不支援 shalllow 用戶端"
+
+#: fetch-pack.c:1032
+msgid "Server does not support --shallow-since"
+msgstr "伺服器不支援 --shallow-since"
+
+#: fetch-pack.c:1037
+msgid "Server does not support --shallow-exclude"
+msgstr "伺服器不支援 --shallow-exclude"
+
+#: fetch-pack.c:1041
+msgid "Server does not support --deepen"
+msgstr "伺服器不支援 --deepen"
+
+#: fetch-pack.c:1058
+msgid "no common commits"
+msgstr "沒有共同的提交"
+
+#: fetch-pack.c:1070 fetch-pack.c:1536
+msgid "git fetch-pack: fetch failed."
+msgstr "git fetch-pack：取得失敗。"
+
+#: fetch-pack.c:1209
+msgid "Server does not support shallow requests"
+msgstr "伺服器不支援 shalllow 請求"
+
+#: fetch-pack.c:1216
+msgid "Server supports filter"
+msgstr "伺服器支援 filter"
+
+#: fetch-pack.c:1239
+msgid "unable to write request to remote"
+msgstr "無法將請求寫到遠端"
+
+#: fetch-pack.c:1257
+#, c-format
+msgid "error reading section header '%s'"
+msgstr "讀取節標題 '%s' 發生錯誤"
+
+#: fetch-pack.c:1263
+#, c-format
+msgid "expected '%s', received '%s'"
+msgstr "預期 '%s'，得到 '%s'"
+
+#: fetch-pack.c:1303
+#, c-format
+msgid "unexpected acknowledgment line: '%s'"
+msgstr "意外的確認行：'%s'"
+
+#: fetch-pack.c:1308
+#, c-format
+msgid "error processing acks: %d"
+msgstr "處理 ack 發生錯誤：%d"
+
+#: fetch-pack.c:1318
+msgid "expected packfile to be sent after 'ready'"
+msgstr "預期在 'ready' 之後傳送 packfile"
+
+#: fetch-pack.c:1320
+msgid "expected no other sections to be sent after no 'ready'"
+msgstr "在沒有 'ready' 不應該傳送其它小節"
+
+#: fetch-pack.c:1362
+#, c-format
+msgid "error processing shallow info: %d"
+msgstr "處理淺複製訊息發生錯誤：%d"
+
+#: fetch-pack.c:1409
+#, c-format
+msgid "expected wanted-ref, got '%s'"
+msgstr "預期 wanted-ref，得到 '%s'"
+
+#: fetch-pack.c:1414
+#, c-format
+msgid "unexpected wanted-ref: '%s'"
+msgstr "意外的 wanted-ref：'%s'"
+
+#: fetch-pack.c:1419
+#, c-format
+msgid "error processing wanted refs: %d"
+msgstr "處理要取得的引用發生錯誤：%d"
+
+#: fetch-pack.c:1762
+msgid "no matching remote head"
+msgstr "沒有符合的遠端分支"
+
+#: fetch-pack.c:1785 builtin/clone.c:688
+msgid "remote did not send all necessary objects"
+msgstr "遠端沒有傳送所有必需的物件"
+
+#: fetch-pack.c:1812
+#, c-format
+msgid "no such remote ref %s"
+msgstr "沒有這樣的遠端引用 %s"
+
+#: fetch-pack.c:1815
+#, c-format
+msgid "Server does not allow request for unadvertised object %s"
+msgstr "伺服器不允許請求未公開的物件 %s"
+
+#: gpg-interface.c:223
+msgid "could not create temporary file"
+msgstr "不能建立暫存檔"
+
+#: gpg-interface.c:226
+#, c-format
+msgid "failed writing detached signature to '%s'"
+msgstr "無法將分離式簽名寫入 '%s'"
+
+#: gpg-interface.c:390
+msgid "gpg failed to sign the data"
+msgstr "gpg 無法為資料簽名"
+
+#: graph.c:98
+#, c-format
+msgid "ignore invalid color '%.*s' in log.graphColors"
+msgstr "忽略 log.graphColors 中無效的顏色 '%.*s'"
+
+#: grep.c:668
+msgid ""
+"given pattern contains NULL byte (via -f <file>). This is only supported "
+"with -P under PCRE v2"
+msgstr ""
+"提供的模式包含 NULL 字元（通過 -f <檔案> 參數）。只有 PCRE v2 下的 -P 支援此"
+"功能"
+
+#: grep.c:2124
+#, c-format
+msgid "'%s': unable to read %s"
+msgstr "'%s'：無法讀取 %s"
+
+#: grep.c:2141 setup.c:165 builtin/clone.c:411 builtin/diff.c:82
+#: builtin/rm.c:135
+#, c-format
+msgid "failed to stat '%s'"
+msgstr "對 '%s' 呼叫 stat 失敗"
+
+#: grep.c:2152
+#, c-format
+msgid "'%s': short read"
+msgstr "'%s'：讀取不完整"
+
+#: help.c:23
+msgid "start a working area (see also: git help tutorial)"
+msgstr "開始一個工作區（參見：git help tutorial）"
+
+#: help.c:24
+msgid "work on the current change (see also: git help everyday)"
+msgstr "在目前變更上工作（參見：git help everyday）"
+
+#: help.c:25
+msgid "examine the history and state (see also: git help revisions)"
+msgstr "檢查歷史和狀態（參見：git help revisions）"
+
+#: help.c:26
+msgid "grow, mark and tweak your common history"
+msgstr "擴展、標記和調校您的歷史記錄"
+
+#: help.c:27
+msgid "collaborate (see also: git help workflows)"
+msgstr "協同（參見：git help workflows）"
+
+#: help.c:31
+msgid "Main Porcelain Commands"
+msgstr "主要的上層指令"
+
+#: help.c:32
+msgid "Ancillary Commands / Manipulators"
+msgstr "輔助指令/動作者"
+
+#: help.c:33
+msgid "Ancillary Commands / Interrogators"
+msgstr "輔助指令/詢問者"
+
+#: help.c:34
+msgid "Interacting with Others"
+msgstr "與其它系統互動"
+
+#: help.c:35
+msgid "Low-level Commands / Manipulators"
+msgstr "低級指令/動作者"
+
+#: help.c:36
+msgid "Low-level Commands / Interrogators"
+msgstr "低級指令/詢問者"
+
+#: help.c:37
+#| msgid "Low-level Commands / Synching Repositories"
+msgid "Low-level Commands / Syncing Repositories"
+msgstr "低級指令 / 同步版本庫"
+
+#: help.c:38
+msgid "Low-level Commands / Internal Helpers"
+msgstr "低級指令/內部助手"
+
+#: help.c:298
+#, c-format
+msgid "available git commands in '%s'"
+msgstr "在 '%s' 下可用的 git 指令"
+
+#: help.c:305
+msgid "git commands available from elsewhere on your $PATH"
+msgstr "在 $PATH 路徑中的其他地方可用的 git 指令"
+
+#: help.c:314
+msgid "These are common Git commands used in various situations:"
+msgstr "這些是各種場合常見的 Git 指令："
+
+#: help.c:363 git.c:98
+#, c-format
+msgid "unsupported command listing type '%s'"
+msgstr "不支援的指令列表類型 '%s'"
+
+#: help.c:403
+msgid "The common Git guides are:"
+msgstr "最常用的 Git 嚮導有："
+
+#: help.c:512
+msgid "See 'git help <command>' to read about a specific subcommand"
+msgstr "執行　'git help <command>' 來檢視特定子指令"
+
+#: help.c:517
+msgid "External commands"
+msgstr "外部指令"
+
+#: help.c:532
+msgid "Command aliases"
+msgstr "指令別名"
+
+#: help.c:596
+#, c-format
+msgid ""
+"'%s' appears to be a git command, but we were not\n"
+"able to execute it. Maybe git-%s is broken?"
+msgstr ""
+"'%s' 像是一個 git 指令，但卻無法執行。\n"
+"可能是 git-%s 受損？"
+
+#: help.c:655
+msgid "Uh oh. Your system reports no Git commands at all."
+msgstr "唉呀，您的系統中未發現 Git 指令。"
+
+#: help.c:677
+#, c-format
+msgid "WARNING: You called a Git command named '%s', which does not exist."
+msgstr "警告：您執行了一個並不存在的 Git 指令 '%s'。"
+
+#: help.c:682
+#, c-format
+msgid "Continuing under the assumption that you meant '%s'."
+msgstr "假定你想要的是 '%s' 並繼續。"
+
+#: help.c:687
+#, c-format
+msgid "Continuing in %0.1f seconds, assuming that you meant '%s'."
+msgstr "假定你想要的是 '%2$s'，在 %1$0.1f 秒鐘後繼續。"
+
+#: help.c:695
+#, c-format
+msgid "git: '%s' is not a git command. See 'git --help'."
+msgstr "git：'%s' 不是一個 git 指令。參見 'git --help'。"
+
+#: help.c:699
+msgid ""
+"\n"
+"The most similar command is"
+msgid_plural ""
+"\n"
+"The most similar commands are"
+msgstr[0] ""
+"\n"
+"最類似的指令有"
+msgstr[1] ""
+"\n"
+"最類似的指令有"
+
+#: help.c:714
+msgid "git version [<options>]"
+msgstr "git version [<選項>]"
+
+#: help.c:783
+#, c-format
+msgid "%s: %s - %s"
+msgstr "%s：%s - %s"
+
+#: help.c:787
+msgid ""
+"\n"
+"Did you mean this?"
+msgid_plural ""
+"\n"
+"Did you mean one of these?"
+msgstr[0] ""
+"\n"
+"您指的是這個嗎？"
+msgstr[1] ""
+"\n"
+"您指的是這其中的某一個嗎？"
+
+#: ident.c:349
+msgid ""
+"\n"
+"*** Please tell me who you are.\n"
+"\n"
+"Run\n"
+"\n"
+"  git config --global user.email \"you@example.com\"\n"
+"  git config --global user.name \"Your Name\"\n"
+"\n"
+"to set your account's default identity.\n"
+"Omit --global to set the identity only in this repository.\n"
+"\n"
+msgstr ""
+"\n"
+"*** 請告訴我你是誰。\n"
+"\n"
+"執行\n"
+"\n"
+"  git config --global user.email \"you@example.com\"\n"
+"  git config --global user.name \"Your Name\"\n"
+"\n"
+"來設定您帳號的預設身份標記。\n"
+"如果僅在本版本庫設定身份標記，則省略 --global 參數。\n"
+
+#: ident.c:379
+msgid "no email was given and auto-detection is disabled"
+msgstr "未提供信件位址且自動偵測被禁用"
+
+#: ident.c:384
+#, c-format
+msgid "unable to auto-detect email address (got '%s')"
+msgstr "無法自動偵測信件位址（得到 '%s'）"
+
+#: ident.c:401
+msgid "no name was given and auto-detection is disabled"
+msgstr "未提供姓名且自動偵測被禁用"
+
+#: ident.c:407
+#, c-format
+msgid "unable to auto-detect name (got '%s')"
+msgstr "無法自動偵測姓名（得到 '%s'）"
+
+#: ident.c:415
+#, c-format
+msgid "empty ident name (for <%s>) not allowed"
+msgstr "不允許空的姓名（對於 <%s>）"
+
+#: ident.c:421
+#, c-format
+msgid "name consists only of disallowed characters: %s"
+msgstr "姓名中僅包含禁用字元：%s"
+
+#: ident.c:436 builtin/commit.c:631
+#, c-format
+msgid "invalid date format: %s"
+msgstr "無效的日期格式：%s"
+
+#: list-objects.c:127
+#, c-format
+msgid "entry '%s' in tree %s has tree mode, but is not a tree"
+msgstr "樹 %2$s 中的條目 '%1$s' 具有樹的屬性，但不是一個樹狀物件"
+
+#: list-objects.c:140
+#, c-format
+msgid "entry '%s' in tree %s has blob mode, but is not a blob"
+msgstr "樹 %2$s 中的條目 '%1$s' 具有資料物件的屬性，但不是一個資料物件"
+
+#: list-objects.c:375
+#, c-format
+msgid "unable to load root tree for commit %s"
+msgstr "無法為提交 %s 載入根樹"
+
+#: list-objects-filter.c:492
+#, c-format
+msgid "unable to access sparse blob in '%s'"
+msgstr "不能存取 '%s' 中的稀疏資料物件"
+
+#: list-objects-filter.c:495
+#, c-format
+msgid "unable to parse sparse filter data in %s"
+msgstr "無法解析 %s 中的稀疏過濾器資料"
+
+#: list-objects-filter-options.c:58
+msgid "expected 'tree:<depth>'"
+msgstr "期望 'tree:<深度>'"
+
+#: list-objects-filter-options.c:73
+msgid "sparse:path filters support has been dropped"
+msgstr "sparse:path 過濾器支援已被刪除"
+
+#: list-objects-filter-options.c:86
+#, c-format
+msgid "invalid filter-spec '%s'"
+msgstr "無效的過濾器表達式 '%s'"
+
+#: list-objects-filter-options.c:102
+#, c-format
+msgid "must escape char in sub-filter-spec: '%c'"
+msgstr "必須對 sub-filter-spec 中的字元進行轉義：'%c'"
+
+#: list-objects-filter-options.c:144
+msgid "expected something after combine:"
+msgstr "期望在組合後有一些東西："
+
+#: list-objects-filter-options.c:226
+msgid "multiple filter-specs cannot be combined"
+msgstr "不能混用多種過濾規格"
+
+#: lockfile.c:151
+#, c-format
+msgid ""
+"Unable to create '%s.lock': %s.\n"
+"\n"
+"Another git process seems to be running in this repository, e.g.\n"
+"an editor opened by 'git commit'. Please make sure all processes\n"
+"are terminated then try again. If it still fails, a git process\n"
+"may have crashed in this repository earlier:\n"
+"remove the file manually to continue."
+msgstr ""
+"無法建立 '%s.lock'：%s。\n"
+"\n"
+"似乎另外一個 git 進程在這個版本庫中執行，例如：'git commit' 指令打\n"
+"開了一個編輯器。請確認所有進程都已經關閉然後重試。如果仍然報錯，\n"
+"可能之前有一個 git 進程在這個版本庫中異常離開：\n"
+"手動刪除這個檔案再繼續。"
+
+#: lockfile.c:159
+#, c-format
+msgid "Unable to create '%s.lock': %s"
+msgstr "不能建立 '%s.lock'：%s"
+
+#: merge.c:41
+msgid "failed to read the cache"
+msgstr "讀取快取失敗"
+
+#: merge.c:107 rerere.c:720 builtin/am.c:1874 builtin/am.c:1908
+#: builtin/checkout.c:539 builtin/checkout.c:798 builtin/clone.c:809
+#: builtin/stash.c:264
+msgid "unable to write new index file"
+msgstr "無法寫新的索引檔案"
+
+#: merge-recursive.c:367
+msgid "(bad commit)\n"
+msgstr "（壞提交）\n"
+
+#: merge-recursive.c:390
+#, c-format
+msgid "add_cacheinfo failed for path '%s'; merge aborting."
+msgstr "add_cacheinfo 對路徑 '%s' 執行失敗，合併終止。"
+
+#: merge-recursive.c:399
+#, c-format
+msgid "add_cacheinfo failed to refresh for path '%s'; merge aborting."
+msgstr "add_cacheinfo 無法重新整理路徑 '%s'，合併終止。"
+
+#: merge-recursive.c:885
+#, c-format
+msgid "failed to create path '%s'%s"
+msgstr "建立路徑 '%s'%s 失敗"
+
+#: merge-recursive.c:896
+#, c-format
+msgid "Removing %s to make room for subdirectory\n"
+msgstr "刪除 %s 以便為子目錄留出空間\n"
+
+#: merge-recursive.c:910 merge-recursive.c:929
+msgid ": perhaps a D/F conflict?"
+msgstr "：可能是一個目錄/檔案衝突？"
+
+#: merge-recursive.c:919
+#, c-format
+msgid "refusing to lose untracked file at '%s'"
+msgstr "拒絕捨棄 '%s' 中的未追蹤檔案"
+
+#: merge-recursive.c:960 builtin/cat-file.c:41
+#, c-format
+msgid "cannot read object %s '%s'"
+msgstr "不能讀取物件 %s '%s'"
+
+#: merge-recursive.c:965
+#, c-format
+msgid "blob expected for %s '%s'"
+msgstr "%s '%s' 應為資料物件"
+
+#: merge-recursive.c:990
+#, c-format
+msgid "failed to open '%s': %s"
+msgstr "開啟 '%s' 失敗：%s"
+
+#: merge-recursive.c:1001
+#, c-format
+msgid "failed to symlink '%s': %s"
+msgstr "建立符號連結 '%s' 失敗：%s"
+
+#: merge-recursive.c:1006
+#, c-format
+msgid "do not know what to do with %06o %s '%s'"
+msgstr "不知道如何處理 %06o %s '%s'"
+
+#: merge-recursive.c:1199
+#, c-format
+msgid "Failed to merge submodule %s (not checked out)"
+msgstr "無法合併子模組 %s （沒有簽出）"
+
+#: merge-recursive.c:1206
+#, c-format
+msgid "Failed to merge submodule %s (commits not present)"
+msgstr "無法合併子模組 %s（提交不存在）"
+
+#: merge-recursive.c:1213
+#, c-format
+msgid "Failed to merge submodule %s (commits don't follow merge-base)"
+msgstr "無法合併子模組 %s （提交未跟隨合併基礎）"
+
+#: merge-recursive.c:1221 merge-recursive.c:1233
+#, c-format
+msgid "Fast-forwarding submodule %s to the following commit:"
+msgstr "子模組 %s 快轉到如下提交："
+
+#: merge-recursive.c:1224 merge-recursive.c:1236
+#, c-format
+msgid "Fast-forwarding submodule %s"
+msgstr "快轉子模組 %s"
+
+#: merge-recursive.c:1259
+#, c-format
+msgid "Failed to merge submodule %s (merge following commits not found)"
+msgstr "無法合併子模組 %s （沒發現合併跟隨的提交）"
+
+#: merge-recursive.c:1263
+#, c-format
+msgid "Failed to merge submodule %s (not fast-forward)"
+msgstr "無法合併子模組 %s（非快轉）"
+
+#: merge-recursive.c:1264
+msgid "Found a possible merge resolution for the submodule:\n"
+msgstr "找到子模組的一個可能的合併方案：\n"
+
+#: merge-recursive.c:1267
+#, c-format
+msgid ""
+"If this is correct simply add it to the index for example\n"
+"by using:\n"
+"\n"
+"  git update-index --cacheinfo 160000 %s \"%s\"\n"
+"\n"
+"which will accept this suggestion.\n"
+msgstr ""
+"如果這個正確，將其新增到索引，例如使用指令：\n"
+"\n"
+"  git update-index --cacheinfo 160000 %s \"%s\"\n"
+"\n"
+"以接受此建議。\n"
+
+#: merge-recursive.c:1276
+#, c-format
+msgid "Failed to merge submodule %s (multiple merges found)"
+msgstr "無法合併子模組 %s （發現多個合併）"
+
+#: merge-recursive.c:1349
+msgid "Failed to execute internal merge"
+msgstr "無法執行內部合併"
+
+#: merge-recursive.c:1354
+#, c-format
+msgid "Unable to add %s to database"
+msgstr "不能新增 %s 至物件庫"
+
+#: merge-recursive.c:1386
+#, c-format
+msgid "Auto-merging %s"
+msgstr "自動合併 %s"
+
+#: merge-recursive.c:1410
+#, c-format
+msgid "Error: Refusing to lose untracked file at %s; writing to %s instead."
+msgstr "錯誤：拒絕遺失未追蹤檔案 '%s'，而是寫入 %s。"
+
+#: merge-recursive.c:1482
+#, c-format
+msgid ""
+"CONFLICT (%s/delete): %s deleted in %s and %s in %s. Version %s of %s left "
+"in tree."
+msgstr ""
+"衝突（%1$s/刪除）：%2$s 在 %3$s 中被刪除，在 %5$s 中被 %4$s。%7$s 的 %6$s 版"
+"本被保留。"
+
+#: merge-recursive.c:1487
+#, c-format
+msgid ""
+"CONFLICT (%s/delete): %s deleted in %s and %s to %s in %s. Version %s of %s "
+"left in tree."
+msgstr ""
+"衝突（%1$s/刪除）：%2$s 在 %3$s 中被刪除，在 %6$s 中的 %5$s 被 %4$s。%8$s 的 "
+"%7$s 版本被保留。"
+
+#: merge-recursive.c:1494
+#, c-format
+msgid ""
+"CONFLICT (%s/delete): %s deleted in %s and %s in %s. Version %s of %s left "
+"in tree at %s."
+msgstr ""
+"衝突（%1$s/刪除）：%2$s 在 %3$s 中被刪除，在 %5$s 中被 %4$s。%7$s 的 %6$s 版"
+"本保留在 %8$s 中。"
+
+#: merge-recursive.c:1499
+#, c-format
+msgid ""
+"CONFLICT (%s/delete): %s deleted in %s and %s to %s in %s. Version %s of %s "
+"left in tree at %s."
+msgstr ""
+"衝突（%1$s/刪除）：%2$s 在 %3$s 中被刪除，在 %6$s 中的 %5$s 被 %4$s。%8$s 的 "
+"%7$s 版本保留在 %9$s 中。"
+
+#: merge-recursive.c:1534
+msgid "rename"
+msgstr "重新命名"
+
+#: merge-recursive.c:1534
+msgid "renamed"
+msgstr "重新命名"
+
+#: merge-recursive.c:1614 merge-recursive.c:2530 merge-recursive.c:3175
+#, c-format
+msgid "Refusing to lose dirty file at %s"
+msgstr "拒絕遺失髒檔案 '%s'"
+
+#: merge-recursive.c:1624
+#, c-format
+msgid "Refusing to lose untracked file at %s, even though it's in the way."
+msgstr "拒絕在 '%s' 處失去未追蹤檔案，即使它存在於重新命名中。"
+
+#: merge-recursive.c:1682
+#, c-format
+msgid "CONFLICT (rename/add): Rename %s->%s in %s.  Added %s in %s"
+msgstr "衝突（重新命名/新增）：在 %3$s 中重新命名 %1$s->%2$s。在 %5$s 中新增 %4$s"
+
+#: merge-recursive.c:1713
+#, c-format
+msgid "%s is a directory in %s adding as %s instead"
+msgstr "%s 是 %s 中的一個目錄而已 %s 為名被新增"
+
+#: merge-recursive.c:1718
+#, c-format
+msgid "Refusing to lose untracked file at %s; adding as %s instead"
+msgstr "拒絕遺失未追蹤檔案 '%s'，而是新增為 %s"
+
+#: merge-recursive.c:1737
+#, c-format
+msgid ""
+"CONFLICT (rename/rename): Rename \"%s\"->\"%s\" in branch \"%s\" rename \"%s"
+"\"->\"%s\" in \"%s\"%s"
+msgstr ""
+"衝突（重新命名/重新命名）：在分支 \"%3$s\" 中重新命名 \"%1$s\"->\"%2$s\"，在"
+"分支 \"%6$s\" 中重新命名 \"%4$s\"->\"%5$s\"%7$s"
+
+#: merge-recursive.c:1742
+msgid " (left unresolved)"
+msgstr "（留下未解決）"
+
+#: merge-recursive.c:1851
+#, c-format
+msgid "CONFLICT (rename/rename): Rename %s->%s in %s. Rename %s->%s in %s"
+msgstr ""
+"衝突（重新命名/重新命名）：在 %3$s 中重新命名 %1$s->%2$s，在 %6$s 中重新命名 "
+"%4$s->%5$s"
+
+#: merge-recursive.c:2114
+#, c-format
+msgid ""
+"CONFLICT (directory rename split): Unclear where to place %s because "
+"directory %s was renamed to multiple other directories, with no destination "
+"getting a majority of the files."
+msgstr ""
+"衝突（分割的目錄重新命名）：不清楚 %s 應該放在哪裡，因為目錄 %s 被重新命名到"
+"多個其它目錄，沒有目錄包含大部分檔案。"
+
+#: merge-recursive.c:2146
+#, c-format
+msgid ""
+"CONFLICT (implicit dir rename): Existing file/dir at %s in the way of "
+"implicit directory rename(s) putting the following path(s) there: %s."
+msgstr ""
+"衝突（隱式目錄重新命名）：處於隱式目錄重新命名的現存檔案/目錄 %s，將以下路徑"
+"放在：%s。"
+
+#: merge-recursive.c:2156
+#, c-format
+msgid ""
+"CONFLICT (implicit dir rename): Cannot map more than one path to %s; "
+"implicit directory renames tried to put these paths there: %s"
+msgstr ""
+"衝突（隱式目錄重新命名）：無法映射一個以上路徑到 %s，隱式目錄重新命名嘗試將這"
+"些路徑放置於此：%s"
+
+#: merge-recursive.c:2248
+#, c-format
+msgid ""
+"CONFLICT (rename/rename): Rename directory %s->%s in %s. Rename directory %s-"
+">%s in %s"
+msgstr ""
+"衝突（重新命名/重新命名）：在 %3$s 中重新命名目錄 %1$s->%2$s，在 %6$s 中重新"
+"命名目錄 %4$s->%5$s"
+
+#: merge-recursive.c:2493
+#, c-format
+msgid ""
+"WARNING: Avoiding applying %s -> %s rename to %s, because %s itself was "
+"renamed."
+msgstr "警告：避免應用 %s -> %s 的重新命名到 %s，因為 %s 本身已被重新命名。"
+
+#: merge-recursive.c:3019
+#, c-format
+msgid "cannot read object %s"
+msgstr "不能讀取物件 %s"
+
+#: merge-recursive.c:3022
+#, c-format
+msgid "object %s is not a blob"
+msgstr "物件 %s 不是一個資料物件"
+
+#: merge-recursive.c:3086
+msgid "modify"
+msgstr "修改"
+
+#: merge-recursive.c:3086
+msgid "modified"
+msgstr "修改"
+
+#: merge-recursive.c:3098
+msgid "content"
+msgstr "內容"
+
+#: merge-recursive.c:3102
+msgid "add/add"
+msgstr "新增/新增"
+
+#: merge-recursive.c:3125
+#, c-format
+msgid "Skipped %s (merged same as existing)"
+msgstr "略過 %s（已經做過相同合併）"
+
+#: merge-recursive.c:3147 git-submodule.sh:993
+msgid "submodule"
+msgstr "子模組"
+
+#: merge-recursive.c:3148
+#, c-format
+msgid "CONFLICT (%s): Merge conflict in %s"
+msgstr "衝突（%s）：合併衝突於 %s"
+
+#: merge-recursive.c:3178
+#, c-format
+msgid "Adding as %s instead"
+msgstr "而是以 %s 為名新增"
+
+#: merge-recursive.c:3261
+#, c-format
+msgid ""
+"Path updated: %s added in %s inside a directory that was renamed in %s; "
+"moving it to %s."
+msgstr "路徑已更新：%s 新增到 %s，位於一個被重新命名到 %s 的目錄中，將其移動到 %s。"
+
+#: merge-recursive.c:3264
+#, c-format
+msgid ""
+"CONFLICT (file location): %s added in %s inside a directory that was renamed "
+"in %s, suggesting it should perhaps be moved to %s."
+msgstr ""
+"衝突（檔案位置）：%s 新增到 %s，位於一個被重新命名為 %s 的目錄中，建議將其移"
+"動到 %s。"
+
+#: merge-recursive.c:3268
+#, c-format
+msgid ""
+"Path updated: %s renamed to %s in %s, inside a directory that was renamed in "
+"%s; moving it to %s."
+msgstr ""
+"路徑已更新：%1$s 重新命名為 %3$s 中的 %2$s，而該目錄被重新命名到 %4$s 中，將"
+"其移動到 %5$s。"
+
+#: merge-recursive.c:3271
+#, c-format
+msgid ""
+"CONFLICT (file location): %s renamed to %s in %s, inside a directory that "
+"was renamed in %s, suggesting it should perhaps be moved to %s."
+msgstr ""
+"衝突（檔案位置）：%1$s 重新命名為 %3$s 中的 %2$s，而該目錄被重新命名到 %4$s "
+"中，建議將其移動到 %5$s。"
+
+#: merge-recursive.c:3385
+#, c-format
+msgid "Removing %s"
+msgstr "刪除 %s"
+
+#: merge-recursive.c:3408
+msgid "file/directory"
+msgstr "檔案/目錄"
+
+#: merge-recursive.c:3413
+msgid "directory/file"
+msgstr "目錄/檔案"
+
+#: merge-recursive.c:3420
+#, c-format
+msgid "CONFLICT (%s): There is a directory with name %s in %s. Adding %s as %s"
+msgstr "衝突（%1$s）：在 %3$s 中有一個名為 %2$s 的目錄。以 %5$s 為名新增 %4$s"
+
+#: merge-recursive.c:3429
+#, c-format
+msgid "Adding %s"
+msgstr "新增 %s"
+
+#: merge-recursive.c:3438
+#, c-format
+msgid "CONFLICT (add/add): Merge conflict in %s"
+msgstr "衝突（add/add）：合併衝突於 %s"
+
+#: merge-recursive.c:3482
+msgid "Already up to date!"
+msgstr "已經是最新的！"
+
+#: merge-recursive.c:3491
+#, c-format
+msgid "merging of trees %s and %s failed"
+msgstr "無法合併樹 %s 和 %s"
+
+#: merge-recursive.c:3595
+msgid "Merging:"
+msgstr "合併："
+
+#: merge-recursive.c:3608
+#, c-format
+msgid "found %u common ancestor:"
+msgid_plural "found %u common ancestors:"
+msgstr[0] "發現 %u 個共同祖先："
+msgstr[1] "發現 %u 個共同祖先："
+
+#: merge-recursive.c:3658
+msgid "merge returned no commit"
+msgstr "合併未返回提交"
+
+#: merge-recursive.c:3717
+#, c-format
+msgid ""
+"Your local changes to the following files would be overwritten by merge:\n"
+"  %s"
+msgstr ""
+"您對下列檔案的本機修改將被合併動作覆蓋：\n"
+"  %s"
+
+#: merge-recursive.c:3814
+#, c-format
+msgid "Could not parse object '%s'"
+msgstr "不能解析物件 '%s'"
+
+#: merge-recursive.c:3832 builtin/merge.c:694 builtin/merge.c:874
+msgid "Unable to write index."
+msgstr "不能寫入索引。"
+
+#: midx.c:68
+#, c-format
+msgid "multi-pack-index file %s is too small"
+msgstr "多包索引檔案 %s 太小"
+
+#: midx.c:84
+#, c-format
+msgid "multi-pack-index signature 0x%08x does not match signature 0x%08x"
+msgstr "多包索引簽名 0x%08x 和簽名 0x%08x 不符合"
+
+#: midx.c:89
+#, c-format
+msgid "multi-pack-index version %d not recognized"
+msgstr "multi-pack-index 版本 %d 不能被識別"
+
+#: midx.c:94
+#, c-format
+msgid "hash version %u does not match"
+msgstr "散列版本 %u 不符合"
+
+#: midx.c:108
+msgid "invalid chunk offset (too large)"
+msgstr "無效的區塊位移（太大）"
+
+#: midx.c:132
+msgid "terminating multi-pack-index chunk id appears earlier than expected"
+msgstr "終止多包索引區塊 id 出現時間早於預期"
+
+#: midx.c:145
+msgid "multi-pack-index missing required pack-name chunk"
+msgstr "多包索引缺少必需的包名塊"
+
+#: midx.c:147
+msgid "multi-pack-index missing required OID fanout chunk"
+msgstr "多包索引缺少必需的物件 ID 扇出塊"
+
+#: midx.c:149
+msgid "multi-pack-index missing required OID lookup chunk"
+msgstr "多包索引缺少必需的物件 ID 查詢塊"
+
+#: midx.c:151
+msgid "multi-pack-index missing required object offsets chunk"
+msgstr "多包索引缺少必需的物件位移塊"
+
+#: midx.c:165
+#, c-format
+msgid "multi-pack-index pack names out of order: '%s' before '%s'"
+msgstr "多包索引包名無序：'%s' 在 '%s' 之前"
+
+#: midx.c:210
+#, c-format
+msgid "bad pack-int-id: %u (%u total packs)"
+msgstr "錯的 pack-int-id：%u（共有 %u 個包）"
+
+#: midx.c:260
+msgid "multi-pack-index stores a 64-bit offset, but off_t is too small"
+msgstr "多包索引儲存一個64位位移，但是 off_t 太小"
+
+#: midx.c:288
+msgid "error preparing packfile from multi-pack-index"
+msgstr "從多包索引準備 packfile 時發生錯誤"
+
+#: midx.c:472
+#, c-format
+msgid "failed to add packfile '%s'"
+msgstr "新增 packfile '%s' 失敗"
+
+#: midx.c:478
+#, c-format
+msgid "failed to open pack-index '%s'"
+msgstr "開啟包索引 '%s' 失敗"
+
+#: midx.c:538
+#, c-format
+msgid "failed to locate object %d in packfile"
+msgstr "在 packfile 中定位物件 %d 失敗"
+
+#: midx.c:842
+#| msgid "error preparing packfile from multi-pack-index"
+msgid "Adding packfiles to multi-pack-index"
+msgstr "正在新增 packfile 至多包索引"
+
+#: midx.c:875
+#, c-format
+msgid "did not see pack-file %s to drop"
+msgstr "沒有看到要捨棄的包檔案 %s"
+
+#: midx.c:973
+#| msgid "Write and verify multi-pack-indexes"
+msgid "Writing chunks to multi-pack-index"
+msgstr "寫入區塊至多包索引"
+
+#: midx.c:1052
+#, c-format
+msgid "failed to clear multi-pack-index at %s"
+msgstr "清理位於 %s 的多包索引失敗"
+
+#: midx.c:1108
+msgid "Looking for referenced packfiles"
+msgstr "正在尋找引用的 packfile"
+
+#: midx.c:1123
+#, c-format
+msgid ""
+"oid fanout out of order: fanout[%d] = %<PRIx32> > %<PRIx32> = fanout[%d]"
+msgstr "物件 ID 扇出無序：fanout[%d] = %<PRIx32> > %<PRIx32> = fanout[%d]"
+
+#: midx.c:1128
+#| msgid "Verifying OID order in MIDX"
+msgid "Verifying OID order in multi-pack-index"
+msgstr "正在驗證多包索引中的物件 ID 順序"
+
+#: midx.c:1137
+#, c-format
+msgid "oid lookup out of order: oid[%d] = %s >= %s = oid[%d]"
+msgstr "物件 ID 查詢無序：oid[%d] = %s >= %s = oid[%d]"
+
+#: midx.c:1157
+msgid "Sorting objects by packfile"
+msgstr "透過 packfile 為物件排序"
+
+#: midx.c:1164
+msgid "Verifying object offsets"
+msgstr "正在驗證物件位移"
+
+#: midx.c:1180
+#, c-format
+msgid "failed to load pack entry for oid[%d] = %s"
+msgstr "為 oid[%d] = %s 載入包條目失敗"
+
+#: midx.c:1186
+#, c-format
+msgid "failed to load pack-index for packfile %s"
+msgstr "為 packfile %s 載入包索引失敗"
+
+#: midx.c:1195
+#, c-format
+msgid "incorrect object offset for oid[%d] = %s: %<PRIx64> != %<PRIx64>"
+msgstr "oid[%d] = %s 錯誤的物件位移：%<PRIx64> != %<PRIx64>"
+
+#: midx.c:1220
+#| msgid "prune unreferenced objects"
+msgid "Counting referenced objects"
+msgstr "正在計算引用物件"
+
+#: midx.c:1230
+#| msgid "Looking for referenced packfiles"
+msgid "Finding and deleting unreferenced packfiles"
+msgstr "正在尋找並刪除沒有參考的 packfile"
+
+#: midx.c:1388
+msgid "could not start pack-objects"
+msgstr "不能開始 pack-objects"
+
+#: midx.c:1407
+msgid "could not finish pack-objects"
+msgstr "不能結束 pack-objects"
+
+#: name-hash.c:537
+#, c-format
+msgid "unable to create lazy_dir thread: %s"
+msgstr "不能建立 lazy_dir 執行緒：%s"
+
+#: name-hash.c:559
+#, c-format
+msgid "unable to create lazy_name thread: %s"
+msgstr "不能建立 lazy_name 執行緒：%s"
+
+#: name-hash.c:565
+#, c-format
+msgid "unable to join lazy_name thread: %s"
+msgstr "不能加入 lasy_name 執行緒：%s"
+
+#: notes-merge.c:277
+#, c-format
+msgid ""
+"You have not concluded your previous notes merge (%s exists).\n"
+"Please, use 'git notes merge --commit' or 'git notes merge --abort' to "
+"commit/abort the previous merge before you start a new notes merge."
+msgstr ""
+"您的前一次備註合併尚未結束（存在 %s）。\n"
+"在開始一個新的備註合併之前，請使用 'git notes merge --commit' 或者 'git "
+"notes merge --abort' 來提交/終止前一次合併。"
+
+#: notes-merge.c:284
+#, c-format
+msgid "You have not concluded your notes merge (%s exists)."
+msgstr "您尚未結束備註合併（存在 %s）。"
+
+#: notes-utils.c:46
+msgid "Cannot commit uninitialized/unreferenced notes tree"
+msgstr "不能提交未初始化/未引用的註解樹"
+
+#: notes-utils.c:105
+#, c-format
+msgid "Bad notes.rewriteMode value: '%s'"
+msgstr "壞的 notes.rewriteMode 值：'%s'"
+
+#: notes-utils.c:115
+#, c-format
+msgid "Refusing to rewrite notes in %s (outside of refs/notes/)"
+msgstr "拒絕向 %s（在 refs/notes/ 之外）寫入註解"
+
+#. TRANSLATORS: The first %s is the name of
+#. the environment variable, the second %s is
+#. its value.
+#.
+#: notes-utils.c:145
+#, c-format
+msgid "Bad %s value: '%s'"
+msgstr "壞的 %s 值：'%s'"
+
+#: object.c:53
+#, c-format
+msgid "invalid object type \"%s\""
+msgstr "無效的物件類型 \"%s\""
+
+#: object.c:173
+#, c-format
+msgid "object %s is a %s, not a %s"
+msgstr "物件 %s 是一個 %s，不是一個 %s"
+
+#: object.c:233
+#, c-format
+msgid "object %s has unknown type id %d"
+msgstr "物件 %s 有未知的類型 id %d"
+
+#: object.c:246
+#, c-format
+msgid "unable to parse object: %s"
+msgstr "不能解析物件：%s"
+
+#: object.c:266 object.c:277
+#, c-format
+msgid "hash mismatch %s"
+msgstr "雜湊值與 %s 不符合"
+
+#: packfile.c:641
+msgid "offset before end of packfile (broken .idx?)"
+msgstr "位移量在 packfile 結束之前（損壞的 .idx？）"
+
+#: packfile.c:1888
+#, c-format
+msgid "offset before start of pack index for %s (corrupt index?)"
+msgstr "位移量在 %s 的包索引開始之前（損壞的索引？）"
+
+#: packfile.c:1892
+#, c-format
+msgid "offset beyond end of pack index for %s (truncated index?)"
+msgstr "位移量越過了 %s 的包索引的結尾（被截斷的索引？）"
+
+#: parse-options.c:38
+#, c-format
+msgid "%s requires a value"
+msgstr "%s 需要一個值"
+
+#: parse-options.c:73
+#, c-format
+msgid "%s is incompatible with %s"
+msgstr "%s 與 %s 不相容"
+
+#: parse-options.c:78
+#, c-format
+msgid "%s : incompatible with something else"
+msgstr "%s：和其它的不相容"
+
+#: parse-options.c:92 parse-options.c:96 parse-options.c:319
+#, c-format
+msgid "%s takes no value"
+msgstr "%s 不取值"
+
+#: parse-options.c:94
+#, c-format
+msgid "%s isn't available"
+msgstr "%s 不可用"
+
+#: parse-options.c:219
+#, c-format
+msgid "%s expects a non-negative integer value with an optional k/m/g suffix"
+msgstr "%s 期望一個非負整數和一個可選的 k/m/g 後綴"
+
+#: parse-options.c:389
+#, c-format
+msgid "ambiguous option: %s (could be --%s%s or --%s%s)"
+msgstr "有歧義的選項：%s（可以是 --%s%s 或 --%s%s）"
+
+#: parse-options.c:423 parse-options.c:431
+#, c-format
+msgid "did you mean `--%s` (with two dashes ?)"
+msgstr "你的意思是 `--%s`（有兩個短線？）"
+
+#: parse-options.c:860
+#, c-format
+msgid "unknown option `%s'"
+msgstr "未知選項 `%s'"
+
+#: parse-options.c:862
+#, c-format
+msgid "unknown switch `%c'"
+msgstr "未知開關 `%c'"
+
+#: parse-options.c:864
+#, c-format
+msgid "unknown non-ascii option in string: `%s'"
+msgstr "字串中未知的非 ascii 字元選項：`%s'"
+
+#: parse-options.c:888
+msgid "..."
+msgstr "..."
+
+#: parse-options.c:907
+#, c-format
+msgid "usage: %s"
+msgstr "用法：%s"
+
+#. TRANSLATORS: the colon here should align with the
+#. one in "usage: %s" translation.
+#.
+#: parse-options.c:913
+#, c-format
+msgid "   or: %s"
+msgstr "  或：%s"
+
+#  譯者：為保證在輸出中對齊，注意調整句中空格！
+#: parse-options.c:916
+#, c-format
+msgid "    %s"
+msgstr "    %s"
+
+#: parse-options.c:955
+msgid "-NUM"
+msgstr "-數字"
+
+#: parse-options.c:969
+#, c-format
+msgid "alias of --%s"
+msgstr "--%s 的別名"
+
+#: parse-options-cb.c:20 parse-options-cb.c:24
+#, c-format
+msgid "option `%s' expects a numerical value"
+msgstr "選項 `%s' 期望一個數字值"
+
+#: parse-options-cb.c:41
+#, c-format
+msgid "malformed expiration date '%s'"
+msgstr "格式錯誤的到期時間：'%s'"
+
+#: parse-options-cb.c:54
+#, c-format
+msgid "option `%s' expects \"always\", \"auto\", or \"never\""
+msgstr "選項 `%s' 期望 \"always\"、\"auto\" 或 \"never\""
+
+#: parse-options-cb.c:130 parse-options-cb.c:147
+#, c-format
+msgid "malformed object name '%s'"
+msgstr "格式錯誤的物件名 '%s'"
+
+#: path.c:915
+#, c-format
+msgid "Could not make %s writable by group"
+msgstr "不能設定 %s 為組可寫"
+
+#: pathspec.c:130
+msgid "Escape character '\\' not allowed as last character in attr value"
+msgstr "跳脫字元 '\\' 不能作為屬性值的最後一個字元"
+
+#: pathspec.c:148
+msgid "Only one 'attr:' specification is allowed."
+msgstr "只允許一個 'attr:' 規格。"
+
+#: pathspec.c:151
+msgid "attr spec must not be empty"
+msgstr "屬性規格不能為空"
+
+#: pathspec.c:194
+#, c-format
+msgid "invalid attribute name %s"
+msgstr "無效的屬性名 %s"
+
+#: pathspec.c:259
+msgid "global 'glob' and 'noglob' pathspec settings are incompatible"
+msgstr "全域的 'glob' 和 'noglob' 路徑規格設定不相容"
+
+#: pathspec.c:266
+msgid ""
+"global 'literal' pathspec setting is incompatible with all other global "
+"pathspec settings"
+msgstr "全域的 'literal' 路徑規格設定和其它的全域路徑規格設定不相容"
+
+#: pathspec.c:306
+msgid "invalid parameter for pathspec magic 'prefix'"
+msgstr "路徑規格包含無效的神奇前綴"
+
+#: pathspec.c:327
+#, c-format
+msgid "Invalid pathspec magic '%.*s' in '%s'"
+msgstr "在路徑規格 '%3$s' 中無效的神奇前綴 '%2$.*1$s'"
+
+#: pathspec.c:332
+#, c-format
+msgid "Missing ')' at the end of pathspec magic in '%s'"
+msgstr "路徑規格 '%s' 的神奇前綴結尾少了一個 ')'"
+
+#: pathspec.c:370
+#, c-format
+msgid "Unimplemented pathspec magic '%c' in '%s'"
+msgstr "路徑規格 '%2$s' 中包含未實現的神奇前綴 '%1$c'"
+
+#: pathspec.c:429
+#, c-format
+msgid "%s: 'literal' and 'glob' are incompatible"
+msgstr "%s：'literal' 和 'glob' 不相容"
+
+#: pathspec.c:442
+#, c-format
+msgid "%s: '%s' is outside repository"
+msgstr "%s：'%s' 在版本庫之外"
+
+#: pathspec.c:516
+#, c-format
+msgid "'%s' (mnemonic: '%c')"
+msgstr "'%s'（助記符：'%c'）"
+
+#: pathspec.c:526
+#, c-format
+msgid "%s: pathspec magic not supported by this command: %s"
+msgstr "%s：路徑規格神奇前綴不被此指令支援：%s"
+
+#: pathspec.c:593
+#, c-format
+msgid "pathspec '%s' is beyond a symbolic link"
+msgstr "路徑規格 '%s' 位於符號連結中"
+
+#: pathspec.c:638
+#, c-format
+msgid "line is badly quoted: %s"
+msgstr "某行不應該被括號括住：%s"
+
+#: pkt-line.c:92
+msgid "unable to write flush packet"
+msgstr "無法寫 flush 包"
+
+#: pkt-line.c:99
+msgid "unable to write delim packet"
+msgstr "無法寫 delim 包"
+
+#: pkt-line.c:106
+msgid "flush packet write failed"
+msgstr "flush 包寫錯誤"
+
+#: pkt-line.c:146 pkt-line.c:232
+msgid "protocol error: impossibly long line"
+msgstr "協定錯誤：不可能的長行"
+
+#: pkt-line.c:162 pkt-line.c:164
+msgid "packet write with format failed"
+msgstr "格式化包寫入錯誤"
+
+#: pkt-line.c:196
+msgid "packet write failed - data exceeds max packet size"
+msgstr "寫封包失敗：資料超過了包的最大長度"
+
+#: pkt-line.c:203 pkt-line.c:210
+msgid "packet write failed"
+msgstr "封包寫入失敗"
+
+#: pkt-line.c:295
+msgid "read error"
+msgstr "讀取錯誤"
+
+#: pkt-line.c:303
+msgid "the remote end hung up unexpectedly"
+msgstr "遠端意外掛斷了"
+
+#: pkt-line.c:331
+#, c-format
+msgid "protocol error: bad line length character: %.4s"
+msgstr "協定錯誤：錯誤的行長度字串：%.4s"
+
+#: pkt-line.c:341 pkt-line.c:346
+#, c-format
+msgid "protocol error: bad line length %d"
+msgstr "協定錯誤：錯誤的行長度 %d"
+
+#: pkt-line.c:362
+#, c-format
+msgid "remote error: %s"
+msgstr "遠端錯誤：%s"
+
+#: preload-index.c:119
+msgid "Refreshing index"
+msgstr "正在重新整理索引"
+
+#: preload-index.c:138
+#, c-format
+msgid "unable to create threaded lstat: %s"
+msgstr "無法建立執行緒 lstat：%s"
+
+#: pretty.c:981
+msgid "unable to parse --pretty format"
+msgstr "不能解析 --pretty 格式"
+
+#: promisor-remote.c:23
+msgid "Remote with no URL"
+msgstr "遠端未設定 URL"
+
+#: promisor-remote.c:58
+#, c-format
+msgid "promisor remote name cannot begin with '/': %s"
+msgstr "promisor 遠端名稱不能以 '/' 開始：%s"
+
+#: range-diff.c:75
+msgid "could not start `log`"
+msgstr "不能啟動 `log`"
+
+#: range-diff.c:77
+msgid "could not read `log` output"
+msgstr "不能讀取 `log` 的輸出"
+
+#: range-diff.c:96 sequencer.c:5163
+#, c-format
+msgid "could not parse commit '%s'"
+msgstr "不能解析提交 '%s'"
+
+#: range-diff.c:122
+#, c-format
+msgid "could not parse git header '%.*s'"
+msgstr "無法解析 git 頭 '%.*s'"
+
+#: range-diff.c:285
+msgid "failed to generate diff"
+msgstr "生成 diff 失敗"
+
+#: range-diff.c:518 range-diff.c:520
+#, c-format
+msgid "could not parse log for '%s'"
+msgstr "不能解析 '%s' 的日誌"
+
+#: read-cache.c:680
+#, c-format
+msgid "will not add file alias '%s' ('%s' already exists in index)"
+msgstr "將不會新增檔案別名 '%s'（'%s' 已經存在於索引中）"
+
+#: read-cache.c:696
+msgid "cannot create an empty blob in the object database"
+msgstr "不能在物件資料庫中建立空的資料物件"
+
+#: read-cache.c:718
+#, c-format
+msgid "%s: can only add regular files, symbolic links or git-directories"
+msgstr "%s：只能新增一般檔案、符號連結或 git 目錄"
+
+#: read-cache.c:723
+#, c-format
+msgid "'%s' does not have a commit checked out"
+msgstr "'%s' 沒有簽出一個提交"
+
+#: read-cache.c:775
+#, c-format
+msgid "unable to index file '%s'"
+msgstr "無法索引檔案 '%s'"
+
+#: read-cache.c:794
+#, c-format
+msgid "unable to add '%s' to index"
+msgstr "無法在索引中新增 '%s'"
+
+#: read-cache.c:805
+#, c-format
+msgid "unable to stat '%s'"
+msgstr "無法對 %s 執行 stat"
+
+#: read-cache.c:1325
+#, c-format
+msgid "'%s' appears as both a file and as a directory"
+msgstr "'%s' 看起來既是檔案又是目錄"
+
+#: read-cache.c:1531
+msgid "Refresh index"
+msgstr "重新整理索引"
+
+#: read-cache.c:1646
+#, c-format
+msgid ""
+"index.version set, but the value is invalid.\n"
+"Using version %i"
+msgstr ""
+"設定了 index.version，但是取值無效。\n"
+"使用版本 %i"
+
+#: read-cache.c:1656
+#, c-format
+msgid ""
+"GIT_INDEX_VERSION set, but the value is invalid.\n"
+"Using version %i"
+msgstr ""
+"設定了 GIT_INDEX_VERSION，但是取值無效。\n"
+"使用版本 %i"
+
+#: read-cache.c:1712
+#, c-format
+msgid "bad signature 0x%08x"
+msgstr "壞的簽名 0x%08x"
+
+#: read-cache.c:1715
+#, c-format
+msgid "bad index version %d"
+msgstr "壞的索引版本 %d"
+
+#: read-cache.c:1724
+msgid "bad index file sha1 signature"
+msgstr "壞的索引檔案 sha1 簽名"
+
+#: read-cache.c:1754
+#, c-format
+msgid "index uses %.4s extension, which we do not understand"
+msgstr "索引使用不被支援的 %.4s 擴展"
+
+#
+#: read-cache.c:1756
+#, c-format
+msgid "ignoring %.4s extension"
+msgstr "忽略 %.4s 擴展"
+
+#: read-cache.c:1793
+#, c-format
+msgid "unknown index entry format 0x%08x"
+msgstr "未知的索引條目格式 0x%08x"
+
+#: read-cache.c:1809
+#, c-format
+msgid "malformed name field in the index, near path '%s'"
+msgstr "索引中靠近路徑 '%s' 有錯誤的名稱欄位"
+
+#: read-cache.c:1866
+msgid "unordered stage entries in index"
+msgstr "索引中有未排序的暫存條目"
+
+#: read-cache.c:1869
+#, c-format
+msgid "multiple stage entries for merged file '%s'"
+msgstr "合併檔案 '%s' 有多個暫存條目"
+
+#: read-cache.c:1872
+#, c-format
+msgid "unordered stage entries for '%s'"
+msgstr "'%s' 的未排序暫存條目"
+
+#: read-cache.c:1978 read-cache.c:2266 rerere.c:565 rerere.c:599 rerere.c:1111
+#: builtin/add.c:499 builtin/check-ignore.c:178 builtin/checkout.c:470
+#: builtin/checkout.c:654 builtin/clean.c:967 builtin/commit.c:367
+#: builtin/diff-tree.c:120 builtin/grep.c:499 builtin/mv.c:145
+#: builtin/reset.c:246 builtin/rm.c:271 builtin/submodule--helper.c:332
+msgid "index file corrupt"
+msgstr "索引檔案損壞"
+
+#: read-cache.c:2119
+#, c-format
+msgid "unable to create load_cache_entries thread: %s"
+msgstr "無法建立 load_cache_entries 執行緒：%s"
+
+#: read-cache.c:2132
+#, c-format
+msgid "unable to join load_cache_entries thread: %s"
+msgstr "無法加入 load_cache_entries 執行緒：%s"
+
+#: read-cache.c:2165
+#, c-format
+msgid "%s: index file open failed"
+msgstr "%s：開啟索引檔案失敗"
+
+#: read-cache.c:2169
+#, c-format
+msgid "%s: cannot stat the open index"
+msgstr "%s：不能對開啟的索引執行 stat 動作"
+
+#: read-cache.c:2173
+#, c-format
+msgid "%s: index file smaller than expected"
+msgstr "%s：索引檔案比預期的小"
+
+#: read-cache.c:2177
+#, c-format
+msgid "%s: unable to map index file"
+msgstr "%s：無法對索引檔案執行 map 動作"
+
+#: read-cache.c:2219
+#, c-format
+msgid "unable to create load_index_extensions thread: %s"
+msgstr "無法建立 load_index_extensions 執行緒：%s"
+
+#: read-cache.c:2246
+#, c-format
+msgid "unable to join load_index_extensions thread: %s"
+msgstr "無法加入 load_index_extensions 執行緒：%s"
+
+#: read-cache.c:2278
+#, c-format
+msgid "could not freshen shared index '%s'"
+msgstr "無法重新整理共享索引 '%s'"
+
+#: read-cache.c:2325
+#, c-format
+msgid "broken index, expect %s in %s, got %s"
+msgstr "損壞的索引，期望在 %2$s 中的 %1$s，得到 %3$s"
+
+#: read-cache.c:3021 strbuf.c:1145 wrapper.c:622 builtin/merge.c:1119
+#, c-format
+msgid "could not close '%s'"
+msgstr "不能關閉 '%s'"
+
+#: read-cache.c:3124 sequencer.c:2429 sequencer.c:4069
+#, c-format
+msgid "could not stat '%s'"
+msgstr "不能對 '%s' 呼叫 stat"
+
+#: read-cache.c:3137
+#, c-format
+msgid "unable to open git dir: %s"
+msgstr "不能開啟 git 目錄：%s"
+
+#: read-cache.c:3149
+#, c-format
+msgid "unable to unlink: %s"
+msgstr "無法刪除：%s"
+
+#: read-cache.c:3174
+#, c-format
+msgid "cannot fix permission bits on '%s'"
+msgstr "不能修復 '%s' 的權限位"
+
+#: read-cache.c:3323
+#, c-format
+msgid "%s: cannot drop to stage #0"
+msgstr "%s：不能落到暫存區 #0"
+
+#: rebase-interactive.c:26
+#, c-format
+msgid ""
+"unrecognized setting %s for option rebase.missingCommitsCheck. Ignoring."
+msgstr "選項 rebase.missingCommitsCheck 的值 %s 無法識別。已忽略。"
+
+#: rebase-interactive.c:35
+msgid ""
+"\n"
+"Commands:\n"
+"p, pick <commit> = use commit\n"
+"r, reword <commit> = use commit, but edit the commit message\n"
+"e, edit <commit> = use commit, but stop for amending\n"
+"s, squash <commit> = use commit, but meld into previous commit\n"
+"f, fixup <commit> = like \"squash\", but discard this commit's log message\n"
+"x, exec <command> = run command (the rest of the line) using shell\n"
+"b, break = stop here (continue rebase later with 'git rebase --continue')\n"
+"d, drop <commit> = remove commit\n"
+"l, label <label> = label current HEAD with a name\n"
+"t, reset <label> = reset HEAD to a label\n"
+"m, merge [-C <commit> | -c <commit>] <label> [# <oneline>]\n"
+".       create a merge commit using the original merge commit's\n"
+".       message (or the oneline, if no original merge commit was\n"
+".       specified). Use -c <commit> to reword the commit message.\n"
+"\n"
+"These lines can be re-ordered; they are executed from top to bottom.\n"
+msgstr ""
+"\n"
+"指令:\n"
+"p, pick <提交> = 使用提交\n"
+"r, reword <提交> = 使用提交，但修改提交說明\n"
+"e, edit <提交> = 使用提交，進入 shell 以便進行提交修補\n"
+"s, squash <提交> = 使用提交，但融合到前一個提交\n"
+"f, fixup <提交> = 類似於 \"squash\"，但捨棄提交說明日誌\n"
+"x, exec <指令> = 使用 shell 執行指令（此行剩餘部分）\n"
+"b, break = 在此處停止（使用 'git rebase --continue' 繼續重定基底）\n"
+"d, drop <提交> = 刪除提交\n"
+"l, label <label> = 為目前 HEAD 打上標記\n"
+"t, reset <label> = 重設 HEAD 到該標記\n"
+"m, merge [-C <commit> | -c <commit>] <label> [# <oneline>]\n"
+".       建立一個合併提交，並使用原始的合併提交說明（如果沒有指定\n"
+".       原始提交，使用備註部分的 oneline 作為提交說明）。使用\n"
+".       -c <提交> 可以編輯提交說明。\n"
+"\n"
+"可以對這些行重新排序，將從上至下執行。\n"
+
+#: rebase-interactive.c:56
+#, c-format
+msgid "Rebase %s onto %s (%d command)"
+msgid_plural "Rebase %s onto %s (%d commands)"
+msgstr[0] "重定基底 %s 到 %s（%d 個提交）"
+msgstr[1] "重定基底 %s 到 %s（%d 個提交）"
+
+#: rebase-interactive.c:65 git-rebase--preserve-merges.sh:228
+msgid ""
+"\n"
+"Do not remove any line. Use 'drop' explicitly to remove a commit.\n"
+msgstr ""
+"\n"
+"不要刪除任意一行。使用 'drop' 顯式地刪除一個提交。\n"
+
+#: rebase-interactive.c:68 git-rebase--preserve-merges.sh:232
+msgid ""
+"\n"
+"If you remove a line here THAT COMMIT WILL BE LOST.\n"
+msgstr ""
+"\n"
+"如果您在這裡刪除一行，對應的提交將會遺失。\n"
+
+#: rebase-interactive.c:74 git-rebase--preserve-merges.sh:871
+msgid ""
+"\n"
+"You are editing the todo file of an ongoing interactive rebase.\n"
+"To continue rebase after editing, run:\n"
+"    git rebase --continue\n"
+"\n"
+msgstr ""
+"\n"
+"您正在修改進行中的互動式重定基底待辦列表。若要在編輯結束後繼續重定基底，\n"
+"請執行：\n"
+"    git rebase --continue\n"
+"\n"
+
+#: rebase-interactive.c:79 git-rebase--preserve-merges.sh:948
+msgid ""
+"\n"
+"However, if you remove everything, the rebase will be aborted.\n"
+"\n"
+msgstr ""
+"\n"
+"然而，如果您刪除全部內容，重定基底動作將會終止。\n"
+"\n"
+
+#: rebase-interactive.c:85 git-rebase--preserve-merges.sh:955
+msgid "Note that empty commits are commented out"
+msgstr "注意空提交已被備註掉"
+
+#: rebase-interactive.c:105 rerere.c:485 rerere.c:692 sequencer.c:3536
+#: sequencer.c:3562 sequencer.c:5263 builtin/fsck.c:346 builtin/rebase.c:254
+#, c-format
+msgid "could not write '%s'"
+msgstr "不能寫入 '%s'"
+
+#: rebase-interactive.c:108
+#, c-format
+msgid "could not copy '%s' to '%s'."
+msgstr "不能複製 '%s' 至 '%s'。"
+
+#: rebase-interactive.c:173
+#, c-format
+msgid ""
+"Warning: some commits may have been dropped accidentally.\n"
+"Dropped commits (newer to older):\n"
+msgstr ""
+"警告：一些提交可能被意外捨棄。\n"
+"捨棄的提交（從新到舊）：\n"
+
+#: rebase-interactive.c:180
+#, c-format
+msgid ""
+"To avoid this message, use \"drop\" to explicitly remove a commit.\n"
+"\n"
+"Use 'git config rebase.missingCommitsCheck' to change the level of "
+"warnings.\n"
+"The possible behaviours are: ignore, warn, error.\n"
+"\n"
+msgstr ""
+"為避免這條訊息，使用 \"drop\" 指令顯式地刪除一個提交。\n"
+"\n"
+"使用 'git config rebase.missingCommitsCheck' 來修改警告級別。\n"
+"可選值有：ignore、warn、error。\n"
+"\n"
+
+#: refs.c:262
+#, c-format
+msgid "%s does not point to a valid object!"
+msgstr "%s 沒有指向一個有效的物件！"
+
+#: refs.c:667
+#, c-format
+msgid "ignoring dangling symref %s"
+msgstr "忽略懸空符號引用 %s"
+
+#: refs.c:669 ref-filter.c:2098
+#, c-format
+msgid "ignoring broken ref %s"
+msgstr "忽略損壞的引用 %s"
+
+#: refs.c:804
+#, c-format
+msgid "could not open '%s' for writing: %s"
+msgstr "無法為寫入開啟 '%s'：%s"
+
+#: refs.c:814 refs.c:865
+#, c-format
+msgid "could not read ref '%s'"
+msgstr "無法讀取引用 '%s'"
+
+#: refs.c:820
+#, c-format
+msgid "ref '%s' already exists"
+msgstr "引用 '%s' 已經存在"
+
+#: refs.c:825
+#, c-format
+msgid "unexpected object ID when writing '%s'"
+msgstr "寫入 '%s' 時意外的物件 ID"
+
+#: refs.c:833 sequencer.c:405 sequencer.c:2793 sequencer.c:2997
+#: sequencer.c:3011 sequencer.c:3269 sequencer.c:5179 strbuf.c:1142
+#: wrapper.c:620
+#, c-format
+msgid "could not write to '%s'"
+msgstr "不能寫入 '%s'"
+
+#: refs.c:860 strbuf.c:1140 wrapper.c:188 wrapper.c:358 builtin/am.c:714
+#: builtin/rebase.c:1031
+#, c-format
+msgid "could not open '%s' for writing"
+msgstr "無法開啟 '%s' 進行寫入"
+
+#: refs.c:867
+#, c-format
+msgid "unexpected object ID when deleting '%s'"
+msgstr "刪除 '%s' 時意外的物件 ID"
+
+#: refs.c:998
+#, c-format
+msgid "log for ref %s has gap after %s"
+msgstr "引用 %s 的日誌在 %s 之後有缺口"
+
+#: refs.c:1004
+#, c-format
+msgid "log for ref %s unexpectedly ended on %s"
+msgstr "引用 %s 的日誌意外終止於 %s "
+
+#: refs.c:1063
+#, c-format
+msgid "log for %s is empty"
+msgstr "%s 的日誌為空"
+
+#: refs.c:1155
+#, c-format
+msgid "refusing to update ref with bad name '%s'"
+msgstr "拒絕更新有錯誤名稱 '%s' 的引用"
+
+#: refs.c:1231
+#, c-format
+msgid "update_ref failed for ref '%s': %s"
+msgstr "對引用 '%s' 執行 update_ref 失敗：%s"
+
+#: refs.c:2023
+#, c-format
+msgid "multiple updates for ref '%s' not allowed"
+msgstr "不允許對引用 '%s' 多次更新"
+
+#: refs.c:2055
+msgid "ref updates forbidden inside quarantine environment"
+msgstr "在隔離環境中禁止更新引用"
+
+#: refs.c:2151 refs.c:2181
+#, c-format
+msgid "'%s' exists; cannot create '%s'"
+msgstr "'%s' 已存在，無法建立 '%s'"
+
+#: refs.c:2157 refs.c:2192
+#, c-format
+msgid "cannot process '%s' and '%s' at the same time"
+msgstr "無法同時處理 '%s' 和 '%s'"
+
+#: refs/files-backend.c:1234
+#, c-format
+msgid "could not remove reference %s"
+msgstr "無法刪除引用 %s"
+
+#: refs/files-backend.c:1248 refs/packed-backend.c:1541
+#: refs/packed-backend.c:1551
+#, c-format
+msgid "could not delete reference %s: %s"
+msgstr "無法刪除引用 %s：%s"
+
+#: refs/files-backend.c:1251 refs/packed-backend.c:1554
+#, c-format
+msgid "could not delete references: %s"
+msgstr "無法刪除引用：%s"
+
+#: refspec.c:137
+#, c-format
+msgid "invalid refspec '%s'"
+msgstr "無效的引用表達式：'%s'"
+
+#: ref-filter.c:42 wt-status.c:1938
+msgid "gone"
+msgstr "遺失"
+
+#: ref-filter.c:43
+#, c-format
+msgid "ahead %d"
+msgstr "領先 %d"
+
+#: ref-filter.c:44
+#, c-format
+msgid "behind %d"
+msgstr "落後 %d"
+
+#: ref-filter.c:45
+#, c-format
+msgid "ahead %d, behind %d"
+msgstr "領先 %d，落後 %d"
+
+#: ref-filter.c:165
+#, c-format
+msgid "expected format: %%(color:<color>)"
+msgstr "期望的格式：%%(color:<顏色>)"
+
+#: ref-filter.c:167
+#, c-format
+msgid "unrecognized color: %%(color:%s)"
+msgstr "未能識別的顏色：%%(color:%s)"
+
+#: ref-filter.c:189
+#, c-format
+msgid "Integer value expected refname:lstrip=%s"
+msgstr "期望整數值 refname:lstrip=%s"
+
+#: ref-filter.c:193
+#, c-format
+msgid "Integer value expected refname:rstrip=%s"
+msgstr "期望整數值 refname:rstrip=%s"
+
+#: ref-filter.c:195
+#, c-format
+msgid "unrecognized %%(%s) argument: %s"
+msgstr "未能識別的 %%(%s) 參數：%s"
+
+#: ref-filter.c:250
+#, c-format
+msgid "%%(objecttype) does not take arguments"
+msgstr "%%(objecttype) 不帶參數"
+
+#: ref-filter.c:272
+#, c-format
+msgid "unrecognized %%(objectsize) argument: %s"
+msgstr "未能識別的 %%(objectsize) 參數：%s"
+
+#: ref-filter.c:280
+#, c-format
+msgid "%%(deltabase) does not take arguments"
+msgstr "%%(deltabase) 不帶參數"
+
+#: ref-filter.c:292
+#, c-format
+msgid "%%(body) does not take arguments"
+msgstr "%%(body) 不帶參數"
+
+#: ref-filter.c:301
+#, c-format
+msgid "%%(subject) does not take arguments"
+msgstr "%%(subject) 不帶參數"
+
+#: ref-filter.c:323
+#, c-format
+msgid "unknown %%(trailers) argument: %s"
+msgstr "未知的 %%(trailers) 參數：%s"
+
+#: ref-filter.c:352
+#, c-format
+msgid "positive value expected contents:lines=%s"
+msgstr "期望一個正數 contents:lines=%s"
+
+#: ref-filter.c:354
+#, c-format
+msgid "unrecognized %%(contents) argument: %s"
+msgstr "未能識別的 %%(contents) 參數：%s"
+
+#: ref-filter.c:369
+#, c-format
+msgid "positive value expected objectname:short=%s"
+msgstr "期望一個正數 objectname:short=%s"
+
+#: ref-filter.c:373
+#, c-format
+msgid "unrecognized %%(objectname) argument: %s"
+msgstr "未能識別的 %%(objectname) 參數：%s"
+
+#: ref-filter.c:403
+#, c-format
+msgid "expected format: %%(align:<width>,<position>)"
+msgstr "期望的格式：%%(align:<寬度>,<位置>)"
+
+#: ref-filter.c:415
+#, c-format
+msgid "unrecognized position:%s"
+msgstr "未能識別的位置：%s"
+
+#: ref-filter.c:422
+#, c-format
+msgid "unrecognized width:%s"
+msgstr "未能識別的寬度：%s"
+
+#: ref-filter.c:431
+#, c-format
+msgid "unrecognized %%(align) argument: %s"
+msgstr "未能識別的 %%(align) 參數：%s"
+
+#: ref-filter.c:439
+#, c-format
+msgid "positive width expected with the %%(align) atom"
+msgstr "元素 %%(align) 需要一個正數的寬度"
+
+#: ref-filter.c:457
+#, c-format
+msgid "unrecognized %%(if) argument: %s"
+msgstr "未能識別的 %%(if) 參數：%s"
+
+#: ref-filter.c:559
+#, c-format
+msgid "malformed field name: %.*s"
+msgstr "格式錯誤的欄位名：%.*s"
+
+#: ref-filter.c:586
+#, c-format
+msgid "unknown field name: %.*s"
+msgstr "未知的欄位名：%.*s"
+
+#: ref-filter.c:590
+#, c-format
+msgid ""
+"not a git repository, but the field '%.*s' requires access to object data"
+msgstr "不是一個 git 版本庫，但是欄位 '%.*s' 需要存取物件資料"
+
+#: ref-filter.c:714
+#, c-format
+msgid "format: %%(if) atom used without a %%(then) atom"
+msgstr "格式：使用了 %%(if) 元素而沒有 %%(then) 元素"
+
+#: ref-filter.c:777
+#, c-format
+msgid "format: %%(then) atom used without an %%(if) atom"
+msgstr "格式：使用了 %%(then) 元素而沒有 %%(if) 元素"
+
+#: ref-filter.c:779
+#, c-format
+msgid "format: %%(then) atom used more than once"
+msgstr "格式：%%(then) 元素用了多次"
+
+#: ref-filter.c:781
+#, c-format
+msgid "format: %%(then) atom used after %%(else)"
+msgstr "格式：%%(then) 元素用在了 %%(else) 之後"
+
+#: ref-filter.c:809
+#, c-format
+msgid "format: %%(else) atom used without an %%(if) atom"
+msgstr "格式：使用了 %%(else) 元素而沒有 %%(if) 元素"
+
+#: ref-filter.c:811
+#, c-format
+msgid "format: %%(else) atom used without a %%(then) atom"
+msgstr "格式：使用了 %%(else) 元素而沒有 %%(then) 元素"
+
+#: ref-filter.c:813
+#, c-format
+msgid "format: %%(else) atom used more than once"
+msgstr "格式：%%(else) 元素用了多次"
+
+#: ref-filter.c:828
+#, c-format
+msgid "format: %%(end) atom used without corresponding atom"
+msgstr "格式：使用了 %%(end) 元素卻沒有它的對應元素"
+
+#: ref-filter.c:885
+#, c-format
+msgid "malformed format string %s"
+msgstr "錯誤的格式化字串 %s"
+
+#: ref-filter.c:1488
+#, c-format
+msgid "no branch, rebasing %s"
+msgstr "非分支，正重定基底 %s"
+
+#: ref-filter.c:1491
+#, c-format
+msgid "no branch, rebasing detached HEAD %s"
+msgstr "非分支，正重定基底分離開頭指標 %s"
+
+#: ref-filter.c:1494
+#, c-format
+msgid "no branch, bisect started on %s"
+msgstr "非分支，二分尋找開始於 %s"
+
+#: ref-filter.c:1504
+msgid "no branch"
+msgstr "非分支"
+
+#: ref-filter.c:1540 ref-filter.c:1749
+#, c-format
+msgid "missing object %s for %s"
+msgstr "缺少 %2$s 的物件 %1$s"
+
+#: ref-filter.c:1550
+#, c-format
+msgid "parse_object_buffer failed on %s for %s"
+msgstr "parse_object_buffer 失敗於 %2$s 的 %1$s"
+
+#: ref-filter.c:2004
+#, c-format
+msgid "malformed object at '%s'"
+msgstr "格式錯誤的物件 '%s'"
+
+#: ref-filter.c:2093
+#, c-format
+msgid "ignoring ref with broken name %s"
+msgstr "忽略帶有錯誤名稱 %s 的引用"
+
+#: ref-filter.c:2389
+#, c-format
+msgid "format: %%(end) atom missing"
+msgstr "格式：缺少 %%(end) 元素"
+
+#: ref-filter.c:2489
+#, c-format
+msgid "option `%s' is incompatible with --merged"
+msgstr "選項 `%s' 和 --merged 不相容"
+
+#: ref-filter.c:2492
+#, c-format
+msgid "option `%s' is incompatible with --no-merged"
+msgstr "選項 `%s' 和 --no-merged 不相容"
+
+#: ref-filter.c:2502
+#, c-format
+msgid "malformed object name %s"
+msgstr "格式錯誤的物件名 %s"
+
+#: ref-filter.c:2507
+#, c-format
+msgid "option `%s' must point to a commit"
+msgstr "選項 `%s' 必須指向一個提交"
+
+#: remote.c:366
+#, c-format
+msgid "config remote shorthand cannot begin with '/': %s"
+msgstr "設定的遠端短名稱不能以 '/' 開始：%s"
+
+#: remote.c:413
+msgid "more than one receivepack given, using the first"
+msgstr "提供了一個以上的 receivepack，使用第一個"
+
+#: remote.c:421
+msgid "more than one uploadpack given, using the first"
+msgstr "提供了一個以上的 uploadpack，使用第一個"
+
+#: remote.c:611
+#, c-format
+msgid "Cannot fetch both %s and %s to %s"
+msgstr "不能同時取得 %s 和 %s 至 %s"
+
+#: remote.c:615
+#, c-format
+msgid "%s usually tracks %s, not %s"
+msgstr "%s 通常追蹤 %s，而非 %s"
+
+#: remote.c:619
+#, c-format
+msgid "%s tracks both %s and %s"
+msgstr "%s 同時追蹤 %s 和 %s"
+
+#: remote.c:687
+#, c-format
+msgid "key '%s' of pattern had no '*'"
+msgstr "模式的鍵 '%s' 沒有 '*'"
+
+#: remote.c:697
+#, c-format
+msgid "value '%s' of pattern has no '*'"
+msgstr "模式的值 '%s' 沒有 '*'"
+
+#: remote.c:1003
+#, c-format
+msgid "src refspec %s does not match any"
+msgstr "源引用表達式 %s 沒有符合"
+
+#: remote.c:1008
+#, c-format
+msgid "src refspec %s matches more than one"
+msgstr "源引用表達式 %s 符合超過一個"
+
+#. TRANSLATORS: "matches '%s'%" is the <dst> part of "git push
+#. <remote> <src>:<dst>" push, and "being pushed ('%s')" is
+#. the <src>.
+#.
+#: remote.c:1023
+#, c-format
+msgid ""
+"The destination you provided is not a full refname (i.e.,\n"
+"starting with \"refs/\"). We tried to guess what you meant by:\n"
+"\n"
+"- Looking for a ref that matches '%s' on the remote side.\n"
+"- Checking if the <src> being pushed ('%s')\n"
+"  is a ref in \"refs/{heads,tags}/\". If so we add a corresponding\n"
+"  refs/{heads,tags}/ prefix on the remote side.\n"
+"\n"
+"Neither worked, so we gave up. You must fully qualify the ref."
+msgstr ""
+"您提供的目標不是一個完整的引用名稱（即以 \"refs/\" 開頭）。我們\n"
+"試著猜測您的想法：\n"
+"\n"
+"- 在遠端查詢和 '%s' 符合的引用。\n"
+"- 檢查要推送的 <src>（'%s'）是不是在 \"refs/{heads,tags}/\" 中的\n"
+"  引用。如果是，我們會在對應的遠端新增 refs/{heads,tags}/ 前綴。\n"
+"\n"
+"都不行，所以我們已放棄。您必須給出完整的引用。"
+
+#: remote.c:1043
+#, c-format
+msgid ""
+"The <src> part of the refspec is a commit object.\n"
+"Did you mean to create a new branch by pushing to\n"
+"'%s:refs/heads/%s'?"
+msgstr ""
+"引用表達式的 <src> 是一個提交物件。您是想建立一個新的分支而向\n"
+"'%s:refs/heads/%s' 推送嗎？"
+
+#: remote.c:1048
+#, c-format
+msgid ""
+"The <src> part of the refspec is a tag object.\n"
+"Did you mean to create a new tag by pushing to\n"
+"'%s:refs/tags/%s'?"
+msgstr ""
+"引用表達式的 <src> 是一個標籤物件。您是想建立一個新的標籤而向\n"
+"'%s:refs/tags/%s' 推送嗎？"
+
+#: remote.c:1053
+#, c-format
+msgid ""
+"The <src> part of the refspec is a tree object.\n"
+"Did you mean to tag a new tree by pushing to\n"
+"'%s:refs/tags/%s'?"
+msgstr ""
+"引用表達式的 <src> 是一個樹狀物件。您是想為這個樹狀物件建立標籤而向\n"
+"'%s:refs/tags/%s' 推送嗎？"
+
+#: remote.c:1058
+#, c-format
+msgid ""
+"The <src> part of the refspec is a blob object.\n"
+"Did you mean to tag a new blob by pushing to\n"
+"'%s:refs/tags/%s'?"
+msgstr ""
+"引用表達式的 <src> 是一個資料物件。您是想為這個資料物件建立標籤而向\n"
+"'%s:refs/tags/%s' 推送嗎？"
+
+#: remote.c:1094
+#, c-format
+msgid "%s cannot be resolved to branch"
+msgstr "%s 無法被解析為分支"
+
+#: remote.c:1105
+#, c-format
+msgid "unable to delete '%s': remote ref does not exist"
+msgstr "無法刪除 '%s'：遠端引用不存在"
+
+#: remote.c:1117
+#, c-format
+msgid "dst refspec %s matches more than one"
+msgstr "目標引用表達式 %s 符合超過一個"
+
+#: remote.c:1124
+#, c-format
+msgid "dst ref %s receives from more than one src"
+msgstr "目標引用 %s 接收超過一個源"
+
+#: remote.c:1627 remote.c:1728
+msgid "HEAD does not point to a branch"
+msgstr "HEAD 沒有指向一個分支"
+
+#: remote.c:1636
+#, c-format
+msgid "no such branch: '%s'"
+msgstr "沒有此分支：'%s'"
+
+#: remote.c:1639
+#, c-format
+msgid "no upstream configured for branch '%s'"
+msgstr "尚未給分支 '%s' 設定上游"
+
+#: remote.c:1645
+#, c-format
+msgid "upstream branch '%s' not stored as a remote-tracking branch"
+msgstr "上游分支 '%s' 沒有儲存為一個遠端追蹤分支"
+
+#: remote.c:1660
+#, c-format
+msgid "push destination '%s' on remote '%s' has no local tracking branch"
+msgstr "推送目標 '%s' 至遠端 '%s' 沒有本機追蹤分支"
+
+#: remote.c:1672
+#, c-format
+msgid "branch '%s' has no remote for pushing"
+msgstr "分支 '%s' 沒有設定要推送的遠端伺服器"
+
+#: remote.c:1682
+#, c-format
+msgid "push refspecs for '%s' do not include '%s'"
+msgstr "向 '%s' 推送引用規格未包含 '%s'"
+
+#: remote.c:1695
+msgid "push has no destination (push.default is 'nothing')"
+msgstr "推送無目標（push.default 是 'nothing'）"
+
+#: remote.c:1717
+msgid "cannot resolve 'simple' push to a single destination"
+msgstr "無法解析 'simple' 推送至一個單獨的目標"
+
+#: remote.c:1843
+#, c-format
+msgid "couldn't find remote ref %s"
+msgstr "無法找到遠端引用 %s"
+
+#: remote.c:1856
+#, c-format
+msgid "* Ignoring funny ref '%s' locally"
+msgstr "* 在本機忽略可笑的引用 '%s'"
+
+#: remote.c:2019
+#, c-format
+msgid "Your branch is based on '%s', but the upstream is gone.\n"
+msgstr "您的分支基於 '%s'，但此上游分支已經不存在。\n"
+
+#: remote.c:2023
+msgid "  (use \"git branch --unset-upstream\" to fixup)\n"
+msgstr "  （使用 \"git branch --unset-upstream\" 來修復）\n"
+
+#: remote.c:2026
+#, c-format
+msgid "Your branch is up to date with '%s'.\n"
+msgstr "您的分支與上游分支 '%s' 一致。\n"
+
+#: remote.c:2030
+#, c-format
+msgid "Your branch and '%s' refer to different commits.\n"
+msgstr "您的分支和 '%s' 指向不同的提交。\n"
+
+#: remote.c:2033
+#, c-format
+msgid "  (use \"%s\" for details)\n"
+msgstr "  （使用 \"%s\" 檢視詳情）\n"
+
+#: remote.c:2037
+#, c-format
+msgid "Your branch is ahead of '%s' by %d commit.\n"
+msgid_plural "Your branch is ahead of '%s' by %d commits.\n"
+msgstr[0] "您的分支領先 '%s' 共 %d 個提交。\n"
+msgstr[1] "您的分支領先 '%s' 共 %d 個提交。\n"
+
+#: remote.c:2043
+msgid "  (use \"git push\" to publish your local commits)\n"
+msgstr "  （使用 \"git push\" 來發布您的本機提交）\n"
+
+#: remote.c:2046
+#, c-format
+msgid "Your branch is behind '%s' by %d commit, and can be fast-forwarded.\n"
+msgid_plural ""
+"Your branch is behind '%s' by %d commits, and can be fast-forwarded.\n"
+msgstr[0] "您的分支落後 '%s' 共 %d 個提交，並且可以快轉。\n"
+msgstr[1] "您的分支落後 '%s' 共 %d 個提交，並且可以快轉。\n"
+
+#  譯者：請維持前導空格
+#: remote.c:2054
+msgid "  (use \"git pull\" to update your local branch)\n"
+msgstr "  （使用 \"git pull\" 來更新您的本機分支）\n"
+
+#: remote.c:2057
+#, c-format
+msgid ""
+"Your branch and '%s' have diverged,\n"
+"and have %d and %d different commit each, respectively.\n"
+msgid_plural ""
+"Your branch and '%s' have diverged,\n"
+"and have %d and %d different commits each, respectively.\n"
+msgstr[0] ""
+"您的分支和 '%s' 出現了偏離，\n"
+"並且分別有 %d 和 %d 處不同的提交。\n"
+msgstr[1] ""
+"您的分支和 '%s' 出現了偏離，\n"
+"並且分別有 %d 和 %d 處不同的提交。\n"
+
+#  譯者：請維持前導空格
+#: remote.c:2067
+msgid "  (use \"git pull\" to merge the remote branch into yours)\n"
+msgstr "  （使用 \"git pull\" 來合併遠端分支）\n"
+
+#: remote.c:2250
+#, c-format
+msgid "cannot parse expected object name '%s'"
+msgstr "無法解析期望的物件名 '%s'"
+
+#: replace-object.c:21
+#, c-format
+msgid "bad replace ref name: %s"
+msgstr "錯誤的取代引用名稱：%s"
+
+#: replace-object.c:30
+#, c-format
+msgid "duplicate replace ref: %s"
+msgstr "重複的取代引用：%s"
+
+#: replace-object.c:73
+#, c-format
+msgid "replace depth too high for object %s"
+msgstr "物件 %s 的取代層級太深"
+
+#: rerere.c:217 rerere.c:226 rerere.c:229
+msgid "corrupt MERGE_RR"
+msgstr "損壞的 MERGE_RR"
+
+#: rerere.c:264 rerere.c:269
+msgid "unable to write rerere record"
+msgstr "無法寫入 rerere 記錄"
+
+#: rerere.c:495
+#, c-format
+msgid "there were errors while writing '%s' (%s)"
+msgstr "寫入 '%s' (%s) 時發生錯誤"
+
+#: rerere.c:498
+#, c-format
+msgid "failed to flush '%s'"
+msgstr "重新整理 '%s' 失敗"
+
+#: rerere.c:503 rerere.c:1039
+#, c-format
+msgid "could not parse conflict hunks in '%s'"
+msgstr "不能解析 '%s' 中的衝突塊"
+
+#: rerere.c:684
+#, c-format
+msgid "failed utime() on '%s'"
+msgstr "在 '%s' 上呼叫 utime() 失敗"
+
+#: rerere.c:694
+#, c-format
+msgid "writing '%s' failed"
+msgstr "寫入 '%s' 失敗"
+
+#: rerere.c:714
+#, c-format
+msgid "Staged '%s' using previous resolution."
+msgstr "使用之前的解決方案暫存 '%s'。"
+
+#: rerere.c:753
+#, c-format
+msgid "Recorded resolution for '%s'."
+msgstr "已記錄 '%s' 的解決方案。"
+
+#: rerere.c:788
+#, c-format
+msgid "Resolved '%s' using previous resolution."
+msgstr "使用之前的解決方案解決 '%s'。"
+
+#: rerere.c:803
+#, c-format
+msgid "cannot unlink stray '%s'"
+msgstr "不能刪除 stray '%s'"
+
+#: rerere.c:807
+#, c-format
+msgid "Recorded preimage for '%s'"
+msgstr "為 '%s' 記錄 preimage"
+
+#: rerere.c:881 submodule.c:2067 builtin/log.c:1871
+#: builtin/submodule--helper.c:1436 builtin/submodule--helper.c:1448
+#, c-format
+msgid "could not create directory '%s'"
+msgstr "不能建立目錄 '%s'"
+
+#: rerere.c:1057
+#, c-format
+msgid "failed to update conflicted state in '%s'"
+msgstr "更新 '%s' 中的衝突狀態失敗"
+
+#: rerere.c:1068 rerere.c:1075
+#, c-format
+msgid "no remembered resolution for '%s'"
+msgstr "沒有為 '%s' 記憶的解決方案"
+
+#: rerere.c:1077
+#, c-format
+msgid "cannot unlink '%s'"
+msgstr "不能刪除 '%s'"
+
+#: rerere.c:1087
+#, c-format
+msgid "Updated preimage for '%s'"
+msgstr "已為 '%s' 更新 preimage"
+
+#: rerere.c:1096
+#, c-format
+msgid "Forgot resolution for '%s'\n"
+msgstr "忘記 '%s' 的解決方案\n"
+
+#: rerere.c:1199
+msgid "unable to open rr-cache directory"
+msgstr "不能開啟 rr-cache 目錄"
+
+#: revision.c:2497
+msgid "your current branch appears to be broken"
+msgstr "您的目前分支好像被損壞"
+
+#: revision.c:2500
+#, c-format
+msgid "your current branch '%s' does not have any commits yet"
+msgstr "您的目前分支 '%s' 尚無任何提交"
+
+#: revision.c:2708
+msgid "--first-parent is incompatible with --bisect"
+msgstr "--first-parent 與 --bisect 不相容"
+
+#: revision.c:2712
+msgid "-L does not yet support diff formats besides -p and -s"
+msgstr "-L 尚不支援 -p 和 -s 之外的差異格式"
+
+#: run-command.c:762
+msgid "open /dev/null failed"
+msgstr "不能開啟 /dev/null"
+
+#: run-command.c:1268
+#, c-format
+msgid "cannot create async thread: %s"
+msgstr "不能建立 async 執行緒：%s"
+
+#: run-command.c:1332
+#, c-format
+msgid ""
+"The '%s' hook was ignored because it's not set as executable.\n"
+"You can disable this warning with `git config advice.ignoredHook false`."
+msgstr ""
+"因為沒有將掛鉤 '%s' 設定為可執行，掛鉤被忽略。您可以透過\n"
+"設定 `git config advice.ignoredHook false` 來關閉這條警告。"
+
+#: send-pack.c:144
+msgid "unexpected flush packet while reading remote unpack status"
+msgstr "讀取遠端解包狀態時收到意外的 flush 包"
+
+#: send-pack.c:146
+#, c-format
+msgid "unable to parse remote unpack status: %s"
+msgstr "不能解析遠端解包狀態：%s"
+
+#: send-pack.c:148
+#, c-format
+msgid "remote unpack failed: %s"
+msgstr "遠端解包失敗：%s"
+
+#: send-pack.c:309
+msgid "failed to sign the push certificate"
+msgstr "為推送證書籤名失敗"
+
+#: send-pack.c:423
+msgid "the receiving end does not support --signed push"
+msgstr "接收端不支援簽名推送"
+
+#: send-pack.c:425
+msgid ""
+"not sending a push certificate since the receiving end does not support --"
+"signed push"
+msgstr "未傳送推送證書，因為接收端不支援簽名推送"
+
+#: send-pack.c:437
+msgid "the receiving end does not support --atomic push"
+msgstr "接收端不支援原子推送"
+
+#: send-pack.c:442
+msgid "the receiving end does not support push options"
+msgstr "接收端不支援推送選項"
+
+#: sequencer.c:189
+#, c-format
+msgid "invalid commit message cleanup mode '%s'"
+msgstr "無效的提交訊息清理模式 '%s'"
+
+#: sequencer.c:294
+#, c-format
+msgid "could not delete '%s'"
+msgstr "無法刪除 '%s'"
+
+#: sequencer.c:313 builtin/rebase.c:781 builtin/rebase.c:1706 builtin/rm.c:369
+#, c-format
+msgid "could not remove '%s'"
+msgstr "無法刪除 '%s'"
+
+#: sequencer.c:323
+msgid "revert"
+msgstr "還原"
+
+#: sequencer.c:325
+msgid "cherry-pick"
+msgstr "揀選"
+
+#: sequencer.c:327
+msgid "rebase -i"
+msgstr "rebase -i"
+
+#: sequencer.c:329
+#, c-format
+msgid "unknown action: %d"
+msgstr "未知動作：%d"
+
+#: sequencer.c:387
+msgid ""
+"after resolving the conflicts, mark the corrected paths\n"
+"with 'git add <paths>' or 'git rm <paths>'"
+msgstr ""
+"衝突解決完畢後，用 'git add <路徑>' 或 'git rm <路徑>'\n"
+"指令標記修正後的檔案"
+
+#: sequencer.c:390
+msgid ""
+"after resolving the conflicts, mark the corrected paths\n"
+"with 'git add <paths>' or 'git rm <paths>'\n"
+"and commit the result with 'git commit'"
+msgstr ""
+"衝突解決完畢後，用 'git add <路徑>' 或 'git rm <路徑>'\n"
+"對修正後的檔案做標記，然後用 'git commit' 提交"
+
+#: sequencer.c:403 sequencer.c:2993
+#, c-format
+msgid "could not lock '%s'"
+msgstr "不能鎖定 '%s'"
+
+#: sequencer.c:410
+#, c-format
+msgid "could not write eol to '%s'"
+msgstr "不能將換行符號寫入 '%s'"
+
+#: sequencer.c:415 sequencer.c:2798 sequencer.c:2999 sequencer.c:3013
+#: sequencer.c:3277
+#, c-format
+msgid "failed to finalize '%s'"
+msgstr "無法完成 '%s'"
+
+#: sequencer.c:438 sequencer.c:1707 sequencer.c:2818 sequencer.c:3259
+#: sequencer.c:3368 builtin/am.c:244 builtin/commit.c:783 builtin/merge.c:1117
+#: builtin/rebase.c:589
+#, c-format
+msgid "could not read '%s'"
+msgstr "不能讀取 '%s'"
+
+#: sequencer.c:464
+#, c-format
+msgid "your local changes would be overwritten by %s."
+msgstr "您的本機修改將被%s覆蓋。"
+
+#: sequencer.c:468
+msgid "commit your changes or stash them to proceed."
+msgstr "提交您的修改或儲藏後再繼續。"
+
+#: sequencer.c:500
+#, c-format
+msgid "%s: fast-forward"
+msgstr "%s：快轉"
+
+#: sequencer.c:539 builtin/tag.c:565
+#, c-format
+msgid "Invalid cleanup mode %s"
+msgstr "無效的清理模式 %s"
+
+#. TRANSLATORS: %s will be "revert", "cherry-pick" or
+#. "rebase -i".
+#.
+#: sequencer.c:633
+#, c-format
+msgid "%s: Unable to write new index file"
+msgstr "%s：無法寫入新索引檔案"
+
+#: sequencer.c:650
+msgid "unable to update cache tree"
+msgstr "不能更新快取樹"
+
+#: sequencer.c:664
+msgid "could not resolve HEAD commit"
+msgstr "不能解析 HEAD 提交"
+
+#: sequencer.c:744
+#, c-format
+msgid "no key present in '%.*s'"
+msgstr "在 '%.*s' 中沒有 key"
+
+#: sequencer.c:755
+#, c-format
+msgid "unable to dequote value of '%s'"
+msgstr "無法為 '%s' 的值去引號"
+
+#: sequencer.c:792 wrapper.c:190 wrapper.c:360 builtin/am.c:705
+#: builtin/am.c:797 builtin/merge.c:1114 builtin/rebase.c:1074
+#, c-format
+msgid "could not open '%s' for reading"
+msgstr "無法開啟 '%s' 進行讀取"
+
+#: sequencer.c:802
+msgid "'GIT_AUTHOR_NAME' already given"
+msgstr "已經給出 'GIT_AUTHOR_NAME'"
+
+#: sequencer.c:807
+msgid "'GIT_AUTHOR_EMAIL' already given"
+msgstr "已經給出 'GIT_AUTHOR_EMAIL'"
+
+#: sequencer.c:812
+msgid "'GIT_AUTHOR_DATE' already given"
+msgstr "已經給出 'GIT_AUTHOR_DATE'"
+
+#: sequencer.c:816
+#, c-format
+msgid "unknown variable '%s'"
+msgstr "未知變數 '%s'"
+
+#: sequencer.c:821
+msgid "missing 'GIT_AUTHOR_NAME'"
+msgstr "缺少 'GIT_AUTHOR_NAME'"
+
+#: sequencer.c:823
+msgid "missing 'GIT_AUTHOR_EMAIL'"
+msgstr "缺少 'GIT_AUTHOR_EMAIL'"
+
+#: sequencer.c:825
+msgid "missing 'GIT_AUTHOR_DATE'"
+msgstr "缺少 'GIT_AUTHOR_DATE'"
+
+#: sequencer.c:902 sequencer.c:1427
+#| msgid "malformed input line: '%s'."
+msgid "malformed ident line"
+msgstr "識別行的格式錯誤"
+
+#: sequencer.c:925
+#, c-format
+msgid ""
+"you have staged changes in your working tree\n"
+"If these changes are meant to be squashed into the previous commit, run:\n"
+"\n"
+"  git commit --amend %s\n"
+"\n"
+"If they are meant to go into a new commit, run:\n"
+"\n"
+"  git commit %s\n"
+"\n"
+"In both cases, once you're done, continue with:\n"
+"\n"
+"  git rebase --continue\n"
+msgstr ""
+"您的工作區中存在已暫存的修改\n"
+"如果這些修改需要被併入前一個提交，執行：\n"
+"\n"
+"  git commit --amend %s\n"
+"\n"
+"如果這些修改要形成一個新提交，執行：\n"
+"\n"
+"  git commit %s\n"
+"\n"
+"無論哪種情況，當您完成提交，繼續執行：\n"
+"\n"
+"  git rebase --continue\n"
+
+#: sequencer.c:1218
+msgid "'prepare-commit-msg' hook failed"
+msgstr "'prepare-commit-msg' 掛鉤失敗"
+
+#: sequencer.c:1224
+msgid ""
+"Your name and email address were configured automatically based\n"
+"on your username and hostname. Please check that they are accurate.\n"
+"You can suppress this message by setting them explicitly. Run the\n"
+"following command and follow the instructions in your editor to edit\n"
+"your configuration file:\n"
+"\n"
+"    git config --global --edit\n"
+"\n"
+"After doing this, you may fix the identity used for this commit with:\n"
+"\n"
+"    git commit --amend --reset-author\n"
+msgstr ""
+"您的姓名和信件位址基於登入名稱和主機名稱自動設定。請檢查它們正確\n"
+"與否。您可以對其進行設定以免再出現本提示訊息。執行如下指令在編輯器\n"
+"中編輯您的設定檔案：\n"
+"\n"
+"    git config --global --edit\n"
+"\n"
+"設定完畢後，您可以用下面的指令來修正本次提交所使用的使用者身份：\n"
+"\n"
+"    git commit --amend --reset-author\n"
+
+#: sequencer.c:1237
+msgid ""
+"Your name and email address were configured automatically based\n"
+"on your username and hostname. Please check that they are accurate.\n"
+"You can suppress this message by setting them explicitly:\n"
+"\n"
+"    git config --global user.name \"Your Name\"\n"
+"    git config --global user.email you@example.com\n"
+"\n"
+"After doing this, you may fix the identity used for this commit with:\n"
+"\n"
+"    git commit --amend --reset-author\n"
+msgstr ""
+"您的姓名和信件位址基於登入名稱和主機名稱自動設定。請檢查它們正確\n"
+"與否。您可以對其進行設定以免再出現本提示訊息：\n"
+"\n"
+"    git config --global user.name \"Your Name\"\n"
+"    git config --global user.email you@example.com\n"
+"\n"
+"設定完畢後，您可以用下面的指令來修正本次提交所使用的使用者身份：\n"
+"\n"
+"    git commit --amend --reset-author\n"
+
+#: sequencer.c:1279
+msgid "couldn't look up newly created commit"
+msgstr "無法找到新建立的提交"
+
+#: sequencer.c:1281
+msgid "could not parse newly created commit"
+msgstr "不能解析新建立的提交"
+
+#: sequencer.c:1327
+msgid "unable to resolve HEAD after creating commit"
+msgstr "建立提交後，不能解析 HEAD"
+
+#: sequencer.c:1329
+msgid "detached HEAD"
+msgstr "分離開頭指標"
+
+#  譯者：中文字串拼接，可刪除前導空格
+#: sequencer.c:1333
+msgid " (root-commit)"
+msgstr " (根提交)"
+
+#: sequencer.c:1354
+msgid "could not parse HEAD"
+msgstr "不能解析 HEAD"
+
+#: sequencer.c:1356
+#, c-format
+msgid "HEAD %s is not a commit!"
+msgstr "HEAD %s 不是一個提交！"
+
+#: sequencer.c:1360 sequencer.c:1458 builtin/commit.c:1569
+msgid "could not parse HEAD commit"
+msgstr "不能解析 HEAD 提交"
+
+#: sequencer.c:1411 sequencer.c:2055
+msgid "unable to parse commit author"
+msgstr "不能解析提交作者"
+
+#: sequencer.c:1431
+#| msgid "refresh stat information"
+msgid "corrupted author without date information"
+msgstr ""
+
+#: sequencer.c:1447 builtin/am.c:1561 builtin/merge.c:684
+msgid "git write-tree failed to write a tree"
+msgstr "git write-tree 無法寫入樹狀物件"
+
+#: sequencer.c:1480 sequencer.c:1550
+#, c-format
+msgid "unable to read commit message from '%s'"
+msgstr "不能從 '%s' 讀取提交說明"
+
+#: sequencer.c:1516 builtin/am.c:1583 builtin/commit.c:1668 builtin/merge.c:883
+#: builtin/merge.c:908
+msgid "failed to write commit object"
+msgstr "寫提交物件失敗"
+
+#: sequencer.c:1577
+#, c-format
+msgid "could not parse commit %s"
+msgstr "不能解析提交 %s"
+
+#: sequencer.c:1582
+#, c-format
+msgid "could not parse parent commit %s"
+msgstr "不能解析父提交 %s"
+
+#: sequencer.c:1656 sequencer.c:1767
+#, c-format
+msgid "unknown command: %d"
+msgstr "未知指令：%d"
+
+#: sequencer.c:1714 sequencer.c:1739
+#, c-format
+msgid "This is a combination of %d commits."
+msgstr "這是一個 %d 個提交的組合。"
+
+#: sequencer.c:1724
+msgid "need a HEAD to fixup"
+msgstr "需要一個 HEAD 來修復"
+
+#: sequencer.c:1726 sequencer.c:3304
+msgid "could not read HEAD"
+msgstr "不能讀取 HEAD"
+
+#: sequencer.c:1728
+msgid "could not read HEAD's commit message"
+msgstr "不能讀取 HEAD 的提交說明"
+
+#: sequencer.c:1734
+#, c-format
+msgid "cannot write '%s'"
+msgstr "不能寫 '%s'"
+
+#: sequencer.c:1741 git-rebase--preserve-merges.sh:496
+msgid "This is the 1st commit message:"
+msgstr "這是第一個提交說明："
+
+#: sequencer.c:1749
+#, c-format
+msgid "could not read commit message of %s"
+msgstr "不能讀取 %s 的提交說明"
+
+#: sequencer.c:1756
+#, c-format
+msgid "This is the commit message #%d:"
+msgstr "這是提交說明 #%d："
+
+#: sequencer.c:1762
+#, c-format
+msgid "The commit message #%d will be skipped:"
+msgstr "提交說明 #%d 將被跳過："
+
+#: sequencer.c:1850
+msgid "your index file is unmerged."
+msgstr "您的索引檔案未完成合併。"
+
+#: sequencer.c:1857
+msgid "cannot fixup root commit"
+msgstr "不能修復根提交"
+
+#: sequencer.c:1876
+#, c-format
+msgid "commit %s is a merge but no -m option was given."
+msgstr "提交 %s 是一個合併提交但未提供 -m 選項。"
+
+#: sequencer.c:1884 sequencer.c:1892
+#, c-format
+msgid "commit %s does not have parent %d"
+msgstr "提交 %s 沒有第 %d 個父提交"
+
+#: sequencer.c:1898
+#, c-format
+msgid "cannot get commit message for %s"
+msgstr "不能得到 %s 的提交說明"
+
+#. TRANSLATORS: The first %s will be a "todo" command like
+#. "revert" or "pick", the second %s a SHA1.
+#: sequencer.c:1917
+#, c-format
+msgid "%s: cannot parse parent commit %s"
+msgstr "%s：不能解析父提交 %s"
+
+#: sequencer.c:1982
+#, c-format
+msgid "could not rename '%s' to '%s'"
+msgstr "不能將 '%s' 重新命名為 '%s'"
+
+#: sequencer.c:2037
+#, c-format
+msgid "could not revert %s... %s"
+msgstr "不能還原 %s... %s"
+
+#: sequencer.c:2038
+#, c-format
+msgid "could not apply %s... %s"
+msgstr "不能應用 %s... %s"
+
+#: sequencer.c:2105
+#, c-format
+msgid "git %s: failed to read the index"
+msgstr "git %s：無法讀取索引"
+
+#: sequencer.c:2112
+#, c-format
+msgid "git %s: failed to refresh the index"
+msgstr "git %s：無法重新整理索引"
+
+#: sequencer.c:2189
+#, c-format
+msgid "%s does not accept arguments: '%s'"
+msgstr "%s 不接受參數：'%s'"
+
+#: sequencer.c:2198
+#, c-format
+msgid "missing arguments for %s"
+msgstr "缺少 %s 的參數"
+
+#: sequencer.c:2235
+#, c-format
+msgid "could not parse '%.*s'"
+msgstr "無法解析 '%.*s'"
+
+#: sequencer.c:2289
+#, c-format
+msgid "invalid line %d: %.*s"
+msgstr "無效行 %d：%.*s"
+
+#: sequencer.c:2300
+#, c-format
+msgid "cannot '%s' without a previous commit"
+msgstr "沒有父提交的情況下不能 '%s'"
+
+#: sequencer.c:2348 builtin/rebase.c:172 builtin/rebase.c:197
+#: builtin/rebase.c:223 builtin/rebase.c:248
+#, c-format
+msgid "could not read '%s'."
+msgstr "不能讀取 '%s'。"
+
+#: sequencer.c:2384
+msgid "cancelling a cherry picking in progress"
+msgstr "正在取消一個進行中的揀選"
+
+#: sequencer.c:2391
+msgid "cancelling a revert in progress"
+msgstr "正在取消一個進行中的還原"
+
+#: sequencer.c:2435
+msgid "please fix this using 'git rebase --edit-todo'."
+msgstr "請用 'git rebase --edit-todo' 來修改。"
+
+#: sequencer.c:2437
+#, c-format
+msgid "unusable instruction sheet: '%s'"
+msgstr "不可用的指令清單：'%s'"
+
+#: sequencer.c:2442
+msgid "no commits parsed."
+msgstr "沒有解析提交。"
+
+#: sequencer.c:2453
+msgid "cannot cherry-pick during a revert."
+msgstr "不能在還原提交中執行揀選。"
+
+#: sequencer.c:2455
+msgid "cannot revert during a cherry-pick."
+msgstr "不能在揀選中執行還原提交。"
+
+#: sequencer.c:2533
+#, c-format
+msgid "invalid value for %s: %s"
+msgstr "%s 的值無效：%s"
+
+#: sequencer.c:2630
+msgid "unusable squash-onto"
+msgstr "不可用的 squash-onto"
+
+#: sequencer.c:2646
+#, c-format
+msgid "malformed options sheet: '%s'"
+msgstr "格式錯誤的選項清單：'%s'"
+
+#: sequencer.c:2736 sequencer.c:4463
+msgid "empty commit set passed"
+msgstr "提供了空的提交集"
+
+#: sequencer.c:2752
+msgid "revert is already in progress"
+msgstr "一個還原動作已在進行"
+
+#: sequencer.c:2754
+#, c-format
+msgid "try \"git revert (--continue | %s--abort | --quit)\""
+msgstr "嘗試 \"git revert (--continue | %s--abort | --quit)\""
+
+#: sequencer.c:2757
+msgid "cherry-pick is already in progress"
+msgstr "揀選動作已在進行"
+
+#: sequencer.c:2759
+#, c-format
+msgid "try \"git cherry-pick (--continue | %s--abort | --quit)\""
+msgstr "嘗試 \"git cherry-pick (--continue | %s--abort | --quit)\""
+
+#: sequencer.c:2773
+#, c-format
+msgid "could not create sequencer directory '%s'"
+msgstr "不能建立序列目錄 '%s'"
+
+#: sequencer.c:2788
+msgid "could not lock HEAD"
+msgstr "不能鎖定 HEAD"
+
+#: sequencer.c:2848 sequencer.c:4209
+msgid "no cherry-pick or revert in progress"
+msgstr "揀選或還原動作並未進行"
+
+#: sequencer.c:2850 sequencer.c:2861
+msgid "cannot resolve HEAD"
+msgstr "不能解析 HEAD"
+
+#: sequencer.c:2852 sequencer.c:2896
+msgid "cannot abort from a branch yet to be born"
+msgstr "不能從尚未建立的分支終止"
+
+#: sequencer.c:2882 builtin/grep.c:736
+#, c-format
+msgid "cannot open '%s'"
+msgstr "不能開啟 '%s'"
+
+#: sequencer.c:2884
+#, c-format
+msgid "cannot read '%s': %s"
+msgstr "不能讀取 '%s'：%s"
+
+#: sequencer.c:2885
+msgid "unexpected end of file"
+msgstr "意外的檔案結束"
+
+#: sequencer.c:2891
+#, c-format
+msgid "stored pre-cherry-pick HEAD file '%s' is corrupt"
+msgstr "儲存揀選提交前的 HEAD 檔案 '%s' 損壞"
+
+#: sequencer.c:2902
+msgid "You seem to have moved HEAD. Not rewinding, check your HEAD!"
+msgstr "您好像移動了 HEAD。未能還原，檢查您的 HEAD！"
+
+#: sequencer.c:2943
+msgid "no revert in progress"
+msgstr "沒有正在進行的還原"
+
+#: sequencer.c:2951
+msgid "no cherry-pick in progress"
+msgstr "沒有正在進行的揀選"
+
+#: sequencer.c:2961
+msgid "failed to skip the commit"
+msgstr "無法跳過這個提交"
+
+#: sequencer.c:2968
+msgid "there is nothing to skip"
+msgstr "沒有要跳過的"
+
+#: sequencer.c:2971
+#, c-format
+msgid ""
+"have you committed already?\n"
+"try \"git %s --continue\""
+msgstr ""
+"您已經提交了嗎？\n"
+"試試 \"git %s --continue\""
+
+#: sequencer.c:3095 sequencer.c:4121
+#, c-format
+msgid "could not update %s"
+msgstr "不能更新 %s"
+
+#: sequencer.c:3134 sequencer.c:4101
+msgid "cannot read HEAD"
+msgstr "不能讀取 HEAD"
+
+#: sequencer.c:3151
+#, c-format
+msgid "unable to copy '%s' to '%s'"
+msgstr "無法複製 '%s' 至 '%s'"
+
+#: sequencer.c:3159
+#, c-format
+msgid ""
+"You can amend the commit now, with\n"
+"\n"
+"  git commit --amend %s\n"
+"\n"
+"Once you are satisfied with your changes, run\n"
+"\n"
+"  git rebase --continue\n"
+msgstr ""
+"您現在可以修補這個提交，使用\n"
+"\n"
+"  git commit --amend %s\n"
+"\n"
+"當您對變更感到滿意，執行\n"
+"\n"
+"  git rebase --continue\n"
+
+#: sequencer.c:3169
+#, c-format
+msgid "Could not apply %s... %.*s"
+msgstr "不能應用 %s... %.*s"
+
+#: sequencer.c:3176
+#, c-format
+msgid "Could not merge %.*s"
+msgstr "不能合併 %.*s"
+
+#: sequencer.c:3190 sequencer.c:3194 builtin/difftool.c:641
+#, c-format
+msgid "could not copy '%s' to '%s'"
+msgstr "不能複製 '%s' 至 '%s'"
+
+#  譯者：請維持前導空格
+#: sequencer.c:3221
+#, c-format
+msgid ""
+"execution failed: %s\n"
+"%sYou can fix the problem, and then run\n"
+"\n"
+"  git rebase --continue\n"
+"\n"
+msgstr ""
+"執行失敗：%s\n"
+"%s您可以改正該問題，然後執行\n"
+"\n"
+"  git rebase --continue\n"
+"\n"
+
+#: sequencer.c:3227
+msgid "and made changes to the index and/or the working tree\n"
+msgstr "並且修改索引和/或工作區\n"
+
+#: sequencer.c:3233
+#, c-format
+msgid ""
+"execution succeeded: %s\n"
+"but left changes to the index and/or the working tree\n"
+"Commit or stash your changes, and then run\n"
+"\n"
+"  git rebase --continue\n"
+"\n"
+msgstr ""
+"執行成功：%s\n"
+"但是在索引和/或工作區中存在變更\n"
+"提交或儲藏修改，然後執行\n"
+"\n"
+"  git rebase --continue\n"
+"\n"
+
+#: sequencer.c:3294
+#, c-format
+msgid "illegal label name: '%.*s'"
+msgstr "非法的標籤名稱：'%.*s'"
+
+#: sequencer.c:3348
+msgid "writing fake root commit"
+msgstr "寫偽根提交"
+
+#: sequencer.c:3353
+msgid "writing squash-onto"
+msgstr "寫入 squash-onto"
+
+#: sequencer.c:3391 builtin/rebase.c:876 builtin/rebase.c:882
+#, c-format
+msgid "failed to find tree of %s"
+msgstr "無法找到 %s 指向的樹。"
+
+#: sequencer.c:3436
+#, c-format
+msgid "could not resolve '%s'"
+msgstr "無法解析 '%s'"
+
+#: sequencer.c:3467
+msgid "cannot merge without a current revision"
+msgstr "沒有目前版本不能合併"
+
+#: sequencer.c:3489
+#, c-format
+msgid "unable to parse '%.*s'"
+msgstr "無法解析 '%.*s'"
+
+#: sequencer.c:3498
+#, c-format
+msgid "nothing to merge: '%.*s'"
+msgstr "無可用合併：'%.*s'"
+
+#: sequencer.c:3510
+msgid "octopus merge cannot be executed on top of a [new root]"
+msgstr "章魚合並不能在一個新的根提交上執行"
+
+#: sequencer.c:3526
+#, c-format
+msgid "could not get commit message of '%s'"
+msgstr "不能取得 '%s' 的提交說明"
+
+#: sequencer.c:3688
+#, c-format
+msgid "could not even attempt to merge '%.*s'"
+msgstr "甚至不能嘗試合併 '%.*s'"
+
+#: sequencer.c:3704
+msgid "merge: Unable to write new index file"
+msgstr "合併：無法寫入新索引檔案"
+
+#: sequencer.c:3773 builtin/rebase.c:733
+#, c-format
+msgid "Applied autostash.\n"
+msgstr "已應用 autostash。\n"
+
+#: sequencer.c:3785
+#, c-format
+msgid "cannot store %s"
+msgstr "不能儲存 %s"
+
+#: sequencer.c:3788 builtin/rebase.c:749 git-rebase--preserve-merges.sh:113
+#, c-format
+msgid ""
+"Applying autostash resulted in conflicts.\n"
+"Your changes are safe in the stash.\n"
+"You can run \"git stash pop\" or \"git stash drop\" at any time.\n"
+msgstr ""
+"應用 autostash 導致衝突。\n"
+"您的修改安全地儲存在儲藏區中。\n"
+"您可以在任何時候執行 \"git stash pop\" 或 \"git stash drop\"。\n"
+
+#: sequencer.c:3849
+#, c-format
+msgid "could not checkout %s"
+msgstr "不能簽出 %s"
+
+#: sequencer.c:3863
+#, c-format
+msgid "%s: not a valid OID"
+msgstr "%s：不是一個有效的物件 ID"
+
+#: sequencer.c:3868 git-rebase--preserve-merges.sh:779
+msgid "could not detach HEAD"
+msgstr "不能分離開頭指標"
+
+#: sequencer.c:3883
+#, c-format
+msgid "Stopped at HEAD\n"
+msgstr "停止在 HEAD\n"
+
+#: sequencer.c:3885
+#, c-format
+msgid "Stopped at %s\n"
+msgstr "停止在 %s\n"
+
+#: sequencer.c:3893
+#, c-format
+msgid ""
+"Could not execute the todo command\n"
+"\n"
+"    %.*s\n"
+"It has been rescheduled; To edit the command before continuing, please\n"
+"edit the todo list first:\n"
+"\n"
+"    git rebase --edit-todo\n"
+"    git rebase --continue\n"
+msgstr ""
+"無法執行待辦指令\n"
+"\n"
+"    %.*s\n"
+"已被重新安排，在繼續之前編輯指令，請先編輯待辦列表：\n"
+"\n"
+"    git rebase --edit-todo\n"
+"    git rebase --continue\n"
+
+#: sequencer.c:3979
+#, c-format
+msgid "Stopped at %s...  %.*s\n"
+msgstr "停止在 %s... %.*s\n"
+
+#: sequencer.c:4050
+#, c-format
+msgid "unknown command %d"
+msgstr "未知指令 %d"
+
+#: sequencer.c:4109
+msgid "could not read orig-head"
+msgstr "不能讀取 orig-head"
+
+#: sequencer.c:4114
+msgid "could not read 'onto'"
+msgstr "不能讀取 'onto'"
+
+#: sequencer.c:4128
+#, c-format
+msgid "could not update HEAD to %s"
+msgstr "不能更新 HEAD 為 %s"
+
+#: sequencer.c:4221
+msgid "cannot rebase: You have unstaged changes."
+msgstr "不能重定基底：您有未暫存的變更。"
+
+#: sequencer.c:4230
+msgid "cannot amend non-existing commit"
+msgstr "不能修補不存在的提交"
+
+#: sequencer.c:4232
+#, c-format
+msgid "invalid file: '%s'"
+msgstr "無效檔案：'%s'"
+
+#: sequencer.c:4234
+#, c-format
+msgid "invalid contents: '%s'"
+msgstr "無效內容：'%s'"
+
+#: sequencer.c:4237
+msgid ""
+"\n"
+"You have uncommitted changes in your working tree. Please, commit them\n"
+"first and then run 'git rebase --continue' again."
+msgstr ""
+"\n"
+"您的工作區中有未提交的變更。請先提交然後再次執行 'git rebase --continue'。"
+
+#: sequencer.c:4273 sequencer.c:4312
+#, c-format
+msgid "could not write file: '%s'"
+msgstr "不能寫入檔案：'%s'"
+
+#: sequencer.c:4327
+msgid "could not remove CHERRY_PICK_HEAD"
+msgstr "不能刪除 CHERRY_PICK_HEAD"
+
+#: sequencer.c:4334
+msgid "could not commit staged changes."
+msgstr "不能提交暫存的修改。"
+
+#: sequencer.c:4440
+#, c-format
+msgid "%s: can't cherry-pick a %s"
+msgstr "%s：不能揀選一個%s"
+
+#: sequencer.c:4444
+#, c-format
+msgid "%s: bad revision"
+msgstr "%s：錯誤的版本"
+
+#: sequencer.c:4479
+msgid "can't revert as initial commit"
+msgstr "不能作為初始提交還原提交"
+
+#: sequencer.c:4952
+msgid "make_script: unhandled options"
+msgstr "make_script：有未能處理的選項"
+
+#: sequencer.c:4955
+msgid "make_script: error preparing revisions"
+msgstr "make_script：準備版本時錯誤"
+
+#: sequencer.c:5113
+msgid ""
+"You can fix this with 'git rebase --edit-todo' and then run 'git rebase --"
+"continue'.\n"
+"Or you can abort the rebase with 'git rebase --abort'.\n"
+msgstr ""
+"您可以用 'git rebase --edit-todo' 修正，然後執行 'git rebase --continue'。\n"
+"或者您可以用 'git rebase --abort' 終止重定基底。\n"
+
+#: sequencer.c:5226 sequencer.c:5243
+msgid "nothing to do"
+msgstr "無事可做"
+
+#: sequencer.c:5257
+msgid "could not skip unnecessary pick commands"
+msgstr "無法跳過不必要的揀選"
+
+#: sequencer.c:5351
+msgid "the script was already rearranged."
+msgstr "腳本已經重新編排。"
+
+#: setup.c:124
+#, c-format
+msgid "'%s' is outside repository"
+msgstr "'%s' 在版本庫之外"
+
+#: setup.c:174
+#, c-format
+msgid ""
+"%s: no such path in the working tree.\n"
+"Use 'git <command> -- <path>...' to specify paths that do not exist locally."
+msgstr ""
+"%s：工作區中無此路徑。\n"
+"使用指令 'git <指令> -- <路徑>...' 來指定本機不存在的路徑。"
+
+#: setup.c:187
+#, c-format
+msgid ""
+"ambiguous argument '%s': unknown revision or path not in the working tree.\n"
+"Use '--' to separate paths from revisions, like this:\n"
+"'git <command> [<revision>...] -- [<file>...]'"
+msgstr ""
+"有歧義的參數 '%s'：未知的版本或路徑不存在於工作區中。\n"
+"使用 '--' 來分隔版本和路徑，例如：\n"
+"'git <指令> [<版本>...] -- [<檔案>...]'"
+
+#: setup.c:236
+#, c-format
+msgid "option '%s' must come before non-option arguments"
+msgstr "選項 '%s' 必須在其他非選項參數之前"
+
+#: setup.c:255
+#, c-format
+msgid ""
+"ambiguous argument '%s': both revision and filename\n"
+"Use '--' to separate paths from revisions, like this:\n"
+"'git <command> [<revision>...] -- [<file>...]'"
+msgstr ""
+"有歧義的參數 '%s'：可同時是版本和檔案\n"
+"使用 '--' 來分隔版本和路徑，例如：\n"
+"'git <指令> [<版本>...] -- [<檔案>...]'"
+
+#: setup.c:391
+msgid "unable to set up work tree using invalid config"
+msgstr "無法使用無效設定來建立工作區"
+
+#: setup.c:395
+msgid "this operation must be run in a work tree"
+msgstr "該動作必須在一個工作區中執行"
+
+#: setup.c:541
+#, c-format
+msgid "Expected git repo version <= %d, found %d"
+msgstr "期望 git 版本庫版本 <= %d，卻得到 %d"
+
+#: setup.c:549
+msgid "unknown repository extensions found:"
+msgstr "發現未知的版本庫擴展："
+
+#: setup.c:568
+#, c-format
+msgid "error opening '%s'"
+msgstr "開啟 '%s' 發生錯誤"
+
+#: setup.c:570
+#, c-format
+msgid "too large to be a .git file: '%s'"
+msgstr "檔案太大，無法作為 .git 檔案：'%s'"
+
+#: setup.c:572
+#, c-format
+msgid "error reading %s"
+msgstr "讀取 %s 發生錯誤"
+
+#: setup.c:574
+#, c-format
+msgid "invalid gitfile format: %s"
+msgstr "無效的 gitfile 格式：%s"
+
+#: setup.c:576
+#, c-format
+msgid "no path in gitfile: %s"
+msgstr "在 gitfile 中沒有路徑：%s"
+
+#: setup.c:578
+#, c-format
+msgid "not a git repository: %s"
+msgstr "不是一個 git 版本庫：%s"
+
+#: setup.c:677
+#, c-format
+msgid "'$%s' too big"
+msgstr "'$%s' 太大"
+
+#: setup.c:691
+#, c-format
+msgid "not a git repository: '%s'"
+msgstr "不是一個 git 版本庫：'%s'"
+
+#: setup.c:720 setup.c:722 setup.c:753
+#, c-format
+msgid "cannot chdir to '%s'"
+msgstr "不能切換目錄到 '%s'"
+
+#: setup.c:725 setup.c:781 setup.c:791 setup.c:830 setup.c:838
+msgid "cannot come back to cwd"
+msgstr "無法返回目前工作目錄"
+
+#: setup.c:852
+#, c-format
+msgid "failed to stat '%*s%s%s'"
+msgstr "取得 '%*s%s%s' 狀態（stat）失敗"
+
+#: setup.c:1090
+msgid "Unable to read current working directory"
+msgstr "不能讀取目前工作目錄"
+
+#: setup.c:1099 setup.c:1105
+#, c-format
+msgid "cannot change to '%s'"
+msgstr "不能切換到 '%s'"
+
+#: setup.c:1110
+#, c-format
+msgid "not a git repository (or any of the parent directories): %s"
+msgstr "不是一個 git 版本庫（或者任何父目錄）：%s"
+
+#: setup.c:1116
+#, c-format
+msgid ""
+"not a git repository (or any parent up to mount point %s)\n"
+"Stopping at filesystem boundary (GIT_DISCOVERY_ACROSS_FILESYSTEM not set)."
+msgstr ""
+"不是一個 git 版本庫（或者直至掛載點 %s 的任何父目錄）\n"
+"停止在檔案系統邊界（未設定 GIT_DISCOVERY_ACROSS_FILESYSTEM）。"
+
+#: setup.c:1227
+#, c-format
+msgid ""
+"problem with core.sharedRepository filemode value (0%.3o).\n"
+"The owner of files must always have read and write permissions."
+msgstr ""
+"參數 core.sharedRepository 的檔案屬性值有問題（0%.3o）。\n"
+"檔案所有者必須始終擁有讀寫權限。"
+
+#: setup.c:1271
+msgid "open /dev/null or dup failed"
+msgstr "不能開啟或者複製 /dev/null"
+
+#: setup.c:1286
+msgid "fork failed"
+msgstr "fork 失敗"
+
+#: setup.c:1291
+msgid "setsid failed"
+msgstr "setsid 失敗"
+
+#: sha1-file.c:452
+#, c-format
+msgid "object directory %s does not exist; check .git/objects/info/alternates"
+msgstr "物件目錄 %s 不存在，檢查 .git/objects/info/alternates"
+
+#: sha1-file.c:503
+#, c-format
+msgid "unable to normalize alternate object path: %s"
+msgstr "無法規範化備用物件路徑：%s"
+
+#: sha1-file.c:575
+#, c-format
+msgid "%s: ignoring alternate object stores, nesting too deep"
+msgstr "%s：忽略備用物件庫，嵌套太深"
+
+#: sha1-file.c:582
+#, c-format
+msgid "unable to normalize object directory: %s"
+msgstr "無法規範化物件目錄: %s"
+
+#: sha1-file.c:625
+msgid "unable to fdopen alternates lockfile"
+msgstr "無法 fdopen 取代鎖檔案"
+
+#: sha1-file.c:643
+msgid "unable to read alternates file"
+msgstr "無法讀取替代檔案"
+
+#: sha1-file.c:650
+msgid "unable to move new alternates file into place"
+msgstr "無法將新的替代檔案移動到位"
+
+#: sha1-file.c:685
+#, c-format
+msgid "path '%s' does not exist"
+msgstr "路徑 '%s' 不存在"
+
+#: sha1-file.c:711
+#, c-format
+msgid "reference repository '%s' as a linked checkout is not supported yet."
+msgstr "尚不支援將參考版本庫 '%s' 作為一個連結簽出。"
+
+#: sha1-file.c:717
+#, c-format
+msgid "reference repository '%s' is not a local repository."
+msgstr "參考版本庫 '%s' 不是一個本機版本庫。"
+
+#: sha1-file.c:723
+#, c-format
+msgid "reference repository '%s' is shallow"
+msgstr "參考版本庫 '%s' 是一個淺複製"
+
+#: sha1-file.c:731
+#, c-format
+msgid "reference repository '%s' is grafted"
+msgstr "參考版本庫 '%s' 已被移植"
+
+#: sha1-file.c:791
+#, c-format
+msgid "invalid line while parsing alternate refs: %s"
+msgstr "解析備用引用時無效的行：%s"
+
+#: sha1-file.c:943
+#, c-format
+msgid "attempting to mmap %<PRIuMAX> over limit %<PRIuMAX>"
+msgstr "嘗試 mmap %<PRIuMAX>，超過了最大值 %<PRIuMAX>"
+
+#: sha1-file.c:964
+msgid "mmap failed"
+msgstr "mmap 失敗"
+
+#: sha1-file.c:1128
+#, c-format
+msgid "object file %s is empty"
+msgstr "物件檔案 %s 為空"
+
+#: sha1-file.c:1252 sha1-file.c:2392
+#, c-format
+msgid "corrupt loose object '%s'"
+msgstr "損壞的鬆散物件 '%s'"
+
+#: sha1-file.c:1254 sha1-file.c:2396
+#, c-format
+msgid "garbage at end of loose object '%s'"
+msgstr "鬆散物件 '%s' 後面有垃圾資料"
+
+#: sha1-file.c:1296
+msgid "invalid object type"
+msgstr "無效的物件類型"
+
+#: sha1-file.c:1380
+#, c-format
+msgid "unable to unpack %s header with --allow-unknown-type"
+msgstr "無法用 --allow-unknown-type 參數解開 %s 標頭訊息"
+
+#: sha1-file.c:1383
+#, c-format
+msgid "unable to unpack %s header"
+msgstr "無法解開 %s 頭部"
+
+#: sha1-file.c:1389
+#, c-format
+msgid "unable to parse %s header with --allow-unknown-type"
+msgstr "無法用 --allow-unknown-type 參數解析 %s 標頭訊息"
+
+#: sha1-file.c:1392
+#, c-format
+msgid "unable to parse %s header"
+msgstr "無法解析 %s 頭部"
+
+#: sha1-file.c:1584
+#, c-format
+msgid "failed to read object %s"
+msgstr "讀取物件 %s 失敗"
+
+#: sha1-file.c:1588
+#, c-format
+msgid "replacement %s not found for %s"
+msgstr "找不到 %2$s 的替代 %1$s"
+
+#: sha1-file.c:1592
+#, c-format
+msgid "loose object %s (stored in %s) is corrupt"
+msgstr "鬆散物件 %s（儲存在 %s）已損壞"
+
+#: sha1-file.c:1596
+#, c-format
+msgid "packed object %s (stored in %s) is corrupt"
+msgstr "打包物件 %s（儲存在 %s）已損壞"
+
+#: sha1-file.c:1699
+#, c-format
+msgid "unable to write file %s"
+msgstr "無法寫檔案 %s"
+
+#: sha1-file.c:1706
+#, c-format
+msgid "unable to set permission to '%s'"
+msgstr "無法為 '%s' 設定權限"
+
+#: sha1-file.c:1713
+msgid "file write error"
+msgstr "檔案寫錯誤"
+
+#: sha1-file.c:1732
+msgid "error when closing loose object file"
+msgstr "關閉鬆散物件檔案時發生錯誤"
+
+#: sha1-file.c:1797
+#, c-format
+msgid "insufficient permission for adding an object to repository database %s"
+msgstr "權限不足，無法在版本庫物件庫 %s 中新增物件"
+
+#: sha1-file.c:1799
+msgid "unable to create temporary file"
+msgstr "無法建立暫存檔"
+
+#: sha1-file.c:1823
+msgid "unable to write loose object file"
+msgstr "不能寫鬆散物件檔案"
+
+#: sha1-file.c:1829
+#, c-format
+msgid "unable to deflate new object %s (%d)"
+msgstr "不能壓縮新物件 %s（%d）"
+
+#: sha1-file.c:1833
+#, c-format
+msgid "deflateEnd on object %s failed (%d)"
+msgstr "在物件 %s 上呼叫 deflateEnd 失敗（%d）"
+
+#: sha1-file.c:1837
+#, c-format
+msgid "confused by unstable object source data for %s"
+msgstr "被 %s 的不穩定物件源資料搞糊塗了"
+
+#: sha1-file.c:1847 builtin/pack-objects.c:925
+#, c-format
+msgid "failed utime() on %s"
+msgstr "在 %s 上呼叫 utime() 失敗"
+
+#: sha1-file.c:1922
+#, c-format
+msgid "cannot read object for %s"
+msgstr "不能讀取物件 %s"
+
+#: sha1-file.c:1962
+msgid "corrupt commit"
+msgstr "損壞的提交"
+
+#: sha1-file.c:1970
+msgid "corrupt tag"
+msgstr "損壞的標籤"
+
+#: sha1-file.c:2069
+#, c-format
+msgid "read error while indexing %s"
+msgstr "索引 %s 時讀取錯誤"
+
+#: sha1-file.c:2072
+#, c-format
+msgid "short read while indexing %s"
+msgstr "索引 %s 時讀入不完整"
+
+#: sha1-file.c:2145 sha1-file.c:2154
+#, c-format
+msgid "%s: failed to insert into database"
+msgstr "%s：插入資料庫失敗"
+
+#: sha1-file.c:2160
+#, c-format
+msgid "%s: unsupported file type"
+msgstr "%s：不支援的檔案類型"
+
+#: sha1-file.c:2184
+#, c-format
+msgid "%s is not a valid object"
+msgstr "%s 不是一個有效的物件"
+
+#: sha1-file.c:2186
+#, c-format
+msgid "%s is not a valid '%s' object"
+msgstr "%s 不是一個有效的 '%s' 物件"
+
+#: sha1-file.c:2213 builtin/index-pack.c:155
+#, c-format
+msgid "unable to open %s"
+msgstr "不能開啟 %s"
+
+#: sha1-file.c:2403 sha1-file.c:2455
+#, c-format
+msgid "hash mismatch for %s (expected %s)"
+msgstr "%s 的雜湊值不符合（預期 %s）"
+
+#: sha1-file.c:2427
+#, c-format
+msgid "unable to mmap %s"
+msgstr "不能 mmap %s"
+
+#: sha1-file.c:2432
+#, c-format
+msgid "unable to unpack header of %s"
+msgstr "無法解壓縮 %s 的頭部"
+
+#: sha1-file.c:2438
+#, c-format
+msgid "unable to parse header of %s"
+msgstr "無法解析 %s 的頭部"
+
+#: sha1-file.c:2449
+#, c-format
+msgid "unable to unpack contents of %s"
+msgstr "無法解壓縮 %s 的內容"
+
+#: sha1-name.c:487
+#, c-format
+msgid "short SHA1 %s is ambiguous"
+msgstr "短 SHA1 %s 存在歧義"
+
+#: sha1-name.c:498
+msgid "The candidates are:"
+msgstr "候選者有："
+
+#: sha1-name.c:797
+msgid ""
+"Git normally never creates a ref that ends with 40 hex characters\n"
+"because it will be ignored when you just specify 40-hex. These refs\n"
+"may be created by mistake. For example,\n"
+"\n"
+"  git switch -c $br $(git rev-parse ...)\n"
+"\n"
+"where \"$br\" is somehow empty and a 40-hex ref is created. Please\n"
+"examine these refs and maybe delete them. Turn this message off by\n"
+"running \"git config advice.objectNameWarning false\""
+msgstr ""
+"Git 通常不會建立一個以40個十六進位字元結尾的引用，因為當您只提供40\n"
+"個十六進位字元時將被忽略。這些引用可能被錯誤地建立。例如：\n"
+"\n"
+"  git switch -c $br $(git rev-parse ...)\n"
+"\n"
+"當 \"$br\" 某種原因空白時，一個40位十六進位的引用將被建立。請檢查這些\n"
+"引用，可能需要刪除它們。執行 \"git config advice.objectNameWarning\n"
+"false\" 指令關閉本消息通知。"
+
+#. TRANSLATORS: IEC 80000-13:2008 gibibyte
+#: strbuf.c:822
+#, c-format
+msgid "%u.%2.2u GiB"
+msgstr "%u.%2.2u GiB"
+
+#. TRANSLATORS: IEC 80000-13:2008 gibibyte/second
+#: strbuf.c:824
+#, c-format
+msgid "%u.%2.2u GiB/s"
+msgstr "%u.%2.2u GiB/s"
+
+#. TRANSLATORS: IEC 80000-13:2008 mebibyte
+#: strbuf.c:832
+#, c-format
+msgid "%u.%2.2u MiB"
+msgstr "%u.%2.2u MiB"
+
+#. TRANSLATORS: IEC 80000-13:2008 mebibyte/second
+#: strbuf.c:834
+#, c-format
+msgid "%u.%2.2u MiB/s"
+msgstr "%u.%2.2u MiB/s"
+
+#. TRANSLATORS: IEC 80000-13:2008 kibibyte
+#: strbuf.c:841
+#, c-format
+msgid "%u.%2.2u KiB"
+msgstr "%u.%2.2u KiB"
+
+#. TRANSLATORS: IEC 80000-13:2008 kibibyte/second
+#: strbuf.c:843
+#, c-format
+msgid "%u.%2.2u KiB/s"
+msgstr "%u.%2.2u KiB/s"
+
+#. TRANSLATORS: IEC 80000-13:2008 byte
+#: strbuf.c:849
+#, c-format
+msgid "%u byte"
+msgid_plural "%u bytes"
+msgstr[0] "%u 位元組"
+msgstr[1] "%u 位元組"
+
+#. TRANSLATORS: IEC 80000-13:2008 byte/second
+#: strbuf.c:851
+#, c-format
+msgid "%u byte/s"
+msgid_plural "%u bytes/s"
+msgstr[0] "%u 位元組/秒"
+msgstr[1] "%u 位元組/秒"
+
+#: strbuf.c:1149
+#, c-format
+#| msgid "could not read '%s'"
+msgid "could not edit '%s'"
+msgstr "無法編輯 '%s'"
+
+#: submodule.c:114 submodule.c:143
+msgid "Cannot change unmerged .gitmodules, resolve merge conflicts first"
+msgstr "無法修改未合併的 .gitmodules，先解決合併衝突"
+
+#: submodule.c:118 submodule.c:147
+#, c-format
+msgid "Could not find section in .gitmodules where path=%s"
+msgstr "無法在 .gitmodules 中找到 path=%s 的小節"
+
+#: submodule.c:154
+#, c-format
+msgid "Could not remove .gitmodules entry for %s"
+msgstr "無法移除 %s 的 .gitmodules 條目"
+
+#: submodule.c:165
+msgid "staging updated .gitmodules failed"
+msgstr "將更新後 .gitmodules 新增暫存區失敗"
+
+#: submodule.c:327
+#, c-format
+msgid "in unpopulated submodule '%s'"
+msgstr "位於未簽出的子模組 '%s'"
+
+#: submodule.c:358
+#, c-format
+msgid "Pathspec '%s' is in submodule '%.*s'"
+msgstr "路徑規格 '%s' 在子模組 '%.*s' 中"
+
+#: submodule.c:910
+#, c-format
+msgid "submodule entry '%s' (%s) is a %s, not a commit"
+msgstr "子模組條目 '%s'（%s）是一個 %s，不是一個提交"
+
+#: submodule.c:1147 builtin/branch.c:680 builtin/submodule--helper.c:2016
+msgid "Failed to resolve HEAD as a valid ref."
+msgstr "無法將 HEAD 解析為有效引用。"
+
+#: submodule.c:1481
+#, c-format
+msgid "Could not access submodule '%s'"
+msgstr "無法存取子模組 '%s'"
+
+#: submodule.c:1651
+#, c-format
+msgid "'%s' not recognized as a git repository"
+msgstr "無法將 '%s' 識別為一個 git 版本庫"
+
+#: submodule.c:1789
+#, c-format
+msgid "could not start 'git status' in submodule '%s'"
+msgstr "無法在子模組 '%s' 中啟動 'git status'"
+
+#: submodule.c:1802
+#, c-format
+msgid "could not run 'git status' in submodule '%s'"
+msgstr "無法在子模組 '%s' 中執行 'git status'"
+
+#: submodule.c:1817
+#, c-format
+msgid "Could not unset core.worktree setting in submodule '%s'"
+msgstr "無法在子模組 '%s' 中取消 core.worktree 的設定"
+
+#: submodule.c:1907
+#, c-format
+msgid "submodule '%s' has dirty index"
+msgstr "子模組 '%s' 中有髒索引"
+
+#: submodule.c:1959
+#, c-format
+msgid "Submodule '%s' could not be updated."
+msgstr "子模組 '%s' 無法被更新。"
+
+#: submodule.c:2027
+#, c-format
+msgid "submodule git dir '%s' is inside git dir '%.*s'"
+msgstr "「%s」子模組 git 目錄在「%.*s」git 路徑中"
+
+#: submodule.c:2048
+#, c-format
+msgid ""
+"relocate_gitdir for submodule '%s' with more than one worktree not supported"
+msgstr "不支援對有多個工作區的子模組 '%s' 執行 relocate_gitdir"
+
+#: submodule.c:2060 submodule.c:2119
+#, c-format
+msgid "could not lookup name for submodule '%s'"
+msgstr "不能查詢子模組 '%s' 的名稱"
+
+#: submodule.c:2064
+#, c-format
+msgid "refusing to move '%s' into an existing git dir"
+msgstr "拒絕移動「%s」至現存 git 目錄"
+
+#: submodule.c:2071
+#, c-format
+msgid ""
+"Migrating git directory of '%s%s' from\n"
+"'%s' to\n"
+"'%s'\n"
+msgstr ""
+"將 '%s%s' 的 git 目錄從\n"
+"'%s' 遷移至\n"
+"'%s'\n"
+
+#: submodule.c:2154
+#, c-format
+msgid "could not recurse into submodule '%s'"
+msgstr "無法遞迴子模組路徑 '%s'"
+
+#: submodule.c:2198
+msgid "could not start ls-files in .."
+msgstr "無法在 .. 中啟動 ls-files"
+
+#: submodule.c:2237
+#, c-format
+msgid "ls-tree returned unexpected return code %d"
+msgstr "ls-tree 返回未知返回值 %d"
+
+#: submodule-config.c:236
+#, c-format
+msgid "ignoring suspicious submodule name: %s"
+msgstr "忽略可疑的子模組名稱：%s"
+
+#: submodule-config.c:303
+msgid "negative values not allowed for submodule.fetchjobs"
+msgstr "submodule.fetchjobs 不允許為負值"
+
+#: submodule-config.c:401
+#, c-format
+msgid "ignoring '%s' which may be interpreted as a command-line option: %s"
+msgstr "忽略可能被解析為指令列選項的 '%s'：%s"
+
+#: submodule-config.c:498
+#, c-format
+msgid "invalid value for %s"
+msgstr "%s 的值無效"
+
+#: submodule-config.c:769
+#, c-format
+msgid "Could not update .gitmodules entry %s"
+msgstr "不能更新 .gitmodules 條目 %s"
+
+#: trailer.c:238
+#, c-format
+msgid "running trailer command '%s' failed"
+msgstr "執行 trailer 指令 '%s' 失敗"
+
+#: trailer.c:485 trailer.c:490 trailer.c:495 trailer.c:549 trailer.c:553
+#: trailer.c:557
+#, c-format
+msgid "unknown value '%s' for key '%s'"
+msgstr "鍵 '%2$s' 的未知取值 '%1$s'"
+
+#: trailer.c:539 trailer.c:544 builtin/remote.c:295
+#, c-format
+msgid "more than one %s"
+msgstr "多於一個 %s"
+
+#: trailer.c:730
+#, c-format
+msgid "empty trailer token in trailer '%.*s'"
+msgstr "簽名 '%.*s' 的鍵為空"
+
+#: trailer.c:750
+#, c-format
+msgid "could not read input file '%s'"
+msgstr "不能讀取輸入檔案 '%s'"
+
+#: trailer.c:753
+msgid "could not read from stdin"
+msgstr "不能自標準輸入讀取"
+
+#: trailer.c:1011 wrapper.c:665
+#, c-format
+msgid "could not stat %s"
+msgstr "不能對 %s 呼叫 stat"
+
+#: trailer.c:1013
+#, c-format
+msgid "file %s is not a regular file"
+msgstr "檔案 %s 不是一個正規檔案"
+
+#: trailer.c:1015
+#, c-format
+msgid "file %s is not writable by user"
+msgstr "檔案 %s 使用者不可寫"
+
+#: trailer.c:1027
+msgid "could not open temporary file"
+msgstr "不能開啟暫存檔"
+
+#: trailer.c:1067
+#, c-format
+msgid "could not rename temporary file to %s"
+msgstr "不能重新命名暫存檔為 %s"
+
+#: transport.c:116
+#, c-format
+msgid "Would set upstream of '%s' to '%s' of '%s'\n"
+msgstr "將要設定 '%1$s' 的上游為 '%3$s' 的 '%2$s'\n"
+
+#: transport.c:145
+#, c-format
+msgid "could not read bundle '%s'"
+msgstr "無法讀取 bundle '%s'"
+
+#: transport.c:214
+#, c-format
+msgid "transport: invalid depth option '%s'"
+msgstr "傳輸：無效的深度選項 '%s'"
+
+#: transport.c:266
+msgid "see protocol.version in 'git help config' for more details"
+msgstr "檢視 'git help config' 中的 protocol.version 取得更多訊息"
+
+#: transport.c:267
+msgid "server options require protocol version 2 or later"
+msgstr "服務端選項需要版本 2 協定或更高"
+
+#: transport.c:632
+msgid "could not parse transport.color.* config"
+msgstr "不能解析 transport.color.* 設定"
+
+#: transport.c:705
+msgid "support for protocol v2 not implemented yet"
+msgstr "協定 v2 的支援尚未實現"
+
+#: transport.c:831
+#, c-format
+msgid "unknown value for config '%s': %s"
+msgstr "設定 '%s' 的取值未知：%s"
+
+#: transport.c:897
+#, c-format
+msgid "transport '%s' not allowed"
+msgstr "傳輸 '%s' 不允許"
+
+#: transport.c:949
+msgid "git-over-rsync is no longer supported"
+msgstr "不再支援 git-over-rsync"
+
+#: transport.c:1044
+#, c-format
+msgid ""
+"The following submodule paths contain changes that can\n"
+"not be found on any remote:\n"
+msgstr "下列子模組路徑所包含的修改在任何遠端源中都找不到：\n"
+
+#: transport.c:1048
+#, c-format
+msgid ""
+"\n"
+"Please try\n"
+"\n"
+"\tgit push --recurse-submodules=on-demand\n"
+"\n"
+"or cd to the path and use\n"
+"\n"
+"\tgit push\n"
+"\n"
+"to push them to a remote.\n"
+"\n"
+msgstr ""
+"\n"
+"請嘗試\n"
+"\n"
+"\tgit push --recurse-submodules=on-demand\n"
+"\n"
+"或者進入到子目錄執行\n"
+"\n"
+"\tgit push\n"
+"\n"
+"以推送至遠端。\n"
+"\n"
+
+#: transport.c:1056
+msgid "Aborting."
+msgstr "正在終止。"
+
+#: transport.c:1201
+msgid "failed to push all needed submodules"
+msgstr "不能推送全部需要的子模組"
+
+#: transport.c:1345 transport-helper.c:656
+msgid "operation not supported by protocol"
+msgstr "協定不支援該動作"
+
+#: transport-helper.c:61 transport-helper.c:90
+msgid "full write to remote helper failed"
+msgstr "完整寫入遠端助手失敗"
+
+#: transport-helper.c:144
+#, c-format
+msgid "unable to find remote helper for '%s'"
+msgstr "無法為 '%s' 找到遠端助手"
+
+#: transport-helper.c:160 transport-helper.c:570
+msgid "can't dup helper output fd"
+msgstr "無法複製助手輸出檔案句柄"
+
+#: transport-helper.c:211
+#, c-format
+msgid ""
+"unknown mandatory capability %s; this remote helper probably needs newer "
+"version of Git"
+msgstr "未知的強制能力 %s，該遠端助手可能需要新版本的Git"
+
+#: transport-helper.c:217
+msgid "this remote helper should implement refspec capability"
+msgstr "遠端助手需要實現 refspec 能力"
+
+#: transport-helper.c:284 transport-helper.c:424
+#, c-format
+msgid "%s unexpectedly said: '%s'"
+msgstr "%s 意外地說：'%s'"
+
+#: transport-helper.c:413
+#, c-format
+msgid "%s also locked %s"
+msgstr "%s 也鎖定了 %s"
+
+#: transport-helper.c:492
+msgid "couldn't run fast-import"
+msgstr "不能執行 fast-import"
+
+#: transport-helper.c:515
+msgid "error while running fast-import"
+msgstr "執行 fast-import 發生錯誤"
+
+#: transport-helper.c:544 transport-helper.c:1133
+#, c-format
+msgid "could not read ref %s"
+msgstr "無法讀取引用 %s"
+
+#: transport-helper.c:589
+#, c-format
+msgid "unknown response to connect: %s"
+msgstr "連線時未知的回應：%s"
+
+#: transport-helper.c:611
+msgid "setting remote service path not supported by protocol"
+msgstr "協定不支援設定遠端服務路徑"
+
+#: transport-helper.c:613
+msgid "invalid remote service path"
+msgstr "無效的遠端服務路徑"
+
+#: transport-helper.c:659
+#, c-format
+msgid "can't connect to subservice %s"
+msgstr "不能連線到子服務 %s"
+
+#: transport-helper.c:735
+#, c-format
+msgid "expected ok/error, helper said '%s'"
+msgstr "預期 ok/error，助手說 '%s'"
+
+#: transport-helper.c:788
+#, c-format
+msgid "helper reported unexpected status of %s"
+msgstr "助手報告 %s 的意外狀態"
+
+#: transport-helper.c:849
+#, c-format
+msgid "helper %s does not support dry-run"
+msgstr "助手 %s 不支援 dry-run"
+
+#: transport-helper.c:852
+#, c-format
+msgid "helper %s does not support --signed"
+msgstr "助手 %s 不支援 --signed"
+
+#: transport-helper.c:855
+#, c-format
+msgid "helper %s does not support --signed=if-asked"
+msgstr "助手 %s 不支援 --signed=if-asked"
+
+#: transport-helper.c:860
+#, c-format
+msgid "helper %s does not support --atomic"
+msgstr "助手 %s 不支援 --atomic"
+
+#: transport-helper.c:866
+#, c-format
+msgid "helper %s does not support 'push-option'"
+msgstr "助手 %s 不支援 'push-option'"
+
+#: transport-helper.c:964
+msgid "remote-helper doesn't support push; refspec needed"
+msgstr "remote-heper 不支援 push，需要引用表達式"
+
+#: transport-helper.c:969
+#, c-format
+msgid "helper %s does not support 'force'"
+msgstr "助手 %s 不支援 'force'"
+
+#: transport-helper.c:1016
+msgid "couldn't run fast-export"
+msgstr "無法執行 fast-export"
+
+#: transport-helper.c:1021
+msgid "error while running fast-export"
+msgstr "執行 fast-export 時發生錯誤"
+
+#: transport-helper.c:1046
+#, c-format
+msgid ""
+"No refs in common and none specified; doing nothing.\n"
+"Perhaps you should specify a branch such as 'master'.\n"
+msgstr ""
+"沒有共同的引用並且也沒有指定，什麼也不會做。\n"
+"可能您應該指定一個分支如 'master'。\n"
+
+#: transport-helper.c:1119
+#, c-format
+msgid "malformed response in ref list: %s"
+msgstr "引用列表中格式錯誤的回應：%s"
+
+#: transport-helper.c:1271
+#, c-format
+msgid "read(%s) failed"
+msgstr "讀取（%s）失敗"
+
+#: transport-helper.c:1298
+#, c-format
+msgid "write(%s) failed"
+msgstr "寫（%s）失敗"
+
+#: transport-helper.c:1347
+#, c-format
+msgid "%s thread failed"
+msgstr "%s 執行緒失敗"
+
+#: transport-helper.c:1351
+#, c-format
+msgid "%s thread failed to join: %s"
+msgstr "%s 執行緒等待失敗：%s"
+
+#: transport-helper.c:1370 transport-helper.c:1374
+#, c-format
+msgid "can't start thread for copying data: %s"
+msgstr "不能啟動執行緒來複製資料：%s"
+
+#: transport-helper.c:1411
+#, c-format
+msgid "%s process failed to wait"
+msgstr "%s 進程等待失敗"
+
+#: transport-helper.c:1415
+#, c-format
+msgid "%s process failed"
+msgstr "%s 進程失敗"
+
+#: transport-helper.c:1433 transport-helper.c:1442
+msgid "can't start thread for copying data"
+msgstr "不能啟動執行緒來複製資料"
+
+#: tree-walk.c:33
+msgid "too-short tree object"
+msgstr "太短的樹狀物件"
+
+#: tree-walk.c:39
+msgid "malformed mode in tree entry"
+msgstr "樹狀物件中的條目模式錯誤"
+
+#: tree-walk.c:43
+msgid "empty filename in tree entry"
+msgstr "樹狀物件條目中空的檔案名"
+
+#: tree-walk.c:48
+#, c-format
+msgid "filename in tree entry contains backslash: '%s'"
+msgstr "樹狀物件中的檔案名稱有反斜線：'%s'"
+
+#: tree-walk.c:124
+msgid "too-short tree file"
+msgstr "太短的樹檔案"
+
+#: unpack-trees.c:110
+#, c-format
+msgid ""
+"Your local changes to the following files would be overwritten by checkout:\n"
+"%%sPlease commit your changes or stash them before you switch branches."
+msgstr ""
+"您對下列檔案的本機修改將被簽出動作覆蓋：\n"
+"%%s請在切換分支前提交或儲藏您的修改。"
+
+#: unpack-trees.c:112
+#, c-format
+msgid ""
+"Your local changes to the following files would be overwritten by checkout:\n"
+"%%s"
+msgstr ""
+"您對下列檔案的本機修改將被簽出動作覆蓋：\n"
+"%%s"
+
+#: unpack-trees.c:115
+#, c-format
+msgid ""
+"Your local changes to the following files would be overwritten by merge:\n"
+"%%sPlease commit your changes or stash them before you merge."
+msgstr ""
+"您對下列檔案的本機修改將被合併動作覆蓋：\n"
+"%%s請在合併前提交或儲藏您的修改。"
+
+#: unpack-trees.c:117
+#, c-format
+msgid ""
+"Your local changes to the following files would be overwritten by merge:\n"
+"%%s"
+msgstr ""
+"您對下列檔案的本機修改將被合併動作覆蓋：\n"
+"%%s"
+
+#: unpack-trees.c:120
+#, c-format
+msgid ""
+"Your local changes to the following files would be overwritten by %s:\n"
+"%%sPlease commit your changes or stash them before you %s."
+msgstr ""
+"您對下列檔案的本機修改將被 %s 覆蓋：\n"
+"%%s請在 %s 之前提交或儲藏您的修改。"
+
+#: unpack-trees.c:122
+#, c-format
+msgid ""
+"Your local changes to the following files would be overwritten by %s:\n"
+"%%s"
+msgstr ""
+"您對下列檔案的本機修改將被 %s 覆蓋：\n"
+"%%s"
+
+#: unpack-trees.c:127
+#, c-format
+msgid ""
+"Updating the following directories would lose untracked files in them:\n"
+"%s"
+msgstr ""
+"更新如下目錄將會遺失其中未追蹤的檔案：\n"
+"%s"
+
+#: unpack-trees.c:131
+#, c-format
+msgid ""
+"The following untracked working tree files would be removed by checkout:\n"
+"%%sPlease move or remove them before you switch branches."
+msgstr ""
+"工作區中下列未追蹤的檔案將會因為簽出動作而被刪除：\n"
+"%%s請在切換分支之前移動或刪除。"
+
+#: unpack-trees.c:133
+#, c-format
+msgid ""
+"The following untracked working tree files would be removed by checkout:\n"
+"%%s"
+msgstr ""
+"工作區中下列未追蹤的檔案將會因為簽出動作而被刪除：\n"
+"%%s"
+
+#: unpack-trees.c:136
+#, c-format
+msgid ""
+"The following untracked working tree files would be removed by merge:\n"
+"%%sPlease move or remove them before you merge."
+msgstr ""
+"工作區中下列未追蹤的檔案將會因為合併動作而被刪除：\n"
+"%%s請在合併前移動或刪除。"
+
+#: unpack-trees.c:138
+#, c-format
+msgid ""
+"The following untracked working tree files would be removed by merge:\n"
+"%%s"
+msgstr ""
+"工作區中下列未追蹤的檔案將會因為合併動作而被刪除：\n"
+"%%s"
+
+#: unpack-trees.c:141
+#, c-format
+msgid ""
+"The following untracked working tree files would be removed by %s:\n"
+"%%sPlease move or remove them before you %s."
+msgstr ""
+"工作區中下列未追蹤的檔案將會因為 %s 動作而被刪除：\n"
+"%%s請在 %s 前移動或刪除。"
+
+#: unpack-trees.c:143
+#, c-format
+msgid ""
+"The following untracked working tree files would be removed by %s:\n"
+"%%s"
+msgstr ""
+"工作區中下列未追蹤的檔案將會因為 %s 動作而被刪除：\n"
+"%%s"
+
+#: unpack-trees.c:149
+#, c-format
+msgid ""
+"The following untracked working tree files would be overwritten by "
+"checkout:\n"
+"%%sPlease move or remove them before you switch branches."
+msgstr ""
+"工作區中下列未追蹤的檔案將會因為簽出動作而被覆蓋：\n"
+"%%s請在切換分支前移動或刪除。"
+
+#: unpack-trees.c:151
+#, c-format
+msgid ""
+"The following untracked working tree files would be overwritten by "
+"checkout:\n"
+"%%s"
+msgstr ""
+"工作區中下列未追蹤的檔案將會因為簽出動作而被覆蓋：\n"
+"%%s"
+
+#: unpack-trees.c:154
+#, c-format
+msgid ""
+"The following untracked working tree files would be overwritten by merge:\n"
+"%%sPlease move or remove them before you merge."
+msgstr ""
+"工作區中下列未追蹤的檔案將會因為合併動作而被覆蓋：\n"
+"%%s請在合併前移動或刪除。"
+
+#: unpack-trees.c:156
+#, c-format
+msgid ""
+"The following untracked working tree files would be overwritten by merge:\n"
+"%%s"
+msgstr ""
+"工作區中下列未追蹤的檔案將會因為合併動作而被覆蓋：\n"
+"%%s"
+
+#: unpack-trees.c:159
+#, c-format
+msgid ""
+"The following untracked working tree files would be overwritten by %s:\n"
+"%%sPlease move or remove them before you %s."
+msgstr ""
+"工作區中下列未追蹤的檔案將會因為 %s 動作而被覆蓋：\n"
+"%%s請在 %s 前移動或刪除。"
+
+#: unpack-trees.c:161
+#, c-format
+msgid ""
+"The following untracked working tree files would be overwritten by %s:\n"
+"%%s"
+msgstr ""
+"工作區中下列未追蹤的檔案將會因為 %s 動作而被覆蓋：\n"
+"%%s"
+
+#: unpack-trees.c:169
+#, c-format
+msgid "Entry '%s' overlaps with '%s'.  Cannot bind."
+msgstr "條目 '%s' 和 '%s' 重疊。無法合併。"
+
+#: unpack-trees.c:172
+#, c-format
+msgid ""
+"Cannot update sparse checkout: the following entries are not up to date:\n"
+"%s"
+msgstr ""
+"無法更新稀疏簽出：如下條目不是最新：\n"
+"%s"
+
+#: unpack-trees.c:174
+#, c-format
+msgid ""
+"The following working tree files would be overwritten by sparse checkout "
+"update:\n"
+"%s"
+msgstr ""
+"工作區中下列檔案將被稀疏簽出更新所覆蓋：\n"
+"%s"
+
+#: unpack-trees.c:176
+#, c-format
+msgid ""
+"The following working tree files would be removed by sparse checkout "
+"update:\n"
+"%s"
+msgstr ""
+"工作區中下列檔案將被稀疏簽出更新所刪除：\n"
+"%s"
+
+#: unpack-trees.c:178
+#, c-format
+msgid ""
+"Cannot update submodule:\n"
+"%s"
+msgstr ""
+"無法更新子模組：\n"
+"%s"
+
+#: unpack-trees.c:255
+#, c-format
+msgid "Aborting\n"
+msgstr "正在終止\n"
+
+#: unpack-trees.c:317
+msgid "Updating files"
+msgstr "正在更新檔案"
+
+#: unpack-trees.c:349
+msgid ""
+"the following paths have collided (e.g. case-sensitive paths\n"
+"on a case-insensitive filesystem) and only one from the same\n"
+"colliding group is in the working tree:\n"
+msgstr ""
+"以下路徑發生碰撞（如：在不區分大小寫的檔案系統上的區分大小寫的路徑），\n"
+"並且碰撞組中只有一個檔案存在工作區中：\n"
+
+#: unpack-trees.c:1441
+#| msgid "Updating files"
+msgid "Updating index flags"
+msgstr "正在更新索引旗標"
+
+#: urlmatch.c:163
+msgid "invalid URL scheme name or missing '://' suffix"
+msgstr "無效的 URL 方案名稱或遺失 '://' 後綴"
+
+#: urlmatch.c:187 urlmatch.c:346 urlmatch.c:405
+#, c-format
+msgid "invalid %XX escape sequence"
+msgstr "無效的 %XX 轉義序列"
+
+#: urlmatch.c:215
+msgid "missing host and scheme is not 'file:'"
+msgstr "缺少主機名稱且 URL 方案不是 'file:'"
+
+#: urlmatch.c:232
+msgid "a 'file:' URL may not have a port number"
+msgstr "一個 'file:' URL 不應該包含埠號"
+
+#: urlmatch.c:247
+msgid "invalid characters in host name"
+msgstr "主機名稱中包含無效的字元"
+
+#: urlmatch.c:292 urlmatch.c:303
+msgid "invalid port number"
+msgstr "無效的埠號"
+
+#: urlmatch.c:371
+msgid "invalid '..' path segment"
+msgstr "無效的 '..' 路徑片段"
+
+#: worktree.c:258 builtin/am.c:2084
+#, c-format
+msgid "failed to read '%s'"
+msgstr "讀取 '%s' 失敗"
+
+#: worktree.c:304
+#, c-format
+msgid "'%s' at main working tree is not the repository directory"
+msgstr "在主工作區的 '%s' 不是版本庫目錄"
+
+#: worktree.c:315
+#, c-format
+msgid "'%s' file does not contain absolute path to the working tree location"
+msgstr "檔案 '%s' 不包含工作區的絕對路徑"
+
+#: worktree.c:327
+#, c-format
+msgid "'%s' does not exist"
+msgstr "'%s' 不存在"
+
+#: worktree.c:333
+#, c-format
+msgid "'%s' is not a .git file, error code %d"
+msgstr "'%s' 不是一個 .git 檔案，錯誤碼 %d"
+
+#: worktree.c:341
+#, c-format
+msgid "'%s' does not point back to '%s'"
+msgstr "'%s' 沒有指回到 '%s'"
+
+#: wrapper.c:186 wrapper.c:356
+#, c-format
+msgid "could not open '%s' for reading and writing"
+msgstr "無法開啟 '%s' 進行讀寫"
+
+#: wrapper.c:387 wrapper.c:588
+#, c-format
+msgid "unable to access '%s'"
+msgstr "不能存取 '%s'"
+
+#: wrapper.c:596
+msgid "unable to get current working directory"
+msgstr "不能取得目前工作目錄"
+
+#: wt-status.c:158
+msgid "Unmerged paths:"
+msgstr "未合併的路徑："
+
+#  譯者：請維持前導空格
+#: wt-status.c:187 wt-status.c:219
+msgid "  (use \"git restore --staged <file>...\" to unstage)"
+msgstr "  （使用 \"git restore --staged <檔案>...\" 以取消暫存）"
+
+#  譯者：請維持前導空格
+#: wt-status.c:190 wt-status.c:222
+#, c-format
+msgid "  (use \"git restore --source=%s --staged <file>...\" to unstage)"
+msgstr "  （使用 \"git restore --source=%s --staged <檔案>...\" 以取消暫存）"
+
+#  譯者：請維持前導空格
+#: wt-status.c:193 wt-status.c:225
+msgid "  (use \"git rm --cached <file>...\" to unstage)"
+msgstr "  （使用 \"git rm --cached <檔案>...\" 以取消暫存）"
+
+#  譯者：請維持前導空格
+#: wt-status.c:197
+msgid "  (use \"git add <file>...\" to mark resolution)"
+msgstr "  （使用 \"git add <檔案>...\" 標記解決方案）"
+
+#  譯者：請維持前導空格
+#: wt-status.c:199 wt-status.c:203
+msgid "  (use \"git add/rm <file>...\" as appropriate to mark resolution)"
+msgstr "  （酌情使用 \"git add/rm <檔案>...\" 標記解決方案）"
+
+#  譯者：請維持前導空格
+#: wt-status.c:201
+msgid "  (use \"git rm <file>...\" to mark resolution)"
+msgstr "  （使用 \"git rm <檔案>...\" 標記解決方案）"
+
+#: wt-status.c:211 wt-status.c:1074
+msgid "Changes to be committed:"
+msgstr "要提交的變更："
+
+#: wt-status.c:234 wt-status.c:1083
+msgid "Changes not staged for commit:"
+msgstr "尚未暫存以備提交的變更："
+
+#  譯者：請維持前導空格
+#: wt-status.c:238
+msgid "  (use \"git add <file>...\" to update what will be committed)"
+msgstr "  （使用 \"git add <檔案>...\" 更新要提交的內容）"
+
+#  譯者：請維持前導空格
+#: wt-status.c:240
+msgid "  (use \"git add/rm <file>...\" to update what will be committed)"
+msgstr "  （使用 \"git add/rm <檔案>...\" 更新要提交的內容）"
+
+#  譯者：請維持前導空格
+#: wt-status.c:241
+msgid ""
+"  (use \"git restore <file>...\" to discard changes in working directory)"
+msgstr "  （使用 \"git restore <檔案>...\" 捨棄工作區的改動）"
+
+#  譯者：請維持前導空格
+#: wt-status.c:243
+msgid "  (commit or discard the untracked or modified content in submodules)"
+msgstr "  （提交或捨棄子模組中未追蹤或修改的內容）"
+
+#  譯者：請維持前導空格
+#: wt-status.c:254
+#, c-format
+msgid "  (use \"git %s <file>...\" to include in what will be committed)"
+msgstr "  （使用 \"git %s <檔案>...\" 以包含要提交的內容）"
+
+#: wt-status.c:268
+msgid "both deleted:"
+msgstr "雙方刪除："
+
+#: wt-status.c:270
+msgid "added by us:"
+msgstr "由我們新增："
+
+#: wt-status.c:272
+msgid "deleted by them:"
+msgstr "由他們刪除："
+
+#: wt-status.c:274
+msgid "added by them:"
+msgstr "由他們新增："
+
+#: wt-status.c:276
+msgid "deleted by us:"
+msgstr "由我們刪除："
+
+#: wt-status.c:278
+msgid "both added:"
+msgstr "雙方新增："
+
+#: wt-status.c:280
+msgid "both modified:"
+msgstr "雙方修改："
+
+#: wt-status.c:290
+msgid "new file:"
+msgstr "新檔案："
+
+#: wt-status.c:292
+msgid "copied:"
+msgstr "複製："
+
+#: wt-status.c:294
+msgid "deleted:"
+msgstr "刪除："
+
+#: wt-status.c:296
+msgid "modified:"
+msgstr "修改："
+
+#: wt-status.c:298
+msgid "renamed:"
+msgstr "重新命名："
+
+#: wt-status.c:300
+msgid "typechange:"
+msgstr "類型變更："
+
+#: wt-status.c:302
+msgid "unknown:"
+msgstr "未知："
+
+#: wt-status.c:304
+msgid "unmerged:"
+msgstr "未合併："
+
+#  譯者：末尾兩個位元組可能被刪減，如果翻譯為中文標點會出現半個漢字
+#: wt-status.c:384
+msgid "new commits, "
+msgstr "新提交, "
+
+#  譯者：末尾兩個位元組可能被刪減，如果翻譯為中文標點會出現半個漢字
+#: wt-status.c:386
+msgid "modified content, "
+msgstr "修改的內容, "
+
+#  譯者：末尾兩個位元組可能被刪減，如果翻譯為中文標點會出現半個漢字
+#: wt-status.c:388
+msgid "untracked content, "
+msgstr "未追蹤的內容, "
+
+#: wt-status.c:906
+#, c-format
+msgid "Your stash currently has %d entry"
+msgid_plural "Your stash currently has %d entries"
+msgstr[0] "您的儲藏區目前有 %d 條紀錄"
+msgstr[1] "您的儲藏區目前有 %d 條紀錄"
+
+#: wt-status.c:938
+msgid "Submodules changed but not updated:"
+msgstr "子模組已修改但尚未更新："
+
+#: wt-status.c:940
+msgid "Submodule changes to be committed:"
+msgstr "要提交的子模組變更："
+
+#: wt-status.c:1022
+msgid ""
+"Do not modify or remove the line above.\n"
+"Everything below it will be ignored."
+msgstr ""
+"不要改動或刪除上面的一行。\n"
+"其下所有內容都將被忽略。"
+
+#: wt-status.c:1114
+#, c-format
+msgid ""
+"\n"
+"It took %.2f seconds to compute the branch ahead/behind values.\n"
+"You can use '--no-ahead-behind' to avoid this.\n"
+msgstr ""
+"\n"
+"花了 %.2f 秒才計算出分支的領先/落後範圍。\n"
+"為避免，您可以使用 '--no-ahead-behind'。\n"
+
+#: wt-status.c:1144
+msgid "You have unmerged paths."
+msgstr "您有尚未合併的路徑。"
+
+#  譯者：請維持前導空格
+#: wt-status.c:1147
+msgid "  (fix conflicts and run \"git commit\")"
+msgstr "  （解決衝突並執行 \"git commit\"）"
+
+#  譯者：請維持前導空格
+#: wt-status.c:1149
+msgid "  (use \"git merge --abort\" to abort the merge)"
+msgstr "  （使用 \"git merge --abort\" 終止合併）"
+
+#: wt-status.c:1153
+msgid "All conflicts fixed but you are still merging."
+msgstr "所有衝突已解決但您仍處於合併中。"
+
+#  譯者：請維持前導空格
+#: wt-status.c:1156
+msgid "  (use \"git commit\" to conclude merge)"
+msgstr "  （使用 \"git commit\" 結束合併）"
+
+#: wt-status.c:1165
+msgid "You are in the middle of an am session."
+msgstr "您正處於 am 動作過程中。"
+
+#: wt-status.c:1168
+msgid "The current patch is empty."
+msgstr "目前的修補檔為空。"
+
+#  譯者：請維持前導空格
+#: wt-status.c:1172
+msgid "  (fix conflicts and then run \"git am --continue\")"
+msgstr "  （解決衝突，然後執行 \"git am --continue\"）"
+
+#  譯者：請維持前導空格
+#: wt-status.c:1174
+msgid "  (use \"git am --skip\" to skip this patch)"
+msgstr "  （使用 \"git am --skip\" 跳過此修補檔）"
+
+#  譯者：請維持前導空格
+#: wt-status.c:1176
+msgid "  (use \"git am --abort\" to restore the original branch)"
+msgstr "  （使用 \"git am --abort\" 復原原有分支）"
+
+#: wt-status.c:1309
+msgid "git-rebase-todo is missing."
+msgstr "git-rebase-todo 遺失。"
+
+#: wt-status.c:1311
+msgid "No commands done."
+msgstr "沒有指令被執行。"
+
+#: wt-status.c:1314
+#, c-format
+msgid "Last command done (%d command done):"
+msgid_plural "Last commands done (%d commands done):"
+msgstr[0] "最後一條指令已完成（%d 條指令被執行）："
+msgstr[1] "最後的指令已完成（%d 條指令被執行）："
+
+#: wt-status.c:1325
+#, c-format
+msgid "  (see more in file %s)"
+msgstr "  （更多參見檔案 %s）"
+
+#: wt-status.c:1330
+msgid "No commands remaining."
+msgstr "未剩下任何指令。"
+
+#: wt-status.c:1333
+#, c-format
+msgid "Next command to do (%d remaining command):"
+msgid_plural "Next commands to do (%d remaining commands):"
+msgstr[0] "接下來要執行的指令（剩餘 %d 條指令）："
+msgstr[1] "接下來要執行的指令（剩餘 %d 條指令）："
+
+#  譯者：請維持前導空格
+#: wt-status.c:1341
+msgid "  (use \"git rebase --edit-todo\" to view and edit)"
+msgstr "  （使用 \"git rebase --edit-todo\" 來檢視和編輯）"
+
+#: wt-status.c:1353
+#, c-format
+msgid "You are currently rebasing branch '%s' on '%s'."
+msgstr "您在執行將分支 '%s' 重定基底到 '%s' 的動作。"
+
+#: wt-status.c:1358
+msgid "You are currently rebasing."
+msgstr "您在執行重定基底動作。"
+
+#  譯者：請維持前導空格
+#: wt-status.c:1371
+msgid "  (fix conflicts and then run \"git rebase --continue\")"
+msgstr "  （解決衝突，然後執行 \"git rebase --continue\"）"
+
+#  譯者：請維持前導空格
+#: wt-status.c:1373
+msgid "  (use \"git rebase --skip\" to skip this patch)"
+msgstr "  （使用 \"git rebase --skip\" 跳過此修補檔）"
+
+#  譯者：請維持前導空格
+#: wt-status.c:1375
+msgid "  (use \"git rebase --abort\" to check out the original branch)"
+msgstr "  （使用 \"git rebase --abort\" 以簽出原有分支）"
+
+#  譯者：請維持前導空格
+#: wt-status.c:1382
+msgid "  (all conflicts fixed: run \"git rebase --continue\")"
+msgstr "  （所有衝突已解決：執行 \"git rebase --continue\"）"
+
+#: wt-status.c:1386
+#, c-format
+msgid ""
+"You are currently splitting a commit while rebasing branch '%s' on '%s'."
+msgstr "您在執行將分支 '%s' 重定基底到 '%s' 的動作時分割提交。"
+
+#: wt-status.c:1391
+msgid "You are currently splitting a commit during a rebase."
+msgstr "您在執行重定基底動作時分割提交。"
+
+#  譯者：請維持前導空格
+#: wt-status.c:1394
+msgid "  (Once your working directory is clean, run \"git rebase --continue\")"
+msgstr "  （一旦您工作目錄提交乾淨後，執行 \"git rebase --continue\"）"
+
+#: wt-status.c:1398
+#, c-format
+msgid "You are currently editing a commit while rebasing branch '%s' on '%s'."
+msgstr "您在執行將分支 '%s' 重定基底到 '%s' 的動作時編輯提交。"
+
+#: wt-status.c:1403
+msgid "You are currently editing a commit during a rebase."
+msgstr "您在執行重定基底動作時編輯提交。"
+
+#  譯者：請維持前導空格
+#: wt-status.c:1406
+msgid "  (use \"git commit --amend\" to amend the current commit)"
+msgstr "  （使用 \"git commit --amend\" 修補目前提交）"
+
+#  譯者：請維持前導空格
+#: wt-status.c:1408
+msgid ""
+"  (use \"git rebase --continue\" once you are satisfied with your changes)"
+msgstr "  （當您對您的修改滿意後執行 \"git rebase --continue\"）"
+
+#: wt-status.c:1419
+msgid "Cherry-pick currently in progress."
+msgstr "揀選動作正在進行中。"
+
+#: wt-status.c:1422
+#, c-format
+msgid "You are currently cherry-picking commit %s."
+msgstr "您在執行揀選提交 %s 的動作。"
+
+#  譯者：請維持前導空格
+#: wt-status.c:1429
+msgid "  (fix conflicts and run \"git cherry-pick --continue\")"
+msgstr "  （解決衝突並執行 \"git cherry-pick --continue\"）"
+
+#  譯者：請維持前導空格
+#: wt-status.c:1432
+msgid "  (run \"git cherry-pick --continue\" to continue)"
+msgstr "  （執行 \"git cherry-pick --continue\" 以繼續）"
+
+#  譯者：請維持前導空格
+#: wt-status.c:1435
+msgid "  (all conflicts fixed: run \"git cherry-pick --continue\")"
+msgstr "  （所有衝突已解決：執行 \"git cherry-pick --continue\"）"
+
+#  譯者：請維持前導空格
+#: wt-status.c:1437
+msgid "  (use \"git cherry-pick --skip\" to skip this patch)"
+msgstr "  （使用 \"git cherry-pick --skip\" 跳過此修補檔）"
+
+#  譯者：請維持前導空格
+#: wt-status.c:1439
+msgid "  (use \"git cherry-pick --abort\" to cancel the cherry-pick operation)"
+msgstr "  （使用 \"git cherry-pick --abort\" 以取消揀選動作）"
+
+#: wt-status.c:1449
+msgid "Revert currently in progress."
+msgstr "還原動作正在行中。"
+
+#: wt-status.c:1452
+#, c-format
+msgid "You are currently reverting commit %s."
+msgstr "您在執行反轉提交 %s 的動作。"
+
+#  譯者：請維持前導空格
+#: wt-status.c:1458
+msgid "  (fix conflicts and run \"git revert --continue\")"
+msgstr "  （解決衝突並執行 \"git revert --continue\"）"
+
+#  譯者：請維持前導空格
+#: wt-status.c:1461
+msgid "  (run \"git revert --continue\" to continue)"
+msgstr "  （執行 \"git revert --continue\" 以繼續）"
+
+#  譯者：請維持前導空格
+#: wt-status.c:1464
+msgid "  (all conflicts fixed: run \"git revert --continue\")"
+msgstr "  （所有衝突已解決：執行 \"git revert --continue\"）"
+
+#  譯者：請維持前導空格
+#: wt-status.c:1466
+msgid "  (use \"git revert --skip\" to skip this patch)"
+msgstr "  （使用 \"git revert --skip\" 跳過此修補檔）"
+
+#  譯者：請維持前導空格
+#: wt-status.c:1468
+msgid "  (use \"git revert --abort\" to cancel the revert operation)"
+msgstr "  （使用 \"git revert --abort\" 以取消反轉提交動作）"
+
+#: wt-status.c:1478
+#, c-format
+msgid "You are currently bisecting, started from branch '%s'."
+msgstr "您在執行從分支 '%s' 開始的二分尋找動作。"
+
+#: wt-status.c:1482
+msgid "You are currently bisecting."
+msgstr "您在執行二分尋找動作。"
+
+#  譯者：請維持前導空格
+#: wt-status.c:1485
+msgid "  (use \"git bisect reset\" to get back to the original branch)"
+msgstr "  （使用 \"git bisect reset\" 簽出原有分支）"
+
+#: wt-status.c:1694
+msgid "On branch "
+msgstr "位於分支 "
+
+#: wt-status.c:1701
+msgid "interactive rebase in progress; onto "
+msgstr "互動式重定基底動作正在進行中；至 "
+
+#: wt-status.c:1703
+msgid "rebase in progress; onto "
+msgstr "重定基底動作正在進行中；至 "
+
+#: wt-status.c:1713
+msgid "Not currently on any branch."
+msgstr "目前不在任何分支上。"
+
+#: wt-status.c:1730
+msgid "Initial commit"
+msgstr "初始提交"
+
+#: wt-status.c:1731
+msgid "No commits yet"
+msgstr "尚無提交"
+
+#: wt-status.c:1745
+msgid "Untracked files"
+msgstr "未追蹤的檔案"
+
+#: wt-status.c:1747
+msgid "Ignored files"
+msgstr "忽略的檔案"
+
+#: wt-status.c:1751
+#, c-format
+msgid ""
+"It took %.2f seconds to enumerate untracked files. 'status -uno'\n"
+"may speed it up, but you have to be careful not to forget to add\n"
+"new files yourself (see 'git help status')."
+msgstr ""
+"耗費了 %.2f 秒以枚舉未追蹤的檔案。'status -uno' 也許能提高速度，\n"
+"但您需要小心不要忘了新增新檔案（參見 'git help status'）。"
+
+#: wt-status.c:1757
+#, c-format
+msgid "Untracked files not listed%s"
+msgstr "未追蹤的檔案沒有列出%s"
+
+#  譯者：中文字串拼接，可刪除前導空格
+#: wt-status.c:1759
+msgid " (use -u option to show untracked files)"
+msgstr "（使用 -u 參數顯示未追蹤的檔案）"
+
+#: wt-status.c:1765
+msgid "No changes"
+msgstr "沒有修改"
+
+#: wt-status.c:1770
+#, c-format
+msgid "no changes added to commit (use \"git add\" and/or \"git commit -a\")\n"
+msgstr "修改尚未加入提交（使用 \"git add\" 和/或 \"git commit -a\"）\n"
+
+#: wt-status.c:1773
+#, c-format
+msgid "no changes added to commit\n"
+msgstr "修改尚未加入提交\n"
+
+#: wt-status.c:1776
+#, c-format
+msgid ""
+"nothing added to commit but untracked files present (use \"git add\" to "
+"track)\n"
+msgstr "提交為空，但是存在尚未追蹤的檔案（使用 \"git add\" 建立追蹤）\n"
+
+#: wt-status.c:1779
+#, c-format
+msgid "nothing added to commit but untracked files present\n"
+msgstr "提交為空，但是存在尚未追蹤的檔案\n"
+
+#  譯者：中文字串拼接，可刪除前導空格
+#: wt-status.c:1782
+#, c-format
+msgid "nothing to commit (create/copy files and use \"git add\" to track)\n"
+msgstr "無檔案要提交（建立/複製檔案並使用 \"git add\" 建立追蹤）\n"
+
+#: wt-status.c:1785 wt-status.c:1790
+#, c-format
+msgid "nothing to commit\n"
+msgstr "無檔案要提交\n"
+
+#  譯者：中文字串拼接，可刪除前導空格
+#: wt-status.c:1788
+#, c-format
+msgid "nothing to commit (use -u to show untracked files)\n"
+msgstr "無檔案要提交（使用 -u 顯示未追蹤的檔案）\n"
+
+#  譯者：中文字串拼接，可刪除前導空格
+#: wt-status.c:1792
+#, c-format
+msgid "nothing to commit, working tree clean\n"
+msgstr "沒有要提交的檔案，工作區為乾淨狀態\n"
+
+#: wt-status.c:1905
+msgid "No commits yet on "
+msgstr "尚無提交在 "
+
+#: wt-status.c:1909
+msgid "HEAD (no branch)"
+msgstr "HEAD（非分支）"
+
+#: wt-status.c:1940
+msgid "different"
+msgstr "不同"
+
+#  譯者：請維持句尾空格
+#: wt-status.c:1942 wt-status.c:1950
+msgid "behind "
+msgstr "落後 "
+
+#: wt-status.c:1945 wt-status.c:1948
+msgid "ahead "
+msgstr "領先 "
+
+#. TRANSLATORS: the action is e.g. "pull with rebase"
+#: wt-status.c:2470
+#, c-format
+msgid "cannot %s: You have unstaged changes."
+msgstr "不能%s：您有未暫存的變更。"
+
+#: wt-status.c:2476
+msgid "additionally, your index contains uncommitted changes."
+msgstr "另外，您的索引中包含未提交的變更。"
+
+#: wt-status.c:2478
+#, c-format
+msgid "cannot %s: Your index contains uncommitted changes."
+msgstr "不能%s：您的索引中包含未提交的變更。"
+
+#: compat/precompose_utf8.c:58 builtin/clone.c:455
+#, c-format
+msgid "failed to unlink '%s'"
+msgstr "刪除 '%s' 失敗"
+
+#: builtin/add.c:26
+msgid "git add [<options>] [--] <pathspec>..."
+msgstr "git add [<選項>] [--] <路徑規格>..."
+
+#: builtin/add.c:87
+#, c-format
+msgid "unexpected diff status %c"
+msgstr "意外的差異狀態 %c"
+
+#: builtin/add.c:92 builtin/commit.c:288
+msgid "updating files failed"
+msgstr "更新檔案失敗"
+
+#: builtin/add.c:102
+#, c-format
+msgid "remove '%s'\n"
+msgstr "刪除 '%s'\n"
+
+#: builtin/add.c:177
+msgid "Unstaged changes after refreshing the index:"
+msgstr "重新整理索引之後尚未被暫存的變更："
+
+#: builtin/add.c:252 builtin/rev-parse.c:899
+msgid "Could not read the index"
+msgstr "不能讀取索引"
+
+#: builtin/add.c:263
+#, c-format
+msgid "Could not open '%s' for writing."
+msgstr "無法為寫入開啟 '%s'。"
+
+#: builtin/add.c:267
+msgid "Could not write patch"
+msgstr "不能生成修補檔"
+
+#: builtin/add.c:270
+msgid "editing patch failed"
+msgstr "編輯修補檔失敗"
+
+#: builtin/add.c:273
+#, c-format
+msgid "Could not stat '%s'"
+msgstr "不能對 '%s' 呼叫 stat"
+
+#: builtin/add.c:275
+msgid "Empty patch. Aborted."
+msgstr "空修補檔。異常終止。"
+
+#: builtin/add.c:280
+#, c-format
+msgid "Could not apply '%s'"
+msgstr "不能應用 '%s'"
+
+#: builtin/add.c:288
+msgid "The following paths are ignored by one of your .gitignore files:\n"
+msgstr "下列路徑根據您的一個 .gitignore 檔案而被忽略：\n"
+
+#: builtin/add.c:308 builtin/clean.c:910 builtin/fetch.c:163 builtin/mv.c:124
+#: builtin/prune-packed.c:56 builtin/pull.c:223 builtin/push.c:548
+#: builtin/remote.c:1344 builtin/rm.c:241 builtin/send-pack.c:165
+msgid "dry run"
+msgstr "測試執行"
+
+#: builtin/add.c:311
+msgid "interactive picking"
+msgstr "互動式揀選"
+
+#: builtin/add.c:312 builtin/checkout.c:1482 builtin/reset.c:307
+msgid "select hunks interactively"
+msgstr "互動式挑選資料區塊"
+
+#: builtin/add.c:313
+msgid "edit current diff and apply"
+msgstr "編輯目前差異並應用"
+
+#: builtin/add.c:314
+msgid "allow adding otherwise ignored files"
+msgstr "允許新增忽略的檔案"
+
+#: builtin/add.c:315
+msgid "update tracked files"
+msgstr "更新已追蹤的檔案"
+
+#: builtin/add.c:316
+msgid "renormalize EOL of tracked files (implies -u)"
+msgstr "對已追蹤檔案（隱含 -u）重新歸一換行符號"
+
+#: builtin/add.c:317
+msgid "record only the fact that the path will be added later"
+msgstr "只記錄，該路徑稍後再新增"
+
+#: builtin/add.c:318
+msgid "add changes from all tracked and untracked files"
+msgstr "新增所有改變的已追蹤檔案和未追蹤檔案"
+
+#: builtin/add.c:321
+msgid "ignore paths removed in the working tree (same as --no-all)"
+msgstr "忽略工作區中移除的路徑（和 --no-all 相同）"
+
+#: builtin/add.c:323
+msgid "don't add, only refresh the index"
+msgstr "不新增，只重新整理索引"
+
+#: builtin/add.c:324
+msgid "just skip files which cannot be added because of errors"
+msgstr "跳過因發生錯誤不能新增的檔案"
+
+#: builtin/add.c:325
+msgid "check if - even missing - files are ignored in dry run"
+msgstr "檢查在測試執行模式下檔案（即使不存在）是否被忽略"
+
+#: builtin/add.c:327 builtin/update-index.c:1004
+msgid "override the executable bit of the listed files"
+msgstr "覆蓋列表裡檔案的可執行位"
+
+#: builtin/add.c:329
+msgid "warn when adding an embedded repository"
+msgstr "建立一個嵌入式版本庫時給予警告"
+
+#: builtin/add.c:347
+#, c-format
+msgid ""
+"You've added another git repository inside your current repository.\n"
+"Clones of the outer repository will not contain the contents of\n"
+"the embedded repository and will not know how to obtain it.\n"
+"If you meant to add a submodule, use:\n"
+"\n"
+"\tgit submodule add <url> %s\n"
+"\n"
+"If you added this path by mistake, you can remove it from the\n"
+"index with:\n"
+"\n"
+"\tgit rm --cached %s\n"
+"\n"
+"See \"git help submodule\" for more information."
+msgstr ""
+"您在目前版本庫中新增了另外一個Git版本庫。複製外層的版本庫將不包含嵌入版本庫的"
+"內容，並且不知道該如何取得它。\n"
+"如果您要新增一個子模組，使用：\n"
+"\n"
+"\tgit submodule add <url> %s\n"
+"\n"
+"如果您不小心新增了這個路徑，可以用下面的指令將其從索引中刪除：\n"
+"\n"
+"\tgit rm --cached %s\n"
+"\n"
+"參見 \"git help submodule\" 取得更多訊息。"
+
+#: builtin/add.c:375
+#, c-format
+msgid "adding embedded git repository: %s"
+msgstr "正在新增嵌入式 git 版本庫：%s"
+
+#: builtin/add.c:393
+#, c-format
+msgid "Use -f if you really want to add them.\n"
+msgstr "使用 -f 參數如果您確實要新增它們。\n"
+
+#: builtin/add.c:400
+msgid "adding files failed"
+msgstr "新增檔案失敗"
+
+#: builtin/add.c:428 builtin/commit.c:348
+#| msgid "--first-parent is incompatible with --bisect"
+msgid "--pathspec-from-file is incompatible with --interactive/--patch"
+msgstr "--pathspec-from-file 與 --interactive/--patch 不相容"
+
+#: builtin/add.c:434
+#| msgid "--first-parent is incompatible with --bisect"
+msgid "--pathspec-from-file is incompatible with --edit"
+msgstr "--pathspec-from-file 與 --edit 不相容"
+
+#: builtin/add.c:446
+msgid "-A and -u are mutually incompatible"
+msgstr "-A 和 -u 選項互斥"
+
+#: builtin/add.c:449
+msgid "Option --ignore-missing can only be used together with --dry-run"
+msgstr "選項 --ignore-missing 只能和 --dry-run 同時使用"
+
+#: builtin/add.c:453
+#, c-format
+msgid "--chmod param '%s' must be either -x or +x"
+msgstr "參數 --chmod 取值 '%s' 必須是 -x 或 +x"
+
+#: builtin/add.c:471 builtin/checkout.c:1648 builtin/commit.c:354
+#: builtin/reset.c:327
+#| msgid "--patch is incompatible with --{hard,mixed,soft}"
+msgid "--pathspec-from-file is incompatible with pathspec arguments"
+msgstr "--pathspec-from-file 與 <路徑規格> 參數不相容"
+
+#: builtin/add.c:478 builtin/checkout.c:1660 builtin/commit.c:360
+#: builtin/reset.c:333
+msgid "--pathspec-file-nul requires --pathspec-from-file"
+msgstr "--pathspec-file-nul 需要 --pathspec-from-file"
+
+#: builtin/add.c:482
+#, c-format
+msgid "Nothing specified, nothing added.\n"
+msgstr "沒有指定檔案，也沒有檔案被新增。\n"
+
+#: builtin/add.c:483
+#, c-format
+msgid "Maybe you wanted to say 'git add .'?\n"
+msgstr "也許您想要執行 'git add .'？\n"
+
+#: builtin/am.c:347
+msgid "could not parse author script"
+msgstr "不能解析作者腳本"
+
+#: builtin/am.c:431
+#, c-format
+msgid "'%s' was deleted by the applypatch-msg hook"
+msgstr "'%s' 被 applypatch-msg 掛鉤刪除"
+
+#: builtin/am.c:473
+#, c-format
+msgid "Malformed input line: '%s'."
+msgstr "非法的輸入行：'%s'。"
+
+#: builtin/am.c:511
+#, c-format
+msgid "Failed to copy notes from '%s' to '%s'"
+msgstr "從 '%s' 複製註解到 '%s' 時失敗"
+
+#: builtin/am.c:537
+msgid "fseek failed"
+msgstr "fseek 失敗"
+
+#: builtin/am.c:725
+#, c-format
+msgid "could not parse patch '%s'"
+msgstr "無法解析修補檔 '%s'"
+
+#: builtin/am.c:790
+msgid "Only one StGIT patch series can be applied at once"
+msgstr "一次只能有一個 StGIT 修補檔佇列被應用"
+
+#: builtin/am.c:838
+msgid "invalid timestamp"
+msgstr "無效的時間戳"
+
+#: builtin/am.c:843 builtin/am.c:855
+msgid "invalid Date line"
+msgstr "無效的日期行"
+
+#: builtin/am.c:850
+msgid "invalid timezone offset"
+msgstr "無效的時區位移值"
+
+#: builtin/am.c:943
+msgid "Patch format detection failed."
+msgstr "修補檔格式偵測失敗。"
+
+#: builtin/am.c:948 builtin/clone.c:409
+#, c-format
+msgid "failed to create directory '%s'"
+msgstr "建立目錄 '%s' 失敗"
+
+#: builtin/am.c:953
+msgid "Failed to split patches."
+msgstr "分割修補檔失敗。"
+
+#: builtin/am.c:1084
+#, c-format
+msgid "When you have resolved this problem, run \"%s --continue\"."
+msgstr "當您解決這一問題，執行 \"%s --continue\"。"
+
+#: builtin/am.c:1085
+#, c-format
+msgid "If you prefer to skip this patch, run \"%s --skip\" instead."
+msgstr "如果您想要跳過這一修補檔，則執行 \"%s --skip\"。"
+
+#: builtin/am.c:1086
+#, c-format
+msgid "To restore the original branch and stop patching, run \"%s --abort\"."
+msgstr "若要復原至原始分支並停止修補檔動作，執行 \"%s --abort\"。"
+
+#: builtin/am.c:1169
+msgid "Patch sent with format=flowed; space at the end of lines might be lost."
+msgstr "修補檔使用 format=flowed 格式傳送，行尾的空格可能會遺失。"
+
+#: builtin/am.c:1197
+msgid "Patch is empty."
+msgstr "修補檔為空。"
+
+#: builtin/am.c:1262
+#, c-format
+msgid "missing author line in commit %s"
+msgstr "在提交 %s 中缺少作者行"
+
+#: builtin/am.c:1265
+#, c-format
+msgid "invalid ident line: %.*s"
+msgstr "無效的身份標記：%.*s"
+
+#: builtin/am.c:1484
+msgid "Repository lacks necessary blobs to fall back on 3-way merge."
+msgstr "版本庫缺乏必要的資料物件以進行三方合併。"
+
+#: builtin/am.c:1486
+msgid "Using index info to reconstruct a base tree..."
+msgstr "使用索引來重建一個（三方合併的）基礎目錄樹..."
+
+#: builtin/am.c:1505
+msgid ""
+"Did you hand edit your patch?\n"
+"It does not apply to blobs recorded in its index."
+msgstr ""
+"您是否曾手動編輯過您的修補檔？\n"
+"無法套用修補檔到索引中的資料物件上。"
+
+#: builtin/am.c:1511
+msgid "Falling back to patching base and 3-way merge..."
+msgstr "回落到基礎版本上打修補檔及進行三方合併..."
+
+#: builtin/am.c:1537
+msgid "Failed to merge in the changes."
+msgstr "無法合併變更。"
+
+#: builtin/am.c:1569
+msgid "applying to an empty history"
+msgstr "正套用到一個空歷史上"
+
+#: builtin/am.c:1616 builtin/am.c:1620
+#, c-format
+msgid "cannot resume: %s does not exist."
+msgstr "無法繼續：%s 不存在。"
+
+#: builtin/am.c:1638
+msgid "Commit Body is:"
+msgstr "提交內容為："
+
+#  譯者：請維持句尾空格
+#. TRANSLATORS: Make sure to include [y], [n], [e], [v] and [a]
+#. in your translation. The program will only accept English
+#. input at this point.
+#.
+#: builtin/am.c:1648
+#, c-format
+msgid "Apply? [y]es/[n]o/[e]dit/[v]iew patch/[a]ccept all: "
+msgstr "套用？是[y]/否[n]/編輯[e]/檢視修補檔[v]/應用所有[a]："
+
+#: builtin/am.c:1695 builtin/commit.c:394
+msgid "unable to write index file"
+msgstr "無法寫入索引檔案"
+
+#: builtin/am.c:1699
+#, c-format
+msgid "Dirty index: cannot apply patches (dirty: %s)"
+msgstr "髒索引：不能套用修補檔（髒檔案：%s）"
+
+#: builtin/am.c:1739 builtin/am.c:1807
+#, c-format
+msgid "Applying: %.*s"
+msgstr "應用：%.*s"
+
+#: builtin/am.c:1756
+msgid "No changes -- Patch already applied."
+msgstr "沒有變更 —— 修補檔已經應用過。"
+
+#: builtin/am.c:1762
+#, c-format
+msgid "Patch failed at %s %.*s"
+msgstr "打修補檔失敗於 %s %.*s"
+
+#: builtin/am.c:1766
+msgid "Use 'git am --show-current-patch' to see the failed patch"
+msgstr "用 'git am --show-current-patch' 指令檢視失敗的修補檔"
+
+#: builtin/am.c:1810
+msgid ""
+"No changes - did you forget to use 'git add'?\n"
+"If there is nothing left to stage, chances are that something else\n"
+"already introduced the same changes; you might want to skip this patch."
+msgstr ""
+"沒有變更 —— 您是不是忘了執行 'git add'？\n"
+"如果沒有什麼要新增到暫存區的，則很可能是其它提交已經引入了相同的變更。\n"
+"您也許想要跳過這個修補檔。"
+
+#: builtin/am.c:1817
+msgid ""
+"You still have unmerged paths in your index.\n"
+"You should 'git add' each file with resolved conflicts to mark them as "
+"such.\n"
+"You might run `git rm` on a file to accept \"deleted by them\" for it."
+msgstr ""
+"在您的索引中仍存在未合併的路徑。\n"
+"您應該對已經衝突解決的每一個檔案執行 'git add' 來標記已經完成。 \n"
+"你可以對 \"由他們刪除\" 的檔案執行 `git rm` 指令。"
+
+#: builtin/am.c:1924 builtin/am.c:1928 builtin/am.c:1940 builtin/reset.c:346
+#: builtin/reset.c:354
+#, c-format
+msgid "Could not parse object '%s'."
+msgstr "不能解析物件 '%s'。"
+
+#: builtin/am.c:1976
+msgid "failed to clean index"
+msgstr "清空索引失敗"
+
+#: builtin/am.c:2020
+msgid ""
+"You seem to have moved HEAD since the last 'am' failure.\n"
+"Not rewinding to ORIG_HEAD"
+msgstr "您好像在上一次 'am' 失敗後移動了 HEAD。未還原至 ORIG_HEAD"
+
+#: builtin/am.c:2117
+#, c-format
+msgid "Invalid value for --patch-format: %s"
+msgstr "無效的 --patch-format 值：%s"
+
+#: builtin/am.c:2153
+msgid "git am [<options>] [(<mbox> | <Maildir>)...]"
+msgstr "git am [<選項>] [(<mbox> | <Maildir>)...]"
+
+#: builtin/am.c:2154
+msgid "git am [<options>] (--continue | --skip | --abort)"
+msgstr "git am [<選項>] (--continue | --skip | --abort)"
+
+#: builtin/am.c:2160
+msgid "run interactively"
+msgstr "以互動式方式執行"
+
+#: builtin/am.c:2162
+msgid "historical option -- no-op"
+msgstr "老的參數 —— 無作用"
+
+#: builtin/am.c:2164
+msgid "allow fall back on 3way merging if needed"
+msgstr "如果必要，允許使用三方合併。"
+
+#: builtin/am.c:2165 builtin/init-db.c:494 builtin/prune-packed.c:58
+#: builtin/repack.c:304 builtin/stash.c:811
+msgid "be quiet"
+msgstr "靜默模式"
+
+#: builtin/am.c:2167
+msgid "add a Signed-off-by line to the commit message"
+msgstr "在提交說明中新增一個 Signed-off-by 簽名"
+
+#: builtin/am.c:2170
+msgid "recode into utf8 (default)"
+msgstr "使用 utf8 字元集（預設）"
+
+#: builtin/am.c:2172
+msgid "pass -k flag to git-mailinfo"
+msgstr "向 git-mailinfo 傳遞 -k 參數"
+
+#: builtin/am.c:2174
+msgid "pass -b flag to git-mailinfo"
+msgstr "向 git-mailinfo 傳遞 -b 參數"
+
+#: builtin/am.c:2176
+msgid "pass -m flag to git-mailinfo"
+msgstr "向 git-mailinfo 傳遞 -m 參數"
+
+#: builtin/am.c:2178
+msgid "pass --keep-cr flag to git-mailsplit for mbox format"
+msgstr "針對 mbox 格式，向 git-mailsplit 傳遞 --keep-cr 參數"
+
+#: builtin/am.c:2181
+msgid "do not pass --keep-cr flag to git-mailsplit independent of am.keepcr"
+msgstr "不向 git-mailsplit 傳遞 --keep-cr 參數，覆蓋 am.keepcr 的設定"
+
+#: builtin/am.c:2184
+msgid "strip everything before a scissors line"
+msgstr "捨棄裁切線前的所有內容"
+
+#: builtin/am.c:2186 builtin/am.c:2189 builtin/am.c:2192 builtin/am.c:2195
+#: builtin/am.c:2198 builtin/am.c:2201 builtin/am.c:2204 builtin/am.c:2207
+#: builtin/am.c:2213
+msgid "pass it through git-apply"
+msgstr "傳遞給 git-apply"
+
+#: builtin/am.c:2203 builtin/commit.c:1386 builtin/fmt-merge-msg.c:673
+#: builtin/fmt-merge-msg.c:676 builtin/grep.c:883 builtin/merge.c:249
+#: builtin/pull.c:160 builtin/pull.c:219 builtin/rebase.c:1469
+#: builtin/repack.c:315 builtin/repack.c:319 builtin/repack.c:321
+#: builtin/show-branch.c:650 builtin/show-ref.c:172 builtin/tag.c:403
+#: parse-options.h:154 parse-options.h:175 parse-options.h:316
+msgid "n"
+msgstr "n"
+
+#: builtin/am.c:2209 builtin/branch.c:661 builtin/for-each-ref.c:38
+#: builtin/replace.c:555 builtin/tag.c:437 builtin/verify-tag.c:38
+msgid "format"
+msgstr "格式"
+
+#: builtin/am.c:2210
+msgid "format the patch(es) are in"
+msgstr "修補檔的格式"
+
+#: builtin/am.c:2216
+msgid "override error message when patch failure occurs"
+msgstr "打修補檔失敗時顯示的錯誤訊息"
+
+#: builtin/am.c:2218
+msgid "continue applying patches after resolving a conflict"
+msgstr "衝突解決後繼續套用修補檔"
+
+#: builtin/am.c:2221
+msgid "synonyms for --continue"
+msgstr "和 --continue 同義"
+
+#: builtin/am.c:2224
+msgid "skip the current patch"
+msgstr "跳過目前修補檔"
+
+#: builtin/am.c:2227
+msgid "restore the original branch and abort the patching operation."
+msgstr "復原原始分支並終止打修補檔動作。"
+
+#: builtin/am.c:2230
+msgid "abort the patching operation but keep HEAD where it is."
+msgstr "終止修補檔動作但保持 HEAD 不變。"
+
+#: builtin/am.c:2233
+msgid "show the patch being applied."
+msgstr "顯示正在套用的修補檔。"
+
+#: builtin/am.c:2237
+msgid "lie about committer date"
+msgstr "將作者日期作為提交日期"
+
+#: builtin/am.c:2239
+msgid "use current timestamp for author date"
+msgstr "用目前時間作為作者日期"
+
+#: builtin/am.c:2241 builtin/commit-tree.c:120 builtin/commit.c:1507
+#: builtin/merge.c:286 builtin/pull.c:194 builtin/rebase.c:509
+#: builtin/rebase.c:1513 builtin/revert.c:117 builtin/tag.c:418
+msgid "key-id"
+msgstr "key-id"
+
+#: builtin/am.c:2242 builtin/rebase.c:510 builtin/rebase.c:1514
+msgid "GPG-sign commits"
+msgstr "使用 GPG 簽名提交"
+
+#: builtin/am.c:2245
+msgid "(internal use for git-rebase)"
+msgstr "（內部使用，用於 git-rebase）"
+
+#: builtin/am.c:2263
+msgid ""
+"The -b/--binary option has been a no-op for long time, and\n"
+"it will be removed. Please do not use it anymore."
+msgstr ""
+"參數 -b/--binary 已經很長時間不做任何實質動作了，並且將被移除。\n"
+"請不要再使用它了。"
+
+#: builtin/am.c:2270
+msgid "failed to read the index"
+msgstr "讀取索引失敗"
+
+#: builtin/am.c:2285
+#, c-format
+msgid "previous rebase directory %s still exists but mbox given."
+msgstr "之前的重定基底目錄 %s 仍然存在，但卻提供了 mbox。"
+
+#: builtin/am.c:2309
+#, c-format
+msgid ""
+"Stray %s directory found.\n"
+"Use \"git am --abort\" to remove it."
+msgstr ""
+"發現了錯誤的 %s 目錄。\n"
+"使用 \"git am --abort\" 刪除它。"
+
+#: builtin/am.c:2315
+msgid "Resolve operation not in progress, we are not resuming."
+msgstr "解決動作未進行，我們不會繼續。"
+
+#: builtin/am.c:2325
+msgid "interactive mode requires patches on the command line"
+msgstr "互動式模式需要指令列上提供修補檔"
+
+#: builtin/apply.c:8
+msgid "git apply [<options>] [<patch>...]"
+msgstr "git apply [<選項>] [<修補檔>...]"
+
+#: builtin/archive.c:17
+#, c-format
+msgid "could not create archive file '%s'"
+msgstr "不能建立歸檔檔案 '%s'"
+
+#: builtin/archive.c:20
+msgid "could not redirect output"
+msgstr "不能重定向輸出"
+
+#: builtin/archive.c:37
+msgid "git archive: Remote with no URL"
+msgstr "git archive：未提供遠端 URL"
+
+#: builtin/archive.c:61
+msgid "git archive: expected ACK/NAK, got a flush packet"
+msgstr "git archive：期望是 ACK/NAK，卻得到 flush 包"
+
+#: builtin/archive.c:64
+#, c-format
+msgid "git archive: NACK %s"
+msgstr "git archive：NACK %s"
+
+#: builtin/archive.c:65
+msgid "git archive: protocol error"
+msgstr "git archive：協定錯誤"
+
+#: builtin/archive.c:69
+msgid "git archive: expected a flush"
+msgstr "git archive：應有一個 flush 包"
+
+#: builtin/bisect--helper.c:22
+msgid "git bisect--helper --next-all [--no-checkout]"
+msgstr "git bisect--helper --next-all [--no-checkout]"
+
+#: builtin/bisect--helper.c:23
+msgid "git bisect--helper --write-terms <bad_term> <good_term>"
+msgstr "git bisect--helper --write-terms <壞-術語> <好-術語>"
+
+#: builtin/bisect--helper.c:24
+msgid "git bisect--helper --bisect-clean-state"
+msgstr "git bisect--helper --bisect-clean-state"
+
+#: builtin/bisect--helper.c:25
+msgid "git bisect--helper --bisect-reset [<commit>]"
+msgstr "git bisect--helper --bisect-reset [<提交>]"
+
+#: builtin/bisect--helper.c:26
+msgid ""
+"git bisect--helper --bisect-write [--no-log] <state> <revision> <good_term> "
+"<bad_term>"
+msgstr ""
+"git bisect--helper --bisect-write [--no-log] <狀態> <版本> <好-術語> <壞-術語"
+">"
+
+#: builtin/bisect--helper.c:27
+msgid ""
+"git bisect--helper --bisect-check-and-set-terms <command> <good_term> "
+"<bad_term>"
+msgstr "git bisect--helper --bisect-check-and-set-terms <指令> <好-術語> <壞-術語>"
+
+#: builtin/bisect--helper.c:28
+msgid "git bisect--helper --bisect-next-check <good_term> <bad_term> [<term>]"
+msgstr "git bisect--helper --bisect-next-check <好-術語> <壞-術語> [<術語>]"
+
+#: builtin/bisect--helper.c:29
+msgid ""
+"git bisect--helper --bisect-terms [--term-good | --term-old | --term-bad | --"
+"term-new]"
+msgstr ""
+"git bisect--helper --bisect-terms [--term-good | --term-old | --term-bad | --"
+"term-new]"
+
+#: builtin/bisect--helper.c:30
+msgid ""
+"git bisect--helper --bisect-start [--term-{old,good}=<term> --term-{new,bad}"
+"=<term>][--no-checkout] [<bad> [<good>...]] [--] [<paths>...]"
+msgstr ""
+"git bisect--helper --bisect-start [--term-{old,good}=<術語> --term-{new,bad}"
+"=<術語>][--no-checkout] [<壞> [<好>...]] [--] [<路徑>...]"
+
+#: builtin/bisect--helper.c:86
+#, c-format
+msgid "'%s' is not a valid term"
+msgstr "'%s' 不是一個有效的術語"
+
+#: builtin/bisect--helper.c:90
+#, c-format
+msgid "can't use the builtin command '%s' as a term"
+msgstr "不能使用內建指令 '%s' 作為術語"
+
+#: builtin/bisect--helper.c:100
+#, c-format
+msgid "can't change the meaning of the term '%s'"
+msgstr "不能修改術語 '%s' 的含義"
+
+#: builtin/bisect--helper.c:111
+msgid "please use two different terms"
+msgstr "請使用兩個不同的術語"
+
+#: builtin/bisect--helper.c:118
+msgid "could not open the file BISECT_TERMS"
+msgstr "不能開啟檔案 BISECT_TERMS"
+
+#: builtin/bisect--helper.c:155
+#, c-format
+msgid "We are not bisecting.\n"
+msgstr "我們沒有在二分尋找。\n"
+
+#: builtin/bisect--helper.c:163
+#, c-format
+msgid "'%s' is not a valid commit"
+msgstr "'%s' 不是一個有效的提交"
+
+#: builtin/bisect--helper.c:172
+#, c-format
+msgid ""
+"could not check out original HEAD '%s'. Try 'git bisect reset <commit>'."
+msgstr "不能簽出原始 HEAD '%s'。嘗試 'git bisect reset <提交>'。"
+
+#: builtin/bisect--helper.c:216
+#, c-format
+msgid "Bad bisect_write argument: %s"
+msgstr "壞的 bisect_write 參數：%s"
+
+#: builtin/bisect--helper.c:221
+#, c-format
+msgid "couldn't get the oid of the rev '%s'"
+msgstr "無法取得版本 '%s' 的物件 ID"
+
+#: builtin/bisect--helper.c:233
+#, c-format
+msgid "couldn't open the file '%s'"
+msgstr "無法開啟檔案 '%s'"
+
+#: builtin/bisect--helper.c:259
+#, c-format
+msgid "Invalid command: you're currently in a %s/%s bisect"
+msgstr "無效的指令：您目前正處於一個 %s/%s 二分尋找中"
+
+#: builtin/bisect--helper.c:286
+#, c-format
+msgid ""
+"You need to give me at least one %s and %s revision.\n"
+"You can use \"git bisect %s\" and \"git bisect %s\" for that."
+msgstr ""
+"您需要給我至少一個 %s 和一個 %s 版本。\n"
+"為此您可以用 \"git bisect %s\" 和 \"git bisect %s\"。"
+
+#: builtin/bisect--helper.c:290
+#, c-format
+msgid ""
+"You need to start by \"git bisect start\".\n"
+"You then need to give me at least one %s and %s revision.\n"
+"You can use \"git bisect %s\" and \"git bisect %s\" for that."
+msgstr ""
+"您需要執行 \"git bisect start\" 來開始。\n"
+"然後需要提供我至少一個 %s 和一個 %s 版本。\n"
+"為此您可以用 \"git bisect %s\" 和 \"git bisect %s\" 指令。"
+
+#: builtin/bisect--helper.c:322
+#, c-format
+msgid "bisecting only with a %s commit"
+msgstr "在只有一個 %s 提交的情況下二分尋找"
+
+#  譯者：請維持句尾空格
+#. TRANSLATORS: Make sure to include [Y] and [n] in your
+#. translation. The program will only accept English input
+#. at this point.
+#.
+#: builtin/bisect--helper.c:330
+msgid "Are you sure [Y/n]? "
+msgstr "您確認嗎[Y/n]？ "
+
+#: builtin/bisect--helper.c:377
+msgid "no terms defined"
+msgstr "未定義術語"
+
+#: builtin/bisect--helper.c:380
+#, c-format
+msgid ""
+"Your current terms are %s for the old state\n"
+"and %s for the new state.\n"
+msgstr "您目前針對舊狀態的術語是 %s，對新狀態的術語是 %s。\n"
+
+#: builtin/bisect--helper.c:390
+#, c-format
+msgid ""
+"invalid argument %s for 'git bisect terms'.\n"
+"Supported options are: --term-good|--term-old and --term-bad|--term-new."
+msgstr ""
+"指令 'git bisect terms' 的參數 %s 無效。\n"
+"支援的選項有：--term-good|--term-old 和 --term-bad|--term-new。"
+
+#: builtin/bisect--helper.c:476
+#, c-format
+msgid "unrecognized option: '%s'"
+msgstr "未識別的選項：'%s'"
+
+#: builtin/bisect--helper.c:480
+#, c-format
+msgid "'%s' does not appear to be a valid revision"
+msgstr "'%s' 看起來不是一個有效的版本"
+
+#: builtin/bisect--helper.c:512
+msgid "bad HEAD - I need a HEAD"
+msgstr "壞的 HEAD - 我需要一個 HEAD"
+
+#: builtin/bisect--helper.c:527
+#, c-format
+msgid "checking out '%s' failed. Try 'git bisect start <valid-branch>'."
+msgstr "簽出 '%s' 失敗。嘗試 'git bisect start <有效分支>'。"
+
+#: builtin/bisect--helper.c:548
+msgid "won't bisect on cg-seek'ed tree"
+msgstr "不會在做了 cg-seek 的樹上做二分尋找"
+
+#: builtin/bisect--helper.c:551
+msgid "bad HEAD - strange symbolic ref"
+msgstr "壞的 HEAD - 奇怪的符號引用"
+
+#: builtin/bisect--helper.c:575
+#, c-format
+msgid "invalid ref: '%s'"
+msgstr "無效的引用：'%s'"
+
+#: builtin/bisect--helper.c:631
+msgid "perform 'git bisect next'"
+msgstr "執行 'git bisect next'"
+
+#: builtin/bisect--helper.c:633
+msgid "write the terms to .git/BISECT_TERMS"
+msgstr "將術語寫入 .git/BISECT_TERMS"
+
+#: builtin/bisect--helper.c:635
+msgid "cleanup the bisection state"
+msgstr "清除二分尋找狀態"
+
+#: builtin/bisect--helper.c:637
+msgid "check for expected revs"
+msgstr "檢查預期的版本"
+
+#: builtin/bisect--helper.c:639
+msgid "reset the bisection state"
+msgstr "清除二分尋找狀態"
+
+#: builtin/bisect--helper.c:641
+msgid "write out the bisection state in BISECT_LOG"
+msgstr "將二分尋找的狀態寫入 BISECT_LOG"
+
+#: builtin/bisect--helper.c:643
+msgid "check and set terms in a bisection state"
+msgstr "在一個二分尋找狀態中檢查和設定術語"
+
+#: builtin/bisect--helper.c:645
+msgid "check whether bad or good terms exist"
+msgstr "檢查壞的或好的術語是否存在"
+
+#: builtin/bisect--helper.c:647
+msgid "print out the bisect terms"
+msgstr "列印二分尋找術語"
+
+#: builtin/bisect--helper.c:649
+msgid "start the bisect session"
+msgstr "啟動二分尋找過程"
+
+#: builtin/bisect--helper.c:651
+msgid "update BISECT_HEAD instead of checking out the current commit"
+msgstr "更新 BISECT_HEAD 而非簽出目前提交"
+
+#: builtin/bisect--helper.c:653
+msgid "no log for BISECT_WRITE"
+msgstr "BISECT_WRITE 無日誌"
+
+#: builtin/bisect--helper.c:670
+msgid "--write-terms requires two arguments"
+msgstr "--write-terms 需要兩個參數"
+
+#: builtin/bisect--helper.c:674
+msgid "--bisect-clean-state requires no arguments"
+msgstr "--bisect-clean-state 不帶參數"
+
+#: builtin/bisect--helper.c:681
+msgid "--bisect-reset requires either no argument or a commit"
+msgstr "--bisect-reset 無需參數或者需要一個提交"
+
+#: builtin/bisect--helper.c:685
+msgid "--bisect-write requires either 4 or 5 arguments"
+msgstr "--bisect-write 需要 4 或 5 個參數"
+
+#: builtin/bisect--helper.c:691
+msgid "--check-and-set-terms requires 3 arguments"
+msgstr "--check-and-set-terms 需要 3 個參數"
+
+#: builtin/bisect--helper.c:697
+msgid "--bisect-next-check requires 2 or 3 arguments"
+msgstr "--bisect-next-check 需要 2 或 3 個參數"
+
+#: builtin/bisect--helper.c:703
+msgid "--bisect-terms requires 0 or 1 argument"
+msgstr "--bisect-terms 需要 0 或 1 個參數"
+
+#: builtin/blame.c:31
+msgid "git blame [<options>] [<rev-opts>] [<rev>] [--] <file>"
+msgstr "git blame [<選項>] [<版本選項>] [<版本>] [--] <檔案>"
+
+#: builtin/blame.c:36
+msgid "<rev-opts> are documented in git-rev-list(1)"
+msgstr "<版本選項> 的檔案記錄在 git-rev-list(1) 中"
+
+#: builtin/blame.c:409
+#, c-format
+msgid "expecting a color: %s"
+msgstr "期望一個顏色：%s"
+
+#: builtin/blame.c:416
+msgid "must end with a color"
+msgstr "必須以一個顏色結尾"
+
+#: builtin/blame.c:729
+#, c-format
+msgid "invalid color '%s' in color.blame.repeatedLines"
+msgstr "設定 color.blame.repeatedLines 中的無效顏色 '%s'"
+
+#: builtin/blame.c:747
+msgid "invalid value for blame.coloring"
+msgstr "設定 blame.coloring 中的無效取值"
+
+#: builtin/blame.c:822
+#, c-format
+msgid "cannot find revision %s to ignore"
+msgstr "不能找到要忽略的版本 %s"
+
+#: builtin/blame.c:844
+msgid "Show blame entries as we find them, incrementally"
+msgstr "增量式地顯示發現的 blame 條目"
+
+#: builtin/blame.c:845
+msgid "Show blank SHA-1 for boundary commits (Default: off)"
+msgstr "邊界提交顯示空的 SHA-1（預設：關閉）"
+
+#: builtin/blame.c:846
+msgid "Do not treat root commits as boundaries (Default: off)"
+msgstr "不把根提交作為邊界（預設：關閉）"
+
+#: builtin/blame.c:847
+msgid "Show work cost statistics"
+msgstr "顯示指令消耗統計"
+
+#: builtin/blame.c:848
+msgid "Force progress reporting"
+msgstr "強制進度顯示"
+
+#: builtin/blame.c:849
+msgid "Show output score for blame entries"
+msgstr "顯示判斷 blame 條目位移的得分診斷訊息"
+
+#: builtin/blame.c:850
+msgid "Show original filename (Default: auto)"
+msgstr "顯示原始檔案名（預設：自動）"
+
+#: builtin/blame.c:851
+msgid "Show original linenumber (Default: off)"
+msgstr "顯示原始的行號（預設：關閉）"
+
+#: builtin/blame.c:852
+msgid "Show in a format designed for machine consumption"
+msgstr "顯示為一個適合機器讀取的格式"
+
+#: builtin/blame.c:853
+msgid "Show porcelain format with per-line commit information"
+msgstr "為每一行顯示機器適用的提交訊息"
+
+#: builtin/blame.c:854
+msgid "Use the same output mode as git-annotate (Default: off)"
+msgstr "使用和 git-annotate 相同的輸出模式（預設：關閉）"
+
+#: builtin/blame.c:855
+msgid "Show raw timestamp (Default: off)"
+msgstr "顯示原始時間戳（預設：關閉）"
+
+#: builtin/blame.c:856
+msgid "Show long commit SHA1 (Default: off)"
+msgstr "顯示長的 SHA1 提交號（預設：關閉）"
+
+#: builtin/blame.c:857
+msgid "Suppress author name and timestamp (Default: off)"
+msgstr "隱藏作者名字和時間戳（預設：關閉）"
+
+#: builtin/blame.c:858
+msgid "Show author email instead of name (Default: off)"
+msgstr "顯示作者的信箱而不是名字（預設：關閉）"
+
+#: builtin/blame.c:859
+msgid "Ignore whitespace differences"
+msgstr "忽略空白差異"
+
+#: builtin/blame.c:860 builtin/log.c:1702
+msgid "rev"
+msgstr "版本"
+
+#: builtin/blame.c:860
+msgid "Ignore <rev> when blaming"
+msgstr "在執行 blame 動作時忽略 <版本>"
+
+#: builtin/blame.c:861
+msgid "Ignore revisions from <file>"
+msgstr "忽略來自 <檔案> 中的版本"
+
+#: builtin/blame.c:862
+msgid "color redundant metadata from previous line differently"
+msgstr "使用顏色間隔輸出與前一行不同的重複元訊息"
+
+#: builtin/blame.c:863
+msgid "color lines by age"
+msgstr "依據時間著色"
+
+#: builtin/blame.c:864
+msgid "Spend extra cycles to find better match"
+msgstr "花費額外的循環來找到更好的符合"
+
+#: builtin/blame.c:865
+msgid "Use revisions from <file> instead of calling git-rev-list"
+msgstr "使用來自 <檔案> 的修訂集而不是呼叫 git-rev-list"
+
+#: builtin/blame.c:866
+msgid "Use <file>'s contents as the final image"
+msgstr "使用 <檔案> 的內容作為最終的圖片"
+
+#: builtin/blame.c:867 builtin/blame.c:868
+msgid "score"
+msgstr "得分"
+
+#: builtin/blame.c:867
+msgid "Find line copies within and across files"
+msgstr "找到檔案內及跨檔案的行複製"
+
+#: builtin/blame.c:868
+msgid "Find line movements within and across files"
+msgstr "找到檔案內及跨檔案的行移動"
+
+#: builtin/blame.c:869
+msgid "n,m"
+msgstr "n,m"
+
+#: builtin/blame.c:869
+msgid "Process only line range n,m, counting from 1"
+msgstr "只處理行範圍在 n 和 m 之間的，從 1 開始"
+
+#: builtin/blame.c:921
+msgid "--progress can't be used with --incremental or porcelain formats"
+msgstr "--progress 不能和 --incremental 或 --porcelain 同時使用"
+
+#. TRANSLATORS: This string is used to tell us the
+#. maximum display width for a relative timestamp in
+#. "git blame" output.  For C locale, "4 years, 11
+#. months ago", which takes 22 places, is the longest
+#. among various forms of relative timestamps, but
+#. your language may need more or fewer display
+#. columns.
+#.
+#: builtin/blame.c:972
+msgid "4 years, 11 months ago"
+msgstr "4 年 11 個月前"
+
+#: builtin/blame.c:1079
+#, c-format
+msgid "file %s has only %lu line"
+msgid_plural "file %s has only %lu lines"
+msgstr[0] "檔案 %s 只有 %lu 行"
+msgstr[1] "檔案 %s 只有 %lu 行"
+
+#: builtin/blame.c:1125
+msgid "Blaming lines"
+msgstr "追蹤程式碼行"
+
+#: builtin/branch.c:29
+msgid "git branch [<options>] [-r | -a] [--merged | --no-merged]"
+msgstr "git branch [<選項>] [-r | -a] [--merged | --no-merged]"
+
+#: builtin/branch.c:30
+msgid "git branch [<options>] [-l] [-f] <branch-name> [<start-point>]"
+msgstr "git branch [<選項>] [-l] [-f] <分支名> [<起始點>]"
+
+#: builtin/branch.c:31
+msgid "git branch [<options>] [-r] (-d | -D) <branch-name>..."
+msgstr "git branch [<選項>] [-r] (-d | -D) <分支名>..."
+
+#: builtin/branch.c:32
+msgid "git branch [<options>] (-m | -M) [<old-branch>] <new-branch>"
+msgstr "git branch [<選項>] (-m | -M) [<舊分支>] <新分支>"
+
+#: builtin/branch.c:33
+msgid "git branch [<options>] (-c | -C) [<old-branch>] <new-branch>"
+msgstr "git branch [<選項>] (-c | -C) [<老分支>] <新分支>"
+
+#: builtin/branch.c:34
+msgid "git branch [<options>] [-r | -a] [--points-at]"
+msgstr "git branch [<選項>] [-r | -a] [--points-at]"
+
+#: builtin/branch.c:35
+msgid "git branch [<options>] [-r | -a] [--format]"
+msgstr "git branch [<選項>] [-r | -a] [--format]"
+
+#  譯者：保持原換行格式，在輸出時 %s 的替代內容會讓字串變長
+#: builtin/branch.c:154
+#, c-format
+msgid ""
+"deleting branch '%s' that has been merged to\n"
+"         '%s', but not yet merged to HEAD."
+msgstr ""
+"將要刪除的分支 '%s' 已經被合併到\n"
+"         '%s'，但未合併到 HEAD。"
+
+#  譯者：保持原換行格式，在輸出時 %s 的替代內容會讓字串變長
+#: builtin/branch.c:158
+#, c-format
+msgid ""
+"not deleting branch '%s' that is not yet merged to\n"
+"         '%s', even though it is merged to HEAD."
+msgstr ""
+"並未刪除分支 '%s'， 雖然它已經合併到 HEAD，\n"
+"         然而卻尚未被合併到分支 '%s' 。"
+
+#: builtin/branch.c:172
+#, c-format
+msgid "Couldn't look up commit object for '%s'"
+msgstr "無法查詢 '%s' 指向的提交物件"
+
+#: builtin/branch.c:176
+#, c-format
+msgid ""
+"The branch '%s' is not fully merged.\n"
+"If you are sure you want to delete it, run 'git branch -D %s'."
+msgstr ""
+"分支 '%s' 沒有完全合併。\n"
+"如果您確認要刪除它，執行 'git branch -D %s'。"
+
+#: builtin/branch.c:189
+msgid "Update of config-file failed"
+msgstr "更新設定檔案失敗"
+
+#: builtin/branch.c:220
+msgid "cannot use -a with -d"
+msgstr "不能將 -a 和 -d 同時使用"
+
+#: builtin/branch.c:226
+msgid "Couldn't look up commit object for HEAD"
+msgstr "無法查詢 HEAD 指向的提交物件"
+
+#: builtin/branch.c:240
+#, c-format
+msgid "Cannot delete branch '%s' checked out at '%s'"
+msgstr "無法刪除簽出於 '%2$s' 的分支 '%1$s'。"
+
+#: builtin/branch.c:255
+#, c-format
+msgid "remote-tracking branch '%s' not found."
+msgstr "未能找到遠端追蹤分支 '%s'。"
+
+#: builtin/branch.c:256
+#, c-format
+msgid "branch '%s' not found."
+msgstr "分支 '%s' 未發現。"
+
+#: builtin/branch.c:271
+#, c-format
+msgid "Error deleting remote-tracking branch '%s'"
+msgstr "無法刪除遠端追蹤分支 '%s'"
+
+#: builtin/branch.c:272
+#, c-format
+msgid "Error deleting branch '%s'"
+msgstr "無法刪除分支 '%s'"
+
+#: builtin/branch.c:279
+#, c-format
+msgid "Deleted remote-tracking branch %s (was %s).\n"
+msgstr "已刪除遠端追蹤分支 %s（曾為 %s）。\n"
+
+#: builtin/branch.c:280
+#, c-format
+msgid "Deleted branch %s (was %s).\n"
+msgstr "已刪除分支 %s（曾為 %s）。\n"
+
+#: builtin/branch.c:429 builtin/tag.c:61
+msgid "unable to parse format string"
+msgstr "不能解析格式化字串"
+
+#: builtin/branch.c:460
+msgid "could not resolve HEAD"
+msgstr "不能解析 HEAD 提交"
+
+#: builtin/branch.c:466
+#, c-format
+msgid "HEAD (%s) points outside of refs/heads/"
+msgstr "HEAD (%s) 指向 refs/heads/ 之外"
+
+#: builtin/branch.c:481
+#, c-format
+msgid "Branch %s is being rebased at %s"
+msgstr "分支 %s 正被重定基底到 %s"
+
+#: builtin/branch.c:485
+#, c-format
+msgid "Branch %s is being bisected at %s"
+msgstr "分支 %s 正被二分尋找於 %s"
+
+#: builtin/branch.c:502
+msgid "cannot copy the current branch while not on any."
+msgstr "無法複製目前分支因為不處於任何分支上。"
+
+#: builtin/branch.c:504
+msgid "cannot rename the current branch while not on any."
+msgstr "無法重新命名目前分支因為不處於任何分支上。"
+
+#: builtin/branch.c:515
+#, c-format
+msgid "Invalid branch name: '%s'"
+msgstr "無效的分支名：'%s'"
+
+#: builtin/branch.c:542
+msgid "Branch rename failed"
+msgstr "分支重新命名失敗"
+
+#: builtin/branch.c:544
+msgid "Branch copy failed"
+msgstr "分支複製失敗"
+
+#: builtin/branch.c:548
+#, c-format
+msgid "Created a copy of a misnamed branch '%s'"
+msgstr "已為錯誤命名的分支 '%s' 建立了一個副本"
+
+#: builtin/branch.c:551
+#, c-format
+msgid "Renamed a misnamed branch '%s' away"
+msgstr "已將錯誤命名的分支 '%s' 重新命名"
+
+#: builtin/branch.c:557
+#, c-format
+msgid "Branch renamed to %s, but HEAD is not updated!"
+msgstr "分支重新命名為 %s，但 HEAD 沒有更新！"
+
+#: builtin/branch.c:566
+msgid "Branch is renamed, but update of config-file failed"
+msgstr "分支被重新命名，但更新設定檔案失敗"
+
+#: builtin/branch.c:568
+msgid "Branch is copied, but update of config-file failed"
+msgstr "分支已複製，但更新設定檔案失敗"
+
+#: builtin/branch.c:584
+#, c-format
+msgid ""
+"Please edit the description for the branch\n"
+"  %s\n"
+"Lines starting with '%c' will be stripped.\n"
+msgstr ""
+"請編輯分支的描述\n"
+"  %s\n"
+"以 '%c' 開頭的行將被過濾。\n"
+
+#: builtin/branch.c:618
+msgid "Generic options"
+msgstr "通用選項"
+
+#: builtin/branch.c:620
+msgid "show hash and subject, give twice for upstream branch"
+msgstr "顯示雜湊值和主題，若參數出現兩次則顯示上游分支"
+
+#: builtin/branch.c:621
+msgid "suppress informational messages"
+msgstr "不顯示訊息"
+
+#: builtin/branch.c:622
+msgid "set up tracking mode (see git-pull(1))"
+msgstr "設定追蹤模式（參見 git-pull(1)）"
+
+#: builtin/branch.c:624
+msgid "do not use"
+msgstr "不要使用"
+
+#: builtin/branch.c:626 builtin/rebase.c:505
+msgid "upstream"
+msgstr "上游"
+
+#: builtin/branch.c:626
+msgid "change the upstream info"
+msgstr "改變上游訊息"
+
+#: builtin/branch.c:627
+#| msgid "Unset the upstream info"
+msgid "unset the upstream info"
+msgstr "取消上游資訊設定"
+
+#: builtin/branch.c:628
+msgid "use colored output"
+msgstr "使用彩色輸出"
+
+#: builtin/branch.c:629
+msgid "act on remote-tracking branches"
+msgstr "作用於遠端追蹤分支"
+
+#: builtin/branch.c:631 builtin/branch.c:633
+msgid "print only branches that contain the commit"
+msgstr "只列印包含該提交的分支"
+
+#: builtin/branch.c:632 builtin/branch.c:634
+msgid "print only branches that don't contain the commit"
+msgstr "只列印不包含該提交的分支"
+
+#: builtin/branch.c:637
+msgid "Specific git-branch actions:"
+msgstr "具體的 git-branch 動作："
+
+#: builtin/branch.c:638
+msgid "list both remote-tracking and local branches"
+msgstr "列出遠端追蹤及本機分支"
+
+#: builtin/branch.c:640
+msgid "delete fully merged branch"
+msgstr "刪除完全合併的分支"
+
+#: builtin/branch.c:641
+msgid "delete branch (even if not merged)"
+msgstr "刪除分支（即使沒有合併）"
+
+#: builtin/branch.c:642
+msgid "move/rename a branch and its reflog"
+msgstr "移動/重新命名一個分支，以及它的引用日誌"
+
+#: builtin/branch.c:643
+msgid "move/rename a branch, even if target exists"
+msgstr "移動/重新命名一個分支，即使目標已存在"
+
+#: builtin/branch.c:644
+msgid "copy a branch and its reflog"
+msgstr "複製一個分支和它的引用日誌"
+
+#: builtin/branch.c:645
+msgid "copy a branch, even if target exists"
+msgstr "複製一個分支，即使目標已存在"
+
+#: builtin/branch.c:646
+msgid "list branch names"
+msgstr "列出分支名"
+
+#: builtin/branch.c:647
+msgid "show current branch name"
+msgstr "顯示目前分支名"
+
+#: builtin/branch.c:648
+msgid "create the branch's reflog"
+msgstr "建立分支的引用日誌"
+
+#: builtin/branch.c:650
+msgid "edit the description for the branch"
+msgstr "標記分支的描述"
+
+#: builtin/branch.c:651
+msgid "force creation, move/rename, deletion"
+msgstr "強制建立、移動/重新命名、刪除"
+
+#: builtin/branch.c:652
+msgid "print only branches that are merged"
+msgstr "只列印已經合併的分支"
+
+#: builtin/branch.c:653
+msgid "print only branches that are not merged"
+msgstr "只列印尚未合併的分支"
+
+#: builtin/branch.c:654
+msgid "list branches in columns"
+msgstr "以列的方式顯示分支"
+
+#: builtin/branch.c:657 builtin/for-each-ref.c:42 builtin/notes.c:415
+#: builtin/notes.c:418 builtin/notes.c:581 builtin/notes.c:584
+#: builtin/tag.c:433
+msgid "object"
+msgstr "物件"
+
+#: builtin/branch.c:658
+msgid "print only branches of the object"
+msgstr "只列印指向該物件的分支"
+
+#: builtin/branch.c:660 builtin/for-each-ref.c:48 builtin/tag.c:440
+msgid "sorting and filtering are case insensitive"
+msgstr "排序和過濾屬於大小寫不敏感"
+
+#: builtin/branch.c:661 builtin/for-each-ref.c:38 builtin/tag.c:438
+#: builtin/verify-tag.c:38
+msgid "format to use for the output"
+msgstr "輸出格式"
+
+#: builtin/branch.c:684 builtin/clone.c:784
+msgid "HEAD not found below refs/heads!"
+msgstr "HEAD 沒有位於 /refs/heads 之下！"
+
+#: builtin/branch.c:708
+msgid "--column and --verbose are incompatible"
+msgstr "--column 和 --verbose 不相容"
+
+#: builtin/branch.c:723 builtin/branch.c:777 builtin/branch.c:786
+msgid "branch name required"
+msgstr "必須提供分支名"
+
+#: builtin/branch.c:753
+msgid "Cannot give description to detached HEAD"
+msgstr "不能向分離開頭指標提供描述"
+
+#: builtin/branch.c:758
+msgid "cannot edit description of more than one branch"
+msgstr "不能為一個以上的分支編輯描述"
+
+#: builtin/branch.c:765
+#, c-format
+msgid "No commit on branch '%s' yet."
+msgstr "分支 '%s' 尚無提交。"
+
+#: builtin/branch.c:768
+#, c-format
+msgid "No branch named '%s'."
+msgstr "沒有分支 '%s'。"
+
+#: builtin/branch.c:783
+msgid "too many branches for a copy operation"
+msgstr "為複製動作提供了太多的分支名"
+
+#: builtin/branch.c:792
+msgid "too many arguments for a rename operation"
+msgstr "為重新命名動作提供了太多的參數"
+
+#: builtin/branch.c:797
+msgid "too many arguments to set new upstream"
+msgstr "為設定新上游提供了太多的參數"
+
+#: builtin/branch.c:801
+#, c-format
+msgid ""
+"could not set upstream of HEAD to %s when it does not point to any branch."
+msgstr "無法設定 HEAD 的上游為 %s，因為 HEAD 沒有指向任何分支。"
+
+#: builtin/branch.c:804 builtin/branch.c:827
+#, c-format
+msgid "no such branch '%s'"
+msgstr "沒有此分支 '%s'"
+
+#: builtin/branch.c:808
+#, c-format
+msgid "branch '%s' does not exist"
+msgstr "分支 '%s' 不存在"
+
+#: builtin/branch.c:821
+msgid "too many arguments to unset upstream"
+msgstr "為取消上游設定動作提供了太多的參數"
+
+#: builtin/branch.c:825
+msgid "could not unset upstream of HEAD when it does not point to any branch."
+msgstr "無法取消 HEAD 的上游設定因為它沒有指向一個分支"
+
+#: builtin/branch.c:831
+#, c-format
+msgid "Branch '%s' has no upstream information"
+msgstr "分支 '%s' 沒有上游訊息"
+
+#: builtin/branch.c:841
+msgid ""
+"The -a, and -r, options to 'git branch' do not take a branch name.\n"
+"Did you mean to use: -a|-r --list <pattern>?"
+msgstr ""
+"'git branch' 的 -a 和 -r 選項不帶一個分支名。\n"
+"您是否想要使用：-a|-r --list <模式>？"
+
+#: builtin/branch.c:845
+msgid ""
+"the '--set-upstream' option is no longer supported. Please use '--track' or "
+"'--set-upstream-to' instead."
+msgstr "不再支援選項 '--set-upstream'。請使用 '--track' 或 '--set-upstream-to'。"
+
+#: builtin/bundle.c:15 builtin/bundle.c:23
+#| msgid "git remote add [<options>] <name> <url>"
+msgid "git bundle create [<options>] <file> <git-rev-list args>"
+msgstr "git bundle create [<選項>] <檔案> <git-rev-list 參數>"
+
+#: builtin/bundle.c:16 builtin/bundle.c:28
+#| msgid "git rm [<options>] [--] <file>..."
+msgid "git bundle verify [<options>] <file>"
+msgstr "git bundle verify [<選項>] <檔案>"
+
+#: builtin/bundle.c:17 builtin/bundle.c:33
+msgid "git bundle list-heads <file> [<refname>...]"
+msgstr "git bundle list-heads <檔案> [<參考名稱>...]"
+
+#: builtin/bundle.c:18 builtin/bundle.c:38
+msgid "git bundle unbundle <file> [<refname>...]"
+msgstr "git bundle unbundle <檔案> [<參考名稱>...]"
+
+#: builtin/bundle.c:66 builtin/pack-objects.c:3228
+msgid "do not show progress meter"
+msgstr "不顯示進度表"
+
+#: builtin/bundle.c:68 builtin/pack-objects.c:3230
+msgid "show progress meter"
+msgstr "顯示進度表"
+
+#: builtin/bundle.c:70 builtin/pack-objects.c:3232
+msgid "show progress meter during object writing phase"
+msgstr "在物件寫入階段顯示進度表"
+
+#: builtin/bundle.c:73 builtin/pack-objects.c:3235
+msgid "similar to --all-progress when progress meter is shown"
+msgstr "當進度表顯示時類似於 --all-progress"
+
+#: builtin/bundle.c:93
+msgid "Need a repository to create a bundle."
+msgstr "需要一個版本庫來建立包。"
+
+#: builtin/bundle.c:104
+#| msgid "do not show peeled tags"
+msgid "do not show bundle details"
+msgstr "不顯示包 (bundle) 詳細資訊"
+
+#: builtin/bundle.c:119
+#, c-format
+msgid "%s is okay\n"
+msgstr "%s 可以\n"
+
+#: builtin/bundle.c:160
+msgid "Need a repository to unbundle."
+msgstr "需要一個版本庫來解包。"
+
+#: builtin/bundle.c:168 builtin/remote.c:1609
+msgid "be verbose; must be placed before a subcommand"
+msgstr "詳細輸出；必須置於子指令之前"
+
+#: builtin/bundle.c:190 builtin/remote.c:1640
+#, c-format
+msgid "Unknown subcommand: %s"
+msgstr "未知子指令：%s"
+
+#: builtin/cat-file.c:595
+msgid ""
+"git cat-file (-t [--allow-unknown-type] | -s [--allow-unknown-type] | -e | -"
+"p | <type> | --textconv | --filters) [--path=<path>] <object>"
+msgstr ""
+"git cat-file (-t [--allow-unknown-type] | -s [--allow-unknown-type] | -e | -"
+"p | <類型> | --textconv | --filters) [--path=<路徑>] <物件>"
+
+#: builtin/cat-file.c:596
+msgid ""
+"git cat-file (--batch | --batch-check) [--follow-symlinks] [--textconv | --"
+"filters]"
+msgstr ""
+"git cat-file (--batch | --batch-check) [--follow-symlinks] [--textconv | --"
+"filters]"
+
+#: builtin/cat-file.c:617
+msgid "only one batch option may be specified"
+msgstr "只能指定一個批次處理選項"
+
+#: builtin/cat-file.c:635
+msgid "<type> can be one of: blob, tree, commit, tag"
+msgstr "<類型> 可以是其中之一：blob、tree、commit、tag"
+
+#: builtin/cat-file.c:636
+msgid "show object type"
+msgstr "顯示物件類型"
+
+#: builtin/cat-file.c:637
+msgid "show object size"
+msgstr "顯示物件大小"
+
+#: builtin/cat-file.c:639
+msgid "exit with zero when there's no error"
+msgstr "當沒有錯誤時離開並返回零"
+
+#: builtin/cat-file.c:640
+msgid "pretty-print object's content"
+msgstr "美觀地列印物件的內容"
+
+#: builtin/cat-file.c:642
+msgid "for blob objects, run textconv on object's content"
+msgstr "對於資料物件，對其內容做文字轉換"
+
+#: builtin/cat-file.c:644
+msgid "for blob objects, run filters on object's content"
+msgstr "對於資料物件，對其內容做過濾"
+
+#: builtin/cat-file.c:645 git-submodule.sh:992
+msgid "blob"
+msgstr "資料物件"
+
+#: builtin/cat-file.c:646
+msgid "use a specific path for --textconv/--filters"
+msgstr "對於 --textconv/--filters 使用一個特定的路徑"
+
+#: builtin/cat-file.c:648
+msgid "allow -s and -t to work with broken/corrupt objects"
+msgstr "允許 -s 和 -t 對損壞的物件生效"
+
+#: builtin/cat-file.c:649
+msgid "buffer --batch output"
+msgstr "緩衝 --batch 的輸出"
+
+#: builtin/cat-file.c:651
+msgid "show info and content of objects fed from the standard input"
+msgstr "顯示從標準輸入提供的物件的訊息和內容"
+
+#: builtin/cat-file.c:655
+msgid "show info about objects fed from the standard input"
+msgstr "顯示從標準輸入提供的物件的訊息"
+
+#: builtin/cat-file.c:659
+msgid "follow in-tree symlinks (used with --batch or --batch-check)"
+msgstr "跟隨樹內符號連結（和 --batch 或 --batch-check 共用）"
+
+#: builtin/cat-file.c:661
+msgid "show all objects with --batch or --batch-check"
+msgstr "使用 --batch 或 --batch-check 參數顯示所有物件"
+
+#: builtin/cat-file.c:663
+msgid "do not order --batch-all-objects output"
+msgstr "不要對 --batch-all-objects 的輸出排序"
+
+#: builtin/check-attr.c:13
+msgid "git check-attr [-a | --all | <attr>...] [--] <pathname>..."
+msgstr "git check-attr [-a | --all | <屬性>...] [--] <路徑名>..."
+
+#: builtin/check-attr.c:14
+msgid "git check-attr --stdin [-z] [-a | --all | <attr>...]"
+msgstr "git check-attr --stdin [-z] [-a | --all | <屬性>...]"
+
+#: builtin/check-attr.c:21
+msgid "report all attributes set on file"
+msgstr "報告設定在檔案上的所有屬性"
+
+#: builtin/check-attr.c:22
+msgid "use .gitattributes only from the index"
+msgstr "只使用索引中的 .gitattributes"
+
+#: builtin/check-attr.c:23 builtin/check-ignore.c:25 builtin/hash-object.c:102
+msgid "read file names from stdin"
+msgstr "從標準輸入讀出檔案名"
+
+#: builtin/check-attr.c:25 builtin/check-ignore.c:27
+msgid "terminate input and output records by a NUL character"
+msgstr "輸入和輸出的紀錄使用 NUL 字元終結"
+
+#: builtin/check-ignore.c:21 builtin/checkout.c:1435 builtin/gc.c:537
+#: builtin/worktree.c:506
+msgid "suppress progress reporting"
+msgstr "不顯示進度報告"
+
+#: builtin/check-ignore.c:29
+msgid "show non-matching input paths"
+msgstr "顯示未符合的輸入路徑"
+
+#: builtin/check-ignore.c:31
+msgid "ignore index when checking"
+msgstr "檢查時忽略索引"
+
+#: builtin/check-ignore.c:160
+msgid "cannot specify pathnames with --stdin"
+msgstr "不能同時指定路徑及 --stdin 參數"
+
+#: builtin/check-ignore.c:163
+msgid "-z only makes sense with --stdin"
+msgstr "-z 需要和 --stdin 參數共用才有意義"
+
+#: builtin/check-ignore.c:165
+msgid "no path specified"
+msgstr "未指定路徑"
+
+#: builtin/check-ignore.c:169
+msgid "--quiet is only valid with a single pathname"
+msgstr "參數 --quiet 只在提供一個路徑名時有效"
+
+#: builtin/check-ignore.c:171
+msgid "cannot have both --quiet and --verbose"
+msgstr "不能同時提供 --quiet 和 --verbose 參數"
+
+#: builtin/check-ignore.c:174
+msgid "--non-matching is only valid with --verbose"
+msgstr "--non-matching 選項只在使用 --verbose 時有效"
+
+#: builtin/check-mailmap.c:9
+msgid "git check-mailmap [<options>] <contact>..."
+msgstr "git check-mailmap [<選項>] <聯繫位址>..."
+
+#: builtin/check-mailmap.c:14
+msgid "also read contacts from stdin"
+msgstr "還從標準輸入讀取聯繫位址"
+
+#: builtin/check-mailmap.c:25
+#, c-format
+msgid "unable to parse contact: %s"
+msgstr "不能解析聯繫位址：%s"
+
+#: builtin/check-mailmap.c:48
+msgid "no contacts specified"
+msgstr "未指定聯繫位址"
+
+#: builtin/checkout-index.c:131
+msgid "git checkout-index [<options>] [--] [<file>...]"
+msgstr "git checkout-index [<選項>] [--] [<檔案>...]"
+
+#: builtin/checkout-index.c:148
+msgid "stage should be between 1 and 3 or all"
+msgstr "索引值應該取值 1 到 3 或者 all"
+
+#: builtin/checkout-index.c:164
+msgid "check out all files in the index"
+msgstr "簽出索引區的所有檔案"
+
+#: builtin/checkout-index.c:165
+msgid "force overwrite of existing files"
+msgstr "強制覆蓋現有的檔案"
+
+#: builtin/checkout-index.c:167
+msgid "no warning for existing files and files not in index"
+msgstr "存在或不在索引中的檔案都沒有警告"
+
+#: builtin/checkout-index.c:169
+msgid "don't checkout new files"
+msgstr "不簽出新檔案"
+
+#: builtin/checkout-index.c:171
+msgid "update stat information in the index file"
+msgstr "更新索引中檔案的狀態訊息"
+
+#: builtin/checkout-index.c:175
+msgid "read list of paths from the standard input"
+msgstr "從標準輸入讀取路徑列表"
+
+#: builtin/checkout-index.c:177
+msgid "write the content to temporary files"
+msgstr "將內容寫入暫存檔"
+
+#: builtin/checkout-index.c:178 builtin/column.c:31
+#: builtin/submodule--helper.c:1385 builtin/submodule--helper.c:1388
+#: builtin/submodule--helper.c:1396 builtin/submodule--helper.c:1882
+#: builtin/worktree.c:679
+msgid "string"
+msgstr "字串"
+
+#: builtin/checkout-index.c:179
+msgid "when creating files, prepend <string>"
+msgstr "在建立檔案時，在前面加上 <字串>"
+
+#: builtin/checkout-index.c:181
+msgid "copy out the files from named stage"
+msgstr "從指定暫存區中拷出檔案"
+
+#: builtin/checkout.c:31
+msgid "git checkout [<options>] <branch>"
+msgstr "git checkout [<選項>] <分支>"
+
+#: builtin/checkout.c:32
+msgid "git checkout [<options>] [<branch>] -- <file>..."
+msgstr "git checkout [<選項>] [<分支>] -- <檔案>..."
+
+#: builtin/checkout.c:37
+msgid "git switch [<options>] [<branch>]"
+msgstr "git switch [<選項>] [<分支>]"
+
+#: builtin/checkout.c:42
+msgid "git restore [<options>] [--source=<branch>] <file>..."
+msgstr "git restore [<選項>] [--source=<分支>] <檔案>..."
+
+#: builtin/checkout.c:175 builtin/checkout.c:214
+#, c-format
+msgid "path '%s' does not have our version"
+msgstr "路徑 '%s' 沒有我們的版本"
+
+#: builtin/checkout.c:177 builtin/checkout.c:216
+#, c-format
+msgid "path '%s' does not have their version"
+msgstr "路徑 '%s' 沒有他們的版本"
+
+#: builtin/checkout.c:193
+#, c-format
+msgid "path '%s' does not have all necessary versions"
+msgstr "路徑 '%s' 沒有全部必需的版本"
+
+#: builtin/checkout.c:243
+#, c-format
+msgid "path '%s' does not have necessary versions"
+msgstr "路徑 '%s' 沒有必需的版本"
+
+#: builtin/checkout.c:261
+#, c-format
+msgid "path '%s': cannot merge"
+msgstr "path '%s'：無法合併"
+
+#: builtin/checkout.c:277
+#, c-format
+msgid "Unable to add merge result for '%s'"
+msgstr "無法為 '%s' 新增合併結果"
+
+#: builtin/checkout.c:377
+#, c-format
+msgid "Recreated %d merge conflict"
+msgid_plural "Recreated %d merge conflicts"
+msgstr[0] "重新建立了 %d 個合併衝突"
+msgstr[1] "重新建立了 %d 個合併衝突"
+
+#: builtin/checkout.c:382
+#, c-format
+msgid "Updated %d path from %s"
+msgid_plural "Updated %d paths from %s"
+msgstr[0] "從 %2$s 更新了 %1$d 個路徑"
+msgstr[1] "從 %2$s 更新了 %1$d 個路徑"
+
+#: builtin/checkout.c:389
+#, c-format
+msgid "Updated %d path from the index"
+msgid_plural "Updated %d paths from the index"
+msgstr[0] "從索引區更新了 %d 個路徑"
+msgstr[1] "從索引區更新了 %d 個路徑"
+
+#: builtin/checkout.c:412 builtin/checkout.c:415 builtin/checkout.c:418
+#: builtin/checkout.c:422
+#, c-format
+msgid "'%s' cannot be used with updating paths"
+msgstr "'%s' 不能在更新路徑時使用"
+
+#: builtin/checkout.c:425 builtin/checkout.c:428
+#, c-format
+msgid "'%s' cannot be used with %s"
+msgstr "'%s' 不能和 %s 同時使用"
+
+#: builtin/checkout.c:432
+#, c-format
+msgid "Cannot update paths and switch to branch '%s' at the same time."
+msgstr "不能同時更新路徑並切換到分支'%s'。"
+
+#: builtin/checkout.c:436
+#, c-format
+msgid "neither '%s' or '%s' is specified"
+msgstr "'%s' 或 '%s' 都沒有指定"
+
+#: builtin/checkout.c:440
+#, c-format
+msgid "'%s' must be used when '%s' is not specified"
+msgstr "未指定 '%2$s' 時，必須使用 '%1$s'"
+
+#: builtin/checkout.c:445 builtin/checkout.c:450
+#, c-format
+msgid "'%s' or '%s' cannot be used with %s"
+msgstr "'%s' 或 '%s' 不能和 %s 一起使用"
+
+#: builtin/checkout.c:509 builtin/checkout.c:516
+#, c-format
+msgid "path '%s' is unmerged"
+msgstr "路徑 '%s' 未合併"
+
+#: builtin/checkout.c:682 builtin/sparse-checkout.c:82
+msgid "you need to resolve your current index first"
+msgstr "您需要先解決目前索引的衝突"
+
+#: builtin/checkout.c:732
+#, c-format
+msgid ""
+"cannot continue with staged changes in the following files:\n"
+"%s"
+msgstr ""
+"不能繼續，下列檔案有暫存的修改：\n"
+"%s"
+
+#: builtin/checkout.c:835
+#, c-format
+msgid "Can not do reflog for '%s': %s\n"
+msgstr "不能對 '%s' 執行 reflog 動作：%s\n"
+
+#: builtin/checkout.c:877
+msgid "HEAD is now at"
+msgstr "HEAD 目前位於"
+
+#: builtin/checkout.c:881 builtin/clone.c:716
+msgid "unable to update HEAD"
+msgstr "不能更新 HEAD"
+
+#: builtin/checkout.c:885
+#, c-format
+msgid "Reset branch '%s'\n"
+msgstr "重設分支 '%s'\n"
+
+#: builtin/checkout.c:888
+#, c-format
+msgid "Already on '%s'\n"
+msgstr "已經位於 '%s'\n"
+
+#: builtin/checkout.c:892
+#, c-format
+msgid "Switched to and reset branch '%s'\n"
+msgstr "切換並重設分支 '%s'\n"
+
+#: builtin/checkout.c:894 builtin/checkout.c:1291
+#, c-format
+msgid "Switched to a new branch '%s'\n"
+msgstr "切換到一個新分支 '%s'\n"
+
+#: builtin/checkout.c:896
+#, c-format
+msgid "Switched to branch '%s'\n"
+msgstr "切換到分支 '%s'\n"
+
+#  譯者：請維持前導空格
+#: builtin/checkout.c:947
+#, c-format
+msgid " ... and %d more.\n"
+msgstr " ... 及其它 %d 個。\n"
+
+#: builtin/checkout.c:953
+#, c-format
+msgid ""
+"Warning: you are leaving %d commit behind, not connected to\n"
+"any of your branches:\n"
+"\n"
+"%s\n"
+msgid_plural ""
+"Warning: you are leaving %d commits behind, not connected to\n"
+"any of your branches:\n"
+"\n"
+"%s\n"
+msgstr[0] ""
+"警告：您正丟下 %d 個提交，未和任何分支關聯：\n"
+"\n"
+"%s\n"
+msgstr[1] ""
+"警告：您正丟下 %d 個提交，未和任何分支關聯：\n"
+"\n"
+"%s\n"
+
+#: builtin/checkout.c:972
+#, c-format
+msgid ""
+"If you want to keep it by creating a new branch, this may be a good time\n"
+"to do so with:\n"
+"\n"
+" git branch <new-branch-name> %s\n"
+"\n"
+msgid_plural ""
+"If you want to keep them by creating a new branch, this may be a good time\n"
+"to do so with:\n"
+"\n"
+" git branch <new-branch-name> %s\n"
+"\n"
+msgstr[0] ""
+"如果您想要透過建立新分支儲存它，這可能是一個好時候。\n"
+"如下動作：\n"
+"\n"
+" git branch <新分支名> %s\n"
+"\n"
+msgstr[1] ""
+"如果您想要透過建立新分支儲存它們，這可能是一個好時候。\n"
+"如下動作：\n"
+"\n"
+" git branch <新分支名> %s\n"
+"\n"
+
+#: builtin/checkout.c:1007
+msgid "internal error in revision walk"
+msgstr "在版本遍歷時遇到內部錯誤"
+
+#: builtin/checkout.c:1011
+msgid "Previous HEAD position was"
+msgstr "之前的 HEAD 位置是"
+
+#: builtin/checkout.c:1051 builtin/checkout.c:1286
+msgid "You are on a branch yet to be born"
+msgstr "您位於一個尚未初始化的分支"
+
+#: builtin/checkout.c:1178
+msgid "only one reference expected"
+msgstr "預期只有一個引用"
+
+#: builtin/checkout.c:1195
+#, c-format
+msgid "only one reference expected, %d given."
+msgstr "應只有一個引用，卻給出了 %d 個"
+
+#: builtin/checkout.c:1232
+#, c-format
+msgid ""
+"'%s' could be both a local file and a tracking branch.\n"
+"Please use -- (and optionally --no-guess) to disambiguate"
+msgstr ""
+"'%s' 既可以是一個本機檔案，也可以是一個追蹤分支。\n"
+"請使用 --（和可選的 --no-guess）來消除歧義"
+
+#: builtin/checkout.c:1245 builtin/worktree.c:290 builtin/worktree.c:455
+#, c-format
+msgid "invalid reference: %s"
+msgstr "無效引用：%s"
+
+#: builtin/checkout.c:1258 builtin/checkout.c:1622
+#, c-format
+msgid "reference is not a tree: %s"
+msgstr "引用不是一個樹：%s"
+
+#: builtin/checkout.c:1305
+#, c-format
+msgid "a branch is expected, got tag '%s'"
+msgstr "期望一個分支，得到標籤 '%s'"
+
+#: builtin/checkout.c:1307
+#, c-format
+msgid "a branch is expected, got remote branch '%s'"
+msgstr "期望一個分支，得到遠端分支 '%s'"
+
+#: builtin/checkout.c:1308 builtin/checkout.c:1316
+#, c-format
+msgid "a branch is expected, got '%s'"
+msgstr "期望一個分支，得到 '%s'"
+
+#: builtin/checkout.c:1311
+#, c-format
+msgid "a branch is expected, got commit '%s'"
+msgstr "期望一個分支，得到提交 '%s'"
+
+#: builtin/checkout.c:1327
+msgid ""
+"cannot switch branch while merging\n"
+"Consider \"git merge --quit\" or \"git worktree add\"."
+msgstr ""
+"不能在合併時切換分支\n"
+"考慮使用 \"git merge --quit\" 或 \"git worktree add\"。"
+
+#: builtin/checkout.c:1331
+msgid ""
+"cannot switch branch in the middle of an am session\n"
+"Consider \"git am --quit\" or \"git worktree add\"."
+msgstr ""
+"不能在 am 工作階段期間切換分支\n"
+"考慮使用 \"git am --quit\" 或 \"git worktree add\"。"
+
+#: builtin/checkout.c:1335
+msgid ""
+"cannot switch branch while rebasing\n"
+"Consider \"git rebase --quit\" or \"git worktree add\"."
+msgstr ""
+"不能在重定基底時切換分支\n"
+"考慮使用 \"git rebase --quit\" 或 \"git worktree add\"。"
+
+#: builtin/checkout.c:1339
+msgid ""
+"cannot switch branch while cherry-picking\n"
+"Consider \"git cherry-pick --quit\" or \"git worktree add\"."
+msgstr ""
+"不能在揀選時切換分支\n"
+"考慮使用 \"git cherry-pick --quit\" 或 \"git worktree add\"。"
+
+#: builtin/checkout.c:1343
+msgid ""
+"cannot switch branch while reverting\n"
+"Consider \"git revert --quit\" or \"git worktree add\"."
+msgstr ""
+"不能在還原時切換分支\n"
+"考慮使用 \"git revert --quit\" 或 \"git worktree add\"。"
+
+#: builtin/checkout.c:1347
+msgid "you are switching branch while bisecting"
+msgstr "您在執行二分尋找時切換分支"
+
+#: builtin/checkout.c:1354
+msgid "paths cannot be used with switching branches"
+msgstr "路徑不能和切換分支同時使用"
+
+#: builtin/checkout.c:1357 builtin/checkout.c:1361 builtin/checkout.c:1365
+#, c-format
+msgid "'%s' cannot be used with switching branches"
+msgstr "'%s' 不能和切換分支同時使用"
+
+#: builtin/checkout.c:1369 builtin/checkout.c:1372 builtin/checkout.c:1375
+#: builtin/checkout.c:1380 builtin/checkout.c:1385
+#, c-format
+msgid "'%s' cannot be used with '%s'"
+msgstr "'%s' 不能和 '%s' 同時使用"
+
+#: builtin/checkout.c:1382
+#, c-format
+msgid "'%s' cannot take <start-point>"
+msgstr "'%s' 不帶 <起始點>"
+
+#: builtin/checkout.c:1390
+#, c-format
+msgid "Cannot switch branch to a non-commit '%s'"
+msgstr "不能切換分支到一個非提交 '%s'"
+
+#: builtin/checkout.c:1397
+msgid "missing branch or commit argument"
+msgstr "缺少分支或提交參數"
+
+#: builtin/checkout.c:1439 builtin/clone.c:91 builtin/commit-graph.c:52
+#: builtin/commit-graph.c:113 builtin/fetch.c:167 builtin/merge.c:285
+#: builtin/multi-pack-index.c:27 builtin/pull.c:138 builtin/push.c:563
+#: builtin/send-pack.c:174
+msgid "force progress reporting"
+msgstr "強制顯示進度報告"
+
+#: builtin/checkout.c:1440
+msgid "perform a 3-way merge with the new branch"
+msgstr "和新的分支執行三方合併"
+
+#: builtin/checkout.c:1441 builtin/log.c:1690 parse-options.h:322
+msgid "style"
+msgstr "風格"
+
+#: builtin/checkout.c:1442
+msgid "conflict style (merge or diff3)"
+msgstr "衝突輸出風格（merge 或 diff3）"
+
+#: builtin/checkout.c:1454 builtin/worktree.c:503
+msgid "detach HEAD at named commit"
+msgstr "HEAD 從指定的提交分離"
+
+#: builtin/checkout.c:1455
+msgid "set upstream info for new branch"
+msgstr "為新的分支設定上游訊息"
+
+#: builtin/checkout.c:1457
+msgid "force checkout (throw away local modifications)"
+msgstr "強制簽出（捨棄本機修改）"
+
+#: builtin/checkout.c:1459
+msgid "new-branch"
+msgstr "新分支"
+
+#: builtin/checkout.c:1459
+msgid "new unparented branch"
+msgstr "新的沒有父提交的分支"
+
+#: builtin/checkout.c:1461 builtin/merge.c:288
+msgid "update ignored files (default)"
+msgstr "更新忽略的檔案（預設）"
+
+#: builtin/checkout.c:1464
+msgid "do not check if another worktree is holding the given ref"
+msgstr "不檢查指定的引用是否被其他工作區所占用"
+
+#: builtin/checkout.c:1477
+msgid "checkout our version for unmerged files"
+msgstr "對尚未合併的檔案簽出我們的版本"
+
+#: builtin/checkout.c:1480
+msgid "checkout their version for unmerged files"
+msgstr "對尚未合併的檔案簽出他們的版本"
+
+#: builtin/checkout.c:1484
+msgid "do not limit pathspecs to sparse entries only"
+msgstr "對路徑不做稀疏簽出的限制"
+
+#: builtin/checkout.c:1537
+msgid "-b, -B and --orphan are mutually exclusive"
+msgstr "-b、-B 和 --orphan 是互斥的"
+
+#: builtin/checkout.c:1540
+msgid "-p and --overlay are mutually exclusive"
+msgstr "-p 和 --overlay 互斥"
+
+#: builtin/checkout.c:1577
+msgid "--track needs a branch name"
+msgstr "--track 需要一個分支名"
+
+#: builtin/checkout.c:1582
+msgid "missing branch name; try -b"
+msgstr "缺少分支名，嘗試 -b"
+
+#: builtin/checkout.c:1615
+#, c-format
+msgid "could not resolve %s"
+msgstr "無法解析 %s"
+
+#: builtin/checkout.c:1631
+msgid "invalid path specification"
+msgstr "無效的路徑規格"
+
+#: builtin/checkout.c:1638
+#, c-format
+msgid "'%s' is not a commit and a branch '%s' cannot be created from it"
+msgstr "'%s' 不是一個提交，不能基於它建立分支 '%s'"
+
+#: builtin/checkout.c:1642
+#, c-format
+msgid "git checkout: --detach does not take a path argument '%s'"
+msgstr "git checkout：--detach 不能接收路徑參數 '%s'"
+
+#: builtin/checkout.c:1651
+#| msgid "--first-parent is incompatible with --bisect"
+msgid "--pathspec-from-file is incompatible with --detach"
+msgstr "--pathspec-from-file 與 --detach 不相容"
+
+#: builtin/checkout.c:1654 builtin/reset.c:324
+#| msgid "--first-parent is incompatible with --bisect"
+msgid "--pathspec-from-file is incompatible with --patch"
+msgstr "--pathspec-from-file 與 --patch 不相容"
+
+#: builtin/checkout.c:1665
+msgid ""
+"git checkout: --ours/--theirs, --force and --merge are incompatible when\n"
+"checking out of the index."
+msgstr "git checkout：在從索引簽出時，--ours/--theirs、--force 和 --merge 不相容。"
+
+#: builtin/checkout.c:1670
+msgid "you must specify path(s) to restore"
+msgstr "您必須指定一個要復原的路徑"
+
+#: builtin/checkout.c:1689
+#, c-format
+msgid ""
+"'%s' matched more than one remote tracking branch.\n"
+"We found %d remotes with a reference that matched. So we fell back\n"
+"on trying to resolve the argument as a path, but failed there too!\n"
+"\n"
+"If you meant to check out a remote tracking branch on, e.g. 'origin',\n"
+"you can do so by fully qualifying the name with the --track option:\n"
+"\n"
+"    git checkout --track origin/<name>\n"
+"\n"
+"If you'd like to always have checkouts of an ambiguous <name> prefer\n"
+"one remote, e.g. the 'origin' remote, consider setting\n"
+"checkout.defaultRemote=origin in your config."
+msgstr ""
+"'%s' 符合了一個以上的遠端追蹤分支。\n"
+"我們發現 %d 個遠端版本庫具有同名分支。所以我們轉而嘗試將這個參數解析為\n"
+"路徑，但是也失敗了！\n"
+"\n"
+"如果您想要簽出一個遠端追蹤分支，例如在遠端版本庫 'origin' 上的，您可以\n"
+"使用分支全名和 --track 選項：\n"
+"\n"
+"    git checkout --track origin/<name>\n"
+"\n"
+"如果您總是喜歡使用模糊的簡短分支名 <name>，而不喜歡如 'origin' 的遠端\n"
+"版本庫名，可以在設定中設定 checkout.defaultRemote=origin。"
+
+#: builtin/checkout.c:1714 builtin/checkout.c:1716 builtin/checkout.c:1765
+#: builtin/checkout.c:1767 builtin/clone.c:121 builtin/remote.c:169
+#: builtin/remote.c:171 builtin/worktree.c:499 builtin/worktree.c:501
+msgid "branch"
+msgstr "分支"
+
+#: builtin/checkout.c:1715
+msgid "create and checkout a new branch"
+msgstr "建立並簽出一個新的分支"
+
+#: builtin/checkout.c:1717
+msgid "create/reset and checkout a branch"
+msgstr "建立/重設並簽出一個分支"
+
+#: builtin/checkout.c:1718
+msgid "create reflog for new branch"
+msgstr "為新的分支建立引用日誌"
+
+#: builtin/checkout.c:1720
+msgid "second guess 'git checkout <no-such-branch>' (default)"
+msgstr "二次猜測 'git checkout <無此分支>'（預設）"
+
+#: builtin/checkout.c:1721
+msgid "use overlay mode (default)"
+msgstr "使用疊加模式（預設）"
+
+#: builtin/checkout.c:1766
+msgid "create and switch to a new branch"
+msgstr "建立並切換一個新分支"
+
+#: builtin/checkout.c:1768
+msgid "create/reset and switch to a branch"
+msgstr "建立/重設並切換一個分支"
+
+#: builtin/checkout.c:1770
+msgid "second guess 'git switch <no-such-branch>'"
+msgstr "二次猜測 'git switch <無此分支>'"
+
+#: builtin/checkout.c:1772
+msgid "throw away local modifications"
+msgstr "捨棄本機修改"
+
+#: builtin/checkout.c:1804
+msgid "which tree-ish to checkout from"
+msgstr "要簽出哪一個樹"
+
+#: builtin/checkout.c:1806
+msgid "restore the index"
+msgstr "復原索引"
+
+#: builtin/checkout.c:1808
+msgid "restore the working tree (default)"
+msgstr "復原工作區（預設）"
+
+#: builtin/checkout.c:1810
+msgid "ignore unmerged entries"
+msgstr "忽略未合併條目"
+
+#: builtin/checkout.c:1811
+msgid "use overlay mode"
+msgstr "使用疊加模式"
+
+#: builtin/clean.c:28
+msgid ""
+"git clean [-d] [-f] [-i] [-n] [-q] [-e <pattern>] [-x | -X] [--] <paths>..."
+msgstr "git clean [-d] [-f] [-i] [-n] [-q] [-e <模式>] [-x | -X] [--] <路徑>..."
+
+#: builtin/clean.c:32
+#, c-format
+msgid "Removing %s\n"
+msgstr "正刪除 %s\n"
+
+#: builtin/clean.c:33
+#, c-format
+msgid "Would remove %s\n"
+msgstr "將刪除 %s\n"
+
+#: builtin/clean.c:34
+#, c-format
+msgid "Skipping repository %s\n"
+msgstr "忽略版本庫 %s\n"
+
+#: builtin/clean.c:35
+#, c-format
+msgid "Would skip repository %s\n"
+msgstr "將忽略版本庫 %s\n"
+
+#: builtin/clean.c:36
+#, c-format
+msgid "failed to remove %s"
+msgstr "刪除 %s 失敗"
+
+#: builtin/clean.c:37
+#, c-format
+msgid "could not lstat %s\n"
+msgstr "不能對 %s 呼叫 lstat\n"
+
+#: builtin/clean.c:301 git-add--interactive.perl:595
+#, c-format
+msgid ""
+"Prompt help:\n"
+"1          - select a numbered item\n"
+"foo        - select item based on unique prefix\n"
+"           - (empty) select nothing\n"
+msgstr ""
+"協助：\n"
+"1          - 透過編號選擇一個選項\n"
+"foo        - 透過唯一前綴選擇一個選項\n"
+"           - （空）什麼也不選擇\n"
+
+#: builtin/clean.c:305 git-add--interactive.perl:604
+#, c-format
+msgid ""
+"Prompt help:\n"
+"1          - select a single item\n"
+"3-5        - select a range of items\n"
+"2-3,6-9    - select multiple ranges\n"
+"foo        - select item based on unique prefix\n"
+"-...       - unselect specified items\n"
+"*          - choose all items\n"
+"           - (empty) finish selecting\n"
+msgstr ""
+"協助：\n"
+"1          - 選擇一個選項\n"
+"3-5        - 選擇一個範圍內的所有選項\n"
+"2-3,6-9    - 選擇多個範圍內的所有選項\n"
+"foo        - 透過唯一前綴選擇一個選項\n"
+"-...       - 反選特定的選項\n"
+"*          - 選擇所有選項\n"
+"           - （空）結束選擇\n"
+
+#: builtin/clean.c:521 git-add--interactive.perl:570
+#: git-add--interactive.perl:575
+#, c-format, perl-format
+msgid "Huh (%s)?\n"
+msgstr "嗯（%s）？\n"
+
+#: builtin/clean.c:663
+#, c-format
+msgid "Input ignore patterns>> "
+msgstr "輸入範本以排除條目>> "
+
+#: builtin/clean.c:700
+#, c-format
+msgid "WARNING: Cannot find items matched by: %s"
+msgstr "警告：無法找到和 %s 符合的條目"
+
+#: builtin/clean.c:721
+msgid "Select items to delete"
+msgstr "選擇要刪除的條目"
+
+#. TRANSLATORS: Make sure to keep [y/N] as is
+#: builtin/clean.c:762
+#, c-format
+msgid "Remove %s [y/N]? "
+msgstr "刪除 %s [y/N]？"
+
+#: builtin/clean.c:795
+msgid ""
+"clean               - start cleaning\n"
+"filter by pattern   - exclude items from deletion\n"
+"select by numbers   - select items to be deleted by numbers\n"
+"ask each            - confirm each deletion (like \"rm -i\")\n"
+"quit                - stop cleaning\n"
+"help                - this screen\n"
+"?                   - help for prompt selection"
+msgstr ""
+"clean               - 開始清理\n"
+"filter by pattern   - 透過範本排除要刪除的條目\n"
+"select by numbers   - 透過數字選擇要刪除的條目\n"
+"ask each            - 針對刪除逐一詢問（就像 \"rm -i\"）\n"
+"quit                - 停止刪除並離開\n"
+"help                - 顯示本協助\n"
+"?                   - 顯示如何在提示符下選擇的協助"
+
+#: builtin/clean.c:831
+msgid "Would remove the following item:"
+msgid_plural "Would remove the following items:"
+msgstr[0] "將刪除如下條目："
+msgstr[1] "將刪除如下條目："
+
+#: builtin/clean.c:847
+msgid "No more files to clean, exiting."
+msgstr "沒有要清理的檔案，離開。"
+
+#: builtin/clean.c:909
+msgid "do not print names of files removed"
+msgstr "不列印刪除檔案的名稱"
+
+#: builtin/clean.c:911
+msgid "force"
+msgstr "強制"
+
+#: builtin/clean.c:912
+msgid "interactive cleaning"
+msgstr "互動式清除"
+
+#: builtin/clean.c:914
+msgid "remove whole directories"
+msgstr "刪除整個目錄"
+
+#: builtin/clean.c:915 builtin/describe.c:548 builtin/describe.c:550
+#: builtin/grep.c:901 builtin/log.c:177 builtin/log.c:179
+#: builtin/ls-files.c:557 builtin/name-rev.c:464 builtin/name-rev.c:466
+#: builtin/show-ref.c:179
+msgid "pattern"
+msgstr "模式"
+
+#: builtin/clean.c:916
+msgid "add <pattern> to ignore rules"
+msgstr "新增 <模式> 到忽略規則"
+
+#: builtin/clean.c:917
+msgid "remove ignored files, too"
+msgstr "也刪除忽略的檔案"
+
+#: builtin/clean.c:919
+msgid "remove only ignored files"
+msgstr "只刪除忽略的檔案"
+
+#: builtin/clean.c:937
+msgid "-x and -X cannot be used together"
+msgstr "-x 和 -X 不能同時使用"
+
+#: builtin/clean.c:941
+msgid ""
+"clean.requireForce set to true and neither -i, -n, nor -f given; refusing to "
+"clean"
+msgstr "clean.requireForce 設定為 true 且未提供 -i、-n 或 -f 選項，拒絕執行清理動作"
+
+#: builtin/clean.c:944
+msgid ""
+"clean.requireForce defaults to true and neither -i, -n, nor -f given; "
+"refusing to clean"
+msgstr "clean.requireForce 預設為 true 且未提供 -i、-n 或 -f 選項，拒絕執行清理動作"
+
+#: builtin/clone.c:45
+msgid "git clone [<options>] [--] <repo> [<dir>]"
+msgstr "git clone [<選項>] [--] <版本庫> [<路徑>]"
+
+#: builtin/clone.c:93
+msgid "don't create a checkout"
+msgstr "不建立一個簽出"
+
+#: builtin/clone.c:94 builtin/clone.c:96 builtin/init-db.c:489
+msgid "create a bare repository"
+msgstr "建立一個純版本庫"
+
+#: builtin/clone.c:98
+msgid "create a mirror repository (implies bare)"
+msgstr "建立一個鏡像版本庫（也是純版本庫）"
+
+#: builtin/clone.c:100
+msgid "to clone from a local repository"
+msgstr "從本機版本庫複製"
+
+#: builtin/clone.c:102
+msgid "don't use local hardlinks, always copy"
+msgstr "不使用本機硬連結，始終複製"
+
+#: builtin/clone.c:104
+msgid "setup as shared repository"
+msgstr "設定為共享版本庫"
+
+#: builtin/clone.c:107
+msgid "pathspec"
+msgstr "路徑規格"
+
+#: builtin/clone.c:107
+msgid "initialize submodules in the clone"
+msgstr "在複製時初始化子模組"
+
+#: builtin/clone.c:110
+msgid "number of submodules cloned in parallel"
+msgstr "並發複製的子模組的數量"
+
+#: builtin/clone.c:111 builtin/init-db.c:486
+msgid "template-directory"
+msgstr "範本目錄"
+
+#: builtin/clone.c:112 builtin/init-db.c:487
+msgid "directory from which templates will be used"
+msgstr "範本目錄將被使用"
+
+#: builtin/clone.c:114 builtin/clone.c:116 builtin/submodule--helper.c:1392
+#: builtin/submodule--helper.c:1885
+msgid "reference repository"
+msgstr "參考版本庫"
+
+#: builtin/clone.c:118 builtin/submodule--helper.c:1394
+#: builtin/submodule--helper.c:1887
+msgid "use --reference only while cloning"
+msgstr "僅在複製時參考 --reference 指向的本機版本庫"
+
+#: builtin/clone.c:119 builtin/column.c:27 builtin/merge-file.c:46
+#: builtin/pack-objects.c:3294 builtin/repack.c:327
+msgid "name"
+msgstr "名稱"
+
+#: builtin/clone.c:120
+msgid "use <name> instead of 'origin' to track upstream"
+msgstr "使用 <名稱> 而不是 'origin' 去追蹤上游"
+
+#: builtin/clone.c:122
+msgid "checkout <branch> instead of the remote's HEAD"
+msgstr "簽出 <分支> 而不是遠端 HEAD"
+
+#: builtin/clone.c:124
+msgid "path to git-upload-pack on the remote"
+msgstr "遠端 git-upload-pack 路徑"
+
+#: builtin/clone.c:125 builtin/fetch.c:168 builtin/grep.c:840
+#: builtin/pull.c:227
+msgid "depth"
+msgstr "深度"
+
+#: builtin/clone.c:126
+msgid "create a shallow clone of that depth"
+msgstr "建立一個指定深度的淺複製"
+
+#: builtin/clone.c:127 builtin/fetch.c:170 builtin/pack-objects.c:3283
+msgid "time"
+msgstr "時間"
+
+#: builtin/clone.c:128
+msgid "create a shallow clone since a specific time"
+msgstr "從一個特定時間建立一個淺複製"
+
+#: builtin/clone.c:129 builtin/fetch.c:172 builtin/fetch.c:195
+#: builtin/rebase.c:1445
+msgid "revision"
+msgstr "版本"
+
+#: builtin/clone.c:130 builtin/fetch.c:173
+msgid "deepen history of shallow clone, excluding rev"
+msgstr "深化淺複製的歷史，除了特定版本"
+
+#: builtin/clone.c:132
+msgid "clone only one branch, HEAD or --branch"
+msgstr "只複製一個分支、HEAD 或 --branch"
+
+#: builtin/clone.c:134
+msgid "don't clone any tags, and make later fetches not to follow them"
+msgstr "不要複製任何標籤，並且後續取得動作也不下載它們"
+
+#: builtin/clone.c:136
+msgid "any cloned submodules will be shallow"
+msgstr "子模組將以淺下載模式複製"
+
+#: builtin/clone.c:137 builtin/init-db.c:495
+msgid "gitdir"
+msgstr "git目錄"
+
+#: builtin/clone.c:138 builtin/init-db.c:496
+msgid "separate git dir from working tree"
+msgstr "git目錄和工作區分離"
+
+#: builtin/clone.c:139
+msgid "key=value"
+msgstr "key=value"
+
+#: builtin/clone.c:140
+msgid "set config inside the new repository"
+msgstr "在新版本庫中設定設定訊息"
+
+#: builtin/clone.c:142 builtin/fetch.c:190 builtin/ls-remote.c:76
+#: builtin/push.c:573 builtin/send-pack.c:172
+msgid "server-specific"
+msgstr "server-specific"
+
+#: builtin/clone.c:142 builtin/fetch.c:190 builtin/ls-remote.c:76
+#: builtin/push.c:573 builtin/send-pack.c:173
+msgid "option to transmit"
+msgstr "傳輸選項"
+
+#: builtin/clone.c:143 builtin/fetch.c:191 builtin/pull.c:240
+#: builtin/push.c:574
+msgid "use IPv4 addresses only"
+msgstr "只使用 IPv4 位址"
+
+#: builtin/clone.c:145 builtin/fetch.c:193 builtin/pull.c:243
+#: builtin/push.c:576
+msgid "use IPv6 addresses only"
+msgstr "只使用 IPv6 位址"
+
+#: builtin/clone.c:149
+msgid "any cloned submodules will use their remote-tracking branch"
+msgstr "任何複製的子模組將使用它們的遠端追蹤分支"
+
+#: builtin/clone.c:151
+msgid "initialize sparse-checkout file to include only files at root"
+msgstr "初始化稀疏簽出檔案，只包含根目錄中的檔案"
+
+#: builtin/clone.c:287
+msgid ""
+"No directory name could be guessed.\n"
+"Please specify a directory on the command line"
+msgstr ""
+"無法猜到目錄名。\n"
+"請在指令列指定一個目錄"
+
+#: builtin/clone.c:340
+#, c-format
+msgid "info: Could not add alternate for '%s': %s\n"
+msgstr "info: 不能為 '%s' 新增一個備用：%s\n"
+
+#: builtin/clone.c:413
+#, c-format
+msgid "%s exists and is not a directory"
+msgstr "%s 存在且不是一個目錄"
+
+#: builtin/clone.c:430
+#, c-format
+msgid "failed to start iterator over '%s'"
+msgstr "無法在 '%s' 上啟動疊代器"
+
+#: builtin/clone.c:460
+#, c-format
+msgid "failed to create link '%s'"
+msgstr "建立連結 '%s' 失敗"
+
+#: builtin/clone.c:464
+#, c-format
+msgid "failed to copy file to '%s'"
+msgstr "複製檔案至 '%s' 失敗"
+
+#: builtin/clone.c:469
+#, c-format
+msgid "failed to iterate over '%s'"
+msgstr "無法在 '%s' 上疊代"
+
+#: builtin/clone.c:494
+#, c-format
+msgid "done.\n"
+msgstr "完成。\n"
+
+#: builtin/clone.c:508
+msgid ""
+"Clone succeeded, but checkout failed.\n"
+"You can inspect what was checked out with 'git status'\n"
+"and retry with 'git restore --source=HEAD :/'\n"
+msgstr ""
+"複製成功，但是簽出失敗。\n"
+"您可以透過 'git status' 檢查哪些已被簽出，然後使用指令\n"
+"'git restore --source=HEAD :/' 重試\n"
+
+#: builtin/clone.c:585
+#, c-format
+msgid "Could not find remote branch %s to clone."
+msgstr "不能發現要複製的遠端分支 %s。"
+
+#: builtin/clone.c:704
+#, c-format
+msgid "unable to update %s"
+msgstr "不能更新 %s"
+
+#: builtin/clone.c:752
+#| msgid "failed to finalize '%s'"
+msgid "failed to initialize sparse-checkout"
+msgstr "無法初始化稀疏簽出"
+
+#: builtin/clone.c:775
+msgid "remote HEAD refers to nonexistent ref, unable to checkout.\n"
+msgstr "遠端 HEAD 指向一個不存在的引用，無法簽出。\n"
+
+#: builtin/clone.c:806
+msgid "unable to checkout working tree"
+msgstr "不能簽出工作區"
+
+#: builtin/clone.c:856
+msgid "unable to write parameters to config file"
+msgstr "無法將參數寫入設定檔案"
+
+#: builtin/clone.c:919
+msgid "cannot repack to clean up"
+msgstr "無法執行 repack 來清理"
+
+#: builtin/clone.c:921
+msgid "cannot unlink temporary alternates file"
+msgstr "無法刪除暫時的 alternates 檔案"
+
+#: builtin/clone.c:959 builtin/receive-pack.c:1948
+msgid "Too many arguments."
+msgstr "太多參數。"
+
+#: builtin/clone.c:963
+msgid "You must specify a repository to clone."
+msgstr "您必須指定一個版本庫來複製。"
+
+#: builtin/clone.c:976
+#, c-format
+msgid "--bare and --origin %s options are incompatible."
+msgstr "--bare 和 --origin %s 選項不相容。"
+
+#: builtin/clone.c:979
+msgid "--bare and --separate-git-dir are incompatible."
+msgstr "--bare 和 --separate-git-dir 選項不相容。"
+
+#: builtin/clone.c:992
+#, c-format
+msgid "repository '%s' does not exist"
+msgstr "版本庫 '%s' 不存在"
+
+#: builtin/clone.c:998 builtin/fetch.c:1787
+#, c-format
+msgid "depth %s is not a positive number"
+msgstr "深度 %s 不是一個正數"
+
+#: builtin/clone.c:1008
+#, c-format
+msgid "destination path '%s' already exists and is not an empty directory."
+msgstr "目標路徑 '%s' 已經存在，並且不是一個空目錄。"
+
+#: builtin/clone.c:1018
+#, c-format
+msgid "working tree '%s' already exists."
+msgstr "工作區 '%s' 已經存在。"
+
+#: builtin/clone.c:1033 builtin/clone.c:1054 builtin/difftool.c:271
+#: builtin/log.c:1866 builtin/worktree.c:302 builtin/worktree.c:334
+#, c-format
+msgid "could not create leading directories of '%s'"
+msgstr "不能為 '%s' 建立先導目錄"
+
+#: builtin/clone.c:1038
+#, c-format
+msgid "could not create work tree dir '%s'"
+msgstr "不能建立工作區目錄 '%s'"
+
+#: builtin/clone.c:1058
+#, c-format
+msgid "Cloning into bare repository '%s'...\n"
+msgstr "複製到純版本庫 '%s'...\n"
+
+#: builtin/clone.c:1060
+#, c-format
+msgid "Cloning into '%s'...\n"
+msgstr "正複製到 '%s'...\n"
+
+#: builtin/clone.c:1084
+msgid ""
+"clone --recursive is not compatible with both --reference and --reference-if-"
+"able"
+msgstr "clone --recursive 和 --reference 以及 --reference-if-able 不相容"
+
+#: builtin/clone.c:1148
+msgid "--depth is ignored in local clones; use file:// instead."
+msgstr "--depth 在本機複製時被忽略，請改用 file:// 協定。"
+
+#: builtin/clone.c:1150
+msgid "--shallow-since is ignored in local clones; use file:// instead."
+msgstr "--shallow-since 在本機複製時被忽略，請改用 file:// 協定。"
+
+#: builtin/clone.c:1152
+msgid "--shallow-exclude is ignored in local clones; use file:// instead."
+msgstr "--shallow-exclude 在本機複製時被忽略，請改用 file:// 協定。"
+
+#: builtin/clone.c:1154
+msgid "--filter is ignored in local clones; use file:// instead."
+msgstr "--filter 在本機複製時被忽略，請改用 file:// 協定。"
+
+#: builtin/clone.c:1157
+msgid "source repository is shallow, ignoring --local"
+msgstr "源版本庫是淺複製，忽略 --local"
+
+#: builtin/clone.c:1162
+msgid "--local is ignored"
+msgstr "--local 被忽略"
+
+#: builtin/clone.c:1237 builtin/clone.c:1245
+#, c-format
+msgid "Remote branch %s not found in upstream %s"
+msgstr "遠端分支 %s 在上游 %s 未發現"
+
+#: builtin/clone.c:1248
+msgid "You appear to have cloned an empty repository."
+msgstr "您似乎複製了一個空版本庫。"
+
+#: builtin/column.c:10
+msgid "git column [<options>]"
+msgstr "git column [<選項>]"
+
+#: builtin/column.c:27
+msgid "lookup config vars"
+msgstr "尋找設定變數"
+
+#: builtin/column.c:28 builtin/column.c:29
+msgid "layout to use"
+msgstr "要使用的配置"
+
+#: builtin/column.c:30
+msgid "Maximum width"
+msgstr "最大寬度"
+
+#: builtin/column.c:31
+msgid "Padding space on left border"
+msgstr "左邊框的填充空間"
+
+#: builtin/column.c:32
+msgid "Padding space on right border"
+msgstr "右邊框的填充空間"
+
+#: builtin/column.c:33
+msgid "Padding space between columns"
+msgstr "兩列之間的填充空間"
+
+#: builtin/column.c:51
+msgid "--command must be the first argument"
+msgstr "--command 必須是第一個參數"
+
+#: builtin/commit-tree.c:18
+msgid ""
+"git commit-tree [(-p <parent>)...] [-S[<keyid>]] [(-m <message>)...] [(-F "
+"<file>)...] <tree>"
+msgstr ""
+"git commit-tree [(-p <父提交>)...] [-S[<keyid>]] [(-m <消息>)...] [(-F <檔案"
+">)...] <樹>"
+
+#: builtin/commit-tree.c:31
+#, c-format
+msgid "duplicate parent %s ignored"
+msgstr "忽略重複的父提交 %s"
+
+#: builtin/commit-tree.c:56 builtin/commit-tree.c:136 builtin/log.c:526
+#, c-format
+msgid "not a valid object name %s"
+msgstr "不是一個有效的物件名 %s"
+
+#: builtin/commit-tree.c:93
+#, c-format
+msgid "git commit-tree: failed to open '%s'"
+msgstr "git commit-tree：無法開啟 '%s'"
+
+#: builtin/commit-tree.c:96
+#, c-format
+msgid "git commit-tree: failed to read '%s'"
+msgstr "git commit-tree：無法讀取 '%s'"
+
+#: builtin/commit-tree.c:98
+#, c-format
+msgid "git commit-tree: failed to close '%s'"
+msgstr "git commit-tree：無法關閉 '%s'"
+
+#: builtin/commit-tree.c:111
+msgid "parent"
+msgstr "父提交"
+
+#: builtin/commit-tree.c:112
+msgid "id of a parent commit object"
+msgstr "父提交物件 ID"
+
+#: builtin/commit-tree.c:114 builtin/commit.c:1496 builtin/merge.c:270
+#: builtin/notes.c:409 builtin/notes.c:575 builtin/stash.c:1469
+#: builtin/tag.c:412
+msgid "message"
+msgstr "說明"
+
+#: builtin/commit-tree.c:115 builtin/commit.c:1496
+msgid "commit message"
+msgstr "提交說明"
+
+#: builtin/commit-tree.c:118
+msgid "read commit log message from file"
+msgstr "從檔案中讀取提交說明"
+
+#: builtin/commit-tree.c:121 builtin/commit.c:1508 builtin/merge.c:287
+#: builtin/pull.c:195 builtin/revert.c:118
+msgid "GPG sign commit"
+msgstr "GPG 提交簽名"
+
+#: builtin/commit-tree.c:133
+msgid "must give exactly one tree"
+msgstr "必須精確地提供一個樹"
+
+#: builtin/commit-tree.c:140
+msgid "git commit-tree: failed to read"
+msgstr "git commit-tree：讀取失敗"
+
+#: builtin/commit.c:41
+msgid "git commit [<options>] [--] <pathspec>..."
+msgstr "git commit [<選項>] [--] <路徑規格>..."
+
+#: builtin/commit.c:46
+msgid "git status [<options>] [--] <pathspec>..."
+msgstr "git status [<選項>] [--] <路徑規格>..."
+
+#: builtin/commit.c:51
+msgid ""
+"You asked to amend the most recent commit, but doing so would make\n"
+"it empty. You can repeat your command with --allow-empty, or you can\n"
+"remove the commit entirely with \"git reset HEAD^\".\n"
+msgstr ""
+"您要修補最近的提交，但這麼做會讓它成為空提交。您可以重複您的指令並帶上\n"
+"--allow-empty 選項，或者您可用指令 \"git reset HEAD^\" 整個刪除該提交。\n"
+
+#: builtin/commit.c:56
+msgid ""
+"The previous cherry-pick is now empty, possibly due to conflict resolution.\n"
+"If you wish to commit it anyway, use:\n"
+"\n"
+"    git commit --allow-empty\n"
+"\n"
+msgstr ""
+"之前的揀選動作現在是一個空提交，可能是由衝突解決導致的。如果您無論如何\n"
+"也要提交，使用指令：\n"
+"\n"
+"    git commit --allow-empty\n"
+"\n"
+
+#: builtin/commit.c:63
+msgid "Otherwise, please use 'git cherry-pick --skip'\n"
+msgstr "否則，請使用 'git cherry-pick --skip'\n"
+
+#: builtin/commit.c:66
+msgid ""
+"and then use:\n"
+"\n"
+"    git cherry-pick --continue\n"
+"\n"
+"to resume cherry-picking the remaining commits.\n"
+"If you wish to skip this commit, use:\n"
+"\n"
+"    git cherry-pick --skip\n"
+"\n"
+msgstr ""
+"然後使用：\n"
+"\n"
+"    git cherry-pick --continue\n"
+"\n"
+"來繼續揀選剩餘提交。如果您想跳過此提交，使用：\n"
+"\n"
+"    git cherry-pick --skip\n"
+"\n"
+
+#: builtin/commit.c:315
+msgid "failed to unpack HEAD tree object"
+msgstr "解包 HEAD 樹狀物件失敗"
+
+#: builtin/commit.c:351
+#| msgid "paths '%s ...' with -a does not make sense"
+msgid "--pathspec-from-file with -a does not make sense"
+msgstr "--pathspec-from-file 和 -a 同時使用沒有意義"
+
+#: builtin/commit.c:364
+msgid "No paths with --include/--only does not make sense."
+msgstr "參數 --include/--only 不跟路徑沒有意義。"
+
+#: builtin/commit.c:376
+msgid "unable to create temporary index"
+msgstr "不能建立暫時索引"
+
+#: builtin/commit.c:382
+msgid "interactive add failed"
+msgstr "互動式新增失敗"
+
+#: builtin/commit.c:396
+msgid "unable to update temporary index"
+msgstr "無法更新暫時索引"
+
+#: builtin/commit.c:398
+msgid "Failed to update main cache tree"
+msgstr "不能更新樹的主快取"
+
+#: builtin/commit.c:423 builtin/commit.c:446 builtin/commit.c:492
+msgid "unable to write new_index file"
+msgstr "無法寫 new_index 檔案"
+
+#: builtin/commit.c:475
+msgid "cannot do a partial commit during a merge."
+msgstr "在合併過程中不能做部分提交。"
+
+#: builtin/commit.c:477
+msgid "cannot do a partial commit during a cherry-pick."
+msgstr "在揀選過程中不能做部分提交。"
+
+#: builtin/commit.c:485
+msgid "cannot read the index"
+msgstr "無法讀取索引"
+
+#: builtin/commit.c:504
+msgid "unable to write temporary index file"
+msgstr "無法寫暫時索引檔案"
+
+#: builtin/commit.c:602
+#, c-format
+msgid "commit '%s' lacks author header"
+msgstr "提交 '%s' 缺少作者訊息"
+
+#: builtin/commit.c:604
+#, c-format
+msgid "commit '%s' has malformed author line"
+msgstr "提交 '%s' 有格式錯誤的作者訊息"
+
+#: builtin/commit.c:623
+msgid "malformed --author parameter"
+msgstr "格式錯誤的 --author 參數"
+
+#: builtin/commit.c:676
+msgid ""
+"unable to select a comment character that is not used\n"
+"in the current commit message"
+msgstr "無法選擇一個未被目前提交說明使用的備註字元"
+
+#: builtin/commit.c:714 builtin/commit.c:747 builtin/commit.c:1092
+#, c-format
+msgid "could not lookup commit %s"
+msgstr "不能查詢提交 %s"
+
+#: builtin/commit.c:726 builtin/shortlog.c:319
+#, c-format
+msgid "(reading log message from standard input)\n"
+msgstr "（正從標準輸入中讀取日誌訊息）\n"
+
+#: builtin/commit.c:728
+msgid "could not read log from standard input"
+msgstr "不能從標準輸入中讀取日誌訊息"
+
+#: builtin/commit.c:732
+#, c-format
+msgid "could not read log file '%s'"
+msgstr "不能讀取日誌檔案 '%s'"
+
+#: builtin/commit.c:763 builtin/commit.c:779
+msgid "could not read SQUASH_MSG"
+msgstr "不能讀取 SQUASH_MSG"
+
+#: builtin/commit.c:770
+msgid "could not read MERGE_MSG"
+msgstr "不能讀取 MERGE_MSG"
+
+#: builtin/commit.c:830
+msgid "could not write commit template"
+msgstr "不能寫提交範本"
+
+#: builtin/commit.c:849
+#, c-format
+msgid ""
+"\n"
+"It looks like you may be committing a merge.\n"
+"If this is not correct, please remove the file\n"
+"\t%s\n"
+"and try again.\n"
+msgstr ""
+"\n"
+"似乎您正在做一個合併提交。如果不對，請刪除檔案\n"
+"\t%s\n"
+"然後重試。\n"
+
+#: builtin/commit.c:854
+#, c-format
+msgid ""
+"\n"
+"It looks like you may be committing a cherry-pick.\n"
+"If this is not correct, please remove the file\n"
+"\t%s\n"
+"and try again.\n"
+msgstr ""
+"\n"
+"似乎您正在做一個揀選提交。如果不對，請刪除檔案\n"
+"\t%s\n"
+"然後重試。\n"
+
+#: builtin/commit.c:867
+#, c-format
+msgid ""
+"Please enter the commit message for your changes. Lines starting\n"
+"with '%c' will be ignored, and an empty message aborts the commit.\n"
+msgstr ""
+"請為您的變更輸入提交說明。以 '%c' 開始的行將被忽略，而一個空的提交\n"
+"說明將會終止提交。\n"
+
+#: builtin/commit.c:875
+#, c-format
+msgid ""
+"Please enter the commit message for your changes. Lines starting\n"
+"with '%c' will be kept; you may remove them yourself if you want to.\n"
+"An empty message aborts the commit.\n"
+msgstr ""
+"請為您的變更輸入提交說明。以 '%c' 開始的行將被保留，如果您原意\n"
+"也可以刪除它們。一個空的提交說明將會終止提交。\n"
+
+#  譯者：為保證在輸出中對齊，注意調整句中空格！
+#: builtin/commit.c:892
+#, c-format
+msgid "%sAuthor:    %.*s <%.*s>"
+msgstr "%s作者：  %.*s <%.*s>"
+
+#  譯者：為保證在輸出中對齊，注意調整句中空格！
+#: builtin/commit.c:900
+#, c-format
+msgid "%sDate:      %s"
+msgstr "%s日期：  %s"
+
+#  譯者：為保證在輸出中對齊，注意調整句中空格！
+#: builtin/commit.c:907
+#, c-format
+msgid "%sCommitter: %.*s <%.*s>"
+msgstr "%s提交者：%.*s <%.*s>"
+
+#: builtin/commit.c:925
+msgid "Cannot read index"
+msgstr "無法讀取索引"
+
+#: builtin/commit.c:992
+msgid "Error building trees"
+msgstr "無法建立樹狀物件"
+
+#: builtin/commit.c:1006 builtin/tag.c:275
+#, c-format
+msgid "Please supply the message using either -m or -F option.\n"
+msgstr "請使用 -m 或 -F 選項提供提交說明。\n"
+
+#: builtin/commit.c:1050
+#, c-format
+msgid "--author '%s' is not 'Name <email>' and matches no existing author"
+msgstr "--author '%s' 不是 '姓名 <信箱>' 格式，且未能在現有作者中找到符合"
+
+#: builtin/commit.c:1064
+#, c-format
+msgid "Invalid ignored mode '%s'"
+msgstr "無效的忽略模式 '%s'"
+
+#: builtin/commit.c:1082 builtin/commit.c:1322
+#, c-format
+msgid "Invalid untracked files mode '%s'"
+msgstr "無效的未追蹤檔案參數 '%s'"
+
+#: builtin/commit.c:1122
+msgid "--long and -z are incompatible"
+msgstr "--long 和 -z 選項不相容"
+
+#: builtin/commit.c:1166
+msgid "Using both --reset-author and --author does not make sense"
+msgstr "同時使用 --reset-author 和 --author 沒有意義"
+
+#: builtin/commit.c:1175
+msgid "You have nothing to amend."
+msgstr "您沒有可修補的提交。"
+
+#: builtin/commit.c:1178
+msgid "You are in the middle of a merge -- cannot amend."
+msgstr "您正處於一個合併過程中 -- 無法修補提交。"
+
+#: builtin/commit.c:1180
+msgid "You are in the middle of a cherry-pick -- cannot amend."
+msgstr "您正處於一個揀選過程中 -- 無法修補提交。"
+
+#: builtin/commit.c:1183
+msgid "Options --squash and --fixup cannot be used together"
+msgstr "選項 --squash 和 --fixup 不能同時使用"
+
+#: builtin/commit.c:1193
+msgid "Only one of -c/-C/-F/--fixup can be used."
+msgstr "只能用一個 -c/-C/-F/--fixup 選項。"
+
+#: builtin/commit.c:1195
+msgid "Option -m cannot be combined with -c/-C/-F."
+msgstr "選項 -m 不能和 -c/-C/-F 同時使用。"
+
+#: builtin/commit.c:1203
+msgid "--reset-author can be used only with -C, -c or --amend."
+msgstr "--reset-author 只能和 -C、-c 或 --amend 同時使用。"
+
+#: builtin/commit.c:1220
+msgid "Only one of --include/--only/--all/--interactive/--patch can be used."
+msgstr "只能用一個 --include/--only/--all/--interactive/--patch 選項。"
+
+#: builtin/commit.c:1226
+#, c-format
+msgid "paths '%s ...' with -a does not make sense"
+msgstr "路徑  '%s ...' 和 -a 選項同時使用沒有意義"
+
+#: builtin/commit.c:1357 builtin/commit.c:1519
+msgid "show status concisely"
+msgstr "以簡潔的格式顯示狀態"
+
+#: builtin/commit.c:1359 builtin/commit.c:1521
+msgid "show branch information"
+msgstr "顯示分支訊息"
+
+#: builtin/commit.c:1361
+msgid "show stash information"
+msgstr "顯示儲藏區訊息"
+
+#: builtin/commit.c:1363 builtin/commit.c:1523
+msgid "compute full ahead/behind values"
+msgstr "計算完整的領先/落後值"
+
+#: builtin/commit.c:1365
+msgid "version"
+msgstr "版本"
+
+#: builtin/commit.c:1365 builtin/commit.c:1525 builtin/push.c:549
+#: builtin/worktree.c:650
+msgid "machine-readable output"
+msgstr "機器可讀的輸出"
+
+#: builtin/commit.c:1368 builtin/commit.c:1527
+msgid "show status in long format (default)"
+msgstr "以長格式顯示狀態（預設）"
+
+#: builtin/commit.c:1371 builtin/commit.c:1530
+msgid "terminate entries with NUL"
+msgstr "條目以 NUL 字元結尾"
+
+#: builtin/commit.c:1373 builtin/commit.c:1377 builtin/commit.c:1533
+#: builtin/fast-export.c:1153 builtin/fast-export.c:1156
+#: builtin/fast-export.c:1159 builtin/rebase.c:1525 parse-options.h:336
+msgid "mode"
+msgstr "模式"
+
+#: builtin/commit.c:1374 builtin/commit.c:1533
+msgid "show untracked files, optional modes: all, normal, no. (Default: all)"
+msgstr "顯示未追蹤的檔案，「模式」的可選參數：all、normal、no。（預設：all）"
+
+#: builtin/commit.c:1378
+msgid ""
+"show ignored files, optional modes: traditional, matching, no. (Default: "
+"traditional)"
+msgstr "顯示已忽略的檔案，可選模式：traditional、matching、no。（預設：traditional）"
+
+#: builtin/commit.c:1380 parse-options.h:192
+msgid "when"
+msgstr "何時"
+
+#: builtin/commit.c:1381
+msgid ""
+"ignore changes to submodules, optional when: all, dirty, untracked. "
+"(Default: all)"
+msgstr "忽略子模組的更改，「何時」的可選參數：all、dirty、untracked。（預設：all）"
+
+#: builtin/commit.c:1383
+msgid "list untracked files in columns"
+msgstr "以列的方式顯示未追蹤的檔案"
+
+#: builtin/commit.c:1384
+msgid "do not detect renames"
+msgstr "不檢測重新命名"
+
+#: builtin/commit.c:1386
+msgid "detect renames, optionally set similarity index"
+msgstr "檢測重新命名，可以設定索引相似度"
+
+#: builtin/commit.c:1406
+msgid "Unsupported combination of ignored and untracked-files arguments"
+msgstr "不支援已忽略和未追蹤檔案參數的組合"
+
+#: builtin/commit.c:1489
+msgid "suppress summary after successful commit"
+msgstr "提交成功後不顯示概述訊息"
+
+#: builtin/commit.c:1490
+msgid "show diff in commit message template"
+msgstr "在提交說明範本裡顯示差異"
+
+#: builtin/commit.c:1492
+msgid "Commit message options"
+msgstr "提交說明選項"
+
+#: builtin/commit.c:1493 builtin/merge.c:274 builtin/tag.c:414
+msgid "read message from file"
+msgstr "從檔案中讀取提交說明"
+
+#: builtin/commit.c:1494
+msgid "author"
+msgstr "作者"
+
+#: builtin/commit.c:1494
+msgid "override author for commit"
+msgstr "提交時覆蓋作者"
+
+#: builtin/commit.c:1495 builtin/gc.c:538
+msgid "date"
+msgstr "日期"
+
+#: builtin/commit.c:1495
+msgid "override date for commit"
+msgstr "提交時覆蓋日期"
+
+#: builtin/commit.c:1497 builtin/commit.c:1498 builtin/commit.c:1499
+#: builtin/commit.c:1500 parse-options.h:328 ref-filter.h:92
+msgid "commit"
+msgstr "提交"
+
+#: builtin/commit.c:1497
+msgid "reuse and edit message from specified commit"
+msgstr "重用並編輯指定提交的提交說明"
+
+#: builtin/commit.c:1498
+msgid "reuse message from specified commit"
+msgstr "重用指定提交的提交說明"
+
+#: builtin/commit.c:1499
+msgid "use autosquash formatted message to fixup specified commit"
+msgstr "使用 autosquash 格式的提交說明用以修正指定的提交"
+
+#: builtin/commit.c:1500
+msgid "use autosquash formatted message to squash specified commit"
+msgstr "使用 autosquash 格式的提交說明用以壓縮至指定的提交"
+
+#: builtin/commit.c:1501
+msgid "the commit is authored by me now (used with -C/-c/--amend)"
+msgstr "現在將該提交的作者改為我（和 -C/-c/--amend 參數共用）"
+
+#: builtin/commit.c:1502 builtin/log.c:1634 builtin/merge.c:289
+#: builtin/pull.c:164 builtin/revert.c:110
+msgid "add Signed-off-by:"
+msgstr "新增 Signed-off-by: 簽名"
+
+#: builtin/commit.c:1503
+msgid "use specified template file"
+msgstr "使用指定的範本檔案"
+
+#: builtin/commit.c:1504
+msgid "force edit of commit"
+msgstr "強制編輯提交"
+
+#: builtin/commit.c:1506
+msgid "include status in commit message template"
+msgstr "在提交說明範本裡包含狀態訊息"
+
+#: builtin/commit.c:1511
+msgid "Commit contents options"
+msgstr "提交內容選項"
+
+#: builtin/commit.c:1512
+msgid "commit all changed files"
+msgstr "提交所有改動的檔案"
+
+#: builtin/commit.c:1513
+msgid "add specified files to index for commit"
+msgstr "新增指定的檔案到索引區等待提交"
+
+#: builtin/commit.c:1514
+msgid "interactively add files"
+msgstr "互動式新增檔案"
+
+#: builtin/commit.c:1515
+msgid "interactively add changes"
+msgstr "互動式新增變更"
+
+#: builtin/commit.c:1516
+msgid "commit only specified files"
+msgstr "只提交指定的檔案"
+
+#: builtin/commit.c:1517
+msgid "bypass pre-commit and commit-msg hooks"
+msgstr "繞過 pre-commit 和 commit-msg 掛鉤"
+
+#: builtin/commit.c:1518
+msgid "show what would be committed"
+msgstr "顯示將要提交的內容"
+
+#: builtin/commit.c:1531
+msgid "amend previous commit"
+msgstr "修改先前的提交"
+
+#: builtin/commit.c:1532
+msgid "bypass post-rewrite hook"
+msgstr "繞過 post-rewrite 掛鉤"
+
+#: builtin/commit.c:1539
+msgid "ok to record an empty change"
+msgstr "允許一個空提交"
+
+#: builtin/commit.c:1541
+msgid "ok to record a change with an empty message"
+msgstr "允許空的提交說明"
+
+#: builtin/commit.c:1614
+#, c-format
+msgid "Corrupt MERGE_HEAD file (%s)"
+msgstr "損壞的 MERGE_HEAD 檔案（%s）"
+
+#: builtin/commit.c:1621
+msgid "could not read MERGE_MODE"
+msgstr "不能讀取 MERGE_MODE"
+
+#: builtin/commit.c:1640
+#, c-format
+msgid "could not read commit message: %s"
+msgstr "不能讀取提交說明：%s"
+
+#: builtin/commit.c:1647
+#, c-format
+msgid "Aborting commit due to empty commit message.\n"
+msgstr "終止提交因為提交說明為空。\n"
+
+#: builtin/commit.c:1652
+#, c-format
+msgid "Aborting commit; you did not edit the message.\n"
+msgstr "終止提交；您未更改來自範本的提交說明。\n"
+
+#: builtin/commit.c:1686
+msgid ""
+"repository has been updated, but unable to write\n"
+"new_index file. Check that disk is not full and quota is\n"
+"not exceeded, and then \"git restore --staged :/\" to recover."
+msgstr ""
+"版本庫已更新，但無法寫 new_index 檔案。檢查是否磁碟已滿或\n"
+"磁碟配額已耗盡，然後執行 \"git restore --staged :/\" 復原。"
+
+#: builtin/commit-graph.c:11 builtin/commit-graph.c:17
+msgid ""
+"git commit-graph verify [--object-dir <objdir>] [--shallow] [--[no-]progress]"
+msgstr ""
+"git commit-graph verify [--object-dir <物件目錄>] [--shallow] [--"
+"[no-]progress]"
+
+#: builtin/commit-graph.c:12 builtin/commit-graph.c:22
+msgid ""
+"git commit-graph write [--object-dir <objdir>] [--append|--split] [--"
+"reachable|--stdin-packs|--stdin-commits] [--[no-]progress] <split options>"
+msgstr ""
+"git commit-graph write [--object-dir <物件目錄>] [--append|--split] [--"
+"reachable|--stdin-packs|--stdin-commits] [--[no-]progress] <split options>"
+
+#: builtin/commit-graph.c:48 builtin/commit-graph.c:103
+#: builtin/commit-graph.c:187 builtin/fetch.c:179 builtin/log.c:1657
+msgid "dir"
+msgstr "目錄"
+
+#: builtin/commit-graph.c:49 builtin/commit-graph.c:104
+#: builtin/commit-graph.c:188
+msgid "The object directory to store the graph"
+msgstr "儲存圖形的物件目錄"
+
+#: builtin/commit-graph.c:51
+msgid "if the commit-graph is split, only verify the tip file"
+msgstr "如果提交圖形被分割，只驗證頭一個檔案"
+
+#: builtin/commit-graph.c:73 t/helper/test-read-graph.c:23
+#, c-format
+msgid "Could not open commit-graph '%s'"
+msgstr "無法開啟提交圖形 '%s'"
+
+#: builtin/commit-graph.c:106
+msgid "start walk at all refs"
+msgstr "開始遍歷所有引用"
+
+#: builtin/commit-graph.c:108
+msgid "scan pack-indexes listed by stdin for commits"
+msgstr "從標準輸入中的包索引檔案列表中掃描提交"
+
+#: builtin/commit-graph.c:110
+msgid "start walk at commits listed by stdin"
+msgstr "從標準輸入中的提交開始掃描"
+
+#: builtin/commit-graph.c:112
+msgid "include all commits already in the commit-graph file"
+msgstr "包含 commit-graph 檔案中已有所有提交"
+
+#: builtin/commit-graph.c:115
+msgid "allow writing an incremental commit-graph file"
+msgstr "允許寫一個增量提交圖形檔案"
+
+#: builtin/commit-graph.c:117 builtin/commit-graph.c:121
+msgid "maximum number of commits in a non-base split commit-graph"
+msgstr "在非基本分割提交圖形中的最大提交數"
+
+#: builtin/commit-graph.c:119
+msgid "maximum ratio between two levels of a split commit-graph"
+msgstr "一個分割提交圖形的兩個級別之間的最大比率"
+
+#: builtin/commit-graph.c:137
+msgid "use at most one of --reachable, --stdin-commits, or --stdin-packs"
+msgstr "不能同時使用 --reachable、--stdin-commits 或 --stdin-packs"
+
+#: builtin/config.c:11
+msgid "git config [<options>]"
+msgstr "git config [<選項>]"
+
+#: builtin/config.c:103 builtin/env--helper.c:23
+#, c-format
+msgid "unrecognized --type argument, %s"
+msgstr "未能識別的 --type 參數，%s"
+
+#: builtin/config.c:115
+msgid "only one type at a time"
+msgstr "一次只能一個類型"
+
+#: builtin/config.c:124
+msgid "Config file location"
+msgstr "設定檔案位置"
+
+#: builtin/config.c:125
+msgid "use global config file"
+msgstr "使用全域設定檔案"
+
+#: builtin/config.c:126
+msgid "use system config file"
+msgstr "使用系統級設定檔案"
+
+#: builtin/config.c:127
+msgid "use repository config file"
+msgstr "使用版本庫級設定檔案"
+
+#: builtin/config.c:128
+msgid "use per-worktree config file"
+msgstr "使用工作區級別的設定檔案"
+
+#: builtin/config.c:129
+msgid "use given config file"
+msgstr "使用指定的設定檔案"
+
+#: builtin/config.c:130
+msgid "blob-id"
+msgstr "資料物件 ID"
+
+#: builtin/config.c:130
+msgid "read config from given blob object"
+msgstr "從提供的資料物件讀取設定"
+
+#: builtin/config.c:131
+msgid "Action"
+msgstr "動作"
+
+#: builtin/config.c:132
+msgid "get value: name [value-regex]"
+msgstr "取得值：name [value-regex]"
+
+#: builtin/config.c:133
+msgid "get all values: key [value-regex]"
+msgstr "獲得所有的值：key [value-regex]"
+
+#: builtin/config.c:134
+msgid "get values for regexp: name-regex [value-regex]"
+msgstr "根據正規表示式獲得值：name-regex [value-regex]"
+
+#: builtin/config.c:135
+msgid "get value specific for the URL: section[.var] URL"
+msgstr "獲得 URL 取值：section[.var] URL"
+
+#: builtin/config.c:136
+msgid "replace all matching variables: name value [value_regex]"
+msgstr "取代所有符合的變數：name value [value_regex]"
+
+#: builtin/config.c:137
+msgid "add a new variable: name value"
+msgstr "新增一個新的變數：name value"
+
+#: builtin/config.c:138
+msgid "remove a variable: name [value-regex]"
+msgstr "刪除一個變數：name [value-regex]"
+
+#: builtin/config.c:139
+msgid "remove all matches: name [value-regex]"
+msgstr "刪除所有符合項：name [value-regex]"
+
+#: builtin/config.c:140
+msgid "rename section: old-name new-name"
+msgstr "重新命名小節：old-name new-name"
+
+#: builtin/config.c:141
+msgid "remove a section: name"
+msgstr "刪除一個小節：name"
+
+#: builtin/config.c:142
+msgid "list all"
+msgstr "全部列出"
+
+#: builtin/config.c:143
+msgid "open an editor"
+msgstr "開啟一個編輯器"
+
+#: builtin/config.c:144
+msgid "find the color configured: slot [default]"
+msgstr "獲得設定的顏色：設定 [預設]"
+
+#: builtin/config.c:145
+msgid "find the color setting: slot [stdout-is-tty]"
+msgstr "獲得顏色設定：設定 [stdout-is-tty]"
+
+#: builtin/config.c:146
+msgid "Type"
+msgstr "類型"
+
+#: builtin/config.c:147 builtin/env--helper.c:38
+msgid "value is given this type"
+msgstr "取值為該類型"
+
+#: builtin/config.c:148
+msgid "value is \"true\" or \"false\""
+msgstr "值是 \"true\" 或 \"false\""
+
+#: builtin/config.c:149
+msgid "value is decimal number"
+msgstr "值是十進位數"
+
+#: builtin/config.c:150
+msgid "value is --bool or --int"
+msgstr "值是 --bool or --int"
+
+#: builtin/config.c:151
+msgid "value is a path (file or directory name)"
+msgstr "值是一個路徑（檔案或目錄名）"
+
+#: builtin/config.c:152
+msgid "value is an expiry date"
+msgstr "值是一個到期日期"
+
+#: builtin/config.c:153
+msgid "Other"
+msgstr "其它"
+
+#: builtin/config.c:154
+msgid "terminate values with NUL byte"
+msgstr "終止值是 NUL 位元組"
+
+#: builtin/config.c:155
+msgid "show variable names only"
+msgstr "只顯示變數名"
+
+#: builtin/config.c:156
+msgid "respect include directives on lookup"
+msgstr "查詢時參照 include 指令遞迴尋找"
+
+#: builtin/config.c:157
+msgid "show origin of config (file, standard input, blob, command line)"
+msgstr "顯示設定的來源（檔案、標準輸入、資料物件，或指令列）"
+
+#: builtin/config.c:158 builtin/env--helper.c:40
+msgid "value"
+msgstr "取值"
+
+#: builtin/config.c:158
+msgid "with --get, use default value when missing entry"
+msgstr "使用 --get 但未指定參數時所使用的預設值"
+
+#: builtin/config.c:172
+#, c-format
+msgid "wrong number of arguments, should be %d"
+msgstr "錯誤的參數個數，應該為 %d 個"
+
+#: builtin/config.c:174
+#, c-format
+msgid "wrong number of arguments, should be from %d to %d"
+msgstr "錯誤的參數個數，應該為從 %d 個到 %d 個"
+
+#: builtin/config.c:308
+#, c-format
+msgid "invalid key pattern: %s"
+msgstr "無效鍵名模式：%s"
+
+#: builtin/config.c:344
+#, c-format
+msgid "failed to format default config value: %s"
+msgstr "格式化預設設定值失敗：%s"
+
+#: builtin/config.c:401
+#, c-format
+msgid "cannot parse color '%s'"
+msgstr "無法解析顏色 '%s'"
+
+#: builtin/config.c:443
+msgid "unable to parse default color value"
+msgstr "無法解析預設顏色值"
+
+#: builtin/config.c:496 builtin/config.c:742
+msgid "not in a git directory"
+msgstr "不在 git 版本庫中"
+
+#: builtin/config.c:499
+msgid "writing to stdin is not supported"
+msgstr "不支援寫到標準輸入"
+
+#: builtin/config.c:502
+msgid "writing config blobs is not supported"
+msgstr "不支援寫到設定資料物件"
+
+#: builtin/config.c:587
+#, c-format
+msgid ""
+"# This is Git's per-user configuration file.\n"
+"[user]\n"
+"# Please adapt and uncomment the following lines:\n"
+"#\tname = %s\n"
+"#\temail = %s\n"
+msgstr ""
+"# This is Git's per-user configuration file.\n"
+"[user]\n"
+"# Please adapt and uncomment the following lines:\n"
+"#\tname = %s\n"
+"#\temail = %s\n"
+
+#: builtin/config.c:611
+msgid "only one config file at a time"
+msgstr "一次只能有一個設定檔案"
+
+#: builtin/config.c:616
+msgid "--local can only be used inside a git repository"
+msgstr "--local 只能在一個版本庫內使用"
+
+#: builtin/config.c:619
+msgid "--blob can only be used inside a git repository"
+msgstr "--blob 只能在一個版本庫內使用"
+
+#: builtin/config.c:638
+msgid "$HOME not set"
+msgstr "$HOME 未設定"
+
+#: builtin/config.c:658
+msgid ""
+"--worktree cannot be used with multiple working trees unless the config\n"
+"extension worktreeConfig is enabled. Please read \"CONFIGURATION FILE\"\n"
+"section in \"git help worktree\" for details"
+msgstr ""
+"不能和多個工作區一起使用 --worktree，除非啟用 worktreeConfig 設定擴展。\n"
+"詳情請閱讀「git help worktree」的「CONFIGURATION FILE」小節"
+
+#: builtin/config.c:688
+msgid "--get-color and variable type are incoherent"
+msgstr "--get-color 和變數類型不相容"
+
+#: builtin/config.c:693
+msgid "only one action at a time"
+msgstr "一次只能有一個動作"
+
+#: builtin/config.c:706
+msgid "--name-only is only applicable to --list or --get-regexp"
+msgstr "--name-only 僅適用於 --list 或 --get-regexp"
+
+#: builtin/config.c:712
+msgid ""
+"--show-origin is only applicable to --get, --get-all, --get-regexp, and --"
+"list"
+msgstr "--show-origin 僅適用於 --get、--get-all、--get-regexp 和 --list"
+
+#: builtin/config.c:718
+msgid "--default is only applicable to --get"
+msgstr "--default 僅適用於 --get"
+
+#: builtin/config.c:731
+#, c-format
+msgid "unable to read config file '%s'"
+msgstr "無法讀取設定檔案 '%s'"
+
+#: builtin/config.c:734
+msgid "error processing config file(s)"
+msgstr "處理設定檔案發生錯誤"
+
+#: builtin/config.c:744
+msgid "editing stdin is not supported"
+msgstr "不支援編輯標準輸入"
+
+#: builtin/config.c:746
+msgid "editing blobs is not supported"
+msgstr "不支援編輯資料物件"
+
+#: builtin/config.c:760
+#, c-format
+msgid "cannot create configuration file %s"
+msgstr "不能建立設定檔案 %s"
+
+#: builtin/config.c:773
+#, c-format
+msgid ""
+"cannot overwrite multiple values with a single value\n"
+"       Use a regexp, --add or --replace-all to change %s."
+msgstr ""
+"無法用一個值覆蓋多個值\n"
+"       使用一個正規表示式、--add 或 --replace-all 來修改 %s。"
+
+#: builtin/config.c:847 builtin/config.c:858
+#, c-format
+msgid "no such section: %s"
+msgstr "無此小節：%s"
+
+#: builtin/count-objects.c:90
+msgid "git count-objects [-v] [-H | --human-readable]"
+msgstr "git count-objects [-v] [-H | --human-readable]"
+
+#: builtin/count-objects.c:100
+msgid "print sizes in human readable format"
+msgstr "以使用者可讀的格式顯示大小"
+
+#: builtin/describe.c:26
+msgid "git describe [<options>] [<commit-ish>...]"
+msgstr "git describe [<選項>] [<提交號>...]"
+
+#: builtin/describe.c:27
+msgid "git describe [<options>] --dirty"
+msgstr "git describe [<選項>] --dirty"
+
+#: builtin/describe.c:62
+msgid "head"
+msgstr "頭"
+
+#: builtin/describe.c:62
+msgid "lightweight"
+msgstr "輕量級的"
+
+#: builtin/describe.c:62
+msgid "annotated"
+msgstr "附註的"
+
+#: builtin/describe.c:275
+#, c-format
+msgid "annotated tag %s not available"
+msgstr "附註標籤 %s 無效"
+
+#: builtin/describe.c:279
+#, c-format
+msgid "annotated tag %s has no embedded name"
+msgstr "附註標籤 %s 沒有嵌入名稱"
+
+#: builtin/describe.c:281
+#, c-format
+msgid "tag '%s' is really '%s' here"
+msgstr "標籤 '%s' 的確是在 '%s'"
+
+#: builtin/describe.c:325
+#, c-format
+msgid "no tag exactly matches '%s'"
+msgstr "沒有標籤準確符合 '%s'"
+
+#: builtin/describe.c:327
+#, c-format
+msgid "No exact match on refs or tags, searching to describe\n"
+msgstr "沒有精確符合到引用或標籤，繼續搜尋進行描述\n"
+
+#: builtin/describe.c:381
+#, c-format
+msgid "finished search at %s\n"
+msgstr "完成搜尋 %s\n"
+
+#: builtin/describe.c:407
+#, c-format
+msgid ""
+"No annotated tags can describe '%s'.\n"
+"However, there were unannotated tags: try --tags."
+msgstr ""
+"沒有附註標籤能描述 '%s'。\n"
+"然而，存在未附註標籤：嘗試 --tags。"
+
+#: builtin/describe.c:411
+#, c-format
+msgid ""
+"No tags can describe '%s'.\n"
+"Try --always, or create some tags."
+msgstr ""
+"沒有標籤能描述 '%s'。\n"
+"嘗試 --always，或者建立一些標籤。"
+
+#: builtin/describe.c:441
+#, c-format
+msgid "traversed %lu commits\n"
+msgstr "已遍歷 %lu 個提交\n"
+
+#: builtin/describe.c:444
+#, c-format
+msgid ""
+"more than %i tags found; listed %i most recent\n"
+"gave up search at %s\n"
+msgstr ""
+"發現多於 %i 個標籤，列出最近的 %i 個\n"
+"在 %s 放棄搜尋\n"
+
+#: builtin/describe.c:512
+#, c-format
+msgid "describe %s\n"
+msgstr "描述 %s\n"
+
+#: builtin/describe.c:515
+#, c-format
+msgid "Not a valid object name %s"
+msgstr "不是一個有效的物件名 %s"
+
+#: builtin/describe.c:523
+#, c-format
+msgid "%s is neither a commit nor blob"
+msgstr "%s 既不是提交也不是資料物件"
+
+#: builtin/describe.c:537
+msgid "find the tag that comes after the commit"
+msgstr "尋找該提交之後的標籤"
+
+#: builtin/describe.c:538
+msgid "debug search strategy on stderr"
+msgstr "在標準錯誤上除錯搜尋策略"
+
+#: builtin/describe.c:539
+msgid "use any ref"
+msgstr "使用任意引用"
+
+#: builtin/describe.c:540
+msgid "use any tag, even unannotated"
+msgstr "使用任意標籤，即使未附帶備註"
+
+#: builtin/describe.c:541
+msgid "always use long format"
+msgstr "始終使用長提交號格式"
+
+#: builtin/describe.c:542
+msgid "only follow first parent"
+msgstr "只跟隨第一個父提交"
+
+#: builtin/describe.c:545
+msgid "only output exact matches"
+msgstr "只輸出精確符合"
+
+#: builtin/describe.c:547
+msgid "consider <n> most recent tags (default: 10)"
+msgstr "考慮最近 <n> 個標籤（預設：10）"
+
+#: builtin/describe.c:549
+msgid "only consider tags matching <pattern>"
+msgstr "只考慮符合 <模式> 的標籤"
+
+#: builtin/describe.c:551
+msgid "do not consider tags matching <pattern>"
+msgstr "不考慮符合 <模式> 的標籤"
+
+#: builtin/describe.c:553 builtin/name-rev.c:473
+msgid "show abbreviated commit object as fallback"
+msgstr "顯示簡寫的提交號作為後備"
+
+#: builtin/describe.c:554 builtin/describe.c:557
+msgid "mark"
+msgstr "標記"
+
+#: builtin/describe.c:555
+msgid "append <mark> on dirty working tree (default: \"-dirty\")"
+msgstr "對於髒工作區，追加 <標記>（預設：\"-dirty\"）"
+
+#: builtin/describe.c:558
+msgid "append <mark> on broken working tree (default: \"-broken\")"
+msgstr "對於損壞的工作區，追加 <標記>（預設：\"-broken\"）"
+
+#: builtin/describe.c:576
+msgid "--long is incompatible with --abbrev=0"
+msgstr "--long 與 --abbrev=0 不相容"
+
+#: builtin/describe.c:605
+msgid "No names found, cannot describe anything."
+msgstr "沒有發現名稱，無法描述任何東西。"
+
+#: builtin/describe.c:656
+msgid "--dirty is incompatible with commit-ishes"
+msgstr "--dirty 與提交號不相容"
+
+#: builtin/describe.c:658
+msgid "--broken is incompatible with commit-ishes"
+msgstr "--broken 與提交號不相容"
+
+#: builtin/diff.c:84
+#, c-format
+msgid "'%s': not a regular file or symlink"
+msgstr "'%s'：不是一個正規檔案或符號連結"
+
+#: builtin/diff.c:235
+#, c-format
+msgid "invalid option: %s"
+msgstr "無效選項：%s"
+
+#: builtin/diff.c:350
+msgid "Not a git repository"
+msgstr "不是一個 git 版本庫"
+
+#: builtin/diff.c:394
+#, c-format
+msgid "invalid object '%s' given."
+msgstr "提供了無效物件 '%s'。"
+
+#: builtin/diff.c:403
+#, c-format
+msgid "more than two blobs given: '%s'"
+msgstr "提供了超過兩個資料物件：'%s'"
+
+#: builtin/diff.c:408
+#, c-format
+msgid "unhandled object '%s' given."
+msgstr "無法處理的物件 '%s'。"
+
+#: builtin/difftool.c:30
+msgid "git difftool [<options>] [<commit> [<commit>]] [--] [<path>...]"
+msgstr "git difftool [<選項>] [<提交> [<提交>]] [--] [<路徑>...]"
+
+#: builtin/difftool.c:260
+#, c-format
+msgid "failed: %d"
+msgstr "失敗：%d"
+
+#: builtin/difftool.c:302
+#, c-format
+msgid "could not read symlink %s"
+msgstr "無法讀取符號連結 %s"
+
+#: builtin/difftool.c:304
+#, c-format
+msgid "could not read symlink file %s"
+msgstr "無法讀取符號連結檔案 %s"
+
+#: builtin/difftool.c:312
+#, c-format
+msgid "could not read object %s for symlink %s"
+msgstr "無法讀取符號連結 %2$s 指向的物件 %1$s"
+
+#: builtin/difftool.c:413
+msgid ""
+"combined diff formats('-c' and '--cc') are not supported in\n"
+"directory diff mode('-d' and '--dir-diff')."
+msgstr ""
+"不支援在目錄比較模式（'-d' 和 '--dir-diff'）中採用組合差異格式（'-c' 和 '--"
+"cc'）。"
+
+#: builtin/difftool.c:634
+#, c-format
+msgid "both files modified: '%s' and '%s'."
+msgstr "兩個檔案都被修改：'%s' 和 '%s'。"
+
+#: builtin/difftool.c:636
+msgid "working tree file has been left."
+msgstr "工作區檔案被留了下來。"
+
+#: builtin/difftool.c:647
+#, c-format
+msgid "temporary files exist in '%s'."
+msgstr "暫存檔存在於 '%s'。"
+
+#: builtin/difftool.c:648
+msgid "you may want to cleanup or recover these."
+msgstr "您可能想要清理或者復原它們。"
+
+#: builtin/difftool.c:697
+msgid "use `diff.guitool` instead of `diff.tool`"
+msgstr "使用 `diff.guitool` 代替 `diff.tool`"
+
+#: builtin/difftool.c:699
+msgid "perform a full-directory diff"
+msgstr "執行一個全目錄差異比較"
+
+#: builtin/difftool.c:701
+msgid "do not prompt before launching a diff tool"
+msgstr "啟動差異比較工具之前不提示"
+
+#: builtin/difftool.c:706
+msgid "use symlinks in dir-diff mode"
+msgstr "在 dir-diff 模式中使用符號連結"
+
+#: builtin/difftool.c:707
+msgid "tool"
+msgstr "工具"
+
+#: builtin/difftool.c:708
+msgid "use the specified diff tool"
+msgstr "使用指定的差異比較工具"
+
+#: builtin/difftool.c:710
+msgid "print a list of diff tools that may be used with `--tool`"
+msgstr "顯示可以用在 `--tool` 參數後的差異工具列表"
+
+#: builtin/difftool.c:713
+msgid ""
+"make 'git-difftool' exit when an invoked diff tool returns a non - zero exit "
+"code"
+msgstr "當執行 diff 工具返回非零離開碼時，使 'git-difftool' 離開"
+
+#: builtin/difftool.c:716
+msgid "specify a custom command for viewing diffs"
+msgstr "指定一個用於檢視差異的自訂指令"
+
+#: builtin/difftool.c:717
+msgid "passed to `diff`"
+msgstr "傳遞給 `diff`"
+
+#: builtin/difftool.c:732
+msgid "difftool requires worktree or --no-index"
+msgstr "difftool 要求工作區或者 --no-index"
+
+#: builtin/difftool.c:739
+msgid "--dir-diff is incompatible with --no-index"
+msgstr "--dir-diff 和 --no-index 不相容"
+
+#: builtin/difftool.c:742
+msgid "--gui, --tool and --extcmd are mutually exclusive"
+msgstr "--gui、--tool 和 --extcmd 互斥"
+
+#: builtin/difftool.c:750
+msgid "no <tool> given for --tool=<tool>"
+msgstr "沒有為 --tool=<工具> 參數提供 <工具>"
+
+#: builtin/difftool.c:757
+msgid "no <cmd> given for --extcmd=<cmd>"
+msgstr "沒有為 --extcmd=<指令> 參數提供 <指令>"
+
+#: builtin/env--helper.c:6
+msgid "git env--helper --type=[bool|ulong] <options> <env-var>"
+msgstr "git env--helper --type=[bool|ulong] <選項> <環境變數>"
+
+#: builtin/env--helper.c:37 builtin/hash-object.c:98
+msgid "type"
+msgstr "類型"
+
+#: builtin/env--helper.c:41
+msgid "default for git_env_*(...) to fall back on"
+msgstr "git_env_*(...) 的預設值"
+
+#: builtin/env--helper.c:43
+msgid "be quiet only use git_env_*() value as exit code"
+msgstr "安靜模式，只使用 git_env_*() 的值作為離開碼"
+
+#: builtin/env--helper.c:62
+#, c-format
+msgid "option `--default' expects a boolean value with `--type=bool`, not `%s`"
+msgstr "選項 `--default' 和 `type=bool` 期望一個布林值，不是 `%s`"
+
+#: builtin/env--helper.c:77
+#, c-format
+msgid ""
+"option `--default' expects an unsigned long value with `--type=ulong`, not `"
+"%s`"
+msgstr "選項 `--default' 和 `type=ulong` 期望一個無符號長整型，不是 `%s`"
+
+#: builtin/fast-export.c:29
+msgid "git fast-export [rev-list-opts]"
+msgstr "git fast-export [rev-list-opts]"
+
+#: builtin/fast-export.c:852
+msgid "Error: Cannot export nested tags unless --mark-tags is specified."
+msgstr "錯誤：除非指定 --mark-tags，否則無法匯出嵌套標籤。"
+
+#: builtin/fast-export.c:1152
+msgid "show progress after <n> objects"
+msgstr "在 <n> 個物件之後顯示進度"
+
+#: builtin/fast-export.c:1154
+msgid "select handling of signed tags"
+msgstr "選擇如何處理簽名標籤"
+
+#: builtin/fast-export.c:1157
+msgid "select handling of tags that tag filtered objects"
+msgstr "選擇當標籤指向被過濾物件時該標籤的處理方式"
+
+#: builtin/fast-export.c:1160
+msgid "select handling of commit messages in an alternate encoding"
+msgstr "選擇使用備用編碼處理提交說明"
+
+#: builtin/fast-export.c:1163
+msgid "Dump marks to this file"
+msgstr "把標記儲存到這個檔案"
+
+#: builtin/fast-export.c:1165
+msgid "Import marks from this file"
+msgstr "從這個檔案匯入標記"
+
+#: builtin/fast-export.c:1169
+msgid "Import marks from this file if it exists"
+msgstr "從該檔案匯入標記（如果存在的話）"
+
+#: builtin/fast-export.c:1171
+msgid "Fake a tagger when tags lack one"
+msgstr "當標籤缺少標記者欄位時，假裝提供一個"
+
+#: builtin/fast-export.c:1173
+msgid "Output full tree for each commit"
+msgstr "每次提交都輸出整個樹"
+
+#: builtin/fast-export.c:1175
+msgid "Use the done feature to terminate the stream"
+msgstr "使用 done 功能來終止流"
+
+#: builtin/fast-export.c:1176
+msgid "Skip output of blob data"
+msgstr "跳過資料物件的輸出"
+
+#: builtin/fast-export.c:1177 builtin/log.c:1705
+msgid "refspec"
+msgstr "引用規格"
+
+#: builtin/fast-export.c:1178
+msgid "Apply refspec to exported refs"
+msgstr "對匯出的引用應用引用規格"
+
+#: builtin/fast-export.c:1179
+msgid "anonymize output"
+msgstr "匿名輸出"
+
+#: builtin/fast-export.c:1181
+msgid "Reference parents which are not in fast-export stream by object id"
+msgstr "引用父物件 ID 不在 fast-export 流中"
+
+#: builtin/fast-export.c:1183
+msgid "Show original object ids of blobs/commits"
+msgstr "顯示資料物件/提交的原始物件 ID"
+
+#: builtin/fast-export.c:1185
+msgid "Label tags with mark ids"
+msgstr "對帶有標記 ID 的標籤做標記"
+
+#: builtin/fast-export.c:1220
+msgid "Cannot pass both --import-marks and --import-marks-if-exists"
+msgstr "不能同時傳遞參數 --import-marks 和 --import-marks-if-exists"
+
+#: builtin/fetch.c:34
+msgid "git fetch [<options>] [<repository> [<refspec>...]]"
+msgstr "git fetch [<選項>] [<版本庫> [<引用規格>...]]"
+
+#: builtin/fetch.c:35
+msgid "git fetch [<options>] <group>"
+msgstr "git fetch [<選項>] <組>"
+
+#: builtin/fetch.c:36
+msgid "git fetch --multiple [<options>] [(<repository> | <group>)...]"
+msgstr "git fetch --multiple [<選項>] [(<版本庫> | <組>)...]"
+
+#: builtin/fetch.c:37
+msgid "git fetch --all [<options>]"
+msgstr "git fetch --all [<選項>]"
+
+#: builtin/fetch.c:116
+msgid "fetch.parallel cannot be negative"
+msgstr "fetch.parallel 不能為負數"
+
+#: builtin/fetch.c:139 builtin/pull.c:204
+msgid "fetch from all remotes"
+msgstr "從所有的遠端抓取"
+
+#: builtin/fetch.c:141 builtin/pull.c:248
+msgid "set upstream for git pull/fetch"
+msgstr "為 git pull/fetch 設定上游"
+
+#: builtin/fetch.c:143 builtin/pull.c:207
+msgid "append to .git/FETCH_HEAD instead of overwriting"
+msgstr "追加到 .git/FETCH_HEAD 而不是覆蓋它"
+
+#: builtin/fetch.c:145 builtin/pull.c:210
+msgid "path to upload pack on remote end"
+msgstr "上傳包到遠端的路徑"
+
+#: builtin/fetch.c:146
+msgid "force overwrite of local reference"
+msgstr "強制覆蓋本機引用"
+
+#: builtin/fetch.c:148
+msgid "fetch from multiple remotes"
+msgstr "從多個遠端抓取"
+
+#: builtin/fetch.c:150 builtin/pull.c:214
+msgid "fetch all tags and associated objects"
+msgstr "抓取所有的標籤和關聯物件"
+
+#: builtin/fetch.c:152
+msgid "do not fetch all tags (--no-tags)"
+msgstr "不抓取任何標籤(--no-tags)"
+
+#: builtin/fetch.c:154
+msgid "number of submodules fetched in parallel"
+msgstr "子模組取得的並發數"
+
+#: builtin/fetch.c:156 builtin/pull.c:217
+msgid "prune remote-tracking branches no longer on remote"
+msgstr "清除遠端已經不存在的分支的追蹤分支"
+
+#: builtin/fetch.c:158
+msgid "prune local tags no longer on remote and clobber changed tags"
+msgstr "清除遠端不存在的本機標籤，並且取代變更標籤"
+
+#  譯者：可選值，不能翻譯
+#: builtin/fetch.c:159 builtin/fetch.c:182 builtin/pull.c:141
+msgid "on-demand"
+msgstr "on-demand"
+
+#: builtin/fetch.c:160
+msgid "control recursive fetching of submodules"
+msgstr "控制子模組的遞迴抓取"
+
+#: builtin/fetch.c:164 builtin/pull.c:225
+msgid "keep downloaded pack"
+msgstr "保持下載包"
+
+#: builtin/fetch.c:166
+msgid "allow updating of HEAD ref"
+msgstr "允許更新 HEAD 引用"
+
+#: builtin/fetch.c:169 builtin/fetch.c:175 builtin/pull.c:228
+msgid "deepen history of shallow clone"
+msgstr "深化淺複製的歷史"
+
+#: builtin/fetch.c:171
+msgid "deepen history of shallow repository based on time"
+msgstr "基於時間來深化淺複製的歷史"
+
+#: builtin/fetch.c:177 builtin/pull.c:231
+msgid "convert to a complete repository"
+msgstr "轉換為一個完整的版本庫"
+
+#: builtin/fetch.c:180
+msgid "prepend this to submodule path output"
+msgstr "在子模組路徑輸出的前面加上此目錄"
+
+#: builtin/fetch.c:183
+msgid ""
+"default for recursive fetching of submodules (lower priority than config "
+"files)"
+msgstr "遞迴取得子模組的預設值（比設定檔案優先度低）"
+
+#: builtin/fetch.c:187 builtin/pull.c:234
+msgid "accept refs that update .git/shallow"
+msgstr "接受更新 .git/shallow 的引用"
+
+#: builtin/fetch.c:188 builtin/pull.c:236
+msgid "refmap"
+msgstr "引用映射"
+
+#: builtin/fetch.c:189 builtin/pull.c:237
+msgid "specify fetch refmap"
+msgstr "指定取得動作的引用映射"
+
+#: builtin/fetch.c:196
+msgid "report that we have only objects reachable from this object"
+msgstr "報告我們只擁有從該物件開始可以取得的物件"
+
+#: builtin/fetch.c:199
+msgid "run 'gc --auto' after fetching"
+msgstr "取得後執行 'gc --auto'"
+
+#: builtin/fetch.c:201 builtin/pull.c:246
+msgid "check for forced-updates on all updated branches"
+msgstr "在所有更新分支上檢查強制更新"
+
+#: builtin/fetch.c:203
+#, fuzzy
+#| msgid "prune remotes after fetching"
+msgid "write the commit-graph after fetching"
+msgstr "抓取後清除遠端"
+
+#: builtin/fetch.c:513
+msgid "Couldn't find remote ref HEAD"
+msgstr "無法發現遠端 HEAD 引用"
+
+#: builtin/fetch.c:653
+#, c-format
+msgid "configuration fetch.output contains invalid value %s"
+msgstr "設定變數 fetch.output 包含無效值 %s"
+
+#: builtin/fetch.c:751
+#, c-format
+msgid "object %s not found"
+msgstr "物件 %s 未發現"
+
+#: builtin/fetch.c:755
+msgid "[up to date]"
+msgstr "[最新]"
+
+#: builtin/fetch.c:768 builtin/fetch.c:784 builtin/fetch.c:856
+msgid "[rejected]"
+msgstr "[已拒絕]"
+
+#: builtin/fetch.c:769
+msgid "can't fetch in current branch"
+msgstr "目前分支下不能執行取得動作"
+
+#: builtin/fetch.c:779
+msgid "[tag update]"
+msgstr "[標籤更新]"
+
+#: builtin/fetch.c:780 builtin/fetch.c:817 builtin/fetch.c:839
+#: builtin/fetch.c:851
+msgid "unable to update local ref"
+msgstr "不能更新本機引用"
+
+#: builtin/fetch.c:784
+msgid "would clobber existing tag"
+msgstr "會破壞現有的標籤"
+
+#: builtin/fetch.c:806
+msgid "[new tag]"
+msgstr "[新標籤]"
+
+#: builtin/fetch.c:809
+msgid "[new branch]"
+msgstr "[新分支]"
+
+#: builtin/fetch.c:812
+msgid "[new ref]"
+msgstr "[新引用]"
+
+#: builtin/fetch.c:851
+msgid "forced update"
+msgstr "強制更新"
+
+#: builtin/fetch.c:856
+msgid "non-fast-forward"
+msgstr "非快轉"
+
+#: builtin/fetch.c:877
+msgid ""
+"Fetch normally indicates which branches had a forced update,\n"
+"but that check has been disabled. To re-enable, use '--show-forced-updates'\n"
+"flag or run 'git config fetch.showForcedUpdates true'."
+msgstr ""
+"取得動作通常顯示哪些分支發生了強制更新，但該檢查已被禁用。\n"
+"要重新啟用，請使用 '--show-forced-updates' 選項或執行\n"
+"'git config fetch.showForcedUpdates true'。"
+
+#: builtin/fetch.c:881
+#, c-format
+msgid ""
+"It took %.2f seconds to check forced updates. You can use\n"
+"'--no-show-forced-updates' or run 'git config fetch.showForcedUpdates "
+"false'\n"
+" to avoid this check.\n"
+msgstr ""
+"花了 %.2f 秒來檢查強制更新。您可以使用 '--no-show-forced-updates'\n"
+"或執行 'git config fetch.showForcedUpdates false' 以避免此項檢查。\n"
+
+#: builtin/fetch.c:911
+#, c-format
+msgid "%s did not send all necessary objects\n"
+msgstr "%s 未傳送所有必需的物件\n"
+
+#: builtin/fetch.c:932
+#, c-format
+msgid "reject %s because shallow roots are not allowed to be updated"
+msgstr "拒絕 %s 因為淺複製不允許被更新"
+
+#: builtin/fetch.c:1017 builtin/fetch.c:1155
+#, c-format
+msgid "From %.*s\n"
+msgstr "來自 %.*s\n"
+
+#: builtin/fetch.c:1028
+#, c-format
+msgid ""
+"some local refs could not be updated; try running\n"
+" 'git remote prune %s' to remove any old, conflicting branches"
+msgstr ""
+"一些本機引用不能被更新；嘗試執行\n"
+" 'git remote prune %s' 來刪除舊的、有衝突的分支"
+
+#  譯者：請維持前導空格
+#: builtin/fetch.c:1125
+#, c-format
+msgid "   (%s will become dangling)"
+msgstr "   （%s 將成為懸空狀態）"
+
+#  譯者：請維持前導空格
+#: builtin/fetch.c:1126
+#, c-format
+msgid "   (%s has become dangling)"
+msgstr "   （%s 已成為懸空狀態）"
+
+#: builtin/fetch.c:1158
+msgid "[deleted]"
+msgstr "[已刪除]"
+
+#: builtin/fetch.c:1159 builtin/remote.c:1035
+msgid "(none)"
+msgstr "（無）"
+
+#: builtin/fetch.c:1182
+#, c-format
+msgid "Refusing to fetch into current branch %s of non-bare repository"
+msgstr "拒絕取得到非純版本庫的目前分支 %s"
+
+#: builtin/fetch.c:1201
+#, c-format
+msgid "Option \"%s\" value \"%s\" is not valid for %s"
+msgstr "選項 \"%s\" 的值 \"%s\" 對於 %s 是無效的"
+
+#: builtin/fetch.c:1204
+#, c-format
+msgid "Option \"%s\" is ignored for %s\n"
+msgstr "選項 \"%s\" 為 %s 所忽略\n"
+
+#: builtin/fetch.c:1412
+#| msgid "multiple branch detected, incompatible with --set-upstream"
+msgid "multiple branches detected, incompatible with --set-upstream"
+msgstr "檢測到多分支，和 --set-upstream 不相容"
+
+#: builtin/fetch.c:1427
+msgid "not setting upstream for a remote remote-tracking branch"
+msgstr "沒有為一個遠端追蹤分支設定上游"
+
+#: builtin/fetch.c:1429
+msgid "not setting upstream for a remote tag"
+msgstr "沒有為一個遠端標籤設定上游"
+
+#: builtin/fetch.c:1431
+msgid "unknown branch type"
+msgstr "未知的分支類型"
+
+#: builtin/fetch.c:1433
+msgid ""
+"no source branch found.\n"
+"you need to specify exactly one branch with the --set-upstream option."
+msgstr ""
+"未發現源分支。\n"
+"您需要使用 --set-upstream 選項指定一個分支。"
+
+#: builtin/fetch.c:1559 builtin/fetch.c:1622
+#, c-format
+msgid "Fetching %s\n"
+msgstr "正在取得 %s\n"
+
+#: builtin/fetch.c:1569 builtin/fetch.c:1624 builtin/remote.c:100
+#, c-format
+msgid "Could not fetch %s"
+msgstr "不能取得 %s"
+
+#: builtin/fetch.c:1581
+#, c-format
+msgid "could not fetch '%s' (exit code: %d)\n"
+msgstr "無法取得 '%s'（離開碼：%d）\n"
+
+#: builtin/fetch.c:1684
+msgid ""
+"No remote repository specified.  Please, specify either a URL or a\n"
+"remote name from which new revisions should be fetched."
+msgstr "未指定遠端版本庫。請透過一個 URL 或遠端版本庫名指定，用以取得新提交。"
+
+#: builtin/fetch.c:1721
+msgid "You need to specify a tag name."
+msgstr "您需要指定一個標籤名稱。"
+
+#: builtin/fetch.c:1771
+msgid "Negative depth in --deepen is not supported"
+msgstr "--deepen 不支援負數深度"
+
+#: builtin/fetch.c:1773
+msgid "--deepen and --depth are mutually exclusive"
+msgstr "--deepen 和 --depth 是互斥的"
+
+#: builtin/fetch.c:1778
+msgid "--depth and --unshallow cannot be used together"
+msgstr "--depth 和 --unshallow 不能同時使用"
+
+#: builtin/fetch.c:1780
+msgid "--unshallow on a complete repository does not make sense"
+msgstr "對於一個完整的版本庫，參數 --unshallow 沒有意義"
+
+#: builtin/fetch.c:1796
+msgid "fetch --all does not take a repository argument"
+msgstr "fetch --all 不能帶一個版本庫參數"
+
+#: builtin/fetch.c:1798
+msgid "fetch --all does not make sense with refspecs"
+msgstr "fetch --all 帶引用規格沒有任何意義"
+
+#: builtin/fetch.c:1807
+#, c-format
+msgid "No such remote or remote group: %s"
+msgstr "沒有這樣的遠端或遠端組：%s"
+
+#: builtin/fetch.c:1814
+msgid "Fetching a group and specifying refspecs does not make sense"
+msgstr "取得組並指定引用規格沒有意義"
+
+#: builtin/fetch.c:1832
+msgid ""
+"--filter can only be used with the remote configured in extensions."
+"partialclone"
+msgstr "只可以將 --filter 用於在 extensions.partialClone 中設定的遠端版本庫"
+
+#: builtin/fmt-merge-msg.c:18
+msgid ""
+"git fmt-merge-msg [-m <message>] [--log[=<n>] | --no-log] [--file <file>]"
+msgstr "git fmt-merge-msg [-m <說明>] [--log[=<n>] | --no-log] [--file <檔案>]"
+
+#: builtin/fmt-merge-msg.c:674
+msgid "populate log with at most <n> entries from shortlog"
+msgstr "向提交說明中最多複製指定條目（合併而來的提交）的簡短說明"
+
+#: builtin/fmt-merge-msg.c:677
+msgid "alias for --log (deprecated)"
+msgstr "參數 --log 的別名（已棄用）"
+
+#: builtin/fmt-merge-msg.c:680
+msgid "text"
+msgstr "文字"
+
+#: builtin/fmt-merge-msg.c:681
+msgid "use <text> as start of message"
+msgstr "使用 <文字> 作為提交說明的開始"
+
+#: builtin/fmt-merge-msg.c:682
+msgid "file to read from"
+msgstr "從檔案中讀取"
+
+#: builtin/for-each-ref.c:10
+msgid "git for-each-ref [<options>] [<pattern>]"
+msgstr "git for-each-ref [<選項>] [<模式>]"
+
+#: builtin/for-each-ref.c:11
+msgid "git for-each-ref [--points-at <object>]"
+msgstr "git for-each-ref [--points-at <物件>]"
+
+#: builtin/for-each-ref.c:12
+msgid "git for-each-ref [(--merged | --no-merged) [<commit>]]"
+msgstr "git for-each-ref [(--merged | --no-merged) [<提交>]]"
+
+#: builtin/for-each-ref.c:13
+msgid "git for-each-ref [--contains [<commit>]] [--no-contains [<commit>]]"
+msgstr "git for-each-ref [--contains [<提交>]] [--no-contains [<提交>]]"
+
+#: builtin/for-each-ref.c:28
+msgid "quote placeholders suitably for shells"
+msgstr "引用占位符適用於 shells"
+
+#: builtin/for-each-ref.c:30
+msgid "quote placeholders suitably for perl"
+msgstr "引用占位符適用於 perl"
+
+#: builtin/for-each-ref.c:32
+msgid "quote placeholders suitably for python"
+msgstr "引用占位符適用於 python"
+
+#: builtin/for-each-ref.c:34
+msgid "quote placeholders suitably for Tcl"
+msgstr "引用占位符適用於 Tcl"
+
+#: builtin/for-each-ref.c:37
+msgid "show only <n> matched refs"
+msgstr "只顯示 <n> 個符合的引用"
+
+#: builtin/for-each-ref.c:39 builtin/tag.c:439
+msgid "respect format colors"
+msgstr "遵照格式中的顏色輸出"
+
+#: builtin/for-each-ref.c:42
+msgid "print only refs which points at the given object"
+msgstr "只列印指向提供物件的引用"
+
+#: builtin/for-each-ref.c:44
+msgid "print only refs that are merged"
+msgstr "只列印已經合併的引用"
+
+#: builtin/for-each-ref.c:45
+msgid "print only refs that are not merged"
+msgstr "只列印沒有合併的引用"
+
+#: builtin/for-each-ref.c:46
+msgid "print only refs which contain the commit"
+msgstr "只列印包含該提交的引用"
+
+#: builtin/for-each-ref.c:47
+msgid "print only refs which don't contain the commit"
+msgstr "只列印不包含該提交的引用"
+
+#: builtin/fsck.c:68 builtin/fsck.c:147 builtin/fsck.c:148
+msgid "unknown"
+msgstr "未知"
+
+#. TRANSLATORS: e.g. error in tree 01bfda: <more explanation>
+#: builtin/fsck.c:100 builtin/fsck.c:120
+#, c-format
+msgid "error in %s %s: %s"
+msgstr "%s %s 錯誤：%s"
+
+#. TRANSLATORS: e.g. warning in tree 01bfda: <more explanation>
+#: builtin/fsck.c:114
+#, c-format
+msgid "warning in %s %s: %s"
+msgstr "%s %s 警告：%s"
+
+#: builtin/fsck.c:143 builtin/fsck.c:146
+#, c-format
+msgid "broken link from %7s %s"
+msgstr "來自 %7s %s 的損壞的連結"
+
+#: builtin/fsck.c:155
+msgid "wrong object type in link"
+msgstr "連結中錯誤的物件類型"
+
+#: builtin/fsck.c:171
+#, c-format
+msgid ""
+"broken link from %7s %s\n"
+"              to %7s %s"
+msgstr ""
+"損壞的連結來自於 %7s %s\n"
+"              到 %7s %s"
+
+#: builtin/fsck.c:282
+#, c-format
+msgid "missing %s %s"
+msgstr "缺少 %s %s"
+
+#: builtin/fsck.c:309
+#, c-format
+msgid "unreachable %s %s"
+msgstr "無法取得 %s %s"
+
+#: builtin/fsck.c:329
+#, c-format
+msgid "dangling %s %s"
+msgstr "懸空 %s %s"
+
+#: builtin/fsck.c:339
+msgid "could not create lost-found"
+msgstr "不能建立 lost-found"
+
+#: builtin/fsck.c:350
+#, c-format
+msgid "could not finish '%s'"
+msgstr "不能完成 '%s'"
+
+#: builtin/fsck.c:367
+#, c-format
+msgid "Checking %s"
+msgstr "正在檢查 %s"
+
+#: builtin/fsck.c:405
+#, c-format
+msgid "Checking connectivity (%d objects)"
+msgstr "正在檢查連通性（%d 個物件）"
+
+#: builtin/fsck.c:424
+#, c-format
+msgid "Checking %s %s"
+msgstr "正在檢查 %s %s"
+
+#: builtin/fsck.c:429
+msgid "broken links"
+msgstr "損壞的連結"
+
+#: builtin/fsck.c:438
+#, c-format
+msgid "root %s"
+msgstr "根 %s"
+
+#: builtin/fsck.c:446
+#, c-format
+msgid "tagged %s %s (%s) in %s"
+msgstr "標記 %s %s (%s) 於 %s"
+
+#: builtin/fsck.c:475
+#, c-format
+msgid "%s: object corrupt or missing"
+msgstr "%s：物件損壞或遺失"
+
+#: builtin/fsck.c:500
+#, c-format
+msgid "%s: invalid reflog entry %s"
+msgstr "%s：無效的引用日誌條目 %s"
+
+#: builtin/fsck.c:514
+#, c-format
+msgid "Checking reflog %s->%s"
+msgstr "正在檢查引用日誌 %s->%s"
+
+#: builtin/fsck.c:548
+#, c-format
+msgid "%s: invalid sha1 pointer %s"
+msgstr "%s：無效的 sha1 指標 %s"
+
+#: builtin/fsck.c:555
+#, c-format
+msgid "%s: not a commit"
+msgstr "%s：不是一個提交"
+
+#: builtin/fsck.c:609
+msgid "notice: No default references"
+msgstr "注意：無預設引用"
+
+#: builtin/fsck.c:624
+#, c-format
+msgid "%s: object corrupt or missing: %s"
+msgstr "%s：物件損壞或遺失：%s"
+
+#: builtin/fsck.c:637
+#, c-format
+msgid "%s: object could not be parsed: %s"
+msgstr "%s：不能解析物件：%s"
+
+#: builtin/fsck.c:657
+#, c-format
+msgid "bad sha1 file: %s"
+msgstr "壞的 sha1 檔案：%s"
+
+#: builtin/fsck.c:672
+msgid "Checking object directory"
+msgstr "正在檢查物件目錄"
+
+#: builtin/fsck.c:675
+msgid "Checking object directories"
+msgstr "正在檢查物件目錄"
+
+#: builtin/fsck.c:690
+#, c-format
+msgid "Checking %s link"
+msgstr "正在檢查 %s 連結"
+
+#: builtin/fsck.c:695 builtin/index-pack.c:842
+#, c-format
+msgid "invalid %s"
+msgstr "無效的 %s"
+
+#: builtin/fsck.c:702
+#, c-format
+msgid "%s points to something strange (%s)"
+msgstr "%s 指向奇怪的東西（%s）"
+
+#: builtin/fsck.c:708
+#, c-format
+msgid "%s: detached HEAD points at nothing"
+msgstr "%s：分離開頭指標的指向不存在"
+
+#: builtin/fsck.c:712
+#, c-format
+msgid "notice: %s points to an unborn branch (%s)"
+msgstr "注意：%s 指向一個尚未誕生的分支（%s）"
+
+#: builtin/fsck.c:724
+msgid "Checking cache tree"
+msgstr "正在檢查快取樹"
+
+#: builtin/fsck.c:729
+#, c-format
+msgid "%s: invalid sha1 pointer in cache-tree"
+msgstr "%s：cache-tree 中無效的 sha1 指標"
+
+#: builtin/fsck.c:738
+msgid "non-tree in cache-tree"
+msgstr "cache-tree 中非樹狀物件"
+
+#: builtin/fsck.c:769
+msgid "git fsck [<options>] [<object>...]"
+msgstr "git fsck [<選項>] [<物件>...]"
+
+#: builtin/fsck.c:775
+msgid "show unreachable objects"
+msgstr "顯示無法取得的物件"
+
+#: builtin/fsck.c:776
+msgid "show dangling objects"
+msgstr "顯示懸空的物件"
+
+#: builtin/fsck.c:777
+msgid "report tags"
+msgstr "報告標籤"
+
+#: builtin/fsck.c:778
+msgid "report root nodes"
+msgstr "報告根節點"
+
+#: builtin/fsck.c:779
+msgid "make index objects head nodes"
+msgstr "將索引亦作為檢查的頭節點"
+
+#: builtin/fsck.c:780
+msgid "make reflogs head nodes (default)"
+msgstr "將引用日誌作為檢查的頭節點（預設）"
+
+#: builtin/fsck.c:781
+msgid "also consider packs and alternate objects"
+msgstr "也考慮包和備用物件"
+
+#: builtin/fsck.c:782
+msgid "check only connectivity"
+msgstr "僅檢查連通性"
+
+#: builtin/fsck.c:783
+msgid "enable more strict checking"
+msgstr "啟用更嚴格的檢查"
+
+#: builtin/fsck.c:785
+msgid "write dangling objects in .git/lost-found"
+msgstr "將懸空物件寫入 .git/lost-found 中"
+
+#: builtin/fsck.c:786 builtin/prune.c:132
+msgid "show progress"
+msgstr "顯示進度"
+
+#: builtin/fsck.c:787
+msgid "show verbose names for reachable objects"
+msgstr "顯示可以取得物件的詳細名稱"
+
+#: builtin/fsck.c:846 builtin/index-pack.c:225
+msgid "Checking objects"
+msgstr "正在檢查物件"
+
+#: builtin/fsck.c:874
+#, c-format
+msgid "%s: object missing"
+msgstr "%s：物件缺少"
+
+#: builtin/fsck.c:885
+#, c-format
+msgid "invalid parameter: expected sha1, got '%s'"
+msgstr "無效的參數：期望 sha1，得到 '%s'"
+
+#: builtin/gc.c:35
+msgid "git gc [<options>]"
+msgstr "git gc [<選項>]"
+
+#: builtin/gc.c:90
+#, c-format
+msgid "Failed to fstat %s: %s"
+msgstr "對 %s 呼叫 fstat 失敗：%s"
+
+#: builtin/gc.c:126
+#, c-format
+msgid "failed to parse '%s' value '%s'"
+msgstr "無法解析 '%s' 值 '%s'"
+
+#: builtin/gc.c:475 builtin/init-db.c:55
+#, c-format
+msgid "cannot stat '%s'"
+msgstr "不能對 '%s' 呼叫 stat"
+
+#: builtin/gc.c:484 builtin/notes.c:240 builtin/tag.c:529
+#, c-format
+msgid "cannot read '%s'"
+msgstr "不能讀取 '%s'"
+
+#: builtin/gc.c:491
+#, c-format
+msgid ""
+"The last gc run reported the following. Please correct the root cause\n"
+"and remove %s.\n"
+"Automatic cleanup will not be performed until the file is removed.\n"
+"\n"
+"%s"
+msgstr ""
+"最後一次 gc 動作報告如下訊息。請檢查原因並刪除 %s。\n"
+"在該檔案被刪除之前，自動清理將不會執行。\n"
+"\n"
+"%s"
+
+#: builtin/gc.c:539
+msgid "prune unreferenced objects"
+msgstr "清除未引用的物件"
+
+#: builtin/gc.c:541
+msgid "be more thorough (increased runtime)"
+msgstr "更徹底（增加執行時間）"
+
+#: builtin/gc.c:542
+msgid "enable auto-gc mode"
+msgstr "啟用自動垃圾回收模式"
+
+#: builtin/gc.c:545
+msgid "force running gc even if there may be another gc running"
+msgstr "強制執行 gc 即使另外一個 gc 正在執行"
+
+#: builtin/gc.c:548
+msgid "repack all other packs except the largest pack"
+msgstr "除了最大的包之外，對所有其它包檔案重新打包"
+
+#: builtin/gc.c:565
+#, c-format
+msgid "failed to parse gc.logexpiry value %s"
+msgstr "解析 gc.logexpiry 的值 %s 失敗"
+
+#: builtin/gc.c:576
+#, c-format
+msgid "failed to parse prune expiry value %s"
+msgstr "解析清除期限值 %s 失敗"
+
+#: builtin/gc.c:596
+#, c-format
+msgid "Auto packing the repository in background for optimum performance.\n"
+msgstr "自動在後台執行版本庫打包以求最佳性能。\n"
+
+#: builtin/gc.c:598
+#, c-format
+msgid "Auto packing the repository for optimum performance.\n"
+msgstr "自動打包版本庫以求最佳性能。\n"
+
+#: builtin/gc.c:599
+#, c-format
+msgid "See \"git help gc\" for manual housekeeping.\n"
+msgstr "手動維護參見 \"git help gc\"。\n"
+
+#: builtin/gc.c:639
+#, c-format
+msgid ""
+"gc is already running on machine '%s' pid %<PRIuMAX> (use --force if not)"
+msgstr "gc 已在「%s」機器 pid %<PRIuMAX> 執行（如果不是，使用 --force）"
+
+#: builtin/gc.c:694
+msgid ""
+"There are too many unreachable loose objects; run 'git prune' to remove them."
+msgstr "有太多無法取得的鬆散物件，執行 'git prune' 刪除它們。"
+
+#: builtin/grep.c:29
+msgid "git grep [<options>] [-e] <pattern> [<rev>...] [[--] <path>...]"
+msgstr "git grep [<選項>] [-e] <模式> [<版本>...] [[--] <路徑>...]"
+
+#: builtin/grep.c:225
+#, c-format
+msgid "grep: failed to create thread: %s"
+msgstr "grep：無法建立執行緒：%s"
+
+#: builtin/grep.c:279
+#, c-format
+msgid "invalid number of threads specified (%d) for %s"
+msgstr "為 %2$s 設定的執行緒數 (%1$d) 無效"
+
+#. TRANSLATORS: %s is the configuration
+#. variable for tweaking threads, currently
+#. grep.threads
+#.
+#: builtin/grep.c:287 builtin/index-pack.c:1534 builtin/index-pack.c:1727
+#: builtin/pack-objects.c:2708
+#, c-format
+msgid "no threads support, ignoring %s"
+msgstr "沒有執行緒支援，忽略 %s"
+
+#: builtin/grep.c:467 builtin/grep.c:592 builtin/grep.c:635
+#, c-format
+msgid "unable to read tree (%s)"
+msgstr "無法讀取樹（%s）"
+
+#: builtin/grep.c:650
+#, c-format
+msgid "unable to grep from object of type %s"
+msgstr "無法抓取來自於 %s 類型的物件"
+
+#: builtin/grep.c:716
+#, c-format
+msgid "switch `%c' expects a numerical value"
+msgstr "開關 `%c' 期望一個數字值"
+
+#: builtin/grep.c:815
+msgid "search in index instead of in the work tree"
+msgstr "在索引區搜尋而不是在工作區"
+
+#: builtin/grep.c:817
+msgid "find in contents not managed by git"
+msgstr "在未被 git 管理的內容中尋找"
+
+#  譯者：中文字串拼接，可刪除前導空格
+#: builtin/grep.c:819
+msgid "search in both tracked and untracked files"
+msgstr "在追蹤和未追蹤的檔案中搜尋"
+
+#: builtin/grep.c:821
+msgid "ignore files specified via '.gitignore'"
+msgstr "忽略 '.gitignore' 包含的檔案"
+
+#: builtin/grep.c:823
+msgid "recursively search in each submodule"
+msgstr "在每一個子模組中遞迴搜尋"
+
+#: builtin/grep.c:826
+msgid "show non-matching lines"
+msgstr "顯示未符合的行"
+
+#: builtin/grep.c:828
+msgid "case insensitive matching"
+msgstr "不區分大小寫符合"
+
+#: builtin/grep.c:830
+msgid "match patterns only at word boundaries"
+msgstr "只在單詞邊界符合模式"
+
+#: builtin/grep.c:832
+msgid "process binary files as text"
+msgstr "把二進位檔案當做文字處理"
+
+#: builtin/grep.c:834
+msgid "don't match patterns in binary files"
+msgstr "不在二進位檔案中符合模式"
+
+#: builtin/grep.c:837
+msgid "process binary files with textconv filters"
+msgstr "用 textconv 過濾器處理二進位檔案"
+
+#: builtin/grep.c:839
+msgid "search in subdirectories (default)"
+msgstr "在子目錄中尋找（預設）"
+
+#: builtin/grep.c:841
+msgid "descend at most <depth> levels"
+msgstr "最多以指定的深度向下尋找"
+
+#: builtin/grep.c:845
+msgid "use extended POSIX regular expressions"
+msgstr "使用擴展的 POSIX 正規表示式"
+
+#: builtin/grep.c:848
+msgid "use basic POSIX regular expressions (default)"
+msgstr "使用基本的 POSIX 正規表示式（預設）"
+
+#: builtin/grep.c:851
+msgid "interpret patterns as fixed strings"
+msgstr "把模式解析為固定的字串"
+
+#: builtin/grep.c:854
+msgid "use Perl-compatible regular expressions"
+msgstr "使用 Perl 相容的正規表示式"
+
+#: builtin/grep.c:857
+msgid "show line numbers"
+msgstr "顯示行號"
+
+#: builtin/grep.c:858
+msgid "show column number of first match"
+msgstr "顯示第一個符合的列號"
+
+#: builtin/grep.c:859
+msgid "don't show filenames"
+msgstr "不顯示檔案名"
+
+#: builtin/grep.c:860
+msgid "show filenames"
+msgstr "顯示檔案名"
+
+#: builtin/grep.c:862
+msgid "show filenames relative to top directory"
+msgstr "顯示相對於頂級目錄的檔案名"
+
+#: builtin/grep.c:864
+msgid "show only filenames instead of matching lines"
+msgstr "只顯示檔案名而不顯示符合的行"
+
+#: builtin/grep.c:866
+msgid "synonym for --files-with-matches"
+msgstr "和 --files-with-matches 同義"
+
+#: builtin/grep.c:869
+msgid "show only the names of files without match"
+msgstr "只顯示未符合的檔案名"
+
+#: builtin/grep.c:871
+msgid "print NUL after filenames"
+msgstr "在檔案名後輸出 NUL 字元"
+
+#: builtin/grep.c:874
+msgid "show only matching parts of a line"
+msgstr "只顯示行中的符合的部分"
+
+#: builtin/grep.c:876
+msgid "show the number of matches instead of matching lines"
+msgstr "顯示總符合行數，而不顯示符合的行"
+
+#: builtin/grep.c:877
+msgid "highlight matches"
+msgstr "高亮顯示符合項"
+
+#: builtin/grep.c:879
+msgid "print empty line between matches from different files"
+msgstr "在不同檔案的符合項之間列印空行"
+
+#: builtin/grep.c:881
+msgid "show filename only once above matches from same file"
+msgstr "只在同一檔案的符合項的上面顯示一次檔案名"
+
+#: builtin/grep.c:884
+msgid "show <n> context lines before and after matches"
+msgstr "顯示符合項前後的 <n> 行上下文"
+
+#: builtin/grep.c:887
+msgid "show <n> context lines before matches"
+msgstr "顯示符合項前 <n> 行上下文"
+
+#: builtin/grep.c:889
+msgid "show <n> context lines after matches"
+msgstr "顯示符合項後 <n> 行上下文"
+
+#: builtin/grep.c:891
+msgid "use <n> worker threads"
+msgstr "使用 <n> 個工作執行緒"
+
+#: builtin/grep.c:892
+msgid "shortcut for -C NUM"
+msgstr "快捷鍵 -C 數字"
+
+#: builtin/grep.c:895
+msgid "show a line with the function name before matches"
+msgstr "在符合的前面顯示一行函數名"
+
+#: builtin/grep.c:897
+msgid "show the surrounding function"
+msgstr "顯示所在函數的前後內容"
+
+#: builtin/grep.c:900
+msgid "read patterns from file"
+msgstr "從檔案讀取模式"
+
+#: builtin/grep.c:902
+msgid "match <pattern>"
+msgstr "符合 <模式>"
+
+#: builtin/grep.c:904
+msgid "combine patterns specified with -e"
+msgstr "組合用 -e 參數設定的模式"
+
+#: builtin/grep.c:916
+msgid "indicate hit with exit status without output"
+msgstr "不輸出，而用離開碼標記命中狀態"
+
+#: builtin/grep.c:918
+msgid "show only matches from files that match all patterns"
+msgstr "只顯示符合所有模式的檔案中的符合"
+
+#: builtin/grep.c:920
+msgid "show parse tree for grep expression"
+msgstr "顯示 grep 表達式的解析樹"
+
+#: builtin/grep.c:924
+msgid "pager"
+msgstr "分頁"
+
+#: builtin/grep.c:924
+msgid "show matching files in the pager"
+msgstr "分頁顯示符合的檔案"
+
+#: builtin/grep.c:928
+msgid "allow calling of grep(1) (ignored by this build)"
+msgstr "允許呼叫 grep(1)（本次構建忽略）"
+
+#: builtin/grep.c:992
+msgid "no pattern given"
+msgstr "未提供符合模式"
+
+#: builtin/grep.c:1028
+msgid "--no-index or --untracked cannot be used with revs"
+msgstr "--no-index 或 --untracked 不能和版本同時使用"
+
+#: builtin/grep.c:1036
+#, c-format
+msgid "unable to resolve revision: %s"
+msgstr "不能解析版本：%s"
+
+#: builtin/grep.c:1067
+msgid "invalid option combination, ignoring --threads"
+msgstr "無效的選項組合，忽略 --threads"
+
+#: builtin/grep.c:1070 builtin/pack-objects.c:3400
+msgid "no threads support, ignoring --threads"
+msgstr "沒有執行緒支援，忽略 --threads"
+
+#: builtin/grep.c:1073 builtin/index-pack.c:1531 builtin/pack-objects.c:2705
+#, c-format
+msgid "invalid number of threads specified (%d)"
+msgstr "指定的執行緒數無效（%d）"
+
+#: builtin/grep.c:1096
+msgid "--open-files-in-pager only works on the worktree"
+msgstr "--open-files-in-pager 僅用於工作區"
+
+#: builtin/grep.c:1119
+msgid "option not supported with --recurse-submodules"
+msgstr "選項不支援和 --recurse-submodules 共用"
+
+#: builtin/grep.c:1125
+msgid "--cached or --untracked cannot be used with --no-index"
+msgstr "--cached 或 --untracked 不能與 --no-index 同時使用"
+
+#: builtin/grep.c:1131
+msgid "--[no-]exclude-standard cannot be used for tracked contents"
+msgstr "--[no-]exclude-standard 不能用於已追蹤內容"
+
+#: builtin/grep.c:1139
+msgid "both --cached and trees are given"
+msgstr "同時給出了 --cached 和樹狀物件"
+
+#: builtin/hash-object.c:85
+msgid ""
+"git hash-object [-t <type>] [-w] [--path=<file> | --no-filters] [--stdin] "
+"[--] <file>..."
+msgstr ""
+"git hash-object [-t <類型>] [-w] [--path=<檔案> | --no-filters] [--stdin] "
+"[--] <檔案>..."
+
+#: builtin/hash-object.c:86
+msgid "git hash-object  --stdin-paths"
+msgstr "git hash-object  --stdin-paths"
+
+#: builtin/hash-object.c:98
+msgid "object type"
+msgstr "物件類型"
+
+#: builtin/hash-object.c:99
+msgid "write the object into the object database"
+msgstr "將物件寫入物件資料庫"
+
+#: builtin/hash-object.c:101
+msgid "read the object from stdin"
+msgstr "從標準輸入讀取物件"
+
+#: builtin/hash-object.c:103
+msgid "store file as is without filters"
+msgstr "原樣儲存檔案不使用過濾器"
+
+#: builtin/hash-object.c:104
+msgid ""
+"just hash any random garbage to create corrupt objects for debugging Git"
+msgstr "允許對任意隨機垃圾資料做散列來建立損壞的物件以便除錯 Git"
+
+#: builtin/hash-object.c:105
+msgid "process file as it were from this path"
+msgstr "處理檔案並假設其來自於此路徑"
+
+#: builtin/help.c:46
+msgid "print all available commands"
+msgstr "列印所有可用的指令"
+
+#: builtin/help.c:47
+msgid "exclude guides"
+msgstr "排除嚮導"
+
+#: builtin/help.c:48
+msgid "print list of useful guides"
+msgstr "顯示有用的指南列表"
+
+#: builtin/help.c:49
+msgid "print all configuration variable names"
+msgstr "列印所有設定變數名稱"
+
+#: builtin/help.c:51
+msgid "show man page"
+msgstr "顯示 man 手冊"
+
+#: builtin/help.c:52
+msgid "show manual in web browser"
+msgstr "在 web 瀏覽器中顯示手冊"
+
+#: builtin/help.c:54
+msgid "show info page"
+msgstr "顯示 info 手冊"
+
+#: builtin/help.c:56
+msgid "print command description"
+msgstr "列印指令描述"
+
+#: builtin/help.c:61
+msgid "git help [--all] [--guides] [--man | --web | --info] [<command>]"
+msgstr "git help [--all] [--guides] [--man | --web | --info] [<指令>]"
+
+#: builtin/help.c:77
+#, c-format
+msgid "unrecognized help format '%s'"
+msgstr "未能識別的協助格式 '%s'"
+
+#: builtin/help.c:104
+msgid "Failed to start emacsclient."
+msgstr "無法啟動 emacsclient。"
+
+#: builtin/help.c:117
+msgid "Failed to parse emacsclient version."
+msgstr "無法解析 emacsclient 版本。"
+
+#: builtin/help.c:125
+#, c-format
+msgid "emacsclient version '%d' too old (< 22)."
+msgstr "emacsclient 版本 '%d' 太老（< 22）。"
+
+#: builtin/help.c:143 builtin/help.c:165 builtin/help.c:175 builtin/help.c:183
+#, c-format
+msgid "failed to exec '%s'"
+msgstr "執行 '%s' 失敗"
+
+#: builtin/help.c:221
+#, c-format
+msgid ""
+"'%s': path for unsupported man viewer.\n"
+"Please consider using 'man.<tool>.cmd' instead."
+msgstr ""
+"'%s'：不支援的 man 手冊檢視器的路徑。\n"
+"請使用 'man.<工具>.cmd'。"
+
+#: builtin/help.c:233
+#, c-format
+msgid ""
+"'%s': cmd for supported man viewer.\n"
+"Please consider using 'man.<tool>.path' instead."
+msgstr ""
+"'%s': 支援的 man 手冊檢視器指令。\n"
+"請使用 'man.<工具>.path'。"
+
+#: builtin/help.c:350
+#, c-format
+msgid "'%s': unknown man viewer."
+msgstr "'%s'：未知的 man 檢視器。"
+
+#: builtin/help.c:367
+msgid "no man viewer handled the request"
+msgstr "沒有 man 檢視器處理此請求"
+
+#: builtin/help.c:375
+msgid "no info viewer handled the request"
+msgstr "沒有 info 檢視器處理此請求"
+
+#: builtin/help.c:434 builtin/help.c:445 git.c:336
+#, c-format
+msgid "'%s' is aliased to '%s'"
+msgstr "'%s' 是 '%s' 的別名"
+
+#: builtin/help.c:448 git.c:365
+#, c-format
+msgid "bad alias.%s string: %s"
+msgstr "壞的 alias.%s 字串：%s"
+
+#: builtin/help.c:477 builtin/help.c:507
+#, c-format
+msgid "usage: %s%s"
+msgstr "用法：%s%s"
+
+#: builtin/help.c:491
+msgid "'git help config' for more information"
+msgstr "'git help config' 取得更多訊息"
+
+#: builtin/index-pack.c:185
+#, c-format
+msgid "object type mismatch at %s"
+msgstr "%s 的物件類型不符合"
+
+#: builtin/index-pack.c:205
+#, c-format
+msgid "did not receive expected object %s"
+msgstr "未能取得預期的物件 %s"
+
+#: builtin/index-pack.c:208
+#, c-format
+msgid "object %s: expected type %s, found %s"
+msgstr "物件 %s：應為類型 %s，卻是 %s"
+
+#: builtin/index-pack.c:258
+#, c-format
+msgid "cannot fill %d byte"
+msgid_plural "cannot fill %d bytes"
+msgstr[0] "無法填充 %d 位元組"
+msgstr[1] "無法填充 %d 位元組"
+
+#: builtin/index-pack.c:268
+msgid "early EOF"
+msgstr "過早的檔案結束符（EOF）"
+
+#: builtin/index-pack.c:269
+msgid "read error on input"
+msgstr "輸入上的讀錯誤"
+
+#: builtin/index-pack.c:281
+msgid "used more bytes than were available"
+msgstr "用掉了超過可用的位元組"
+
+#: builtin/index-pack.c:288 builtin/pack-objects.c:604
+msgid "pack too large for current definition of off_t"
+msgstr "包太大超過了目前 off_t 的定義"
+
+#: builtin/index-pack.c:291 builtin/unpack-objects.c:95
+msgid "pack exceeds maximum allowed size"
+msgstr "包超過了最大允許值"
+
+#: builtin/index-pack.c:312
+#, c-format
+msgid "cannot open packfile '%s'"
+msgstr "無法開啟 packfile '%s'"
+
+#: builtin/index-pack.c:326
+msgid "pack signature mismatch"
+msgstr "包簽名不符合"
+
+#: builtin/index-pack.c:328
+#, c-format
+msgid "pack version %<PRIu32> unsupported"
+msgstr "不支援包版本 %<PRIu32>"
+
+#: builtin/index-pack.c:346
+#, c-format
+msgid "pack has bad object at offset %<PRIuMAX>: %s"
+msgstr "包中有錯誤的物件位於位移量 %<PRIuMAX>：%s"
+
+#: builtin/index-pack.c:466
+#, c-format
+msgid "inflate returned %d"
+msgstr "解壓縮返回 %d"
+
+#: builtin/index-pack.c:515
+msgid "offset value overflow for delta base object"
+msgstr "位移值覆蓋了 delta 基準物件"
+
+#: builtin/index-pack.c:523
+msgid "delta base offset is out of bound"
+msgstr "delta 基準位移越界"
+
+#: builtin/index-pack.c:531
+#, c-format
+msgid "unknown object type %d"
+msgstr "未知物件類型 %d"
+
+#: builtin/index-pack.c:562
+msgid "cannot pread pack file"
+msgstr "無法讀取包檔案"
+
+#: builtin/index-pack.c:564
+#, c-format
+msgid "premature end of pack file, %<PRIuMAX> byte missing"
+msgid_plural "premature end of pack file, %<PRIuMAX> bytes missing"
+msgstr[0] "包檔案過早結束，缺少 %<PRIuMAX> 位元組"
+msgstr[1] "包檔案過早結束，缺少 %<PRIuMAX> 位元組"
+
+#: builtin/index-pack.c:590
+msgid "serious inflate inconsistency"
+msgstr "解壓縮嚴重的不一致"
+
+#: builtin/index-pack.c:735 builtin/index-pack.c:741 builtin/index-pack.c:764
+#: builtin/index-pack.c:803 builtin/index-pack.c:812
+#, c-format
+msgid "SHA1 COLLISION FOUND WITH %s !"
+msgstr "發現 %s 出現 SHA1 衝突！"
+
+#: builtin/index-pack.c:738 builtin/pack-objects.c:157
+#: builtin/pack-objects.c:217 builtin/pack-objects.c:311
+#, c-format
+msgid "unable to read %s"
+msgstr "不能讀 %s"
+
+#: builtin/index-pack.c:801
+#, c-format
+msgid "cannot read existing object info %s"
+msgstr "不能讀取現存物件訊息 %s"
+
+#: builtin/index-pack.c:809
+#, c-format
+msgid "cannot read existing object %s"
+msgstr "不能讀取現存物件 %s"
+
+#: builtin/index-pack.c:823
+#, c-format
+msgid "invalid blob object %s"
+msgstr "無效的資料物件 %s"
+
+#: builtin/index-pack.c:826 builtin/index-pack.c:845
+msgid "fsck error in packed object"
+msgstr "對打包物件 fsck 檢查發生錯誤"
+
+#: builtin/index-pack.c:847
+#, c-format
+msgid "Not all child objects of %s are reachable"
+msgstr "%s 的所有子物件並非都可以取得"
+
+#: builtin/index-pack.c:919 builtin/index-pack.c:950
+msgid "failed to apply delta"
+msgstr "應用 delta 失敗"
+
+#: builtin/index-pack.c:1118
+msgid "Receiving objects"
+msgstr "接收物件中"
+
+#: builtin/index-pack.c:1118
+msgid "Indexing objects"
+msgstr "索引物件中"
+
+#: builtin/index-pack.c:1152
+msgid "pack is corrupted (SHA1 mismatch)"
+msgstr "包衝突（SHA1 不符合）"
+
+#: builtin/index-pack.c:1157
+msgid "cannot fstat packfile"
+msgstr "不能對 packfile 呼叫 fstat"
+
+#: builtin/index-pack.c:1160
+msgid "pack has junk at the end"
+msgstr "包的結尾有垃圾資料"
+
+#: builtin/index-pack.c:1172
+msgid "confusion beyond insanity in parse_pack_objects()"
+msgstr "parse_pack_objects() 中遇到不可理喻的問題"
+
+#: builtin/index-pack.c:1195
+msgid "Resolving deltas"
+msgstr "處理 delta 中"
+
+#: builtin/index-pack.c:1205 builtin/pack-objects.c:2481
+#, c-format
+msgid "unable to create thread: %s"
+msgstr "不能建立執行緒：%s"
+
+#: builtin/index-pack.c:1246
+msgid "confusion beyond insanity"
+msgstr "不可理喻"
+
+#: builtin/index-pack.c:1252
+#, c-format
+msgid "completed with %d local object"
+msgid_plural "completed with %d local objects"
+msgstr[0] "完成 %d 個本機物件"
+msgstr[1] "完成 %d 個本機物件"
+
+#: builtin/index-pack.c:1264
+#, c-format
+msgid "Unexpected tail checksum for %s (disk corruption?)"
+msgstr "對 %s 的尾部總和檢查出現意外（磁碟損壞？）"
+
+#: builtin/index-pack.c:1268
+#, c-format
+msgid "pack has %d unresolved delta"
+msgid_plural "pack has %d unresolved deltas"
+msgstr[0] "包有 %d 個未解決的 delta"
+msgstr[1] "包有 %d 個未解決的 delta"
+
+#: builtin/index-pack.c:1292
+#, c-format
+msgid "unable to deflate appended object (%d)"
+msgstr "不能壓縮附加物件（%d）"
+
+#: builtin/index-pack.c:1388
+#, c-format
+msgid "local object %s is corrupt"
+msgstr "本機物件 %s 已損壞"
+
+#: builtin/index-pack.c:1402
+#, c-format
+msgid "packfile name '%s' does not end with '.pack'"
+msgstr "packfile 名稱 '%s' 沒有以 '.pack' 結尾"
+
+#: builtin/index-pack.c:1427
+#, c-format
+msgid "cannot write %s file '%s'"
+msgstr "無法寫入 %s 檔案 '%s'"
+
+#: builtin/index-pack.c:1435
+#, c-format
+msgid "cannot close written %s file '%s'"
+msgstr "無法關閉已寫入的 %s 檔案 '%s'"
+
+#: builtin/index-pack.c:1459
+msgid "error while closing pack file"
+msgstr "關閉包檔案時發生錯誤"
+
+#: builtin/index-pack.c:1473
+msgid "cannot store pack file"
+msgstr "無法儲存包檔案"
+
+#: builtin/index-pack.c:1481
+msgid "cannot store index file"
+msgstr "無法儲存索引檔案"
+
+#: builtin/index-pack.c:1525 builtin/pack-objects.c:2716
+#, c-format
+msgid "bad pack.indexversion=%<PRIu32>"
+msgstr "壞的 pack.indexversion=%<PRIu32>"
+
+#: builtin/index-pack.c:1593
+#, c-format
+msgid "Cannot open existing pack file '%s'"
+msgstr "無法開啟現存包檔案 '%s'"
+
+#: builtin/index-pack.c:1595
+#, c-format
+msgid "Cannot open existing pack idx file for '%s'"
+msgstr "無法為 %s 開啟包索引檔案"
+
+#: builtin/index-pack.c:1643
+#, c-format
+msgid "non delta: %d object"
+msgid_plural "non delta: %d objects"
+msgstr[0] "非 delta：%d 個物件"
+msgstr[1] "非 delta：%d 個物件"
+
+#: builtin/index-pack.c:1650
+#, c-format
+msgid "chain length = %d: %lu object"
+msgid_plural "chain length = %d: %lu objects"
+msgstr[0] "鏈長 = %d: %lu 物件"
+msgstr[1] "鏈長 = %d: %lu 物件"
+
+#: builtin/index-pack.c:1689
+msgid "Cannot come back to cwd"
+msgstr "無法返回目前工作目錄"
+
+#: builtin/index-pack.c:1738 builtin/index-pack.c:1741
+#: builtin/index-pack.c:1757 builtin/index-pack.c:1761
+#, c-format
+msgid "bad %s"
+msgstr "錯誤選項 %s"
+
+#: builtin/index-pack.c:1777
+msgid "--fix-thin cannot be used without --stdin"
+msgstr "--fix-thin 不能和 --stdin 同時使用"
+
+#: builtin/index-pack.c:1779
+msgid "--stdin requires a git repository"
+msgstr "--stdin 需要一個 git 版本庫"
+
+#: builtin/index-pack.c:1785
+msgid "--verify with no packfile name given"
+msgstr "--verify 沒有提供 packfile 名稱參數"
+
+#: builtin/index-pack.c:1833 builtin/unpack-objects.c:581
+msgid "fsck error in pack objects"
+msgstr "在打包物件中 fsck 檢查發生錯誤"
+
+#: builtin/init-db.c:61
+#, c-format
+msgid "cannot stat template '%s'"
+msgstr "不能對範本 '%s' 呼叫 stat"
+
+#: builtin/init-db.c:66
+#, c-format
+msgid "cannot opendir '%s'"
+msgstr "不能開啟目錄 '%s'"
+
+#: builtin/init-db.c:78
+#, c-format
+msgid "cannot readlink '%s'"
+msgstr "不能讀取連結 '%s'"
+
+#: builtin/init-db.c:80
+#, c-format
+msgid "cannot symlink '%s' '%s'"
+msgstr "不能自 '%s' 到 '%s' 建立符號連結"
+
+#: builtin/init-db.c:86
+#, c-format
+msgid "cannot copy '%s' to '%s'"
+msgstr "不能複製 '%s' 至 '%s'"
+
+#: builtin/init-db.c:90
+#, c-format
+msgid "ignoring template %s"
+msgstr "忽略範本 %s"
+
+#: builtin/init-db.c:121
+#, c-format
+msgid "templates not found in %s"
+msgstr "沒有在 %s 中找到範本"
+
+#: builtin/init-db.c:136
+#, c-format
+msgid "not copying templates from '%s': %s"
+msgstr "沒有從 '%s' 複製範本：%s"
+
+#: builtin/init-db.c:334
+#, c-format
+msgid "unable to handle file type %d"
+msgstr "不能處理 %d 類型的檔案"
+
+#: builtin/init-db.c:337
+#, c-format
+msgid "unable to move %s to %s"
+msgstr "不能移動 %s 至 %s"
+
+#: builtin/init-db.c:354 builtin/init-db.c:357
+#, c-format
+msgid "%s already exists"
+msgstr "%s 已經存在"
+
+#: builtin/init-db.c:413
+#, c-format
+msgid "Reinitialized existing shared Git repository in %s%s\n"
+msgstr "重新初始化已存在的共享 Git 版本庫於 %s%s\n"
+
+#: builtin/init-db.c:414
+#, c-format
+msgid "Reinitialized existing Git repository in %s%s\n"
+msgstr "重新初始化已存在的 Git 版本庫於 %s%s\n"
+
+#: builtin/init-db.c:418
+#, c-format
+msgid "Initialized empty shared Git repository in %s%s\n"
+msgstr "已初始化空的共享 Git 版本庫於 %s%s\n"
+
+#: builtin/init-db.c:419
+#, c-format
+msgid "Initialized empty Git repository in %s%s\n"
+msgstr "已初始化空的 Git 版本庫於 %s%s\n"
+
+#: builtin/init-db.c:468
+msgid ""
+"git init [-q | --quiet] [--bare] [--template=<template-directory>] [--"
+"shared[=<permissions>]] [<directory>]"
+msgstr ""
+"git init [-q | --quiet] [--bare] [--template=<範本目錄>] [--shared[=<權限>]] "
+"[<目錄>]"
+
+#: builtin/init-db.c:491
+msgid "permissions"
+msgstr "權限"
+
+#: builtin/init-db.c:492
+msgid "specify that the git repository is to be shared amongst several users"
+msgstr "指定 git 版本庫是多個使用者之間共享的"
+
+#: builtin/init-db.c:529 builtin/init-db.c:534
+#, c-format
+msgid "cannot mkdir %s"
+msgstr "不能建立目錄 %s"
+
+#: builtin/init-db.c:538
+#, c-format
+msgid "cannot chdir to %s"
+msgstr "不能切換目錄到 %s"
+
+#: builtin/init-db.c:559
+#, c-format
+msgid ""
+"%s (or --work-tree=<directory>) not allowed without specifying %s (or --git-"
+"dir=<directory>)"
+msgstr "不允許 %s（或 --work-tree=<目錄>）而沒有指定 %s（或 --git-dir=<目錄>）"
+
+#: builtin/init-db.c:587
+#, c-format
+msgid "Cannot access work tree '%s'"
+msgstr "不能存取工作區 '%s'"
+
+#: builtin/interpret-trailers.c:16
+msgid ""
+"git interpret-trailers [--in-place] [--trim-empty] [(--trailer "
+"<token>[(=|:)<value>])...] [<file>...]"
+msgstr ""
+"git interpret-trailers [--in-place] [--trim-empty] [(--trailer <鍵>[(=|:)<值"
+">])...] [<檔案>...]"
+
+#: builtin/interpret-trailers.c:95
+msgid "edit files in place"
+msgstr "在原位編輯檔案"
+
+#: builtin/interpret-trailers.c:96
+msgid "trim empty trailers"
+msgstr "刪除空的尾部署名"
+
+#: builtin/interpret-trailers.c:99
+msgid "where to place the new trailer"
+msgstr "在哪裡放置新的尾部署名"
+
+#: builtin/interpret-trailers.c:101
+msgid "action if trailer already exists"
+msgstr "當尾部署名已經存在時所採取的動作"
+
+#: builtin/interpret-trailers.c:103
+msgid "action if trailer is missing"
+msgstr "當尾部署名缺少時所採取的動作"
+
+#: builtin/interpret-trailers.c:105
+msgid "output only the trailers"
+msgstr "只輸出尾部署名"
+
+#: builtin/interpret-trailers.c:106
+msgid "do not apply config rules"
+msgstr "不要應用設定規則"
+
+#: builtin/interpret-trailers.c:107
+msgid "join whitespace-continued values"
+msgstr "連線空白折行的值"
+
+#: builtin/interpret-trailers.c:108
+msgid "set parsing options"
+msgstr "設定解析選項"
+
+#: builtin/interpret-trailers.c:110
+msgid "do not treat --- specially"
+msgstr "不要對 --- 特殊處理"
+
+#: builtin/interpret-trailers.c:111
+msgid "trailer"
+msgstr "尾部署名"
+
+#: builtin/interpret-trailers.c:112
+msgid "trailer(s) to add"
+msgstr "要新增的尾部署名"
+
+#: builtin/interpret-trailers.c:123
+msgid "--trailer with --only-input does not make sense"
+msgstr "--trailer 和 --only-input 同時使用沒有意義"
+
+#: builtin/interpret-trailers.c:133
+msgid "no input file given for in-place editing"
+msgstr "沒有給出要原位編輯的檔案"
+
+#: builtin/log.c:56
+msgid "git log [<options>] [<revision-range>] [[--] <path>...]"
+msgstr "git log [<選項>] [<版本範圍>] [[--] <路徑>...]"
+
+#: builtin/log.c:57
+msgid "git show [<options>] <object>..."
+msgstr "git show [<選項>] <物件>..."
+
+#: builtin/log.c:110
+#, c-format
+msgid "invalid --decorate option: %s"
+msgstr "無效的 --decorate 選項：%s"
+
+#: builtin/log.c:174
+msgid "show source"
+msgstr "顯示源"
+
+#: builtin/log.c:175
+msgid "Use mail map file"
+msgstr "使用信件映射檔案"
+
+#: builtin/log.c:177
+msgid "only decorate refs that match <pattern>"
+msgstr "只修飾與 <模式> 符合的引用"
+
+#: builtin/log.c:179
+msgid "do not decorate refs that match <pattern>"
+msgstr "不修飾和 <模式> 符合的引用"
+
+#: builtin/log.c:180
+msgid "decorate options"
+msgstr "修飾選項"
+
+#: builtin/log.c:183
+msgid "Process line range n,m in file, counting from 1"
+msgstr "處理檔案中第 n 到 m 之間的行，從 1 開始"
+
+#: builtin/log.c:281
+#, c-format
+msgid "Final output: %d %s\n"
+msgstr "最終輸出：%d %s\n"
+
+#: builtin/log.c:535
+#, c-format
+msgid "git show %s: bad file"
+msgstr "git show %s: 損壞的檔案"
+
+#: builtin/log.c:550 builtin/log.c:645
+#, c-format
+msgid "could not read object %s"
+msgstr "不能讀取物件 %s"
+
+#: builtin/log.c:670
+#, c-format
+msgid "unknown type: %d"
+msgstr "未知類型：%d"
+
+#: builtin/log.c:814
+#, c-format
+msgid "%s: invalid cover from description mode"
+msgstr ""
+
+#: builtin/log.c:821
+msgid "format.headers without value"
+msgstr "format.headers 沒有值"
+
+#: builtin/log.c:936
+msgid "name of output directory is too long"
+msgstr "輸出目錄名太長"
+
+#: builtin/log.c:952
+#, c-format
+msgid "cannot open patch file %s"
+msgstr "無法開啟修補檔案 %s"
+
+#: builtin/log.c:969
+msgid "need exactly one range"
+msgstr "只需要一個範圍"
+
+#: builtin/log.c:979
+msgid "not a range"
+msgstr "不是一個範圍"
+
+#: builtin/log.c:1143
+msgid "cover letter needs email format"
+msgstr "附函需要信件位址格式"
+
+#: builtin/log.c:1149
+msgid "failed to create cover-letter file"
+msgstr "無法建立附函檔案"
+
+#: builtin/log.c:1228
+#, c-format
+msgid "insane in-reply-to: %s"
+msgstr "不正常的 in-reply-to：%s"
+
+#: builtin/log.c:1255
+msgid "git format-patch [<options>] [<since> | <revision-range>]"
+msgstr "git format-patch [<選項>] [<從> | <版本範圍>]"
+
+#: builtin/log.c:1313
+msgid "two output directories?"
+msgstr "兩個輸出目錄？"
+
+#: builtin/log.c:1424 builtin/log.c:2197 builtin/log.c:2199 builtin/log.c:2211
+#, c-format
+msgid "unknown commit %s"
+msgstr "未知提交 %s"
+
+#: builtin/log.c:1434 builtin/replace.c:58 builtin/replace.c:207
+#: builtin/replace.c:210
+#, c-format
+msgid "failed to resolve '%s' as a valid ref"
+msgstr "無法將 '%s' 解析為一個有效引用"
+
+#: builtin/log.c:1439
+msgid "could not find exact merge base"
+msgstr "不能找到準確的合併基礎"
+
+#: builtin/log.c:1443
+msgid ""
+"failed to get upstream, if you want to record base commit automatically,\n"
+"please use git branch --set-upstream-to to track a remote branch.\n"
+"Or you could specify base commit by --base=<base-commit-id> manually"
+msgstr ""
+"無法得到上游位址，如果你想自動記錄基礎提交，請使用指令\n"
+"git branch --set-upstream-to 來追蹤一個遠端分支。或者你可以透過\n"
+"參數 --base=<基礎提交> 手動指定一個基礎提交"
+
+#: builtin/log.c:1463
+msgid "failed to find exact merge base"
+msgstr "無法找到準確的合併基礎"
+
+#: builtin/log.c:1474
+msgid "base commit should be the ancestor of revision list"
+msgstr "基礎提交應該是版本列表的祖先"
+
+#: builtin/log.c:1478
+msgid "base commit shouldn't be in revision list"
+msgstr "基礎提交不應該出現在版本列表中"
+
+#: builtin/log.c:1531
+msgid "cannot get patch id"
+msgstr "無法得到修補檔 id"
+
+#: builtin/log.c:1583
+msgid "failed to infer range-diff ranges"
+msgstr "無法推斷 range-diff 範圍"
+
+#: builtin/log.c:1629
+msgid "use [PATCH n/m] even with a single patch"
+msgstr "使用 [PATCH n/m]，即使只有一個修補檔"
+
+#: builtin/log.c:1632
+msgid "use [PATCH] even with multiple patches"
+msgstr "使用 [PATCH]，即使有多個修補檔"
+
+#: builtin/log.c:1636
+msgid "print patches to standard out"
+msgstr "列印修補檔到標準輸出"
+
+#: builtin/log.c:1638
+msgid "generate a cover letter"
+msgstr "生成一封附函"
+
+#: builtin/log.c:1640
+msgid "use simple number sequence for output file names"
+msgstr "使用簡單的數字序列作為輸出檔案名"
+
+#: builtin/log.c:1641
+msgid "sfx"
+msgstr "後綴"
+
+#: builtin/log.c:1642
+msgid "use <sfx> instead of '.patch'"
+msgstr "使用 <後綴> 代替 '.patch'"
+
+#: builtin/log.c:1644
+msgid "start numbering patches at <n> instead of 1"
+msgstr "修補檔以 <n> 開始編號，而不是1"
+
+#: builtin/log.c:1646
+msgid "mark the series as Nth re-roll"
+msgstr "標記修補檔系列是第幾次重製"
+
+#: builtin/log.c:1648
+msgid "Use [RFC PATCH] instead of [PATCH]"
+msgstr "使用 [RFC PATCH] 代替 [PATCH]"
+
+#: builtin/log.c:1651
+msgid "cover-from-description-mode"
+msgstr ""
+
+#: builtin/log.c:1652
+msgid "generate parts of a cover letter based on a branch's description"
+msgstr ""
+
+#: builtin/log.c:1654
+msgid "Use [<prefix>] instead of [PATCH]"
+msgstr "使用 [<前綴>] 代替 [PATCH]"
+
+#: builtin/log.c:1657
+msgid "store resulting files in <dir>"
+msgstr "把結果檔案儲存在 <目錄>"
+
+#: builtin/log.c:1660
+msgid "don't strip/add [PATCH]"
+msgstr "不刪除/新增 [PATCH]"
+
+#: builtin/log.c:1663
+msgid "don't output binary diffs"
+msgstr "不輸出二進位差異"
+
+#: builtin/log.c:1665
+msgid "output all-zero hash in From header"
+msgstr "在 From 標頭訊息中輸出全為零的雜湊值"
+
+#: builtin/log.c:1667
+msgid "don't include a patch matching a commit upstream"
+msgstr "不包含已在上游提交中的修補檔"
+
+#: builtin/log.c:1669
+msgid "show patch format instead of default (patch + stat)"
+msgstr "顯示純修補檔格式而非預設的（修補檔+狀態）"
+
+#: builtin/log.c:1671
+msgid "Messaging"
+msgstr "信件傳送"
+
+#: builtin/log.c:1672
+msgid "header"
+msgstr "header"
+
+#: builtin/log.c:1673
+msgid "add email header"
+msgstr "新增信件頭"
+
+#: builtin/log.c:1674 builtin/log.c:1676
+msgid "email"
+msgstr "信件位址"
+
+#: builtin/log.c:1674
+msgid "add To: header"
+msgstr "新增收件人"
+
+#: builtin/log.c:1676
+msgid "add Cc: header"
+msgstr "新增抄送"
+
+#: builtin/log.c:1678
+msgid "ident"
+msgstr "標記"
+
+#: builtin/log.c:1679
+msgid "set From address to <ident> (or committer ident if absent)"
+msgstr "將 From 位址設定為 <標記>（如若不提供，則用提交者 ID 做為位址）"
+
+#: builtin/log.c:1681
+msgid "message-id"
+msgstr "信件標記"
+
+#: builtin/log.c:1682
+msgid "make first mail a reply to <message-id>"
+msgstr "使第一封信件作為對 <信件標記> 的回覆"
+
+#: builtin/log.c:1683 builtin/log.c:1686
+msgid "boundary"
+msgstr "邊界"
+
+#: builtin/log.c:1684
+msgid "attach the patch"
+msgstr "附件方式新增修補檔"
+
+#: builtin/log.c:1687
+msgid "inline the patch"
+msgstr "內聯顯示修補檔"
+
+#: builtin/log.c:1691
+msgid "enable message threading, styles: shallow, deep"
+msgstr "啟用信件線索，風格：淺，深"
+
+#: builtin/log.c:1693
+msgid "signature"
+msgstr "簽名"
+
+#: builtin/log.c:1694
+msgid "add a signature"
+msgstr "新增一個簽名"
+
+#: builtin/log.c:1695
+msgid "base-commit"
+msgstr "基礎提交"
+
+#: builtin/log.c:1696
+msgid "add prerequisite tree info to the patch series"
+msgstr "為修補檔列表新增前置樹訊息"
+
+#: builtin/log.c:1698
+msgid "add a signature from a file"
+msgstr "從檔案新增一個簽名"
+
+#: builtin/log.c:1699
+msgid "don't print the patch filenames"
+msgstr "不要列印修補檔檔案名"
+
+#: builtin/log.c:1701
+msgid "show progress while generating patches"
+msgstr "在生成修補檔時顯示進度"
+
+#: builtin/log.c:1703
+msgid "show changes against <rev> in cover letter or single patch"
+msgstr "在附函或單個修補檔中顯示和 <rev> 的差異"
+
+#: builtin/log.c:1706
+msgid "show changes against <refspec> in cover letter or single patch"
+msgstr "在附函或單個修補檔中顯示和 <refspec> 的差異"
+
+#: builtin/log.c:1708
+msgid "percentage by which creation is weighted"
+msgstr "建立權重的百分比"
+
+#: builtin/log.c:1792
+#, c-format
+msgid "invalid ident line: %s"
+msgstr "包含無效的身份標記：%s"
+
+#: builtin/log.c:1807
+msgid "-n and -k are mutually exclusive"
+msgstr "-n 和 -k 互斥"
+
+#: builtin/log.c:1809
+msgid "--subject-prefix/--rfc and -k are mutually exclusive"
+msgstr "--subject-prefix/--rfc 和 -k 互斥"
+
+#: builtin/log.c:1817
+msgid "--name-only does not make sense"
+msgstr "--name-only 無意義"
+
+#: builtin/log.c:1819
+msgid "--name-status does not make sense"
+msgstr "--name-status 無意義"
+
+#: builtin/log.c:1821
+msgid "--check does not make sense"
+msgstr "--check 無意義"
+
+#: builtin/log.c:1854
+msgid "standard output, or directory, which one?"
+msgstr "標準輸出或目錄，哪一個？"
+
+#: builtin/log.c:1958
+msgid "--interdiff requires --cover-letter or single patch"
+msgstr "--interdiff 需要 --cover-letter 或單一修補檔"
+
+#: builtin/log.c:1962
+msgid "Interdiff:"
+msgstr "版本間差異："
+
+#: builtin/log.c:1963
+#, c-format
+msgid "Interdiff against v%d:"
+msgstr "對 v%d 的版本差異："
+
+#: builtin/log.c:1969
+msgid "--creation-factor requires --range-diff"
+msgstr "--creation-factor 需要 --range-diff"
+
+#: builtin/log.c:1973
+msgid "--range-diff requires --cover-letter or single patch"
+msgstr "--range-diff 需要 --cover-letter 或單一修補檔"
+
+#: builtin/log.c:1981
+msgid "Range-diff:"
+msgstr "範圍差異："
+
+#: builtin/log.c:1982
+#, c-format
+msgid "Range-diff against v%d:"
+msgstr "對 v%d 的範圍差異："
+
+#: builtin/log.c:1993
+#, c-format
+msgid "unable to read signature file '%s'"
+msgstr "無法讀取簽名檔案 '%s'"
+
+#: builtin/log.c:2029
+msgid "Generating patches"
+msgstr "生成修補檔"
+
+#: builtin/log.c:2073
+msgid "failed to create output files"
+msgstr "無法建立輸出檔案"
+
+#: builtin/log.c:2132
+msgid "git cherry [-v] [<upstream> [<head> [<limit>]]]"
+msgstr "git cherry [-v] [<上游> [<頭> [<限制>]]]"
+
+#: builtin/log.c:2186
+#, c-format
+msgid ""
+"Could not find a tracked remote branch, please specify <upstream> manually.\n"
+msgstr "不能找到追蹤的遠端分支，請手動指定 <上游>。\n"
+
+#: builtin/ls-files.c:470
+msgid "git ls-files [<options>] [<file>...]"
+msgstr "git ls-files [<選項>] [<檔案>...]"
+
+#: builtin/ls-files.c:526
+msgid "identify the file status with tags"
+msgstr "用標籤標記檔案的狀態"
+
+#: builtin/ls-files.c:528
+msgid "use lowercase letters for 'assume unchanged' files"
+msgstr "使用小寫字母表示 '假設未改變的' 檔案"
+
+#: builtin/ls-files.c:530
+msgid "use lowercase letters for 'fsmonitor clean' files"
+msgstr "使用小寫字母表示 'fsmonitor clean' 檔案"
+
+#: builtin/ls-files.c:532
+msgid "show cached files in the output (default)"
+msgstr "顯示快取的檔案（預設）"
+
+#: builtin/ls-files.c:534
+msgid "show deleted files in the output"
+msgstr "顯示已刪除的檔案"
+
+#: builtin/ls-files.c:536
+msgid "show modified files in the output"
+msgstr "顯示已修改的檔案"
+
+#: builtin/ls-files.c:538
+msgid "show other files in the output"
+msgstr "顯示其它檔案"
+
+#: builtin/ls-files.c:540
+msgid "show ignored files in the output"
+msgstr "顯示忽略的檔案"
+
+#: builtin/ls-files.c:543
+msgid "show staged contents' object name in the output"
+msgstr "顯示暫存區內容的物件名稱"
+
+#: builtin/ls-files.c:545
+msgid "show files on the filesystem that need to be removed"
+msgstr "顯示檔案系統需要刪除的檔案"
+
+#: builtin/ls-files.c:547
+msgid "show 'other' directories' names only"
+msgstr "只顯示「其他」目錄的名稱"
+
+#: builtin/ls-files.c:549
+msgid "show line endings of files"
+msgstr "顯示檔案換行符號格式"
+
+#: builtin/ls-files.c:551
+msgid "don't show empty directories"
+msgstr "不顯示空目錄"
+
+#: builtin/ls-files.c:554
+msgid "show unmerged files in the output"
+msgstr "顯示未合併的檔案"
+
+#: builtin/ls-files.c:556
+msgid "show resolve-undo information"
+msgstr "顯示 resolve-undo 訊息"
+
+#: builtin/ls-files.c:558
+msgid "skip files matching pattern"
+msgstr "符合排除檔案的模式"
+
+#: builtin/ls-files.c:561
+msgid "exclude patterns are read from <file>"
+msgstr "從 <檔案> 中讀取排除模式"
+
+#: builtin/ls-files.c:564
+msgid "read additional per-directory exclude patterns in <file>"
+msgstr "從 <檔案> 讀取額外的每個目錄的排除模式"
+
+#: builtin/ls-files.c:566
+msgid "add the standard git exclusions"
+msgstr "新增標準的 git 排除"
+
+#: builtin/ls-files.c:570
+msgid "make the output relative to the project top directory"
+msgstr "顯示相對於頂級目錄的檔案名"
+
+#: builtin/ls-files.c:573
+msgid "recurse through submodules"
+msgstr "在子模組中遞迴"
+
+#: builtin/ls-files.c:575
+msgid "if any <file> is not in the index, treat this as an error"
+msgstr "如果任何 <檔案> 都不在索引區，視為錯誤"
+
+#: builtin/ls-files.c:576
+msgid "tree-ish"
+msgstr "樹或提交"
+
+#: builtin/ls-files.c:577
+msgid "pretend that paths removed since <tree-ish> are still present"
+msgstr "假裝自從 <樹或提交> 之後刪除的路徑仍然存在"
+
+#: builtin/ls-files.c:579
+msgid "show debugging data"
+msgstr "顯示除錯資料"
+
+#: builtin/ls-remote.c:9
+msgid ""
+"git ls-remote [--heads] [--tags] [--refs] [--upload-pack=<exec>]\n"
+"                     [-q | --quiet] [--exit-code] [--get-url]\n"
+"                     [--symref] [<repository> [<refs>...]]"
+msgstr ""
+"git ls-remote [--heads] [--tags] [--refs] [--upload-pack=<exec>]\n"
+"                     [-q | --quiet] [--exit-code] [--get-url]\n"
+"                     [--symref] [<版本庫> [<引用>...]]"
+
+#: builtin/ls-remote.c:59
+msgid "do not print remote URL"
+msgstr "不列印遠端 URL"
+
+#: builtin/ls-remote.c:60 builtin/ls-remote.c:62 builtin/rebase.c:1518
+msgid "exec"
+msgstr "exec"
+
+#: builtin/ls-remote.c:61 builtin/ls-remote.c:63
+msgid "path of git-upload-pack on the remote host"
+msgstr "遠端主機上的 git-upload-pack 路徑"
+
+#: builtin/ls-remote.c:65
+msgid "limit to tags"
+msgstr "僅限於標籤"
+
+#: builtin/ls-remote.c:66
+msgid "limit to heads"
+msgstr "僅限於分支"
+
+#: builtin/ls-remote.c:67
+msgid "do not show peeled tags"
+msgstr "不顯示已解析的標籤"
+
+#: builtin/ls-remote.c:69
+msgid "take url.<base>.insteadOf into account"
+msgstr "參考 url.<base>.insteadOf 設定"
+
+#: builtin/ls-remote.c:72
+msgid "exit with exit code 2 if no matching refs are found"
+msgstr "若未找到符合的引用則以離開碼2離開"
+
+#: builtin/ls-remote.c:75
+msgid "show underlying ref in addition to the object pointed by it"
+msgstr "除了顯示指向的物件外，顯示指向的引用名"
+
+#: builtin/ls-tree.c:30
+msgid "git ls-tree [<options>] <tree-ish> [<path>...]"
+msgstr "git ls-tree [<選項>] <樹或提交> [<路徑>...]"
+
+#: builtin/ls-tree.c:128
+msgid "only show trees"
+msgstr "只顯示樹"
+
+#: builtin/ls-tree.c:130
+msgid "recurse into subtrees"
+msgstr "遞迴到子樹"
+
+#: builtin/ls-tree.c:132
+msgid "show trees when recursing"
+msgstr "當遞迴時顯示樹"
+
+#: builtin/ls-tree.c:135
+msgid "terminate entries with NUL byte"
+msgstr "條目以 NUL 字元終止"
+
+#: builtin/ls-tree.c:136
+msgid "include object size"
+msgstr "包括物件大小"
+
+#: builtin/ls-tree.c:138 builtin/ls-tree.c:140
+msgid "list only filenames"
+msgstr "只列出檔案名"
+
+#: builtin/ls-tree.c:143
+msgid "use full path names"
+msgstr "使用檔案的全路徑"
+
+#: builtin/ls-tree.c:145
+msgid "list entire tree; not just current directory (implies --full-name)"
+msgstr "列出整個樹；不僅僅目前目錄（隱含 --full-name）"
+
+#: builtin/mailsplit.c:241
+#, c-format
+msgid "empty mbox: '%s'"
+msgstr "空的 mbox：'%s'"
+
+#: builtin/merge.c:55
+msgid "git merge [<options>] [<commit>...]"
+msgstr "git merge [<選項>] [<提交>...]"
+
+#: builtin/merge.c:56
+msgid "git merge --abort"
+msgstr "git merge --abort"
+
+#: builtin/merge.c:57
+msgid "git merge --continue"
+msgstr "git merge --continue"
+
+#: builtin/merge.c:118
+msgid "switch `m' requires a value"
+msgstr "開關 `m' 需要一個值"
+
+#: builtin/merge.c:141
+#, c-format
+msgid "option `%s' requires a value"
+msgstr "選項 `%s' 需要一個值"
+
+#: builtin/merge.c:187
+#, c-format
+msgid "Could not find merge strategy '%s'.\n"
+msgstr "不能找到合併策略 '%s'。\n"
+
+#: builtin/merge.c:188
+#, c-format
+msgid "Available strategies are:"
+msgstr "可用的策略有："
+
+#: builtin/merge.c:193
+#, c-format
+msgid "Available custom strategies are:"
+msgstr "可用的自訂策略有："
+
+#: builtin/merge.c:244 builtin/pull.c:152
+msgid "do not show a diffstat at the end of the merge"
+msgstr "在合併的最後不顯示差異統計"
+
+#: builtin/merge.c:247 builtin/pull.c:155
+msgid "show a diffstat at the end of the merge"
+msgstr "在合併的最後顯示差異統計"
+
+#: builtin/merge.c:248 builtin/pull.c:158
+msgid "(synonym to --stat)"
+msgstr "（和 --stat 同義）"
+
+#: builtin/merge.c:250 builtin/pull.c:161
+msgid "add (at most <n>) entries from shortlog to merge commit message"
+msgstr "在合併提交訊息中新增（最多 <n> 條）精簡提交記錄"
+
+#: builtin/merge.c:253 builtin/pull.c:167
+msgid "create a single commit instead of doing a merge"
+msgstr "建立一個單獨的提交而不是做一次合併"
+
+#: builtin/merge.c:255 builtin/pull.c:170
+msgid "perform a commit if the merge succeeds (default)"
+msgstr "如果合併成功，執行一次提交（預設）"
+
+#: builtin/merge.c:257 builtin/pull.c:173
+msgid "edit message before committing"
+msgstr "在提交前編輯提交說明"
+
+#: builtin/merge.c:259
+msgid "allow fast-forward (default)"
+msgstr "允許快轉（預設）"
+
+#: builtin/merge.c:261 builtin/pull.c:180
+msgid "abort if fast-forward is not possible"
+msgstr "如果不能快轉就放棄合併"
+
+#: builtin/merge.c:265 builtin/pull.c:183
+msgid "verify that the named commit has a valid GPG signature"
+msgstr "驗證指定的提交是否包含一個有效的 GPG 簽名"
+
+#: builtin/merge.c:266 builtin/notes.c:787 builtin/pull.c:187
+#: builtin/rebase.c:512 builtin/rebase.c:1531 builtin/revert.c:114
+msgid "strategy"
+msgstr "策略"
+
+#: builtin/merge.c:267 builtin/pull.c:188
+msgid "merge strategy to use"
+msgstr "要使用的合併策略"
+
+#: builtin/merge.c:268 builtin/pull.c:191
+msgid "option=value"
+msgstr "option=value"
+
+#: builtin/merge.c:269 builtin/pull.c:192
+msgid "option for selected merge strategy"
+msgstr "所選的合併策略的選項"
+
+#: builtin/merge.c:271
+msgid "merge commit message (for a non-fast-forward merge)"
+msgstr "合併的提交說明（針對非快轉式合併）"
+
+#: builtin/merge.c:278
+msgid "abort the current in-progress merge"
+msgstr "放棄目前正在進行的合併"
+
+#
+#: builtin/merge.c:280
+msgid "--abort but leave index and working tree alone"
+msgstr "--abort，但是保留索引和工作區"
+
+#: builtin/merge.c:282
+msgid "continue the current in-progress merge"
+msgstr "繼續目前正在進行的合併"
+
+#: builtin/merge.c:284 builtin/pull.c:199
+msgid "allow merging unrelated histories"
+msgstr "允許合並不相關的歷史"
+
+#: builtin/merge.c:290
+msgid "bypass pre-merge-commit and commit-msg hooks"
+msgstr "繞過 pre-merge-commit 和 commit-msg 掛鉤"
+
+#: builtin/merge.c:307
+msgid "could not run stash."
+msgstr "不能執行儲藏。"
+
+#: builtin/merge.c:312
+msgid "stash failed"
+msgstr "儲藏失敗"
+
+#: builtin/merge.c:317
+#, c-format
+msgid "not a valid object: %s"
+msgstr "不是一個有效物件：%s"
+
+#: builtin/merge.c:339 builtin/merge.c:356
+msgid "read-tree failed"
+msgstr "讀取樹失敗"
+
+#  譯者：請維持前導空格
+#: builtin/merge.c:386
+msgid " (nothing to squash)"
+msgstr " （無可壓縮）"
+
+#: builtin/merge.c:397
+#, c-format
+msgid "Squash commit -- not updating HEAD\n"
+msgstr "壓縮提交 -- 未更新 HEAD\n"
+
+#: builtin/merge.c:447
+#, c-format
+msgid "No merge message -- not updating HEAD\n"
+msgstr "無合併訊息 -- 未更新 HEAD\n"
+
+#: builtin/merge.c:498
+#, c-format
+msgid "'%s' does not point to a commit"
+msgstr "'%s' 沒有指向一個提交"
+
+#: builtin/merge.c:585
+#, c-format
+msgid "Bad branch.%s.mergeoptions string: %s"
+msgstr "壞的 branch.%s.mergeoptions 字串：%s"
+
+#: builtin/merge.c:705
+msgid "Not handling anything other than two heads merge."
+msgstr "未處理兩個頭合併之外的任何動作。"
+
+#: builtin/merge.c:719
+#, c-format
+msgid "Unknown option for merge-recursive: -X%s"
+msgstr "merge-recursive 的未知選項：-X%s"
+
+#: builtin/merge.c:734
+#, c-format
+msgid "unable to write %s"
+msgstr "不能寫 %s"
+
+#: builtin/merge.c:786
+#, c-format
+msgid "Could not read from '%s'"
+msgstr "不能從 '%s' 讀取"
+
+#: builtin/merge.c:795
+#, c-format
+msgid "Not committing merge; use 'git commit' to complete the merge.\n"
+msgstr "未提交合並，使用 'git commit' 完成此次合併。\n"
+
+#: builtin/merge.c:801
+msgid ""
+"Please enter a commit message to explain why this merge is necessary,\n"
+"especially if it merges an updated upstream into a topic branch.\n"
+"\n"
+msgstr ""
+"請輸入一個提交訊息以解釋此合併的必要性，尤其是將一個更新後的上游分支\n"
+"合併到主題分支。\n"
+"\n"
+
+#: builtin/merge.c:806
+msgid "An empty message aborts the commit.\n"
+msgstr "空的提交說明會終止提交。\n"
+
+#: builtin/merge.c:809
+#, c-format
+msgid ""
+"Lines starting with '%c' will be ignored, and an empty message aborts\n"
+"the commit.\n"
+msgstr "以 '%c' 開始的行將被忽略，而空的提交說明將終止提交。\n"
+
+#: builtin/merge.c:862
+msgid "Empty commit message."
+msgstr "空提交訊息。"
+
+#: builtin/merge.c:877
+#, c-format
+msgid "Wonderful.\n"
+msgstr "太棒了。\n"
+
+#: builtin/merge.c:938
+#, c-format
+msgid "Automatic merge failed; fix conflicts and then commit the result.\n"
+msgstr "自動合併失敗，修正衝突然後提交修正的結果。\n"
+
+#: builtin/merge.c:977
+msgid "No current branch."
+msgstr "沒有目前分支。"
+
+#: builtin/merge.c:979
+msgid "No remote for the current branch."
+msgstr "目前分支沒有對應的遠端版本庫。"
+
+#: builtin/merge.c:981
+msgid "No default upstream defined for the current branch."
+msgstr "目前分支沒有定義預設的上游分支。"
+
+#: builtin/merge.c:986
+#, c-format
+msgid "No remote-tracking branch for %s from %s"
+msgstr "對於 %s 沒有來自 %s 的遠端追蹤分支"
+
+#: builtin/merge.c:1043
+#, c-format
+msgid "Bad value '%s' in environment '%s'"
+msgstr "環境 '%2$s' 中存在壞的取值 '%1$s'"
+
+#: builtin/merge.c:1146
+#, c-format
+msgid "not something we can merge in %s: %s"
+msgstr "不能在 %s 中合併：%s"
+
+#: builtin/merge.c:1180
+msgid "not something we can merge"
+msgstr "不能合併"
+
+#: builtin/merge.c:1283
+msgid "--abort expects no arguments"
+msgstr "--abort 不帶參數"
+
+#: builtin/merge.c:1287
+msgid "There is no merge to abort (MERGE_HEAD missing)."
+msgstr "沒有要終止的合併（MERGE_HEAD 遺失）。"
+
+#: builtin/merge.c:1296
+msgid "--quit expects no arguments"
+msgstr "--quit 不帶參數"
+
+#: builtin/merge.c:1309
+msgid "--continue expects no arguments"
+msgstr "--continue 不帶參數"
+
+#: builtin/merge.c:1313
+msgid "There is no merge in progress (MERGE_HEAD missing)."
+msgstr "沒有進行中的合併（MERGE_HEAD 遺失）。"
+
+#: builtin/merge.c:1329
+msgid ""
+"You have not concluded your merge (MERGE_HEAD exists).\n"
+"Please, commit your changes before you merge."
+msgstr ""
+"您尚未結束您的合併（存在 MERGE_HEAD）。\n"
+"請在合併前先提交您的修改。"
+
+#: builtin/merge.c:1336
+msgid ""
+"You have not concluded your cherry-pick (CHERRY_PICK_HEAD exists).\n"
+"Please, commit your changes before you merge."
+msgstr ""
+"您尚未結束您的揀選（存在 CHERRY_PICK_HEAD）。\n"
+"請在合併前先提交您的修改。"
+
+#: builtin/merge.c:1339
+msgid "You have not concluded your cherry-pick (CHERRY_PICK_HEAD exists)."
+msgstr "您尚未結束您的揀選（存在 CHERRY_PICK_HEAD）。"
+
+#: builtin/merge.c:1353
+msgid "You cannot combine --squash with --no-ff."
+msgstr "您不能將 --squash 和 --no-ff 組合使用。"
+
+#: builtin/merge.c:1355
+msgid "You cannot combine --squash with --commit."
+msgstr "您不能將 --squash 和 --commit 組合使用。"
+
+#: builtin/merge.c:1371
+msgid "No commit specified and merge.defaultToUpstream not set."
+msgstr "未指定提交並且 merge.defaultToUpstream 未設定。"
+
+#: builtin/merge.c:1388
+msgid "Squash commit into empty head not supported yet"
+msgstr "尚不支援到空分支的壓縮提交"
+
+#: builtin/merge.c:1390
+msgid "Non-fast-forward commit does not make sense into an empty head"
+msgstr "到空分支的非快轉式提交沒有意義"
+
+#: builtin/merge.c:1395
+#, c-format
+msgid "%s - not something we can merge"
+msgstr "%s - 不能被合併"
+
+#: builtin/merge.c:1397
+msgid "Can merge only exactly one commit into empty head"
+msgstr "只能將一個提交合並到空分支上"
+
+#: builtin/merge.c:1476
+msgid "refusing to merge unrelated histories"
+msgstr "拒絕合併無關的歷史"
+
+#: builtin/merge.c:1485
+msgid "Already up to date."
+msgstr "已經是最新的。"
+
+#: builtin/merge.c:1495
+#, c-format
+msgid "Updating %s..%s\n"
+msgstr "更新 %s..%s\n"
+
+#: builtin/merge.c:1537
+#, c-format
+msgid "Trying really trivial in-index merge...\n"
+msgstr "嘗試非常小的索引內合併...\n"
+
+#: builtin/merge.c:1544
+#, c-format
+msgid "Nope.\n"
+msgstr "無。\n"
+
+#: builtin/merge.c:1569
+msgid "Already up to date. Yeeah!"
+msgstr "已經是最新的。耶！"
+
+#: builtin/merge.c:1575
+msgid "Not possible to fast-forward, aborting."
+msgstr "無法快轉，終止。"
+
+#: builtin/merge.c:1598 builtin/merge.c:1663
+#, c-format
+msgid "Rewinding the tree to pristine...\n"
+msgstr "將樹回滾至原始狀態...\n"
+
+#: builtin/merge.c:1602
+#, c-format
+msgid "Trying merge strategy %s...\n"
+msgstr "嘗試合併策略 %s...\n"
+
+#: builtin/merge.c:1654
+#, c-format
+msgid "No merge strategy handled the merge.\n"
+msgstr "沒有合併策略處理此合併。\n"
+
+#: builtin/merge.c:1656
+#, c-format
+msgid "Merge with strategy %s failed.\n"
+msgstr "使用策略 %s 合併失敗。\n"
+
+#: builtin/merge.c:1665
+#, c-format
+msgid "Using the %s to prepare resolving by hand.\n"
+msgstr "使用 %s 以準備手動解決。\n"
+
+#: builtin/merge.c:1677
+#, c-format
+msgid "Automatic merge went well; stopped before committing as requested\n"
+msgstr "自動合併進展順利，按要求在提交前停止\n"
+
+#: builtin/merge-base.c:32
+msgid "git merge-base [-a | --all] <commit> <commit>..."
+msgstr "git merge-base [-a | --all] <提交> <提交>..."
+
+#: builtin/merge-base.c:33
+msgid "git merge-base [-a | --all] --octopus <commit>..."
+msgstr "git merge-base [-a | --all] --octopus <提交>..."
+
+#: builtin/merge-base.c:34
+msgid "git merge-base --independent <commit>..."
+msgstr "git merge-base --independent <提交>..."
+
+#: builtin/merge-base.c:35
+msgid "git merge-base --is-ancestor <commit> <commit>"
+msgstr "git merge-base --is-ancestor <提交> <提交>"
+
+#: builtin/merge-base.c:36
+msgid "git merge-base --fork-point <ref> [<commit>]"
+msgstr "git merge-base --fork-point <引用> [<提交>]"
+
+#: builtin/merge-base.c:153
+msgid "output all common ancestors"
+msgstr "輸出所有共同的祖先"
+
+#: builtin/merge-base.c:155
+msgid "find ancestors for a single n-way merge"
+msgstr "尋找一個多路合併的祖先提交"
+
+#: builtin/merge-base.c:157
+msgid "list revs not reachable from others"
+msgstr "顯示不能被其他存取到的版本"
+
+#: builtin/merge-base.c:159
+msgid "is the first one ancestor of the other?"
+msgstr "第一個是其他的祖先提交嗎？"
+
+#: builtin/merge-base.c:161
+msgid "find where <commit> forked from reflog of <ref>"
+msgstr "根據 <引用> 的引用日誌尋找 <提交> 的衍生處"
+
+#: builtin/merge-file.c:9
+msgid ""
+"git merge-file [<options>] [-L <name1> [-L <orig> [-L <name2>]]] <file1> "
+"<orig-file> <file2>"
+msgstr ""
+"git merge-file [<選項>] [-L <檔案1> [-L <初始> [-L <名字2>]]] <檔案1> <初始文"
+"件> <檔案2>"
+
+#: builtin/merge-file.c:35
+msgid "send results to standard output"
+msgstr "將結果傳送到標準輸出"
+
+#: builtin/merge-file.c:36
+msgid "use a diff3 based merge"
+msgstr "使用基於 diff3 的合併"
+
+#: builtin/merge-file.c:37
+msgid "for conflicts, use our version"
+msgstr "如果衝突，使用我們的版本"
+
+#: builtin/merge-file.c:39
+msgid "for conflicts, use their version"
+msgstr "如果衝突，使用他們的版本"
+
+#: builtin/merge-file.c:41
+msgid "for conflicts, use a union version"
+msgstr "如果衝突，使用聯合版本"
+
+#: builtin/merge-file.c:44
+msgid "for conflicts, use this marker size"
+msgstr "如果衝突，使用指定長度的標記"
+
+#: builtin/merge-file.c:45
+msgid "do not warn about conflicts"
+msgstr "不要警告衝突"
+
+#: builtin/merge-file.c:47
+msgid "set labels for file1/orig-file/file2"
+msgstr "為 檔案1/初始檔案/檔案2 設定標籤"
+
+#: builtin/merge-recursive.c:47
+#, c-format
+msgid "unknown option %s"
+msgstr "未知選項 %s"
+
+#: builtin/merge-recursive.c:53
+#, c-format
+msgid "could not parse object '%s'"
+msgstr "不能解析物件 '%s'"
+
+#: builtin/merge-recursive.c:57
+#, c-format
+msgid "cannot handle more than %d base. Ignoring %s."
+msgid_plural "cannot handle more than %d bases. Ignoring %s."
+msgstr[0] "無法處理 %d 條以上的基礎。忽略 %s。"
+msgstr[1] "無法處理 %d 條以上的基礎。忽略 %s。"
+
+#: builtin/merge-recursive.c:65
+msgid "not handling anything other than two heads merge."
+msgstr "不能處理兩個頭合併之外的任何動作。"
+
+#: builtin/merge-recursive.c:74 builtin/merge-recursive.c:76
+#, c-format
+msgid "could not resolve ref '%s'"
+msgstr "無法解析引用 '%s'"
+
+#: builtin/merge-recursive.c:82
+#, c-format
+msgid "Merging %s with %s\n"
+msgstr "合併 %s 和 %s\n"
+
+#: builtin/mktree.c:66
+msgid "git mktree [-z] [--missing] [--batch]"
+msgstr "git mktree [-z] [--missing] [--batch]"
+
+#: builtin/mktree.c:154
+msgid "input is NUL terminated"
+msgstr "輸入以 NUL 字元終止"
+
+#: builtin/mktree.c:155 builtin/write-tree.c:26
+msgid "allow missing objects"
+msgstr "允許遺失的物件"
+
+#: builtin/mktree.c:156
+msgid "allow creation of more than one tree"
+msgstr "允許建立一個以上的樹"
+
+#: builtin/multi-pack-index.c:9
+#| msgid ""
+#| "git multi-pack-index [--object-dir=<dir>] (write|verify|expire|repack --"
+#| "batch-size=<size>)"
+msgid ""
+"git multi-pack-index [<options>] (write|verify|expire|repack --batch-"
+"size=<size>)"
+msgstr ""
+"git multi-pack-index [<選項>] (write|verify|expire|repack --batch-"
+"size=<大小>)"
+
+#: builtin/multi-pack-index.c:26
+msgid "object directory containing set of packfile and pack-index pairs"
+msgstr "包含成對 packfile 和包索引的物件目錄"
+
+#: builtin/multi-pack-index.c:29
+msgid ""
+"during repack, collect pack-files of smaller size into a batch that is "
+"larger than this size"
+msgstr "在 repack 期間，將較小尺寸的包檔案收集到大於此大小的批次中"
+
+#: builtin/multi-pack-index.c:50 builtin/prune-packed.c:67
+msgid "too many arguments"
+msgstr "太多參數"
+
+#: builtin/multi-pack-index.c:60
+msgid "--batch-size option is only for 'repack' subcommand"
+msgstr "--batch-size 選項僅用於 'repack' 子指令"
+
+#: builtin/multi-pack-index.c:69
+#, c-format
+msgid "unrecognized subcommand: %s"
+msgstr "未識別的子指令：%s"
+
+#: builtin/mv.c:18
+msgid "git mv [<options>] <source>... <destination>"
+msgstr "git mv [<選項>] <源>... <目標>"
+
+#: builtin/mv.c:83
+#, c-format
+msgid "Directory %s is in index and no submodule?"
+msgstr "目錄 %s 在索引中並且不是子模組？"
+
+#: builtin/mv.c:85
+msgid "Please stage your changes to .gitmodules or stash them to proceed"
+msgstr "請將您的修改暫存到 .gitmodules 中或儲藏後再繼續"
+
+#: builtin/mv.c:103
+#, c-format
+msgid "%.*s is in index"
+msgstr "%.*s 在索引中"
+
+#: builtin/mv.c:125
+msgid "force move/rename even if target exists"
+msgstr "強制移動/重指令，即使目標存在"
+
+#: builtin/mv.c:127
+msgid "skip move/rename errors"
+msgstr "跳過移動/重新命名錯誤"
+
+#: builtin/mv.c:169
+#, c-format
+msgid "destination '%s' is not a directory"
+msgstr "目標 '%s' 不是一個目錄"
+
+#: builtin/mv.c:180
+#, c-format
+msgid "Checking rename of '%s' to '%s'\n"
+msgstr "檢查 '%s' 到 '%s' 的重新命名\n"
+
+#: builtin/mv.c:184
+msgid "bad source"
+msgstr "壞的源"
+
+#: builtin/mv.c:187
+msgid "can not move directory into itself"
+msgstr "不能將目錄移動到自身"
+
+#: builtin/mv.c:190
+msgid "cannot move directory over file"
+msgstr "不能將目錄移動到檔案"
+
+#: builtin/mv.c:199
+msgid "source directory is empty"
+msgstr "源目錄為空"
+
+#: builtin/mv.c:224
+msgid "not under version control"
+msgstr "不在版本控制之下"
+
+#: builtin/mv.c:227
+msgid "destination exists"
+msgstr "目標已存在"
+
+#: builtin/mv.c:235
+#, c-format
+msgid "overwriting '%s'"
+msgstr "覆蓋 '%s'"
+
+#: builtin/mv.c:238
+msgid "Cannot overwrite"
+msgstr "不能覆蓋"
+
+#: builtin/mv.c:241
+msgid "multiple sources for the same target"
+msgstr "同一目標具有多個源"
+
+#: builtin/mv.c:243
+msgid "destination directory does not exist"
+msgstr "目標目錄不存在"
+
+#: builtin/mv.c:250
+#, c-format
+msgid "%s, source=%s, destination=%s"
+msgstr "%s，源=%s，目標=%s"
+
+#: builtin/mv.c:271
+#, c-format
+msgid "Renaming %s to %s\n"
+msgstr "重新命名 %s 至 %s\n"
+
+#: builtin/mv.c:277 builtin/remote.c:716 builtin/repack.c:518
+#, c-format
+msgid "renaming '%s' failed"
+msgstr "重新命名 '%s' 失敗"
+
+#: builtin/name-rev.c:403
+msgid "git name-rev [<options>] <commit>..."
+msgstr "git name-rev [<選項>] <提交>..."
+
+#: builtin/name-rev.c:404
+msgid "git name-rev [<options>] --all"
+msgstr "git name-rev [<選項>] --all"
+
+#: builtin/name-rev.c:405
+msgid "git name-rev [<options>] --stdin"
+msgstr "git name-rev [<選項>] --stdin"
+
+#: builtin/name-rev.c:462
+msgid "print only names (no SHA-1)"
+msgstr "只列印名稱（無 SHA-1）"
+
+#: builtin/name-rev.c:463
+msgid "only use tags to name the commits"
+msgstr "只使用標籤來命名提交"
+
+#: builtin/name-rev.c:465
+msgid "only use refs matching <pattern>"
+msgstr "只使用和 <模式> 相符合的引用"
+
+#: builtin/name-rev.c:467
+msgid "ignore refs matching <pattern>"
+msgstr "忽略和 <模式> 相符合的引用"
+
+#: builtin/name-rev.c:469
+msgid "list all commits reachable from all refs"
+msgstr "列出可以從所有引用存取的提交"
+
+#: builtin/name-rev.c:470
+msgid "read from stdin"
+msgstr "從標準輸入讀取"
+
+#: builtin/name-rev.c:471
+msgid "allow to print `undefined` names (default)"
+msgstr "允許列印 `未定義` 的名稱（預設）"
+
+#: builtin/name-rev.c:477
+msgid "dereference tags in the input (internal use)"
+msgstr "反向解析輸入中的標籤（內部使用）"
+
+#: builtin/notes.c:28
+msgid "git notes [--ref <notes-ref>] [list [<object>]]"
+msgstr "git notes [--ref <註解引用>] [list [<物件>]]"
+
+#: builtin/notes.c:29
+msgid ""
+"git notes [--ref <notes-ref>] add [-f] [--allow-empty] [-m <msg> | -F <file> "
+"| (-c | -C) <object>] [<object>]"
+msgstr ""
+"git notes [--ref <註解引用>] add [-f] [--allow-empty] [-m <說明> | -F <檔案> "
+"| (-c | -C) <物件>] [<物件>]"
+
+#: builtin/notes.c:30
+msgid "git notes [--ref <notes-ref>] copy [-f] <from-object> <to-object>"
+msgstr "git notes [--ref <註解引用>] copy [-f] <源物件> <目標物件>"
+
+#: builtin/notes.c:31
+msgid ""
+"git notes [--ref <notes-ref>] append [--allow-empty] [-m <msg> | -F <file> | "
+"(-c | -C) <object>] [<object>]"
+msgstr ""
+"git notes [--ref <註解引用>] append [--allow-empty] [-m <說明> | -F <檔案> | "
+"(-c | -C) <物件>] [<物件>]"
+
+#: builtin/notes.c:32
+msgid "git notes [--ref <notes-ref>] edit [--allow-empty] [<object>]"
+msgstr "git notes [--ref <註解引用>] edit [--allow-empty] [<物件>]"
+
+#: builtin/notes.c:33
+msgid "git notes [--ref <notes-ref>] show [<object>]"
+msgstr "git notes [--ref <註解引用>] show [<物件>]"
+
+#: builtin/notes.c:34
+msgid ""
+"git notes [--ref <notes-ref>] merge [-v | -q] [-s <strategy>] <notes-ref>"
+msgstr "git notes [--ref <註解引用>] merge [-v | -q] [-s <策略> ] <註解引用>"
+
+#: builtin/notes.c:35
+msgid "git notes merge --commit [-v | -q]"
+msgstr "git notes merge --commit [-v | -q]"
+
+#: builtin/notes.c:36
+msgid "git notes merge --abort [-v | -q]"
+msgstr "git notes merge --abort [-v | -q]"
+
+#: builtin/notes.c:37
+msgid "git notes [--ref <notes-ref>] remove [<object>...]"
+msgstr "git notes [--ref <註解引用>] remove [<物件>...]"
+
+#: builtin/notes.c:38
+msgid "git notes [--ref <notes-ref>] prune [-n] [-v]"
+msgstr "git notes [--ref <註解引用>] prune [-n] [-v]"
+
+#: builtin/notes.c:39
+msgid "git notes [--ref <notes-ref>] get-ref"
+msgstr "git notes [--ref <註解引用>] get-ref"
+
+#: builtin/notes.c:44
+msgid "git notes [list [<object>]]"
+msgstr "git notes [list [<物件>]]"
+
+#: builtin/notes.c:49
+msgid "git notes add [<options>] [<object>]"
+msgstr "git notes add [<選項>] [<物件>]"
+
+#: builtin/notes.c:54
+msgid "git notes copy [<options>] <from-object> <to-object>"
+msgstr "git notes copy [<選項>] <源物件> <目標物件>"
+
+#: builtin/notes.c:55
+msgid "git notes copy --stdin [<from-object> <to-object>]..."
+msgstr "git notes copy --stdin [<源物件> <目標物件>]..."
+
+#: builtin/notes.c:60
+msgid "git notes append [<options>] [<object>]"
+msgstr "git notes append [<選項>] [<物件>]"
+
+#: builtin/notes.c:65
+msgid "git notes edit [<object>]"
+msgstr "git notes edit [<物件>]"
+
+#: builtin/notes.c:70
+msgid "git notes show [<object>]"
+msgstr "git notes show [<物件>]"
+
+#: builtin/notes.c:75
+msgid "git notes merge [<options>] <notes-ref>"
+msgstr "git notes merge [<選項>] <註解引用>"
+
+#: builtin/notes.c:76
+msgid "git notes merge --commit [<options>]"
+msgstr "git notes merge --commit [<選項>]"
+
+#: builtin/notes.c:77
+msgid "git notes merge --abort [<options>]"
+msgstr "git notes merge --abort [<選項>]"
+
+#: builtin/notes.c:82
+msgid "git notes remove [<object>]"
+msgstr "git notes remove [<物件>]"
+
+#: builtin/notes.c:87
+msgid "git notes prune [<options>]"
+msgstr "git notes prune [<選項>]"
+
+#: builtin/notes.c:92
+msgid "git notes get-ref"
+msgstr "git notes get-ref"
+
+#: builtin/notes.c:97
+msgid "Write/edit the notes for the following object:"
+msgstr "為下面的物件寫/編輯說明："
+
+#: builtin/notes.c:150
+#, c-format
+msgid "unable to start 'show' for object '%s'"
+msgstr "不能為物件 '%s' 開始 'show'"
+
+#: builtin/notes.c:154
+msgid "could not read 'show' output"
+msgstr "不能讀取 'show' 的輸出"
+
+#: builtin/notes.c:162
+#, c-format
+msgid "failed to finish 'show' for object '%s'"
+msgstr "無法為物件 '%s' 完成 'show'"
+
+#: builtin/notes.c:197
+msgid "please supply the note contents using either -m or -F option"
+msgstr "請透過 -m 或 -F 選項為註解提供內容"
+
+#: builtin/notes.c:206
+msgid "unable to write note object"
+msgstr "不能寫註解物件"
+
+#: builtin/notes.c:208
+#, c-format
+msgid "the note contents have been left in %s"
+msgstr "註解內容被留在 %s 中"
+
+#: builtin/notes.c:242 builtin/tag.c:532
+#, c-format
+msgid "could not open or read '%s'"
+msgstr "不能開啟或讀取 '%s'"
+
+#: builtin/notes.c:263 builtin/notes.c:313 builtin/notes.c:315
+#: builtin/notes.c:383 builtin/notes.c:438 builtin/notes.c:526
+#: builtin/notes.c:531 builtin/notes.c:610 builtin/notes.c:672
+#, c-format
+msgid "failed to resolve '%s' as a valid ref."
+msgstr "無法解析 '%s' 為一個有效引用。"
+
+#: builtin/notes.c:265
+#, c-format
+msgid "failed to read object '%s'."
+msgstr "讀取物件 '%s' 失敗。"
+
+#: builtin/notes.c:268
+#, c-format
+msgid "cannot read note data from non-blob object '%s'."
+msgstr "不能從非資料物件 '%s' 中讀取註解資料。"
+
+#: builtin/notes.c:309
+#, c-format
+msgid "malformed input line: '%s'."
+msgstr "格式錯誤的輸入行：'%s'。"
+
+#: builtin/notes.c:324
+#, c-format
+msgid "failed to copy notes from '%s' to '%s'"
+msgstr "從 '%s' 複製註解到 '%s' 時失敗"
+
+#. TRANSLATORS: the first %s will be replaced by a git
+#. notes command: 'add', 'merge', 'remove', etc.
+#.
+#: builtin/notes.c:356
+#, c-format
+msgid "refusing to %s notes in %s (outside of refs/notes/)"
+msgstr "拒絕向 %2$s（在 refs/notes/ 之外）%1$s註解"
+
+#: builtin/notes.c:376 builtin/notes.c:431 builtin/notes.c:509
+#: builtin/notes.c:521 builtin/notes.c:598 builtin/notes.c:665
+#: builtin/notes.c:815 builtin/notes.c:963 builtin/notes.c:985
+msgid "too many parameters"
+msgstr "參數太多"
+
+#: builtin/notes.c:389 builtin/notes.c:678
+#, c-format
+msgid "no note found for object %s."
+msgstr "未發現物件 %s 的註解。"
+
+#: builtin/notes.c:410 builtin/notes.c:576
+msgid "note contents as a string"
+msgstr "註解內容作為一個字串"
+
+#: builtin/notes.c:413 builtin/notes.c:579
+msgid "note contents in a file"
+msgstr "註解內容到一個檔案中"
+
+#: builtin/notes.c:416 builtin/notes.c:582
+msgid "reuse and edit specified note object"
+msgstr "重用和編輯指定的註解物件"
+
+#: builtin/notes.c:419 builtin/notes.c:585
+msgid "reuse specified note object"
+msgstr "重用指定的註解物件"
+
+#: builtin/notes.c:422 builtin/notes.c:588
+msgid "allow storing empty note"
+msgstr "允許儲存空白備註"
+
+#: builtin/notes.c:423 builtin/notes.c:496
+msgid "replace existing notes"
+msgstr "取代已存在的註解"
+
+#: builtin/notes.c:448
+#, c-format
+msgid ""
+"Cannot add notes. Found existing notes for object %s. Use '-f' to overwrite "
+"existing notes"
+msgstr "不能新增註解。發現物件 %s 已存在註解。使用 '-f' 覆蓋現存註解"
+
+#: builtin/notes.c:463 builtin/notes.c:544
+#, c-format
+msgid "Overwriting existing notes for object %s\n"
+msgstr "覆蓋物件 %s 現存註解\n"
+
+#: builtin/notes.c:475 builtin/notes.c:637 builtin/notes.c:902
+#, c-format
+msgid "Removing note for object %s\n"
+msgstr "刪除物件 %s 的註解\n"
+
+#: builtin/notes.c:497
+msgid "read objects from stdin"
+msgstr "從標準輸入讀取物件"
+
+#: builtin/notes.c:499
+msgid "load rewriting config for <command> (implies --stdin)"
+msgstr "重新載入 <指令> 的設定（隱含 --stdin）"
+
+#: builtin/notes.c:517
+msgid "too few parameters"
+msgstr "參數太少"
+
+#: builtin/notes.c:538
+#, c-format
+msgid ""
+"Cannot copy notes. Found existing notes for object %s. Use '-f' to overwrite "
+"existing notes"
+msgstr "不能複製註解。發現物件 %s 已存在註解。使用 '-f' 覆蓋現存註解"
+
+#: builtin/notes.c:550
+#, c-format
+msgid "missing notes on source object %s. Cannot copy."
+msgstr "源物件 %s 缺少註解。不能複製。"
+
+#: builtin/notes.c:603
+#, c-format
+msgid ""
+"The -m/-F/-c/-C options have been deprecated for the 'edit' subcommand.\n"
+"Please use 'git notes add -f -m/-F/-c/-C' instead.\n"
+msgstr ""
+"子指令 'edit' 的選項 -m/-F/-c/-C 已棄用。\n"
+"請換用 'git notes add -f -m/-F/-c/-C'。\n"
+
+#: builtin/notes.c:698
+msgid "failed to delete ref NOTES_MERGE_PARTIAL"
+msgstr "刪除引用 NOTES_MERGE_PARTIAL 失敗"
+
+#: builtin/notes.c:700
+msgid "failed to delete ref NOTES_MERGE_REF"
+msgstr "刪除引用 NOTES_MERGE_REF 失敗"
+
+#: builtin/notes.c:702
+msgid "failed to remove 'git notes merge' worktree"
+msgstr "刪除 'git notes merge' 工作區失敗"
+
+#: builtin/notes.c:722
+msgid "failed to read ref NOTES_MERGE_PARTIAL"
+msgstr "讀取引用 NOTES_MERGE_PARTIAL 失敗"
+
+#: builtin/notes.c:724
+msgid "could not find commit from NOTES_MERGE_PARTIAL."
+msgstr "無法從 NOTES_MERGE_PARTIAL 中找到提交。"
+
+#: builtin/notes.c:726
+msgid "could not parse commit from NOTES_MERGE_PARTIAL."
+msgstr "無法從 NOTES_MERGE_PARTIAL 中解析提交。"
+
+#: builtin/notes.c:739
+msgid "failed to resolve NOTES_MERGE_REF"
+msgstr "解析 NOTES_MERGE_REF 失敗"
+
+#: builtin/notes.c:742
+msgid "failed to finalize notes merge"
+msgstr "無法完成註解合併"
+
+#: builtin/notes.c:768
+#, c-format
+msgid "unknown notes merge strategy %s"
+msgstr "未知的註解合併策略 %s"
+
+#: builtin/notes.c:784
+msgid "General options"
+msgstr "通用選項"
+
+#: builtin/notes.c:786
+msgid "Merge options"
+msgstr "合併選項"
+
+#: builtin/notes.c:788
+msgid ""
+"resolve notes conflicts using the given strategy (manual/ours/theirs/union/"
+"cat_sort_uniq)"
+msgstr "使用指定的策略解決註解衝突 (manual/ours/theirs/union/cat_sort_uniq)"
+
+#: builtin/notes.c:790
+msgid "Committing unmerged notes"
+msgstr "提交未合併的註解"
+
+#: builtin/notes.c:792
+msgid "finalize notes merge by committing unmerged notes"
+msgstr "透過提交未合併的註解來完成註解合併"
+
+#: builtin/notes.c:794
+msgid "Aborting notes merge resolution"
+msgstr "中止註解合併的方案"
+
+#: builtin/notes.c:796
+msgid "abort notes merge"
+msgstr "中止註解合併"
+
+#: builtin/notes.c:807
+msgid "cannot mix --commit, --abort or -s/--strategy"
+msgstr "不能混用 --commit、--abort 或 -s/--strategy"
+
+#: builtin/notes.c:812
+msgid "must specify a notes ref to merge"
+msgstr "必須指定一個註解引用來合併"
+
+#: builtin/notes.c:836
+#, c-format
+msgid "unknown -s/--strategy: %s"
+msgstr "未知的 -s/--strategy：%s"
+
+#: builtin/notes.c:873
+#, c-format
+msgid "a notes merge into %s is already in-progress at %s"
+msgstr "位於 %2$s 的一個到 %1$s 中的註解合併正在執行中"
+
+#: builtin/notes.c:876
+#, c-format
+msgid "failed to store link to current notes ref (%s)"
+msgstr "無法儲存連結到目前的註解引用（%s）"
+
+#: builtin/notes.c:878
+#, c-format
+msgid ""
+"Automatic notes merge failed. Fix conflicts in %s and commit the result with "
+"'git notes merge --commit', or abort the merge with 'git notes merge --"
+"abort'.\n"
+msgstr ""
+"自動合併說明失敗。修改 %s 中的衝突並且使用指令 'git notes merge --commit' 提"
+"交結果，或者使用指令 'git notes merge --abort' 終止合併。\n"
+
+#: builtin/notes.c:897 builtin/tag.c:545
+#, c-format
+msgid "Failed to resolve '%s' as a valid ref."
+msgstr "無法解析 '%s' 為一個有效引用。"
+
+#: builtin/notes.c:900
+#, c-format
+msgid "Object %s has no note\n"
+msgstr "物件 %s 沒有註解\n"
+
+#: builtin/notes.c:912
+msgid "attempt to remove non-existent note is not an error"
+msgstr "嘗試刪除不存在的註解不是一個錯誤"
+
+#: builtin/notes.c:915
+msgid "read object names from the standard input"
+msgstr "從標準輸入讀取物件名稱"
+
+#: builtin/notes.c:954 builtin/prune.c:130 builtin/worktree.c:164
+msgid "do not remove, show only"
+msgstr "不刪除，只顯示"
+
+#: builtin/notes.c:955
+msgid "report pruned notes"
+msgstr "報告清除的註解"
+
+#: builtin/notes.c:998
+msgid "notes-ref"
+msgstr "註解引用"
+
+#: builtin/notes.c:999
+msgid "use notes from <notes-ref>"
+msgstr "從 <註解引用> 使用註解"
+
+#: builtin/notes.c:1034 builtin/stash.c:1607
+#, c-format
+msgid "unknown subcommand: %s"
+msgstr "未知子指令：%s"
+
+#: builtin/pack-objects.c:52
+msgid ""
+"git pack-objects --stdout [<options>...] [< <ref-list> | < <object-list>]"
+msgstr "git pack-objects --stdout [<選項>...] [< <引用列表> | < <物件列表>]"
+
+#: builtin/pack-objects.c:53
+msgid ""
+"git pack-objects [<options>...] <base-name> [< <ref-list> | < <object-list>]"
+msgstr "git pack-objects [<選項>...] <前綴名稱> [< <引用列表> | < <物件列表>]"
+
+#: builtin/pack-objects.c:428
+#, c-format
+msgid "bad packed object CRC for %s"
+msgstr "%s 錯的包物件 CRC"
+
+#: builtin/pack-objects.c:439
+#, c-format
+msgid "corrupt packed object for %s"
+msgstr "%s 損壞的包物件"
+
+#: builtin/pack-objects.c:570
+#, c-format
+msgid "recursive delta detected for object %s"
+msgstr "發現物件 %s 遞迴 delta"
+
+#: builtin/pack-objects.c:781
+#, c-format
+msgid "ordered %u objects, expected %<PRIu32>"
+msgstr "排序了 %u 個物件，預期 %<PRIu32> 個"
+
+#: builtin/pack-objects.c:794
+#, c-format
+msgid "packfile is invalid: %s"
+msgstr "無效的 packfile：%s"
+
+#: builtin/pack-objects.c:798
+#, c-format
+msgid "unable to open packfile for reuse: %s"
+msgstr "無法為重用開啟 packfile：%s"
+
+#: builtin/pack-objects.c:802
+msgid "unable to seek in reused packfile"
+msgstr "無法在重用的 packfile 中尋找"
+
+#: builtin/pack-objects.c:813
+msgid "unable to read from reused packfile"
+msgstr "無法從復用的 packfile 中讀取"
+
+#: builtin/pack-objects.c:841
+msgid "disabling bitmap writing, packs are split due to pack.packSizeLimit"
+msgstr "禁用 bitmap 寫入，因為 pack.packSizeLimit 設定使得包被切分為多個"
+
+#: builtin/pack-objects.c:854
+msgid "Writing objects"
+msgstr "寫入物件中"
+
+#: builtin/pack-objects.c:917 builtin/update-index.c:90
+#, c-format
+msgid "failed to stat %s"
+msgstr "對 %s 呼叫 stat 失敗"
+
+#: builtin/pack-objects.c:970
+#, c-format
+msgid "wrote %<PRIu32> objects while expecting %<PRIu32>"
+msgstr "寫入 %<PRIu32> 個物件而預期 %<PRIu32> 個"
+
+#: builtin/pack-objects.c:1164
+msgid "disabling bitmap writing, as some objects are not being packed"
+msgstr "禁用 bitmap 寫入，因為一些物件將不會被打包"
+
+#: builtin/pack-objects.c:1592
+#, c-format
+msgid "delta base offset overflow in pack for %s"
+msgstr "%s 壓縮中 delta 基準位移越界"
+
+#: builtin/pack-objects.c:1601
+#, c-format
+msgid "delta base offset out of bound for %s"
+msgstr "%s 的 delta 基準位移越界"
+
+#: builtin/pack-objects.c:1870
+msgid "Counting objects"
+msgstr "物件計數中"
+
+#: builtin/pack-objects.c:2000
+#, c-format
+msgid "unable to get size of %s"
+msgstr "不能得到 %s 的大小"
+
+#: builtin/pack-objects.c:2015
+#, c-format
+msgid "unable to parse object header of %s"
+msgstr "無法解析物件 %s 標頭訊息"
+
+#: builtin/pack-objects.c:2085 builtin/pack-objects.c:2101
+#: builtin/pack-objects.c:2111
+#, c-format
+msgid "object %s cannot be read"
+msgstr "物件 %s 無法讀取"
+
+#: builtin/pack-objects.c:2088 builtin/pack-objects.c:2115
+#, c-format
+msgid "object %s inconsistent object length (%<PRIuMAX> vs %<PRIuMAX>)"
+msgstr "物件 %s 不一致的物件長度（%<PRIuMAX> vs %<PRIuMAX>）"
+
+#: builtin/pack-objects.c:2125
+msgid "suboptimal pack - out of memory"
+msgstr "次優（suboptimal）打包 - 記憶體不足"
+
+#: builtin/pack-objects.c:2440
+#, c-format
+msgid "Delta compression using up to %d threads"
+msgstr "使用 %d 個執行緒進行壓縮"
+
+#: builtin/pack-objects.c:2572
+#, c-format
+msgid "unable to pack objects reachable from tag %s"
+msgstr "無法為標籤 %s 壓縮物件"
+
+#: builtin/pack-objects.c:2659
+msgid "Compressing objects"
+msgstr "壓縮物件中"
+
+#: builtin/pack-objects.c:2665
+msgid "inconsistency with delta count"
+msgstr "不一致的差異計數"
+
+#: builtin/pack-objects.c:2742
+#, c-format
+msgid ""
+"expected edge object ID, got garbage:\n"
+" %s"
+msgstr ""
+"預期邊界物件（edge object）ID，卻得到垃圾資料：\n"
+" %s"
+
+#: builtin/pack-objects.c:2748
+#, c-format
+msgid ""
+"expected object ID, got garbage:\n"
+" %s"
+msgstr ""
+"預期物件 ID，卻得到垃圾資料：\n"
+" %s"
+
+#: builtin/pack-objects.c:2846
+msgid "invalid value for --missing"
+msgstr "選項 --missing 的值無效"
+
+#: builtin/pack-objects.c:2905 builtin/pack-objects.c:3013
+msgid "cannot open pack index"
+msgstr "無法開啟包檔案索引"
+
+#: builtin/pack-objects.c:2936
+#, c-format
+msgid "loose object at %s could not be examined"
+msgstr "無法檢查 %s 處的鬆散物件"
+
+#: builtin/pack-objects.c:3021
+msgid "unable to force loose object"
+msgstr "無法強制鬆散物件"
+
+#: builtin/pack-objects.c:3113
+#, c-format
+msgid "not a rev '%s'"
+msgstr "不是一個版本 '%s'"
+
+#: builtin/pack-objects.c:3116
+#, c-format
+msgid "bad revision '%s'"
+msgstr "壞的版本 '%s'"
+
+#: builtin/pack-objects.c:3141
+msgid "unable to add recent objects"
+msgstr "無法新增最近的物件"
+
+#: builtin/pack-objects.c:3194
+#, c-format
+msgid "unsupported index version %s"
+msgstr "不支援的索引版本 %s"
+
+#: builtin/pack-objects.c:3198
+#, c-format
+msgid "bad index version '%s'"
+msgstr "壞的索引版本 '%s'"
+
+#: builtin/pack-objects.c:3236
+msgid "<version>[,<offset>]"
+msgstr "<版本>[,<位移>]"
+
+#: builtin/pack-objects.c:3237
+msgid "write the pack index file in the specified idx format version"
+msgstr "用指定的 idx 格式版本來寫包索引檔案"
+
+#: builtin/pack-objects.c:3240
+msgid "maximum size of each output pack file"
+msgstr "每個輸出包的最大尺寸"
+
+#: builtin/pack-objects.c:3242
+msgid "ignore borrowed objects from alternate object store"
+msgstr "忽略從備用物件儲存裡借用物件"
+
+#: builtin/pack-objects.c:3244
+msgid "ignore packed objects"
+msgstr "忽略包物件"
+
+#: builtin/pack-objects.c:3246
+msgid "limit pack window by objects"
+msgstr "限制打包視窗的物件數"
+
+#: builtin/pack-objects.c:3248
+msgid "limit pack window by memory in addition to object limit"
+msgstr "除物件數量限制外設定打包視窗的記憶體限制"
+
+#: builtin/pack-objects.c:3250
+msgid "maximum length of delta chain allowed in the resulting pack"
+msgstr "打包允許的 delta 鏈的最大長度"
+
+#: builtin/pack-objects.c:3252
+msgid "reuse existing deltas"
+msgstr "重用已存在的 deltas"
+
+#: builtin/pack-objects.c:3254
+msgid "reuse existing objects"
+msgstr "重用已存在的物件"
+
+#: builtin/pack-objects.c:3256
+msgid "use OFS_DELTA objects"
+msgstr "使用 OFS_DELTA 物件"
+
+#: builtin/pack-objects.c:3258
+msgid "use threads when searching for best delta matches"
+msgstr "使用執行緒查詢最佳 delta 符合"
+
+#: builtin/pack-objects.c:3260
+msgid "do not create an empty pack output"
+msgstr "不建立空的包輸出"
+
+#: builtin/pack-objects.c:3262
+msgid "read revision arguments from standard input"
+msgstr "從標準輸入讀取版本號參數"
+
+#: builtin/pack-objects.c:3264
+msgid "limit the objects to those that are not yet packed"
+msgstr "限制那些尚未打包的物件"
+
+#: builtin/pack-objects.c:3267
+msgid "include objects reachable from any reference"
+msgstr "包括可以從任何引用存取到的物件"
+
+#: builtin/pack-objects.c:3270
+msgid "include objects referred by reflog entries"
+msgstr "包括被引用日誌引用到的物件"
+
+#: builtin/pack-objects.c:3273
+msgid "include objects referred to by the index"
+msgstr "包括被索引引用到的物件"
+
+#: builtin/pack-objects.c:3276
+msgid "output pack to stdout"
+msgstr "輸出包到標準輸出"
+
+#: builtin/pack-objects.c:3278
+msgid "include tag objects that refer to objects to be packed"
+msgstr "包括那些引用了待打包物件的標籤物件"
+
+#: builtin/pack-objects.c:3280
+msgid "keep unreachable objects"
+msgstr "維持無法取得的物件"
+
+#: builtin/pack-objects.c:3282
+msgid "pack loose unreachable objects"
+msgstr "打包鬆散的無法取得物件"
+
+#: builtin/pack-objects.c:3284
+msgid "unpack unreachable objects newer than <time>"
+msgstr "將比提供 <時間> 新的無法存取的物件解包"
+
+#: builtin/pack-objects.c:3287
+msgid "use the sparse reachability algorithm"
+msgstr "使用稀疏可以取得性演算法"
+
+#: builtin/pack-objects.c:3289
+msgid "create thin packs"
+msgstr "建立精簡包"
+
+#: builtin/pack-objects.c:3291
+msgid "create packs suitable for shallow fetches"
+msgstr "建立適合淺複製版本庫取得的包"
+
+#: builtin/pack-objects.c:3293
+msgid "ignore packs that have companion .keep file"
+msgstr "忽略配有 .keep 檔案的包"
+
+#: builtin/pack-objects.c:3295
+msgid "ignore this pack"
+msgstr "忽略該 pack"
+
+#: builtin/pack-objects.c:3297
+msgid "pack compression level"
+msgstr "打包壓縮級別"
+
+#: builtin/pack-objects.c:3299
+msgid "do not hide commits by grafts"
+msgstr "顯示被移植隱藏的提交"
+
+#: builtin/pack-objects.c:3301
+msgid "use a bitmap index if available to speed up counting objects"
+msgstr "使用 bitmap 索引（如果有的話）以提高物件計數時的速度"
+
+#: builtin/pack-objects.c:3303
+msgid "write a bitmap index together with the pack index"
+msgstr "在建立包索引的同時建立 bitmap 索引"
+
+#: builtin/pack-objects.c:3307
+msgid "write a bitmap index if possible"
+msgstr "如果可能，寫 bitmap 索引"
+
+#: builtin/pack-objects.c:3311
+msgid "handling for missing objects"
+msgstr "處理遺失的物件"
+
+#: builtin/pack-objects.c:3314
+msgid "do not pack objects in promisor packfiles"
+msgstr "不要打包 promisor packfile 中的物件"
+
+#: builtin/pack-objects.c:3316
+msgid "respect islands during delta compression"
+msgstr "在增量壓縮時參考資料島"
+
+#: builtin/pack-objects.c:3345
+#, c-format
+msgid "delta chain depth %d is too deep, forcing %d"
+msgstr "增量鏈深度 %d 太深了，強制為 %d"
+
+#: builtin/pack-objects.c:3350
+#, c-format
+msgid "pack.deltaCacheLimit is too high, forcing %d"
+msgstr "設定 pack.deltaCacheLimit 太高了，強制為 %d"
+
+#: builtin/pack-objects.c:3404
+msgid "--max-pack-size cannot be used to build a pack for transfer"
+msgstr "不能使用 --max-pack-size 來構建傳輸用的包檔案"
+
+#: builtin/pack-objects.c:3406
+msgid "minimum pack size limit is 1 MiB"
+msgstr "最小的包檔案大小是 1 MiB"
+
+#: builtin/pack-objects.c:3411
+msgid "--thin cannot be used to build an indexable pack"
+msgstr "--thin 不能用於建立一個可索引包"
+
+#: builtin/pack-objects.c:3414
+msgid "--keep-unreachable and --unpack-unreachable are incompatible"
+msgstr "--keep-unreachable 和 --unpack-unreachable 不相容"
+
+#: builtin/pack-objects.c:3420
+msgid "cannot use --filter without --stdout"
+msgstr "不能在沒有 --stdout 的情況下使用 --filter"
+
+#: builtin/pack-objects.c:3481
+msgid "Enumerating objects"
+msgstr "枚舉物件"
+
+#: builtin/pack-objects.c:3511
+#, c-format
+msgid "Total %<PRIu32> (delta %<PRIu32>), reused %<PRIu32> (delta %<PRIu32>)"
+msgstr "總共 %<PRIu32> （差異 %<PRIu32>），復用 %<PRIu32> （差異 %<PRIu32>）"
+
+#: builtin/pack-refs.c:8
+msgid "git pack-refs [<options>]"
+msgstr "git pack-refs [<選項>]"
+
+#: builtin/pack-refs.c:16
+msgid "pack everything"
+msgstr "打包一切"
+
+#: builtin/pack-refs.c:17
+msgid "prune loose refs (default)"
+msgstr "清除鬆散的引用（預設）"
+
+#: builtin/prune-packed.c:9
+msgid "git prune-packed [-n | --dry-run] [-q | --quiet]"
+msgstr "git prune-packed [-n | --dry-run] [-q | --quiet]"
+
+#: builtin/prune-packed.c:42
+msgid "Removing duplicate objects"
+msgstr "正在刪除重複物件"
+
+#: builtin/prune.c:12
+msgid "git prune [-n] [-v] [--progress] [--expire <time>] [--] [<head>...]"
+msgstr "git prune [-n] [-v] [--progress] [--expire <時間>] [--] [<head>...]"
+
+#: builtin/prune.c:131
+msgid "report pruned objects"
+msgstr "報告清除的物件"
+
+#: builtin/prune.c:134
+msgid "expire objects older than <time>"
+msgstr "使早於提供時間的物件過期"
+
+#: builtin/prune.c:136
+msgid "limit traversal to objects outside promisor packfiles"
+msgstr "限制遍歷 promisor packfile 以外的物件"
+
+#: builtin/prune.c:150
+msgid "cannot prune in a precious-objects repo"
+msgstr "不能在珍品版本庫中執行清理動作"
+
+#: builtin/pull.c:66 builtin/pull.c:68
+#, c-format
+msgid "Invalid value for %s: %s"
+msgstr "%s 的值無效：%s"
+
+#: builtin/pull.c:88
+msgid "git pull [<options>] [<repository> [<refspec>...]]"
+msgstr "git pull [<選項>] [<版本庫> [<引用規格>...]]"
+
+#: builtin/pull.c:142
+msgid "control for recursive fetching of submodules"
+msgstr "控制子模組的遞迴取得"
+
+#: builtin/pull.c:146
+msgid "Options related to merging"
+msgstr "和合併相關的選項"
+
+#: builtin/pull.c:149
+msgid "incorporate changes by rebasing rather than merging"
+msgstr "使用重定基底動作取代合併動作以套用修改"
+
+#: builtin/pull.c:177 builtin/rebase.c:467 builtin/revert.c:126
+msgid "allow fast-forward"
+msgstr "允許快轉式"
+
+#: builtin/pull.c:186
+msgid "automatically stash/stash pop before and after rebase"
+msgstr "重定基底動作前後執行自動儲藏和彈出儲藏"
+
+#: builtin/pull.c:202
+msgid "Options related to fetching"
+msgstr "和取得相關的參數"
+
+#: builtin/pull.c:212
+msgid "force overwrite of local branch"
+msgstr "強制覆蓋本機分支"
+
+#: builtin/pull.c:220
+msgid "number of submodules pulled in parallel"
+msgstr "並發拉取的子模組的數量"
+
+#: builtin/pull.c:320
+#, c-format
+msgid "Invalid value for pull.ff: %s"
+msgstr "pull.ff 的取值無效：%s"
+
+#: builtin/pull.c:437
+msgid ""
+"There is no candidate for rebasing against among the refs that you just "
+"fetched."
+msgstr "在您剛剛取得到的引用中沒有重定基底動作的候選。"
+
+#: builtin/pull.c:439
+msgid ""
+"There are no candidates for merging among the refs that you just fetched."
+msgstr "在您剛剛取得到的引用中沒有合併動作的候選。"
+
+#: builtin/pull.c:440
+msgid ""
+"Generally this means that you provided a wildcard refspec which had no\n"
+"matches on the remote end."
+msgstr "通常這意味著您提供了一萬用字元引用規格但未能和遠端符合。"
+
+#: builtin/pull.c:443
+#, c-format
+msgid ""
+"You asked to pull from the remote '%s', but did not specify\n"
+"a branch. Because this is not the default configured remote\n"
+"for your current branch, you must specify a branch on the command line."
+msgstr ""
+"您要求從遠端 '%s' 拉取，但是未指定一個分支。因為這不是目前\n"
+"分支預設的遠端版本庫，您必須在指令列中指定一個分支名。"
+
+#: builtin/pull.c:448 builtin/rebase.c:1375 git-parse-remote.sh:73
+msgid "You are not currently on a branch."
+msgstr "您目前不在一個分支上。"
+
+#: builtin/pull.c:450 builtin/pull.c:465 git-parse-remote.sh:79
+msgid "Please specify which branch you want to rebase against."
+msgstr "請指定您要重定基底到哪一個分支。"
+
+#: builtin/pull.c:452 builtin/pull.c:467 git-parse-remote.sh:82
+msgid "Please specify which branch you want to merge with."
+msgstr "請指定您要合併哪一個分支。"
+
+#: builtin/pull.c:453 builtin/pull.c:468
+msgid "See git-pull(1) for details."
+msgstr "詳見 git-pull(1)。"
+
+#: builtin/pull.c:455 builtin/pull.c:461 builtin/pull.c:470
+#: builtin/rebase.c:1381 git-parse-remote.sh:64
+msgid "<remote>"
+msgstr "<遠端>"
+
+#: builtin/pull.c:455 builtin/pull.c:470 builtin/pull.c:475
+#: git-parse-remote.sh:65
+msgid "<branch>"
+msgstr "<分支>"
+
+#: builtin/pull.c:463 builtin/rebase.c:1373 git-parse-remote.sh:75
+msgid "There is no tracking information for the current branch."
+msgstr "目前分支沒有追蹤訊息。"
+
+#: builtin/pull.c:472 git-parse-remote.sh:95
+msgid ""
+"If you wish to set tracking information for this branch you can do so with:"
+msgstr "如果您想要為此分支建立追蹤訊息，您可以執行："
+
+#: builtin/pull.c:477
+#, c-format
+msgid ""
+"Your configuration specifies to merge with the ref '%s'\n"
+"from the remote, but no such ref was fetched."
+msgstr ""
+"您的設定中指定要合併遠端的引用 '%s'，\n"
+"但是沒有取得到這個引用。"
+
+#: builtin/pull.c:587
+#, c-format
+msgid "unable to access commit %s"
+msgstr "無法存取提交 %s"
+
+#: builtin/pull.c:867
+msgid "ignoring --verify-signatures for rebase"
+msgstr "為重定基底動作忽略 --verify-signatures"
+
+#: builtin/pull.c:922
+msgid "--[no-]autostash option is only valid with --rebase."
+msgstr "--[no-]autostash 選項只在使用 --rebase 時有效。"
+
+#: builtin/pull.c:930
+msgid "Updating an unborn branch with changes added to the index."
+msgstr "更新尚未誕生的分支，變更新增至索引。"
+
+#: builtin/pull.c:934
+msgid "pull with rebase"
+msgstr "重定基底式拉取"
+
+#: builtin/pull.c:935
+msgid "please commit or stash them."
+msgstr "請提交或儲藏它們。"
+
+#: builtin/pull.c:960
+#, c-format
+msgid ""
+"fetch updated the current branch head.\n"
+"fast-forwarding your working tree from\n"
+"commit %s."
+msgstr ""
+"fetch 更新了目前的分支。快轉您的工作區\n"
+"至提交 %s。"
+
+#: builtin/pull.c:966
+#, c-format
+msgid ""
+"Cannot fast-forward your working tree.\n"
+"After making sure that you saved anything precious from\n"
+"$ git diff %s\n"
+"output, run\n"
+"$ git reset --hard\n"
+"to recover."
+msgstr ""
+"您目前的工作區無法執行快轉動作。\n"
+"首先執行如下指令：\n"
+"$ git diff %s\n"
+"以確認所有有用的資料均已儲存。然後執行下面的指令\n"
+"$ git reset --hard\n"
+"復原之前的狀態。"
+
+#: builtin/pull.c:981
+msgid "Cannot merge multiple branches into empty head."
+msgstr "無法將多個分支合併到空分支。"
+
+#: builtin/pull.c:985
+msgid "Cannot rebase onto multiple branches."
+msgstr "無法重定基底到多個分支。"
+
+#: builtin/pull.c:992
+msgid "cannot rebase with locally recorded submodule modifications"
+msgstr "本機子模組中有修改，無法重定基底"
+
+#: builtin/push.c:19
+msgid "git push [<options>] [<repository> [<refspec>...]]"
+msgstr "git push [<選項>] [<版本庫> [<引用規格>...]]"
+
+#: builtin/push.c:112
+msgid "tag shorthand without <tag>"
+msgstr "標籤後面未提供 <標籤> 參數"
+
+#: builtin/push.c:122
+msgid "--delete only accepts plain target ref names"
+msgstr "--delete 只接受簡單的目標引用名"
+
+#: builtin/push.c:168
+msgid ""
+"\n"
+"To choose either option permanently, see push.default in 'git help config'."
+msgstr ""
+"\n"
+"為了永久地選擇任一選項，參見 'git help config' 中的 push.default。"
+
+#: builtin/push.c:171
+#, c-format
+msgid ""
+"The upstream branch of your current branch does not match\n"
+"the name of your current branch.  To push to the upstream branch\n"
+"on the remote, use\n"
+"\n"
+"    git push %s HEAD:%s\n"
+"\n"
+"To push to the branch of the same name on the remote, use\n"
+"\n"
+"    git push %s HEAD\n"
+"%s"
+msgstr ""
+"您目前分支的上游分支和您目前分支名不符合，為推送到遠端的上游分支，\n"
+"使用\n"
+"\n"
+"    git push %s HEAD:%s\n"
+"\n"
+"為推送至遠端同名分支，使用\n"
+"\n"
+"    git push %s HEAD\n"
+"%s"
+
+#: builtin/push.c:186
+#, c-format
+msgid ""
+"You are not currently on a branch.\n"
+"To push the history leading to the current (detached HEAD)\n"
+"state now, use\n"
+"\n"
+"    git push %s HEAD:<name-of-remote-branch>\n"
+msgstr ""
+"您目前不在一個分支上。\n"
+"現在為推送目前（分離開頭指標）的歷史，使用\n"
+"\n"
+"    git push %s HEAD:<遠端分支名字>\n"
+
+#: builtin/push.c:200
+#, c-format
+msgid ""
+"The current branch %s has no upstream branch.\n"
+"To push the current branch and set the remote as upstream, use\n"
+"\n"
+"    git push --set-upstream %s %s\n"
+msgstr ""
+"目前分支 %s 沒有對應的上游分支。\n"
+"為推送目前分支並建立與遠端上游的追蹤，使用\n"
+"\n"
+"    git push --set-upstream %s %s\n"
+
+#: builtin/push.c:208
+#, c-format
+msgid "The current branch %s has multiple upstream branches, refusing to push."
+msgstr "目前分支 %s 有多個上游分支，拒絕推送。"
+
+#: builtin/push.c:211
+#, c-format
+msgid ""
+"You are pushing to remote '%s', which is not the upstream of\n"
+"your current branch '%s', without telling me what to push\n"
+"to update which remote branch."
+msgstr ""
+"您正推送至遠端 '%s'（其並非目前分支 '%s' 的上游），\n"
+"而沒有告訴我要推送什麼、更新哪個遠端分支。"
+
+#: builtin/push.c:270
+msgid ""
+"You didn't specify any refspecs to push, and push.default is \"nothing\"."
+msgstr "您沒有為推送指定任何引用規格，並且 push.default 為 \"nothing\"。"
+
+#: builtin/push.c:277
+msgid ""
+"Updates were rejected because the tip of your current branch is behind\n"
+"its remote counterpart. Integrate the remote changes (e.g.\n"
+"'git pull ...') before pushing again.\n"
+"See the 'Note about fast-forwards' in 'git push --help' for details."
+msgstr ""
+"更新被拒絕，因為您目前分支的最新提交落後於其對應的遠端分支。\n"
+"再次推送前，先與遠端變更合併（如 'git pull ...'）。詳見\n"
+"'git push --help' 中的 'Note about fast-forwards' 小節。"
+
+#: builtin/push.c:283
+msgid ""
+"Updates were rejected because a pushed branch tip is behind its remote\n"
+"counterpart. Check out this branch and integrate the remote changes\n"
+"(e.g. 'git pull ...') before pushing again.\n"
+"See the 'Note about fast-forwards' in 'git push --help' for details."
+msgstr ""
+"更新被拒絕，因為推送的一個分支的最新提交落後於其對應的遠端分支。\n"
+"簽出該分支並整合遠端變更（如 'git pull ...'），然後再推送。詳見\n"
+"'git push --help' 中的 'Note about fast-forwards' 小節。"
+
+#: builtin/push.c:289
+msgid ""
+"Updates were rejected because the remote contains work that you do\n"
+"not have locally. This is usually caused by another repository pushing\n"
+"to the same ref. You may want to first integrate the remote changes\n"
+"(e.g., 'git pull ...') before pushing again.\n"
+"See the 'Note about fast-forwards' in 'git push --help' for details."
+msgstr ""
+"因為遠端版本庫包含您本機尚不存在的提交，而導致更新被拒絕。這通常是因為另外\n"
+"一個版本庫已向該引用進行了推送。再次推送前，您可能需要先整合遠端變更\n"
+"（如 'git pull ...'）。\n"
+"詳見 'git push --help' 中的 'Note about fast-forwards' 小節。"
+
+#: builtin/push.c:296
+msgid "Updates were rejected because the tag already exists in the remote."
+msgstr "更新被拒絕，因為該標籤在遠端已經存在。"
+
+#: builtin/push.c:299
+msgid ""
+"You cannot update a remote ref that points at a non-commit object,\n"
+"or update a remote ref to make it point at a non-commit object,\n"
+"without using the '--force' option.\n"
+msgstr ""
+"如果不使用 '--force' 參數，您不能更新一個指向非提交物件的遠端引用，\n"
+"也不能更新遠端引用讓其指向一個非提交物件。\n"
+
+#: builtin/push.c:360
+#, c-format
+msgid "Pushing to %s\n"
+msgstr "推送到 %s\n"
+
+#: builtin/push.c:367
+#, c-format
+msgid "failed to push some refs to '%s'"
+msgstr "推送一些引用到 '%s' 失敗"
+
+#: builtin/push.c:542
+msgid "repository"
+msgstr "版本庫"
+
+#: builtin/push.c:543 builtin/send-pack.c:164
+msgid "push all refs"
+msgstr "推送所有引用"
+
+#: builtin/push.c:544 builtin/send-pack.c:166
+msgid "mirror all refs"
+msgstr "鏡像所有引用"
+
+#: builtin/push.c:546
+msgid "delete refs"
+msgstr "刪除引用"
+
+#: builtin/push.c:547
+msgid "push tags (can't be used with --all or --mirror)"
+msgstr "推送標籤（不能使用 --all or --mirror）"
+
+#: builtin/push.c:550 builtin/send-pack.c:167
+msgid "force updates"
+msgstr "強制更新"
+
+#: builtin/push.c:552 builtin/send-pack.c:181
+msgid "<refname>:<expect>"
+msgstr "<引用名>:<期望值>"
+
+#: builtin/push.c:553 builtin/send-pack.c:182
+msgid "require old value of ref to be at this value"
+msgstr "要求引用舊的取值為設定值"
+
+#: builtin/push.c:556
+msgid "control recursive pushing of submodules"
+msgstr "控制子模組的遞迴推送"
+
+#: builtin/push.c:558 builtin/send-pack.c:175
+msgid "use thin pack"
+msgstr "使用精簡打包"
+
+#: builtin/push.c:559 builtin/push.c:560 builtin/send-pack.c:161
+#: builtin/send-pack.c:162
+msgid "receive pack program"
+msgstr "接收包程式"
+
+#: builtin/push.c:561
+msgid "set upstream for git pull/status"
+msgstr "設定 git pull/status 的上游"
+
+#: builtin/push.c:564
+msgid "prune locally removed refs"
+msgstr "清除本機刪除的引用"
+
+#: builtin/push.c:566
+msgid "bypass pre-push hook"
+msgstr "繞過 pre-push 掛鉤"
+
+#: builtin/push.c:567
+msgid "push missing but relevant tags"
+msgstr "推送缺少但有關的標籤"
+
+#: builtin/push.c:570 builtin/send-pack.c:169
+msgid "GPG sign the push"
+msgstr "用 GPG 為推送簽名"
+
+#: builtin/push.c:572 builtin/send-pack.c:176
+msgid "request atomic transaction on remote side"
+msgstr "需要遠端支援原子事務"
+
+#: builtin/push.c:590
+msgid "--delete is incompatible with --all, --mirror and --tags"
+msgstr "--delete 與 --all、--mirror 及 --tags 不相容"
+
+#: builtin/push.c:592
+msgid "--delete doesn't make sense without any refs"
+msgstr "--delete 未接任何引用沒有意義"
+
+#: builtin/push.c:612
+#, c-format
+msgid "bad repository '%s'"
+msgstr "壞的版本庫 '%s'"
+
+#: builtin/push.c:613
+msgid ""
+"No configured push destination.\n"
+"Either specify the URL from the command-line or configure a remote "
+"repository using\n"
+"\n"
+"    git remote add <name> <url>\n"
+"\n"
+"and then push using the remote name\n"
+"\n"
+"    git push <name>\n"
+msgstr ""
+"沒有設定推送目標。\n"
+"或透過指令列指定 URL，或用下面指令設定一個遠端版本庫\n"
+"\n"
+"    git remote add <名稱> <位址>\n"
+"\n"
+"然後使用該遠端版本庫名執行推送\n"
+"\n"
+"    git push <名稱>\n"
+
+#: builtin/push.c:628
+msgid "--all and --tags are incompatible"
+msgstr "--all 和 --tags 不相容"
+
+#: builtin/push.c:630
+msgid "--all can't be combined with refspecs"
+msgstr "--all 不能和引用規格同時使用"
+
+#: builtin/push.c:634
+msgid "--mirror and --tags are incompatible"
+msgstr "--mirror 和 --tags 不相容"
+
+#: builtin/push.c:636
+msgid "--mirror can't be combined with refspecs"
+msgstr "--mirror 不能和引用規格同時使用"
+
+#: builtin/push.c:639
+msgid "--all and --mirror are incompatible"
+msgstr "--all 和 --mirror 不相容"
+
+#: builtin/push.c:643
+msgid "push options must not have new line characters"
+msgstr "推送選項不能有換行符號"
+
+#: builtin/range-diff.c:8
+msgid "git range-diff [<options>] <old-base>..<old-tip> <new-base>..<new-tip>"
+msgstr "git range-diff [<選項>] <old-base>..<old-tip> <new-base>..<new-tip>"
+
+#: builtin/range-diff.c:9
+msgid "git range-diff [<options>] <old-tip>...<new-tip>"
+msgstr "git range-diff [<選項>] <old-tip>...<new-tip>"
+
+#: builtin/range-diff.c:10
+msgid "git range-diff [<options>] <base> <old-tip> <new-tip>"
+msgstr "git range-diff [<選項>] <base> <old-tip> <new-tip>"
+
+#: builtin/range-diff.c:22
+msgid "Percentage by which creation is weighted"
+msgstr "建立權重的百分比"
+
+#: builtin/range-diff.c:24
+msgid "use simple diff colors"
+msgstr "使用簡單差異顏色"
+
+#: builtin/range-diff.c:26
+#| msgid "notes-ref"
+msgid "notes"
+msgstr "註解"
+
+#: builtin/range-diff.c:26
+#| msgid "passed to 'git am'"
+msgid "passed to 'git log'"
+msgstr "傳遞給 'git log'"
+
+#: builtin/range-diff.c:50 builtin/range-diff.c:54
+#, c-format
+msgid "no .. in range: '%s'"
+msgstr "沒有在範圍中使用 ..：'%s'"
+
+#: builtin/range-diff.c:64
+msgid "single arg format must be symmetric range"
+msgstr "單個參數格式必須是對稱範圍（即包含...）"
+
+#: builtin/range-diff.c:79
+msgid "need two commit ranges"
+msgstr "需要兩個提交範圍"
+
+#: builtin/read-tree.c:41
+msgid ""
+"git read-tree [(-m [--trivial] [--aggressive] | --reset | --prefix=<prefix>) "
+"[-u [--exclude-per-directory=<gitignore>] | -i]] [--no-sparse-checkout] [--"
+"index-output=<file>] (--empty | <tree-ish1> [<tree-ish2> [<tree-ish3>]])"
+msgstr ""
+"git read-tree [(-m [--trivial] [--aggressive] | --reset | --prefix=<前綴>) [-"
+"u [--exclude-per-directory=<gitignore>] | -i]] [--no-sparse-checkout] [--"
+"index-output=<檔案>] (--empty | <樹狀物件1> [<樹狀物件2> [<樹狀物件3>]])"
+
+#: builtin/read-tree.c:124
+msgid "write resulting index to <file>"
+msgstr "將索引結果寫入 <檔案>"
+
+#: builtin/read-tree.c:127
+msgid "only empty the index"
+msgstr "只是清空索引"
+
+#: builtin/read-tree.c:129
+msgid "Merging"
+msgstr "合併"
+
+#: builtin/read-tree.c:131
+msgid "perform a merge in addition to a read"
+msgstr "讀取之餘再執行一個合併"
+
+#: builtin/read-tree.c:133
+msgid "3-way merge if no file level merging required"
+msgstr "如果沒有檔案級合併需要，執行三方合併"
+
+#: builtin/read-tree.c:135
+msgid "3-way merge in presence of adds and removes"
+msgstr "存在新增和刪除時，也執行三方合併"
+
+#: builtin/read-tree.c:137
+msgid "same as -m, but discard unmerged entries"
+msgstr "類似於 -m，但捨棄未合併的條目"
+
+#: builtin/read-tree.c:138
+msgid "<subdirectory>/"
+msgstr "<子目錄>/"
+
+#: builtin/read-tree.c:139
+msgid "read the tree into the index under <subdirectory>/"
+msgstr "讀取樹狀物件到索引的 <子目錄>/ 下"
+
+#: builtin/read-tree.c:142
+msgid "update working tree with merge result"
+msgstr "用合併的結果更新工作區"
+
+#: builtin/read-tree.c:144
+msgid "gitignore"
+msgstr "gitignore"
+
+#: builtin/read-tree.c:145
+msgid "allow explicitly ignored files to be overwritten"
+msgstr "允許忽略檔案中設定的檔案可以被覆蓋"
+
+#: builtin/read-tree.c:148
+msgid "don't check the working tree after merging"
+msgstr "合併後不檢查工作區"
+
+#: builtin/read-tree.c:149
+msgid "don't update the index or the work tree"
+msgstr "不更新索引區和工作區"
+
+#: builtin/read-tree.c:151
+msgid "skip applying sparse checkout filter"
+msgstr "跳過應用稀疏簽出過濾器"
+
+#: builtin/read-tree.c:153
+msgid "debug unpack-trees"
+msgstr "除錯 unpack-trees"
+
+#: builtin/read-tree.c:157
+msgid "suppress feedback messages"
+msgstr "抑制回饋訊息"
+
+#: builtin/read-tree.c:188
+#| msgid "you need to resolve your current index first"
+msgid "You need to resolve your current index first"
+msgstr "您需要先解決目前索引的衝突"
+
+#: builtin/rebase.c:32
+msgid ""
+"git rebase [-i] [options] [--exec <cmd>] [--onto <newbase> | --keep-base] "
+"[<upstream> [<branch>]]"
+msgstr ""
+"git rebase [-i] [options] [--exec <指令>] [--onto <新基礎> | --keep-base] [<"
+"上游> [<分支>]]"
+
+#: builtin/rebase.c:34
+msgid ""
+"git rebase [-i] [options] [--exec <cmd>] [--onto <newbase>] --root [<branch>]"
+msgstr "git rebase [-i] [選項] [--exec <指令>] [--onto <新基礎>] --root [<分支>]"
+
+#: builtin/rebase.c:36
+msgid "git rebase --continue | --abort | --skip | --edit-todo"
+msgstr "git rebase --continue | --abort | --skip | --edit-todo"
+
+#: builtin/rebase.c:177 builtin/rebase.c:201 builtin/rebase.c:228
+#, c-format
+msgid "unusable todo list: '%s'"
+msgstr "不可用的待辦列表：'%s'"
+
+#: builtin/rebase.c:186 builtin/rebase.c:212 builtin/rebase.c:236
+#, c-format
+msgid "could not write '%s'."
+msgstr "不能寫入 '%s'。"
+
+#: builtin/rebase.c:271
+msgid "no HEAD?"
+msgstr "沒有 HEAD？"
+
+#: builtin/rebase.c:298
+#, c-format
+msgid "could not create temporary %s"
+msgstr "無法建立暫時的 %s"
+
+#: builtin/rebase.c:304
+msgid "could not mark as interactive"
+msgstr "無法標記為互動式"
+
+#: builtin/rebase.c:362
+msgid "could not generate todo list"
+msgstr "無法生成待辦列表"
+
+#: builtin/rebase.c:402
+msgid "a base commit must be provided with --upstream or --onto"
+msgstr "使用 --upstream 或 --onto 必須提供一個基礎提交"
+
+#: builtin/rebase.c:457
+msgid "git rebase--interactive [<options>]"
+msgstr "git rebase--interactive [<選項>]"
+
+#: builtin/rebase.c:469
+msgid "keep empty commits"
+msgstr "保持空提交"
+
+#: builtin/rebase.c:471 builtin/revert.c:128
+msgid "allow commits with empty messages"
+msgstr "允許提交說明為空"
+
+#: builtin/rebase.c:472
+msgid "rebase merge commits"
+msgstr "對合併提交重定基底"
+
+#: builtin/rebase.c:474
+msgid "keep original branch points of cousins"
+msgstr "保持兄弟提交的原始分支點"
+
+#: builtin/rebase.c:476
+msgid "move commits that begin with squash!/fixup!"
+msgstr "移動以 squash!/fixup! 開頭的提交"
+
+#: builtin/rebase.c:477
+msgid "sign commits"
+msgstr "簽名提交"
+
+#: builtin/rebase.c:479 builtin/rebase.c:1455
+msgid "display a diffstat of what changed upstream"
+msgstr "顯示上游變化的差異統計"
+
+#: builtin/rebase.c:481
+msgid "continue rebase"
+msgstr "繼續重定基底"
+
+#: builtin/rebase.c:483
+msgid "skip commit"
+msgstr "跳過提交"
+
+#: builtin/rebase.c:484
+msgid "edit the todo list"
+msgstr "重定基底待辦列表"
+
+#: builtin/rebase.c:486
+msgid "show the current patch"
+msgstr "顯示目前修補檔"
+
+#: builtin/rebase.c:489
+msgid "shorten commit ids in the todo list"
+msgstr "縮短待辦列表中的提交號"
+
+#: builtin/rebase.c:491
+msgid "expand commit ids in the todo list"
+msgstr "擴展待辦列表中的提交號"
+
+#: builtin/rebase.c:493
+msgid "check the todo list"
+msgstr "檢查待辦列表"
+
+#: builtin/rebase.c:495
+msgid "rearrange fixup/squash lines"
+msgstr "重新排列 fixup/squash 行"
+
+#: builtin/rebase.c:497
+msgid "insert exec commands in todo list"
+msgstr "在待辦列表中插入 exec 執行指令"
+
+#: builtin/rebase.c:498
+msgid "onto"
+msgstr "onto"
+
+#: builtin/rebase.c:501
+msgid "restrict-revision"
+msgstr "restrict-revision"
+
+#: builtin/rebase.c:501
+msgid "restrict revision"
+msgstr "限制版本"
+
+#: builtin/rebase.c:503
+msgid "squash-onto"
+msgstr "squash-onto"
+
+#: builtin/rebase.c:504
+msgid "squash onto"
+msgstr "squash onto"
+
+#: builtin/rebase.c:506
+msgid "the upstream commit"
+msgstr "上游提交"
+
+#: builtin/rebase.c:508
+msgid "head-name"
+msgstr "head-name"
+
+#: builtin/rebase.c:508
+msgid "head name"
+msgstr "head 名稱"
+
+#: builtin/rebase.c:513
+msgid "rebase strategy"
+msgstr "重定基底策略"
+
+#: builtin/rebase.c:514
+msgid "strategy-opts"
+msgstr "strategy-opts"
+
+#: builtin/rebase.c:515
+msgid "strategy options"
+msgstr "策略選項"
+
+#: builtin/rebase.c:516
+msgid "switch-to"
+msgstr "切換到"
+
+#: builtin/rebase.c:517
+msgid "the branch or commit to checkout"
+msgstr "要簽出的分支或提交"
+
+#: builtin/rebase.c:518
+msgid "onto-name"
+msgstr "onto-name"
+
+#: builtin/rebase.c:518
+msgid "onto name"
+msgstr "onto name"
+
+#: builtin/rebase.c:519
+msgid "cmd"
+msgstr "cmd"
+
+#: builtin/rebase.c:519
+msgid "the command to run"
+msgstr "要執行的指令"
+
+#: builtin/rebase.c:522 builtin/rebase.c:1540
+msgid "automatically re-schedule any `exec` that fails"
+msgstr "自動重新安排任何失敗的 `exec`"
+
+#: builtin/rebase.c:540
+msgid "--[no-]rebase-cousins has no effect without --rebase-merges"
+msgstr "不使用 --rebase-merges，則 --[no-]rebase-cousins 沒有效果"
+
+#: builtin/rebase.c:556
+#, c-format
+msgid "%s requires an interactive rebase"
+msgstr "%s 需要互動式重定基底"
+
+#: builtin/rebase.c:608
+#, c-format
+msgid "could not get 'onto': '%s'"
+msgstr "無法取得 'onto'：'%s'"
+
+#: builtin/rebase.c:623
+#, c-format
+msgid "invalid orig-head: '%s'"
+msgstr "無效的原始 head：'%s'"
+
+#: builtin/rebase.c:648
+#, c-format
+msgid "ignoring invalid allow_rerere_autoupdate: '%s'"
+msgstr "忽略無效的 allow_rerere_autoupdate：'%s'"
+
+#: builtin/rebase.c:724
+#, c-format
+msgid "Could not read '%s'"
+msgstr "不能讀取 '%s'"
+
+#: builtin/rebase.c:742
+#, c-format
+msgid "Cannot store %s"
+msgstr "不能儲存 %s"
+
+#: builtin/rebase.c:849
+msgid "could not determine HEAD revision"
+msgstr "不能確定 HEAD 版本"
+
+#: builtin/rebase.c:972 git-rebase--preserve-merges.sh:81
+msgid ""
+"Resolve all conflicts manually, mark them as resolved with\n"
+"\"git add/rm <conflicted_files>\", then run \"git rebase --continue\".\n"
+"You can instead skip this commit: run \"git rebase --skip\".\n"
+"To abort and get back to the state before \"git rebase\", run \"git rebase --"
+"abort\"."
+msgstr ""
+"手動解決所有衝突，執行 \"git add/rm <衝突的檔案>\" 標記\n"
+"衝突已解決，然後執行 \"git rebase --continue\"。您也可以執行\n"
+"\"git rebase --skip\" 指令跳過這個提交。如果想要終止執行並回到\n"
+"\"git rebase\" 執行之前的狀態，執行 \"git rebase --abort\"。"
+
+#: builtin/rebase.c:1060
+#, c-format
+msgid ""
+"\n"
+"git encountered an error while preparing the patches to replay\n"
+"these revisions:\n"
+"\n"
+"    %s\n"
+"\n"
+"As a result, git cannot rebase them."
+msgstr ""
+"\n"
+"在為重放這些版本而準備修補檔時，git 遇到了一個錯誤：\n"
+"\n"
+"    %s\n"
+"\n"
+"因此 git 無法對其重定基底。"
+
+#: builtin/rebase.c:1367
+#, c-format
+msgid ""
+"%s\n"
+"Please specify which branch you want to rebase against.\n"
+"See git-rebase(1) for details.\n"
+"\n"
+"    git rebase '<branch>'\n"
+"\n"
+msgstr ""
+"%s\n"
+"請指定您要重定基底到哪個分支。\n"
+"詳見 git-rebase(1)。\n"
+"\n"
+"    git rebase '<branch>'\n"
+"\n"
+
+#: builtin/rebase.c:1383
+#, c-format
+msgid ""
+"If you wish to set tracking information for this branch you can do so with:\n"
+"\n"
+"    git branch --set-upstream-to=%s/<branch> %s\n"
+"\n"
+msgstr ""
+"如果您想要為此分支建立追蹤訊息，您可以執行：\n"
+"\n"
+"    git branch --set-upstream-to=%s/<branch> %s\n"
+"\n"
+
+#: builtin/rebase.c:1413
+msgid "exec commands cannot contain newlines"
+msgstr "exec 指令不能包含換行符號"
+
+#: builtin/rebase.c:1417
+msgid "empty exec command"
+msgstr "空的 exec 指令"
+
+#: builtin/rebase.c:1446
+msgid "rebase onto given branch instead of upstream"
+msgstr "重定基底到提供的分支而非上游"
+
+#: builtin/rebase.c:1448
+msgid "use the merge-base of upstream and branch as the current base"
+msgstr "使用上游和分支的合併基礎做為目前基礎"
+
+#: builtin/rebase.c:1450
+msgid "allow pre-rebase hook to run"
+msgstr "允許執行 pre-rebase 掛鉤"
+
+#: builtin/rebase.c:1452
+msgid "be quiet. implies --no-stat"
+msgstr "安靜。暗示 --no-stat"
+
+#: builtin/rebase.c:1458
+msgid "do not show diffstat of what changed upstream"
+msgstr "不顯示上游變化的差異統計"
+
+#: builtin/rebase.c:1461
+msgid "add a Signed-off-by: line to each commit"
+msgstr "為每一個提交新增一個 Signed-off-by: 簽名"
+
+#: builtin/rebase.c:1464
+#| msgid "Group by committer rather than author"
+msgid "make committer date match author date"
+msgstr "使提交日期符合撰寫日期"
+
+#: builtin/rebase.c:1466
+msgid "ignore author date and use current date"
+msgstr "忽略撰寫日期，使用目前日期"
+
+#: builtin/rebase.c:1468
+#| msgid "synonym for --files-with-matches"
+msgid "synonym of --reset-author-date"
+msgstr "和 --reset-author-date 同義"
+
+#: builtin/rebase.c:1470 builtin/rebase.c:1474
+msgid "passed to 'git apply'"
+msgstr "傳遞給 'git apply'"
+
+#: builtin/rebase.c:1472
+#| msgid "ignore changes in whitespace at EOL"
+msgid "ignore changes in whitespace"
+msgstr "忽略空白字元變更"
+
+#: builtin/rebase.c:1476 builtin/rebase.c:1479
+msgid "cherry-pick all commits, even if unchanged"
+msgstr "揀選所有提交，即使未修改"
+
+#: builtin/rebase.c:1481
+msgid "continue"
+msgstr "繼續"
+
+#: builtin/rebase.c:1484
+msgid "skip current patch and continue"
+msgstr "跳過目前修補檔並繼續"
+
+#  譯者：請維持前導空格
+#: builtin/rebase.c:1486
+msgid "abort and check out the original branch"
+msgstr "終止並簽出原有分支"
+
+#: builtin/rebase.c:1489
+msgid "abort but keep HEAD where it is"
+msgstr "終止但保持 HEAD 不變"
+
+#: builtin/rebase.c:1490
+msgid "edit the todo list during an interactive rebase"
+msgstr "在互動式重定基底中編輯待辦列表"
+
+#: builtin/rebase.c:1493
+msgid "show the patch file being applied or merged"
+msgstr "顯示正在套用或合併的修補檔案"
+
+#: builtin/rebase.c:1496
+msgid "use merging strategies to rebase"
+msgstr "使用合併策略進行重定基底"
+
+#: builtin/rebase.c:1500
+msgid "let the user edit the list of commits to rebase"
+msgstr "讓使用者編輯要重定基底的提交列表"
+
+#: builtin/rebase.c:1504
+msgid "(DEPRECATED) try to recreate merges instead of ignoring them"
+msgstr "（已棄用）嘗試重建合併提交而非忽略它們"
+
+#: builtin/rebase.c:1509
+msgid "preserve empty commits during rebase"
+msgstr "重定基底時保留空提交"
+
+#: builtin/rebase.c:1511
+msgid "move commits that begin with squash!/fixup! under -i"
+msgstr "在 -i 互動模式下，移動以 squash!/fixup! 開頭的提交"
+
+#: builtin/rebase.c:1517
+msgid "automatically stash/stash pop before and after"
+msgstr "在動作前後執行自動儲藏和彈出儲藏"
+
+#: builtin/rebase.c:1519
+msgid "add exec lines after each commit of the editable list"
+msgstr "可編輯列表的每一個提交下面增加一行 exec"
+
+#: builtin/rebase.c:1523
+msgid "allow rebasing commits with empty messages"
+msgstr "允許針對空提交說明的提交重定基底"
+
+#: builtin/rebase.c:1526
+msgid "try to rebase merges instead of skipping them"
+msgstr "嘗試對合併提交重定基底而不是忽略它們"
+
+#: builtin/rebase.c:1529
+msgid "use 'merge-base --fork-point' to refine upstream"
+msgstr "使用 'merge-base --fork-point' 來最佳化上游"
+
+#: builtin/rebase.c:1531
+msgid "use the given merge strategy"
+msgstr "使用提供的合併策略"
+
+#: builtin/rebase.c:1533 builtin/revert.c:115
+msgid "option"
+msgstr "選項"
+
+#: builtin/rebase.c:1534
+msgid "pass the argument through to the merge strategy"
+msgstr "將參數傳遞給合併策略"
+
+#: builtin/rebase.c:1537
+msgid "rebase all reachable commits up to the root(s)"
+msgstr "將所有可以取得的提交重定基底到根提交"
+
+#: builtin/rebase.c:1554
+msgid ""
+"the rebase.useBuiltin support has been removed!\n"
+"See its entry in 'git help config' for details."
+msgstr ""
+"對 rebase.useBuiltin 的支援已被刪除！\n"
+"詳見 'git help config' 中的條目。"
+
+#: builtin/rebase.c:1560
+msgid "It looks like 'git am' is in progress. Cannot rebase."
+msgstr "看起來 'git-am' 正在執行中。無法重定基底。"
+
+#: builtin/rebase.c:1601
+msgid ""
+"git rebase --preserve-merges is deprecated. Use --rebase-merges instead."
+msgstr "git rebase --preserve-merges 被棄用。用 --rebase-merges 代替。"
+
+#: builtin/rebase.c:1606
+msgid "cannot combine '--keep-base' with '--onto'"
+msgstr "不能將 '--keep-base' 和 '--onto' 組合使用"
+
+#: builtin/rebase.c:1608
+msgid "cannot combine '--keep-base' with '--root'"
+msgstr "不能將 '--keep-base' 和 '--root' 組合使用"
+
+#: builtin/rebase.c:1612
+msgid "No rebase in progress?"
+msgstr "沒有正在進行的重定基底？"
+
+#: builtin/rebase.c:1616
+msgid "The --edit-todo action can only be used during interactive rebase."
+msgstr "動作 --edit-todo 只能用在互動式重定基底過程中。"
+
+#: builtin/rebase.c:1639
+msgid "Cannot read HEAD"
+msgstr "不能讀取 HEAD"
+
+#: builtin/rebase.c:1651
+msgid ""
+"You must edit all merge conflicts and then\n"
+"mark them as resolved using git add"
+msgstr ""
+"您必須編輯所有的合併衝突，然後透過 git add\n"
+"指令將它們標記為已解決"
+
+#: builtin/rebase.c:1670
+msgid "could not discard worktree changes"
+msgstr "無法捨棄工作區變更"
+
+#: builtin/rebase.c:1689
+#, c-format
+msgid "could not move back to %s"
+msgstr "無法移回 %s"
+
+#: builtin/rebase.c:1734
+#, c-format
+msgid ""
+"It seems that there is already a %s directory, and\n"
+"I wonder if you are in the middle of another rebase.  If that is the\n"
+"case, please try\n"
+"\t%s\n"
+"If that is not the case, please\n"
+"\t%s\n"
+"and run me again.  I am stopping in case you still have something\n"
+"valuable there.\n"
+msgstr ""
+"似乎已有一個 %s 目錄，我懷疑您正處於另外一個重定基底動作過程中。\n"
+"如果是這樣，請執行\n"
+"\t%s\n"
+"如果不是這樣，請執行\n"
+"\t%s\n"
+"然後再重新執行。 為避免遺失重要資料，我已經停止目前動作。\n"
+
+#: builtin/rebase.c:1757
+msgid "switch `C' expects a numerical value"
+msgstr "開關 `C' 期望一個數字值"
+
+#: builtin/rebase.c:1798
+#, c-format
+msgid "Unknown mode: %s"
+msgstr "未知模式：%s"
+
+#: builtin/rebase.c:1820
+msgid "--strategy requires --merge or --interactive"
+msgstr "--strategy 需要 --merge 或 --interactive"
+
+#: builtin/rebase.c:1860
+msgid "--reschedule-failed-exec requires --exec or --interactive"
+msgstr "--reschedule-failed-exec 需要 --exec 或 --interactive"
+
+#: builtin/rebase.c:1872
+msgid "cannot combine am options with either interactive or merge options"
+msgstr "不能將 am 選項與互動或合併選項同時使用"
+
+#: builtin/rebase.c:1891
+msgid "cannot combine '--preserve-merges' with '--rebase-merges'"
+msgstr "不能將 '--preserve-merges' 和 '--rebase-merges' 同時使用"
+
+#: builtin/rebase.c:1895
+msgid ""
+"error: cannot combine '--preserve-merges' with '--reschedule-failed-exec'"
+msgstr "錯誤：不能將 '--preserve-merges' 和 '--reschedule-failed-exec' 同時使用"
+
+#: builtin/rebase.c:1919
+#, c-format
+msgid "invalid upstream '%s'"
+msgstr "無效的上游 '%s'"
+
+#: builtin/rebase.c:1925
+msgid "Could not create new root commit"
+msgstr "不能建立新的根提交"
+
+#: builtin/rebase.c:1951
+#, c-format
+msgid "'%s': need exactly one merge base with branch"
+msgstr "'%s'：只需要與分支的一個合併基礎"
+
+#: builtin/rebase.c:1954
+#, c-format
+msgid "'%s': need exactly one merge base"
+msgstr "'%s'：只需要一個合併基礎"
+
+#: builtin/rebase.c:1962
+#, c-format
+msgid "Does not point to a valid commit '%s'"
+msgstr "沒有指向一個有效的提交 '%s'"
+
+#: builtin/rebase.c:1987
+#, c-format
+msgid "fatal: no such branch/commit '%s'"
+msgstr "致命錯誤：無此分支/提交 '%s'"
+
+#: builtin/rebase.c:1995 builtin/submodule--helper.c:40
+#: builtin/submodule--helper.c:1961
+#, c-format
+msgid "No such ref: %s"
+msgstr "沒有這樣的引用：%s"
+
+#: builtin/rebase.c:2006
+msgid "Could not resolve HEAD to a revision"
+msgstr "無法將 HEAD 解析為一個版本"
+
+#: builtin/rebase.c:2044
+msgid "Cannot autostash"
+msgstr "無法 autostash"
+
+#: builtin/rebase.c:2047
+#, c-format
+msgid "Unexpected stash response: '%s'"
+msgstr "意外的 stash 回應：'%s'"
+
+#: builtin/rebase.c:2053
+#, c-format
+msgid "Could not create directory for '%s'"
+msgstr "不能為 '%s' 建立目錄"
+
+#: builtin/rebase.c:2056
+#, c-format
+msgid "Created autostash: %s\n"
+msgstr "建立了 autostash：%s\n"
+
+#: builtin/rebase.c:2059
+msgid "could not reset --hard"
+msgstr "無法 reset --hard"
+
+#: builtin/rebase.c:2068
+msgid "Please commit or stash them."
+msgstr "請提交或儲藏修改。"
+
+#: builtin/rebase.c:2095
+#, c-format
+msgid "could not parse '%s'"
+msgstr "無法解析 '%s'"
+
+#: builtin/rebase.c:2108
+#, c-format
+msgid "could not switch to %s"
+msgstr "無法切換到 %s"
+
+#: builtin/rebase.c:2119
+msgid "HEAD is up to date."
+msgstr "HEAD 是最新的。"
+
+#: builtin/rebase.c:2121
+#, c-format
+msgid "Current branch %s is up to date.\n"
+msgstr "目前分支 %s 是最新的。\n"
+
+#: builtin/rebase.c:2129
+msgid "HEAD is up to date, rebase forced."
+msgstr "HEAD 是最新的，強制重定基底。"
+
+#: builtin/rebase.c:2131
+#, c-format
+msgid "Current branch %s is up to date, rebase forced.\n"
+msgstr "目前分支 %s 是最新的，強制重定基底。\n"
+
+#: builtin/rebase.c:2139
+msgid "The pre-rebase hook refused to rebase."
+msgstr "pre-rebase 掛鉤拒絕了重定基底動作。"
+
+#: builtin/rebase.c:2146
+#, c-format
+msgid "Changes to %s:\n"
+msgstr "到 %s 的變更：\n"
+
+#: builtin/rebase.c:2149
+#, c-format
+msgid "Changes from %s to %s:\n"
+msgstr "從 %s 到 %s 的變更：\n"
+
+#: builtin/rebase.c:2174
+#, c-format
+msgid "First, rewinding head to replay your work on top of it...\n"
+msgstr "首先，還原開頭指標以便在其上重放您的工作...\n"
+
+#: builtin/rebase.c:2183
+msgid "Could not detach HEAD"
+msgstr "無法分離開頭指標"
+
+#: builtin/rebase.c:2192
+#, c-format
+msgid "Fast-forwarded %s to %s.\n"
+msgstr "快轉 %s 到 %s。\n"
+
+#: builtin/receive-pack.c:32
+msgid "git receive-pack <git-dir>"
+msgstr "git receive-pack <版本庫目錄>"
+
+#: builtin/receive-pack.c:830
+msgid ""
+"By default, updating the current branch in a non-bare repository\n"
+"is denied, because it will make the index and work tree inconsistent\n"
+"with what you pushed, and will require 'git reset --hard' to match\n"
+"the work tree to HEAD.\n"
+"\n"
+"You can set the 'receive.denyCurrentBranch' configuration variable\n"
+"to 'ignore' or 'warn' in the remote repository to allow pushing into\n"
+"its current branch; however, this is not recommended unless you\n"
+"arranged to update its work tree to match what you pushed in some\n"
+"other way.\n"
+"\n"
+"To squelch this message and still keep the default behaviour, set\n"
+"'receive.denyCurrentBranch' configuration variable to 'refuse'."
+msgstr ""
+"預設禁止更新非純版本庫的目前分支，因為您推送的內容將導致索引和工作區\n"
+"不一致，並且將需要執行 'git reset --hard' 將工作區符合到 HEAD。\n"
+"\n"
+"您可以在遠端版本庫中設定 'receive.denyCurrentBranch' 設定變數為\n"
+"'ignore' 或 'warn' 以允許推送到目前分支。然而不推薦這麼做，除非您\n"
+"用某種方式將其工作區更新至您推送的狀態。\n"
+"\n"
+"若要封鎖此訊息且保持預設行為，設定 'receive.denyCurrentBranch'\n"
+"設定變數為 'refuse'。"
+
+#: builtin/receive-pack.c:850
+msgid ""
+"By default, deleting the current branch is denied, because the next\n"
+"'git clone' won't result in any file checked out, causing confusion.\n"
+"\n"
+"You can set 'receive.denyDeleteCurrent' configuration variable to\n"
+"'warn' or 'ignore' in the remote repository to allow deleting the\n"
+"current branch, with or without a warning message.\n"
+"\n"
+"To squelch this message, you can set it to 'refuse'."
+msgstr ""
+"預設禁止刪除目前分支，因為下一次 'git clone' 將不會簽出任何檔案，\n"
+"導致困惑。\n"
+"\n"
+"您可以在遠端版本庫中設定 'receive.denyDeleteCurrent' 設定變數為\n"
+"'warn'（顯示警告訊息）或 'ignore'（忽略警告訊息）以允許刪除目前分支。\n"
+"\n"
+"若要封鎖此訊息，您可以設定它為 'refuse'。"
+
+#: builtin/receive-pack.c:1936
+msgid "quiet"
+msgstr "靜默模式"
+
+#: builtin/receive-pack.c:1950
+msgid "You must specify a directory."
+msgstr "您必須指定一個目錄。"
+
+#: builtin/reflog.c:17
+msgid ""
+"git reflog expire [--expire=<time>] [--expire-unreachable=<time>] [--"
+"rewrite] [--updateref] [--stale-fix] [--dry-run | -n] [--verbose] [--all] "
+"<refs>..."
+msgstr ""
+"git reflog expire [--expire=<時間>] [--expire-unreachable=<時間>] [--"
+"rewrite] [--updateref] [--stale-fix] [--dry-run | -n] [--verbose] [--all] <引"
+"用>..."
+
+#: builtin/reflog.c:22
+msgid ""
+"git reflog delete [--rewrite] [--updateref] [--dry-run | -n] [--verbose] "
+"<refs>..."
+msgstr ""
+"git reflog delete [--rewrite] [--updateref] [--dry-run | -n] [--verbose] <引"
+"用>..."
+
+#: builtin/reflog.c:25
+msgid "git reflog exists <ref>"
+msgstr "git reflog exists <引用>"
+
+#: builtin/reflog.c:567 builtin/reflog.c:572
+#, c-format
+msgid "'%s' is not a valid timestamp"
+msgstr "'%s' 不是一個有效的時間戳"
+
+#: builtin/reflog.c:605
+#, c-format
+msgid "Marking reachable objects..."
+msgstr "正在標記可以取得物件..."
+
+#: builtin/reflog.c:643
+#, c-format
+msgid "%s points nowhere!"
+msgstr "%s 指向不存在！"
+
+#: builtin/reflog.c:695
+msgid "no reflog specified to delete"
+msgstr "未指定要刪除的引用日誌"
+
+#: builtin/reflog.c:704
+#, c-format
+msgid "not a reflog: %s"
+msgstr "不是一個引用日誌：%s"
+
+#: builtin/reflog.c:709
+#, c-format
+msgid "no reflog for '%s'"
+msgstr "沒有 '%s' 的引用日誌"
+
+#: builtin/reflog.c:755
+#, c-format
+msgid "invalid ref format: %s"
+msgstr "無效的引用格式：%s"
+
+#: builtin/reflog.c:764
+msgid "git reflog [ show | expire | delete | exists ]"
+msgstr "git reflog [ show | expire | delete | exists ]"
+
+#: builtin/remote.c:16
+msgid "git remote [-v | --verbose]"
+msgstr "git remote [-v | --verbose]"
+
+#: builtin/remote.c:17
+msgid ""
+"git remote add [-t <branch>] [-m <master>] [-f] [--tags | --no-tags] [--"
+"mirror=<fetch|push>] <name> <url>"
+msgstr ""
+"git remote add [-t <分支>] [-m <master>] [-f] [--tags | --no-tags] [--"
+"mirror=<fetch|push>] <名稱> <位址>"
+
+#: builtin/remote.c:18 builtin/remote.c:38
+msgid "git remote rename <old> <new>"
+msgstr "git remote rename <舊名稱> <新名稱>"
+
+#: builtin/remote.c:19 builtin/remote.c:43
+msgid "git remote remove <name>"
+msgstr "git remote remove <名稱>"
+
+#: builtin/remote.c:20 builtin/remote.c:48
+msgid "git remote set-head <name> (-a | --auto | -d | --delete | <branch>)"
+msgstr "git remote set-head <名稱> (-a | --auto | -d | --delete | <分支>)"
+
+#: builtin/remote.c:21
+msgid "git remote [-v | --verbose] show [-n] <name>"
+msgstr "git remote [-v | --verbose] show [-n] <名稱>"
+
+#: builtin/remote.c:22
+msgid "git remote prune [-n | --dry-run] <name>"
+msgstr "git remote prune [-n | --dry-run] <名稱>"
+
+#: builtin/remote.c:23
+msgid ""
+"git remote [-v | --verbose] update [-p | --prune] [(<group> | <remote>)...]"
+msgstr "git remote [-v | --verbose] update [-p | --prune] [(<組> | <遠端>)...]"
+
+#: builtin/remote.c:24
+msgid "git remote set-branches [--add] <name> <branch>..."
+msgstr "git remote set-branches [--add] <名稱> <分支>..."
+
+#: builtin/remote.c:25 builtin/remote.c:74
+msgid "git remote get-url [--push] [--all] <name>"
+msgstr "git remote get-url [--push] [--all] <名稱>"
+
+#: builtin/remote.c:26 builtin/remote.c:79
+msgid "git remote set-url [--push] <name> <newurl> [<oldurl>]"
+msgstr "git remote set-url [--push] <名稱> <新的位址> [<舊的位址>]"
+
+#: builtin/remote.c:27 builtin/remote.c:80
+msgid "git remote set-url --add <name> <newurl>"
+msgstr "git remote set-url --add <名稱> <新的位址>"
+
+#: builtin/remote.c:28 builtin/remote.c:81
+msgid "git remote set-url --delete <name> <url>"
+msgstr "git remote set-url --delete <名稱> <位址>"
+
+#: builtin/remote.c:33
+msgid "git remote add [<options>] <name> <url>"
+msgstr "git remote add [<選項>] <名稱> <位址>"
+
+#: builtin/remote.c:53
+msgid "git remote set-branches <name> <branch>..."
+msgstr "git remote set-branches <名稱> <分支>..."
+
+#: builtin/remote.c:54
+msgid "git remote set-branches --add <name> <branch>..."
+msgstr "git remote set-branches --add <名稱> <分支>..."
+
+#: builtin/remote.c:59
+msgid "git remote show [<options>] <name>"
+msgstr "git remote show [<選項>] <名稱>"
+
+#: builtin/remote.c:64
+msgid "git remote prune [<options>] <name>"
+msgstr "git remote prune [<選項>] <名稱>"
+
+#: builtin/remote.c:69
+msgid "git remote update [<options>] [<group> | <remote>]..."
+msgstr "git remote update [<選項>] [<組> | <遠端>]..."
+
+#: builtin/remote.c:98
+#, c-format
+msgid "Updating %s"
+msgstr "更新 %s 中"
+
+#: builtin/remote.c:130
+msgid ""
+"--mirror is dangerous and deprecated; please\n"
+"\t use --mirror=fetch or --mirror=push instead"
+msgstr ""
+"--mirror 選項危險且過時，請使用 --mirror=fetch\n"
+"\t 或 --mirror=push"
+
+#: builtin/remote.c:147
+#, c-format
+msgid "unknown mirror argument: %s"
+msgstr "未知的鏡像參數：%s"
+
+#: builtin/remote.c:163
+msgid "fetch the remote branches"
+msgstr "抓取遠端的分支"
+
+#: builtin/remote.c:165
+msgid "import all tags and associated objects when fetching"
+msgstr "抓取時匯入所有的標籤和關聯物件"
+
+#: builtin/remote.c:168
+msgid "or do not fetch any tag at all (--no-tags)"
+msgstr "或不抓取任何標籤（--no-tags）"
+
+#: builtin/remote.c:170
+msgid "branch(es) to track"
+msgstr "追蹤的分支"
+
+#: builtin/remote.c:171
+msgid "master branch"
+msgstr "主線分支"
+
+#: builtin/remote.c:173
+msgid "set up remote as a mirror to push to or fetch from"
+msgstr "把遠端設定為用以推送或抓取的鏡像"
+
+#: builtin/remote.c:185
+msgid "specifying a master branch makes no sense with --mirror"
+msgstr "指定一個 master 分支並使用 --mirror 選項沒有意義"
+
+#: builtin/remote.c:187
+msgid "specifying branches to track makes sense only with fetch mirrors"
+msgstr "指定要追蹤的分支只在與取得鏡像同時使用才有意義"
+
+#: builtin/remote.c:194 builtin/remote.c:636
+#, c-format
+msgid "remote %s already exists."
+msgstr "遠端 %s 已經存在。"
+
+#: builtin/remote.c:198 builtin/remote.c:640
+#, c-format
+msgid "'%s' is not a valid remote name"
+msgstr "'%s' 不是一個有效的遠端名稱"
+
+#: builtin/remote.c:238
+#, c-format
+msgid "Could not setup master '%s'"
+msgstr "無法設定 master '%s'"
+
+#: builtin/remote.c:344
+#, c-format
+msgid "Could not get fetch map for refspec %s"
+msgstr "無法得到引用規格 %s 的取得列表"
+
+#: builtin/remote.c:443 builtin/remote.c:451
+msgid "(matching)"
+msgstr "（符合）"
+
+#: builtin/remote.c:455
+msgid "(delete)"
+msgstr "（刪除）"
+
+#: builtin/remote.c:629 builtin/remote.c:764 builtin/remote.c:863
+#, c-format
+msgid "No such remote: '%s'"
+msgstr "沒有此遠端版本庫：'%s'"
+
+#: builtin/remote.c:646
+#, c-format
+msgid "Could not rename config section '%s' to '%s'"
+msgstr "不能重新命名設定小節 '%s' 到 '%s'"
+
+#: builtin/remote.c:666
+#, c-format
+msgid ""
+"Not updating non-default fetch refspec\n"
+"\t%s\n"
+"\tPlease update the configuration manually if necessary."
+msgstr ""
+"沒有更新非預設的取得引用規格\n"
+"\t%s\n"
+"\t如果必要請手動更新設定。"
+
+#: builtin/remote.c:701
+#, c-format
+msgid "deleting '%s' failed"
+msgstr "刪除 '%s' 失敗"
+
+#: builtin/remote.c:735
+#, c-format
+msgid "creating '%s' failed"
+msgstr "建立 '%s' 失敗"
+
+#: builtin/remote.c:801
+msgid ""
+"Note: A branch outside the refs/remotes/ hierarchy was not removed;\n"
+"to delete it, use:"
+msgid_plural ""
+"Note: Some branches outside the refs/remotes/ hierarchy were not removed;\n"
+"to delete them, use:"
+msgstr[0] "注意：ref/remotes 層級之外的一個分支未被移除。要刪除它，使用："
+msgstr[1] "注意：ref/remotes 層級之外的一些分支未被移除。要刪除它們，使用："
+
+#: builtin/remote.c:815
+#, c-format
+msgid "Could not remove config section '%s'"
+msgstr "不能移除設定小節 '%s'"
+
+#: builtin/remote.c:916
+#, c-format
+msgid " new (next fetch will store in remotes/%s)"
+msgstr " 新的（下一次取得將儲存於 remotes/%s）"
+
+#: builtin/remote.c:919
+msgid " tracked"
+msgstr " 已追蹤"
+
+#: builtin/remote.c:921
+msgid " stale (use 'git remote prune' to remove)"
+msgstr " 過時（使用 'git remote prune' 來移除）"
+
+#: builtin/remote.c:923
+msgid " ???"
+msgstr " ???"
+
+#: builtin/remote.c:964
+#, c-format
+msgid "invalid branch.%s.merge; cannot rebase onto > 1 branch"
+msgstr "無效的 branch.%s.merge，不能重定基底到一個以上的分支"
+
+#: builtin/remote.c:973
+#, c-format
+msgid "rebases interactively onto remote %s"
+msgstr "互動式重定基底到遠端 %s"
+
+#: builtin/remote.c:975
+#, c-format
+msgid "rebases interactively (with merges) onto remote %s"
+msgstr "互動式重定基底（含合併提交）到遠端 %s"
+
+#: builtin/remote.c:978
+#, c-format
+msgid "rebases onto remote %s"
+msgstr "重定基底到遠端 %s"
+
+#: builtin/remote.c:982
+#, c-format
+msgid " merges with remote %s"
+msgstr " 與遠端 %s 合併"
+
+#: builtin/remote.c:985
+#, c-format
+msgid "merges with remote %s"
+msgstr "與遠端 %s 合併"
+
+#: builtin/remote.c:988
+#, c-format
+msgid "%-*s    and with remote %s\n"
+msgstr "%-*s    以及和遠端 %s\n"
+
+#: builtin/remote.c:1031
+msgid "create"
+msgstr "建立"
+
+#: builtin/remote.c:1034
+msgid "delete"
+msgstr "刪除"
+
+#: builtin/remote.c:1038
+msgid "up to date"
+msgstr "最新"
+
+#: builtin/remote.c:1041
+msgid "fast-forwardable"
+msgstr "可快轉"
+
+#: builtin/remote.c:1044
+msgid "local out of date"
+msgstr "本機已過時"
+
+#: builtin/remote.c:1051
+#, c-format
+msgid "    %-*s forces to %-*s (%s)"
+msgstr "    %-*s 強制推送至 %-*s (%s)"
+
+#: builtin/remote.c:1054
+#, c-format
+msgid "    %-*s pushes to %-*s (%s)"
+msgstr "    %-*s 推送至 %-*s (%s)"
+
+#: builtin/remote.c:1058
+#, c-format
+msgid "    %-*s forces to %s"
+msgstr "    %-*s 強制推送至 %s"
+
+#: builtin/remote.c:1061
+#, c-format
+msgid "    %-*s pushes to %s"
+msgstr "    %-*s 推送至 %s"
+
+#: builtin/remote.c:1129
+msgid "do not query remotes"
+msgstr "不查詢遠端"
+
+#: builtin/remote.c:1156
+#, c-format
+msgid "* remote %s"
+msgstr "* 遠端 %s"
+
+#: builtin/remote.c:1157
+#, c-format
+msgid "  Fetch URL: %s"
+msgstr "  取得位址：%s"
+
+#: builtin/remote.c:1158 builtin/remote.c:1174 builtin/remote.c:1313
+msgid "(no URL)"
+msgstr "(無 URL)"
+
+#. TRANSLATORS: the colon ':' should align
+#. with the one in " Fetch URL: %s"
+#. translation.
+#.
+#: builtin/remote.c:1172 builtin/remote.c:1174
+#, c-format
+msgid "  Push  URL: %s"
+msgstr "  推送位址：%s"
+
+#: builtin/remote.c:1176 builtin/remote.c:1178 builtin/remote.c:1180
+#, c-format
+msgid "  HEAD branch: %s"
+msgstr "  HEAD 分支：%s"
+
+#  譯者：中文字串拼接，可刪除前導空格
+#: builtin/remote.c:1176
+msgid "(not queried)"
+msgstr "（未查詢）"
+
+#: builtin/remote.c:1178
+msgid "(unknown)"
+msgstr "（未知）"
+
+#: builtin/remote.c:1182
+#, c-format
+msgid ""
+"  HEAD branch (remote HEAD is ambiguous, may be one of the following):\n"
+msgstr "  HEAD 分支（遠端 HEAD 模糊，可能是下列中的一個）：\n"
+
+#: builtin/remote.c:1194
+#, c-format
+msgid "  Remote branch:%s"
+msgid_plural "  Remote branches:%s"
+msgstr[0] "  遠端分支：%s"
+msgstr[1] "  遠端分支：%s"
+
+#  譯者：中文字串拼接，可刪除前導空格
+#: builtin/remote.c:1197 builtin/remote.c:1223
+msgid " (status not queried)"
+msgstr "（狀態未查詢）"
+
+#: builtin/remote.c:1206
+msgid "  Local branch configured for 'git pull':"
+msgid_plural "  Local branches configured for 'git pull':"
+msgstr[0] "  為 'git pull' 設定的本機分支："
+msgstr[1] "  為 'git pull' 設定的本機分支："
+
+#: builtin/remote.c:1214
+msgid "  Local refs will be mirrored by 'git push'"
+msgstr "  本機引用將在 'git push' 時被鏡像"
+
+#: builtin/remote.c:1220
+#, c-format
+msgid "  Local ref configured for 'git push'%s:"
+msgid_plural "  Local refs configured for 'git push'%s:"
+msgstr[0] "  為 'git push' 設定的本機引用%s："
+msgstr[1] "  為 'git push' 設定的本機引用%s："
+
+#: builtin/remote.c:1241
+msgid "set refs/remotes/<name>/HEAD according to remote"
+msgstr "根據遠端設定 refs/remotes/<名稱>/HEAD"
+
+#: builtin/remote.c:1243
+msgid "delete refs/remotes/<name>/HEAD"
+msgstr "刪除 refs/remotes/<名稱>/HEAD"
+
+#: builtin/remote.c:1258
+msgid "Cannot determine remote HEAD"
+msgstr "無法確定遠端 HEAD"
+
+#: builtin/remote.c:1260
+msgid "Multiple remote HEAD branches. Please choose one explicitly with:"
+msgstr "多個遠端 HEAD 分支。請明確地選擇一個用指令："
+
+#: builtin/remote.c:1270
+#, c-format
+msgid "Could not delete %s"
+msgstr "無法刪除 %s"
+
+#: builtin/remote.c:1278
+#, c-format
+msgid "Not a valid ref: %s"
+msgstr "不是一個有效引用：%s"
+
+#: builtin/remote.c:1280
+#, c-format
+msgid "Could not setup %s"
+msgstr "不能設定 %s"
+
+#  譯者：請維持前導空格
+#: builtin/remote.c:1298
+#, c-format
+msgid " %s will become dangling!"
+msgstr " %s 將成為懸空狀態！"
+
+#  譯者：請維持前導空格
+#: builtin/remote.c:1299
+#, c-format
+msgid " %s has become dangling!"
+msgstr " %s 已成為懸空狀態！"
+
+#: builtin/remote.c:1309
+#, c-format
+msgid "Pruning %s"
+msgstr "修剪 %s"
+
+#: builtin/remote.c:1310
+#, c-format
+msgid "URL: %s"
+msgstr "URL：%s"
+
+#: builtin/remote.c:1326
+#, c-format
+msgid " * [would prune] %s"
+msgstr " * [將刪除] %s"
+
+#: builtin/remote.c:1329
+#, c-format
+msgid " * [pruned] %s"
+msgstr " * [已刪除] %s"
+
+#: builtin/remote.c:1374
+msgid "prune remotes after fetching"
+msgstr "抓取後清除遠端"
+
+#: builtin/remote.c:1437 builtin/remote.c:1491 builtin/remote.c:1559
+#, c-format
+msgid "No such remote '%s'"
+msgstr "沒有此遠端 '%s'"
+
+#: builtin/remote.c:1453
+msgid "add branch"
+msgstr "新增分支"
+
+#: builtin/remote.c:1460
+msgid "no remote specified"
+msgstr "未指定遠端"
+
+#: builtin/remote.c:1477
+msgid "query push URLs rather than fetch URLs"
+msgstr "查詢推送 URL 位址，而非取得 URL 位址"
+
+#: builtin/remote.c:1479
+msgid "return all URLs"
+msgstr "返回所有 URL 位址"
+
+#: builtin/remote.c:1507
+#, c-format
+msgid "no URLs configured for remote '%s'"
+msgstr "沒有給遠端版本庫 '%s' 設定 URL"
+
+#: builtin/remote.c:1533
+msgid "manipulate push URLs"
+msgstr "動作推送 URLS"
+
+#: builtin/remote.c:1535
+msgid "add URL"
+msgstr "新增 URL"
+
+#: builtin/remote.c:1537
+msgid "delete URLs"
+msgstr "刪除 URL"
+
+#: builtin/remote.c:1544
+msgid "--add --delete doesn't make sense"
+msgstr "--add --delete 無意義"
+
+#: builtin/remote.c:1583
+#, c-format
+msgid "Invalid old URL pattern: %s"
+msgstr "無效的舊 URL 符合範本：%s"
+
+#: builtin/remote.c:1591
+#, c-format
+msgid "No such URL found: %s"
+msgstr "未找到此 URL：%s"
+
+#: builtin/remote.c:1593
+msgid "Will not delete all non-push URLs"
+msgstr "將不會刪除所有非推送 URL 位址"
+
+#: builtin/repack.c:23
+msgid "git repack [<options>]"
+msgstr "git repack [<選項>]"
+
+#: builtin/repack.c:28
+msgid ""
+"Incremental repacks are incompatible with bitmap indexes.  Use\n"
+"--no-write-bitmap-index or disable the pack.writebitmaps configuration."
+msgstr ""
+"增量 repack 和 bitmap 索引不相容。  使用 --no-write-bitmap-index\n"
+"或禁用 pack.writebitmaps 設定。"
+
+#: builtin/repack.c:191
+msgid "could not start pack-objects to repack promisor objects"
+msgstr "無法開始 pack-objects 來重新打包 promisor 物件"
+
+#: builtin/repack.c:230 builtin/repack.c:416
+msgid "repack: Expecting full hex object ID lines only from pack-objects."
+msgstr "repack：期望來自 pack-objects 的完整十六進位物件 ID。"
+
+#: builtin/repack.c:254
+msgid "could not finish pack-objects to repack promisor objects"
+msgstr "無法完成 pack-objects 來重新打包 promisor 物件"
+
+#: builtin/repack.c:292
+msgid "pack everything in a single pack"
+msgstr "所有內容打包到一個包檔案中"
+
+#: builtin/repack.c:294
+msgid "same as -a, and turn unreachable objects loose"
+msgstr "和 -a 相同，並將無法取得的物件設為鬆散物件"
+
+#: builtin/repack.c:297
+msgid "remove redundant packs, and run git-prune-packed"
+msgstr "刪除多餘的包，執行 git-prune-packed"
+
+#: builtin/repack.c:299
+msgid "pass --no-reuse-delta to git-pack-objects"
+msgstr "向 git-pack-objects 傳遞參數 --no-reuse-delta"
+
+#: builtin/repack.c:301
+msgid "pass --no-reuse-object to git-pack-objects"
+msgstr "向 git-pack-objects 傳遞參數 --no-reuse-object"
+
+#: builtin/repack.c:303
+msgid "do not run git-update-server-info"
+msgstr "不執行 git-update-server-info"
+
+#: builtin/repack.c:306
+msgid "pass --local to git-pack-objects"
+msgstr "向 git-pack-objects 傳遞參數 --local"
+
+#: builtin/repack.c:308
+msgid "write bitmap index"
+msgstr "寫 bitmap 索引"
+
+#: builtin/repack.c:310
+msgid "pass --delta-islands to git-pack-objects"
+msgstr "向 git-pack-objects 傳遞參數 --delta-islands"
+
+#: builtin/repack.c:311
+msgid "approxidate"
+msgstr "近似日期"
+
+#: builtin/repack.c:312
+msgid "with -A, do not loosen objects older than this"
+msgstr "使用 -A，不要將早於提供時間的物件過期"
+
+#: builtin/repack.c:314
+msgid "with -a, repack unreachable objects"
+msgstr "使用 -a ，重新對無法取得物件打包"
+
+#: builtin/repack.c:316
+msgid "size of the window used for delta compression"
+msgstr "用於增量壓縮的視窗值"
+
+#: builtin/repack.c:317 builtin/repack.c:323
+msgid "bytes"
+msgstr "位元組"
+
+#: builtin/repack.c:318
+msgid "same as the above, but limit memory size instead of entries count"
+msgstr "和上面的相似，但限制記憶體大小而非條目數"
+
+#: builtin/repack.c:320
+msgid "limits the maximum delta depth"
+msgstr "限制最大增量深度"
+
+#: builtin/repack.c:322
+msgid "limits the maximum number of threads"
+msgstr "限制最大執行緒數"
+
+#: builtin/repack.c:324
+msgid "maximum size of each packfile"
+msgstr "每個 packfile 的最大尺寸"
+
+#: builtin/repack.c:326
+msgid "repack objects in packs marked with .keep"
+msgstr "對標記為 .keep 的包中的物件重新打包"
+
+#: builtin/repack.c:328
+msgid "do not repack this pack"
+msgstr "不要對該包檔案重新打包"
+
+#: builtin/repack.c:338
+msgid "cannot delete packs in a precious-objects repo"
+msgstr "不能刪除珍品版本庫中的打包檔案"
+
+#: builtin/repack.c:342
+msgid "--keep-unreachable and -A are incompatible"
+msgstr "--keep-unreachable 和 -A 不相容"
+
+#: builtin/repack.c:425
+msgid "Nothing new to pack."
+msgstr "沒有新的要打包。"
+
+#: builtin/repack.c:486
+#, c-format
+msgid ""
+"WARNING: Some packs in use have been renamed by\n"
+"WARNING: prefixing old- to their name, in order to\n"
+"WARNING: replace them with the new version of the\n"
+"WARNING: file.  But the operation failed, and the\n"
+"WARNING: attempt to rename them back to their\n"
+"WARNING: original names also failed.\n"
+"WARNING: Please rename them in %s manually:\n"
+msgstr ""
+"警告：為了將包檔案取代為新版本，一些使用中的包已經\n"
+"警告：透過新增 old- 前綴的方式重新命名。但是動作失敗，\n"
+"警告：並且嘗試重新命名改回原有檔案名的動作也失敗。\n"
+"警告：請手動將 %s 下的這些檔案重新命名：\n"
+
+#: builtin/repack.c:534
+#, c-format
+msgid "failed to remove '%s'"
+msgstr "刪除 '%s' 失敗"
+
+#: builtin/replace.c:22
+msgid "git replace [-f] <object> <replacement>"
+msgstr "git replace [-f] <物件> <取代物>"
+
+#: builtin/replace.c:23
+msgid "git replace [-f] --edit <object>"
+msgstr "git replace [-f] --edit <物件>"
+
+#: builtin/replace.c:24
+msgid "git replace [-f] --graft <commit> [<parent>...]"
+msgstr "git replace [-f] --graft <提交> [<父提交>...]"
+
+#: builtin/replace.c:25
+msgid "git replace [-f] --convert-graft-file"
+msgstr "git replace [-f] --convert-graft-file"
+
+#: builtin/replace.c:26
+msgid "git replace -d <object>..."
+msgstr "git replace -d <物件>..."
+
+#: builtin/replace.c:27
+msgid "git replace [--format=<format>] [-l [<pattern>]]"
+msgstr "git replace [--format=<格式>] [-l [<模式>]]"
+
+#: builtin/replace.c:90
+#, c-format
+msgid ""
+"invalid replace format '%s'\n"
+"valid formats are 'short', 'medium' and 'long'"
+msgstr ""
+"無效的取代格式 '%s'\n"
+"有效的格式有 'short'、'medium' 和 'long'"
+
+#: builtin/replace.c:125
+#, c-format
+msgid "replace ref '%s' not found"
+msgstr "未發現取代引用 '%s'"
+
+#: builtin/replace.c:141
+#, c-format
+msgid "Deleted replace ref '%s'"
+msgstr "已刪除取代引用 '%s'"
+
+#: builtin/replace.c:153
+#, c-format
+msgid "'%s' is not a valid ref name"
+msgstr "'%s' 不是一個有效的引用名"
+
+#: builtin/replace.c:158
+#, c-format
+msgid "replace ref '%s' already exists"
+msgstr "取代引用 '%s' 已經存在"
+
+#: builtin/replace.c:178
+#, c-format
+msgid ""
+"Objects must be of the same type.\n"
+"'%s' points to a replaced object of type '%s'\n"
+"while '%s' points to a replacement object of type '%s'."
+msgstr ""
+"物件必須屬於同一類型。\n"
+"'%s' 指向 '%s' 類型的取代物件\n"
+"而 '%s' 指向 '%s' 類型的取代物件。"
+
+#: builtin/replace.c:229
+#, c-format
+msgid "unable to open %s for writing"
+msgstr "無法為寫入開啟 %s"
+
+#: builtin/replace.c:242
+msgid "cat-file reported failure"
+msgstr "cat-file 報告失敗"
+
+#: builtin/replace.c:258
+#, c-format
+msgid "unable to open %s for reading"
+msgstr "無法為讀取開啟 %s"
+
+#: builtin/replace.c:272
+msgid "unable to spawn mktree"
+msgstr "無法啟動 mktree"
+
+#: builtin/replace.c:276
+msgid "unable to read from mktree"
+msgstr "無法從 mktree 讀取"
+
+#: builtin/replace.c:285
+msgid "mktree reported failure"
+msgstr "mktree 報告失敗"
+
+#: builtin/replace.c:289
+msgid "mktree did not return an object name"
+msgstr "mktree 沒有返回一個物件名"
+
+#: builtin/replace.c:298
+#, c-format
+msgid "unable to fstat %s"
+msgstr "無法對 %s 執行 fstat"
+
+#: builtin/replace.c:303
+msgid "unable to write object to database"
+msgstr "無法向資料庫寫入物件"
+
+#: builtin/replace.c:322 builtin/replace.c:378 builtin/replace.c:423
+#: builtin/replace.c:453
+#, c-format
+msgid "not a valid object name: '%s'"
+msgstr "不是一個有效的物件名：'%s'"
+
+#: builtin/replace.c:326
+#, c-format
+msgid "unable to get object type for %s"
+msgstr "無法得到 %s 的物件類型"
+
+#: builtin/replace.c:342
+msgid "editing object file failed"
+msgstr "編輯物件檔案失敗"
+
+#: builtin/replace.c:351
+#, c-format
+msgid "new object is the same as the old one: '%s'"
+msgstr "新物件和舊物件相同：'%s'"
+
+#: builtin/replace.c:384
+#, c-format
+msgid "could not parse %s as a commit"
+msgstr "無法將 %s 解析為一個提交"
+
+#: builtin/replace.c:415
+#, c-format
+msgid "bad mergetag in commit '%s'"
+msgstr "提交 '%s' 中含有損壞的合併標籤"
+
+#: builtin/replace.c:417
+#, c-format
+msgid "malformed mergetag in commit '%s'"
+msgstr "提交 '%s' 中含有格式錯誤的合併標籤"
+
+#: builtin/replace.c:429
+#, c-format
+msgid ""
+"original commit '%s' contains mergetag '%s' that is discarded; use --edit "
+"instead of --graft"
+msgstr "原始提交 '%s' 包含已經捨棄的合併標籤 '%s'，使用 --edit 代替 --graft"
+
+#: builtin/replace.c:468
+#, c-format
+msgid "the original commit '%s' has a gpg signature"
+msgstr "原始提交 '%s' 中有一個 gpg 簽名"
+
+#: builtin/replace.c:469
+msgid "the signature will be removed in the replacement commit!"
+msgstr "在取代的提交中簽名將被移除！"
+
+#: builtin/replace.c:479
+#, c-format
+msgid "could not write replacement commit for: '%s'"
+msgstr "不能為 '%s' 寫取代提交"
+
+#: builtin/replace.c:487
+#, c-format
+msgid "graft for '%s' unnecessary"
+msgstr "對 '%s' 移植沒有必要"
+
+#: builtin/replace.c:491
+#, c-format
+msgid "new commit is the same as the old one: '%s'"
+msgstr "新提交和舊的一樣：'%s'"
+
+#: builtin/replace.c:526
+#, c-format
+msgid ""
+"could not convert the following graft(s):\n"
+"%s"
+msgstr ""
+"不能轉換下列移植：\n"
+"%s"
+
+#: builtin/replace.c:547
+msgid "list replace refs"
+msgstr "列出取代的引用"
+
+#: builtin/replace.c:548
+msgid "delete replace refs"
+msgstr "刪除取代的引用"
+
+#: builtin/replace.c:549
+msgid "edit existing object"
+msgstr "編輯現存的物件"
+
+#: builtin/replace.c:550
+msgid "change a commit's parents"
+msgstr "修改一個提交的父提交"
+
+#: builtin/replace.c:551
+msgid "convert existing graft file"
+msgstr "轉換現存的移植檔案"
+
+#: builtin/replace.c:552
+msgid "replace the ref if it exists"
+msgstr "如果存在則取代引用"
+
+#: builtin/replace.c:554
+msgid "do not pretty-print contents for --edit"
+msgstr "不要為 --edit 動作美觀顯示內容"
+
+#: builtin/replace.c:555
+msgid "use this format"
+msgstr "使用此格式"
+
+#: builtin/replace.c:568
+msgid "--format cannot be used when not listing"
+msgstr "不列出時不能使用 --format"
+
+#: builtin/replace.c:576
+msgid "-f only makes sense when writing a replacement"
+msgstr "只有寫一個取代時 -f 才有意義"
+
+#: builtin/replace.c:580
+msgid "--raw only makes sense with --edit"
+msgstr "--raw 只有和 --edit 共用才有意義"
+
+#: builtin/replace.c:586
+msgid "-d needs at least one argument"
+msgstr "-d 需要至少一個參數"
+
+#: builtin/replace.c:592
+msgid "bad number of arguments"
+msgstr "錯誤的參數個數"
+
+#: builtin/replace.c:598
+msgid "-e needs exactly one argument"
+msgstr "-e 需要且僅需要一個參數"
+
+#: builtin/replace.c:604
+msgid "-g needs at least one argument"
+msgstr "-g 需要至少一個參數"
+
+#: builtin/replace.c:610
+msgid "--convert-graft-file takes no argument"
+msgstr "--convert-graft-file 不帶參數"
+
+#: builtin/replace.c:616
+msgid "only one pattern can be given with -l"
+msgstr "只能為 -l 提供一個模式"
+
+#: builtin/rerere.c:13
+msgid "git rerere [clear | forget <path>... | status | remaining | diff | gc]"
+msgstr "git rerere [clear | forget <路徑>... | status | remaining | diff | gc]"
+
+#: builtin/rerere.c:60
+msgid "register clean resolutions in index"
+msgstr "在索引中註冊乾淨的解決方案"
+
+#: builtin/rerere.c:79
+msgid "'git rerere forget' without paths is deprecated"
+msgstr "沒有路徑的 'git rerere forget' 已經過時"
+
+#: builtin/rerere.c:113
+#, c-format
+msgid "unable to generate diff for '%s'"
+msgstr "無法為 '%s' 生成差異"
+
+#: builtin/reset.c:32
+msgid ""
+"git reset [--mixed | --soft | --hard | --merge | --keep] [-q] [<commit>]"
+msgstr "git reset [--mixed | --soft | --hard | --merge | --keep] [-q] [<提交>]"
+
+#: builtin/reset.c:33
+#| msgid "git reset [-q] [<tree-ish>] [--] <paths>..."
+msgid "git reset [-q] [<tree-ish>] [--] <pathspec>..."
+msgstr "git reset [-q] [<樹或提交>] [--] <路徑規格>..."
+
+#: builtin/reset.c:34
+msgid ""
+"git reset [-q] [--pathspec-from-file [--pathspec-file-nul]] [<tree-ish>]"
+msgstr "git reset [-q] [--pathspec-from-file [--pathspec-file-nul]] [<樹或提交>]"
+
+#: builtin/reset.c:35
+#| msgid "git reset --patch [<tree-ish>] [--] [<paths>...]"
+msgid "git reset --patch [<tree-ish>] [--] [<pathspec>...]"
+msgstr "git reset --patch [<樹或提交>] [--] [<路徑規格>...]"
+
+#: builtin/reset.c:41
+msgid "mixed"
+msgstr "混雜"
+
+#: builtin/reset.c:41
+msgid "soft"
+msgstr "軟性"
+
+#: builtin/reset.c:41
+msgid "hard"
+msgstr "硬性"
+
+#: builtin/reset.c:41
+msgid "merge"
+msgstr "合併"
+
+#: builtin/reset.c:41
+msgid "keep"
+msgstr "保持"
+
+#: builtin/reset.c:82
+msgid "You do not have a valid HEAD."
+msgstr "您沒有一個有效的 HEAD。"
+
+#: builtin/reset.c:84
+msgid "Failed to find tree of HEAD."
+msgstr "無法找到 HEAD 指向的樹。"
+
+#: builtin/reset.c:90
+#, c-format
+msgid "Failed to find tree of %s."
+msgstr "無法找到 %s 指向的樹。"
+
+#: builtin/reset.c:115
+#, c-format
+msgid "HEAD is now at %s"
+msgstr "HEAD 現在位於 %s"
+
+#  譯者：漢字之間無空格，故刪除%s前後空格
+#: builtin/reset.c:194
+#, c-format
+msgid "Cannot do a %s reset in the middle of a merge."
+msgstr "在合併過程中不能做%s重設動作。"
+
+#: builtin/reset.c:294 builtin/stash.c:519 builtin/stash.c:594
+#: builtin/stash.c:618
+msgid "be quiet, only report errors"
+msgstr "安靜模式，只報告錯誤"
+
+#: builtin/reset.c:296
+msgid "reset HEAD and index"
+msgstr "重設 HEAD 和索引"
+
+#: builtin/reset.c:297
+msgid "reset only HEAD"
+msgstr "只重設 HEAD"
+
+#: builtin/reset.c:299 builtin/reset.c:301
+msgid "reset HEAD, index and working tree"
+msgstr "重設 HEAD、索引和工作區"
+
+#: builtin/reset.c:303
+msgid "reset HEAD but keep local changes"
+msgstr "重設 HEAD 但儲存本機變更"
+
+#: builtin/reset.c:309
+msgid "record only the fact that removed paths will be added later"
+msgstr "將刪除的路徑標記為稍後新增"
+
+#: builtin/reset.c:343
+#, c-format
+msgid "Failed to resolve '%s' as a valid revision."
+msgstr "無法將 '%s' 解析為一個有效的版本。"
+
+#: builtin/reset.c:351
+#, c-format
+msgid "Failed to resolve '%s' as a valid tree."
+msgstr "無法將 '%s' 解析為一個有效的樹狀物件。"
+
+#: builtin/reset.c:360
+msgid "--patch is incompatible with --{hard,mixed,soft}"
+msgstr "--patch 與 --{hard、mixed、soft} 選項不相容"
+
+#: builtin/reset.c:370
+msgid "--mixed with paths is deprecated; use 'git reset -- <paths>' instead."
+msgstr "--mixed 帶路徑已棄用，而是用 'git reset -- <路徑>'。"
+
+#  譯者：漢字之間無空格，故刪除%s前後空格
+#: builtin/reset.c:372
+#, c-format
+msgid "Cannot do %s reset with paths."
+msgstr "不能帶路徑進行%s重設。"
+
+#  譯者：漢字之間無空格，故刪除%s前後空格
+#: builtin/reset.c:387
+#, c-format
+msgid "%s reset is not allowed in a bare repository"
+msgstr "不能對純版本庫進行%s重設"
+
+#: builtin/reset.c:391
+msgid "-N can only be used with --mixed"
+msgstr "-N 只能和 --mixed 同時使用"
+
+#: builtin/reset.c:412
+msgid "Unstaged changes after reset:"
+msgstr "重設後取消暫存的變更："
+
+#: builtin/reset.c:415
+#, c-format
+msgid ""
+"\n"
+"It took %.2f seconds to enumerate unstaged changes after reset.  You can\n"
+"use '--quiet' to avoid this.  Set the config setting reset.quiet to true\n"
+"to make this the default.\n"
+msgstr ""
+"\n"
+"重設後，枚舉未暫存變更花費了 %.2f 秒。 您可以使用 '--quiet' 避免此情況。\n"
+"將設定變數 reset.quiet 設定為 true 可使其成為預設值。\n"
+
+#: builtin/reset.c:425
+#, c-format
+msgid "Could not reset index file to revision '%s'."
+msgstr "不能重設索引檔案至版本 '%s'。"
+
+#: builtin/reset.c:429
+msgid "Could not write new index file."
+msgstr "不能寫入新的索引檔案。"
+
+#: builtin/rev-list.c:411
+msgid "cannot combine --exclude-promisor-objects and --missing"
+msgstr "不能同時使用 --exclude-promisor-objects 和 --missing 選項"
+
+#: builtin/rev-list.c:472
+msgid "object filtering requires --objects"
+msgstr "物件過濾需要 --objects"
+
+#: builtin/rev-list.c:522
+msgid "rev-list does not support display of notes"
+msgstr "rev-list 不支援顯示註解"
+
+#: builtin/rev-list.c:525
+msgid "cannot combine --use-bitmap-index with object filtering"
+msgstr "不能將 --use-bitmap-index 和物件過濾組合使用"
+
+#: builtin/rev-parse.c:408
+msgid "git rev-parse --parseopt [<options>] -- [<args>...]"
+msgstr "git rev-parse --parseopt [<選項>] -- [<參數>...]"
+
+#: builtin/rev-parse.c:413
+msgid "keep the `--` passed as an arg"
+msgstr "保持 `--` 作為一個參數傳遞"
+
+#: builtin/rev-parse.c:415
+msgid "stop parsing after the first non-option argument"
+msgstr "遇到第一個非選項參數後停止解析"
+
+#: builtin/rev-parse.c:418
+msgid "output in stuck long form"
+msgstr "以固定長格式輸出"
+
+#: builtin/rev-parse.c:551
+msgid ""
+"git rev-parse --parseopt [<options>] -- [<args>...]\n"
+"   or: git rev-parse --sq-quote [<arg>...]\n"
+"   or: git rev-parse [<options>] [<arg>...]\n"
+"\n"
+"Run \"git rev-parse --parseopt -h\" for more information on the first usage."
+msgstr ""
+"git rev-parse --parseopt [<選項>] -- [<參數>...]\n"
+"   或者：git rev-parse --sq-quote [<參數>...]\n"
+"   或者：git rev-parse [<選項>] [<參數>...]\n"
+"\n"
+"初次使用時執行 \"git rev-parse --parseopt -h\" 來獲得更多訊息。"
+
+#: builtin/revert.c:24
+msgid "git revert [<options>] <commit-ish>..."
+msgstr "git revert [<選項>] <提交號>..."
+
+#: builtin/revert.c:25
+msgid "git revert <subcommand>"
+msgstr "git revert <子指令>"
+
+#: builtin/revert.c:30
+msgid "git cherry-pick [<options>] <commit-ish>..."
+msgstr "git cherry-pick [<選項>] <提交號>..."
+
+#: builtin/revert.c:31
+msgid "git cherry-pick <subcommand>"
+msgstr "git cherry-pick <子指令>"
+
+#: builtin/revert.c:72
+#, c-format
+msgid "option `%s' expects a number greater than zero"
+msgstr "選項 `%s' 期望一個大於零的數字"
+
+#: builtin/revert.c:92
+#, c-format
+msgid "%s: %s cannot be used with %s"
+msgstr "%s：%s 不能和 %s 同時使用"
+
+#: builtin/revert.c:102
+msgid "end revert or cherry-pick sequence"
+msgstr "終止反轉或揀選動作"
+
+#: builtin/revert.c:103
+msgid "resume revert or cherry-pick sequence"
+msgstr "繼續反轉或揀選動作"
+
+#: builtin/revert.c:104
+msgid "cancel revert or cherry-pick sequence"
+msgstr "取消反轉或揀選動作"
+
+#: builtin/revert.c:105
+msgid "skip current commit and continue"
+msgstr "跳過目前提交並繼續"
+
+#: builtin/revert.c:107
+msgid "don't automatically commit"
+msgstr "不要自動提交"
+
+#: builtin/revert.c:108
+msgid "edit the commit message"
+msgstr "編輯提交說明"
+
+#: builtin/revert.c:111
+msgid "parent-number"
+msgstr "父編號"
+
+#: builtin/revert.c:112
+msgid "select mainline parent"
+msgstr "選擇主幹父提交編號"
+
+#: builtin/revert.c:114
+msgid "merge strategy"
+msgstr "合併策略"
+
+#: builtin/revert.c:116
+msgid "option for merge strategy"
+msgstr "合併策略的選項"
+
+#: builtin/revert.c:125
+msgid "append commit name"
+msgstr "追加提交名稱"
+
+#: builtin/revert.c:127
+msgid "preserve initially empty commits"
+msgstr "保留初始化的空提交"
+
+#: builtin/revert.c:129
+msgid "keep redundant, empty commits"
+msgstr "保持多餘的、空的提交"
+
+#: builtin/revert.c:232
+msgid "revert failed"
+msgstr "還原失敗"
+
+#: builtin/revert.c:245
+msgid "cherry-pick failed"
+msgstr "揀選失敗"
+
+#: builtin/rm.c:19
+msgid "git rm [<options>] [--] <file>..."
+msgstr "git rm [<選項>] [--] <檔案>..."
+
+#: builtin/rm.c:207
+msgid ""
+"the following file has staged content different from both the\n"
+"file and the HEAD:"
+msgid_plural ""
+"the following files have staged content different from both the\n"
+"file and the HEAD:"
+msgstr[0] "如下檔案其暫存的內容和工作區及 HEAD 中的都不一樣："
+msgstr[1] "如下檔案其暫存的內容和工作區及 HEAD 中的都不一樣："
+
+#: builtin/rm.c:212
+msgid ""
+"\n"
+"(use -f to force removal)"
+msgstr ""
+"\n"
+"（使用 -f 強制刪除）"
+
+#: builtin/rm.c:216
+msgid "the following file has changes staged in the index:"
+msgid_plural "the following files have changes staged in the index:"
+msgstr[0] "下列檔案索引中有變更"
+msgstr[1] "下列檔案索引中有變更"
+
+#: builtin/rm.c:220 builtin/rm.c:229
+msgid ""
+"\n"
+"(use --cached to keep the file, or -f to force removal)"
+msgstr ""
+"\n"
+"（使用 --cached 保留本機檔案，或用 -f 強制刪除）"
+
+#: builtin/rm.c:226
+msgid "the following file has local modifications:"
+msgid_plural "the following files have local modifications:"
+msgstr[0] "如下檔案有本機修改："
+msgstr[1] "如下檔案有本機修改："
+
+#: builtin/rm.c:242
+msgid "do not list removed files"
+msgstr "不列出刪除的檔案"
+
+#: builtin/rm.c:243
+msgid "only remove from the index"
+msgstr "只從索引區刪除"
+
+#: builtin/rm.c:244
+msgid "override the up-to-date check"
+msgstr "忽略檔案更新狀態檢查"
+
+#: builtin/rm.c:245
+msgid "allow recursive removal"
+msgstr "允許遞迴刪除"
+
+#: builtin/rm.c:247
+msgid "exit with a zero status even if nothing matched"
+msgstr "即使沒有符合，也以零狀態離開"
+
+#: builtin/rm.c:289
+msgid "please stage your changes to .gitmodules or stash them to proceed"
+msgstr "請將您的修改暫存到 .gitmodules 中或儲藏後再繼續"
+
+#: builtin/rm.c:307
+#, c-format
+msgid "not removing '%s' recursively without -r"
+msgstr "未提供 -r 選項不會遞迴刪除 '%s'"
+
+#: builtin/rm.c:346
+#, c-format
+msgid "git rm: unable to remove %s"
+msgstr "git rm：不能刪除 %s"
+
+#: builtin/send-pack.c:20
+msgid ""
+"git send-pack [--all | --mirror] [--dry-run] [--force] [--receive-pack=<git-"
+"receive-pack>] [--verbose] [--thin] [--atomic] [<host>:]<directory> "
+"[<ref>...]\n"
+"  --all and explicit <ref> specification are mutually exclusive."
+msgstr ""
+"git send-pack [--all | --mirror] [--dry-run] [--force] [--receive-pack=<git-"
+"receive-pack>] [--verbose] [--thin] [--atomic] [<主機>:]<目錄> [<引用>...]\n"
+"  --all 和明確的 <引用> 互斥。"
+
+#: builtin/send-pack.c:163
+msgid "remote name"
+msgstr "遠端名稱"
+
+#: builtin/send-pack.c:177
+msgid "use stateless RPC protocol"
+msgstr "使用無狀態的 RPC 協定"
+
+#: builtin/send-pack.c:178
+msgid "read refs from stdin"
+msgstr "從標準輸入讀取引用"
+
+#: builtin/send-pack.c:179
+msgid "print status from remote helper"
+msgstr "列印來自遠端 helper 的狀態"
+
+#: builtin/shortlog.c:14
+msgid "git shortlog [<options>] [<revision-range>] [[--] <path>...]"
+msgstr "git shortlog [<選項>] [<版本範圍>] [[--] <路徑>...]"
+
+#: builtin/shortlog.c:15
+msgid "git log --pretty=short | git shortlog [<options>]"
+msgstr "git log --pretty=short | git shortlog [<選項>]"
+
+#: builtin/shortlog.c:264
+msgid "Group by committer rather than author"
+msgstr "按照提交者分組而不是作者"
+
+#: builtin/shortlog.c:266
+msgid "sort output according to the number of commits per author"
+msgstr "根據每個作者的提交數量排序"
+
+#: builtin/shortlog.c:268
+msgid "Suppress commit descriptions, only provides commit count"
+msgstr "隱藏提交說明，只提供提交數量"
+
+#: builtin/shortlog.c:270
+msgid "Show the email address of each author"
+msgstr "顯示每個作者的電子信件位址"
+
+#: builtin/shortlog.c:271
+msgid "<w>[,<i1>[,<i2>]]"
+msgstr "<w>[,<i1>[,<i2>]]"
+
+#: builtin/shortlog.c:272
+msgid "Linewrap output"
+msgstr "折行輸出"
+
+#: builtin/shortlog.c:301
+msgid "too many arguments given outside repository"
+msgstr "版本庫外執行提供了太多的參數"
+
+#: builtin/show-branch.c:13
+msgid ""
+"git show-branch [-a | --all] [-r | --remotes] [--topo-order | --date-order]\n"
+"\t\t[--current] [--color[=<when>] | --no-color] [--sparse]\n"
+"\t\t[--more=<n> | --list | --independent | --merge-base]\n"
+"\t\t[--no-name | --sha1-name] [--topics] [(<rev> | <glob>)...]"
+msgstr ""
+"git show-branch [-a | --all] [-r | --remotes] [--topo-order | --date-order]\n"
+"\t\t[--current] [--color[=<何時>] | --no-color] [--sparse]\n"
+"\t\t[--more=<n> | --list | --independent | --merge-base]\n"
+"\t\t[--no-name | --sha1-name] [--topics] [(<版本> | <萬用字元>)...]"
+
+#: builtin/show-branch.c:17
+msgid "git show-branch (-g | --reflog)[=<n>[,<base>]] [--list] [<ref>]"
+msgstr "git show-branch (-g | --reflog)[=<n>[,<起始點>]] [--list] [<引用>]"
+
+#: builtin/show-branch.c:395
+#, c-format
+msgid "ignoring %s; cannot handle more than %d ref"
+msgid_plural "ignoring %s; cannot handle more than %d refs"
+msgstr[0] "忽略 %s，無法處理 %d 個以上的引用"
+msgstr[1] "忽略 %s，無法處理 %d 個以上的引用"
+
+#: builtin/show-branch.c:548
+#, c-format
+msgid "no matching refs with %s"
+msgstr "沒有和 %s 符合的引用"
+
+#: builtin/show-branch.c:645
+msgid "show remote-tracking and local branches"
+msgstr "顯示遠端追蹤的和本機的分支"
+
+#: builtin/show-branch.c:647
+msgid "show remote-tracking branches"
+msgstr "顯示遠端追蹤的分支"
+
+#: builtin/show-branch.c:649
+msgid "color '*!+-' corresponding to the branch"
+msgstr "著色 '*!+-' 到相應的分支"
+
+#: builtin/show-branch.c:651
+msgid "show <n> more commits after the common ancestor"
+msgstr "顯示共同祖先後的 <n> 個提交"
+
+#: builtin/show-branch.c:653
+msgid "synonym to more=-1"
+msgstr "和 more=-1 同義"
+
+#: builtin/show-branch.c:654
+msgid "suppress naming strings"
+msgstr "不顯示字串命名"
+
+#: builtin/show-branch.c:656
+msgid "include the current branch"
+msgstr "包括目前分支"
+
+#: builtin/show-branch.c:658
+msgid "name commits with their object names"
+msgstr "以物件名字命名提交"
+
+#: builtin/show-branch.c:660
+msgid "show possible merge bases"
+msgstr "顯示可能合併的基礎"
+
+#: builtin/show-branch.c:662
+msgid "show refs unreachable from any other ref"
+msgstr "顯示沒有任何引用的的引用"
+
+#: builtin/show-branch.c:664
+msgid "show commits in topological order"
+msgstr "以拓撲順序顯示提交"
+
+#: builtin/show-branch.c:667
+msgid "show only commits not on the first branch"
+msgstr "只顯示不在第一個分支上的提交"
+
+#: builtin/show-branch.c:669
+msgid "show merges reachable from only one tip"
+msgstr "顯示僅一個分支可存取的合併提交"
+
+#: builtin/show-branch.c:671
+msgid "topologically sort, maintaining date order where possible"
+msgstr "拓撲方式排序，並儘可能地保持日期順序"
+
+#: builtin/show-branch.c:674
+msgid "<n>[,<base>]"
+msgstr "<n>[,<base>]"
+
+#: builtin/show-branch.c:675
+msgid "show <n> most recent ref-log entries starting at base"
+msgstr "顯示從起始點開始的 <n> 條最近的引用日誌記錄"
+
+#: builtin/show-branch.c:711
+msgid ""
+"--reflog is incompatible with --all, --remotes, --independent or --merge-base"
+msgstr "--reflog 和 --all、--remotes、--independent 或 --merge-base 不相容"
+
+#: builtin/show-branch.c:735
+msgid "no branches given, and HEAD is not valid"
+msgstr "未提供分支，且 HEAD 無效"
+
+#: builtin/show-branch.c:738
+msgid "--reflog option needs one branch name"
+msgstr "選項 --reflog 需要一個分支名"
+
+#: builtin/show-branch.c:741
+#, c-format
+msgid "only %d entry can be shown at one time."
+msgid_plural "only %d entries can be shown at one time."
+msgstr[0] "一次只能顯示 %d 個條目。"
+msgstr[1] "一次只能顯示 %d 個條目。"
+
+#: builtin/show-branch.c:745
+#, c-format
+msgid "no such ref %s"
+msgstr "無此引用 %s"
+
+#: builtin/show-branch.c:831
+#, c-format
+msgid "cannot handle more than %d rev."
+msgid_plural "cannot handle more than %d revs."
+msgstr[0] "不能處理 %d 個以上的版本。"
+msgstr[1] "不能處理 %d 個以上的版本。"
+
+#: builtin/show-branch.c:835
+#, c-format
+msgid "'%s' is not a valid ref."
+msgstr "'%s' 不是一個有效的引用。"
+
+#: builtin/show-branch.c:838
+#, c-format
+msgid "cannot find commit %s (%s)"
+msgstr "不能找到提交 %s（%s）"
+
+#: builtin/show-ref.c:12
+msgid ""
+"git show-ref [-q | --quiet] [--verify] [--head] [-d | --dereference] [-s | --"
+"hash[=<n>]] [--abbrev[=<n>]] [--tags] [--heads] [--] [<pattern>...]"
+msgstr ""
+"git show-ref [-q | --quiet] [--verify] [--head] [-d | --dereference] [-s | --"
+"hash[=<n>]] [--abbrev[=<n>]] [--tags] [--heads] [--] [<模式>...]"
+
+#: builtin/show-ref.c:13
+msgid "git show-ref --exclude-existing[=<pattern>]"
+msgstr "git show-ref --exclude-existing[=<模式>]"
+
+#: builtin/show-ref.c:162
+msgid "only show tags (can be combined with heads)"
+msgstr "只顯示標籤（可以和頭共用）"
+
+#: builtin/show-ref.c:163
+msgid "only show heads (can be combined with tags)"
+msgstr "只顯示頭（可以和標籤共用）"
+
+#: builtin/show-ref.c:164
+msgid "stricter reference checking, requires exact ref path"
+msgstr "更嚴格的引用檢測，需要精確的引用路徑"
+
+#: builtin/show-ref.c:167 builtin/show-ref.c:169
+msgid "show the HEAD reference, even if it would be filtered out"
+msgstr "顯示 HEAD 引用，即使被過濾掉"
+
+#: builtin/show-ref.c:171
+msgid "dereference tags into object IDs"
+msgstr "轉換標籤到物件 ID"
+
+#: builtin/show-ref.c:173
+msgid "only show SHA1 hash using <n> digits"
+msgstr "只顯示使用 <n> 個數字的 SHA1 雜湊"
+
+#: builtin/show-ref.c:177
+msgid "do not print results to stdout (useful with --verify)"
+msgstr "不列印結果到標準輸出（例如與 --verify 參數共用）"
+
+#: builtin/show-ref.c:179
+msgid "show refs from stdin that aren't in local repository"
+msgstr "顯示從標準輸入中讀入的不在本機版本庫中的引用"
+
+#: builtin/sparse-checkout.c:20
+msgid "git sparse-checkout (init|list|set|disable) <options>"
+msgstr "git sparse-checkout (init|list|set|disable) <選項>"
+
+#: builtin/sparse-checkout.c:61
+msgid "this worktree is not sparse (sparse-checkout file may not exist)"
+msgstr "這不是稀疏工作區（sparse-checkout 檔案可能不存在）"
+
+#: builtin/sparse-checkout.c:220
+msgid "failed to set extensions.worktreeConfig setting"
+msgstr "無法設定 extensions.worktreeConfig 設定"
+
+#: builtin/sparse-checkout.c:237
+msgid "git sparse-checkout init [--cone]"
+msgstr "git sparse-checkout init [--cone]"
+
+#: builtin/sparse-checkout.c:256
+msgid "initialize the sparse-checkout in cone mode"
+msgstr "以 cone 模式初始化稀疏簽出"
+
+#: builtin/sparse-checkout.c:262
+#| msgid "skip applying sparse checkout filter"
+msgid "initialize sparse-checkout"
+msgstr "初始化稀疏簽出"
+
+#: builtin/sparse-checkout.c:295
+#, c-format
+#| msgid "failed to open '%s': %s"
+msgid "failed to open '%s'"
+msgstr "無法開啟「%s」"
+
+#: builtin/sparse-checkout.c:361
+#| msgid "git hash-object  --stdin-paths"
+msgid "git sparse-checkout set (--stdin | <patterns>)"
+msgstr "git sparse-checkout set (--stdin | <樣式>)"
+
+#: builtin/sparse-checkout.c:378
+#| msgid "read updates from stdin"
+msgid "read patterns from standard in"
+msgstr "從標準輸入讀取樣式"
+
+#: builtin/sparse-checkout.c:384
+#| msgid "skip applying sparse checkout filter"
+msgid "set sparse-checkout patterns"
+msgstr "設定稀疏簽出樣式"
+
+#: builtin/sparse-checkout.c:447
+#| msgid "skip applying sparse checkout filter"
+msgid "disable sparse-checkout"
+msgstr "停用稀疏簽出"
+
+#: builtin/sparse-checkout.c:459
+#| msgid "unable to get current working directory"
+msgid "error while refreshing working directory"
+msgstr "重新整理工作目錄時發生錯誤"
+
+#: builtin/stash.c:22 builtin/stash.c:37
+msgid "git stash list [<options>]"
+msgstr "git stash list [<選項>]"
+
+#: builtin/stash.c:23 builtin/stash.c:42
+msgid "git stash show [<options>] [<stash>]"
+msgstr "git stash show [<選項>] [<stash>]"
+
+#: builtin/stash.c:24 builtin/stash.c:47
+msgid "git stash drop [-q|--quiet] [<stash>]"
+msgstr "git stash drop [-q|--quiet] [<stash>]"
+
+#: builtin/stash.c:25
+msgid "git stash ( pop | apply ) [--index] [-q|--quiet] [<stash>]"
+msgstr "git stash ( pop | apply ) [--index] [-q|--quiet] [<stash>]"
+
+#: builtin/stash.c:26 builtin/stash.c:62
+msgid "git stash branch <branchname> [<stash>]"
+msgstr "git stash branch <分支名> [<stash>]"
+
+#: builtin/stash.c:27 builtin/stash.c:67
+msgid "git stash clear"
+msgstr "git stash clear"
+
+#: builtin/stash.c:28 builtin/stash.c:77
+msgid ""
+"git stash [push [-p|--patch] [-k|--[no-]keep-index] [-q|--quiet]\n"
+"          [-u|--include-untracked] [-a|--all] [-m|--message <message>]\n"
+"          [--] [<pathspec>...]]"
+msgstr ""
+"git stash [push [-p|--patch] [-k|--[no-]keep-index] [-q|--quiet]\n"
+"          [-u|--include-untracked] [-a|--all] [-m|--message <消息>]\n"
+"          [--] [<路徑規格>...]]"
+
+#: builtin/stash.c:31 builtin/stash.c:84
+msgid ""
+"git stash save [-p|--patch] [-k|--[no-]keep-index] [-q|--quiet]\n"
+"          [-u|--include-untracked] [-a|--all] [<message>]"
+msgstr ""
+"git stash save [-p|--patch] [-k|--[no-]keep-index] [-q|--quiet]\n"
+"          [-u|--include-untracked] [-a|--all] [<消息>]"
+
+#: builtin/stash.c:52
+msgid "git stash pop [--index] [-q|--quiet] [<stash>]"
+msgstr "git stash pop [--index] [-q|--quiet] [<stash>]"
+
+#: builtin/stash.c:57
+msgid "git stash apply [--index] [-q|--quiet] [<stash>]"
+msgstr "git stash apply [--index] [-q|--quiet] [<stash>]"
+
+#: builtin/stash.c:72
+msgid "git stash store [-m|--message <message>] [-q|--quiet] <commit>"
+msgstr "git stash store [-m|--message <消息>] [-q|--quiet] <提交>"
+
+#: builtin/stash.c:127
+#, c-format
+msgid "'%s' is not a stash-like commit"
+msgstr "'%s' 不像是一個儲藏提交"
+
+#: builtin/stash.c:147
+#, c-format
+msgid "Too many revisions specified:%s"
+msgstr "指定了太多的版本：%s"
+
+#: builtin/stash.c:161 git-legacy-stash.sh:549
+msgid "No stash entries found."
+msgstr "未發現儲藏條目。"
+
+#: builtin/stash.c:175
+#, c-format
+msgid "%s is not a valid reference"
+msgstr "%s 不是一個有效的引用名"
+
+#: builtin/stash.c:224 git-legacy-stash.sh:75
+msgid "git stash clear with parameters is unimplemented"
+msgstr "git stash clear 不支援參數"
+
+#: builtin/stash.c:403
+msgid "cannot apply a stash in the middle of a merge"
+msgstr "無法在合併過程套用儲藏"
+
+#: builtin/stash.c:414
+#, c-format
+msgid "could not generate diff %s^!."
+msgstr "無法生成差異 %s^!."
+
+#: builtin/stash.c:421
+msgid "conflicts in index.Try without --index."
+msgstr "索引中有衝突。嘗試不用 --index。"
+
+#: builtin/stash.c:427
+msgid "could not save index tree"
+msgstr "不能儲存索引樹"
+
+#: builtin/stash.c:436
+msgid "could not restore untracked files from stash"
+msgstr "無法從儲藏條目中復原未追蹤檔案"
+
+#: builtin/stash.c:450
+#, c-format
+msgid "Merging %s with %s"
+msgstr "正在合併 %s 和 %s"
+
+#: builtin/stash.c:460 git-legacy-stash.sh:681
+msgid "Index was not unstashed."
+msgstr "索引未從儲藏中復原。"
+
+#: builtin/stash.c:521 builtin/stash.c:620
+msgid "attempt to recreate the index"
+msgstr "嘗試重建索引"
+
+#: builtin/stash.c:554
+#, c-format
+msgid "Dropped %s (%s)"
+msgstr "捨棄了 %s（%s）"
+
+#: builtin/stash.c:557
+#, c-format
+msgid "%s: Could not drop stash entry"
+msgstr "%s：無法捨棄儲藏條目"
+
+#: builtin/stash.c:582
+#, c-format
+msgid "'%s' is not a stash reference"
+msgstr "'%s' 不是一個儲藏引用"
+
+#: builtin/stash.c:632 git-legacy-stash.sh:695
+msgid "The stash entry is kept in case you need it again."
+msgstr "儲藏條目被保留以備您再次需要。"
+
+#: builtin/stash.c:655 git-legacy-stash.sh:713
+msgid "No branch name specified"
+msgstr "未指定分支名"
+
+#: builtin/stash.c:795 builtin/stash.c:832
+#, c-format
+msgid "Cannot update %s with %s"
+msgstr "無法用 %2$s 更新 %1$s"
+
+#: builtin/stash.c:813 builtin/stash.c:1470 builtin/stash.c:1506
+msgid "stash message"
+msgstr "儲藏說明"
+
+#: builtin/stash.c:823
+msgid "\"git stash store\" requires one <commit> argument"
+msgstr "\"git stash store\" 需要一個 <提交> 參數"
+
+#: builtin/stash.c:1045 git-legacy-stash.sh:218
+msgid "No changes selected"
+msgstr "沒有選擇變更"
+
+#: builtin/stash.c:1145 git-legacy-stash.sh:150
+msgid "You do not have the initial commit yet"
+msgstr "您尚未建立初始提交"
+
+#: builtin/stash.c:1172 git-legacy-stash.sh:165
+msgid "Cannot save the current index state"
+msgstr "無法儲存目前索引狀態"
+
+#: builtin/stash.c:1181 git-legacy-stash.sh:180
+msgid "Cannot save the untracked files"
+msgstr "無法儲存未追蹤檔案"
+
+#: builtin/stash.c:1192 builtin/stash.c:1201 git-legacy-stash.sh:201
+#: git-legacy-stash.sh:214
+msgid "Cannot save the current worktree state"
+msgstr "無法儲存目前工作區狀態"
+
+#: builtin/stash.c:1229 git-legacy-stash.sh:234
+msgid "Cannot record working tree state"
+msgstr "不能記錄工作區狀態"
+
+#: builtin/stash.c:1278 git-legacy-stash.sh:338
+msgid "Can't use --patch and --include-untracked or --all at the same time"
+msgstr "不能同時使用參數 --patch 和 --include-untracked 或 --all"
+
+#: builtin/stash.c:1294
+msgid "Did you forget to 'git add'?"
+msgstr "您是否忘了執行 'git add'？"
+
+#: builtin/stash.c:1309 git-legacy-stash.sh:346
+msgid "No local changes to save"
+msgstr "沒有要儲存的本機修改"
+
+#: builtin/stash.c:1316 git-legacy-stash.sh:351
+msgid "Cannot initialize stash"
+msgstr "無法初始化儲藏"
+
+#: builtin/stash.c:1331 git-legacy-stash.sh:355
+msgid "Cannot save the current status"
+msgstr "無法儲存目前狀態"
+
+#: builtin/stash.c:1336
+#, c-format
+msgid "Saved working directory and index state %s"
+msgstr "儲存工作目錄和索引狀態 %s"
+
+#: builtin/stash.c:1426 git-legacy-stash.sh:385
+msgid "Cannot remove worktree changes"
+msgstr "無法刪除工作區變更"
+
+#: builtin/stash.c:1461 builtin/stash.c:1497
+msgid "keep index"
+msgstr "保持索引"
+
+#: builtin/stash.c:1463 builtin/stash.c:1499
+msgid "stash in patch mode"
+msgstr "以修補檔模式儲藏"
+
+#: builtin/stash.c:1464 builtin/stash.c:1500
+msgid "quiet mode"
+msgstr "靜默模式"
+
+#: builtin/stash.c:1466 builtin/stash.c:1502
+msgid "include untracked files in stash"
+msgstr "儲藏中包含未追蹤檔案"
+
+#: builtin/stash.c:1468 builtin/stash.c:1504
+msgid "include ignore files"
+msgstr "包含忽略的檔案"
+
+#: builtin/stash.c:1564
+#, c-format
+msgid "could not exec %s"
+msgstr "不能執行 %s"
+
+#: builtin/stripspace.c:18
+msgid "git stripspace [-s | --strip-comments]"
+msgstr "git stripspace [-s | --strip-comments]"
+
+#: builtin/stripspace.c:19
+msgid "git stripspace [-c | --comment-lines]"
+msgstr "git stripspace [-c | --comment-lines]"
+
+#: builtin/stripspace.c:37
+msgid "skip and remove all lines starting with comment character"
+msgstr "跳過和移除所有的備註行"
+
+#: builtin/stripspace.c:40
+msgid "prepend comment character and space to each line"
+msgstr "為每一行的行首新增備註符和空格"
+
+#: builtin/submodule--helper.c:47 builtin/submodule--helper.c:1970
+#, c-format
+msgid "Expecting a full ref name, got %s"
+msgstr "期望一個完整的引用名稱，卻得到 %s"
+
+#: builtin/submodule--helper.c:64
+msgid "submodule--helper print-default-remote takes no arguments"
+msgstr "submodule--helper print-default-remote 不帶參數"
+
+#: builtin/submodule--helper.c:102
+#, c-format
+msgid "cannot strip one component off url '%s'"
+msgstr "無法從 url '%s' 剝離一個元件"
+
+#: builtin/submodule--helper.c:410 builtin/submodule--helper.c:1380
+msgid "alternative anchor for relative paths"
+msgstr "相對路徑的替代錨記（anchor）"
+
+#: builtin/submodule--helper.c:415
+msgid "git submodule--helper list [--prefix=<path>] [<path>...]"
+msgstr "git submodule--helper list [--prefix=<路徑>] [<路徑>...]"
+
+#: builtin/submodule--helper.c:472 builtin/submodule--helper.c:630
+#: builtin/submodule--helper.c:653
+#, c-format
+msgid "No url found for submodule path '%s' in .gitmodules"
+msgstr "在 .gitmodules 中未找到子模組 '%s' 的 url"
+
+#: builtin/submodule--helper.c:524
+#, c-format
+msgid "Entering '%s'\n"
+msgstr "進入 '%s'\n"
+
+#: builtin/submodule--helper.c:527
+#, c-format
+msgid ""
+"run_command returned non-zero status for %s\n"
+"."
+msgstr ""
+"對 %s 執行 run_command 返回非零值。\n"
+"."
+
+#: builtin/submodule--helper.c:549
+#, c-format
+msgid ""
+"run_command returned non-zero status while recursing in the nested "
+"submodules of %s\n"
+"."
+msgstr ""
+"在遞迴 %s 的子模組執行 run_command 時返回非零值。\n"
+"."
+
+#: builtin/submodule--helper.c:565
+msgid "Suppress output of entering each submodule command"
+msgstr "阻止進入每一個子模組指令的輸出"
+
+#: builtin/submodule--helper.c:567 builtin/submodule--helper.c:1053
+msgid "Recurse into nested submodules"
+msgstr "遞迴進入嵌套子模組中"
+
+#: builtin/submodule--helper.c:572
+msgid "git submodule--helper foreach [--quiet] [--recursive] [--] <command>"
+msgstr "git submodule--helper foreach [--quiet] [--recursive] [--] <指令>"
+
+#: builtin/submodule--helper.c:599
+#, c-format
+msgid ""
+"could not look up configuration '%s'. Assuming this repository is its own "
+"authoritative upstream."
+msgstr "無法找到設定 '%s'。假定這個版本庫是其自身的官方上游。"
+
+#: builtin/submodule--helper.c:667
+#, c-format
+msgid "Failed to register url for submodule path '%s'"
+msgstr "無法為子模組 '%s' 註冊 url"
+
+#: builtin/submodule--helper.c:671
+#, c-format
+msgid "Submodule '%s' (%s) registered for path '%s'\n"
+msgstr "子模組 '%s'（%s）已對路徑 '%s' 註冊\n"
+
+#: builtin/submodule--helper.c:681
+#, c-format
+msgid "warning: command update mode suggested for submodule '%s'\n"
+msgstr "警告：建議子模組 '%s' 使用指令更新模式\n"
+
+#: builtin/submodule--helper.c:688
+#, c-format
+msgid "Failed to register update mode for submodule path '%s'"
+msgstr "無法為子模組 '%s' 註冊更新模式"
+
+#: builtin/submodule--helper.c:710
+msgid "Suppress output for initializing a submodule"
+msgstr "阻止子模組初始化的輸出"
+
+#: builtin/submodule--helper.c:715
+msgid "git submodule--helper init [<options>] [<path>]"
+msgstr "git submodule--helper init [<選項>] [<路徑>]"
+
+#: builtin/submodule--helper.c:787 builtin/submodule--helper.c:914
+#, c-format
+msgid "no submodule mapping found in .gitmodules for path '%s'"
+msgstr "在 .gitmodules 中沒有發現路徑 '%s' 的子模組映射"
+
+#: builtin/submodule--helper.c:827
+#, c-format
+msgid "could not resolve HEAD ref inside the submodule '%s'"
+msgstr "無法解析子模組 '%s' 的 HEAD 引用"
+
+#: builtin/submodule--helper.c:854 builtin/submodule--helper.c:1023
+#, c-format
+msgid "failed to recurse into submodule '%s'"
+msgstr "遞迴子模組 '%s' 失敗"
+
+#: builtin/submodule--helper.c:878 builtin/submodule--helper.c:1189
+msgid "Suppress submodule status output"
+msgstr "阻止子模組狀態輸出"
+
+#: builtin/submodule--helper.c:879
+msgid ""
+"Use commit stored in the index instead of the one stored in the submodule "
+"HEAD"
+msgstr "使用儲存在索引中的提交，而非儲存在子模組 HEAD 中的提交"
+
+#: builtin/submodule--helper.c:880
+msgid "recurse into nested submodules"
+msgstr "遞迴進入嵌套子模組中"
+
+#: builtin/submodule--helper.c:885
+msgid "git submodule status [--quiet] [--cached] [--recursive] [<path>...]"
+msgstr "git submodule status [--quiet] [--cached] [--recursive] [<路徑>...]"
+
+#: builtin/submodule--helper.c:909
+msgid "git submodule--helper name <path>"
+msgstr "git submodule--helper name <路徑>"
+
+#: builtin/submodule--helper.c:973
+#, c-format
+msgid "Synchronizing submodule url for '%s'\n"
+msgstr "為 '%s' 同步子模組 url\n"
+
+#: builtin/submodule--helper.c:979
+#, c-format
+msgid "failed to register url for submodule path '%s'"
+msgstr "無法為子模組路徑 '%s' 註冊 url"
+
+#: builtin/submodule--helper.c:993
+#, c-format
+msgid "failed to get the default remote for submodule '%s'"
+msgstr "無法得到子模組 '%s' 的預設遠端關聯"
+
+#: builtin/submodule--helper.c:1004
+#, c-format
+msgid "failed to update remote for submodule '%s'"
+msgstr "無法為子模組 '%s' 更新遠端關聯"
+
+#: builtin/submodule--helper.c:1051
+msgid "Suppress output of synchronizing submodule url"
+msgstr "阻止子模組 url 同步的輸出"
+
+#: builtin/submodule--helper.c:1058
+msgid "git submodule--helper sync [--quiet] [--recursive] [<path>]"
+msgstr "git submodule--helper sync [--quiet] [--recursive] [<路徑>]"
+
+#: builtin/submodule--helper.c:1112
+#, c-format
+msgid ""
+"Submodule work tree '%s' contains a .git directory (use 'rm -rf' if you "
+"really want to remove it including all of its history)"
+msgstr ""
+"子模組工作區 '%s' 包含一個 .git 目錄（如果您確需刪除它及其全部歷史，使用 'rm "
+"-rf' 指令）"
+
+#: builtin/submodule--helper.c:1124
+#, c-format
+msgid ""
+"Submodule work tree '%s' contains local modifications; use '-f' to discard "
+"them"
+msgstr "子模組工作區 '%s' 包含本機修改；使用 '-f' 捨棄它們"
+
+#: builtin/submodule--helper.c:1132
+#, c-format
+msgid "Cleared directory '%s'\n"
+msgstr "已清除目錄 '%s'\n"
+
+#: builtin/submodule--helper.c:1134
+#, c-format
+msgid "Could not remove submodule work tree '%s'\n"
+msgstr "無法移除子模組工作區 '%s'\n"
+
+#: builtin/submodule--helper.c:1145
+#, c-format
+msgid "could not create empty submodule directory %s"
+msgstr "不能建立空的子模組目錄 %s"
+
+#: builtin/submodule--helper.c:1161
+#, c-format
+msgid "Submodule '%s' (%s) unregistered for path '%s'\n"
+msgstr "子模組 '%s'（%s）未對路徑 '%s' 註冊\n"
+
+#: builtin/submodule--helper.c:1190
+msgid "Remove submodule working trees even if they contain local changes"
+msgstr "刪除子模組工作區，即使包含本機修改"
+
+#: builtin/submodule--helper.c:1191
+msgid "Unregister all submodules"
+msgstr "將所有子模組取消註冊"
+
+#: builtin/submodule--helper.c:1196
+msgid ""
+"git submodule deinit [--quiet] [-f | --force] [--all | [--] [<path>...]]"
+msgstr "git submodule deinit [--quiet] [-f | --force] [--all | [--] [<路徑>...]]"
+
+#: builtin/submodule--helper.c:1210
+msgid "Use '--all' if you really want to deinitialize all submodules"
+msgstr "如果您確實想要對所有子模組執行取消初始化，請使用 '--all'"
+
+#: builtin/submodule--helper.c:1275
+msgid ""
+"An alternate computed from a superproject's alternate is invalid.\n"
+"To allow Git to clone without an alternate in such a case, set\n"
+"submodule.alternateErrorStrategy to 'info' or, equivalently, clone with\n"
+"'--reference-if-able' instead of '--reference'."
+msgstr ""
+
+#: builtin/submodule--helper.c:1314 builtin/submodule--helper.c:1317
+#, c-format
+msgid "submodule '%s' cannot add alternate: %s"
+msgstr "子模組 '%s' 不能新增版本庫備選：%s"
+
+#: builtin/submodule--helper.c:1353
+#, c-format
+msgid "Value '%s' for submodule.alternateErrorStrategy is not recognized"
+msgstr "不能識別 submodule.alternateErrorStrategy 的取值 '%s'"
+
+#: builtin/submodule--helper.c:1360
+#, c-format
+msgid "Value '%s' for submodule.alternateLocation is not recognized"
+msgstr "不能識別 submodule.alternateLocaion 的取值 '%s'"
+
+#: builtin/submodule--helper.c:1383
+msgid "where the new submodule will be cloned to"
+msgstr "新的子模組將要複製的路徑"
+
+#: builtin/submodule--helper.c:1386
+msgid "name of the new submodule"
+msgstr "新子模組的名稱"
+
+#: builtin/submodule--helper.c:1389
+msgid "url where to clone the submodule from"
+msgstr "複製子模組的 url 位址"
+
+#: builtin/submodule--helper.c:1397
+msgid "depth for shallow clones"
+msgstr "淺複製的深度"
+
+#: builtin/submodule--helper.c:1400 builtin/submodule--helper.c:1897
+msgid "force cloning progress"
+msgstr "強制顯示複製進度"
+
+#: builtin/submodule--helper.c:1402 builtin/submodule--helper.c:1899
+#| msgid "applying to an empty history"
+msgid "disallow cloning into non-empty directory"
+msgstr "不允許複製至非空白目錄"
+
+#: builtin/submodule--helper.c:1407
+msgid ""
+"git submodule--helper clone [--prefix=<path>] [--quiet] [--reference "
+"<repository>] [--name <name>] [--depth <depth>] --url <url> --path <path>"
+msgstr ""
+"git submodule--helper clone [--prefix=<路徑>] [--quiet] [--reference <版本庫"
+">] [--name <名字>] [--depth <深度>] --url <url> --path <路徑>"
+
+#: builtin/submodule--helper.c:1431
+#, c-format
+msgid "refusing to create/use '%s' in another submodule's git dir"
+msgstr "拒絕在其他子模組的 git 路徑建立／使用「%s」"
+
+#: builtin/submodule--helper.c:1442
+#, c-format
+msgid "clone of '%s' into submodule path '%s' failed"
+msgstr "無法複製 '%s' 到子模組路徑 '%s'"
+
+#: builtin/submodule--helper.c:1446
+#, c-format
+#| msgid "source directory is empty"
+msgid "directory not empty: '%s'"
+msgstr "目錄不是空的：「%s」"
+
+#: builtin/submodule--helper.c:1458
+#, c-format
+msgid "could not get submodule directory for '%s'"
+msgstr "無法得到 '%s' 的子模組目錄"
+
+#: builtin/submodule--helper.c:1494
+#, c-format
+msgid "Invalid update mode '%s' for submodule path '%s'"
+msgstr "子模組 '%2$s' 的更新模式 '%1$s' 無效"
+
+#: builtin/submodule--helper.c:1498
+#, c-format
+msgid "Invalid update mode '%s' configured for submodule path '%s'"
+msgstr "為子模組 '%2$s' 設定的更新模式 '%1$s' 無效"
+
+#: builtin/submodule--helper.c:1594
+#, c-format
+msgid "Submodule path '%s' not initialized"
+msgstr "子模組 '%s' 尚未初始化"
+
+#: builtin/submodule--helper.c:1598
+msgid "Maybe you want to use 'update --init'?"
+msgstr "也許您想要執行 'update --init'？"
+
+#: builtin/submodule--helper.c:1628
+#, c-format
+msgid "Skipping unmerged submodule %s"
+msgstr "略過未合併的子模組 %s"
+
+#: builtin/submodule--helper.c:1657
+#, c-format
+msgid "Skipping submodule '%s'"
+msgstr "略過子模組 '%s'"
+
+#: builtin/submodule--helper.c:1803
+#, c-format
+msgid "Failed to clone '%s'. Retry scheduled"
+msgstr "複製 '%s' 失敗。按計劃重試"
+
+#: builtin/submodule--helper.c:1814
+#, c-format
+msgid "Failed to clone '%s' a second time, aborting"
+msgstr "第二次嘗試複製 '%s' 失敗，離開"
+
+#: builtin/submodule--helper.c:1876 builtin/submodule--helper.c:2120
+msgid "path into the working tree"
+msgstr "到工作區的路徑"
+
+#: builtin/submodule--helper.c:1879
+msgid "path into the working tree, across nested submodule boundaries"
+msgstr "工作區中的路徑，遞迴嵌套子模組"
+
+#: builtin/submodule--helper.c:1883
+msgid "rebase, merge, checkout or none"
+msgstr "rebase、merge、checkout 或 none"
+
+#: builtin/submodule--helper.c:1889
+msgid "Create a shallow clone truncated to the specified number of revisions"
+msgstr "建立一個指定深度的淺複製"
+
+#: builtin/submodule--helper.c:1892
+msgid "parallel jobs"
+msgstr "並發任務"
+
+#: builtin/submodule--helper.c:1894
+msgid "whether the initial clone should follow the shallow recommendation"
+msgstr "初始複製是否應該遵守推薦的淺複製選項"
+
+#: builtin/submodule--helper.c:1895
+msgid "don't print cloning progress"
+msgstr "不要輸出複製進度"
+
+#: builtin/submodule--helper.c:1904
+msgid "git submodule--helper update-clone [--prefix=<path>] [<path>...]"
+msgstr "git submodule--helper update-clone [--prefix=<路徑>] [<路徑>...]"
+
+#: builtin/submodule--helper.c:1917
+msgid "bad value for update parameter"
+msgstr "update 參數取值錯誤"
+
+#: builtin/submodule--helper.c:1965
+#, c-format
+msgid ""
+"Submodule (%s) branch configured to inherit branch from superproject, but "
+"the superproject is not on any branch"
+msgstr "子模組（%s）的分支設定為繼承上級項目的分支，但是上級項目不在任何分支上"
+
+#: builtin/submodule--helper.c:2088
+#, c-format
+msgid "could not get a repository handle for submodule '%s'"
+msgstr "無法獲得子模組 '%s' 的版本庫句柄"
+
+#: builtin/submodule--helper.c:2121
+msgid "recurse into submodules"
+msgstr "在子模組中遞迴"
+
+#: builtin/submodule--helper.c:2127
+msgid "git submodule--helper absorb-git-dirs [<options>] [<path>...]"
+msgstr "git submodule--helper absorb-git-dirs [<選項>] [<路徑>...]"
+
+#: builtin/submodule--helper.c:2183
+msgid "check if it is safe to write to the .gitmodules file"
+msgstr "檢查寫入 .gitmodules 檔案是否安全"
+
+#: builtin/submodule--helper.c:2186
+msgid "unset the config in the .gitmodules file"
+msgstr "取消 .gitmodules 檔案中的設定"
+
+#: builtin/submodule--helper.c:2191
+msgid "git submodule--helper config <name> [<value>]"
+msgstr "git submodule--helper config <名稱> [<值>]"
+
+#: builtin/submodule--helper.c:2192
+msgid "git submodule--helper config --unset <name>"
+msgstr "git submodule--helper config --unset <名稱>"
+
+#: builtin/submodule--helper.c:2193
+msgid "git submodule--helper config --check-writeable"
+msgstr "git submodule--helper config --check-writeable"
+
+#: builtin/submodule--helper.c:2212 git-submodule.sh:173
+#, sh-format
+msgid "please make sure that the .gitmodules file is in the working tree"
+msgstr "請確認 .gitmodules 檔案在工作區裡"
+
+#: builtin/submodule--helper.c:2262 git.c:433 git.c:684
+#, c-format
+msgid "%s doesn't support --super-prefix"
+msgstr "%s 不支援 --super-prefix"
+
+#: builtin/submodule--helper.c:2268
+#, c-format
+msgid "'%s' is not a valid submodule--helper subcommand"
+msgstr "'%s' 不是一個有效的 submodule--helper 子指令"
+
+#: builtin/symbolic-ref.c:8
+msgid "git symbolic-ref [<options>] <name> [<ref>]"
+msgstr "git symbolic-ref [<選項>] <名稱> [<引用>]"
+
+#: builtin/symbolic-ref.c:9
+msgid "git symbolic-ref -d [-q] <name>"
+msgstr "git symbolic-ref -d [-q] <名稱>"
+
+#: builtin/symbolic-ref.c:40
+msgid "suppress error message for non-symbolic (detached) refs"
+msgstr "不顯示非符號（分離的）引用的錯誤訊息"
+
+#: builtin/symbolic-ref.c:41
+msgid "delete symbolic ref"
+msgstr "刪除符號引用"
+
+#: builtin/symbolic-ref.c:42
+msgid "shorten ref output"
+msgstr "縮短引用輸出"
+
+#: builtin/symbolic-ref.c:43 builtin/update-ref.c:363
+msgid "reason"
+msgstr "原因"
+
+#: builtin/symbolic-ref.c:43 builtin/update-ref.c:363
+msgid "reason of the update"
+msgstr "更新的原因"
+
+#: builtin/tag.c:25
+msgid ""
+"git tag [-a | -s | -u <key-id>] [-f] [-m <msg> | -F <file>]\n"
+"\t\t<tagname> [<head>]"
+msgstr ""
+"git tag [-a | -s | -u <key-id>] [-f] [-m <消息> | -F <檔案>]\n"
+"\t\t<標籤名> [<頭>]"
+
+#: builtin/tag.c:27
+msgid "git tag -d <tagname>..."
+msgstr "git tag -d <標籤名>..."
+
+#: builtin/tag.c:28
+msgid ""
+"git tag -l [-n[<num>]] [--contains <commit>] [--no-contains <commit>] [--"
+"points-at <object>]\n"
+"\t\t[--format=<format>] [--[no-]merged [<commit>]] [<pattern>...]"
+msgstr ""
+"git tag -l [-n[<數字>]] [--contains <提交>] [--no-contains <提交>] [--points-"
+"at <物件>]\n"
+"\t\t[--format=<格式>] [--[no-]merged [<提交>]] [<模式>...]"
+
+#: builtin/tag.c:30
+msgid "git tag -v [--format=<format>] <tagname>..."
+msgstr "git tag -v [--format=<格式>] <標籤名>..."
+
+#: builtin/tag.c:89
+#, c-format
+msgid "tag '%s' not found."
+msgstr "未發現標籤 '%s'。"
+
+#: builtin/tag.c:105
+#, c-format
+msgid "Deleted tag '%s' (was %s)\n"
+msgstr "已刪除標籤 '%s'（曾為 %s）\n"
+
+#: builtin/tag.c:135
+#, c-format
+msgid ""
+"\n"
+"Write a message for tag:\n"
+"  %s\n"
+"Lines starting with '%c' will be ignored.\n"
+msgstr ""
+"\n"
+"輸入一個標籤說明：\n"
+"  %s\n"
+"以 '%c' 開頭的行將被忽略。\n"
+
+#: builtin/tag.c:139
+#, c-format
+msgid ""
+"\n"
+"Write a message for tag:\n"
+"  %s\n"
+"Lines starting with '%c' will be kept; you may remove them yourself if you "
+"want to.\n"
+msgstr ""
+"\n"
+"輸入一個標籤說明：\n"
+"  %s\n"
+"以 '%c' 開頭的行將被保留，如果您願意也可以刪除它們。\n"
+
+#: builtin/tag.c:198
+msgid "unable to sign the tag"
+msgstr "無法簽署標籤"
+
+#: builtin/tag.c:200
+msgid "unable to write tag file"
+msgstr "無法寫標籤檔案"
+
+#: builtin/tag.c:216
+#, c-format
+msgid ""
+"You have created a nested tag. The object referred to by your new tag is\n"
+"already a tag. If you meant to tag the object that it points to, use:\n"
+"\n"
+"\tgit tag -f %s %s^{}"
+msgstr ""
+"您建立了一個嵌套的標籤。您的新標籤指向的物件已經是一個標籤。如果您想要\n"
+"對其指向的目標建立標籤，使用：\n"
+"\n"
+"\tgit tag -f %s %s^{}"
+
+#: builtin/tag.c:232
+msgid "bad object type."
+msgstr "壞的物件類型。"
+
+#: builtin/tag.c:284
+msgid "no tag message?"
+msgstr "無標籤說明？"
+
+#: builtin/tag.c:291
+#, c-format
+msgid "The tag message has been left in %s\n"
+msgstr "標籤說明被保留在 %s\n"
+
+#: builtin/tag.c:402
+msgid "list tag names"
+msgstr "列出標籤名稱"
+
+#: builtin/tag.c:404
+msgid "print <n> lines of each tag message"
+msgstr "每個標籤訊息列印 <n> 行"
+
+#: builtin/tag.c:406
+msgid "delete tags"
+msgstr "刪除標籤"
+
+#: builtin/tag.c:407
+msgid "verify tags"
+msgstr "驗證標籤"
+
+#: builtin/tag.c:409
+msgid "Tag creation options"
+msgstr "標籤建立選項"
+
+#: builtin/tag.c:411
+msgid "annotated tag, needs a message"
+msgstr "附註標籤，需要一個說明"
+
+#: builtin/tag.c:413
+msgid "tag message"
+msgstr "標籤說明"
+
+#: builtin/tag.c:415
+msgid "force edit of tag message"
+msgstr "強制編輯標籤說明"
+
+#: builtin/tag.c:416
+msgid "annotated and GPG-signed tag"
+msgstr "附註並附加 GPG 簽名的標籤"
+
+#: builtin/tag.c:419
+msgid "use another key to sign the tag"
+msgstr "使用另外的私鑰簽名該標籤"
+
+#: builtin/tag.c:420
+msgid "replace the tag if exists"
+msgstr "如果存在，取代現有的標籤"
+
+#: builtin/tag.c:421 builtin/update-ref.c:369
+msgid "create a reflog"
+msgstr "建立引用日誌"
+
+#: builtin/tag.c:423
+msgid "Tag listing options"
+msgstr "標籤列表選項"
+
+#: builtin/tag.c:424
+msgid "show tag list in columns"
+msgstr "以列的方式顯示標籤列表"
+
+#: builtin/tag.c:425 builtin/tag.c:427
+msgid "print only tags that contain the commit"
+msgstr "只列印包含該提交的標籤"
+
+#: builtin/tag.c:426 builtin/tag.c:428
+msgid "print only tags that don't contain the commit"
+msgstr "只列印不包含該提交的標籤"
+
+#: builtin/tag.c:429
+msgid "print only tags that are merged"
+msgstr "只列印已經合併的標籤"
+
+#: builtin/tag.c:430
+msgid "print only tags that are not merged"
+msgstr "只列印尚未合併的標籤"
+
+#: builtin/tag.c:434
+msgid "print only tags of the object"
+msgstr "只列印指向該物件的標籤"
+
+#: builtin/tag.c:482
+msgid "--column and -n are incompatible"
+msgstr "--column 和 -n 不相容"
+
+#: builtin/tag.c:504
+msgid "-n option is only allowed in list mode"
+msgstr "-n 選項只允許用在列表顯示模式"
+
+#: builtin/tag.c:506
+msgid "--contains option is only allowed in list mode"
+msgstr "--contains 選項只允許用在列表顯示模式"
+
+#: builtin/tag.c:508
+msgid "--no-contains option is only allowed in list mode"
+msgstr "--no-contains 選項只允許用在列表顯示模式"
+
+#: builtin/tag.c:510
+msgid "--points-at option is only allowed in list mode"
+msgstr "--points-at 選項只允許用在列表顯示模式"
+
+#: builtin/tag.c:512
+msgid "--merged and --no-merged options are only allowed in list mode"
+msgstr "--merged 和 --no-merged 選項只允許用在列表顯示模式"
+
+#: builtin/tag.c:523
+msgid "only one -F or -m option is allowed."
+msgstr "只允許一個 -F 或 -m 選項。"
+
+#: builtin/tag.c:542
+msgid "too many params"
+msgstr "太多參數"
+
+#: builtin/tag.c:548
+#, c-format
+msgid "'%s' is not a valid tag name."
+msgstr "'%s' 不是一個有效的標籤名稱。"
+
+#: builtin/tag.c:553
+#, c-format
+msgid "tag '%s' already exists"
+msgstr "標籤 '%s' 已存在"
+
+#: builtin/tag.c:584
+#, c-format
+msgid "Updated tag '%s' (was %s)\n"
+msgstr "已更新標籤 '%s'（曾為 %s）\n"
+
+#: builtin/unpack-objects.c:501
+msgid "Unpacking objects"
+msgstr "展開物件中"
+
+#: builtin/update-index.c:84
+#, c-format
+msgid "failed to create directory %s"
+msgstr "建立目錄 %s 失敗"
+
+#: builtin/update-index.c:100
+#, c-format
+msgid "failed to create file %s"
+msgstr "建立檔案 %s 失敗"
+
+#: builtin/update-index.c:108
+#, c-format
+msgid "failed to delete file %s"
+msgstr "刪除檔案 %s 失敗"
+
+#: builtin/update-index.c:115 builtin/update-index.c:221
+#, c-format
+msgid "failed to delete directory %s"
+msgstr "刪除目錄 %s 失敗"
+
+#: builtin/update-index.c:140
+#, c-format
+msgid "Testing mtime in '%s' "
+msgstr "在 '%s' 中測試 mtime "
+
+#: builtin/update-index.c:154
+msgid "directory stat info does not change after adding a new file"
+msgstr "新增一個新檔案後，目錄的狀態訊息未改變"
+
+#: builtin/update-index.c:167
+msgid "directory stat info does not change after adding a new directory"
+msgstr "新增一個新目錄後，目錄的狀態訊息未改變"
+
+#: builtin/update-index.c:180
+msgid "directory stat info changes after updating a file"
+msgstr "更新一個檔案後，目錄的狀態訊息被修改"
+
+#: builtin/update-index.c:191
+msgid "directory stat info changes after adding a file inside subdirectory"
+msgstr "在子目錄中新增檔案後，目錄的狀態訊息被修改"
+
+#: builtin/update-index.c:202
+msgid "directory stat info does not change after deleting a file"
+msgstr "刪除一個檔案後，目錄的狀態訊息未改變"
+
+#: builtin/update-index.c:215
+msgid "directory stat info does not change after deleting a directory"
+msgstr "刪除一個目錄後，目錄的狀態訊息未改變"
+
+#: builtin/update-index.c:222
+msgid " OK"
+msgstr " OK"
+
+#: builtin/update-index.c:591
+msgid "git update-index [<options>] [--] [<file>...]"
+msgstr "git update-index [<選項>] [--] [<檔案>...]"
+
+#: builtin/update-index.c:974
+msgid "continue refresh even when index needs update"
+msgstr "當索引需要更新時繼續重新整理"
+
+#: builtin/update-index.c:977
+msgid "refresh: ignore submodules"
+msgstr "重新整理：忽略子模組"
+
+#: builtin/update-index.c:980
+msgid "do not ignore new files"
+msgstr "不忽略新的檔案"
+
+#: builtin/update-index.c:982
+msgid "let files replace directories and vice-versa"
+msgstr "讓檔案取代目錄（反之亦然）"
+
+#: builtin/update-index.c:984
+msgid "notice files missing from worktree"
+msgstr "通知檔案從工作區遺失"
+
+#: builtin/update-index.c:986
+msgid "refresh even if index contains unmerged entries"
+msgstr "即使索引區包含未合併的條目也執行重新整理"
+
+#: builtin/update-index.c:989
+msgid "refresh stat information"
+msgstr "重新整理統計訊息"
+
+#: builtin/update-index.c:993
+msgid "like --refresh, but ignore assume-unchanged setting"
+msgstr "類似於 --refresh，但是忽略 assume-unchanged 設定"
+
+#: builtin/update-index.c:997
+msgid "<mode>,<object>,<path>"
+msgstr "<存取模式>,<物件>,<路徑>"
+
+#: builtin/update-index.c:998
+msgid "add the specified entry to the index"
+msgstr "新增指定的條目到索引區"
+
+#: builtin/update-index.c:1008
+msgid "mark files as \"not changing\""
+msgstr "把檔案標記為 \"沒有變更\""
+
+#: builtin/update-index.c:1011
+msgid "clear assumed-unchanged bit"
+msgstr "清除 assumed-unchanged 位"
+
+#: builtin/update-index.c:1014
+msgid "mark files as \"index-only\""
+msgstr "把檔案標記為 \"僅索引\""
+
+#: builtin/update-index.c:1017
+msgid "clear skip-worktree bit"
+msgstr "清除 skip-worktree 位"
+
+#: builtin/update-index.c:1020
+msgid "do not touch index-only entries"
+msgstr "不要建立只有索引的項目"
+
+#: builtin/update-index.c:1022
+msgid "add to index only; do not add content to object database"
+msgstr "只新增到索引區；不新增物件到物件庫"
+
+#: builtin/update-index.c:1024
+msgid "remove named paths even if present in worktree"
+msgstr "即使存在工作區裡，也刪除路徑"
+
+#: builtin/update-index.c:1026
+msgid "with --stdin: input lines are terminated by null bytes"
+msgstr "攜帶 --stdin：輸入的行以 null 字元終止"
+
+#: builtin/update-index.c:1028
+msgid "read list of paths to be updated from standard input"
+msgstr "從標準輸入中讀取需要更新的路徑列表"
+
+#: builtin/update-index.c:1032
+msgid "add entries from standard input to the index"
+msgstr "從標準輸入新增條目到索引區"
+
+#: builtin/update-index.c:1036
+msgid "repopulate stages #2 and #3 for the listed paths"
+msgstr "為指定檔案重新生成第2和第3暫存區"
+
+#: builtin/update-index.c:1040
+msgid "only update entries that differ from HEAD"
+msgstr "只更新與 HEAD 不同的條目"
+
+#: builtin/update-index.c:1044
+msgid "ignore files missing from worktree"
+msgstr "忽略工作區遺失的檔案"
+
+#: builtin/update-index.c:1047
+msgid "report actions to standard output"
+msgstr "在標準輸出顯示動作"
+
+#: builtin/update-index.c:1049
+msgid "(for porcelains) forget saved unresolved conflicts"
+msgstr "(for porcelains) 忘記儲存的未解決的衝突"
+
+#: builtin/update-index.c:1053
+msgid "write index in this format"
+msgstr "以這種格式寫入索引區"
+
+#: builtin/update-index.c:1055
+msgid "enable or disable split index"
+msgstr "啟用或禁用索引分割"
+
+#: builtin/update-index.c:1057
+msgid "enable/disable untracked cache"
+msgstr "啟用/禁用對未追蹤檔案的快取"
+
+#: builtin/update-index.c:1059
+msgid "test if the filesystem supports untracked cache"
+msgstr "測試檔案系統是否支援未追蹤檔案快取"
+
+#: builtin/update-index.c:1061
+msgid "enable untracked cache without testing the filesystem"
+msgstr "無需檢測檔案系統，啟用對未追蹤檔案的快取"
+
+#: builtin/update-index.c:1063
+msgid "write out the index even if is not flagged as changed"
+msgstr "即使沒有被標記為已更改，也要寫出索引"
+
+#: builtin/update-index.c:1065
+msgid "enable or disable file system monitor"
+msgstr "啟用或禁用檔案系統監控"
+
+#: builtin/update-index.c:1067
+msgid "mark files as fsmonitor valid"
+msgstr "標記檔案為 fsmonitor 有效"
+
+#: builtin/update-index.c:1070
+msgid "clear fsmonitor valid bit"
+msgstr "清除 fsmonitor 有效位"
+
+#: builtin/update-index.c:1173
+msgid ""
+"core.splitIndex is set to false; remove or change it, if you really want to "
+"enable split index"
+msgstr "core.splitIndex 被設定為 false。如果您確實要啟用索引分割，請刪除或修改它。"
+
+#: builtin/update-index.c:1182
+msgid ""
+"core.splitIndex is set to true; remove or change it, if you really want to "
+"disable split index"
+msgstr "core.splitIndex 被設定為 true。如果您確實要禁用索引分割，請刪除或修改它。"
+
+#: builtin/update-index.c:1194
+msgid ""
+"core.untrackedCache is set to true; remove or change it, if you really want "
+"to disable the untracked cache"
+msgstr ""
+"core.untrackedCache 被設定為 true。如果您確實要禁用未追蹤檔案快取，請刪除或修"
+"改它。"
+
+#: builtin/update-index.c:1198
+msgid "Untracked cache disabled"
+msgstr "快取未追蹤檔案被禁用"
+
+#: builtin/update-index.c:1206
+msgid ""
+"core.untrackedCache is set to false; remove or change it, if you really want "
+"to enable the untracked cache"
+msgstr ""
+"core.untrackedCache 被設定為 false。如果您確實要啟用未追蹤檔案快取，請刪除或"
+"修改它。"
+
+#: builtin/update-index.c:1210
+#, c-format
+msgid "Untracked cache enabled for '%s'"
+msgstr "快取未追蹤檔案在 '%s' 啟用"
+
+#: builtin/update-index.c:1218
+msgid "core.fsmonitor is unset; set it if you really want to enable fsmonitor"
+msgstr "core.fsmonitor 未設定；如果想要啟用 fsmonitor 請設定該選項"
+
+#: builtin/update-index.c:1222
+msgid "fsmonitor enabled"
+msgstr "fsmonitor 被啟用"
+
+#: builtin/update-index.c:1225
+msgid ""
+"core.fsmonitor is set; remove it if you really want to disable fsmonitor"
+msgstr "core.fsmonitor 已設定；如果想要禁用 fsmonitor 請移除該選項"
+
+#: builtin/update-index.c:1229
+msgid "fsmonitor disabled"
+msgstr "fsmonitor 被禁用"
+
+#: builtin/update-ref.c:10
+msgid "git update-ref [<options>] -d <refname> [<old-val>]"
+msgstr "git update-ref [<選項>] -d <引用名> [<舊值>]"
+
+#: builtin/update-ref.c:11
+msgid "git update-ref [<options>]    <refname> <new-val> [<old-val>]"
+msgstr "git update-ref [<選項>]    <引用名> <新值> [<舊值>]"
+
+#: builtin/update-ref.c:12
+msgid "git update-ref [<options>] --stdin [-z]"
+msgstr "git update-ref [<選項>] --stdin [-z]"
+
+#: builtin/update-ref.c:364
+msgid "delete the reference"
+msgstr "刪除引用"
+
+#: builtin/update-ref.c:366
+msgid "update <refname> not the one it points to"
+msgstr "更新 <引用名> 本身而不是它指向的引用"
+
+#: builtin/update-ref.c:367
+msgid "stdin has NUL-terminated arguments"
+msgstr "標準輸入有以 NUL 字元終止的參數"
+
+#: builtin/update-ref.c:368
+msgid "read updates from stdin"
+msgstr "從標準輸入讀取更新"
+
+#: builtin/update-server-info.c:7
+msgid "git update-server-info [--force]"
+msgstr "git update-server-info [--force]"
+
+#: builtin/update-server-info.c:15
+msgid "update the info files from scratch"
+msgstr "從頭開始更新檔案訊息"
+
+#: builtin/upload-pack.c:11
+msgid "git upload-pack [<options>] <dir>"
+msgstr "git upload-pack [<選項>] <目錄>"
+
+#: builtin/upload-pack.c:23 t/helper/test-serve-v2.c:17
+msgid "quit after a single request/response exchange"
+msgstr "在一次單獨的請求/回應之後離開"
+
+#: builtin/upload-pack.c:25
+msgid "exit immediately after initial ref advertisement"
+msgstr "在初始的引用廣告後立即離開"
+
+#: builtin/upload-pack.c:27
+msgid "do not try <directory>/.git/ if <directory> is no Git directory"
+msgstr "如果 <目錄> 不是一個 Git 目錄，不要嘗試 <目錄>/.git/"
+
+#: builtin/upload-pack.c:29
+msgid "interrupt transfer after <n> seconds of inactivity"
+msgstr "不活動 <n> 秒鐘後終止傳輸"
+
+#: builtin/verify-commit.c:19
+msgid "git verify-commit [-v | --verbose] <commit>..."
+msgstr "git verify-commit [-v | --verbose] <提交>..."
+
+#: builtin/verify-commit.c:68
+msgid "print commit contents"
+msgstr "列印提交內容"
+
+#: builtin/verify-commit.c:69 builtin/verify-tag.c:37
+msgid "print raw gpg status output"
+msgstr "列印原始 gpg 狀態輸出"
+
+#: builtin/verify-pack.c:55
+msgid "git verify-pack [-v | --verbose] [-s | --stat-only] <pack>..."
+msgstr "git verify-pack [-v | --verbose] [-s | --stat-only] <包>..."
+
+#: builtin/verify-pack.c:65
+msgid "verbose"
+msgstr "詳細輸出"
+
+#: builtin/verify-pack.c:67
+msgid "show statistics only"
+msgstr "只顯示統計"
+
+#: builtin/verify-tag.c:18
+msgid "git verify-tag [-v | --verbose] [--format=<format>] <tag>..."
+msgstr "git verify-tag [-v | --verbose] [--format=<格式>] <標籤>..."
+
+#: builtin/verify-tag.c:36
+msgid "print tag contents"
+msgstr "列印標籤內容"
+
+#: builtin/worktree.c:17
+msgid "git worktree add [<options>] <path> [<commit-ish>]"
+msgstr "git worktree add [<選項>] <路徑> [<提交>]"
+
+#: builtin/worktree.c:18
+msgid "git worktree list [<options>]"
+msgstr "git worktree list [<選項>]"
+
+#: builtin/worktree.c:19
+msgid "git worktree lock [<options>] <path>"
+msgstr "git worktree lock [<選項>] <路徑>"
+
+#: builtin/worktree.c:20
+msgid "git worktree move <worktree> <new-path>"
+msgstr "git worktree move <工作區> <新路徑>"
+
+#: builtin/worktree.c:21
+msgid "git worktree prune [<options>]"
+msgstr "git worktree prune [<選項>]"
+
+#: builtin/worktree.c:22
+msgid "git worktree remove [<options>] <worktree>"
+msgstr "git worktree remove [<選項>] <工作區>"
+
+#: builtin/worktree.c:23
+msgid "git worktree unlock <path>"
+msgstr "git worktree unlock <路徑>"
+
+#: builtin/worktree.c:60 builtin/worktree.c:898
+#, c-format
+msgid "failed to delete '%s'"
+msgstr "刪除 '%s' 失敗"
+
+#: builtin/worktree.c:79
+#, c-format
+msgid "Removing worktrees/%s: not a valid directory"
+msgstr "刪除工作區/%s：不是一個有效的目錄"
+
+#: builtin/worktree.c:85
+#, c-format
+msgid "Removing worktrees/%s: gitdir file does not exist"
+msgstr "刪除 worktrees/%s：gitdir 檔案不存在"
+
+#: builtin/worktree.c:90 builtin/worktree.c:99
+#, c-format
+msgid "Removing worktrees/%s: unable to read gitdir file (%s)"
+msgstr "刪除 worktrees/%s：無法讀取 gitdir 檔案 (%s)"
+
+#: builtin/worktree.c:109
+#, c-format
+msgid ""
+"Removing worktrees/%s: short read (expected %<PRIuMAX> bytes, read "
+"%<PRIuMAX>)"
+msgstr "刪除工作樹/%s：讀取過短（期望 %<PRIuMAX> 位元組，讀取 %<PRIuMAX>）"
+
+#: builtin/worktree.c:117
+#, c-format
+msgid "Removing worktrees/%s: invalid gitdir file"
+msgstr "刪除 worktrees/%s：無效的 gitdir 檔案"
+
+#: builtin/worktree.c:126
+#, c-format
+msgid "Removing worktrees/%s: gitdir file points to non-existent location"
+msgstr "刪除 worktrees/%s：gitdir 檔案的指向不存在"
+
+#: builtin/worktree.c:165
+msgid "report pruned working trees"
+msgstr "報告清除的工作區"
+
+#: builtin/worktree.c:167
+msgid "expire working trees older than <time>"
+msgstr "將早於 <時間> 的工作區過期"
+
+#: builtin/worktree.c:234
+#, c-format
+msgid "'%s' already exists"
+msgstr "'%s' 已經存在"
+
+#: builtin/worktree.c:251
+#, c-format
+msgid "unable to re-add worktree '%s'"
+msgstr "無法再次新增工作區 '%s'"
+
+#: builtin/worktree.c:256
+#, c-format
+msgid ""
+"'%s' is a missing but locked worktree;\n"
+"use 'add -f -f' to override, or 'unlock' and 'prune' or 'remove' to clear"
+msgstr ""
+"'%s' 是一個遺失但鎖定的工作區，使用\n"
+"'add -f -f' 覆蓋，或 'unlock' 和 'prune' 或 'remove' 清除"
+
+#: builtin/worktree.c:258
+#, c-format
+msgid ""
+"'%s' is a missing but already registered worktree;\n"
+"use 'add -f' to override, or 'prune' or 'remove' to clear"
+msgstr ""
+"'%s' 是一個遺失但已經註冊的工作區，使用\n"
+"'add -f' 覆蓋，或 'prune' 或 'remove' 清除"
+
+#: builtin/worktree.c:308
+#, c-format
+msgid "could not create directory of '%s'"
+msgstr "不能建立目錄 '%s'"
+
+#: builtin/worktree.c:439 builtin/worktree.c:445
+#, c-format
+msgid "Preparing worktree (new branch '%s')"
+msgstr "準備工作區（新分支 '%s'）"
+
+#: builtin/worktree.c:441
+#, c-format
+msgid "Preparing worktree (resetting branch '%s'; was at %s)"
+msgstr "準備工作區（重設分支 '%s'，之前為 %s）"
+
+#: builtin/worktree.c:450
+#, c-format
+msgid "Preparing worktree (checking out '%s')"
+msgstr "準備工作區（簽出 '%s'）"
+
+#: builtin/worktree.c:456
+#, c-format
+msgid "Preparing worktree (detached HEAD %s)"
+msgstr "準備工作區（分離開頭指標 %s）"
+
+#: builtin/worktree.c:497
+msgid "checkout <branch> even if already checked out in other worktree"
+msgstr "簽出 <分支>，即使已經被簽出到其它工作區"
+
+#: builtin/worktree.c:500
+msgid "create a new branch"
+msgstr "建立一個新分支"
+
+#: builtin/worktree.c:502
+msgid "create or reset a branch"
+msgstr "建立或重設一個分支"
+
+#: builtin/worktree.c:504
+msgid "populate the new working tree"
+msgstr "生成新的工作區"
+
+#: builtin/worktree.c:505
+msgid "keep the new working tree locked"
+msgstr "鎖定新工作區"
+
+#: builtin/worktree.c:508
+msgid "set up tracking mode (see git-branch(1))"
+msgstr "設定追蹤模式（參見 git-branch(1)）"
+
+#: builtin/worktree.c:511
+msgid "try to match the new branch name with a remote-tracking branch"
+msgstr "嘗試為新分支名符合一個遠端追蹤分支"
+
+#: builtin/worktree.c:519
+msgid "-b, -B, and --detach are mutually exclusive"
+msgstr "-b、-B 和 --detach 是互斥的"
+
+#: builtin/worktree.c:580
+msgid "--[no-]track can only be used if a new branch is created"
+msgstr "只能在建立新分支時使用選項 --[no-]track "
+
+#: builtin/worktree.c:680
+msgid "reason for locking"
+msgstr "鎖定原因"
+
+#: builtin/worktree.c:692 builtin/worktree.c:725 builtin/worktree.c:799
+#: builtin/worktree.c:926
+#, c-format
+msgid "'%s' is not a working tree"
+msgstr "'%s' 不是一個工作區"
+
+#: builtin/worktree.c:694 builtin/worktree.c:727
+msgid "The main working tree cannot be locked or unlocked"
+msgstr "主工作區無法被加鎖或解鎖"
+
+#: builtin/worktree.c:699
+#, c-format
+msgid "'%s' is already locked, reason: %s"
+msgstr "'%s' 已被鎖定，原因：%s"
+
+#: builtin/worktree.c:701
+#, c-format
+msgid "'%s' is already locked"
+msgstr "'%s' 已被鎖定"
+
+#: builtin/worktree.c:729
+#, c-format
+msgid "'%s' is not locked"
+msgstr "'%s' 未被鎖定"
+
+#: builtin/worktree.c:770
+msgid "working trees containing submodules cannot be moved or removed"
+msgstr "不能移動或刪除包含子模組的工作區"
+
+#: builtin/worktree.c:778
+msgid "force move even if worktree is dirty or locked"
+msgstr "強制移動，即使工作區是髒的或已鎖定"
+
+#: builtin/worktree.c:801 builtin/worktree.c:928
+#, c-format
+msgid "'%s' is a main working tree"
+msgstr "'%s' 是一個主工作區"
+
+#: builtin/worktree.c:806
+#, c-format
+msgid "could not figure out destination name from '%s'"
+msgstr "無法從 '%s' 算出目標名稱"
+
+#: builtin/worktree.c:812
+#, c-format
+msgid "target '%s' already exists"
+msgstr "目標 '%s' 已存在"
+
+#: builtin/worktree.c:820
+#, c-format
+msgid ""
+"cannot move a locked working tree, lock reason: %s\n"
+"use 'move -f -f' to override or unlock first"
+msgstr ""
+"無法移動一個鎖定的工作區，鎖定原因：%s\n"
+"使用 'move -f -f' 覆蓋或先解鎖"
+
+#: builtin/worktree.c:822
+msgid ""
+"cannot move a locked working tree;\n"
+"use 'move -f -f' to override or unlock first"
+msgstr ""
+"無法移動一個鎖定的工作區，\n"
+"使用 'move -f -f' 覆蓋或先解鎖"
+
+#: builtin/worktree.c:825
+#, c-format
+msgid "validation failed, cannot move working tree: %s"
+msgstr "驗證失敗，無法移動工作區：%s"
+
+#: builtin/worktree.c:830
+#, c-format
+msgid "failed to move '%s' to '%s'"
+msgstr "移動 '%s' 到 '%s' 失敗"
+
+#: builtin/worktree.c:878
+#, c-format
+msgid "failed to run 'git status' on '%s'"
+msgstr "在 '%s' 中執行 'git status' 失敗"
+
+#: builtin/worktree.c:882
+#, c-format
+msgid "'%s' contains modified or untracked files, use --force to delete it"
+msgstr "'%s' 包含修改或未追蹤的檔案，使用 --force 刪除"
+
+#: builtin/worktree.c:887
+#, c-format
+msgid "failed to run 'git status' on '%s', code %d"
+msgstr "在 '%s' 中執行 'git status' 失敗，離開碼 %d"
+
+#: builtin/worktree.c:910
+msgid "force removal even if worktree is dirty or locked"
+msgstr "強制刪除，即使工作區是髒的或已鎖定"
+
+#: builtin/worktree.c:933
+#, c-format
+msgid ""
+"cannot remove a locked working tree, lock reason: %s\n"
+"use 'remove -f -f' to override or unlock first"
+msgstr ""
+"無法刪除一個鎖定的工作區，鎖定原因：%s\n"
+"使用 'remove -f -f' 覆蓋或先解鎖"
+
+#: builtin/worktree.c:935
+msgid ""
+"cannot remove a locked working tree;\n"
+"use 'remove -f -f' to override or unlock first"
+msgstr ""
+"無法刪除一個鎖定的工作區，\n"
+"使用 'remove -f -f' 覆蓋或先解鎖"
+
+#: builtin/worktree.c:938
+#, c-format
+msgid "validation failed, cannot remove working tree: %s"
+msgstr "驗證失敗，無法刪除工作區：%s"
+
+#: builtin/write-tree.c:15
+msgid "git write-tree [--missing-ok] [--prefix=<prefix>/]"
+msgstr "git write-tree [--missing-ok] [--prefix=<前綴>/]"
+
+#: builtin/write-tree.c:28
+msgid "<prefix>/"
+msgstr "<前綴>/"
+
+#: builtin/write-tree.c:29
+msgid "write tree object for a subdirectory <prefix>"
+msgstr "將 <前綴> 子目錄內容寫到一個樹狀物件"
+
+#: builtin/write-tree.c:31
+msgid "only useful for debugging"
+msgstr "只對除錯有用"
+
+#: fast-import.c:3125
+#, c-format
+msgid "Expected 'mark' command, got %s"
+msgstr "預期 'mark' 指令，得到 %s"
+
+#: fast-import.c:3130
+#, c-format
+msgid "Expected 'to' command, got %s"
+msgstr "預期 'to' 指令，得到 %s"
+
+#: fast-import.c:3254
+#, c-format
+msgid "feature '%s' forbidden in input without --allow-unsafe-features"
+msgstr ""
+
+#: credential-cache--daemon.c:223
+#, c-format
+msgid ""
+"The permissions on your socket directory are too loose; other\n"
+"users may be able to read your cached credentials. Consider running:\n"
+"\n"
+"\tchmod 0700 %s"
+msgstr ""
+"您的 socket 目錄權限過於寬鬆，其他使用者可能會讀取您快取的認證訊息。考慮執"
+"行：\n"
+"\n"
+"\tchmod 0700 %s"
+
+#: credential-cache--daemon.c:272
+msgid "print debugging messages to stderr"
+msgstr "除錯訊息輸出到標準錯誤"
+
+#: t/helper/test-reach.c:152
+#, c-format
+msgid "commit %s is not marked reachable"
+msgstr "提交 %s 沒有標記為可以取得"
+
+#: t/helper/test-reach.c:162
+msgid "too many commits marked reachable"
+msgstr "太多提交標記為可以取得"
+
+#: t/helper/test-serve-v2.c:7
+msgid "test-tool serve-v2 [<options>]"
+msgstr "test-tool serve-v2 [<選項>]"
+
+#: t/helper/test-serve-v2.c:19
+msgid "exit immediately after advertising capabilities"
+msgstr "對能力廣告之後立即離開"
+
+#: git.c:27
+msgid ""
+"git [--version] [--help] [-C <path>] [-c <name>=<value>]\n"
+"           [--exec-path[=<path>]] [--html-path] [--man-path] [--info-path]\n"
+"           [-p | --paginate | -P | --no-pager] [--no-replace-objects] [--"
+"bare]\n"
+"           [--git-dir=<path>] [--work-tree=<path>] [--namespace=<name>]\n"
+"           <command> [<args>]"
+msgstr ""
+"git [--version] [--help] [-C <路徑>] [-c <名稱>=<取值>]\n"
+"           [--exec-path[=<路徑>]] [--html-path] [--man-path] [--info-path]\n"
+"           [-p | --paginate | -P | --no-pager] [--no-replace-objects] [--"
+"bare]\n"
+"           [--git-dir=<路徑>] [--work-tree=<路徑>] [--namespace=<名稱>]\n"
+"           <指令> [<參數>]"
+
+#: git.c:34
+msgid ""
+"'git help -a' and 'git help -g' list available subcommands and some\n"
+"concept guides. See 'git help <command>' or 'git help <concept>'\n"
+"to read about a specific subcommand or concept.\n"
+"See 'git help git' for an overview of the system."
+msgstr ""
+"指令 'git help -a' 和 'git help -g' 顯示可用的子指令和一些概念說明。\n"
+"檢視 'git help <指令>' 或 'git help <概念>' 以取得提供子指令或概念\n"
+"說明。\n"
+"有關系統概述，檢視 'git help git'。"
+
+#: git.c:186
+#, c-format
+msgid "no directory given for --git-dir\n"
+msgstr "沒有為 --git-dir 提供目錄\n"
+
+#: git.c:200
+#, c-format
+msgid "no namespace given for --namespace\n"
+msgstr "沒有為 --namespace 提供命名空間\n"
+
+#: git.c:214
+#, c-format
+msgid "no directory given for --work-tree\n"
+msgstr "沒有為 --work-tree 提供目錄\n"
+
+#: git.c:228
+#, c-format
+msgid "no prefix given for --super-prefix\n"
+msgstr "沒有為 --super-prefix 提供前綴\n"
+
+#: git.c:250
+#, c-format
+msgid "-c expects a configuration string\n"
+msgstr "應為 -c 提供一個設定字串\n"
+
+#: git.c:288
+#, c-format
+msgid "no directory given for -C\n"
+msgstr "沒有為 -C 提供目錄\n"
+
+#: git.c:314
+#, c-format
+msgid "unknown option: %s\n"
+msgstr "未知選項：%s\n"
+
+#: git.c:360
+#, c-format
+msgid "while expanding alias '%s': '%s'"
+msgstr "在擴展別名 '%s' 時：'%s'"
+
+#: git.c:369
+#, c-format
+msgid ""
+"alias '%s' changes environment variables.\n"
+"You can use '!git' in the alias to do this"
+msgstr ""
+"別名 '%s' 修改環境變數。您可以使用在別名中\n"
+"使用 '!git'"
+
+#: git.c:376
+#, c-format
+msgid "empty alias for %s"
+msgstr "%s 的空別名"
+
+#: git.c:379
+#, c-format
+msgid "recursive alias: %s"
+msgstr "遞迴的別名：%s"
+
+#: git.c:459
+msgid "write failure on standard output"
+msgstr "在標準輸出寫入失敗"
+
+#: git.c:461
+msgid "unknown write failure on standard output"
+msgstr "到標準輸出的未知寫入錯誤"
+
+#: git.c:463
+msgid "close failed on standard output"
+msgstr "標準輸出關閉失敗"
+
+#: git.c:793
+#, c-format
+msgid "alias loop detected: expansion of '%s' does not terminate:%s"
+msgstr "檢測到別名循環：'%s'的擴展未終止：%s"
+
+#: git.c:843
+#, c-format
+msgid "cannot handle %s as a builtin"
+msgstr "不能作為內建指令處理 %s"
+
+#: git.c:856
+#, c-format
+msgid ""
+"usage: %s\n"
+"\n"
+msgstr ""
+"用法：%s\n"
+"\n"
+
+#: git.c:876
+#, c-format
+msgid "expansion of alias '%s' failed; '%s' is not a git command\n"
+msgstr "展開別名指令 '%s' 失敗，'%s' 不是一個 git 指令\n"
+
+#: git.c:888
+#, c-format
+msgid "failed to run command '%s': %s\n"
+msgstr "執行指令 '%s' 失敗：%s\n"
+
+#: http.c:378
+#, c-format
+msgid "negative value for http.postbuffer; defaulting to %d"
+msgstr "http.postbuffer 為負值，預設為 %d"
+
+#: http.c:399
+msgid "Delegation control is not supported with cURL < 7.22.0"
+msgstr "不支援委託控制，因為 cURL < 7.22.0"
+
+#: http.c:408
+msgid "Public key pinning not supported with cURL < 7.44.0"
+msgstr "不支援公鑰檔案鎖定，因為 cURL < 7.44.0"
+
+#: http.c:876
+msgid "CURLSSLOPT_NO_REVOKE not supported with cURL < 7.44.0"
+msgstr "不支援 CURLSSLOPT_NO_REVOKE，因為 cURL < 7.44.0"
+
+#: http.c:949
+msgid "Protocol restrictions not supported with cURL < 7.19.4"
+msgstr "不支援協定限制，因為 cURL < 7.19.4"
+
+#: http.c:1086
+#, c-format
+msgid "Unsupported SSL backend '%s'. Supported SSL backends:"
+msgstr "不支援的 SSL 後端 '%s'。支援的 SSL 後端："
+
+#: http.c:1093
+#, c-format
+msgid "Could not set SSL backend to '%s': cURL was built without SSL backends"
+msgstr "無法設定 SSL 後端為 '%s'：cURL: cURL 沒有使用 SSL 後端構建"
+
+#: http.c:1097
+#, c-format
+msgid "Could not set SSL backend to '%s': already set"
+msgstr "無法將 SSL 後端設定為 '%s'：已經設定"
+
+#: http.c:1966
+#, c-format
+msgid ""
+"unable to update url base from redirection:\n"
+"  asked for: %s\n"
+"   redirect: %s"
+msgstr ""
+"不能更新重定向的 url base：\n"
+"     請求：%s\n"
+"   重定向：%s"
+
+#: remote-curl.c:166
+#, c-format
+msgid "invalid quoting in push-option value: '%s'"
+msgstr "在 push-option 取值中無效的引號：'%s'"
+
+#: remote-curl.c:263
+#, c-format
+msgid "%sinfo/refs not valid: is this a git repository?"
+msgstr "%sinfo/refs 無效：這是一個 git 版本庫嗎？"
+
+#: remote-curl.c:364
+msgid "invalid server response; expected service, got flush packet"
+msgstr "無效的服務端回應。預期服務，得到 flush 包"
+
+#: remote-curl.c:395
+#, c-format
+msgid "invalid server response; got '%s'"
+msgstr "無效的服務端回應，得到 '%s'"
+
+#: remote-curl.c:455
+#, c-format
+msgid "repository '%s' not found"
+msgstr "版本庫 '%s' 未找到"
+
+#: remote-curl.c:459
+#, c-format
+msgid "Authentication failed for '%s'"
+msgstr "'%s' 身份驗證失敗"
+
+#: remote-curl.c:463
+#, c-format
+msgid "unable to access '%s': %s"
+msgstr "無法存取 '%s'：%s"
+
+#: remote-curl.c:469
+#, c-format
+msgid "redirecting to %s"
+msgstr "重定向到 %s"
+
+#: remote-curl.c:593
+msgid "shouldn't have EOF when not gentle on EOF"
+msgstr "當沒有設定溫和處理檔案結束符（EOF）時，不應該有檔案結束符"
+
+#: remote-curl.c:673
+msgid "unable to rewind rpc post data - try increasing http.postBuffer"
+msgstr "無法還原 rpc post 資料 - 嘗試增加 http.postBuffer"
+
+#: remote-curl.c:733
+#, c-format
+msgid "RPC failed; %s"
+msgstr "RPC 失敗。%s"
+
+#: remote-curl.c:773
+msgid "cannot handle pushes this big"
+msgstr "不能處理這麼大的推送"
+
+#: remote-curl.c:888
+#, c-format
+msgid "cannot deflate request; zlib deflate error %d"
+msgstr "不能壓縮請求，zlib 壓縮錯誤 %d"
+
+#: remote-curl.c:892
+#, c-format
+msgid "cannot deflate request; zlib end error %d"
+msgstr "不能壓縮請求，zlib 結束錯誤 %d"
+
+#: remote-curl.c:1023
+msgid "dumb http transport does not support shallow capabilities"
+msgstr "啞 http 傳輸不支援 shalllow 能力"
+
+#: remote-curl.c:1037
+msgid "fetch failed."
+msgstr "取得失敗。"
+
+#: remote-curl.c:1085
+msgid "cannot fetch by sha1 over smart http"
+msgstr "無法透過智慧 HTTP 取得 sha1"
+
+#: remote-curl.c:1129 remote-curl.c:1135
+#, c-format
+msgid "protocol error: expected sha/ref, got '%s'"
+msgstr "協定錯誤：期望 sha/ref，卻得到 '%s'"
+
+#: remote-curl.c:1147 remote-curl.c:1261
+#, c-format
+msgid "http transport does not support %s"
+msgstr "http 傳輸協定不支援 %s"
+
+#: remote-curl.c:1183
+msgid "git-http-push failed"
+msgstr "git-http-push 失敗"
+
+#: remote-curl.c:1367
+msgid "remote-curl: usage: git remote-curl <remote> [<url>]"
+msgstr "remote-curl：用法：git remote-curl <遠端> [<url>]"
+
+#: remote-curl.c:1399
+msgid "remote-curl: error reading command stream from git"
+msgstr "remote-curl：錯誤讀取來自 git 的指令流"
+
+#: remote-curl.c:1406
+msgid "remote-curl: fetch attempted without a local repo"
+msgstr "remote-curl：嘗試沒有本機版本庫下取得"
+
+#: remote-curl.c:1446
+#, c-format
+msgid "remote-curl: unknown command '%s' from git"
+msgstr "remote-curl：未知的來自 git 的指令 '%s'"
+
+#: list-objects-filter-options.h:85
+msgid "args"
+msgstr "參數"
+
+#: list-objects-filter-options.h:86
+msgid "object filtering"
+msgstr "物件過濾"
+
+#: parse-options.h:183
+msgid "expiry-date"
+msgstr "到期時間"
+
+#: parse-options.h:197
+msgid "no-op (backward compatibility)"
+msgstr "空動作（向後相容）"
+
+#: parse-options.h:309
+msgid "be more verbose"
+msgstr "更加詳細"
+
+#: parse-options.h:311
+msgid "be more quiet"
+msgstr "更加安靜"
+
+#: parse-options.h:317
+msgid "use <n> digits to display SHA-1s"
+msgstr "用 <n> 位數字顯示 SHA-1 雜湊值"
+
+#: parse-options.h:336
+msgid "how to strip spaces and #comments from message"
+msgstr "設定如何刪除提交說明裡的空格和 #備註"
+
+#: parse-options.h:337
+#| msgid "read patterns from file"
+msgid "read pathspec from file"
+msgstr "從檔案讀取 <路徑規格>"
+
+#: parse-options.h:338
+#| msgid "paths are separated with NUL character"
+msgid ""
+"with --pathspec-from-file, pathspec elements are separated with NUL character"
+msgstr "如使用 --pathspec-from-file，則 <路徑規格> 元件會使用 NUL 字元分隔"
+
+#: ref-filter.h:101
+msgid "key"
+msgstr "key"
+
+#: ref-filter.h:101
+msgid "field name to sort on"
+msgstr "排序的欄位名"
+
+#: rerere.h:44
+msgid "update the index with reused conflict resolution if possible"
+msgstr "如果可能，重用衝突解決更新索引"
+
+#: wt-status.h:67
+msgid "HEAD detached at "
+msgstr "開頭指標分離於 "
+
+#: wt-status.h:68
+msgid "HEAD detached from "
+msgstr "開頭指標分離自 "
+
+#: command-list.h:50
+msgid "Add file contents to the index"
+msgstr "新增檔案內容至索引"
+
+#: command-list.h:51
+msgid "Apply a series of patches from a mailbox"
+msgstr "套用信箱格式的系列修補檔"
+
+#: command-list.h:52
+msgid "Annotate file lines with commit information"
+msgstr "使用提交訊息備註檔案行"
+
+#: command-list.h:53
+msgid "Apply a patch to files and/or to the index"
+msgstr "套用一個修補檔到檔案和/或索引區"
+
+#: command-list.h:54
+msgid "Import a GNU Arch repository into Git"
+msgstr "將一個 GNU Arch 版本庫匯入到 Git"
+
+#: command-list.h:55
+msgid "Create an archive of files from a named tree"
+msgstr "基於命名過的樹建立檔案封存"
+
+#: command-list.h:56
+msgid "Use binary search to find the commit that introduced a bug"
+msgstr "透過二分尋找定位引入 bug 的提交"
+
+#: command-list.h:57
+msgid "Show what revision and author last modified each line of a file"
+msgstr "顯示檔案每一行最後修改的版本和修改者"
+
+#: command-list.h:58
+msgid "List, create, or delete branches"
+msgstr "列出、建立或刪除分支"
+
+#: command-list.h:59
+msgid "Move objects and refs by archive"
+msgstr "透過歸檔移動物件和引用"
+
+#: command-list.h:60
+msgid "Provide content or type and size information for repository objects"
+msgstr "提供版本庫物件的內容、類型或大小"
+
+#: command-list.h:61
+msgid "Display gitattributes information"
+msgstr "顯示 gitattributes 訊息"
+
+#: command-list.h:62
+msgid "Debug gitignore / exclude files"
+msgstr "除錯 gitignore / exclude 檔案"
+
+#: command-list.h:63
+msgid "Show canonical names and email addresses of contacts"
+msgstr "顯示聯絡人的規範名稱和電子信件"
+
+#: command-list.h:64
+msgid "Switch branches or restore working tree files"
+msgstr "切換分支或復原工作區檔案"
+
+#: command-list.h:65
+msgid "Copy files from the index to the working tree"
+msgstr "從索引複製檔案到工作區"
+
+#: command-list.h:66
+msgid "Ensures that a reference name is well formed"
+msgstr "確保引用名稱格式正確"
+
+#: command-list.h:67
+msgid "Find commits yet to be applied to upstream"
+msgstr "尋找尚未套用到上游的提交"
+
+#: command-list.h:68
+msgid "Apply the changes introduced by some existing commits"
+msgstr "應用一些現存提交引入的修改"
+
+#: command-list.h:69
+msgid "Graphical alternative to git-commit"
+msgstr "git-commit 的圖形替代介面"
+
+#: command-list.h:70
+msgid "Remove untracked files from the working tree"
+msgstr "從工作區中刪除未追蹤檔案"
+
+#: command-list.h:71
+msgid "Clone a repository into a new directory"
+msgstr "複製版本庫到一個新目錄"
+
+#: command-list.h:72
+msgid "Display data in columns"
+msgstr "以列的方式顯示資料"
+
+#: command-list.h:73
+msgid "Record changes to the repository"
+msgstr "記錄變更到版本庫"
+
+#: command-list.h:74
+msgid "Write and verify Git commit-graph files"
+msgstr "寫入和驗證 Git 提交圖檔案"
+
+#: command-list.h:75
+msgid "Create a new commit object"
+msgstr "建立一個新的提交物件"
+
+#: command-list.h:76
+msgid "Get and set repository or global options"
+msgstr "取得和設定版本庫或者全域選項"
+
+#: command-list.h:77
+msgid "Count unpacked number of objects and their disk consumption"
+msgstr "計算未打包物件的數量和磁碟空間占用"
+
+#: command-list.h:78
+msgid "Retrieve and store user credentials"
+msgstr "檢索和儲存使用者密碼"
+
+#: command-list.h:79
+msgid "Helper to temporarily store passwords in memory"
+msgstr "在記憶體中暫時儲存密碼的助手"
+
+#: command-list.h:80
+msgid "Helper to store credentials on disk"
+msgstr "在磁碟儲存密碼的助手"
+
+#: command-list.h:81
+msgid "Export a single commit to a CVS checkout"
+msgstr "將一個提交匯出到 CVS 簽出中"
+
+#: command-list.h:82
+msgid "Salvage your data out of another SCM people love to hate"
+msgstr "從另外一個人們愛恨的設定管理系統中拯救你的資料"
+
+#: command-list.h:83
+msgid "A CVS server emulator for Git"
+msgstr "Git 的一個 CVS 服務模擬器"
+
+#: command-list.h:84
+msgid "A really simple server for Git repositories"
+msgstr "一個非常簡單的 Git 版本庫伺服器"
+
+#: command-list.h:85
+msgid "Give an object a human readable name based on an available ref"
+msgstr "基於一個現存的引用為一個物件起一個可讀的名稱"
+
+#: command-list.h:86
+msgid "Show changes between commits, commit and working tree, etc"
+msgstr "顯示提交之間、提交和工作區之間等的差異"
+
+#: command-list.h:87
+msgid "Compares files in the working tree and the index"
+msgstr "比較工作區和索引區中的檔案"
+
+#: command-list.h:88
+msgid "Compare a tree to the working tree or index"
+msgstr "將一個樹和工作區或索引做比較"
+
+#: command-list.h:89
+msgid "Compares the content and mode of blobs found via two tree objects"
+msgstr "比較兩個樹狀物件的檔案內容和模式"
+
+#: command-list.h:90
+msgid "Show changes using common diff tools"
+msgstr "使用常見的差異工具顯示更改"
+
+#: command-list.h:91
+msgid "Git data exporter"
+msgstr "Git 資料匯出器"
+
+#: command-list.h:92
+msgid "Backend for fast Git data importers"
+msgstr "Git 快速資料匯入器後端"
+
+#: command-list.h:93
+msgid "Download objects and refs from another repository"
+msgstr "從另外一個版本庫下載物件和引用"
+
+#: command-list.h:94
+msgid "Receive missing objects from another repository"
+msgstr "從另一個版本庫取得缺少的物件"
+
+#: command-list.h:95
+msgid "Rewrite branches"
+msgstr "重寫分支"
+
+#: command-list.h:96
+msgid "Produce a merge commit message"
+msgstr "生成一個合併提交訊息"
+
+#: command-list.h:97
+msgid "Output information on each ref"
+msgstr "對每一個引用輸出訊息 "
+
+#: command-list.h:98
+msgid "Prepare patches for e-mail submission"
+msgstr "準備電子信件提交的修補檔"
+
+#: command-list.h:99
+msgid "Verifies the connectivity and validity of the objects in the database"
+msgstr "驗證版本庫中物件的連通性和有效性"
+
+#: command-list.h:100
+msgid "Cleanup unnecessary files and optimize the local repository"
+msgstr "清除不必要的檔案和最佳化本機版本庫"
+
+#: command-list.h:101
+msgid "Extract commit ID from an archive created using git-archive"
+msgstr "從 git-archive 建立的歸檔檔案中擷取提交 ID"
+
+#: command-list.h:102
+msgid "Print lines matching a pattern"
+msgstr "輸出和模式符合的行"
+
+#: command-list.h:103
+msgid "A portable graphical interface to Git"
+msgstr "一個便攜的 Git 圖形用戶端"
+
+#: command-list.h:104
+msgid "Compute object ID and optionally creates a blob from a file"
+msgstr "從一個檔案計算物件 ID，並可以建立 blob 資料物件"
+
+#: command-list.h:105
+msgid "Display help information about Git"
+msgstr "顯示 Git 的說明訊息"
+
+#: command-list.h:106
+msgid "Server side implementation of Git over HTTP"
+msgstr "Git HTTP 協定的服務端實現"
+
+#: command-list.h:107
+msgid "Download from a remote Git repository via HTTP"
+msgstr "通過 HTTP 從遠端 Git 版本庫下載"
+
+#: command-list.h:108
+msgid "Push objects over HTTP/DAV to another repository"
+msgstr "通過 HTTP/DAV 推送物件另一個版本庫"
+
+#: command-list.h:109
+msgid "Send a collection of patches from stdin to an IMAP folder"
+msgstr "從標準輸入將一組修補檔傳送到IMAP資料夾"
+
+#: command-list.h:110
+msgid "Build pack index file for an existing packed archive"
+msgstr "從一個現存的包存檔檔案建立包索引"
+
+#: command-list.h:111
+msgid "Create an empty Git repository or reinitialize an existing one"
+msgstr "建立一個空的 Git 版本庫或重新初始化一個已存在的版本庫"
+
+#: command-list.h:112
+msgid "Instantly browse your working repository in gitweb"
+msgstr "在 gitweb 中即時瀏覽您的工作版本庫"
+
+#: command-list.h:113
+msgid "Add or parse structured information in commit messages"
+msgstr "新增或解析提交說明中的結構化訊息"
+
+#: command-list.h:114
+msgid "The Git repository browser"
+msgstr "Git 版本庫瀏覽器"
+
+#: command-list.h:115
+msgid "Show commit logs"
+msgstr "顯示提交日誌"
+
+#: command-list.h:116
+msgid "Show information about files in the index and the working tree"
+msgstr "顯示索引和工作區中檔案的訊息"
+
+#: command-list.h:117
+msgid "List references in a remote repository"
+msgstr "顯示一個遠端版本庫的引用"
+
+#: command-list.h:118
+msgid "List the contents of a tree object"
+msgstr "顯示一個樹狀物件的內容"
+
+#: command-list.h:119
+msgid "Extracts patch and authorship from a single e-mail message"
+msgstr "從單個電子信件中擷取修補檔和作者身份"
+
+#: command-list.h:120
+msgid "Simple UNIX mbox splitter program"
+msgstr "簡單的 UNIX mbox 信箱切分程式"
+
+#: command-list.h:121
+msgid "Join two or more development histories together"
+msgstr "合併兩個或更多開發歷史"
+
+#: command-list.h:122
+msgid "Find as good common ancestors as possible for a merge"
+msgstr "為了合併尋找儘可能好的公共祖先提交"
+
+#: command-list.h:123
+msgid "Run a three-way file merge"
+msgstr "執行一個三路檔案合併"
+
+#: command-list.h:124
+msgid "Run a merge for files needing merging"
+msgstr "對於需要合併的檔案執行合併"
+
+#: command-list.h:125
+msgid "The standard helper program to use with git-merge-index"
+msgstr "與 git-merge-index 一起使用的標準嚮導程式"
+
+#: command-list.h:126
+msgid "Run merge conflict resolution tools to resolve merge conflicts"
+msgstr "執行合併衝突解決工具以解決合併衝突"
+
+#: command-list.h:127
+msgid "Show three-way merge without touching index"
+msgstr "顯示三路合併而不動索引"
+
+#: command-list.h:128
+msgid "Write and verify multi-pack-indexes"
+msgstr "寫入和驗證多包索引"
+
+#: command-list.h:129
+msgid "Creates a tag object"
+msgstr "建立一個標籤物件"
+
+#: command-list.h:130
+msgid "Build a tree-object from ls-tree formatted text"
+msgstr "基於 ls-tree 的格式化文字建立一個樹狀物件"
+
+#: command-list.h:131
+msgid "Move or rename a file, a directory, or a symlink"
+msgstr "移動或重新命名一個檔案、目錄或符號連結"
+
+# 尋找提供版本的符號名稱
+#: command-list.h:132
+msgid "Find symbolic names for given revs"
+msgstr "尋找提供版本的符號名稱"
+
+#: command-list.h:133
+msgid "Add or inspect object notes"
+msgstr "新增或檢查物件備註"
+
+#: command-list.h:134
+msgid "Import from and submit to Perforce repositories"
+msgstr "匯入和提交到 Perforce 版本庫中"
+
+#: command-list.h:135
+msgid "Create a packed archive of objects"
+msgstr "建立物件的存檔包"
+
+#: command-list.h:136
+msgid "Find redundant pack files"
+msgstr "尋找冗餘的包檔案"
+
+#: command-list.h:137
+msgid "Pack heads and tags for efficient repository access"
+msgstr "打包頭和標籤以實現高效的版本庫存取"
+
+#: command-list.h:138
+msgid "Routines to help parsing remote repository access parameters"
+msgstr "協助解析遠端版本庫存取參數的例程"
+
+#: command-list.h:139
+msgid "Compute unique ID for a patch"
+msgstr "計算一個修補檔的唯一 ID"
+
+#: command-list.h:140
+msgid "Prune all unreachable objects from the object database"
+msgstr "刪除物件庫中所有無法取得物件"
+
+#: command-list.h:141
+msgid "Remove extra objects that are already in pack files"
+msgstr "刪除已經在包檔案中的多餘物件"
+
+#: command-list.h:142
+msgid "Fetch from and integrate with another repository or a local branch"
+msgstr "取得並整合另外的版本庫或一個本機分支"
+
+#: command-list.h:143
+msgid "Update remote refs along with associated objects"
+msgstr "更新遠端引用和相關的物件"
+
+#: command-list.h:144
+msgid "Applies a quilt patchset onto the current branch"
+msgstr "將一個 quilt 修補檔集套用到目前分支。"
+
+#: command-list.h:145
+msgid "Compare two commit ranges (e.g. two versions of a branch)"
+msgstr "比較兩個提交範圍（如一個分支的兩個版本）"
+
+#: command-list.h:146
+msgid "Reads tree information into the index"
+msgstr "將樹訊息讀取到索引"
+
+#: command-list.h:147
+msgid "Reapply commits on top of another base tip"
+msgstr "在另一個分支上重新應用提交"
+
+#: command-list.h:148
+msgid "Receive what is pushed into the repository"
+msgstr "接收推送到版本庫中的物件"
+
+#: command-list.h:149
+msgid "Manage reflog information"
+msgstr "管理 reflog 訊息"
+
+#: command-list.h:150
+msgid "Manage set of tracked repositories"
+msgstr "管理已追蹤版本庫"
+
+#: command-list.h:151
+msgid "Pack unpacked objects in a repository"
+msgstr "打包版本庫中未打包物件"
+
+#: command-list.h:152
+msgid "Create, list, delete refs to replace objects"
+msgstr "建立、列出、刪除物件取代引用"
+
+#: command-list.h:153
+msgid "Generates a summary of pending changes"
+msgstr "生成待定更改的摘要"
+
+#: command-list.h:154
+msgid "Reuse recorded resolution of conflicted merges"
+msgstr "重用衝突合併的解決方案記錄"
+
+#: command-list.h:155
+msgid "Reset current HEAD to the specified state"
+msgstr "重設目前 HEAD 到指定狀態"
+
+#: command-list.h:156
+msgid "Restore working tree files"
+msgstr "復原工作區檔案"
+
+#: command-list.h:157
+msgid "Revert some existing commits"
+msgstr "還原一些現存提交"
+
+#: command-list.h:158
+msgid "Lists commit objects in reverse chronological order"
+msgstr "按時間順序列出提交物件"
+
+#: command-list.h:159
+msgid "Pick out and massage parameters"
+msgstr "選出並處理參數"
+
+#: command-list.h:160
+msgid "Remove files from the working tree and from the index"
+msgstr "從工作區和索引中刪除檔案"
+
+#: command-list.h:161
+msgid "Send a collection of patches as emails"
+msgstr "透過電子信件傳送一組修補檔"
+
+#: command-list.h:162
+msgid "Push objects over Git protocol to another repository"
+msgstr "使用 Git 協定推送物件到另一個版本庫"
+
+#: command-list.h:163
+msgid "Restricted login shell for Git-only SSH access"
+msgstr "只允許 Git SSH 存取的受限登入shell"
+
+#: command-list.h:164
+msgid "Summarize 'git log' output"
+msgstr "'git log' 輸出摘要"
+
+#: command-list.h:165
+msgid "Show various types of objects"
+msgstr "顯示各種類型的物件"
+
+#: command-list.h:166
+msgid "Show branches and their commits"
+msgstr "顯示分支和提交"
+
+#: command-list.h:167
+msgid "Show packed archive index"
+msgstr "顯示打包歸檔索引"
+
+#: command-list.h:168
+msgid "List references in a local repository"
+msgstr "顯示本機版本庫中的引用"
+
+#: command-list.h:169
+msgid "Git's i18n setup code for shell scripts"
+msgstr "為 shell 腳本準備的 Git 國際化設定程式碼"
+
+#: command-list.h:170
+msgid "Common Git shell script setup code"
+msgstr "常用的 Git shell 腳本設定程式碼"
+
+#: command-list.h:171
+msgid "Initialize and modify the sparse-checkout"
+msgstr "初始化並修改稀疏簽出"
+
+#: command-list.h:172
+msgid "Stash the changes in a dirty working directory away"
+msgstr "儲藏髒工作區中的修改"
+
+#: command-list.h:173
+msgid "Add file contents to the staging area"
+msgstr "將檔案內容新增到索引"
+
+#: command-list.h:174
+msgid "Show the working tree status"
+msgstr "顯示工作區狀態"
+
+#: command-list.h:175
+msgid "Remove unnecessary whitespace"
+msgstr "刪除不必要的空白字元"
+
+#: command-list.h:176
+msgid "Initialize, update or inspect submodules"
+msgstr "初始化、更新或檢查子模組"
+
+#: command-list.h:177
+msgid "Bidirectional operation between a Subversion repository and Git"
+msgstr "Subversion 版本庫和 Git 之間的雙向動作"
+
+#: command-list.h:178
+msgid "Switch branches"
+msgstr "切換分支"
+
+#: command-list.h:179
+msgid "Read, modify and delete symbolic refs"
+msgstr "讀取、修改和刪除符號引用"
+
+#: command-list.h:180
+msgid "Create, list, delete or verify a tag object signed with GPG"
+msgstr "建立、列出、刪除或驗證一個 GPG 簽名的標籤物件"
+
+#: command-list.h:181
+msgid "Creates a temporary file with a blob's contents"
+msgstr "用 blob 資料物件的內容建立一個暫存檔"
+
+#: command-list.h:182
+msgid "Unpack objects from a packed archive"
+msgstr "從打包檔案中解壓縮物件"
+
+#: command-list.h:183
+msgid "Register file contents in the working tree to the index"
+msgstr "將工作區的檔案內容註冊到索引"
+
+#: command-list.h:184
+msgid "Update the object name stored in a ref safely"
+msgstr "安全地更新儲存於引用中的物件名稱"
+
+#: command-list.h:185
+msgid "Update auxiliary info file to help dumb servers"
+msgstr "更新輔助訊息檔案以協助啞協定服務"
+
+#: command-list.h:186
+msgid "Send archive back to git-archive"
+msgstr "將存檔傳送回 git-archive"
+
+#: command-list.h:187
+msgid "Send objects packed back to git-fetch-pack"
+msgstr "將物件壓縮包傳送回 git-fetch-pack"
+
+#: command-list.h:188
+msgid "Show a Git logical variable"
+msgstr "顯示 Git 邏輯變數"
+
+#: command-list.h:189
+msgid "Check the GPG signature of commits"
+msgstr "檢查 GPG 提交簽名"
+
+#: command-list.h:190
+msgid "Validate packed Git archive files"
+msgstr "驗證打包的 Git 封存檔案"
+
+#: command-list.h:191
+msgid "Check the GPG signature of tags"
+msgstr "檢查標籤的 GPG 簽名"
+
+#: command-list.h:192
+msgid "Git web interface (web frontend to Git repositories)"
+msgstr "Git web 介面（Git 版本庫的 web 前端）"
+
+#: command-list.h:193
+msgid "Show logs with difference each commit introduces"
+msgstr "顯示每一個提交引入的差異日誌"
+
+#: command-list.h:194
+msgid "Manage multiple working trees"
+msgstr "管理多個工作區"
+
+#: command-list.h:195
+msgid "Create a tree object from the current index"
+msgstr "從目前索引建立一個樹狀物件"
+
+#: command-list.h:196
+msgid "Defining attributes per path"
+msgstr "定義路徑的屬性"
+
+#: command-list.h:197
+msgid "Git command-line interface and conventions"
+msgstr "Git 指令列介面和約定"
+
+#: command-list.h:198
+msgid "A Git core tutorial for developers"
+msgstr "面向開發人員的 Git 核心教學"
+
+#: command-list.h:199
+msgid "Git for CVS users"
+msgstr "適合 CVS 使用者的 Git 協助"
+
+#: command-list.h:200
+msgid "Tweaking diff output"
+msgstr "調整差異輸出"
+
+#: command-list.h:201
+msgid "A useful minimum set of commands for Everyday Git"
+msgstr "每一天 Git 的一組有用的最小指令集合"
+
+#: command-list.h:202
+msgid "A Git Glossary"
+msgstr "Git 詞彙表"
+
+#: command-list.h:203
+msgid "Hooks used by Git"
+msgstr "Git 使用的掛鉤"
+
+#: command-list.h:204
+msgid "Specifies intentionally untracked files to ignore"
+msgstr "忽略指定的未追蹤檔案"
+
+#: command-list.h:205
+msgid "Defining submodule properties"
+msgstr "定義子模組屬性"
+
+#: command-list.h:206
+msgid "Git namespaces"
+msgstr "Git 名字空間"
+
+#: command-list.h:207
+msgid "Git Repository Layout"
+msgstr "Git 版本庫配置"
+
+#: command-list.h:208
+msgid "Specifying revisions and ranges for Git"
+msgstr "指定 Git 的版本和版本範圍"
+
+#: command-list.h:209
+msgid "Mounting one repository inside another"
+msgstr "在某個版本庫掛載某個版本庫"
+
+#: command-list.h:210
+msgid "A tutorial introduction to Git: part two"
+msgstr "一個 Git 教學：第二部分"
+
+#: command-list.h:211
+msgid "A tutorial introduction to Git"
+msgstr "一個 Git 教學"
+
+#: command-list.h:212
+msgid "An overview of recommended workflows with Git"
+msgstr "Git 推薦的工作流概覽"
+
+#: git-bisect.sh:54
+msgid "You need to start by \"git bisect start\""
+msgstr "您需要執行 \"git bisect start\" 來開始"
+
+#  譯者：請維持句尾空格
+#. TRANSLATORS: Make sure to include [Y] and [n] in your
+#. translation. The program will only accept English input
+#. at this point.
+#: git-bisect.sh:60
+msgid "Do you want me to do it for you [Y/n]? "
+msgstr "您想讓我為您這樣做嗎[Y/n]？ "
+
+#: git-bisect.sh:101
+#, sh-format
+msgid "Bad rev input: $arg"
+msgstr "壞的輸入版本：$arg"
+
+#: git-bisect.sh:121
+#, sh-format
+msgid "Bad rev input: $bisected_head"
+msgstr "壞的輸入版本：$bisected_head"
+
+#: git-bisect.sh:130
+#, sh-format
+msgid "Bad rev input: $rev"
+msgstr "壞的輸入版本：$rev"
+
+#: git-bisect.sh:139
+#, sh-format
+msgid "'git bisect $TERM_BAD' can take only one argument."
+msgstr "'git bisect $TERM_BAD' 只能帶一個參數。"
+
+#: git-bisect.sh:209
+msgid "No logfile given"
+msgstr "未提供日誌檔案"
+
+#: git-bisect.sh:210
+#, sh-format
+msgid "cannot read $file for replaying"
+msgstr "不能讀取 $file 來重放"
+
+#: git-bisect.sh:232
+msgid "?? what are you talking about?"
+msgstr "?? 您在說什麼?"
+
+#: git-bisect.sh:241
+msgid "bisect run failed: no command provided."
+msgstr "二分尋找執行失敗：沒有提供指令。"
+
+#: git-bisect.sh:246
+#, sh-format
+msgid "running $command"
+msgstr "執行 $command"
+
+#: git-bisect.sh:253
+#, sh-format
+msgid ""
+"bisect run failed:\n"
+"exit code $res from '$command' is < 0 or >= 128"
+msgstr ""
+"二分尋找執行失敗：\n"
+"指令 '$command' 的離開碼 $res 小於 0 或大於等於 128"
+
+#: git-bisect.sh:279
+msgid "bisect run cannot continue any more"
+msgstr "二分尋找不能繼續執行"
+
+#: git-bisect.sh:285
+#, sh-format
+msgid ""
+"bisect run failed:\n"
+"'bisect_state $state' exited with error code $res"
+msgstr ""
+"二分尋找執行失敗：\n"
+"'bisect_state $state' 離開碼為 $res"
+
+#: git-bisect.sh:292
+msgid "bisect run success"
+msgstr "二分尋找執行成功"
+
+#: git-bisect.sh:300
+msgid "We are not bisecting."
+msgstr "我們沒有在二分尋找。"
+
+#: git-merge-octopus.sh:46
+msgid ""
+"Error: Your local changes to the following files would be overwritten by "
+"merge"
+msgstr "錯誤：您對下列檔案的本機修改將被合併動作覆蓋"
+
+#: git-merge-octopus.sh:61
+msgid "Automated merge did not work."
+msgstr "自動合併未生效。"
+
+#: git-merge-octopus.sh:62
+msgid "Should not be doing an octopus."
+msgstr "不應該執行章魚式合併。"
+
+#: git-merge-octopus.sh:73
+#, sh-format
+msgid "Unable to find common commit with $pretty_name"
+msgstr "無法找到和 $pretty_name 的基礎提交"
+
+#: git-merge-octopus.sh:77
+#, sh-format
+msgid "Already up to date with $pretty_name"
+msgstr "已經和 $pretty_name 保持一致"
+
+#: git-merge-octopus.sh:89
+#, sh-format
+msgid "Fast-forwarding to: $pretty_name"
+msgstr "快轉至：$pretty_name"
+
+#: git-merge-octopus.sh:97
+#, sh-format
+msgid "Trying simple merge with $pretty_name"
+msgstr "嘗試和 $pretty_name 的簡單合併"
+
+#: git-merge-octopus.sh:102
+msgid "Simple merge did not work, trying automatic merge."
+msgstr "簡單合併未生效，嘗試自動合併。"
+
+#: git-legacy-stash.sh:221
+msgid "Cannot remove temporary index (can't happen)"
+msgstr "無法刪除暫時索引（不應發生）"
+
+#: git-legacy-stash.sh:272
+#, sh-format
+msgid "Cannot update $ref_stash with $w_commit"
+msgstr "無法用 $w_commit 更新 $ref_stash"
+
+#: git-legacy-stash.sh:324
+#, sh-format
+msgid "error: unknown option for 'stash push': $option"
+msgstr "錯誤：'stash push' 的未知選項：$option"
+
+#: git-legacy-stash.sh:356
+#, sh-format
+msgid "Saved working directory and index state $stash_msg"
+msgstr "儲存工作目錄和索引狀態 $stash_msg"
+
+#: git-legacy-stash.sh:536
+#, sh-format
+msgid "unknown option: $opt"
+msgstr "未知選項: $opt"
+
+#: git-legacy-stash.sh:556
+#, sh-format
+msgid "Too many revisions specified: $REV"
+msgstr "指定了太多的版本：$REV"
+
+#: git-legacy-stash.sh:571
+#, sh-format
+msgid "$reference is not a valid reference"
+msgstr "$reference 不是一個有效的引用"
+
+#: git-legacy-stash.sh:599
+#, sh-format
+msgid "'$args' is not a stash-like commit"
+msgstr "'$args' 不是儲藏式提交"
+
+#: git-legacy-stash.sh:610
+#, sh-format
+msgid "'$args' is not a stash reference"
+msgstr "'$args' 不是一個儲藏引用"
+
+#: git-legacy-stash.sh:618
+msgid "unable to refresh index"
+msgstr "無法重新整理索引"
+
+#: git-legacy-stash.sh:622
+msgid "Cannot apply a stash in the middle of a merge"
+msgstr "無法在合併過程套用儲藏"
+
+#: git-legacy-stash.sh:630
+msgid "Conflicts in index. Try without --index."
+msgstr "索引中有衝突。嘗試不使用 --index。"
+
+#: git-legacy-stash.sh:632
+msgid "Could not save index tree"
+msgstr "不能儲存索引樹"
+
+#: git-legacy-stash.sh:641
+msgid "Could not restore untracked files from stash entry"
+msgstr "無法從儲藏條目中復原未追蹤檔案"
+
+#: git-legacy-stash.sh:666
+msgid "Cannot unstage modified files"
+msgstr "無法將修改的檔案取消暫存"
+
+#: git-legacy-stash.sh:704
+#, sh-format
+msgid "Dropped ${REV} ($s)"
+msgstr "捨棄了 ${REV} ($s)"
+
+#: git-legacy-stash.sh:705
+#, sh-format
+msgid "${REV}: Could not drop stash entry"
+msgstr "${REV}：無法捨棄儲藏條目"
+
+#: git-legacy-stash.sh:792
+msgid "(To restore them type \"git stash apply\")"
+msgstr "（為復原資料輸入 \"git stash apply\"）"
+
+#: git-submodule.sh:202
+msgid "Relative path can only be used from the toplevel of the working tree"
+msgstr "只能在工作區的頂級目錄中使用相對路徑"
+
+#: git-submodule.sh:212
+#, sh-format
+msgid "repo URL: '$repo' must be absolute or begin with ./|../"
+msgstr "版本庫 URL：'$repo' 必須是絕對路徑或以 ./|../ 起始"
+
+#: git-submodule.sh:231
+#, sh-format
+msgid "'$sm_path' already exists in the index"
+msgstr "'$sm_path' 已經存在於索引中"
+
+#: git-submodule.sh:234
+#, sh-format
+msgid "'$sm_path' already exists in the index and is not a submodule"
+msgstr "'$sm_path' 已經存在於索引中且不是一個子模組"
+
+#: git-submodule.sh:241
+#, sh-format
+msgid "'$sm_path' does not have a commit checked out"
+msgstr "'$sm_path' 沒有簽出的提交"
+
+#: git-submodule.sh:247
+#, sh-format
+msgid ""
+"The following path is ignored by one of your .gitignore files:\n"
+"$sm_path\n"
+"Use -f if you really want to add it."
+msgstr ""
+"以下路徑被您的一個 .gitignore 檔案所忽略：\n"
+"$sm_path\n"
+"如果您確實想新增它，使用 -f 參數。"
+
+#: git-submodule.sh:270
+#, sh-format
+msgid "Adding existing repo at '$sm_path' to the index"
+msgstr "新增位於 '$sm_path' 的現存版本庫到索引"
+
+#: git-submodule.sh:272
+#, sh-format
+msgid "'$sm_path' already exists and is not a valid git repo"
+msgstr "'$sm_path' 已存在且不是一個有效的 git 版本庫"
+
+#: git-submodule.sh:280
+#, sh-format
+msgid "A git directory for '$sm_name' is found locally with remote(s):"
+msgstr "本機發現 '$sm_name' 的一個 git 目錄，與其對應的遠端版本庫："
+
+#: git-submodule.sh:282
+#, sh-format
+msgid ""
+"If you want to reuse this local git directory instead of cloning again from\n"
+"  $realrepo\n"
+"use the '--force' option. If the local git directory is not the correct "
+"repo\n"
+"or you are unsure what this means choose another name with the '--name' "
+"option."
+msgstr ""
+"如果您想要重用這個本機 git 目錄而非重新複製自\n"
+"  $realrepo\n"
+"使用 '--force' 選項。如果本機 git 目錄不是正確的版本庫\n"
+"或者您不確定這裡的含義，使用 '--name' 選項選擇另外的名稱。"
+
+#: git-submodule.sh:288
+#, sh-format
+msgid "Reactivating local git directory for submodule '$sm_name'."
+msgstr "啟動本機 git 目錄到子模組 '$sm_name'。"
+
+#: git-submodule.sh:300
+#, sh-format
+msgid "Unable to checkout submodule '$sm_path'"
+msgstr "不能簽出子模組 '$sm_path'"
+
+#: git-submodule.sh:305
+#, sh-format
+msgid "Failed to add submodule '$sm_path'"
+msgstr "無法新增子模組 '$sm_path'"
+
+#: git-submodule.sh:314
+#, sh-format
+msgid "Failed to register submodule '$sm_path'"
+msgstr "無法註冊子模組 '$sm_path'"
+
+#: git-submodule.sh:580
+#, sh-format
+msgid "Unable to find current revision in submodule path '$displaypath'"
+msgstr "無法在子模組路徑 '$displaypath' 中找到目前版本"
+
+#: git-submodule.sh:590
+#, sh-format
+msgid "Unable to fetch in submodule path '$sm_path'"
+msgstr "無法在子模組路徑 '$sm_path' 中取得"
+
+#: git-submodule.sh:595
+#, sh-format
+msgid ""
+"Unable to find current ${remote_name}/${branch} revision in submodule path "
+"'$sm_path'"
+msgstr "無法在子模組路徑 '$sm_path' 中找到目前版本 ${remote_name}/${branch}"
+
+#: git-submodule.sh:613
+#, sh-format
+msgid ""
+"Unable to fetch in submodule path '$displaypath'; trying to directly fetch "
+"$sha1:"
+msgstr "無法在子模組路徑 '$displaypath' 中取得，嘗試直接取得 $sha1："
+
+#: git-submodule.sh:619
+#, sh-format
+msgid ""
+"Fetched in submodule path '$displaypath', but it did not contain $sha1. "
+"Direct fetching of that commit failed."
+msgstr "取得了子模組路徑 '$displaypath'，但是它沒有包含 $sha1。直接取得該提交失敗。"
+
+#: git-submodule.sh:626
+#, sh-format
+msgid "Unable to checkout '$sha1' in submodule path '$displaypath'"
+msgstr "無法在子模組路徑 '$displaypath' 中簽出 '$sha1'"
+
+#: git-submodule.sh:627
+#, sh-format
+msgid "Submodule path '$displaypath': checked out '$sha1'"
+msgstr "子模組路徑 '$displaypath'：簽出 '$sha1'"
+
+#: git-submodule.sh:631
+#, sh-format
+msgid "Unable to rebase '$sha1' in submodule path '$displaypath'"
+msgstr "無法在子模組路徑 '$displaypath' 中重定基底 '$sha1'"
+
+#: git-submodule.sh:632
+#, sh-format
+msgid "Submodule path '$displaypath': rebased into '$sha1'"
+msgstr "子模組路徑 '$displaypath'：重定基底至 '$sha1'"
+
+#: git-submodule.sh:637
+#, sh-format
+msgid "Unable to merge '$sha1' in submodule path '$displaypath'"
+msgstr "無法合併 '$sha1' 到子模組路徑 '$displaypath' 中"
+
+#: git-submodule.sh:638
+#, sh-format
+msgid "Submodule path '$displaypath': merged in '$sha1'"
+msgstr "子模組路徑 '$displaypath'：已合併入 '$sha1'"
+
+#: git-submodule.sh:643
+#, sh-format
+msgid "Execution of '$command $sha1' failed in submodule path '$displaypath'"
+msgstr "在子模組 '$displaypath' 中執行 '$command $sha1' 失敗"
+
+#: git-submodule.sh:644
+#, sh-format
+msgid "Submodule path '$displaypath': '$command $sha1'"
+msgstr "子模組 '$displaypath'：'$command $sha1'"
+
+#: git-submodule.sh:675
+#, sh-format
+msgid "Failed to recurse into submodule path '$displaypath'"
+msgstr "無法遞迴進子模組路徑 '$displaypath'"
+
+#: git-submodule.sh:886
+msgid "The --cached option cannot be used with the --files option"
+msgstr "選項 --cached 不能和選項 --files 同時使用"
+
+#: git-submodule.sh:938
+#, sh-format
+msgid "unexpected mode $mod_dst"
+msgstr "意外的模式 $mod_dst"
+
+#  譯者：請維持前導空格
+#: git-submodule.sh:958
+#, sh-format
+msgid "  Warn: $display_name doesn't contain commit $sha1_src"
+msgstr "  警告：$display_name 未包含提交 $sha1_src"
+
+#  譯者：請維持前導空格
+#: git-submodule.sh:961
+#, sh-format
+msgid "  Warn: $display_name doesn't contain commit $sha1_dst"
+msgstr "  警告：$display_name 未包含提交 $sha1_dst"
+
+#  譯者：請維持前導空格
+#: git-submodule.sh:964
+#, sh-format
+msgid "  Warn: $display_name doesn't contain commits $sha1_src and $sha1_dst"
+msgstr "  警告：$display_name 未包含提交 $sha1_src 和 $sha1_dst"
+
+#: git-parse-remote.sh:89
+#, sh-format
+msgid "See git-${cmd}(1) for details."
+msgstr "詳見 git-${cmd}(1)。"
+
+#: git-rebase--preserve-merges.sh:109
+msgid "Applied autostash."
+msgstr "已應用 autostash。"
+
+#: git-rebase--preserve-merges.sh:112
+#, sh-format
+msgid "Cannot store $stash_sha1"
+msgstr "不能儲存 $stash_sha1"
+
+#: git-rebase--preserve-merges.sh:191
+#, sh-format
+msgid "Rebasing ($new_count/$total)"
+msgstr "重定基底中（$new_count/$total）"
+
+#: git-rebase--preserve-merges.sh:207
+msgid ""
+"\n"
+"Commands:\n"
+"p, pick <commit> = use commit\n"
+"r, reword <commit> = use commit, but edit the commit message\n"
+"e, edit <commit> = use commit, but stop for amending\n"
+"s, squash <commit> = use commit, but meld into previous commit\n"
+"f, fixup <commit> = like \"squash\", but discard this commit's log message\n"
+"x, exec <commit> = run command (the rest of the line) using shell\n"
+"d, drop <commit> = remove commit\n"
+"l, label <label> = label current HEAD with a name\n"
+"t, reset <label> = reset HEAD to a label\n"
+"m, merge [-C <commit> | -c <commit>] <label> [# <oneline>]\n"
+".       create a merge commit using the original merge commit's\n"
+".       message (or the oneline, if no original merge commit was\n"
+".       specified). Use -c <commit> to reword the commit message.\n"
+"\n"
+"These lines can be re-ordered; they are executed from top to bottom.\n"
+msgstr ""
+"\n"
+"指令:\n"
+"p, pick <提交> = 使用提交\n"
+"r, reword <提交> = 使用提交，但修改提交說明\n"
+"e, edit <提交> = 使用提交，但停下來修補\n"
+"s, squash <提交> = 使用提交，但融合到前一個提交\n"
+"f, fixup <提交> = 類似於 \"squash\"，但捨棄提交說明日誌\n"
+"x, exec <指令> = 使用 shell 執行指令（此行剩餘部分）\n"
+"d, drop <提交> = 刪除提交\n"
+"l, label <標籤> = 為目前 HEAD 打上標籤\n"
+"t, reset <標籤> = 重設 HEAD 到該標籤\n"
+"m, merge [-C <提交> | -c <提交>] <標籤> [# <oneline>]\n"
+".       建立一個合併提交，並使用原始的合併提交說明（如果沒有指定\n"
+".       原始提交，使用備註部分的 oneline 作為提交說明）。使用\n"
+".       -c <提交> 可以編輯提交說明。\n"
+"\n"
+"可以對這些行重新排序，將從上至下執行。\n"
+
+#: git-rebase--preserve-merges.sh:270
+#, sh-format
+msgid ""
+"You can amend the commit now, with\n"
+"\n"
+"\tgit commit --amend $gpg_sign_opt_quoted\n"
+"\n"
+"Once you are satisfied with your changes, run\n"
+"\n"
+"\tgit rebase --continue"
+msgstr ""
+"您現在可以修補這個提交，使用\n"
+"\n"
+"\tgit commit --amend $gpg_sign_opt_quoted\n"
+"\n"
+"當您對變更感到滿意，執行\n"
+"\n"
+"\tgit rebase --continue"
+
+#: git-rebase--preserve-merges.sh:295
+#, sh-format
+msgid "$sha1: not a commit that can be picked"
+msgstr "$sha1：不是一個可以被揀選的提交"
+
+#: git-rebase--preserve-merges.sh:334
+#, sh-format
+msgid "Invalid commit name: $sha1"
+msgstr "無效的提交名：$sha1"
+
+#: git-rebase--preserve-merges.sh:364
+msgid "Cannot write current commit's replacement sha1"
+msgstr "不能寫入目前提交的替代 sha1"
+
+#: git-rebase--preserve-merges.sh:415
+#, sh-format
+msgid "Fast-forward to $sha1"
+msgstr "快轉到 $sha1"
+
+#: git-rebase--preserve-merges.sh:417
+#, sh-format
+msgid "Cannot fast-forward to $sha1"
+msgstr "不能快轉到 $sha1"
+
+#: git-rebase--preserve-merges.sh:426
+#, sh-format
+msgid "Cannot move HEAD to $first_parent"
+msgstr "不能移動 HEAD 到 $first_parent"
+
+#: git-rebase--preserve-merges.sh:431
+#, sh-format
+msgid "Refusing to squash a merge: $sha1"
+msgstr "拒絕壓縮一個合併：$sha1"
+
+#: git-rebase--preserve-merges.sh:449
+#, sh-format
+msgid "Error redoing merge $sha1"
+msgstr "無法重做合併 $sha1"
+
+#: git-rebase--preserve-merges.sh:458
+#, sh-format
+msgid "Could not pick $sha1"
+msgstr "不能揀選 $sha1"
+
+#: git-rebase--preserve-merges.sh:467
+#, sh-format
+msgid "This is the commit message #${n}:"
+msgstr "這是提交說明 #${n}："
+
+#: git-rebase--preserve-merges.sh:472
+#, sh-format
+msgid "The commit message #${n} will be skipped:"
+msgstr "提交說明 #${n} 將被跳過："
+
+#: git-rebase--preserve-merges.sh:483
+#, sh-format
+msgid "This is a combination of $count commit."
+msgid_plural "This is a combination of $count commits."
+msgstr[0] "這是一個 $count 個提交的組合。"
+msgstr[1] "這是一個 $count 個提交的組合。"
+
+#: git-rebase--preserve-merges.sh:492
+#, sh-format
+msgid "Cannot write $fixup_msg"
+msgstr "不能寫入 $fixup_msg"
+
+#: git-rebase--preserve-merges.sh:495
+msgid "This is a combination of 2 commits."
+msgstr "這是一個 2 個提交的組合。"
+
+#: git-rebase--preserve-merges.sh:536 git-rebase--preserve-merges.sh:579
+#: git-rebase--preserve-merges.sh:582
+#, sh-format
+msgid "Could not apply $sha1... $rest"
+msgstr "不能應用 $sha1... $rest"
+
+#: git-rebase--preserve-merges.sh:611
+#, sh-format
+msgid ""
+"Could not amend commit after successfully picking $sha1... $rest\n"
+"This is most likely due to an empty commit message, or the pre-commit hook\n"
+"failed. If the pre-commit hook failed, you may need to resolve the issue "
+"before\n"
+"you are able to reword the commit."
+msgstr ""
+"不能在成功揀選 $sha1... $rest 之後修補提交\n"
+"這通常是因為空的提交說明，或者 pre-commit 掛鉤執行失敗。如果是 pre-commit\n"
+"掛鉤執行失敗，你可能需要在重寫提交說明前解決這個問題。"
+
+#: git-rebase--preserve-merges.sh:626
+#, sh-format
+msgid "Stopped at $sha1_abbrev... $rest"
+msgstr "停止在 $sha1_abbrev... $rest"
+
+#: git-rebase--preserve-merges.sh:641
+#, sh-format
+msgid "Cannot '$squash_style' without a previous commit"
+msgstr "沒有父提交的情況下不能 '$squash_style'"
+
+#: git-rebase--preserve-merges.sh:683
+#, sh-format
+msgid "Executing: $rest"
+msgstr "執行：$rest"
+
+#: git-rebase--preserve-merges.sh:691
+#, sh-format
+msgid "Execution failed: $rest"
+msgstr "執行失敗：$rest"
+
+#: git-rebase--preserve-merges.sh:693
+msgid "and made changes to the index and/or the working tree"
+msgstr "並且修改索引和/或工作區"
+
+#  譯者：請維持前導空格
+#: git-rebase--preserve-merges.sh:695
+msgid ""
+"You can fix the problem, and then run\n"
+"\n"
+"\tgit rebase --continue"
+msgstr ""
+"您可以解決這個問題，然後執行\n"
+"\n"
+"\tgit rebase --continue"
+
+#. TRANSLATORS: after these lines is a command to be issued by the user
+#: git-rebase--preserve-merges.sh:708
+#, sh-format
+msgid ""
+"Execution succeeded: $rest\n"
+"but left changes to the index and/or the working tree\n"
+"Commit or stash your changes, and then run\n"
+"\n"
+"\tgit rebase --continue"
+msgstr ""
+"執行成功：$rest\n"
+"但是在索引和/或工作區中存在變更。提交或儲藏修改，然後執行\n"
+"\n"
+"\tgit rebase --continue"
+
+#: git-rebase--preserve-merges.sh:719
+#, sh-format
+msgid "Unknown command: $command $sha1 $rest"
+msgstr "未知指令：$command $sha1 $rest"
+
+#: git-rebase--preserve-merges.sh:720
+msgid "Please fix this using 'git rebase --edit-todo'."
+msgstr "要修改請使用指令 'git rebase --edit-todo'。"
+
+#: git-rebase--preserve-merges.sh:755
+#, sh-format
+msgid "Successfully rebased and updated $head_name."
+msgstr "成功重定基底並更新 $head_name。"
+
+#: git-rebase--preserve-merges.sh:812
+msgid "Could not remove CHERRY_PICK_HEAD"
+msgstr "不能刪除 CHERRY_PICK_HEAD"
+
+#: git-rebase--preserve-merges.sh:817
+#, sh-format
+msgid ""
+"You have staged changes in your working tree.\n"
+"If these changes are meant to be\n"
+"squashed into the previous commit, run:\n"
+"\n"
+"  git commit --amend $gpg_sign_opt_quoted\n"
+"\n"
+"If they are meant to go into a new commit, run:\n"
+"\n"
+"  git commit $gpg_sign_opt_quoted\n"
+"\n"
+"In both cases, once you're done, continue with:\n"
+"\n"
+"  git rebase --continue\n"
+msgstr ""
+"您已暫存了工作區的修改。如果這些修改要壓縮到前一個提交，執行：\n"
+"\n"
+"  git commit --amend $gpg_sign_opt_quoted\n"
+"\n"
+"如果這些變更要形成一個新提交，執行：\n"
+"\n"
+"  git commit $gpg_sign_opt_quoted\n"
+"\n"
+"無論哪種情況，當您完成提交，繼續執行：\n"
+"\n"
+"  git rebase --continue\n"
+
+#: git-rebase--preserve-merges.sh:834
+msgid "Error trying to find the author identity to amend commit"
+msgstr "在修補提交中尋找作者訊息時遇到錯誤"
+
+#: git-rebase--preserve-merges.sh:839
+msgid ""
+"You have uncommitted changes in your working tree. Please commit them\n"
+"first and then run 'git rebase --continue' again."
+msgstr "您的工作區中有未提交的變更。請先提交然後再次執行 'git rebase --continue'。"
+
+#: git-rebase--preserve-merges.sh:844 git-rebase--preserve-merges.sh:848
+msgid "Could not commit staged changes."
+msgstr "不能提交暫存的修改。"
+
+#: git-rebase--preserve-merges.sh:879 git-rebase--preserve-merges.sh:965
+msgid "Could not execute editor"
+msgstr "無法執行編輯器"
+
+#: git-rebase--preserve-merges.sh:900
+#, sh-format
+msgid "Could not checkout $switch_to"
+msgstr "不能簽出 $switch_to"
+
+#: git-rebase--preserve-merges.sh:907
+msgid "No HEAD?"
+msgstr "沒有 HEAD？"
+
+#: git-rebase--preserve-merges.sh:908
+#, sh-format
+msgid "Could not create temporary $state_dir"
+msgstr "不能建立暫時 $state_dir"
+
+#: git-rebase--preserve-merges.sh:911
+msgid "Could not mark as interactive"
+msgstr "不能標記為互動式"
+
+#: git-rebase--preserve-merges.sh:943
+#, sh-format
+msgid "Rebase $shortrevisions onto $shortonto ($todocount command)"
+msgid_plural "Rebase $shortrevisions onto $shortonto ($todocount commands)"
+msgstr[0] "重定基底 $shortrevisions 到 $shortonto（$todocount 個提交）"
+msgstr[1] "重定基底 $shortrevisions 到 $shortonto（$todocount 個提交）"
+
+#: git-rebase--preserve-merges.sh:997 git-rebase--preserve-merges.sh:1002
+msgid "Could not init rewritten commits"
+msgstr "不能對重寫提交進行初始化"
+
+#: git-sh-setup.sh:89 git-sh-setup.sh:94
+#, sh-format
+msgid "usage: $dashless $USAGE"
+msgstr "用法：$dashless $USAGE"
+
+#: git-sh-setup.sh:191
+#, sh-format
+msgid "Cannot chdir to $cdup, the toplevel of the working tree"
+msgstr "不能切換目錄到 $cdup，工作區的頂級目錄"
+
+#: git-sh-setup.sh:200 git-sh-setup.sh:207
+#, sh-format
+msgid "fatal: $program_name cannot be used without a working tree."
+msgstr "致命錯誤：$program_name 不能在沒有工作區的情況下使用"
+
+#: git-sh-setup.sh:221
+msgid "Cannot rebase: You have unstaged changes."
+msgstr "不能重定基底：您有未暫存的變更。"
+
+#: git-sh-setup.sh:224
+msgid "Cannot rewrite branches: You have unstaged changes."
+msgstr "不能重寫分支：您有未暫存的變更。"
+
+#: git-sh-setup.sh:227
+msgid "Cannot pull with rebase: You have unstaged changes."
+msgstr "無法透過重定基底方式拉取：您有未暫存的變更。"
+
+#: git-sh-setup.sh:230
+#, sh-format
+msgid "Cannot $action: You have unstaged changes."
+msgstr "不能 $action：您有未暫存的變更。"
+
+#: git-sh-setup.sh:243
+msgid "Cannot rebase: Your index contains uncommitted changes."
+msgstr "不能重定基底：您的索引中包含未提交的變更。"
+
+#: git-sh-setup.sh:246
+msgid "Cannot pull with rebase: Your index contains uncommitted changes."
+msgstr "無法透過重定基底方式拉取：您的索引中包含未提交的變更。"
+
+#: git-sh-setup.sh:249
+#, sh-format
+msgid "Cannot $action: Your index contains uncommitted changes."
+msgstr "不能 $action：您的索引中包含未提交的變更。"
+
+#: git-sh-setup.sh:253
+msgid "Additionally, your index contains uncommitted changes."
+msgstr "而且您的索引中包含未提交的變更。"
+
+#: git-sh-setup.sh:373
+msgid "You need to run this command from the toplevel of the working tree."
+msgstr "您需要在工作區的頂級目錄中執行這個指令。"
+
+#: git-sh-setup.sh:378
+msgid "Unable to determine absolute path of git directory"
+msgstr "不能確定 git 目錄的絕對路徑"
+
+#. TRANSLATORS: you can adjust this to align "git add -i" status menu
+#: git-add--interactive.perl:212
+#, perl-format
+msgid "%12s %12s %s"
+msgstr "%12s %12s %s"
+
+#: git-add--interactive.perl:634
+#, perl-format
+msgid "touched %d path\n"
+msgid_plural "touched %d paths\n"
+msgstr[0] "建立了 %d 個路徑\n"
+msgstr[1] "建立了 %d 個路徑\n"
+
+#: git-add--interactive.perl:1053
+msgid ""
+"If the patch applies cleanly, the edited hunk will immediately be\n"
+"marked for staging."
+msgstr "如果修補檔能乾淨地套用，編輯塊將立即標記為暫存。"
+
+#: git-add--interactive.perl:1056
+msgid ""
+"If the patch applies cleanly, the edited hunk will immediately be\n"
+"marked for stashing."
+msgstr "如果修補檔能乾淨地套用，編輯塊將立即標記為儲藏。"
+
+#: git-add--interactive.perl:1059
+msgid ""
+"If the patch applies cleanly, the edited hunk will immediately be\n"
+"marked for unstaging."
+msgstr "如果修補檔能乾淨地套用，編輯塊將立即標記為未暫存。"
+
+#: git-add--interactive.perl:1062 git-add--interactive.perl:1071
+#: git-add--interactive.perl:1077
+msgid ""
+"If the patch applies cleanly, the edited hunk will immediately be\n"
+"marked for applying."
+msgstr "如果修補檔能乾淨地套用，編輯塊將立即標記為應用。"
+
+#: git-add--interactive.perl:1065 git-add--interactive.perl:1068
+#: git-add--interactive.perl:1074
+msgid ""
+"If the patch applies cleanly, the edited hunk will immediately be\n"
+"marked for discarding."
+msgstr "如果修補檔能乾淨地套用，編輯塊將立即標記為捨棄。"
+
+#: git-add--interactive.perl:1111
+#, perl-format
+msgid "failed to open hunk edit file for writing: %s"
+msgstr "為寫入開啟區塊編輯檔案失敗：%s"
+
+#: git-add--interactive.perl:1118
+#, perl-format
+msgid ""
+"---\n"
+"To remove '%s' lines, make them ' ' lines (context).\n"
+"To remove '%s' lines, delete them.\n"
+"Lines starting with %s will be removed.\n"
+msgstr ""
+"---\n"
+"要刪除 '%s' 開始的行，使其成為 ' ' 開始的行（上下文）。\n"
+"要刪除 '%s' 開始的行，刪除它們。\n"
+"以 %s 開始的行將被刪除。\n"
+
+#: git-add--interactive.perl:1140
+#, perl-format
+msgid "failed to open hunk edit file for reading: %s"
+msgstr "無法讀取區塊編輯檔案：%s"
+
+#: git-add--interactive.perl:1248
+msgid ""
+"y - stage this hunk\n"
+"n - do not stage this hunk\n"
+"q - quit; do not stage this hunk or any of the remaining ones\n"
+"a - stage this hunk and all later hunks in the file\n"
+"d - do not stage this hunk or any of the later hunks in the file"
+msgstr ""
+"y - 暫存此區塊\n"
+"n - 不要暫存此區塊\n"
+"q - 離開。不暫存此區塊及後面的全部區塊\n"
+"a - 暫存此區塊和本檔案中後面的全部區塊\n"
+"d - 不暫存此區塊和本檔案中後面的全部區塊"
+
+#: git-add--interactive.perl:1254
+msgid ""
+"y - stash this hunk\n"
+"n - do not stash this hunk\n"
+"q - quit; do not stash this hunk or any of the remaining ones\n"
+"a - stash this hunk and all later hunks in the file\n"
+"d - do not stash this hunk or any of the later hunks in the file"
+msgstr ""
+"y - 儲藏此區塊\n"
+"n - 不要儲藏此區塊\n"
+"q - 離開。不儲藏此區塊及後面的全部區塊\n"
+"a - 儲藏此區塊和本檔案中後面的全部區塊\n"
+"d - 不儲藏此區塊和本檔案中後面的全部區塊"
+
+#: git-add--interactive.perl:1260
+msgid ""
+"y - unstage this hunk\n"
+"n - do not unstage this hunk\n"
+"q - quit; do not unstage this hunk or any of the remaining ones\n"
+"a - unstage this hunk and all later hunks in the file\n"
+"d - do not unstage this hunk or any of the later hunks in the file"
+msgstr ""
+"y - 不暫存此區塊\n"
+"n - 不要不暫存此區塊\n"
+"q - 離開。不要不暫存此區塊及後面的全部區塊\n"
+"a - 不暫存此區塊和本檔案中後面的全部區塊\n"
+"d - 不要不暫存此區塊和本檔案中後面的全部區塊"
+
+#: git-add--interactive.perl:1266
+msgid ""
+"y - apply this hunk to index\n"
+"n - do not apply this hunk to index\n"
+"q - quit; do not apply this hunk or any of the remaining ones\n"
+"a - apply this hunk and all later hunks in the file\n"
+"d - do not apply this hunk or any of the later hunks in the file"
+msgstr ""
+"y - 在索引中套用此區塊\n"
+"n - 不要在索引中套用此區塊\n"
+"q - 離開。不要套用此區塊及後面的全部區塊\n"
+"a - 套用此區塊和本檔案中後面的全部區塊\n"
+"d - 不要套用此區塊和本檔案中後面的全部區塊"
+
+#: git-add--interactive.perl:1272 git-add--interactive.perl:1290
+msgid ""
+"y - discard this hunk from worktree\n"
+"n - do not discard this hunk from worktree\n"
+"q - quit; do not discard this hunk or any of the remaining ones\n"
+"a - discard this hunk and all later hunks in the file\n"
+"d - do not discard this hunk or any of the later hunks in the file"
+msgstr ""
+"y - 在工作區中捨棄此區塊\n"
+"n - 不要在工作區中捨棄此區塊\n"
+"q - 離開。不要捨棄此區塊及後面的全部區塊\n"
+"a - 捨棄此區塊和本檔案中後面的全部區塊\n"
+"d - 不要捨棄此區塊和本檔案中後面的全部區塊"
+
+#: git-add--interactive.perl:1278
+msgid ""
+"y - discard this hunk from index and worktree\n"
+"n - do not discard this hunk from index and worktree\n"
+"q - quit; do not discard this hunk or any of the remaining ones\n"
+"a - discard this hunk and all later hunks in the file\n"
+"d - do not discard this hunk or any of the later hunks in the file"
+msgstr ""
+"y - 在索引和工作區中捨棄此區塊\n"
+"n - 不要在索引和工作區中捨棄此區塊\n"
+"q - 離開。不要捨棄此區塊及後面的全部區塊\n"
+"a - 捨棄此區塊和本檔案中後面的全部區塊\n"
+"d - 不要捨棄此區塊和本檔案中後面的全部區塊"
+
+#: git-add--interactive.perl:1284
+msgid ""
+"y - apply this hunk to index and worktree\n"
+"n - do not apply this hunk to index and worktree\n"
+"q - quit; do not apply this hunk or any of the remaining ones\n"
+"a - apply this hunk and all later hunks in the file\n"
+"d - do not apply this hunk or any of the later hunks in the file"
+msgstr ""
+"y - 在索引和工作區中套用此區塊\n"
+"n - 不要在索引和工作區中套用此區塊\n"
+"q - 離開。不要套用此區塊及後面的全部區塊\n"
+"a - 套用此區塊和本檔案中後面的全部區塊\n"
+"d - 不要套用此區塊和本檔案中後面的全部區塊"
+
+#: git-add--interactive.perl:1296
+msgid ""
+"y - apply this hunk to worktree\n"
+"n - do not apply this hunk to worktree\n"
+"q - quit; do not apply this hunk or any of the remaining ones\n"
+"a - apply this hunk and all later hunks in the file\n"
+"d - do not apply this hunk or any of the later hunks in the file"
+msgstr ""
+"y - 在工作區中套用此區塊\n"
+"n - 不要在工作區中套用此區塊\n"
+"q - 離開。不要套用此區塊及後面的全部區塊\n"
+"a - 套用此區塊和本檔案中後面的全部區塊\n"
+"d - 不要套用此區塊和本檔案中後面的全部區塊"
+
+#: git-add--interactive.perl:1311
+msgid ""
+"g - select a hunk to go to\n"
+"/ - search for a hunk matching the given regex\n"
+"j - leave this hunk undecided, see next undecided hunk\n"
+"J - leave this hunk undecided, see next hunk\n"
+"k - leave this hunk undecided, see previous undecided hunk\n"
+"K - leave this hunk undecided, see previous hunk\n"
+"s - split the current hunk into smaller hunks\n"
+"e - manually edit the current hunk\n"
+"? - print help\n"
+msgstr ""
+"g - 選擇跳轉到一個區塊\n"
+"/ - 尋找和提供正規表示式符合的區塊\n"
+"j - 維持此區塊未決狀態，檢視下一個未決定區塊\n"
+"J - 維持此區塊未決狀態，檢視下一個區塊\n"
+"k - 維持此區塊未決狀態，檢視上一個未決定區塊\n"
+"K - 維持此區塊未決狀態，檢視上一個區塊\n"
+"s - 分割目前區塊為更小的區塊\n"
+"e - 手動編輯目前區塊\n"
+"? - 顯示說明\n"
+
+#: git-add--interactive.perl:1342
+msgid "The selected hunks do not apply to the index!\n"
+msgstr "選中的區塊不能套用到索引！\n"
+
+#: git-add--interactive.perl:1343
+msgid "Apply them to the worktree anyway? "
+msgstr "無論如何都要套用到工作區嗎？"
+
+#: git-add--interactive.perl:1346
+msgid "Nothing was applied.\n"
+msgstr "未套用。\n"
+
+#: git-add--interactive.perl:1357
+#, perl-format
+msgid "ignoring unmerged: %s\n"
+msgstr "忽略未套用的：%s\n"
+
+#: git-add--interactive.perl:1428
+#, perl-format
+msgid "Stage mode change [y,n,q,a,d%s,?]? "
+msgstr "暫存模式變更 [y,n,q,a,d%s,?]? "
+
+#: git-add--interactive.perl:1429
+#, perl-format
+msgid "Stage deletion [y,n,q,a,d%s,?]? "
+msgstr "暫存刪除動作 [y,n,q,a,d%s,?]? "
+
+#: git-add--interactive.perl:1430
+#, perl-format
+msgid "Stage this hunk [y,n,q,a,d%s,?]? "
+msgstr "暫存此區塊 [y,n,q,a,d%s,?]? "
+
+#: git-add--interactive.perl:1433
+#, perl-format
+msgid "Stash mode change [y,n,q,a,d%s,?]? "
+msgstr "儲藏模式變更 [y,n,q,a,d%s,?]? "
+
+#: git-add--interactive.perl:1434
+#, perl-format
+msgid "Stash deletion [y,n,q,a,d%s,?]? "
+msgstr "儲藏刪除動作 [y,n,q,a,d%s,?]? "
+
+#: git-add--interactive.perl:1435
+#, perl-format
+msgid "Stash this hunk [y,n,q,a,d%s,?]? "
+msgstr "儲藏此區塊 [y,n,q,a,d%s,?]? "
+
+#: git-add--interactive.perl:1438
+#, perl-format
+msgid "Unstage mode change [y,n,q,a,d%s,?]? "
+msgstr "取消暫存模式變更 [y,n,q,a,d%s,?]? "
+
+#: git-add--interactive.perl:1439
+#, perl-format
+msgid "Unstage deletion [y,n,q,a,d%s,?]? "
+msgstr "取消暫存刪除動作 [y,n,q,a,d%s,?]? "
+
+#: git-add--interactive.perl:1440
+#, perl-format
+msgid "Unstage this hunk [y,n,q,a,d%s,?]? "
+msgstr "取消暫存此區塊 [y,n,q,a,d%s,?]? "
+
+#: git-add--interactive.perl:1443
+#, perl-format
+msgid "Apply mode change to index [y,n,q,a,d%s,?]? "
+msgstr "將模式變更套用到索引 [y,n,q,a,d%s,?]? "
+
+#: git-add--interactive.perl:1444
+#, perl-format
+msgid "Apply deletion to index [y,n,q,a,d%s,?]? "
+msgstr "將刪除動作套用到索引 [y,n,q,a,d%s,?]? "
+
+#: git-add--interactive.perl:1445
+#, perl-format
+msgid "Apply this hunk to index [y,n,q,a,d%s,?]? "
+msgstr "將此區塊套用到索引 [y,n,q,a,d%s,?]? "
+
+#: git-add--interactive.perl:1448 git-add--interactive.perl:1463
+#, perl-format
+msgid "Discard mode change from worktree [y,n,q,a,d%s,?]? "
+msgstr "從工作區中捨棄模式變更 [y,n,q,a,d%s,?]? "
+
+#: git-add--interactive.perl:1449 git-add--interactive.perl:1464
+#, perl-format
+msgid "Discard deletion from worktree [y,n,q,a,d%s,?]? "
+msgstr "從工作區中捨棄刪除動作 [y,n,q,a,d%s,?]? "
+
+#: git-add--interactive.perl:1450 git-add--interactive.perl:1465
+#, perl-format
+msgid "Discard this hunk from worktree [y,n,q,a,d%s,?]? "
+msgstr "從工作區中捨棄此區塊 [y,n,q,a,d%s,?]? "
+
+#: git-add--interactive.perl:1453
+#, perl-format
+msgid "Discard mode change from index and worktree [y,n,q,a,d%s,?]? "
+msgstr "從索引和工作區中捨棄模式變更 [y,n,q,a,d%s,?]? "
+
+#: git-add--interactive.perl:1454
+#, perl-format
+msgid "Discard deletion from index and worktree [y,n,q,a,d%s,?]? "
+msgstr "從索引和工作區中捨棄刪除 [y,n,q,a,d%s,?]? "
+
+#: git-add--interactive.perl:1455
+#, perl-format
+msgid "Discard this hunk from index and worktree [y,n,q,a,d%s,?]? "
+msgstr "從索引和工作區中捨棄此區塊 [y,n,q,a,d%s,?]? "
+
+#: git-add--interactive.perl:1458
+#, perl-format
+msgid "Apply mode change to index and worktree [y,n,q,a,d%s,?]? "
+msgstr "將模式變更套用到索引和工作區 [y,n,q,a,d%s,?]? "
+
+#: git-add--interactive.perl:1459
+#, perl-format
+msgid "Apply deletion to index and worktree [y,n,q,a,d%s,?]? "
+msgstr "將刪除動作套用到索引和工作區 [y,n,q,a,d%s,?]? "
+
+#: git-add--interactive.perl:1460
+#, perl-format
+msgid "Apply this hunk to index and worktree [y,n,q,a,d%s,?]? "
+msgstr "將此區塊套用到索引和工作區 [y,n,q,a,d%s,?]? "
+
+#: git-add--interactive.perl:1468
+#, perl-format
+msgid "Apply mode change to worktree [y,n,q,a,d%s,?]? "
+msgstr "將模式變更套用到工作區 [y,n,q,a,d%s,?]? "
+
+#: git-add--interactive.perl:1469
+#, perl-format
+msgid "Apply deletion to worktree [y,n,q,a,d%s,?]? "
+msgstr "將刪除動作套用到工作區 [y,n,q,a,d%s,?]? "
+
+#: git-add--interactive.perl:1470
+#, perl-format
+msgid "Apply this hunk to worktree [y,n,q,a,d%s,?]? "
+msgstr "將此區塊套用到工作區 [y,n,q,a,d%s,?]? "
+
+#: git-add--interactive.perl:1570
+msgid "No other hunks to goto\n"
+msgstr "沒有其它可供跳轉的區塊\n"
+
+#: git-add--interactive.perl:1588
+#, perl-format
+msgid "Invalid number: '%s'\n"
+msgstr "無效數字：'%s'\n"
+
+#: git-add--interactive.perl:1593
+#, perl-format
+msgid "Sorry, only %d hunk available.\n"
+msgid_plural "Sorry, only %d hunks available.\n"
+msgstr[0] "對不起，只有 %d 個可用區塊。\n"
+msgstr[1] "對不起，只有 %d 個可用區塊。\n"
+
+#: git-add--interactive.perl:1619
+msgid "No other hunks to search\n"
+msgstr "沒有其它可供尋找的區塊\n"
+
+#: git-add--interactive.perl:1636
+#, perl-format
+msgid "Malformed search regexp %s: %s\n"
+msgstr "錯誤的正規表示式 %s：%s\n"
+
+#: git-add--interactive.perl:1646
+msgid "No hunk matches the given pattern\n"
+msgstr "沒有和提供模式相符合的區塊\n"
+
+#: git-add--interactive.perl:1658 git-add--interactive.perl:1680
+msgid "No previous hunk\n"
+msgstr "沒有前一個區塊\n"
+
+#: git-add--interactive.perl:1667 git-add--interactive.perl:1686
+msgid "No next hunk\n"
+msgstr "沒有下一個區塊\n"
+
+#: git-add--interactive.perl:1692
+msgid "Sorry, cannot split this hunk\n"
+msgstr "對不起，不能分割這個區塊\n"
+
+#: git-add--interactive.perl:1698
+#, perl-format
+msgid "Split into %d hunk.\n"
+msgid_plural "Split into %d hunks.\n"
+msgstr[0] "分割為 %d 塊。\n"
+msgstr[1] "分割為 %d 塊。\n"
+
+#: git-add--interactive.perl:1708
+msgid "Sorry, cannot edit this hunk\n"
+msgstr "對不起，不能編輯這個區塊\n"
+
+#. TRANSLATORS: please do not translate the command names
+#. 'status', 'update', 'revert', etc.
+#: git-add--interactive.perl:1773
+msgid ""
+"status        - show paths with changes\n"
+"update        - add working tree state to the staged set of changes\n"
+"revert        - revert staged set of changes back to the HEAD version\n"
+"patch         - pick hunks and update selectively\n"
+"diff          - view diff between HEAD and index\n"
+"add untracked - add contents of untracked files to the staged set of "
+"changes\n"
+msgstr ""
+"status        - 顯示含變更的路徑\n"
+"update        - 新增工作區狀態至暫存列表\n"
+"revert        - 還原修改的暫存集至 HEAD 版本\n"
+"patch         - 挑選區塊並且有選擇地更新\n"
+"diff          - 顯示 HEAD 和索引間差異\n"
+"add untracked - 新增未追蹤檔案的內容至暫存列表\n"
+
+#: git-add--interactive.perl:1790 git-add--interactive.perl:1795
+#: git-add--interactive.perl:1798 git-add--interactive.perl:1805
+#: git-add--interactive.perl:1808 git-add--interactive.perl:1815
+#: git-add--interactive.perl:1819 git-add--interactive.perl:1825
+msgid "missing --"
+msgstr "缺少 --"
+
+#: git-add--interactive.perl:1821
+#, perl-format
+msgid "unknown --patch mode: %s"
+msgstr "未知的 --patch 模式：%s"
+
+#: git-add--interactive.perl:1827 git-add--interactive.perl:1833
+#, perl-format
+msgid "invalid argument %s, expecting --"
+msgstr "無效的參數 %s，期望是 --"
+
+#: git-send-email.perl:138
+msgid "local zone differs from GMT by a non-minute interval\n"
+msgstr "本機時間和 GMT 有不到一分鐘間隔\n"
+
+#: git-send-email.perl:145 git-send-email.perl:151
+msgid "local time offset greater than or equal to 24 hours\n"
+msgstr "本機時間位移量大於等於 24 小時\n"
+
+#: git-send-email.perl:223 git-send-email.perl:229
+msgid "the editor exited uncleanly, aborting everything"
+msgstr "編輯器非正常離開，終止所有動作"
+
+#: git-send-email.perl:310
+#, perl-format
+msgid ""
+"'%s' contains an intermediate version of the email you were composing.\n"
+msgstr "'%s' 包含您正在編寫的一個中間版本的信件。\n"
+
+#: git-send-email.perl:315
+#, perl-format
+msgid "'%s.final' contains the composed email.\n"
+msgstr "'%s.final' 包含編輯的信件。\n"
+
+#: git-send-email.perl:408
+msgid "--dump-aliases incompatible with other options\n"
+msgstr "--dump-aliases 和其它選項不相容\n"
+
+#: git-send-email.perl:481 git-send-email.perl:683
+msgid "Cannot run git format-patch from outside a repository\n"
+msgstr "不能在版本庫之外執行 git format-patch\n"
+
+#: git-send-email.perl:484
+msgid ""
+"`batch-size` and `relogin` must be specified together (via command-line or "
+"configuration option)\n"
+msgstr "`batch-size` 和 `relogin` 必須同時定義（透過指令列或者設定選項）\n"
+
+#: git-send-email.perl:497
+#, perl-format
+msgid "Unknown --suppress-cc field: '%s'\n"
+msgstr "未知的 --suppress-cc 欄位：'%s'\n"
+
+#: git-send-email.perl:528
+#, perl-format
+msgid "Unknown --confirm setting: '%s'\n"
+msgstr "未知的 --confirm 設定：'%s'\n"
+
+#: git-send-email.perl:556
+#, perl-format
+msgid "warning: sendmail alias with quotes is not supported: %s\n"
+msgstr "警告：不支援帶引號的 sendmail 別名：%s\n"
+
+#: git-send-email.perl:558
+#, perl-format
+msgid "warning: `:include:` not supported: %s\n"
+msgstr "警告：不支援 `:include:`：%s\n"
+
+#: git-send-email.perl:560
+#, perl-format
+msgid "warning: `/file` or `|pipe` redirection not supported: %s\n"
+msgstr "警告：不支援 `/file` 或 `|pipe` 重定向：%s\n"
+
+#: git-send-email.perl:565
+#, perl-format
+msgid "warning: sendmail line is not recognized: %s\n"
+msgstr "警告：不能識別的 sendmail 行：%s\n"
+
+#: git-send-email.perl:649
+#, perl-format
+msgid ""
+"File '%s' exists but it could also be the range of commits\n"
+"to produce patches for.  Please disambiguate by...\n"
+"\n"
+"    * Saying \"./%s\" if you mean a file; or\n"
+"    * Giving --format-patch option if you mean a range.\n"
+msgstr ""
+"存在檔案 '%s' 但是它也可能是一個用於產生修補檔列表的提交範圍。請用如下方法消"
+"除歧義：\n"
+"\n"
+"    * 如果含義為一個檔案，使用 \"./%s\"，或者\n"
+"    * 如果含義為一個範圍，使用 --format-patch 選項。\n"
+
+#: git-send-email.perl:670
+#, perl-format
+msgid "Failed to opendir %s: %s"
+msgstr "無法開啟目錄 %s: %s"
+
+#: git-send-email.perl:694
+#, perl-format
+msgid ""
+"fatal: %s: %s\n"
+"warning: no patches were sent\n"
+msgstr ""
+"致命錯誤：%s：%s\n"
+"警告：修補檔未能傳送\n"
+
+#: git-send-email.perl:705
+msgid ""
+"\n"
+"No patch files specified!\n"
+"\n"
+msgstr ""
+"\n"
+"未指定修補檔案！\n"
+"\n"
+
+#: git-send-email.perl:718
+#, perl-format
+msgid "No subject line in %s?"
+msgstr "在 %s 中沒有標題行？"
+
+#: git-send-email.perl:728
+#, perl-format
+msgid "Failed to open for writing %s: %s"
+msgstr "為寫入開啟 %s 失敗: %s"
+
+#: git-send-email.perl:739
+msgid ""
+"Lines beginning in \"GIT:\" will be removed.\n"
+"Consider including an overall diffstat or table of contents\n"
+"for the patch you are writing.\n"
+"\n"
+"Clear the body content if you don't wish to send a summary.\n"
+msgstr ""
+"以 \"GIT:\" 開頭的行將被刪除。\n"
+"考慮包含一個整體的差異統計或者您正在寫的修補檔的目錄。\n"
+"\n"
+"如果您不想傳送摘要，清除內容。\n"
+
+#: git-send-email.perl:763
+#, perl-format
+msgid "Failed to open %s: %s"
+msgstr "無法開啟 %s: %s"
+
+#: git-send-email.perl:780
+#, perl-format
+msgid "Failed to open %s.final: %s"
+msgstr "無法開啟 %s.final: %s"
+
+#: git-send-email.perl:823
+msgid "Summary email is empty, skipping it\n"
+msgstr "摘要信件為空，跳過\n"
+
+#. TRANSLATORS: please keep [y/N] as is.
+#: git-send-email.perl:858
+#, perl-format
+msgid "Are you sure you want to use <%s> [y/N]? "
+msgstr "您確認要使用 <%s> [y/N]？"
+
+#: git-send-email.perl:913
+msgid ""
+"The following files are 8bit, but do not declare a Content-Transfer-"
+"Encoding.\n"
+msgstr "如下檔案含 8bit 內容，但沒有聲明一個 Content-Transfer-Encoding。\n"
+
+#: git-send-email.perl:918
+msgid "Which 8bit encoding should I declare [UTF-8]? "
+msgstr "要聲明 8bit 為什麼樣的編碼格式 [UTF-8]？"
+
+#: git-send-email.perl:926
+#, perl-format
+msgid ""
+"Refusing to send because the patch\n"
+"\t%s\n"
+"has the template subject '*** SUBJECT HERE ***'. Pass --force if you really "
+"want to send.\n"
+msgstr ""
+"拒絕傳送，因為修補檔\n"
+"\t%s\n"
+"包含範本標題 '*** SUBJECT HERE ***'。如果確實想要傳送，使用參數 --force。\n"
+
+#: git-send-email.perl:945
+msgid "To whom should the emails be sent (if anyone)?"
+msgstr "信件將要傳送給誰？"
+
+#: git-send-email.perl:963
+#, perl-format
+msgid "fatal: alias '%s' expands to itself\n"
+msgstr "致命錯誤：別名 '%s' 擴展為它自己\n"
+
+#: git-send-email.perl:975
+msgid "Message-ID to be used as In-Reply-To for the first email (if any)? "
+msgstr "Message-ID 被用作第一封信件的 In-Reply-To ？"
+
+#: git-send-email.perl:1033 git-send-email.perl:1041
+#, perl-format
+msgid "error: unable to extract a valid address from: %s\n"
+msgstr "錯誤：不能從 %s 中擷取一個有效的信件位址\n"
+
+#. TRANSLATORS: Make sure to include [q] [d] [e] in your
+#. translation. The program will only accept English input
+#. at this point.
+#: git-send-email.perl:1045
+msgid "What to do with this address? ([q]uit|[d]rop|[e]dit): "
+msgstr "如何處理這個位址？([q]uit|[d]rop|[e]dit)："
+
+#: git-send-email.perl:1362
+#, perl-format
+msgid "CA path \"%s\" does not exist"
+msgstr "CA 路徑 \"%s\" 不存在"
+
+#: git-send-email.perl:1445
+msgid ""
+"    The Cc list above has been expanded by additional\n"
+"    addresses found in the patch commit message. By default\n"
+"    send-email prompts before sending whenever this occurs.\n"
+"    This behavior is controlled by the sendemail.confirm\n"
+"    configuration setting.\n"
+"\n"
+"    For additional information, run 'git send-email --help'.\n"
+"    To retain the current behavior, but squelch this message,\n"
+"    run 'git config --global sendemail.confirm auto'.\n"
+"\n"
+msgstr ""
+"    以上的抄送列表（Cc）已經用修補檔提交訊息中發現的位址進行\n"
+"    了擴展。預設 send-email 會給出提示。這個行為可以透過\n"
+"    sendemail.confirm 設定設定。\n"
+"\n"
+"    更多訊息，執行 'git send-email --help'。\n"
+"    要保持目前行為，但不顯示此訊息，執行 'git config --global\n"
+"    sendemail.confirm auto'。\n"
+"\n"
+
+#. TRANSLATORS: Make sure to include [y] [n] [e] [q] [a] in your
+#. translation. The program will only accept English input
+#. at this point.
+#: git-send-email.perl:1460
+msgid "Send this email? ([y]es|[n]o|[e]dit|[q]uit|[a]ll): "
+msgstr "傳送這封信件？([y]es|[n]o|[e]dit|[q]uit|[a]ll): "
+
+#: git-send-email.perl:1463
+msgid "Send this email reply required"
+msgstr "傳送要求的信件回復"
+
+#: git-send-email.perl:1491
+msgid "The required SMTP server is not properly defined."
+msgstr "要求的 SMTP 伺服器未被正確定義。"
+
+#: git-send-email.perl:1538
+#, perl-format
+msgid "Server does not support STARTTLS! %s"
+msgstr "伺服器不支援 STARTTLS！%s"
+
+#: git-send-email.perl:1543 git-send-email.perl:1547
+#, perl-format
+msgid "STARTTLS failed! %s"
+msgstr "STARTTLS 失敗！%s"
+
+#: git-send-email.perl:1556
+msgid "Unable to initialize SMTP properly. Check config and use --smtp-debug."
+msgstr "無法正確地初始化 SMTP。檢查設定並使用 --smtp-debug。"
+
+#: git-send-email.perl:1574
+#, perl-format
+msgid "Failed to send %s\n"
+msgstr "無法傳送 %s\n"
+
+#: git-send-email.perl:1577
+#, perl-format
+msgid "Dry-Sent %s\n"
+msgstr "測試執行傳送 %s\n"
+
+#: git-send-email.perl:1577
+#, perl-format
+msgid "Sent %s\n"
+msgstr "正傳送 %s\n"
+
+#: git-send-email.perl:1579
+msgid "Dry-OK. Log says:\n"
+msgstr "測試執行成功。日誌說：\n"
+
+#: git-send-email.perl:1579
+msgid "OK. Log says:\n"
+msgstr "OK。日誌說：\n"
+
+#: git-send-email.perl:1591
+msgid "Result: "
+msgstr "結果："
+
+#: git-send-email.perl:1594
+msgid "Result: OK\n"
+msgstr "結果：OK\n"
+
+#: git-send-email.perl:1612
+#, perl-format
+msgid "can't open file %s"
+msgstr "無法開啟檔案 %s"
+
+#: git-send-email.perl:1659 git-send-email.perl:1679
+#, perl-format
+msgid "(mbox) Adding cc: %s from line '%s'\n"
+msgstr "(mbox) 新增 cc：%s 自行 '%s'\n"
+
+#: git-send-email.perl:1665
+#, perl-format
+msgid "(mbox) Adding to: %s from line '%s'\n"
+msgstr "(mbox) 新增 to：%s 自行 '%s'\n"
+
+#: git-send-email.perl:1718
+#, perl-format
+msgid "(non-mbox) Adding cc: %s from line '%s'\n"
+msgstr "(non-mbox) 新增 cc：%s 自行 '%s'\n"
+
+#: git-send-email.perl:1753
+#, perl-format
+msgid "(body) Adding cc: %s from line '%s'\n"
+msgstr "(body) 新增 cc: %s 自行 '%s'\n"
+
+#: git-send-email.perl:1864
+#, perl-format
+msgid "(%s) Could not execute '%s'"
+msgstr "(%s) 不能執行 '%s'"
+
+#: git-send-email.perl:1871
+#, perl-format
+msgid "(%s) Adding %s: %s from: '%s'\n"
+msgstr "(%s) 新增 %s: %s 自：'%s'\n"
+
+#: git-send-email.perl:1875
+#, perl-format
+msgid "(%s) failed to close pipe to '%s'"
+msgstr "(%s) 無法關閉管道至 '%s'"
+
+#: git-send-email.perl:1905
+msgid "cannot send message as 7bit"
+msgstr "不能以 7bit 形式傳送訊息"
+
+#: git-send-email.perl:1913
+msgid "invalid transfer encoding"
+msgstr "無效的傳送編碼"
+
+#: git-send-email.perl:1954 git-send-email.perl:2006 git-send-email.perl:2016
+#, perl-format
+msgid "unable to open %s: %s\n"
+msgstr "不能開啟 %s：%s\n"
+
+#: git-send-email.perl:1957
+#, perl-format
+msgid "%s: patch contains a line longer than 998 characters"
+msgstr "%s：修補檔包含一個超過 998 字元的行"
+
+#: git-send-email.perl:1974
+#, perl-format
+msgid "Skipping %s with backup suffix '%s'.\n"
+msgstr "略過 %s 含備份後綴 '%s'。\n"
+
+#. TRANSLATORS: please keep "[y|N]" as is.
+#: git-send-email.perl:1978
+#, perl-format
+msgid "Do you really want to send %s? [y|N]: "
+msgstr "您真的要傳送 %s？[y|N]："
+
+#, c-format
+#~ msgid "unable to get tree for %s"
+#~ msgstr "無法得到 %s 的樹狀物件"
+
+#~ msgid "Use an experimental heuristic to improve diffs"
+#~ msgstr "使用一個實驗性的啟發式演算法改進差異顯示"
+
+#~ msgid "git commit-graph [--object-dir <objdir>]"
+#~ msgstr "git commit-graph [--object-dir <物件目錄>]"
+
+#~ msgid "git commit-graph read [--object-dir <objdir>]"
+#~ msgstr "git commit-graph read [--object-dir <物件目錄>]"
diff -pruN 1.2.1+git2.18.0-1/git/ppc/sha1.c 1.2.3+git2.25.1-1/git/ppc/sha1.c
--- 1.2.1+git2.18.0-1/git/ppc/sha1.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/ppc/sha1.c	2020-02-17 04:47:35.000000000 +0000
@@ -10,8 +10,8 @@
 #include <string.h>
 #include "sha1.h"
 
-extern void ppc_sha1_core(uint32_t *hash, const unsigned char *p,
-			  unsigned int nblocks);
+void ppc_sha1_core(uint32_t *hash, const unsigned char *p,
+		   unsigned int nblocks);
 
 int ppc_SHA1_Init(ppc_SHA_CTX *c)
 {
diff -pruN 1.2.1+git2.18.0-1/git/preload-index.c 1.2.3+git2.25.1-1/git/preload-index.c
--- 1.2.1+git2.18.0-1/git/preload-index.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/preload-index.c	2020-02-17 04:47:35.000000000 +0000
@@ -5,16 +5,10 @@
 #include "pathspec.h"
 #include "dir.h"
 #include "fsmonitor.h"
-
-#ifdef NO_PTHREADS
-static void preload_index(struct index_state *index,
-			  const struct pathspec *pathspec)
-{
-	; /* nothing */
-}
-#else
-
-#include <pthread.h>
+#include "config.h"
+#include "progress.h"
+#include "thread-utils.h"
+#include "repository.h"
 
 /*
  * Mostly randomly chosen maximum thread counts: we
@@ -25,16 +19,23 @@ static void preload_index(struct index_s
 #define MAX_PARALLEL (20)
 #define THREAD_COST (500)
 
+struct progress_data {
+	unsigned long n;
+	struct progress *progress;
+	pthread_mutex_t mutex;
+};
+
 struct thread_data {
 	pthread_t pthread;
 	struct index_state *index;
 	struct pathspec pathspec;
+	struct progress_data *progress;
 	int offset, nr;
 };
 
 static void *preload_thread(void *_data)
 {
-	int nr;
+	int nr, last_nr;
 	struct thread_data *p = _data;
 	struct index_state *index = p->index;
 	struct cache_entry **cep = index->cache + p->offset;
@@ -43,6 +44,7 @@ static void *preload_thread(void *_data)
 	nr = p->nr;
 	if (nr + p->offset > index->cache_nr)
 		nr = index->cache_nr - p->offset;
+	last_nr = nr;
 
 	do {
 		struct cache_entry *ce = *cep++;
@@ -58,7 +60,16 @@ static void *preload_thread(void *_data)
 			continue;
 		if (ce->ce_flags & CE_FSMONITOR_VALID)
 			continue;
-		if (!ce_path_match(ce, &p->pathspec, NULL))
+		if (p->progress && !(nr & 31)) {
+			struct progress_data *pd = p->progress;
+
+			pthread_mutex_lock(&pd->mutex);
+			pd->n += last_nr - nr;
+			display_progress(pd->progress, pd->n);
+			pthread_mutex_unlock(&pd->mutex);
+			last_nr = nr;
+		}
+		if (!ce_path_match(index, ce, &p->pathspec, NULL))
 			continue;
 		if (threaded_has_symlink_leading_path(&cache, ce->name, ce_namelen(ce)))
 			continue;
@@ -67,57 +78,81 @@ static void *preload_thread(void *_data)
 		if (ie_match_stat(index, ce, &st, CE_MATCH_RACY_IS_DIRTY|CE_MATCH_IGNORE_FSMONITOR))
 			continue;
 		ce_mark_uptodate(ce);
-		mark_fsmonitor_valid(ce);
+		mark_fsmonitor_valid(index, ce);
 	} while (--nr > 0);
+	if (p->progress) {
+		struct progress_data *pd = p->progress;
+
+		pthread_mutex_lock(&pd->mutex);
+		display_progress(pd->progress, pd->n + last_nr);
+		pthread_mutex_unlock(&pd->mutex);
+	}
 	cache_def_clear(&cache);
 	return NULL;
 }
 
-static void preload_index(struct index_state *index,
-			  const struct pathspec *pathspec)
+void preload_index(struct index_state *index,
+		   const struct pathspec *pathspec,
+		   unsigned int refresh_flags)
 {
 	int threads, i, work, offset;
 	struct thread_data data[MAX_PARALLEL];
-	uint64_t start = getnanotime();
+	struct progress_data pd;
 
-	if (!core_preload_index)
+	if (!HAVE_THREADS || !core_preload_index)
 		return;
 
 	threads = index->cache_nr / THREAD_COST;
-	if ((index->cache_nr > 1) && (threads < 2) && getenv("GIT_FORCE_PRELOAD_TEST"))
+	if ((index->cache_nr > 1) && (threads < 2) && git_env_bool("GIT_TEST_PRELOAD_INDEX", 0))
 		threads = 2;
 	if (threads < 2)
 		return;
+	trace_performance_enter();
 	if (threads > MAX_PARALLEL)
 		threads = MAX_PARALLEL;
 	offset = 0;
 	work = DIV_ROUND_UP(index->cache_nr, threads);
 	memset(&data, 0, sizeof(data));
+
+	memset(&pd, 0, sizeof(pd));
+	if (refresh_flags & REFRESH_PROGRESS && isatty(2)) {
+		pd.progress = start_delayed_progress(_("Refreshing index"), index->cache_nr);
+		pthread_mutex_init(&pd.mutex, NULL);
+	}
+
 	for (i = 0; i < threads; i++) {
 		struct thread_data *p = data+i;
+		int err;
+
 		p->index = index;
 		if (pathspec)
 			copy_pathspec(&p->pathspec, pathspec);
 		p->offset = offset;
 		p->nr = work;
+		if (pd.progress)
+			p->progress = &pd;
 		offset += work;
-		if (pthread_create(&p->pthread, NULL, preload_thread, p))
-			die("unable to create threaded lstat");
+		err = pthread_create(&p->pthread, NULL, preload_thread, p);
+
+		if (err)
+			die(_("unable to create threaded lstat: %s"), strerror(err));
 	}
 	for (i = 0; i < threads; i++) {
 		struct thread_data *p = data+i;
 		if (pthread_join(p->pthread, NULL))
 			die("unable to join threaded lstat");
 	}
-	trace_performance_since(start, "preload index");
+	stop_progress(&pd.progress);
+
+	trace_performance_leave("preload index");
 }
-#endif
 
-int read_index_preload(struct index_state *index,
-		       const struct pathspec *pathspec)
+int repo_read_index_preload(struct repository *repo,
+			    const struct pathspec *pathspec,
+			    unsigned int refresh_flags)
 {
-	int retval = read_index(index);
+	int retval = repo_read_index(repo);
 
-	preload_index(index, pathspec);
+	preload_index(repo->index, pathspec, refresh_flags);
 	return retval;
 }
diff -pruN 1.2.1+git2.18.0-1/git/pretty.c 1.2.3+git2.25.1-1/git/pretty.c
--- 1.2.1+git2.18.0-1/git/pretty.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/pretty.c	2020-02-17 04:47:35.000000000 +0000
@@ -20,6 +20,7 @@ static struct cmt_fmt_map {
 	int is_tformat;
 	int expand_tabs_in_log;
 	int is_alias;
+	enum date_mode_type default_date_mode_type;
 	const char *user_format;
 } *commit_formats;
 static size_t builtin_formats_len;
@@ -97,13 +98,19 @@ static void setup_commit_formats(void)
 		{ "mboxrd",	CMIT_FMT_MBOXRD,	0,	0 },
 		{ "fuller",	CMIT_FMT_FULLER,	0,	8 },
 		{ "full",	CMIT_FMT_FULL,		0,	8 },
-		{ "oneline",	CMIT_FMT_ONELINE,	1,	0 }
+		{ "oneline",	CMIT_FMT_ONELINE,	1,	0 },
+		{ "reference",	CMIT_FMT_USERFORMAT,	1,	0,
+			0, DATE_SHORT, "%C(auto)%h (%s, %ad)" },
+		/*
+		 * Please update $__git_log_pretty_formats in
+		 * git-completion.bash when you add new formats.
+		 */
 	};
 	commit_formats_len = ARRAY_SIZE(builtin_formats);
 	builtin_formats_len = commit_formats_len;
 	ALLOC_GROW(commit_formats, commit_formats_len, commit_formats_alloc);
-	memcpy(commit_formats, builtin_formats,
-	       sizeof(*builtin_formats)*ARRAY_SIZE(builtin_formats));
+	COPY_ARRAY(commit_formats, builtin_formats,
+		   ARRAY_SIZE(builtin_formats));
 
 	git_config(git_pretty_formats_config, NULL);
 }
@@ -177,6 +184,8 @@ void get_commit_format(const char *arg,
 	rev->commit_format = commit_format->format;
 	rev->use_terminator = commit_format->is_tformat;
 	rev->expand_tabs_in_log_default = commit_format->expand_tabs_in_log;
+	if (!rev->date_mode_explicit && commit_format->default_date_mode_type)
+		rev->date_mode.type = commit_format->default_date_mode_type;
 	if (commit_format->format == CMIT_FMT_USERFORMAT) {
 		save_user_format(rev, commit_format->user_format,
 				 commit_format->is_tformat);
@@ -339,8 +348,7 @@ static int is_rfc2047_special(char ch, e
 	return !(isalnum(ch) || ch == '!' || ch == '*' || ch == '+' || ch == '-' || ch == '/');
 }
 
-static int needs_rfc2047_encoding(const char *line, int len,
-				  enum rfc2047_type type)
+static int needs_rfc2047_encoding(const char *line, int len)
 {
 	int i;
 
@@ -466,7 +474,7 @@ void pp_user_info(struct pretty_print_co
 		}
 
 		strbuf_addstr(sb, "From: ");
-		if (needs_rfc2047_encoding(namebuf, namelen, RFC2047_ADDRESS)) {
+		if (needs_rfc2047_encoding(namebuf, namelen)) {
 			add_rfc2047(sb, namebuf, namelen,
 				    encoding, RFC2047_ADDRESS);
 			max_length = 76; /* per rfc2047 */
@@ -595,14 +603,15 @@ static char *replace_encoding_header(cha
 	return strbuf_detach(&tmp, NULL);
 }
 
-const char *logmsg_reencode(const struct commit *commit,
-			    char **commit_encoding,
-			    const char *output_encoding)
+const char *repo_logmsg_reencode(struct repository *r,
+				 const struct commit *commit,
+				 char **commit_encoding,
+				 const char *output_encoding)
 {
 	static const char *utf8 = "UTF-8";
 	const char *use_encoding;
 	char *encoding;
-	const char *msg = get_commit_buffer(commit, NULL);
+	const char *msg = repo_get_commit_buffer(r, commit, NULL);
 	char *out;
 
 	if (!output_encoding || !*output_encoding) {
@@ -630,7 +639,7 @@ const char *logmsg_reencode(const struct
 		 * the cached copy from get_commit_buffer, we need to duplicate it
 		 * to avoid munging the cached copy.
 		 */
-		if (msg == get_cached_commit_buffer(commit, NULL))
+		if (msg == get_cached_commit_buffer(r, commit, NULL))
 			out = xstrdup(msg);
 		else
 			out = (char *)msg;
@@ -644,7 +653,7 @@ const char *logmsg_reencode(const struct
 		 */
 		out = reencode_string(msg, output_encoding, use_encoding);
 		if (out)
-			unuse_commit_buffer(commit, msg);
+			repo_unuse_commit_buffer(r, commit, msg);
 	}
 
 	/*
@@ -692,7 +701,7 @@ static size_t format_person_part(struct
 	mail = s.mail_begin;
 	maillen = s.mail_end - s.mail_begin;
 
-	if (part == 'N' || part == 'E') /* mailmap lookup */
+	if (part == 'N' || part == 'E' || part == 'L') /* mailmap lookup */
 		mailmap_name(&mail, &maillen, &name, &namelen);
 	if (part == 'n' || part == 'N') {	/* name */
 		strbuf_add(sb, name, namelen);
@@ -702,6 +711,13 @@ static size_t format_person_part(struct
 		strbuf_add(sb, mail, maillen);
 		return placeholder_len;
 	}
+	if (part == 'l' || part == 'L') {	/* local-part */
+		const char *at = memchr(mail, '@', maillen);
+		if (at)
+			maillen = at - mail;
+		strbuf_add(sb, mail, maillen);
+		return placeholder_len;
+	}
 
 	if (!s.date_begin)
 		goto skip;
@@ -727,6 +743,9 @@ static size_t format_person_part(struct
 	case 'I':	/* date, ISO 8601 strict */
 		strbuf_addstr(sb, show_ident_date(&s, DATE_MODE(ISO8601_STRICT)));
 		return placeholder_len;
+	case 's':
+		strbuf_addstr(sb, show_ident_date(&s, DATE_MODE(SHORT)));
+		return placeholder_len;
 	}
 
 skip:
@@ -984,8 +1003,7 @@ static size_t parse_color(struct strbuf
 	return rest - placeholder;
 }
 
-static size_t parse_padding_placeholder(struct strbuf *sb,
-					const char *placeholder,
+static size_t parse_padding_placeholder(const char *placeholder,
 					struct format_commit_context *c)
 {
 	const char *ch = placeholder;
@@ -1056,13 +1074,26 @@ static size_t parse_padding_placeholder(
 	return 0;
 }
 
-static int match_placeholder_arg(const char *to_parse, const char *candidate,
-				 const char **end)
+static int match_placeholder_arg_value(const char *to_parse, const char *candidate,
+				       const char **end, const char **valuestart,
+				       size_t *valuelen)
 {
 	const char *p;
 
 	if (!(skip_prefix(to_parse, candidate, &p)))
 		return 0;
+	if (valuestart) {
+		if (*p == '=') {
+			*valuestart = p + 1;
+			*valuelen = strcspn(*valuestart, ",)");
+			p = *valuestart + *valuelen;
+		} else {
+			if (*p != ',' && *p != ')')
+				return 0;
+			*valuestart = NULL;
+			*valuelen = 0;
+		}
+	}
 	if (*p == ',') {
 		*end = p + 1;
 		return 1;
@@ -1074,6 +1105,47 @@ static int match_placeholder_arg(const c
 	return 0;
 }
 
+static int match_placeholder_bool_arg(const char *to_parse, const char *candidate,
+				      const char **end, int *val)
+{
+	const char *argval;
+	char *strval;
+	size_t arglen;
+	int v;
+
+	if (!match_placeholder_arg_value(to_parse, candidate, end, &argval, &arglen))
+		return 0;
+
+	if (!argval) {
+		*val = 1;
+		return 1;
+	}
+
+	strval = xstrndup(argval, arglen);
+	v = git_parse_maybe_bool(strval);
+	free(strval);
+
+	if (v == -1)
+		return 0;
+
+	*val = v;
+
+	return 1;
+}
+
+static int format_trailer_match_cb(const struct strbuf *key, void *ud)
+{
+	const struct string_list *list = ud;
+	const struct string_list_item *item;
+
+	for_each_string_list_item (item, list) {
+		if (key->len == (uintptr_t)item->util &&
+		    !strncasecmp(item->string, key->buf, key->len))
+			return 1;
+	}
+	return 0;
+}
+
 static size_t format_commit_one(struct strbuf *sb, /* in UTF-8 */
 				const char *placeholder,
 				void *context)
@@ -1083,9 +1155,14 @@ static size_t format_commit_one(struct s
 	const char *msg = c->message;
 	struct commit_list *p;
 	const char *arg;
-	int ch;
+	size_t res;
+	char **slot;
 
 	/* these are independent of the commit */
+	res = strbuf_expand_literal_cb(sb, placeholder, NULL);
+	if (res)
+		return res;
+
 	switch (placeholder[0]) {
 	case 'C':
 		if (starts_with(placeholder + 1, "(auto)")) {
@@ -1104,16 +1181,6 @@ static size_t format_commit_one(struct s
 			 */
 			return ret;
 		}
-	case 'n':		/* newline */
-		strbuf_addch(sb, '\n');
-		return 1;
-	case 'x':
-		/* %x00 == NUL, %x0a == LF, etc. */
-		ch = hex2chr(placeholder + 1);
-		if (ch < 0)
-			return 0;
-		strbuf_addch(sb, ch);
-		return 3;
 	case 'w':
 		if (placeholder[1] == '(') {
 			unsigned long width = 0, indent1 = 0, indent2 = 0;
@@ -1141,12 +1208,12 @@ static size_t format_commit_one(struct s
 
 	case '<':
 	case '>':
-		return parse_padding_placeholder(sb, placeholder, c);
+		return parse_padding_placeholder(placeholder, c);
 	}
 
 	/* these depend on the commit */
 	if (!commit->object.parsed)
-		parse_object(&commit->object.oid);
+		parse_object(the_repository, &commit->object.oid);
 
 	switch (placeholder[0]) {
 	case 'H':		/* commit hash */
@@ -1187,13 +1254,19 @@ static size_t format_commit_one(struct s
 		strbuf_addstr(sb, get_revision_mark(NULL, commit));
 		return 1;
 	case 'd':
-		load_ref_decorations(NULL, DECORATE_SHORT_REFS);
 		format_decorations(sb, commit, c->auto_color);
 		return 1;
 	case 'D':
-		load_ref_decorations(NULL, DECORATE_SHORT_REFS);
 		format_decorations_extended(sb, commit, c->auto_color, "", ", ", "");
 		return 1;
+	case 'S':		/* tag/branch like --source */
+		if (!(c->pretty_ctx->rev && c->pretty_ctx->rev->sources))
+			return 0;
+		slot = revision_sources_at(c->pretty_ctx->rev->sources, commit);
+		if (!(slot && *slot))
+			return 0;
+		strbuf_addstr(sb, *slot);
+		return 1;
 	case 'g':		/* reflog info */
 		switch(placeholder[1]) {
 		case 'd':	/* reflog selector */
@@ -1256,6 +1329,14 @@ static size_t format_commit_one(struct s
 			if (c->signature_check.key)
 				strbuf_addstr(sb, c->signature_check.key);
 			break;
+		case 'F':
+			if (c->signature_check.fingerprint)
+				strbuf_addstr(sb, c->signature_check.fingerprint);
+			break;
+		case 'P':
+			if (c->signature_check.primary_key_fingerprint)
+				strbuf_addstr(sb, c->signature_check.primary_key_fingerprint);
+			break;
 		default:
 			return 0;
 		}
@@ -1304,21 +1385,53 @@ static size_t format_commit_one(struct s
 
 	if (skip_prefix(placeholder, "(trailers", &arg)) {
 		struct process_trailer_options opts = PROCESS_TRAILER_OPTIONS_INIT;
+		struct string_list filter_list = STRING_LIST_INIT_NODUP;
+		struct strbuf sepbuf = STRBUF_INIT;
+		size_t ret = 0;
+
+		opts.no_divider = 1;
+
 		if (*arg == ':') {
 			arg++;
 			for (;;) {
-				if (match_placeholder_arg(arg, "only", &arg))
+				const char *argval;
+				size_t arglen;
+
+				if (match_placeholder_arg_value(arg, "key", &arg, &argval, &arglen)) {
+					uintptr_t len = arglen;
+
+					if (!argval)
+						goto trailer_out;
+
+					if (len && argval[len - 1] == ':')
+						len--;
+					string_list_append(&filter_list, argval)->util = (char *)len;
+
+					opts.filter = format_trailer_match_cb;
+					opts.filter_data = &filter_list;
 					opts.only_trailers = 1;
-				else if (match_placeholder_arg(arg, "unfold", &arg))
-					opts.unfold = 1;
-				else
+				} else if (match_placeholder_arg_value(arg, "separator", &arg, &argval, &arglen)) {
+					char *fmt;
+
+					strbuf_reset(&sepbuf);
+					fmt = xstrndup(argval, arglen);
+					strbuf_expand(&sepbuf, fmt, strbuf_expand_literal_cb, NULL);
+					free(fmt);
+					opts.separator = &sepbuf;
+				} else if (!match_placeholder_bool_arg(arg, "only", &arg, &opts.only_trailers) &&
+					   !match_placeholder_bool_arg(arg, "unfold", &arg, &opts.unfold) &&
+					   !match_placeholder_bool_arg(arg, "valueonly", &arg, &opts.value_only))
 					break;
 			}
 		}
 		if (*arg == ')') {
 			format_trailers_from_commit(sb, msg + c->subject_off, &opts);
-			return arg - placeholder + 1;
+			ret = arg - placeholder + 1;
 		}
+	trailer_out:
+		string_list_clear(&filter_list, 0);
+		strbuf_release(&sepbuf);
+		return ret;
 	}
 
 	return 0;	/* unknown placeholder */
@@ -1487,6 +1600,9 @@ static size_t userformat_want_item(struc
 	case 'N':
 		w->notes = 1;
 		break;
+	case 'S':
+		w->source = 1;
+		break;
 	}
 	return 0;
 }
@@ -1504,25 +1620,26 @@ void userformat_find_requirements(const
 	strbuf_release(&dummy);
 }
 
-void format_commit_message(const struct commit *commit,
-			   const char *format, struct strbuf *sb,
-			   const struct pretty_print_context *pretty_ctx)
-{
-	struct format_commit_context context;
+void repo_format_commit_message(struct repository *r,
+				const struct commit *commit,
+				const char *format, struct strbuf *sb,
+				const struct pretty_print_context *pretty_ctx)
+{
+	struct format_commit_context context = {
+		.commit = commit,
+		.pretty_ctx = pretty_ctx,
+		.wrap_start = sb->len
+	};
 	const char *output_enc = pretty_ctx->output_encoding;
 	const char *utf8 = "UTF-8";
 
-	memset(&context, 0, sizeof(context));
-	context.commit = commit;
-	context.pretty_ctx = pretty_ctx;
-	context.wrap_start = sb->len;
 	/*
 	 * convert a commit message to UTF-8 first
 	 * as far as 'format_commit_item' assumes it in UTF-8
 	 */
-	context.message = logmsg_reencode(commit,
-					  &context.commit_encoding,
-					  utf8);
+	context.message = repo_logmsg_reencode(r, commit,
+					       &context.commit_encoding,
+					       utf8);
 
 	strbuf_expand(sb, format, format_commit_item, &context);
 	rewrap_message_tail(sb, &context, 0, 0, 0);
@@ -1538,7 +1655,7 @@ void format_commit_message(const struct
 	}
 
 	if (output_enc) {
-		int outsz;
+		size_t outsz;
 		char *out = reencode_string_len(sb->buf, sb->len,
 						output_enc, utf8, &outsz);
 		if (out)
@@ -1546,7 +1663,7 @@ void format_commit_message(const struct
 	}
 
 	free(context.commit_encoding);
-	unuse_commit_buffer(commit, context.message);
+	repo_unuse_commit_buffer(r, commit, context.message);
 }
 
 static void pp_header(struct pretty_print_context *pp,
@@ -1575,7 +1692,7 @@ static void pp_header(struct pretty_prin
 		}
 
 		if (starts_with(line, "parent ")) {
-			if (linelen != 48)
+			if (linelen != the_hash_algo->hexsz + 8)
 				die("bad parent line in commit");
 			continue;
 		}
@@ -1583,7 +1700,7 @@ static void pp_header(struct pretty_prin
 		if (!parents_shown) {
 			unsigned num = commit_list_count(commit->parents);
 			/* with enough slop */
-			strbuf_grow(sb, num * 50 + 20);
+			strbuf_grow(sb, num * (GIT_MAX_HEXSZ + 10) + 20);
 			add_merge_info(pp, sb, commit);
 			parents_shown = 1;
 		}
@@ -1622,7 +1739,7 @@ void pp_title_line(struct pretty_print_c
 	if (pp->print_email_subject) {
 		if (pp->rev)
 			fmt_output_email_subject(sb, pp->rev);
-		if (needs_rfc2047_encoding(title.buf, title.len, RFC2047_SUBJECT))
+		if (needs_rfc2047_encoding(title.buf, title.len))
 			add_rfc2047(sb, title.buf, title.len,
 						encoding, RFC2047_SUBJECT);
 		else
diff -pruN 1.2.1+git2.18.0-1/git/pretty.h 1.2.3+git2.25.1-1/git/pretty.h
--- 1.2.1+git2.18.0-1/git/pretty.h	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/pretty.h	2020-02-17 04:47:35.000000000 +0000
@@ -1,7 +1,11 @@
 #ifndef PRETTY_H
 #define PRETTY_H
 
+#include "cache.h"
+#include "string-list.h"
+
 struct commit;
+struct strbuf;
 
 /* Commit formats */
 enum cmit_fmt {
@@ -56,6 +60,7 @@ static inline int cmit_fmt_is_mail(enum
 
 struct userformat_want {
 	unsigned notes:1;
+	unsigned source:1;
 };
 
 /* Set the flag "w->notes" if there is placeholder %N in "fmt". */
@@ -99,9 +104,14 @@ void pp_remainder(struct pretty_print_co
  * Put the result to "sb".
  * Please use this function for custom formats.
  */
-void format_commit_message(const struct commit *commit,
+void repo_format_commit_message(struct repository *r,
+			const struct commit *commit,
 			const char *format, struct strbuf *sb,
 			const struct pretty_print_context *context);
+#ifndef NO_THE_REPOSITORY_COMPATIBILITY_MACROS
+#define format_commit_message(c, f, s, con) \
+	repo_format_commit_message(the_repository, c, f, s, con)
+#endif
 
 /*
  * Parse given arguments from "arg", check it for correctness and
diff -pruN 1.2.1+git2.18.0-1/git/prio-queue.c 1.2.3+git2.25.1-1/git/prio-queue.c
--- 1.2.1+git2.18.0-1/git/prio-queue.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/prio-queue.c	2020-02-17 04:47:35.000000000 +0000
@@ -85,3 +85,12 @@ void *prio_queue_get(struct prio_queue *
 	}
 	return result;
 }
+
+void *prio_queue_peek(struct prio_queue *queue)
+{
+	if (!queue->nr)
+		return NULL;
+	if (!queue->compare)
+		return queue->array[queue->nr - 1].data;
+	return queue->array[0].data;
+}
diff -pruN 1.2.1+git2.18.0-1/git/prio-queue.h 1.2.3+git2.25.1-1/git/prio-queue.h
--- 1.2.1+git2.18.0-1/git/prio-queue.h	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/prio-queue.h	2020-02-17 04:47:35.000000000 +0000
@@ -37,18 +37,24 @@ struct prio_queue {
 /*
  * Add the "thing" to the queue.
  */
-extern void prio_queue_put(struct prio_queue *, void *thing);
+void prio_queue_put(struct prio_queue *, void *thing);
 
 /*
  * Extract the "thing" that compares the smallest out of the queue,
  * or NULL.  If compare function is NULL, the queue acts as a LIFO
  * stack.
  */
-extern void *prio_queue_get(struct prio_queue *);
+void *prio_queue_get(struct prio_queue *);
 
-extern void clear_prio_queue(struct prio_queue *);
+/*
+ * Gain access to the "thing" that would be returned by
+ * prio_queue_get, but do not remove it from the queue.
+ */
+void *prio_queue_peek(struct prio_queue *);
+
+void clear_prio_queue(struct prio_queue *);
 
 /* Reverse the LIFO elements */
-extern void prio_queue_reverse(struct prio_queue *);
+void prio_queue_reverse(struct prio_queue *);
 
 #endif /* PRIO_QUEUE_H */
diff -pruN 1.2.1+git2.18.0-1/git/progress.c 1.2.3+git2.25.1-1/git/progress.c
--- 1.2.1+git2.18.0-1/git/progress.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/progress.c	2020-02-17 04:47:35.000000000 +0000
@@ -8,11 +8,13 @@
  * published by the Free Software Foundation.
  */
 
-#include "git-compat-util.h"
+#include "cache.h"
 #include "gettext.h"
 #include "progress.h"
 #include "strbuf.h"
 #include "trace.h"
+#include "utf8.h"
+#include "config.h"
 
 #define TP_IDX_MAX      8
 
@@ -34,12 +36,29 @@ struct progress {
 	uint64_t total;
 	unsigned last_percent;
 	unsigned delay;
+	unsigned sparse;
 	struct throughput *throughput;
 	uint64_t start_ns;
+	struct strbuf counters_sb;
+	int title_len;
+	int split;
 };
 
 static volatile sig_atomic_t progress_update;
 
+/*
+ * These are only intended for testing the progress output, i.e. exclusively
+ * for 'test-tool progress'.
+ */
+int progress_testing;
+uint64_t progress_test_ns = 0;
+void progress_test_force_update(void); /* To silence -Wmissing-prototypes */
+void progress_test_force_update(void)
+{
+	progress_update = 1;
+}
+
+
 static void progress_interval(int signum)
 {
 	progress_update = 1;
@@ -50,6 +69,9 @@ static void set_progress_signal(void)
 	struct sigaction sa;
 	struct itimerval v;
 
+	if (progress_testing)
+		return;
+
 	progress_update = 0;
 
 	memset(&sa, 0, sizeof(sa));
@@ -67,6 +89,10 @@ static void set_progress_signal(void)
 static void clear_progress_signal(void)
 {
 	struct itimerval v = {{0,},};
+
+	if (progress_testing)
+		return;
+
 	setitimer(ITIMER_REAL, &v, NULL);
 	signal(SIGALRM, SIG_IGN);
 	progress_update = 0;
@@ -78,41 +104,65 @@ static int is_foreground_fd(int fd)
 	return tpgrp < 0 || tpgrp == getpgid(0);
 }
 
-static int display(struct progress *progress, uint64_t n, const char *done)
+static void display(struct progress *progress, uint64_t n, const char *done)
 {
-	const char *eol, *tp;
+	const char *tp;
+	struct strbuf *counters_sb = &progress->counters_sb;
+	int show_update = 0;
+	int last_count_len = counters_sb->len;
 
 	if (progress->delay && (!progress_update || --progress->delay))
-		return 0;
+		return;
 
 	progress->last_value = n;
 	tp = (progress->throughput) ? progress->throughput->display.buf : "";
-	eol = done ? done : "   \r";
 	if (progress->total) {
 		unsigned percent = n * 100 / progress->total;
 		if (percent != progress->last_percent || progress_update) {
 			progress->last_percent = percent;
-			if (is_foreground_fd(fileno(stderr)) || done) {
-				fprintf(stderr, "%s: %3u%% (%"PRIuMAX"/%"PRIuMAX")%s%s",
-					progress->title, percent,
-					(uintmax_t)n, (uintmax_t)progress->total,
-					tp, eol);
-				fflush(stderr);
-			}
-			progress_update = 0;
-			return 1;
+
+			strbuf_reset(counters_sb);
+			strbuf_addf(counters_sb,
+				    "%3u%% (%"PRIuMAX"/%"PRIuMAX")%s", percent,
+				    (uintmax_t)n, (uintmax_t)progress->total,
+				    tp);
+			show_update = 1;
 		}
 	} else if (progress_update) {
+		strbuf_reset(counters_sb);
+		strbuf_addf(counters_sb, "%"PRIuMAX"%s", (uintmax_t)n, tp);
+		show_update = 1;
+	}
+
+	if (show_update) {
 		if (is_foreground_fd(fileno(stderr)) || done) {
-			fprintf(stderr, "%s: %"PRIuMAX"%s%s",
-				progress->title, (uintmax_t)n, tp, eol);
+			const char *eol = done ? done : "\r";
+			size_t clear_len = counters_sb->len < last_count_len ?
+					last_count_len - counters_sb->len + 1 :
+					0;
+			/* The "+ 2" accounts for the ": ". */
+			size_t progress_line_len = progress->title_len +
+						counters_sb->len + 2;
+			int cols = term_columns();
+
+			if (progress->split) {
+				fprintf(stderr, "  %s%*s", counters_sb->buf,
+					(int) clear_len, eol);
+			} else if (!done && cols < progress_line_len) {
+				clear_len = progress->title_len + 1 < cols ?
+					    cols - progress->title_len - 1 : 0;
+				fprintf(stderr, "%s:%*s\n  %s%s",
+					progress->title, (int) clear_len, "",
+					counters_sb->buf, eol);
+				progress->split = 1;
+			} else {
+				fprintf(stderr, "%s: %s%*s", progress->title,
+					counters_sb->buf, (int) clear_len, eol);
+			}
 			fflush(stderr);
 		}
 		progress_update = 0;
-		return 1;
 	}
-
-	return 0;
 }
 
 static void throughput_string(struct strbuf *buf, uint64_t total,
@@ -122,8 +172,15 @@ static void throughput_string(struct str
 	strbuf_addstr(buf, ", ");
 	strbuf_humanise_bytes(buf, total);
 	strbuf_addstr(buf, " | ");
-	strbuf_humanise_bytes(buf, rate * 1024);
-	strbuf_addstr(buf, "/s");
+	strbuf_humanise_rate(buf, rate * 1024);
+}
+
+static uint64_t progress_getnanotime(struct progress *progress)
+{
+	if (progress_testing)
+		return progress->start_ns + progress_test_ns;
+	else
+		return getnanotime();
 }
 
 void display_throughput(struct progress *progress, uint64_t total)
@@ -136,15 +193,13 @@ void display_throughput(struct progress
 		return;
 	tp = progress->throughput;
 
-	now_ns = getnanotime();
+	now_ns = progress_getnanotime(progress);
 
 	if (!tp) {
-		progress->throughput = tp = calloc(1, sizeof(*tp));
-		if (tp) {
-			tp->prev_total = tp->curr_total = total;
-			tp->prev_ns = now_ns;
-			strbuf_init(&tp->display, 0);
-		}
+		progress->throughput = tp = xcalloc(1, sizeof(*tp));
+		tp->prev_total = tp->curr_total = total;
+		tp->prev_ns = now_ns;
+		strbuf_init(&tp->display, 0);
 		return;
 	}
 	tp->curr_total = total;
@@ -188,44 +243,83 @@ void display_throughput(struct progress
 		display(progress, progress->last_value, NULL);
 }
 
-int display_progress(struct progress *progress, uint64_t n)
+void display_progress(struct progress *progress, uint64_t n)
 {
-	return progress ? display(progress, n, NULL) : 0;
+	if (progress)
+		display(progress, n, NULL);
 }
 
 static struct progress *start_progress_delay(const char *title, uint64_t total,
-					     unsigned delay)
+					     unsigned delay, unsigned sparse)
 {
-	struct progress *progress = malloc(sizeof(*progress));
-	if (!progress) {
-		/* unlikely, but here's a good fallback */
-		fprintf(stderr, "%s...\n", title);
-		fflush(stderr);
-		return NULL;
-	}
+	struct progress *progress = xmalloc(sizeof(*progress));
 	progress->title = title;
 	progress->total = total;
 	progress->last_value = -1;
 	progress->last_percent = -1;
 	progress->delay = delay;
+	progress->sparse = sparse;
 	progress->throughput = NULL;
 	progress->start_ns = getnanotime();
+	strbuf_init(&progress->counters_sb, 0);
+	progress->title_len = utf8_strwidth(title);
+	progress->split = 0;
 	set_progress_signal();
 	return progress;
 }
 
+static int get_default_delay(void)
+{
+	static int delay_in_secs = -1;
+
+	if (delay_in_secs < 0)
+		delay_in_secs = git_env_ulong("GIT_PROGRESS_DELAY", 2);
+
+	return delay_in_secs;
+}
+
 struct progress *start_delayed_progress(const char *title, uint64_t total)
 {
-	return start_progress_delay(title, total, 2);
+	return start_progress_delay(title, total, get_default_delay(), 0);
 }
 
 struct progress *start_progress(const char *title, uint64_t total)
 {
-	return start_progress_delay(title, total, 0);
+	return start_progress_delay(title, total, 0, 0);
+}
+
+/*
+ * Here "sparse" means that the caller might use some sampling criteria to
+ * decide when to call display_progress() rather than calling it for every
+ * integer value in[0 .. total).  In particular, the caller might not call
+ * display_progress() for the last value in the range.
+ *
+ * When "sparse" is set, stop_progress() will automatically force the done
+ * message to show 100%.
+ */
+struct progress *start_sparse_progress(const char *title, uint64_t total)
+{
+	return start_progress_delay(title, total, 0, 1);
+}
+
+struct progress *start_delayed_sparse_progress(const char *title,
+					       uint64_t total)
+{
+	return start_progress_delay(title, total, get_default_delay(), 1);
+}
+
+static void finish_if_sparse(struct progress *progress)
+{
+	if (progress &&
+	    progress->sparse &&
+	    progress->last_value != progress->total)
+		display_progress(progress, progress->total);
 }
 
 void stop_progress(struct progress **p_progress)
 {
+	finish_if_sparse(*p_progress);
+
 	stop_progress_msg(p_progress, _("done"));
 }
 
@@ -241,7 +335,7 @@ void stop_progress_msg(struct progress *
 		struct throughput *tp = progress->throughput;
 
 		if (tp) {
-			uint64_t now_ns = getnanotime();
+			uint64_t now_ns = progress_getnanotime(progress);
 			unsigned int misecs, rate;
 			misecs = ((now_ns - progress->start_ns) * 4398) >> 32;
 			rate = tp->curr_total / (misecs ? misecs : 1);
@@ -253,6 +347,7 @@ void stop_progress_msg(struct progress *
 		free(buf);
 	}
 	clear_progress_signal();
+	strbuf_release(&progress->counters_sb);
 	if (progress->throughput)
 		strbuf_release(&progress->throughput->display);
 	free(progress->throughput);
diff -pruN 1.2.1+git2.18.0-1/git/progress.h 1.2.3+git2.25.1-1/git/progress.h
--- 1.2.1+git2.18.0-1/git/progress.h	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/progress.h	2020-02-17 04:47:35.000000000 +0000
@@ -4,9 +4,12 @@
 struct progress;
 
 void display_throughput(struct progress *progress, uint64_t total);
-int display_progress(struct progress *progress, uint64_t n);
+void display_progress(struct progress *progress, uint64_t n);
 struct progress *start_progress(const char *title, uint64_t total);
+struct progress *start_sparse_progress(const char *title, uint64_t total);
 struct progress *start_delayed_progress(const char *title, uint64_t total);
+struct progress *start_delayed_sparse_progress(const char *title,
+					       uint64_t total);
 void stop_progress(struct progress **progress);
 void stop_progress_msg(struct progress **progress, const char *msg);
 
diff -pruN 1.2.1+git2.18.0-1/git/promisor-remote.c 1.2.3+git2.25.1-1/git/promisor-remote.c
--- 1.2.1+git2.18.0-1/git/promisor-remote.c	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/promisor-remote.c	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,265 @@
+#include "cache.h"
+#include "object-store.h"
+#include "promisor-remote.h"
+#include "config.h"
+#include "transport.h"
+
+static char *repository_format_partial_clone;
+static const char *core_partial_clone_filter_default;
+
+void set_repository_format_partial_clone(char *partial_clone)
+{
+	repository_format_partial_clone = xstrdup_or_null(partial_clone);
+}
+
+static int fetch_refs(const char *remote_name, struct ref *ref)
+{
+	struct remote *remote;
+	struct transport *transport;
+	int res;
+
+	remote = remote_get(remote_name);
+	if (!remote->url[0])
+		die(_("Remote with no URL"));
+	transport = transport_get(remote, remote->url[0]);
+
+	transport_set_option(transport, TRANS_OPT_FROM_PROMISOR, "1");
+	transport_set_option(transport, TRANS_OPT_NO_DEPENDENTS, "1");
+	res = transport_fetch_refs(transport, ref);
+
+	return res;
+}
+
+static int fetch_objects(const char *remote_name,
+			 const struct object_id *oids,
+			 int oid_nr)
+{
+	struct ref *ref = NULL;
+	int i;
+
+	for (i = 0; i < oid_nr; i++) {
+		struct ref *new_ref = alloc_ref(oid_to_hex(&oids[i]));
+		oidcpy(&new_ref->old_oid, &oids[i]);
+		new_ref->exact_oid = 1;
+		new_ref->next = ref;
+		ref = new_ref;
+	}
+	return fetch_refs(remote_name, ref);
+}
+
+static struct promisor_remote *promisors;
+static struct promisor_remote **promisors_tail = &promisors;
+
+static struct promisor_remote *promisor_remote_new(const char *remote_name)
+{
+	struct promisor_remote *r;
+
+	if (*remote_name == '/') {
+		warning(_("promisor remote name cannot begin with '/': %s"),
+			remote_name);
+		return NULL;
+	}
+
+	FLEX_ALLOC_STR(r, name, remote_name);
+
+	*promisors_tail = r;
+	promisors_tail = &r->next;
+
+	return r;
+}
+
+static struct promisor_remote *promisor_remote_lookup(const char *remote_name,
+						      struct promisor_remote **previous)
+{
+	struct promisor_remote *r, *p;
+
+	for (p = NULL, r = promisors; r; p = r, r = r->next)
+		if (!strcmp(r->name, remote_name)) {
+			if (previous)
+				*previous = p;
+			return r;
+		}
+
+	return NULL;
+}
+
+static void promisor_remote_move_to_tail(struct promisor_remote *r,
+					 struct promisor_remote *previous)
+{
+	if (r->next == NULL)
+		return;
+
+	if (previous)
+		previous->next = r->next;
+	else
+		promisors = r->next ? r->next : r;
+	r->next = NULL;
+	*promisors_tail = r;
+	promisors_tail = &r->next;
+}
+
+static int promisor_remote_config(const char *var, const char *value, void *data)
+{
+	const char *name;
+	int namelen;
+	const char *subkey;
+
+	if (!strcmp(var, "core.partialclonefilter"))
+		return git_config_string(&core_partial_clone_filter_default,
+					 var, value);
+
+	if (parse_config_key(var, "remote", &name, &namelen, &subkey) < 0)
+		return 0;
+
+	if (!strcmp(subkey, "promisor")) {
+		char *remote_name;
+
+		if (!git_config_bool(var, value))
+			return 0;
+
+		remote_name = xmemdupz(name, namelen);
+
+		if (!promisor_remote_lookup(remote_name, NULL))
+			promisor_remote_new(remote_name);
+
+		free(remote_name);
+		return 0;
+	}
+	if (!strcmp(subkey, "partialclonefilter")) {
+		struct promisor_remote *r;
+		char *remote_name = xmemdupz(name, namelen);
+
+		r = promisor_remote_lookup(remote_name, NULL);
+		if (!r)
+			r = promisor_remote_new(remote_name);
+
+		free(remote_name);
+
+		if (!r)
+			return 0;
+
+		return git_config_string(&r->partial_clone_filter, var, value);
+	}
+
+	return 0;
+}
+
+static int initialized;
+
+static void promisor_remote_init(void)
+{
+	if (initialized)
+		return;
+	initialized = 1;
+
+	git_config(promisor_remote_config, NULL);
+
+	if (repository_format_partial_clone) {
+		struct promisor_remote *o, *previous;
+
+		o = promisor_remote_lookup(repository_format_partial_clone,
+					   &previous);
+		if (o)
+			promisor_remote_move_to_tail(o, previous);
+		else
+			promisor_remote_new(repository_format_partial_clone);
+	}
+}
+
+static void promisor_remote_clear(void)
+{
+	while (promisors) {
+		struct promisor_remote *r = promisors;
+		promisors = promisors->next;
+		free(r);
+	}
+
+	promisors_tail = &promisors;
+}
+
+void promisor_remote_reinit(void)
+{
+	initialized = 0;
+	promisor_remote_clear();
+	promisor_remote_init();
+}
+
+struct promisor_remote *promisor_remote_find(const char *remote_name)
+{
+	promisor_remote_init();
+
+	if (!remote_name)
+		return promisors;
+
+	return promisor_remote_lookup(remote_name, NULL);
+}
+
+int has_promisor_remote(void)
+{
+	return !!promisor_remote_find(NULL);
+}
+
+static int remove_fetched_oids(struct repository *repo,
+			       struct object_id **oids,
+			       int oid_nr, int to_free)
+{
+	int i, remaining_nr = 0;
+	int *remaining = xcalloc(oid_nr, sizeof(*remaining));
+	struct object_id *old_oids = *oids;
+	struct object_id *new_oids;
+
+	for (i = 0; i < oid_nr; i++)
+		if (oid_object_info_extended(repo, &old_oids[i], NULL,
+					     OBJECT_INFO_SKIP_FETCH_OBJECT)) {
+			remaining[i] = 1;
+			remaining_nr++;
+		}
+
+	if (remaining_nr) {
+		int j = 0;
+		new_oids = xcalloc(remaining_nr, sizeof(*new_oids));
+		for (i = 0; i < oid_nr; i++)
+			if (remaining[i])
+				oidcpy(&new_oids[j++], &old_oids[i]);
+		*oids = new_oids;
+		if (to_free)
+			free(old_oids);
+	}
+
+	free(remaining);
+
+	return remaining_nr;
+}
+
+int promisor_remote_get_direct(struct repository *repo,
+			       const struct object_id *oids,
+			       int oid_nr)
+{
+	struct promisor_remote *r;
+	struct object_id *remaining_oids = (struct object_id *)oids;
+	int remaining_nr = oid_nr;
+	int to_free = 0;
+	int res = -1;
+
+	promisor_remote_init();
+
+	for (r = promisors; r; r = r->next) {
+		if (fetch_objects(r->name, remaining_oids, remaining_nr) < 0) {
+			if (remaining_nr == 1)
+				continue;
+			remaining_nr = remove_fetched_oids(repo, &remaining_oids,
+							 remaining_nr, to_free);
+			if (remaining_nr) {
+				to_free = 1;
+				continue;
+			}
+		}
+		res = 0;
+		break;
+	}
+
+	if (to_free)
+		free(remaining_oids);
+
+	return res;
+}
diff -pruN 1.2.1+git2.18.0-1/git/promisor-remote.h 1.2.3+git2.25.1-1/git/promisor-remote.h
--- 1.2.1+git2.18.0-1/git/promisor-remote.h	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/promisor-remote.h	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,33 @@
+#ifndef PROMISOR_REMOTE_H
+#define PROMISOR_REMOTE_H
+
+#include "repository.h"
+
+struct object_id;
+
+/*
+ * Promisor remote linked list
+ *
+ * Information in its fields come from remote.XXX config entries or
+ * from extensions.partialclone or core.partialclonefilter.
+ */
+struct promisor_remote {
+	struct promisor_remote *next;
+	const char *partial_clone_filter;
+	const char name[FLEX_ARRAY];
+};
+
+void promisor_remote_reinit(void);
+struct promisor_remote *promisor_remote_find(const char *remote_name);
+int has_promisor_remote(void);
+int promisor_remote_get_direct(struct repository *repo,
+			       const struct object_id *oids,
+			       int oid_nr);
+
+/*
+ * This should be used only once from setup.c to set the value we got
+ * from the extensions.partialclone config option.
+ */
+void set_repository_format_partial_clone(char *partial_clone);
+
+#endif /* PROMISOR_REMOTE_H */
diff -pruN 1.2.1+git2.18.0-1/git/protocol.c 1.2.3+git2.25.1-1/git/protocol.c
--- 1.2.1+git2.18.0-1/git/protocol.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/protocol.c	2020-02-17 04:47:35.000000000 +0000
@@ -17,6 +17,10 @@ static enum protocol_version parse_proto
 enum protocol_version get_protocol_version_config(void)
 {
 	const char *value;
+	enum protocol_version retval = protocol_v0;
+	const char *git_test_k = "GIT_TEST_PROTOCOL_VERSION";
+	const char *git_test_v = getenv(git_test_k);
+
 	if (!git_config_get_string_const("protocol.version", &value)) {
 		enum protocol_version version = parse_protocol_version(value);
 
@@ -24,10 +28,19 @@ enum protocol_version get_protocol_versi
 			die("unknown value for config 'protocol.version': %s",
 			    value);
 
-		return version;
+		retval = version;
+	}
+
+	if (git_test_v && *git_test_v) {
+		enum protocol_version env = parse_protocol_version(git_test_v);
+
+		if (env == protocol_unknown_version)
+			die("unknown value for %s: %s", git_test_k, git_test_v);
+		if (retval < env)
+			retval = env;
 	}
 
-	return protocol_v0;
+	return retval;
 }
 
 enum protocol_version determine_protocol_version_server(void)
diff -pruN 1.2.1+git2.18.0-1/git/protocol.h 1.2.3+git2.25.1-1/git/protocol.h
--- 1.2.1+git2.18.0-1/git/protocol.h	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/protocol.h	2020-02-17 04:47:35.000000000 +0000
@@ -14,7 +14,7 @@ enum protocol_version {
  * 'protocol.version' config.  If unconfigured, a value of 'protocol_v0' is
  * returned.
  */
-extern enum protocol_version get_protocol_version_config(void);
+enum protocol_version get_protocol_version_config(void);
 
 /*
  * Used by a server to determine which protocol version should be used based on
@@ -23,12 +23,12 @@ extern enum protocol_version get_protoco
  * request a particular protocol version, a default of 'protocol_v0' will be
  * used.
  */
-extern enum protocol_version determine_protocol_version_server(void);
+enum protocol_version determine_protocol_version_server(void);
 
 /*
  * Used by a client to determine which protocol version the server is speaking
  * based on the server's initial response.
  */
-extern enum protocol_version determine_protocol_version_client(const char *server_response);
+enum protocol_version determine_protocol_version_client(const char *server_response);
 
 #endif /* PROTOCOL_H */
diff -pruN 1.2.1+git2.18.0-1/git/quote.c 1.2.3+git2.25.1-1/git/quote.c
--- 1.2.1+git2.18.0-1/git/quote.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/quote.c	2020-02-17 04:47:35.000000000 +0000
@@ -48,6 +48,12 @@ void sq_quote_buf_pretty(struct strbuf *
 	static const char ok_punct[] = "+,-./:=@_^";
 	const char *p;
 
+	/* Avoid losing a zero-length string by adding '' */
+	if (!*src) {
+		strbuf_addstr(dst, "''");
+		return;
+	}
+
 	for (p = src; *p; p++) {
 		if (!isalpha(*p) && !isdigit(*p) && !strchr(ok_punct, *p)) {
 			sq_quote_buf(dst, src);
@@ -84,12 +90,28 @@ void sq_quote_argv(struct strbuf *dst, c
 	}
 }
 
+/*
+ * Legacy function to append each argv value, quoted as necessasry,
+ * with whitespace before each value.  This results in a leading
+ * space in the result.
+ */
 void sq_quote_argv_pretty(struct strbuf *dst, const char **argv)
 {
+	if (argv[0])
+		strbuf_addch(dst, ' ');
+	sq_append_quote_argv_pretty(dst, argv);
+}
+
+/*
+ * Append each argv value, quoted as necessary, with whitespace between them.
+ */
+void sq_append_quote_argv_pretty(struct strbuf *dst, const char **argv)
+{
 	int i;
 
 	for (i = 0; argv[i]; i++) {
-		strbuf_addch(dst, ' ');
+		if (i > 0)
+			strbuf_addch(dst, ' ');
 		sq_quote_buf_pretty(dst, argv[i]);
 	}
 }
@@ -234,7 +256,7 @@ static size_t next_quote_pos(const char
  *     Return value is the same as in (1).
  */
 static size_t quote_c_style_counted(const char *name, ssize_t maxlen,
-                                    struct strbuf *sb, FILE *fp, int no_dq)
+				    struct strbuf *sb, FILE *fp, int no_dq)
 {
 #undef EMIT
 #define EMIT(c)                                 \
diff -pruN 1.2.1+git2.18.0-1/git/quote.h 1.2.3+git2.25.1-1/git/quote.h
--- 1.2.1+git2.18.0-1/git/quote.h	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/quote.h	2020-02-17 04:47:35.000000000 +0000
@@ -29,9 +29,9 @@ struct strbuf;
  * sq_quotef() quotes the entire formatted string as a single result.
  */
 
-extern void sq_quote_buf(struct strbuf *, const char *src);
-extern void sq_quote_argv(struct strbuf *, const char **argv);
-extern void sq_quotef(struct strbuf *, const char *fmt, ...);
+void sq_quote_buf(struct strbuf *, const char *src);
+void sq_quote_argv(struct strbuf *, const char **argv);
+void sq_quotef(struct strbuf *, const char *fmt, ...);
 
 /*
  * These match their non-pretty variants, except that they avoid
@@ -40,19 +40,20 @@ extern void sq_quotef(struct strbuf *, c
  */
 void sq_quote_buf_pretty(struct strbuf *, const char *src);
 void sq_quote_argv_pretty(struct strbuf *, const char **argv);
+void sq_append_quote_argv_pretty(struct strbuf *dst, const char **argv);
 
 /* This unwraps what sq_quote() produces in place, but returns
  * NULL if the input does not look like what sq_quote would have
  * produced.
  */
-extern char *sq_dequote(char *);
+char *sq_dequote(char *);
 
 /*
  * Same as the above, but can be used to unwrap many arguments in the
  * same string separated by space. Like sq_quote, it works in place,
  * modifying arg and appending pointers into it to argv.
  */
-extern int sq_dequote_to_argv(char *arg, const char ***argv, int *nr, int *alloc);
+int sq_dequote_to_argv(char *arg, const char ***argv, int *nr, int *alloc);
 
 /*
  * Same as above, but store the unquoted strings in an argv_array. We will
@@ -60,24 +61,24 @@ extern int sq_dequote_to_argv(char *arg,
  * will duplicate and take ownership of the strings.
  */
 struct argv_array;
-extern int sq_dequote_to_argv_array(char *arg, struct argv_array *);
+int sq_dequote_to_argv_array(char *arg, struct argv_array *);
 
-extern int unquote_c_style(struct strbuf *, const char *quoted, const char **endp);
-extern size_t quote_c_style(const char *name, struct strbuf *, FILE *, int no_dq);
-extern void quote_two_c_style(struct strbuf *, const char *, const char *, int);
-
-extern void write_name_quoted(const char *name, FILE *, int terminator);
-extern void write_name_quoted_relative(const char *name, const char *prefix,
-		FILE *fp, int terminator);
+int unquote_c_style(struct strbuf *, const char *quoted, const char **endp);
+size_t quote_c_style(const char *name, struct strbuf *, FILE *, int no_dq);
+void quote_two_c_style(struct strbuf *, const char *, const char *, int);
+
+void write_name_quoted(const char *name, FILE *, int terminator);
+void write_name_quoted_relative(const char *name, const char *prefix,
+				FILE *fp, int terminator);
 
 /* quote path as relative to the given prefix */
-extern char *quote_path_relative(const char *in, const char *prefix,
+char *quote_path_relative(const char *in, const char *prefix,
 			  struct strbuf *out);
 
 /* quoting as a string literal for other languages */
-extern void perl_quote_buf(struct strbuf *sb, const char *src);
-extern void python_quote_buf(struct strbuf *sb, const char *src);
-extern void tcl_quote_buf(struct strbuf *sb, const char *src);
-extern void basic_regex_quote_buf(struct strbuf *sb, const char *src);
+void perl_quote_buf(struct strbuf *sb, const char *src);
+void python_quote_buf(struct strbuf *sb, const char *src);
+void tcl_quote_buf(struct strbuf *sb, const char *src);
+void basic_regex_quote_buf(struct strbuf *sb, const char *src);
 
 #endif
diff -pruN 1.2.1+git2.18.0-1/git/range-diff.c 1.2.3+git2.25.1-1/git/range-diff.c
--- 1.2.1+git2.18.0-1/git/range-diff.c	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/range-diff.c	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,552 @@
+#include "cache.h"
+#include "range-diff.h"
+#include "string-list.h"
+#include "run-command.h"
+#include "argv-array.h"
+#include "hashmap.h"
+#include "xdiff-interface.h"
+#include "linear-assignment.h"
+#include "diffcore.h"
+#include "commit.h"
+#include "pretty.h"
+#include "userdiff.h"
+#include "apply.h"
+
+struct patch_util {
+	/* For the search for an exact match */
+	struct hashmap_entry e;
+	const char *diff, *patch;
+
+	int i, shown;
+	int diffsize;
+	size_t diff_offset;
+	/* the index of the matching item in the other branch, or -1 */
+	int matching;
+	struct object_id oid;
+};
+
+static size_t find_end_of_line(char *buffer, unsigned long size)
+{
+	char *eol = memchr(buffer, '\n', size);
+
+	if (!eol)
+		return size;
+
+	*eol = '\0';
+	return eol + 1 - buffer;
+}
+
+/*
+ * Reads the patches into a string list, with the `util` field being populated
+ * as struct object_id (will need to be free()d).
+ */
+static int read_patches(const char *range, struct string_list *list,
+			const struct argv_array *other_arg)
+{
+	struct child_process cp = CHILD_PROCESS_INIT;
+	struct strbuf buf = STRBUF_INIT, contents = STRBUF_INIT;
+	struct patch_util *util = NULL;
+	int in_header = 1;
+	char *line, *current_filename = NULL;
+	int offset, len;
+	size_t size;
+
+	argv_array_pushl(&cp.args, "log", "--no-color", "-p", "--no-merges",
+			"--reverse", "--date-order", "--decorate=no",
+			"--no-prefix",
+			/*
+			 * Choose indicators that are not used anywhere
+			 * else in diffs, but still look reasonable
+			 * (e.g. will not be confusing when debugging)
+			 */
+			"--output-indicator-new=>",
+			"--output-indicator-old=<",
+			"--output-indicator-context=#",
+			"--no-abbrev-commit",
+			NULL);
+	if (other_arg)
+		argv_array_pushv(&cp.args, other_arg->argv);
+	argv_array_push(&cp.args, range);
+	cp.out = -1;
+	cp.no_stdin = 1;
+	cp.git_cmd = 1;
+
+	if (start_command(&cp))
+		return error_errno(_("could not start `log`"));
+	if (strbuf_read(&contents, cp.out, 0) < 0) {
+		error_errno(_("could not read `log` output"));
+		finish_command(&cp);
+		return -1;
+	}
+
+	line = contents.buf;
+	size = contents.len;
+	for (offset = 0; size > 0; offset += len, size -= len, line += len) {
+		const char *p;
+
+		len = find_end_of_line(line, size);
+		line[len - 1] = '\0';
+		if (skip_prefix(line, "commit ", &p)) {
+			if (util) {
+				string_list_append(list, buf.buf)->util = util;
+				strbuf_reset(&buf);
+			}
+			util = xcalloc(sizeof(*util), 1);
+			if (get_oid(p, &util->oid)) {
+				error(_("could not parse commit '%s'"), p);
+				free(util);
+				string_list_clear(list, 1);
+				strbuf_release(&buf);
+				strbuf_release(&contents);
+				finish_command(&cp);
+				return -1;
+			}
+			util->matching = -1;
+			in_header = 1;
+			continue;
+		}
+
+		if (starts_with(line, "diff --git")) {
+			struct patch patch = { 0 };
+			struct strbuf root = STRBUF_INIT;
+			int linenr = 0;
+
+			in_header = 0;
+			strbuf_addch(&buf, '\n');
+			if (!util->diff_offset)
+				util->diff_offset = buf.len;
+			line[len - 1] = '\n';
+			len = parse_git_diff_header(&root, &linenr, 0, line,
+						    len, size, &patch);
+			if (len < 0)
+				die(_("could not parse git header '%.*s'"), (int)len, line);
+			strbuf_addstr(&buf, " ## ");
+			if (patch.is_new > 0)
+				strbuf_addf(&buf, "%s (new)", patch.new_name);
+			else if (patch.is_delete > 0)
+				strbuf_addf(&buf, "%s (deleted)", patch.old_name);
+			else if (patch.is_rename)
+				strbuf_addf(&buf, "%s => %s", patch.old_name, patch.new_name);
+			else
+				strbuf_addstr(&buf, patch.new_name);
+
+			free(current_filename);
+			if (patch.is_delete > 0)
+				current_filename = xstrdup(patch.old_name);
+			else
+				current_filename = xstrdup(patch.new_name);
+
+			if (patch.new_mode && patch.old_mode &&
+			    patch.old_mode != patch.new_mode)
+				strbuf_addf(&buf, " (mode change %06o => %06o)",
+					    patch.old_mode, patch.new_mode);
+
+			strbuf_addstr(&buf, " ##");
+		} else if (in_header) {
+			if (starts_with(line, "Author: ")) {
+				strbuf_addstr(&buf, " ## Metadata ##\n");
+				strbuf_addstr(&buf, line);
+				strbuf_addstr(&buf, "\n\n");
+				strbuf_addstr(&buf, " ## Commit message ##\n");
+			} else if (starts_with(line, "Notes") &&
+				   line[strlen(line) - 1] == ':') {
+				strbuf_addstr(&buf, "\n\n");
+				/* strip the trailing colon */
+				strbuf_addf(&buf, " ## %.*s ##\n",
+					    (int)(strlen(line) - 1), line);
+			} else if (starts_with(line, "    ")) {
+				p = line + len - 2;
+				while (isspace(*p) && p >= line)
+					p--;
+				strbuf_add(&buf, line, p - line + 1);
+				strbuf_addch(&buf, '\n');
+			}
+			continue;
+		} else if (skip_prefix(line, "@@ ", &p)) {
+			p = strstr(p, "@@");
+			strbuf_addstr(&buf, "@@");
+			if (current_filename && p[2])
+				strbuf_addf(&buf, " %s:", current_filename);
+			if (p)
+				strbuf_addstr(&buf, p + 2);
+		} else if (!line[0])
+			/*
+			 * A completely blank (not ' \n', which is context)
+			 * line is not valid in a diff.  We skip it
+			 * silently, because this neatly handles the blank
+			 * separator line between commits in git-log
+			 * output.
+			 */
+			continue;
+		else if (line[0] == '>') {
+			strbuf_addch(&buf, '+');
+			strbuf_addstr(&buf, line + 1);
+		} else if (line[0] == '<') {
+			strbuf_addch(&buf, '-');
+			strbuf_addstr(&buf, line + 1);
+		} else if (line[0] == '#') {
+			strbuf_addch(&buf, ' ');
+			strbuf_addstr(&buf, line + 1);
+		} else {
+			strbuf_addch(&buf, ' ');
+			strbuf_addstr(&buf, line);
+		}
+
+		strbuf_addch(&buf, '\n');
+		util->diffsize++;
+	}
+	strbuf_release(&contents);
+
+	if (util)
+		string_list_append(list, buf.buf)->util = util;
+	strbuf_release(&buf);
+	free(current_filename);
+
+	if (finish_command(&cp))
+		return -1;
+
+	return 0;
+}
+
+static int patch_util_cmp(const void *dummy, const struct patch_util *a,
+			  const struct patch_util *b, const char *keydata)
+{
+	return strcmp(a->diff, keydata ? keydata : b->diff);
+}
+
+static void find_exact_matches(struct string_list *a, struct string_list *b)
+{
+	struct hashmap map;
+	int i;
+
+	hashmap_init(&map, (hashmap_cmp_fn)patch_util_cmp, NULL, 0);
+
+	/* First, add the patches of a to a hash map */
+	for (i = 0; i < a->nr; i++) {
+		struct patch_util *util = a->items[i].util;
+
+		util->i = i;
+		util->patch = a->items[i].string;
+		util->diff = util->patch + util->diff_offset;
+		hashmap_entry_init(&util->e, strhash(util->diff));
+		hashmap_add(&map, &util->e);
+	}
+
+	/* Now try to find exact matches in b */
+	for (i = 0; i < b->nr; i++) {
+		struct patch_util *util = b->items[i].util, *other;
+
+		util->i = i;
+		util->patch = b->items[i].string;
+		util->diff = util->patch + util->diff_offset;
+		hashmap_entry_init(&util->e, strhash(util->diff));
+		other = hashmap_remove_entry(&map, util, e, NULL);
+		if (other) {
+			if (other->matching >= 0)
+				BUG("already assigned!");
+
+			other->matching = i;
+			util->matching = other->i;
+		}
+	}
+
+	hashmap_free(&map);
+}
+
+static void diffsize_consume(void *data, char *line, unsigned long len)
+{
+	(*(int *)data)++;
+}
+
+static void diffsize_hunk(void *data, long ob, long on, long nb, long nn,
+			  const char *funcline, long funclen)
+{
+	diffsize_consume(data, NULL, 0);
+}
+
+static int diffsize(const char *a, const char *b)
+{
+	xpparam_t pp = { 0 };
+	xdemitconf_t cfg = { 0 };
+	mmfile_t mf1, mf2;
+	int count = 0;
+
+	mf1.ptr = (char *)a;
+	mf1.size = strlen(a);
+	mf2.ptr = (char *)b;
+	mf2.size = strlen(b);
+
+	cfg.ctxlen = 3;
+	if (!xdi_diff_outf(&mf1, &mf2,
+			   diffsize_hunk, diffsize_consume, &count,
+			   &pp, &cfg))
+		return count;
+
+	error(_("failed to generate diff"));
+	return COST_MAX;
+}
+
+static void get_correspondences(struct string_list *a, struct string_list *b,
+				int creation_factor)
+{
+	int n = a->nr + b->nr;
+	int *cost, c, *a2b, *b2a;
+	int i, j;
+
+	ALLOC_ARRAY(cost, st_mult(n, n));
+	ALLOC_ARRAY(a2b, n);
+	ALLOC_ARRAY(b2a, n);
+
+	for (i = 0; i < a->nr; i++) {
+		struct patch_util *a_util = a->items[i].util;
+
+		for (j = 0; j < b->nr; j++) {
+			struct patch_util *b_util = b->items[j].util;
+
+			if (a_util->matching == j)
+				c = 0;
+			else if (a_util->matching < 0 && b_util->matching < 0)
+				c = diffsize(a_util->diff, b_util->diff);
+			else
+				c = COST_MAX;
+			cost[i + n * j] = c;
+		}
+
+		c = a_util->matching < 0 ?
+			a_util->diffsize * creation_factor / 100 : COST_MAX;
+		for (j = b->nr; j < n; j++)
+			cost[i + n * j] = c;
+	}
+
+	for (j = 0; j < b->nr; j++) {
+		struct patch_util *util = b->items[j].util;
+
+		c = util->matching < 0 ?
+			util->diffsize * creation_factor / 100 : COST_MAX;
+		for (i = a->nr; i < n; i++)
+			cost[i + n * j] = c;
+	}
+
+	for (i = a->nr; i < n; i++)
+		for (j = b->nr; j < n; j++)
+			cost[i + n * j] = 0;
+
+	compute_assignment(n, n, cost, a2b, b2a);
+
+	for (i = 0; i < a->nr; i++)
+		if (a2b[i] >= 0 && a2b[i] < b->nr) {
+			struct patch_util *a_util = a->items[i].util;
+			struct patch_util *b_util = b->items[a2b[i]].util;
+
+			a_util->matching = a2b[i];
+			b_util->matching = i;
+		}
+
+	free(cost);
+	free(a2b);
+	free(b2a);
+}
+
+static void output_pair_header(struct diff_options *diffopt,
+			       int patch_no_width,
+			       struct strbuf *buf,
+			       struct strbuf *dashes,
+			       struct patch_util *a_util,
+			       struct patch_util *b_util)
+{
+	struct object_id *oid = a_util ? &a_util->oid : &b_util->oid;
+	struct commit *commit;
+	char status;
+	const char *color_reset = diff_get_color_opt(diffopt, DIFF_RESET);
+	const char *color_old = diff_get_color_opt(diffopt, DIFF_FILE_OLD);
+	const char *color_new = diff_get_color_opt(diffopt, DIFF_FILE_NEW);
+	const char *color_commit = diff_get_color_opt(diffopt, DIFF_COMMIT);
+	const char *color;
+
+	if (!dashes->len)
+		strbuf_addchars(dashes, '-',
+				strlen(find_unique_abbrev(oid,
+							  DEFAULT_ABBREV)));
+
+	if (!b_util) {
+		color = color_old;
+		status = '<';
+	} else if (!a_util) {
+		color = color_new;
+		status = '>';
+	} else if (strcmp(a_util->patch, b_util->patch)) {
+		color = color_commit;
+		status = '!';
+	} else {
+		color = color_commit;
+		status = '=';
+	}
+
+	strbuf_reset(buf);
+	strbuf_addstr(buf, status == '!' ? color_old : color);
+	if (!a_util)
+		strbuf_addf(buf, "%*s:  %s ", patch_no_width, "-", dashes->buf);
+	else
+		strbuf_addf(buf, "%*d:  %s ", patch_no_width, a_util->i + 1,
+			    find_unique_abbrev(&a_util->oid, DEFAULT_ABBREV));
+
+	if (status == '!')
+		strbuf_addf(buf, "%s%s", color_reset, color);
+	strbuf_addch(buf, status);
+	if (status == '!')
+		strbuf_addf(buf, "%s%s", color_reset, color_new);
+
+	if (!b_util)
+		strbuf_addf(buf, " %*s:  %s", patch_no_width, "-", dashes->buf);
+	else
+		strbuf_addf(buf, " %*d:  %s", patch_no_width, b_util->i + 1,
+			    find_unique_abbrev(&b_util->oid, DEFAULT_ABBREV));
+
+	commit = lookup_commit_reference(the_repository, oid);
+	if (commit) {
+		if (status == '!')
+			strbuf_addf(buf, "%s%s", color_reset, color);
+
+		strbuf_addch(buf, ' ');
+		pp_commit_easy(CMIT_FMT_ONELINE, commit, buf);
+	}
+	strbuf_addf(buf, "%s\n", color_reset);
+
+	fwrite(buf->buf, buf->len, 1, diffopt->file);
+}
+
+static struct userdiff_driver section_headers = {
+	.funcname = { "^ ## (.*) ##$\n"
+		      "^.?@@ (.*)$", REG_EXTENDED }
+};
+
+static struct diff_filespec *get_filespec(const char *name, const char *p)
+{
+	struct diff_filespec *spec = alloc_filespec(name);
+
+	fill_filespec(spec, &null_oid, 0, 0100644);
+	spec->data = (char *)p;
+	spec->size = strlen(p);
+	spec->should_munmap = 0;
+	spec->is_stdin = 1;
+	spec->driver = &section_headers;
+
+	return spec;
+}
+
+static void patch_diff(const char *a, const char *b,
+		       struct diff_options *diffopt)
+{
+	diff_queue(&diff_queued_diff,
+		   get_filespec("a", a), get_filespec("b", b));
+
+	diffcore_std(diffopt);
+	diff_flush(diffopt);
+}
+
+static void output(struct string_list *a, struct string_list *b,
+		   struct diff_options *diffopt)
+{
+	struct strbuf buf = STRBUF_INIT, dashes = STRBUF_INIT;
+	int patch_no_width = decimal_width(1 + (a->nr > b->nr ? a->nr : b->nr));
+	int i = 0, j = 0;
+
+	/*
+	 * We assume the user is really more interested in the second argument
+	 * ("newer" version). To that end, we print the output in the order of
+	 * the RHS (the `b` parameter). To put the LHS (the `a` parameter)
+	 * commits that are no longer in the RHS into a good place, we place
+	 * them once we have shown all of their predecessors in the LHS.
+	 */
+
+	while (i < a->nr || j < b->nr) {
+		struct patch_util *a_util, *b_util;
+		a_util = i < a->nr ? a->items[i].util : NULL;
+		b_util = j < b->nr ? b->items[j].util : NULL;
+
+		/* Skip all the already-shown commits from the LHS. */
+		while (i < a->nr && a_util->shown)
+			a_util = ++i < a->nr ? a->items[i].util : NULL;
+
+		/* Show unmatched LHS commit whose predecessors were shown. */
+		if (i < a->nr && a_util->matching < 0) {
+			output_pair_header(diffopt, patch_no_width,
+					   &buf, &dashes, a_util, NULL);
+			i++;
+			continue;
+		}
+
+		/* Show unmatched RHS commits. */
+		while (j < b->nr && b_util->matching < 0) {
+			output_pair_header(diffopt, patch_no_width,
+					   &buf, &dashes, NULL, b_util);
+			b_util = ++j < b->nr ? b->items[j].util : NULL;
+		}
+
+		/* Show matching LHS/RHS pair. */
+		if (j < b->nr) {
+			a_util = a->items[b_util->matching].util;
+			output_pair_header(diffopt, patch_no_width,
+					   &buf, &dashes, a_util, b_util);
+			if (!(diffopt->output_format & DIFF_FORMAT_NO_OUTPUT))
+				patch_diff(a->items[b_util->matching].string,
+					   b->items[j].string, diffopt);
+			a_util->shown = 1;
+			j++;
+		}
+	}
+	strbuf_release(&buf);
+	strbuf_release(&dashes);
+}
+
+static struct strbuf *output_prefix_cb(struct diff_options *opt, void *data)
+{
+	return data;
+}
+
+int show_range_diff(const char *range1, const char *range2,
+		    int creation_factor, int dual_color,
+		    const struct diff_options *diffopt,
+		    const struct argv_array *other_arg)
+{
+	int res = 0;
+
+	struct string_list branch1 = STRING_LIST_INIT_DUP;
+	struct string_list branch2 = STRING_LIST_INIT_DUP;
+
+	if (read_patches(range1, &branch1, other_arg))
+		res = error(_("could not parse log for '%s'"), range1);
+	if (!res && read_patches(range2, &branch2, other_arg))
+		res = error(_("could not parse log for '%s'"), range2);
+
+	if (!res) {
+		struct diff_options opts;
+		struct strbuf indent = STRBUF_INIT;
+
+		if (diffopt)
+			memcpy(&opts, diffopt, sizeof(opts));
+		else
+			diff_setup(&opts);
+
+		if (!opts.output_format)
+			opts.output_format = DIFF_FORMAT_PATCH;
+		opts.flags.suppress_diff_headers = 1;
+		opts.flags.dual_color_diffed_diffs = dual_color;
+		opts.flags.suppress_hunk_header_line_count = 1;
+		opts.output_prefix = output_prefix_cb;
+		strbuf_addstr(&indent, "    ");
+		opts.output_prefix_data = &indent;
+		diff_setup_done(&opts);
+
+		find_exact_matches(&branch1, &branch2);
+		get_correspondences(&branch1, &branch2, creation_factor);
+		output(&branch1, &branch2, &opts);
+
+		strbuf_release(&indent);
+	}
+
+	string_list_clear(&branch1, 1);
+	string_list_clear(&branch2, 1);
+
+	return res;
+}
diff -pruN 1.2.1+git2.18.0-1/git/range-diff.h 1.2.3+git2.25.1-1/git/range-diff.h
--- 1.2.1+git2.18.0-1/git/range-diff.h	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/range-diff.h	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,19 @@
+#ifndef RANGE_DIFF_H
+#define RANGE_DIFF_H
+
+#include "diff.h"
+#include "argv-array.h"
+
+#define RANGE_DIFF_CREATION_FACTOR_DEFAULT 60
+
+/*
+ * Compare series of commits in RANGE1 and RANGE2, and emit to the
+ * standard output.  NULL can be passed to DIFFOPT to use the built-in
+ * default.
+ */
+int show_range_diff(const char *range1, const char *range2,
+		    int creation_factor, int dual_color,
+		    const struct diff_options *diffopt,
+		    const struct argv_array *other_arg);
+
+#endif
diff -pruN 1.2.1+git2.18.0-1/git/reachable.c 1.2.3+git2.25.1-1/git/reachable.c
--- 1.2.1+git2.18.0-1/git/reachable.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/reachable.c	2020-02-17 04:47:35.000000000 +0000
@@ -12,6 +12,7 @@
 #include "packfile.h"
 #include "worktree.h"
 #include "object-store.h"
+#include "pack-bitmap.h"
 
 struct connectivity_progress {
 	struct progress *progress;
@@ -88,10 +89,10 @@ static void add_recent_object(const stru
 		obj = parse_object_or_die(oid, NULL);
 		break;
 	case OBJ_TREE:
-		obj = (struct object *)lookup_tree(oid);
+		obj = (struct object *)lookup_tree(the_repository, oid);
 		break;
 	case OBJ_BLOB:
-		obj = (struct object *)lookup_blob(oid);
+		obj = (struct object *)lookup_blob(the_repository, oid);
 		break;
 	default:
 		die("unknown object type for %s: %s",
@@ -108,7 +109,7 @@ static int add_recent_loose(const struct
 			    const char *path, void *data)
 {
 	struct stat st;
-	struct object *obj = lookup_object(oid->hash);
+	struct object *obj = lookup_object(the_repository, oid);
 
 	if (obj && obj->flags & SEEN)
 		return 0;
@@ -133,7 +134,7 @@ static int add_recent_packed(const struc
 			     struct packed_git *p, uint32_t pos,
 			     void *data)
 {
-	struct object *obj = lookup_object(oid->hash);
+	struct object *obj = lookup_object(the_repository, oid);
 
 	if (obj && obj->flags & SEEN)
 		return 0;
@@ -158,10 +159,44 @@ int add_unseen_recent_objects_to_travers
 				      FOR_EACH_OBJECT_LOCAL_ONLY);
 }
 
+static void *lookup_object_by_type(struct repository *r,
+				   const struct object_id *oid,
+				   enum object_type type)
+{
+	switch (type) {
+	case OBJ_COMMIT:
+		return lookup_commit(r, oid);
+	case OBJ_TREE:
+		return lookup_tree(r, oid);
+	case OBJ_TAG:
+		return lookup_tag(r, oid);
+	case OBJ_BLOB:
+		return lookup_blob(r, oid);
+	default:
+		die("BUG: unknown object type %d", type);
+	}
+}
+
+static int mark_object_seen(const struct object_id *oid,
+			     enum object_type type,
+			     int exclude,
+			     uint32_t name_hash,
+			     struct packed_git *found_pack,
+			     off_t found_offset)
+{
+	struct object *obj = lookup_object_by_type(the_repository, oid, type);
+	if (!obj)
+		die("unable to create object '%s'", oid_to_hex(oid));
+
+	obj->flags |= SEEN;
+	return 0;
+}
+
 void mark_reachable_objects(struct rev_info *revs, int mark_reflog,
 			    timestamp_t mark_recent, struct progress *progress)
 {
 	struct connectivity_progress cp;
+	struct bitmap_index *bitmap_git;
 
 	/*
 	 * Set up revision parsing, and mark us as being interested
@@ -188,6 +223,13 @@ void mark_reachable_objects(struct rev_i
 	cp.progress = progress;
 	cp.count = 0;
 
+	bitmap_git = prepare_bitmap_walk(revs);
+	if (bitmap_git) {
+		traverse_bitmap_commit_list(bitmap_git, mark_object_seen);
+		free_bitmap_index(bitmap_git);
+		return;
+	}
+
 	/*
 	 * Set up the revision walk - this will move all commits
 	 * from the pending list to the commit walking list.
diff -pruN 1.2.1+git2.18.0-1/git/reachable.h 1.2.3+git2.25.1-1/git/reachable.h
--- 1.2.1+git2.18.0-1/git/reachable.h	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/reachable.h	2020-02-17 04:47:35.000000000 +0000
@@ -2,9 +2,11 @@
 #define REACHEABLE_H
 
 struct progress;
-extern int add_unseen_recent_objects_to_traversal(struct rev_info *revs,
-						  timestamp_t timestamp);
-extern void mark_reachable_objects(struct rev_info *revs, int mark_reflog,
-				   timestamp_t mark_recent, struct progress *);
+struct rev_info;
+
+int add_unseen_recent_objects_to_traversal(struct rev_info *revs,
+					   timestamp_t timestamp);
+void mark_reachable_objects(struct rev_info *revs, int mark_reflog,
+			    timestamp_t mark_recent, struct progress *);
 
 #endif
diff -pruN 1.2.1+git2.18.0-1/git/read-cache.c 1.2.3+git2.25.1-1/git/read-cache.c
--- 1.2.1+git2.18.0-1/git/read-cache.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/read-cache.c	2020-02-17 04:47:35.000000000 +0000
@@ -3,23 +3,28 @@
  *
  * Copyright (C) Linus Torvalds, 2005
  */
-#define NO_THE_INDEX_COMPATIBILITY_MACROS
 #include "cache.h"
 #include "config.h"
+#include "diff.h"
+#include "diffcore.h"
 #include "tempfile.h"
 #include "lockfile.h"
 #include "cache-tree.h"
 #include "refs.h"
 #include "dir.h"
+#include "object-store.h"
 #include "tree.h"
 #include "commit.h"
 #include "blob.h"
 #include "resolve-undo.h"
+#include "run-command.h"
 #include "strbuf.h"
 #include "varint.h"
 #include "split-index.h"
 #include "utf8.h"
 #include "fsmonitor.h"
+#include "thread-utils.h"
+#include "progress.h"
 
 /* Mask for the name length in ce_flags in the on-disk index */
 
@@ -40,13 +45,56 @@
 #define CACHE_EXT_LINK 0x6c696e6b	  /* "link" */
 #define CACHE_EXT_UNTRACKED 0x554E5452	  /* "UNTR" */
 #define CACHE_EXT_FSMONITOR 0x46534D4E	  /* "FSMN" */
+#define CACHE_EXT_ENDOFINDEXENTRIES 0x454F4945	/* "EOIE" */
+#define CACHE_EXT_INDEXENTRYOFFSETTABLE 0x49454F54 /* "IEOT" */
 
 /* changes that can be kept in $GIT_DIR/index (basically all extensions) */
 #define EXTMASK (RESOLVE_UNDO_CHANGED | CACHE_TREE_CHANGED | \
 		 CE_ENTRY_ADDED | CE_ENTRY_REMOVED | CE_ENTRY_CHANGED | \
 		 SPLIT_INDEX_ORDERED | UNTRACKED_CHANGED | FSMONITOR_CHANGED)
 
-struct index_state the_index;
+
+/*
+ * This is an estimate of the pathname length in the index.  We use
+ * this for V4 index files to guess the un-deltafied size of the index
+ * in memory because of pathname deltafication.  This is not required
+ * for V2/V3 index formats because their pathnames are not compressed.
+ * If the initial amount of memory set aside is not sufficient, the
+ * mem pool will allocate extra memory.
+ */
+#define CACHE_ENTRY_PATH_LENGTH 80
+
+static inline struct cache_entry *mem_pool__ce_alloc(struct mem_pool *mem_pool, size_t len)
+{
+	struct cache_entry *ce;
+	ce = mem_pool_alloc(mem_pool, cache_entry_size(len));
+	ce->mem_pool_allocated = 1;
+	return ce;
+}
+
+static inline struct cache_entry *mem_pool__ce_calloc(struct mem_pool *mem_pool, size_t len)
+{
+	struct cache_entry * ce;
+	ce = mem_pool_calloc(mem_pool, 1, cache_entry_size(len));
+	ce->mem_pool_allocated = 1;
+	return ce;
+}
+
+static struct mem_pool *find_mem_pool(struct index_state *istate)
+{
+	struct mem_pool **pool_ptr;
+
+	if (istate->split_index && istate->split_index->base)
+		pool_ptr = &istate->split_index->base->ce_mem_pool;
+	else
+		pool_ptr = &istate->ce_mem_pool;
+
+	if (!*pool_ptr)
+		mem_pool_init(pool_ptr, 0);
+
+	return *pool_ptr;
+}
+
 static const char *alternate_index_output;
 
 static void set_index_entry(struct index_state *istate, int nr, struct cache_entry *ce)
@@ -61,7 +109,7 @@ static void replace_index_entry(struct i
 
 	replace_index_entry_in_base(istate, old, ce);
 	remove_name_hash(istate, old);
-	free(old);
+	discard_cache_entry(old);
 	ce->ce_flags &= ~CE_HASHED;
 	set_index_entry(istate, nr, ce);
 	ce->ce_flags |= CE_UPDATE_IN_BASE;
@@ -74,7 +122,7 @@ void rename_index_entry_at(struct index_
 	struct cache_entry *old_entry = istate->cache[nr], *new_entry;
 	int namelen = strlen(new_name);
 
-	new_entry = xmalloc(cache_entry_size(namelen));
+	new_entry = make_empty_cache_entry(istate, namelen);
 	copy_cache_entry(new_entry, old_entry);
 	new_entry->ce_flags &= ~CE_HASHED;
 	new_entry->ce_namelen = namelen;
@@ -147,7 +195,7 @@ int match_stat_data(const struct stat_da
  * cache, ie the parts that aren't tracked by GIT, and only used
  * to validate the cache.
  */
-void fill_stat_cache_info(struct cache_entry *ce, struct stat *st)
+void fill_stat_cache_info(struct index_state *istate, struct cache_entry *ce, struct stat *st)
 {
 	fill_stat_data(&ce->ce_stat_data, st);
 
@@ -156,19 +204,21 @@ void fill_stat_cache_info(struct cache_e
 
 	if (S_ISREG(st->st_mode)) {
 		ce_mark_uptodate(ce);
-		mark_fsmonitor_valid(ce);
+		mark_fsmonitor_valid(istate, ce);
 	}
 }
 
-static int ce_compare_data(const struct cache_entry *ce, struct stat *st)
+static int ce_compare_data(struct index_state *istate,
+			   const struct cache_entry *ce,
+			   struct stat *st)
 {
 	int match = -1;
 	int fd = git_open_cloexec(ce->name, O_RDONLY);
 
 	if (fd >= 0) {
 		struct object_id oid;
-		if (!index_fd(&oid, fd, st, OBJ_BLOB, ce->name, 0))
-			match = oidcmp(&oid, &ce->oid);
+		if (!index_fd(istate, &oid, fd, st, OBJ_BLOB, ce->name, 0))
+			match = !oideq(&oid, &ce->oid);
 		/* index_fd() closed the file descriptor already */
 	}
 	return match;
@@ -209,14 +259,16 @@ static int ce_compare_gitlink(const stru
 	 */
 	if (resolve_gitlink_ref(ce->name, "HEAD", &oid) < 0)
 		return 0;
-	return oidcmp(&oid, &ce->oid);
+	return !oideq(&oid, &ce->oid);
 }
 
-static int ce_modified_check_fs(const struct cache_entry *ce, struct stat *st)
+static int ce_modified_check_fs(struct index_state *istate,
+				const struct cache_entry *ce,
+				struct stat *st)
 {
 	switch (st->st_mode & S_IFMT) {
 	case S_IFREG:
-		if (ce_compare_data(ce, st))
+		if (ce_compare_data(istate, ce, st))
 			return DATA_CHANGED;
 		break;
 	case S_IFLNK:
@@ -263,7 +315,7 @@ static int ce_match_stat_basic(const str
 			changed |= DATA_CHANGED;
 		return changed;
 	default:
-		die("internal error: ce_mode is %o", ce->ce_mode);
+		BUG("unsupported ce_mode: %o", ce->ce_mode);
 	}
 
 	changed |= match_stat_data(&ce->ce_stat_data, st);
@@ -292,7 +344,7 @@ static int is_racy_stat(const struct ind
 		);
 }
 
-static int is_racy_timestamp(const struct index_state *istate,
+int is_racy_timestamp(const struct index_state *istate,
 			     const struct cache_entry *ce)
 {
 	return (!S_ISGITLINK(ce->ce_mode) &&
@@ -362,7 +414,7 @@ int ie_match_stat(struct index_state *is
 		if (assume_racy_is_modified)
 			changed |= DATA_CHANGED;
 		else
-			changed |= ce_modified_check_fs(ce, st);
+			changed |= ce_modified_check_fs(istate, ce, st);
 	}
 
 	return changed;
@@ -402,7 +454,7 @@ int ie_modified(struct index_state *ista
 	    (S_ISGITLINK(ce->ce_mode) || ce->ce_stat_data.sd_size != 0))
 		return changed;
 
-	changed_fs = ce_modified_check_fs(ce, st);
+	changed_fs = ce_modified_check_fs(istate, ce, st);
 	if (changed_fs)
 		return changed | changed_fs;
 	return 0;
@@ -497,7 +549,7 @@ static int index_name_stage_pos(const st
 	first = 0;
 	last = istate->cache_nr;
 	while (last > first) {
-		int next = (last + first) >> 1;
+		int next = first + ((last - first) >> 1);
 		struct cache_entry *ce = istate->cache[next];
 		int cmp = cache_name_stage_compare(name, namelen, stage, ce->name, ce_namelen(ce), ce_stage(ce));
 		if (!cmp)
@@ -537,13 +589,19 @@ int remove_index_entry_at(struct index_s
  * CE_REMOVE is set in ce_flags.  This is much more effective than
  * calling remove_index_entry_at() for each entry to be removed.
  */
-void remove_marked_cache_entries(struct index_state *istate)
+void remove_marked_cache_entries(struct index_state *istate, int invalidate)
 {
 	struct cache_entry **ce_array = istate->cache;
 	unsigned int i, j;
 
 	for (i = j = 0; i < istate->cache_nr; i++) {
 		if (ce_array[i]->ce_flags & CE_REMOVE) {
+			if (invalidate) {
+				cache_tree_invalidate_path(istate,
+							   ce_array[i]->name);
+				untracked_cache_remove_from_index(istate,
+								  ce_array[i]->name);
+			}
 			remove_name_hash(istate, ce_array[i]);
 			save_or_free_index_entry(istate, ce_array[i]);
 		}
@@ -619,11 +677,12 @@ static struct cache_entry *create_alias_
 	struct cache_entry *new_entry;
 
 	if (alias->ce_flags & CE_ADDED)
-		die("Will not add file alias '%s' ('%s' already exists in index)", ce->name, alias->name);
+		die(_("will not add file alias '%s' ('%s' already exists in index)"),
+		    ce->name, alias->name);
 
 	/* Ok, create the new entry using the name of the existing alias */
 	len = ce_namelen(alias);
-	new_entry = xcalloc(1, cache_entry_size(len));
+	new_entry = make_empty_cache_entry(istate, len);
 	memcpy(new_entry->name, alias->name, len);
 	copy_cache_entry(new_entry, ce);
 	save_or_free_index_entry(istate, ce);
@@ -634,13 +693,13 @@ void set_object_name_for_intent_to_add_e
 {
 	struct object_id oid;
 	if (write_object_file("", 0, blob_type, &oid))
-		die("cannot create an empty blob in the object database");
+		die(_("cannot create an empty blob in the object database"));
 	oidcpy(&ce->oid, &oid);
 }
 
 int add_to_index(struct index_state *istate, const char *path, struct stat *st, int flags)
 {
-	int size, namelen, was_same;
+	int namelen, was_same;
 	mode_t st_mode = st->st_mode;
 	struct cache_entry *ce, *alias = NULL;
 	unsigned ce_option = CE_MATCH_IGNORE_VALID|CE_MATCH_IGNORE_SKIP_WORKTREE|CE_MATCH_RACY_IS_DIRTY;
@@ -649,25 +708,27 @@ int add_to_index(struct index_state *ist
 	int intent_only = flags & ADD_CACHE_INTENT;
 	int add_option = (ADD_CACHE_OK_TO_ADD|ADD_CACHE_OK_TO_REPLACE|
 			  (intent_only ? ADD_CACHE_NEW_ONLY : 0));
-	int newflags = HASH_WRITE_OBJECT;
+	int hash_flags = HASH_WRITE_OBJECT;
+	struct object_id oid;
 
-	if (flags & HASH_RENORMALIZE)
-		newflags |= HASH_RENORMALIZE;
+	if (flags & ADD_CACHE_RENORMALIZE)
+		hash_flags |= HASH_RENORMALIZE;
 
 	if (!S_ISREG(st_mode) && !S_ISLNK(st_mode) && !S_ISDIR(st_mode))
-		return error("%s: can only add regular files, symbolic links or git-directories", path);
+		return error(_("%s: can only add regular files, symbolic links or git-directories"), path);
 
 	namelen = strlen(path);
 	if (S_ISDIR(st_mode)) {
+		if (resolve_gitlink_ref(path, "HEAD", &oid) < 0)
+			return error(_("'%s' does not have a commit checked out"), path);
 		while (namelen && path[namelen-1] == '/')
 			namelen--;
 	}
-	size = cache_entry_size(namelen);
-	ce = xcalloc(1, size);
+	ce = make_empty_cache_entry(istate, namelen);
 	memcpy(ce->name, path, namelen);
 	ce->ce_namelen = namelen;
 	if (!intent_only)
-		fill_stat_cache_info(ce, st);
+		fill_stat_cache_info(istate, ce, st);
 	else
 		ce->ce_flags |= CE_INTENT_TO_ADD;
 
@@ -693,7 +754,7 @@ int add_to_index(struct index_state *ist
 	if (ignore_case) {
 		adjust_dirname_case(istate, ce->name);
 	}
-	if (!(flags & HASH_RENORMALIZE)) {
+	if (!(flags & ADD_CACHE_RENORMALIZE)) {
 		alias = index_file_exists(istate, ce->name,
 					  ce_namelen(ce), ignore_case);
 		if (alias &&
@@ -704,14 +765,14 @@ int add_to_index(struct index_state *ist
 				ce_mark_uptodate(alias);
 			alias->ce_flags |= CE_ADDED;
 
-			free(ce);
+			discard_cache_entry(ce);
 			return 0;
 		}
 	}
 	if (!intent_only) {
-		if (index_path(&ce->oid, path, st, newflags)) {
-			free(ce);
-			return error("unable to index file %s", path);
+		if (index_path(istate, &ce->oid, path, st, hash_flags)) {
+			discard_cache_entry(ce);
+			return error(_("unable to index file '%s'"), path);
 		}
 	} else
 		set_object_name_for_intent_to_add_entry(ce);
@@ -723,14 +784,14 @@ int add_to_index(struct index_state *ist
 	/* It was suspected to be racily clean, but it turns out to be Ok */
 	was_same = (alias &&
 		    !ce_stage(alias) &&
-		    !oidcmp(&alias->oid, &ce->oid) &&
+		    oideq(&alias->oid, &ce->oid) &&
 		    ce->ce_mode == alias->ce_mode);
 
 	if (pretend)
-		free(ce);
+		discard_cache_entry(ce);
 	else if (add_index_entry(istate, ce, add_option)) {
-		free(ce);
-		return error("unable to add %s to index", path);
+		discard_cache_entry(ce);
+		return error(_("unable to add '%s' to index"), path);
 	}
 	if (verbose && !was_same)
 		printf("add '%s'\n", path);
@@ -741,38 +802,73 @@ int add_file_to_index(struct index_state
 {
 	struct stat st;
 	if (lstat(path, &st))
-		die_errno("unable to stat '%s'", path);
+		die_errno(_("unable to stat '%s'"), path);
 	return add_to_index(istate, path, &st, flags);
 }
 
-struct cache_entry *make_cache_entry(unsigned int mode,
-		const unsigned char *sha1, const char *path, int stage,
-		unsigned int refresh_options)
+struct cache_entry *make_empty_cache_entry(struct index_state *istate, size_t len)
+{
+	return mem_pool__ce_calloc(find_mem_pool(istate), len);
+}
+
+struct cache_entry *make_empty_transient_cache_entry(size_t len)
+{
+	return xcalloc(1, cache_entry_size(len));
+}
+
+struct cache_entry *make_cache_entry(struct index_state *istate,
+				     unsigned int mode,
+				     const struct object_id *oid,
+				     const char *path,
+				     int stage,
+				     unsigned int refresh_options)
 {
-	int size, len;
 	struct cache_entry *ce, *ret;
+	int len;
 
 	if (!verify_path(path, mode)) {
-		error("Invalid path '%s'", path);
+		error(_("invalid path '%s'"), path);
 		return NULL;
 	}
 
 	len = strlen(path);
-	size = cache_entry_size(len);
-	ce = xcalloc(1, size);
+	ce = make_empty_cache_entry(istate, len);
 
-	hashcpy(ce->oid.hash, sha1);
+	oidcpy(&ce->oid, oid);
 	memcpy(ce->name, path, len);
 	ce->ce_flags = create_ce_flags(stage);
 	ce->ce_namelen = len;
 	ce->ce_mode = create_ce_mode(mode);
 
-	ret = refresh_cache_entry(ce, refresh_options);
+	ret = refresh_cache_entry(istate, ce, refresh_options);
 	if (ret != ce)
-		free(ce);
+		discard_cache_entry(ce);
 	return ret;
 }
 
+struct cache_entry *make_transient_cache_entry(unsigned int mode, const struct object_id *oid,
+					       const char *path, int stage)
+{
+	struct cache_entry *ce;
+	int len;
+
+	if (!verify_path(path, mode)) {
+		error(_("invalid path '%s'"), path);
+		return NULL;
+	}
+
+	len = strlen(path);
+	ce = make_empty_transient_cache_entry(len);
+
+	oidcpy(&ce->oid, oid);
+	memcpy(ce->name, path, len);
+	ce->ce_flags = create_ce_flags(stage);
+	ce->ce_namelen = len;
+	ce->ce_mode = create_ce_mode(mode);
+
+	return ce;
+}
+
 /*
  * Chmod an index entry with either +x or -x.
  *
@@ -863,11 +959,14 @@ static int verify_dotfile(const char *re
 
 int verify_path(const char *path, unsigned mode)
 {
-	char c;
+	char c = 0;
 
 	if (has_dos_drive_prefix(path))
 		return 0;
 
+	if (!is_valid_path(path))
+		return 0;
+
 	goto inside;
 	for (;;) {
 		if (!c)
@@ -875,6 +974,7 @@ int verify_path(const char *path, unsign
 		if (is_dir_sep(c)) {
 inside:
 			if (protect_hfs) {
+
 				if (is_hfs_dotgit(path))
 					return 0;
 				if (S_ISLNK(mode)) {
@@ -883,6 +983,10 @@ inside:
 				}
 			}
 			if (protect_ntfs) {
+#ifdef GIT_WINDOWS_NATIVE
+				if (c == '\\')
+					return 0;
+#endif
 				if (is_ntfs_dotgit(path))
 					return 0;
 				if (S_ISLNK(mode)) {
@@ -895,7 +999,15 @@ inside:
 			if ((c == '.' && !verify_dotfile(path, mode)) ||
 			    is_dir_sep(c) || c == '\0')
 				return 0;
+		} else if (c == '\\' && protect_ntfs) {
+			if (is_ntfs_dotgit(path))
+				return 0;
+			if (S_ISLNK(mode)) {
+				if (is_ntfs_dotgitmodules(path))
+					return 0;
+			}
 		}
+
 		c = *path++;
 	}
 }
@@ -1180,7 +1292,7 @@ static int add_index_entry_with_check(st
 	 */
 	if (istate->cache_nr > 0 &&
 		strcmp(ce->name, istate->cache[istate->cache_nr - 1]->name) > 0)
-		pos = -istate->cache_nr - 1;
+		pos = index_pos_to_insert_pos(istate->cache_nr);
 	else
 		pos = index_name_stage_pos(istate, ce->name, ce_namelen(ce), ce_stage(ce));
 
@@ -1210,12 +1322,12 @@ static int add_index_entry_with_check(st
 	if (!ok_to_add)
 		return -1;
 	if (!verify_path(ce->name, ce->ce_mode))
-		return error("Invalid path '%s'", ce->name);
+		return error(_("invalid path '%s'"), ce->name);
 
 	if (!skip_df_check &&
 	    check_file_directory_conflict(istate, ce, pos, ok_to_replace)) {
 		if (!ok_to_replace)
-			return error("'%s' appears as both a file and as a directory",
+			return error(_("'%s' appears as both a file and as a directory"),
 				     ce->name);
 		pos = index_name_stage_pos(istate, ce->name, ce_namelen(ce), ce_stage(ce));
 		pos = -pos-1;
@@ -1268,7 +1380,7 @@ static struct cache_entry *refresh_cache
 {
 	struct stat st;
 	struct cache_entry *updated;
-	int changed, size;
+	int changed;
 	int refresh = options & CE_MATCH_REFRESH;
 	int ignore_valid = options & CE_MATCH_IGNORE_VALID;
 	int ignore_skip_worktree = options & CE_MATCH_IGNORE_SKIP_WORKTREE;
@@ -1336,7 +1448,7 @@ static struct cache_entry *refresh_cache
 			 */
 			if (!S_ISGITLINK(ce->ce_mode)) {
 				ce_mark_uptodate(ce);
-				mark_fsmonitor_valid(ce);
+				mark_fsmonitor_valid(istate, ce);
 			}
 			return ce;
 		}
@@ -1348,11 +1460,10 @@ static struct cache_entry *refresh_cache
 		return NULL;
 	}
 
-	size = ce_size(ce);
-	updated = xmalloc(size);
+	updated = make_empty_cache_entry(istate, ce_namelen(ce));
 	copy_cache_entry(updated, ce);
 	memcpy(updated->name, ce->name, ce->ce_namelen + 1);
-	fill_stat_cache_info(updated, &st);
+	fill_stat_cache_info(istate, updated, &st);
 	/*
 	 * If ignore_valid is not set, we should leave CE_VALID bit
 	 * alone.  Otherwise, paths marked with --no-assume-unchanged
@@ -1377,6 +1488,27 @@ static void show_file(const char * fmt,
 	printf(fmt, name);
 }
 
+int repo_refresh_and_write_index(struct repository *repo,
+				 unsigned int refresh_flags,
+				 unsigned int write_flags,
+				 int gentle,
+				 const struct pathspec *pathspec,
+				 char *seen, const char *header_msg)
+{
+	struct lock_file lock_file = LOCK_INIT;
+	int fd, ret = 0;
+
+	fd = repo_hold_locked_index(repo, &lock_file, 0);
+	if (!gentle && fd < 0)
+		return -1;
+	if (refresh_index(repo->index, refresh_flags, pathspec, seen, header_msg))
+		ret = 1;
+	if (0 <= fd && write_locked_index(repo->index, &lock_file, COMMIT_LOCK | write_flags))
+		ret = -1;
+	return ret;
+}
+
+
 int refresh_index(struct index_state *istate, unsigned int flags,
 		  const struct pathspec *pathspec,
 		  char *seen, const char *header_msg)
@@ -1398,13 +1530,24 @@ int refresh_index(struct index_state *is
 	const char *typechange_fmt;
 	const char *added_fmt;
 	const char *unmerged_fmt;
-	uint64_t start = getnanotime();
+	struct progress *progress = NULL;
 
-	modified_fmt = (in_porcelain ? "M\t%s\n" : "%s: needs update\n");
-	deleted_fmt = (in_porcelain ? "D\t%s\n" : "%s: needs update\n");
-	typechange_fmt = (in_porcelain ? "T\t%s\n" : "%s needs update\n");
-	added_fmt = (in_porcelain ? "A\t%s\n" : "%s needs update\n");
-	unmerged_fmt = (in_porcelain ? "U\t%s\n" : "%s: needs merge\n");
+	if (flags & REFRESH_PROGRESS && isatty(2))
+		progress = start_delayed_progress(_("Refresh index"),
+						  istate->cache_nr);
+
+	trace_performance_enter();
+	modified_fmt   = in_porcelain ? "M\t%s\n" : "%s: needs update\n";
+	deleted_fmt    = in_porcelain ? "D\t%s\n" : "%s: needs update\n";
+	typechange_fmt = in_porcelain ? "T\t%s\n" : "%s: needs update\n";
+	added_fmt      = in_porcelain ? "A\t%s\n" : "%s: needs update\n";
+	unmerged_fmt   = in_porcelain ? "U\t%s\n" : "%s: needs merge\n";
+	/*
+	 * Use the multi-threaded preload_index() to refresh most of the
+	 * cache entries quickly then in the single threaded loop below,
+	 * we only have to do the special cases that are left.
+	 */
+	preload_index(istate, pathspec, 0);
 	for (i = 0; i < istate->cache_nr; i++) {
 		struct cache_entry *ce, *new_entry;
 		int cache_errno = 0;
@@ -1415,7 +1558,7 @@ int refresh_index(struct index_state *is
 		if (ignore_submodules && S_ISGITLINK(ce->ce_mode))
 			continue;
 
-		if (pathspec && !ce_path_match(ce, pathspec, seen))
+		if (pathspec && !ce_path_match(istate, ce, pathspec, seen))
 			filtered = 1;
 
 		if (ce_stage(ce)) {
@@ -1438,6 +1581,8 @@ int refresh_index(struct index_state *is
 		new_entry = refresh_cache_ent(istate, ce, options, &cache_errno, &changed);
 		if (new_entry == ce)
 			continue;
+		if (progress)
+			display_progress(progress, i);
 		if (!new_entry) {
 			const char *fmt;
 
@@ -1469,14 +1614,19 @@ int refresh_index(struct index_state *is
 
 		replace_index_entry(istate, i, new_entry);
 	}
-	trace_performance_since(start, "refresh index");
+	if (progress) {
+		display_progress(progress, istate->cache_nr);
+		stop_progress(&progress);
+	}
+	trace_performance_leave("refresh index");
 	return has_errors;
 }
 
-struct cache_entry *refresh_cache_entry(struct cache_entry *ce,
-					       unsigned int options)
+struct cache_entry *refresh_cache_entry(struct index_state *istate,
+					struct cache_entry *ce,
+					unsigned int options)
 {
-	return refresh_cache_ent(&the_index, ce, options, NULL, NULL);
+	return refresh_cache_ent(istate, ce, options, NULL, NULL);
 }
 
 
@@ -1486,16 +1636,17 @@ struct cache_entry *refresh_cache_entry(
 
 #define INDEX_FORMAT_DEFAULT 3
 
-static unsigned int get_index_format_default(void)
+static unsigned int get_index_format_default(struct repository *r)
 {
 	char *envversion = getenv("GIT_INDEX_VERSION");
 	char *endp;
-	int value;
 	unsigned int version = INDEX_FORMAT_DEFAULT;
 
 	if (!envversion) {
-		if (!git_config_get_int("index.version", &value))
-			version = value;
+		prepare_repo_settings(r);
+
+		if (r->settings.index_version >= 0)
+			version = r->settings.index_version;
 		if (version < INDEX_FORMAT_LB || INDEX_FORMAT_UB < version) {
 			warning(_("index.version set, but the value is invalid.\n"
 				  "Using version %i"), INDEX_FORMAT_DEFAULT);
@@ -1531,39 +1682,24 @@ struct ondisk_cache_entry {
 	uint32_t uid;
 	uint32_t gid;
 	uint32_t size;
-	unsigned char sha1[20];
-	uint16_t flags;
-	char name[FLEX_ARRAY]; /* more */
-};
-
-/*
- * This struct is used when CE_EXTENDED bit is 1
- * The struct must match ondisk_cache_entry exactly from
- * ctime till flags
- */
-struct ondisk_cache_entry_extended {
-	struct cache_time ctime;
-	struct cache_time mtime;
-	uint32_t dev;
-	uint32_t ino;
-	uint32_t mode;
-	uint32_t uid;
-	uint32_t gid;
-	uint32_t size;
-	unsigned char sha1[20];
-	uint16_t flags;
-	uint16_t flags2;
-	char name[FLEX_ARRAY]; /* more */
+	/*
+	 * unsigned char hash[hashsz];
+	 * uint16_t flags;
+	 * if (flags & CE_EXTENDED)
+	 *	uint16_t flags2;
+	 */
+	unsigned char data[GIT_MAX_RAWSZ + 2 * sizeof(uint16_t)];
+	char name[FLEX_ARRAY];
 };
 
 /* These are only used for v3 or lower */
 #define align_padding_size(size, len) ((size + (len) + 8) & ~7) - (size + len)
-#define align_flex_name(STRUCT,len) ((offsetof(struct STRUCT,name) + (len) + 8) & ~7)
+#define align_flex_name(STRUCT,len) ((offsetof(struct STRUCT,data) + (len) + 8) & ~7)
 #define ondisk_cache_entry_size(len) align_flex_name(ondisk_cache_entry,len)
-#define ondisk_cache_entry_extended_size(len) align_flex_name(ondisk_cache_entry_extended,len)
-#define ondisk_ce_size(ce) (((ce)->ce_flags & CE_EXTENDED) ? \
-			    ondisk_cache_entry_extended_size(ce_namelen(ce)) : \
-			    ondisk_cache_entry_size(ce_namelen(ce)))
+#define ondisk_data_size(flags, len) (the_hash_algo->rawsz + \
+				     ((flags & CE_EXTENDED) ? 2 : 1) * sizeof(uint16_t) + len)
+#define ondisk_data_size_max(len) (ondisk_data_size(CE_EXTENDED, len))
+#define ondisk_ce_size(ce) (ondisk_cache_entry_size(ondisk_data_size((ce)->ce_flags, ce_namelen(ce))))
 
 /* Allow fsck to force verification of the index checksum. */
 int verify_index_checksum;
@@ -1571,17 +1707,17 @@ int verify_index_checksum;
 /* Allow fsck to force verification of the cache entry order. */
 int verify_ce_order;
 
-static int verify_hdr(struct cache_header *hdr, unsigned long size)
+static int verify_hdr(const struct cache_header *hdr, unsigned long size)
 {
 	git_hash_ctx c;
 	unsigned char hash[GIT_MAX_RAWSZ];
 	int hdr_version;
 
 	if (hdr->hdr_signature != htonl(CACHE_SIGNATURE))
-		return error("bad signature");
+		return error(_("bad signature 0x%08x"), hdr->hdr_signature);
 	hdr_version = ntohl(hdr->hdr_version);
 	if (hdr_version < INDEX_FORMAT_LB || INDEX_FORMAT_UB < hdr_version)
-		return error("bad index version %d", hdr_version);
+		return error(_("bad index version %d"), hdr_version);
 
 	if (!verify_index_checksum)
 		return 0;
@@ -1589,13 +1725,13 @@ static int verify_hdr(struct cache_heade
 	the_hash_algo->init_fn(&c);
 	the_hash_algo->update_fn(&c, hdr, size - the_hash_algo->rawsz);
 	the_hash_algo->final_fn(hash, &c);
-	if (hashcmp(hash, (unsigned char *)hdr + size - the_hash_algo->rawsz))
-		return error("bad index file sha1 signature");
+	if (!hasheq(hash, (unsigned char *)hdr + size - the_hash_algo->rawsz))
+		return error(_("bad index file sha1 signature"));
 	return 0;
 }
 
 static int read_index_extension(struct index_state *istate,
-				const char *ext, void *data, unsigned long sz)
+				const char *ext, const char *data, unsigned long sz)
 {
 	switch (CACHE_EXT(ext)) {
 	case CACHE_EXT_TREE:
@@ -1614,32 +1750,81 @@ static int read_index_extension(struct i
 	case CACHE_EXT_FSMONITOR:
 		read_fsmonitor_extension(istate, data, sz);
 		break;
+	case CACHE_EXT_ENDOFINDEXENTRIES:
+	case CACHE_EXT_INDEXENTRYOFFSETTABLE:
+		/* already handled in do_read_index() */
+		break;
 	default:
 		if (*ext < 'A' || 'Z' < *ext)
-			return error("index uses %.4s extension, which we do not understand",
+			return error(_("index uses %.4s extension, which we do not understand"),
 				     ext);
-		fprintf(stderr, "ignoring %.4s extension\n", ext);
+		fprintf_ln(stderr, _("ignoring %.4s extension"), ext);
 		break;
 	}
 	return 0;
 }
 
-int hold_locked_index(struct lock_file *lk, int lock_flags)
+static struct cache_entry *create_from_disk(struct mem_pool *ce_mem_pool,
+					    unsigned int version,
+					    struct ondisk_cache_entry *ondisk,
+					    unsigned long *ent_size,
+					    const struct cache_entry *previous_ce)
 {
-	return hold_lock_file_for_update(lk, get_index_file(), lock_flags);
-}
+	struct cache_entry *ce;
+	size_t len;
+	const char *name;
+	const unsigned hashsz = the_hash_algo->rawsz;
+	const uint16_t *flagsp = (const uint16_t *)(ondisk->data + hashsz);
+	unsigned int flags;
+	size_t copy_len = 0;
+	/*
+	 * Adjacent cache entries tend to share the leading paths, so it makes
+	 * sense to only store the differences in later entries.  In the v4
+	 * on-disk format of the index, each on-disk cache entry stores the
+	 * number of bytes to be stripped from the end of the previous name,
+	 * and the bytes to append to the result, to come up with its name.
+	 */
+	int expand_name_field = version == 4;
 
-int read_index(struct index_state *istate)
-{
-	return read_index_from(istate, get_index_file(), get_git_dir());
-}
+	/* On-disk flags are just 16 bits */
+	flags = get_be16(flagsp);
+	len = flags & CE_NAMEMASK;
 
-static struct cache_entry *cache_entry_from_ondisk(struct ondisk_cache_entry *ondisk,
-						   unsigned int flags,
-						   const char *name,
-						   size_t len)
-{
-	struct cache_entry *ce = xmalloc(cache_entry_size(len));
+	if (flags & CE_EXTENDED) {
+		int extended_flags;
+		extended_flags = get_be16(flagsp + 1) << 16;
+		/* We do not yet understand any bit out of CE_EXTENDED_FLAGS */
+		if (extended_flags & ~CE_EXTENDED_FLAGS)
+			die(_("unknown index entry format 0x%08x"), extended_flags);
+		flags |= extended_flags;
+		name = (const char *)(flagsp + 2);
+	}
+	else
+		name = (const char *)(flagsp + 1);
+
+	if (expand_name_field) {
+		const unsigned char *cp = (const unsigned char *)name;
+		size_t strip_len, previous_len;
+
+		/* If we're at the beginning of a block, ignore the previous name */
+		strip_len = decode_varint(&cp);
+		if (previous_ce) {
+			previous_len = previous_ce->ce_namelen;
+			if (previous_len < strip_len)
+				die(_("malformed name field in the index, near path '%s'"),
+					previous_ce->name);
+			copy_len = previous_len - strip_len;
+		}
+		name = (const char *)cp;
+	}
+
+	if (len == CE_NAMEMASK) {
+		len = strlen(name);
+		if (expand_name_field)
+			len += copy_len;
+	}
+
+	ce = mem_pool__ce_alloc(ce_mem_pool, len);
 
 	ce->ce_stat_data.sd_ctime.sec = get_be32(&ondisk->ctime.sec);
 	ce->ce_stat_data.sd_mtime.sec = get_be32(&ondisk->mtime.sec);
@@ -1654,75 +1839,18 @@ static struct cache_entry *cache_entry_f
 	ce->ce_flags = flags & ~CE_NAMEMASK;
 	ce->ce_namelen = len;
 	ce->index = 0;
-	hashcpy(ce->oid.hash, ondisk->sha1);
+	hashcpy(ce->oid.hash, ondisk->data);
 	memcpy(ce->name, name, len);
 	ce->name[len] = '\0';
-	return ce;
-}
-
-/*
- * Adjacent cache entries tend to share the leading paths, so it makes
- * sense to only store the differences in later entries.  In the v4
- * on-disk format of the index, each on-disk cache entry stores the
- * number of bytes to be stripped from the end of the previous name,
- * and the bytes to append to the result, to come up with its name.
- */
-static unsigned long expand_name_field(struct strbuf *name, const char *cp_)
-{
-	const unsigned char *ep, *cp = (const unsigned char *)cp_;
-	size_t len = decode_varint(&cp);
-
-	if (name->len < len)
-		die("malformed name field in the index");
-	strbuf_remove(name, name->len - len, len);
-	for (ep = cp; *ep; ep++)
-		; /* find the end */
-	strbuf_add(name, cp, ep - cp);
-	return (const char *)ep + 1 - cp_;
-}
-
-static struct cache_entry *create_from_disk(struct ondisk_cache_entry *ondisk,
-					    unsigned long *ent_size,
-					    struct strbuf *previous_name)
-{
-	struct cache_entry *ce;
-	size_t len;
-	const char *name;
-	unsigned int flags;
-
-	/* On-disk flags are just 16 bits */
-	flags = get_be16(&ondisk->flags);
-	len = flags & CE_NAMEMASK;
-
-	if (flags & CE_EXTENDED) {
-		struct ondisk_cache_entry_extended *ondisk2;
-		int extended_flags;
-		ondisk2 = (struct ondisk_cache_entry_extended *)ondisk;
-		extended_flags = get_be16(&ondisk2->flags2) << 16;
-		/* We do not yet understand any bit out of CE_EXTENDED_FLAGS */
-		if (extended_flags & ~CE_EXTENDED_FLAGS)
-			die("Unknown index entry format %08x", extended_flags);
-		flags |= extended_flags;
-		name = ondisk2->name;
-	}
-	else
-		name = ondisk->name;
 
-	if (!previous_name) {
-		/* v3 and earlier */
-		if (len == CE_NAMEMASK)
-			len = strlen(name);
-		ce = cache_entry_from_ondisk(ondisk, flags, name, len);
-
-		*ent_size = ondisk_ce_size(ce);
+	if (expand_name_field) {
+		if (copy_len)
+			memcpy(ce->name, previous_ce->name, copy_len);
+		memcpy(ce->name + copy_len, name, len + 1 - copy_len);
+		*ent_size = (name - ((char *)ondisk)) + len + 1 - copy_len;
 	} else {
-		unsigned long consumed;
-		consumed = expand_name_field(previous_name, name);
-		ce = cache_entry_from_ondisk(ondisk, flags,
-					     previous_name->buf,
-					     previous_name->len);
-
-		*ent_size = (name - ((char *)ondisk)) + consumed;
+		memcpy(ce->name, name, len + 1);
+		*ent_size = ondisk_ce_size(ce);
 	}
 	return ce;
 }
@@ -1740,13 +1868,13 @@ static void check_ce_order(struct index_
 		int name_compare = strcmp(ce->name, next_ce->name);
 
 		if (0 < name_compare)
-			die("unordered stage entries in index");
+			die(_("unordered stage entries in index"));
 		if (!name_compare) {
 			if (!ce_stage(ce))
-				die("multiple stage entries for merged file '%s'",
+				die(_("multiple stage entries for merged file '%s'"),
 				    ce->name);
 			if (ce_stage(ce) > ce_stage(next_ce))
-				die("unordered stage entries for '%s'",
+				die(_("unordered stage entries for '%s'"),
 				    ce->name);
 		}
 	}
@@ -1754,18 +1882,17 @@ static void check_ce_order(struct index_
 
 static void tweak_untracked_cache(struct index_state *istate)
 {
-	switch (git_config_get_untracked_cache()) {
-	case -1: /* keep: do nothing */
-		break;
-	case 0: /* false */
+	struct repository *r = the_repository;
+
+	prepare_repo_settings(r);
+
+	if (r->settings.core_untracked_cache  == UNTRACKED_CACHE_REMOVE) {
 		remove_untracked_cache(istate);
-		break;
-	case 1: /* true */
-		add_untracked_cache(istate);
-		break;
-	default: /* unknown value: do nothing */
-		break;
+		return;
 	}
+
+	if (r->settings.core_untracked_cache == UNTRACKED_CACHE_WRITE)
+		add_untracked_cache(istate);
 }
 
 static void tweak_split_index(struct index_state *istate)
@@ -1792,16 +1919,244 @@ static void post_read_index_from(struct
 	tweak_fsmonitor(istate);
 }
 
+static size_t estimate_cache_size_from_compressed(unsigned int entries)
+{
+	return entries * (sizeof(struct cache_entry) + CACHE_ENTRY_PATH_LENGTH);
+}
+
+static size_t estimate_cache_size(size_t ondisk_size, unsigned int entries)
+{
+	long per_entry = sizeof(struct cache_entry) - sizeof(struct ondisk_cache_entry);
+
+	/*
+	 * Account for potential alignment differences.
+	 */
+	per_entry += align_padding_size(per_entry, 0);
+	return ondisk_size + entries * per_entry;
+}
+
+struct index_entry_offset
+{
+	/* starting byte offset into index file, count of index entries in this block */
+	int offset, nr;
+};
+
+struct index_entry_offset_table
+{
+	int nr;
+	struct index_entry_offset entries[FLEX_ARRAY];
+};
+
+static struct index_entry_offset_table *read_ieot_extension(const char *mmap, size_t mmap_size, size_t offset);
+static void write_ieot_extension(struct strbuf *sb, struct index_entry_offset_table *ieot);
+
+static size_t read_eoie_extension(const char *mmap, size_t mmap_size);
+static void write_eoie_extension(struct strbuf *sb, git_hash_ctx *eoie_context, size_t offset);
+
+struct load_index_extensions
+{
+	pthread_t pthread;
+	struct index_state *istate;
+	const char *mmap;
+	size_t mmap_size;
+	unsigned long src_offset;
+};
+
+static void *load_index_extensions(void *_data)
+{
+	struct load_index_extensions *p = _data;
+	unsigned long src_offset = p->src_offset;
+
+	while (src_offset <= p->mmap_size - the_hash_algo->rawsz - 8) {
+		/* After an array of active_nr index entries,
+		 * there can be arbitrary number of extended
+		 * sections, each of which is prefixed with
+		 * extension name (4-byte) and section length
+		 * in 4-byte network byte order.
+		 */
+		uint32_t extsize = get_be32(p->mmap + src_offset + 4);
+		if (read_index_extension(p->istate,
+					 p->mmap + src_offset,
+					 p->mmap + src_offset + 8,
+					 extsize) < 0) {
+			munmap((void *)p->mmap, p->mmap_size);
+			die(_("index file corrupt"));
+		}
+		src_offset += 8;
+		src_offset += extsize;
+	}
+
+	return NULL;
+}
+
+/*
+ * A helper function that will load the specified range of cache entries
+ * from the memory mapped file and add them to the given index.
+ */
+static unsigned long load_cache_entry_block(struct index_state *istate,
+			struct mem_pool *ce_mem_pool, int offset, int nr, const char *mmap,
+			unsigned long start_offset, const struct cache_entry *previous_ce)
+{
+	int i;
+	unsigned long src_offset = start_offset;
+
+	for (i = offset; i < offset + nr; i++) {
+		struct ondisk_cache_entry *disk_ce;
+		struct cache_entry *ce;
+		unsigned long consumed;
+
+		disk_ce = (struct ondisk_cache_entry *)(mmap + src_offset);
+		ce = create_from_disk(ce_mem_pool, istate->version, disk_ce, &consumed, previous_ce);
+		set_index_entry(istate, i, ce);
+
+		src_offset += consumed;
+		previous_ce = ce;
+	}
+	return src_offset - start_offset;
+}
+
+static unsigned long load_all_cache_entries(struct index_state *istate,
+			const char *mmap, size_t mmap_size, unsigned long src_offset)
+{
+	unsigned long consumed;
+
+	if (istate->version == 4) {
+		mem_pool_init(&istate->ce_mem_pool,
+				estimate_cache_size_from_compressed(istate->cache_nr));
+	} else {
+		mem_pool_init(&istate->ce_mem_pool,
+				estimate_cache_size(mmap_size, istate->cache_nr));
+	}
+
+	consumed = load_cache_entry_block(istate, istate->ce_mem_pool,
+					0, istate->cache_nr, mmap, src_offset, NULL);
+	return consumed;
+}
+
+/*
+ * Mostly randomly chosen maximum thread counts: we
+ * cap the parallelism to online_cpus() threads, and we want
+ * to have at least 10000 cache entries per thread for it to
+ * be worth starting a thread.
+ */
+
+#define THREAD_COST		(10000)
+
+struct load_cache_entries_thread_data
+{
+	pthread_t pthread;
+	struct index_state *istate;
+	struct mem_pool *ce_mem_pool;
+	int offset;
+	const char *mmap;
+	struct index_entry_offset_table *ieot;
+	int ieot_start;		/* starting index into the ieot array */
+	int ieot_blocks;	/* count of ieot entries to process */
+	unsigned long consumed;	/* return # of bytes in index file processed */
+};
+
+/*
+ * A thread proc to run the load_cache_entries() computation
+ * across multiple background threads.
+ */
+static void *load_cache_entries_thread(void *_data)
+{
+	struct load_cache_entries_thread_data *p = _data;
+	int i;
+
+	/* iterate across all ieot blocks assigned to this thread */
+	for (i = p->ieot_start; i < p->ieot_start + p->ieot_blocks; i++) {
+		p->consumed += load_cache_entry_block(p->istate, p->ce_mem_pool,
+			p->offset, p->ieot->entries[i].nr, p->mmap, p->ieot->entries[i].offset, NULL);
+		p->offset += p->ieot->entries[i].nr;
+	}
+	return NULL;
+}
+
+static unsigned long load_cache_entries_threaded(struct index_state *istate, const char *mmap, size_t mmap_size,
+						 int nr_threads, struct index_entry_offset_table *ieot)
+{
+	int i, offset, ieot_blocks, ieot_start, err;
+	struct load_cache_entries_thread_data *data;
+	unsigned long consumed = 0;
+
+	/* a little sanity checking */
+	if (istate->name_hash_initialized)
+		BUG("the name hash isn't thread safe");
+
+	mem_pool_init(&istate->ce_mem_pool, 0);
+
+	/* ensure we have no more threads than we have blocks to process */
+	if (nr_threads > ieot->nr)
+		nr_threads = ieot->nr;
+	data = xcalloc(nr_threads, sizeof(*data));
+
+	offset = ieot_start = 0;
+	ieot_blocks = DIV_ROUND_UP(ieot->nr, nr_threads);
+	for (i = 0; i < nr_threads; i++) {
+		struct load_cache_entries_thread_data *p = &data[i];
+		int nr, j;
+
+		if (ieot_start + ieot_blocks > ieot->nr)
+			ieot_blocks = ieot->nr - ieot_start;
+
+		p->istate = istate;
+		p->offset = offset;
+		p->mmap = mmap;
+		p->ieot = ieot;
+		p->ieot_start = ieot_start;
+		p->ieot_blocks = ieot_blocks;
+
+		/* create a mem_pool for each thread */
+		nr = 0;
+		for (j = p->ieot_start; j < p->ieot_start + p->ieot_blocks; j++)
+			nr += p->ieot->entries[j].nr;
+		if (istate->version == 4) {
+			mem_pool_init(&p->ce_mem_pool,
+				estimate_cache_size_from_compressed(nr));
+		} else {
+			mem_pool_init(&p->ce_mem_pool,
+				estimate_cache_size(mmap_size, nr));
+		}
+
+		err = pthread_create(&p->pthread, NULL, load_cache_entries_thread, p);
+		if (err)
+			die(_("unable to create load_cache_entries thread: %s"), strerror(err));
+
+		/* increment by the number of cache entries in the ieot block being processed */
+		for (j = 0; j < ieot_blocks; j++)
+			offset += ieot->entries[ieot_start + j].nr;
+		ieot_start += ieot_blocks;
+	}
+
+	for (i = 0; i < nr_threads; i++) {
+		struct load_cache_entries_thread_data *p = &data[i];
+
+		err = pthread_join(p->pthread, NULL);
+		if (err)
+			die(_("unable to join load_cache_entries thread: %s"), strerror(err));
+		mem_pool_combine(istate->ce_mem_pool, p->ce_mem_pool);
+		consumed += p->consumed;
+	}
+
+	free(data);
+
+	return consumed;
+}
+
 /* remember to discard_cache() before reading a different cache! */
 int do_read_index(struct index_state *istate, const char *path, int must_exist)
 {
-	int fd, i;
+	int fd;
 	struct stat st;
 	unsigned long src_offset;
-	struct cache_header *hdr;
-	void *mmap;
+	const struct cache_header *hdr;
+	const char *mmap;
 	size_t mmap_size;
-	struct strbuf previous_name_buf = STRBUF_INIT, *previous_name;
+	struct load_index_extensions p;
+	size_t extension_offset = 0;
+	int nr_threads, cpus;
+	struct index_entry_offset_table *ieot = NULL;
 
 	if (istate->initialized)
 		return istate->cache_nr;
@@ -1812,22 +2167,22 @@ int do_read_index(struct index_state *is
 	if (fd < 0) {
 		if (!must_exist && errno == ENOENT)
 			return 0;
-		die_errno("%s: index file open failed", path);
+		die_errno(_("%s: index file open failed"), path);
 	}
 
 	if (fstat(fd, &st))
-		die_errno("cannot stat the open index");
+		die_errno(_("%s: cannot stat the open index"), path);
 
 	mmap_size = xsize_t(st.st_size);
 	if (mmap_size < sizeof(struct cache_header) + the_hash_algo->rawsz)
-		die("index file smaller than expected");
+		die(_("%s: index file smaller than expected"), path);
 
-	mmap = xmmap(NULL, mmap_size, PROT_READ, MAP_PRIVATE, fd, 0);
+	mmap = xmmap_gently(NULL, mmap_size, PROT_READ, MAP_PRIVATE, fd, 0);
 	if (mmap == MAP_FAILED)
-		die_errno("unable to map index file");
+		die_errno(_("%s: unable to map index file"), path);
 	close(fd);
 
-	hdr = mmap;
+	hdr = (const struct cache_header *)mmap;
 	if (verify_hdr(hdr, mmap_size) < 0)
 		goto unmap;
 
@@ -1838,51 +2193,82 @@ int do_read_index(struct index_state *is
 	istate->cache = xcalloc(istate->cache_alloc, sizeof(*istate->cache));
 	istate->initialized = 1;
 
-	if (istate->version == 4)
-		previous_name = &previous_name_buf;
-	else
-		previous_name = NULL;
+	p.istate = istate;
+	p.mmap = mmap;
+	p.mmap_size = mmap_size;
 
 	src_offset = sizeof(*hdr);
-	for (i = 0; i < istate->cache_nr; i++) {
-		struct ondisk_cache_entry *disk_ce;
-		struct cache_entry *ce;
-		unsigned long consumed;
 
-		disk_ce = (struct ondisk_cache_entry *)((char *)mmap + src_offset);
-		ce = create_from_disk(disk_ce, &consumed, previous_name);
-		set_index_entry(istate, i, ce);
+	if (git_config_get_index_threads(&nr_threads))
+		nr_threads = 1;
 
-		src_offset += consumed;
+	/* TODO: does creating more threads than cores help? */
+	if (!nr_threads) {
+		nr_threads = istate->cache_nr / THREAD_COST;
+		cpus = online_cpus();
+		if (nr_threads > cpus)
+			nr_threads = cpus;
+	}
+
+	if (!HAVE_THREADS)
+		nr_threads = 1;
+
+	if (nr_threads > 1) {
+		extension_offset = read_eoie_extension(mmap, mmap_size);
+		if (extension_offset) {
+			int err;
+
+			p.src_offset = extension_offset;
+			err = pthread_create(&p.pthread, NULL, load_index_extensions, &p);
+			if (err)
+				die(_("unable to create load_index_extensions thread: %s"), strerror(err));
+
+			nr_threads--;
+		}
 	}
-	strbuf_release(&previous_name_buf);
+
+	/*
+	 * Locate and read the index entry offset table so that we can use it
+	 * to multi-thread the reading of the cache entries.
+	 */
+	if (extension_offset && nr_threads > 1)
+		ieot = read_ieot_extension(mmap, mmap_size, extension_offset);
+
+	if (ieot) {
+		src_offset += load_cache_entries_threaded(istate, mmap, mmap_size, nr_threads, ieot);
+		free(ieot);
+	} else {
+		src_offset += load_all_cache_entries(istate, mmap, mmap_size, src_offset);
+	}
+
 	istate->timestamp.sec = st.st_mtime;
 	istate->timestamp.nsec = ST_MTIME_NSEC(st);
 
-	while (src_offset <= mmap_size - the_hash_algo->rawsz - 8) {
-		/* After an array of active_nr index entries,
-		 * there can be arbitrary number of extended
-		 * sections, each of which is prefixed with
-		 * extension name (4-byte) and section length
-		 * in 4-byte network byte order.
-		 */
-		uint32_t extsize;
-		memcpy(&extsize, (char *)mmap + src_offset + 4, 4);
-		extsize = ntohl(extsize);
-		if (read_index_extension(istate,
-					 (const char *) mmap + src_offset,
-					 (char *) mmap + src_offset + 8,
-					 extsize) < 0)
-			goto unmap;
-		src_offset += 8;
-		src_offset += extsize;
+	/* if we created a thread, join it otherwise load the extensions on the primary thread */
+	if (extension_offset) {
+		int ret = pthread_join(p.pthread, NULL);
+		if (ret)
+			die(_("unable to join load_index_extensions thread: %s"), strerror(ret));
+	} else {
+		p.src_offset = src_offset;
+		load_index_extensions(&p);
 	}
-	munmap(mmap, mmap_size);
+	munmap((void *)mmap, mmap_size);
+
+	/*
+	 * TODO trace2: replace "the_repository" with the actual repo instance
+	 * that is associated with the given "istate".
+	 */
+	trace2_data_intmax("index", the_repository, "read/version",
+			   istate->version);
+	trace2_data_intmax("index", the_repository, "read/cache_nr",
+			   istate->cache_nr);
+
 	return istate->cache_nr;
 
 unmap:
-	munmap(mmap, mmap_size);
-	die("index file corrupt");
+	munmap((void *)mmap, mmap_size);
+	die(_("index file corrupt"));
 }
 
 /*
@@ -1894,13 +2280,12 @@ unmap:
 static void freshen_shared_index(const char *shared_index, int warn)
 {
 	if (!check_and_freshen_file(shared_index, 1) && warn)
-		warning("could not freshen shared index '%s'", shared_index);
+		warning(_("could not freshen shared index '%s'"), shared_index);
 }
 
 int read_index_from(struct index_state *istate, const char *path,
 		    const char *gitdir)
 {
-	uint64_t start = getnanotime();
 	struct split_index *split_index;
 	int ret;
 	char *base_oid_hex;
@@ -1910,8 +2295,17 @@ int read_index_from(struct index_state *
 	if (istate->initialized)
 		return istate->cache_nr;
 
+	/*
+	 * TODO trace2: replace "the_repository" with the actual repo instance
+	 * that is associated with the given "istate".
+	 */
+	trace2_region_enter_printf("index", "do_read_index", the_repository,
+				   "%s", path);
+	trace_performance_enter();
 	ret = do_read_index(istate, path, 0);
-	trace_performance_since(start, "read cache %s", path);
+	trace_performance_leave("read cache %s", path);
+	trace2_region_leave_printf("index", "do_read_index", the_repository,
+				   "%s", path);
 
 	split_index = istate->split_index;
 	if (!split_index || is_null_oid(&split_index->base_oid)) {
@@ -1919,6 +2313,7 @@ int read_index_from(struct index_state *
 		return ret;
 	}
 
+	trace_performance_enter();
 	if (split_index->base)
 		discard_index(split_index->base);
 	else
@@ -1926,16 +2321,20 @@ int read_index_from(struct index_state *
 
 	base_oid_hex = oid_to_hex(&split_index->base_oid);
 	base_path = xstrfmt("%s/sharedindex.%s", gitdir, base_oid_hex);
+	trace2_region_enter_printf("index", "shared/do_read_index",
+				   the_repository, "%s", base_path);
 	ret = do_read_index(split_index->base, base_path, 1);
-	if (oidcmp(&split_index->base_oid, &split_index->base->oid))
-		die("broken index, expect %s in %s, got %s",
+	trace2_region_leave_printf("index", "shared/do_read_index",
+				   the_repository, "%s", base_path);
+	if (!oideq(&split_index->base_oid, &split_index->base->oid))
+		die(_("broken index, expect %s in %s, got %s"),
 		    base_oid_hex, base_path,
 		    oid_to_hex(&split_index->base->oid));
 
 	freshen_shared_index(base_path, 0);
 	merge_base_index(istate);
 	post_read_index_from(istate);
-	trace_performance_since(start, "read cache %s", base_path);
+	trace_performance_leave("read cache %s", base_path);
 	free(base_path);
 	return ret;
 }
@@ -1947,17 +2346,15 @@ int is_index_unborn(struct index_state *
 
 int discard_index(struct index_state *istate)
 {
-	int i;
+	/*
+	 * Cache entries in istate->cache[] should have been allocated
+	 * from the memory pool associated with this index, or from an
+	 * associated split_index. There is no need to free individual
+	 * cache entries. validate_cache_entries can detect when this
+	 * assertion does not hold.
+	 */
+	validate_cache_entries(istate);
 
-	for (i = 0; i < istate->cache_nr; i++) {
-		if (istate->cache[i]->index &&
-		    istate->split_index &&
-		    istate->split_index->base &&
-		    istate->cache[i]->index <= istate->split_index->base->cache_nr &&
-		    istate->cache[i] == istate->split_index->base->cache[istate->cache[i]->index - 1])
-			continue;
-		free(istate->cache[i]);
-	}
 	resolve_undo_clear_index(istate);
 	istate->cache_nr = 0;
 	istate->cache_changed = 0;
@@ -1966,14 +2363,53 @@ int discard_index(struct index_state *is
 	free_name_hash(istate);
 	cache_tree_free(&(istate->cache_tree));
 	istate->initialized = 0;
+	istate->fsmonitor_has_run_once = 0;
 	FREE_AND_NULL(istate->cache);
 	istate->cache_alloc = 0;
 	discard_split_index(istate);
 	free_untracked_cache(istate->untracked);
 	istate->untracked = NULL;
+
+	if (istate->ce_mem_pool) {
+		mem_pool_discard(istate->ce_mem_pool, should_validate_cache_entries());
+		istate->ce_mem_pool = NULL;
+	}
+
 	return 0;
 }
 
+/*
+ * Validate the cache entries of this index.
+ * All cache entries associated with this index
+ * should have been allocated by the memory pool
+ * associated with this index, or by a referenced
+ * split index.
+ */
+void validate_cache_entries(const struct index_state *istate)
+{
+	int i;
+
+	if (!should_validate_cache_entries() ||!istate || !istate->initialized)
+		return;
+
+	for (i = 0; i < istate->cache_nr; i++) {
+		if (!istate) {
+			BUG("cache entry is not allocated from expected memory pool");
+		} else if (!istate->ce_mem_pool ||
+			!mem_pool_contains(istate->ce_mem_pool, istate->cache[i])) {
+			if (!istate->split_index ||
+				!istate->split_index->base ||
+				!istate->split_index->base->ce_mem_pool ||
+				!mem_pool_contains(istate->split_index->base->ce_mem_pool, istate->cache[i])) {
+				BUG("cache entry is not allocated from expected memory pool");
+			}
+		}
+	}
+
+	if (istate->split_index)
+		validate_cache_entries(istate->split_index->base);
+}
+
 int unmerged_index(const struct index_state *istate)
 {
 	int i;
@@ -1984,6 +2420,42 @@ int unmerged_index(const struct index_st
 	return 0;
 }
 
+int repo_index_has_changes(struct repository *repo,
+			   struct tree *tree,
+			   struct strbuf *sb)
+{
+	struct index_state *istate = repo->index;
+	struct object_id cmp;
+	int i;
+
+	if (tree)
+		cmp = tree->object.oid;
+	if (tree || !get_oid_tree("HEAD", &cmp)) {
+		struct diff_options opt;
+
+		repo_diff_setup(repo, &opt);
+		opt.flags.exit_with_status = 1;
+		if (!sb)
+			opt.flags.quick = 1;
+		do_diff_cache(&cmp, &opt);
+		diffcore_std(&opt);
+		for (i = 0; sb && i < diff_queued_diff.nr; i++) {
+			if (i)
+				strbuf_addch(sb, ' ');
+			strbuf_addstr(sb, diff_queued_diff.queue[i]->two->path);
+		}
+		diff_flush(&opt);
+		return opt.flags.has_changes != 0;
+	} else {
+		for (i = 0; sb && i < istate->cache_nr; i++) {
+			if (i)
+				strbuf_addch(sb, ' ');
+			strbuf_addstr(sb, istate->cache[i]->name);
+		}
+		return !!istate->cache_nr;
+	}
+}
+
 #define WRITE_BUFFER_SIZE 8192
 static unsigned char write_buffer[WRITE_BUFFER_SIZE];
 static unsigned long write_buffer_len;
@@ -2022,11 +2494,15 @@ static int ce_write(git_hash_ctx *contex
 	return 0;
 }
 
-static int write_index_ext_header(git_hash_ctx *context, int fd,
-				  unsigned int ext, unsigned int sz)
+static int write_index_ext_header(git_hash_ctx *context, git_hash_ctx *eoie_context,
+				  int fd, unsigned int ext, unsigned int sz)
 {
 	ext = htonl(ext);
 	sz = htonl(sz);
+	if (eoie_context) {
+		the_hash_algo->update_fn(eoie_context, &ext, 4);
+		the_hash_algo->update_fn(eoie_context, &sz, 4);
+	}
 	return ((ce_write(context, fd, &ext, 4) < 0) ||
 		(ce_write(context, fd, &sz, 4) < 0)) ? -1 : 0;
 }
@@ -2054,7 +2530,8 @@ static int ce_flush(git_hash_ctx *contex
 	return (write_in_full(fd, write_buffer, left) < 0) ? -1 : 0;
 }
 
-static void ce_smudge_racily_clean_entry(struct cache_entry *ce)
+static void ce_smudge_racily_clean_entry(struct index_state *istate,
+					 struct cache_entry *ce)
 {
 	/*
 	 * The only thing we care about in this function is to smudge the
@@ -2073,7 +2550,7 @@ static void ce_smudge_racily_clean_entry
 		return;
 	if (ce_match_stat_basic(ce, &st))
 		return;
-	if (ce_modified_check_fs(ce, &st)) {
+	if (ce_modified_check_fs(istate, ce, &st)) {
 		/* This is "racily clean"; smudge it.  Note that this
 		 * is a tricky code.  At first glance, it may appear
 		 * that it can break with this sequence:
@@ -2108,6 +2585,8 @@ static void copy_cache_entry_to_ondisk(s
 				       struct cache_entry *ce)
 {
 	short flags;
+	const unsigned hashsz = the_hash_algo->rawsz;
+	uint16_t *flagsp = (uint16_t *)(ondisk->data + hashsz);
 
 	ondisk->ctime.sec = htonl(ce->ce_stat_data.sd_ctime.sec);
 	ondisk->mtime.sec = htonl(ce->ce_stat_data.sd_mtime.sec);
@@ -2119,15 +2598,13 @@ static void copy_cache_entry_to_ondisk(s
 	ondisk->uid  = htonl(ce->ce_stat_data.sd_uid);
 	ondisk->gid  = htonl(ce->ce_stat_data.sd_gid);
 	ondisk->size = htonl(ce->ce_stat_data.sd_size);
-	hashcpy(ondisk->sha1, ce->oid.hash);
+	hashcpy(ondisk->data, ce->oid.hash);
 
 	flags = ce->ce_flags & ~CE_NAMEMASK;
 	flags |= (ce_namelen(ce) >= CE_NAMEMASK ? CE_NAMEMASK : ce_namelen(ce));
-	ondisk->flags = htons(flags);
+	flagsp[0] = htons(flags);
 	if (ce->ce_flags & CE_EXTENDED) {
-		struct ondisk_cache_entry_extended *ondisk2;
-		ondisk2 = (struct ondisk_cache_entry_extended *)ondisk;
-		ondisk2->flags2 = htons((ce->ce_flags & CE_EXTENDED_FLAGS) >> 16);
+		flagsp[1] = htons((ce->ce_flags & CE_EXTENDED_FLAGS) >> 16);
 	}
 }
 
@@ -2146,10 +2623,7 @@ static int ce_write_entry(git_hash_ctx *
 		stripped_name = 1;
 	}
 
-	if (ce->ce_flags & CE_EXTENDED)
-		size = offsetof(struct ondisk_cache_entry_extended, name);
-	else
-		size = offsetof(struct ondisk_cache_entry, name);
+	size = offsetof(struct ondisk_cache_entry,data) + ondisk_data_size(ce->ce_flags, 0);
 
 	if (!previous_name) {
 		int len = ce_namelen(ce);
@@ -2219,7 +2693,7 @@ static int verify_index_from(const struc
 	if (n != the_hash_algo->rawsz)
 		goto out;
 
-	if (hashcmp(istate->oid.hash, hash))
+	if (!hasheq(istate->oid.hash, hash))
 		goto out;
 
 	close(fd);
@@ -2230,9 +2704,9 @@ out:
 	return 0;
 }
 
-static int verify_index(const struct index_state *istate)
+static int repo_verify_index(struct repository *repo)
 {
-	return verify_index_from(istate, get_index_file());
+	return verify_index_from(repo->index, repo->index_file);
 }
 
 static int has_racy_timestamp(struct index_state *istate)
@@ -2248,15 +2722,47 @@ static int has_racy_timestamp(struct ind
 	return 0;
 }
 
-void update_index_if_able(struct index_state *istate, struct lock_file *lockfile)
+void repo_update_index_if_able(struct repository *repo,
+			       struct lock_file *lockfile)
 {
-	if ((istate->cache_changed || has_racy_timestamp(istate)) &&
-	    verify_index(istate))
-		write_locked_index(istate, lockfile, COMMIT_LOCK);
+	if ((repo->index->cache_changed ||
+	     has_racy_timestamp(repo->index)) &&
+	    repo_verify_index(repo))
+		write_locked_index(repo->index, lockfile, COMMIT_LOCK);
 	else
 		rollback_lock_file(lockfile);
 }
 
+static int record_eoie(void)
+{
+	int val;
+
+	if (!git_config_get_bool("index.recordendofindexentries", &val))
+		return val;
+
+	/*
+	 * As a convenience, the end of index entries extension
+	 * used for threading is written by default if the user
+	 * explicitly requested threaded index reads.
+	 */
+	return !git_config_get_index_threads(&val) && val != 1;
+}
+
+static int record_ieot(void)
+{
+	int val;
+
+	if (!git_config_get_bool("index.recordoffsettable", &val))
+		return val;
+
+	/*
+	 * As a convenience, the offset table used for threading is
+	 * written by default if the user explicitly requested
+	 * threaded index reads.
+	 */
+	return !git_config_get_index_threads(&val) && val != 1;
+}
+
 /*
  * On success, `tempfile` is closed. If it is the temporary file
  * of a `struct lock_file`, we will therefore effectively perform
@@ -2269,15 +2775,19 @@ static int do_write_index(struct index_s
 {
 	uint64_t start = getnanotime();
 	int newfd = tempfile->fd;
-	git_hash_ctx c;
+	git_hash_ctx c, eoie_c;
 	struct cache_header hdr;
 	int i, err = 0, removed, extended, hdr_version;
 	struct cache_entry **cache = istate->cache;
 	int entries = istate->cache_nr;
 	struct stat st;
-	struct ondisk_cache_entry_extended ondisk;
+	struct ondisk_cache_entry ondisk;
 	struct strbuf previous_name_buf = STRBUF_INIT, *previous_name;
 	int drop_cache_tree = istate->drop_cache_tree;
+	off_t offset;
+	int ieot_entries = 1;
+	struct index_entry_offset_table *ieot = NULL;
+	int nr, nr_threads;
 
 	for (i = removed = extended = 0; i < entries; i++) {
 		if (cache[i]->ce_flags & CE_REMOVE)
@@ -2292,7 +2802,7 @@ static int do_write_index(struct index_s
 	}
 
 	if (!istate->version) {
-		istate->version = get_index_format_default();
+		istate->version = get_index_format_default(the_repository);
 		if (git_env_bool("GIT_TEST_SPLIT_INDEX", 0))
 			init_split_index(istate);
 	}
@@ -2311,6 +2821,46 @@ static int do_write_index(struct index_s
 	if (ce_write(&c, newfd, &hdr, sizeof(hdr)) < 0)
 		return -1;
 
+	if (!HAVE_THREADS || git_config_get_index_threads(&nr_threads))
+		nr_threads = 1;
+
+	if (nr_threads != 1 && record_ieot()) {
+		int ieot_blocks, cpus;
+
+		/*
+		 * ensure default number of ieot blocks maps evenly to the
+		 * default number of threads that will process them leaving
+		 * room for the thread to load the index extensions.
+		 */
+		if (!nr_threads) {
+			ieot_blocks = istate->cache_nr / THREAD_COST;
+			cpus = online_cpus();
+			if (ieot_blocks > cpus - 1)
+				ieot_blocks = cpus - 1;
+		} else {
+			ieot_blocks = nr_threads;
+			if (ieot_blocks > istate->cache_nr)
+				ieot_blocks = istate->cache_nr;
+		}
+
+		/*
+		 * no reason to write out the IEOT extension if we don't
+		 * have enough blocks to utilize multi-threading
+		 */
+		if (ieot_blocks > 1) {
+			ieot = xcalloc(1, sizeof(struct index_entry_offset_table)
+				+ (ieot_blocks * sizeof(struct index_entry_offset)));
+			ieot_entries = DIV_ROUND_UP(entries, ieot_blocks);
+		}
+	}
+
+	offset = lseek(newfd, 0, SEEK_CUR);
+	if (offset < 0) {
+		free(ieot);
+		return -1;
+	}
+	offset += write_buffer_len;
+	nr = 0;
 	previous_name = (hdr_version == 4) ? &previous_name_buf : NULL;
 
 	for (i = 0; i < entries; i++) {
@@ -2318,7 +2868,7 @@ static int do_write_index(struct index_s
 		if (ce->ce_flags & CE_REMOVE)
 			continue;
 		if (!ce_uptodate(ce) && is_racy_timestamp(istate, ce))
-			ce_smudge_racily_clean_entry(ce);
+			ce_smudge_racily_clean_entry(istate, ce);
 		if (is_null_oid(&ce->oid)) {
 			static const char msg[] = "cache entry has null sha1: %s";
 			static int allow = -1;
@@ -2332,23 +2882,78 @@ static int do_write_index(struct index_s
 
 			drop_cache_tree = 1;
 		}
+		if (ieot && i && (i % ieot_entries == 0)) {
+			ieot->entries[ieot->nr].nr = nr;
+			ieot->entries[ieot->nr].offset = offset;
+			ieot->nr++;
+			/*
+			 * If we have a V4 index, set the first byte to an invalid
+			 * character to ensure there is nothing common with the previous
+			 * entry
+			 */
+			if (previous_name)
+				previous_name->buf[0] = 0;
+			nr = 0;
+			offset = lseek(newfd, 0, SEEK_CUR);
+			if (offset < 0) {
+				free(ieot);
+				return -1;
+			}
+			offset += write_buffer_len;
+		}
 		if (ce_write_entry(&c, newfd, ce, previous_name, (struct ondisk_cache_entry *)&ondisk) < 0)
 			err = -1;
 
 		if (err)
 			break;
+		nr++;
+	}
+	if (ieot && nr) {
+		ieot->entries[ieot->nr].nr = nr;
+		ieot->entries[ieot->nr].offset = offset;
+		ieot->nr++;
 	}
 	strbuf_release(&previous_name_buf);
 
-	if (err)
+	if (err) {
+		free(ieot);
 		return err;
+	}
 
 	/* Write extension data here */
-	if (!strip_extensions && istate->split_index) {
+	offset = lseek(newfd, 0, SEEK_CUR);
+	if (offset < 0) {
+		free(ieot);
+		return -1;
+	}
+	offset += write_buffer_len;
+	the_hash_algo->init_fn(&eoie_c);
+
+	/*
+	 * Lets write out CACHE_EXT_INDEXENTRYOFFSETTABLE first so that we
+	 * can minimize the number of extensions we have to scan through to
+	 * find it during load.  Write it out regardless of the
+	 * strip_extensions parameter as we need it when loading the shared
+	 * index.
+	 */
+	if (ieot) {
+		struct strbuf sb = STRBUF_INIT;
+
+		write_ieot_extension(&sb, ieot);
+		err = write_index_ext_header(&c, &eoie_c, newfd, CACHE_EXT_INDEXENTRYOFFSETTABLE, sb.len) < 0
+			|| ce_write(&c, newfd, sb.buf, sb.len) < 0;
+		strbuf_release(&sb);
+		free(ieot);
+		if (err)
+			return -1;
+	}
+
+	if (!strip_extensions && istate->split_index &&
+	    !is_null_oid(&istate->split_index->base_oid)) {
 		struct strbuf sb = STRBUF_INIT;
 
 		err = write_link_extension(&sb, istate) < 0 ||
-			write_index_ext_header(&c, newfd, CACHE_EXT_LINK,
+			write_index_ext_header(&c, &eoie_c, newfd, CACHE_EXT_LINK,
 					       sb.len) < 0 ||
 			ce_write(&c, newfd, sb.buf, sb.len) < 0;
 		strbuf_release(&sb);
@@ -2359,7 +2964,7 @@ static int do_write_index(struct index_s
 		struct strbuf sb = STRBUF_INIT;
 
 		cache_tree_write(&sb, istate->cache_tree);
-		err = write_index_ext_header(&c, newfd, CACHE_EXT_TREE, sb.len) < 0
+		err = write_index_ext_header(&c, &eoie_c, newfd, CACHE_EXT_TREE, sb.len) < 0
 			|| ce_write(&c, newfd, sb.buf, sb.len) < 0;
 		strbuf_release(&sb);
 		if (err)
@@ -2369,7 +2974,7 @@ static int do_write_index(struct index_s
 		struct strbuf sb = STRBUF_INIT;
 
 		resolve_undo_write(&sb, istate->resolve_undo);
-		err = write_index_ext_header(&c, newfd, CACHE_EXT_RESOLVE_UNDO,
+		err = write_index_ext_header(&c, &eoie_c, newfd, CACHE_EXT_RESOLVE_UNDO,
 					     sb.len) < 0
 			|| ce_write(&c, newfd, sb.buf, sb.len) < 0;
 		strbuf_release(&sb);
@@ -2380,7 +2985,7 @@ static int do_write_index(struct index_s
 		struct strbuf sb = STRBUF_INIT;
 
 		write_untracked_extension(&sb, istate->untracked);
-		err = write_index_ext_header(&c, newfd, CACHE_EXT_UNTRACKED,
+		err = write_index_ext_header(&c, &eoie_c, newfd, CACHE_EXT_UNTRACKED,
 					     sb.len) < 0 ||
 			ce_write(&c, newfd, sb.buf, sb.len) < 0;
 		strbuf_release(&sb);
@@ -2391,7 +2996,24 @@ static int do_write_index(struct index_s
 		struct strbuf sb = STRBUF_INIT;
 
 		write_fsmonitor_extension(&sb, istate);
-		err = write_index_ext_header(&c, newfd, CACHE_EXT_FSMONITOR, sb.len) < 0
+		err = write_index_ext_header(&c, &eoie_c, newfd, CACHE_EXT_FSMONITOR, sb.len) < 0
+			|| ce_write(&c, newfd, sb.buf, sb.len) < 0;
+		strbuf_release(&sb);
+		if (err)
+			return -1;
+	}
+
+	/*
+	 * CACHE_EXT_ENDOFINDEXENTRIES must be written as the last entry before the SHA1
+	 * so that it can be found and processed before all the index entries are
+	 * read.  Write it out regardless of the strip_extensions parameter as we need it
+	 * when loading the shared index.
+	 */
+	if (offset && record_eoie()) {
+		struct strbuf sb = STRBUF_INIT;
+
+		write_eoie_extension(&sb, &eoie_c, offset);
+		err = write_index_ext_header(&c, NULL, newfd, CACHE_EXT_ENDOFINDEXENTRIES, sb.len) < 0
 			|| ce_write(&c, newfd, sb.buf, sb.len) < 0;
 		strbuf_release(&sb);
 		if (err)
@@ -2409,6 +3031,16 @@ static int do_write_index(struct index_s
 	istate->timestamp.sec = (unsigned int)st.st_mtime;
 	istate->timestamp.nsec = ST_MTIME_NSEC(st);
 	trace_performance_since(start, "write index, changed mask = %x", istate->cache_changed);
+
+	/*
+	 * TODO trace2: replace "the_repository" with the actual repo instance
+	 * that is associated with the given "istate".
+	 */
+	trace2_data_intmax("index", the_repository, "write/version",
+			   istate->version);
+	trace2_data_intmax("index", the_repository, "write/cache_nr",
+			   istate->cache_nr);
+
 	return 0;
 }
 
@@ -2428,12 +3060,32 @@ static int commit_locked_index(struct lo
 static int do_write_locked_index(struct index_state *istate, struct lock_file *lock,
 				 unsigned flags)
 {
-	int ret = do_write_index(istate, lock->tempfile, 0);
+	int ret;
+
+	/*
+	 * TODO trace2: replace "the_repository" with the actual repo instance
+	 * that is associated with the given "istate".
+	 */
+	trace2_region_enter_printf("index", "do_write_index", the_repository,
+				   "%s", lock->tempfile->filename.buf);
+	ret = do_write_index(istate, lock->tempfile, 0);
+	trace2_region_leave_printf("index", "do_write_index", the_repository,
+				   "%s", lock->tempfile->filename.buf);
+
 	if (ret)
 		return ret;
 	if (flags & COMMIT_LOCK)
-		return commit_locked_index(lock);
-	return close_lock_file_gently(lock);
+		ret = commit_locked_index(lock);
+	else
+		ret = close_lock_file_gently(lock);
+
+	run_hook_le(NULL, "post-index-change",
+			istate->updated_workdir ? "1" : "0",
+			istate->updated_skipworktree ? "1" : "0", NULL);
+	istate->updated_workdir = 0;
+	istate->updated_skipworktree = 0;
+
+	return ret;
 }
 
 static int write_split_index(struct index_state *istate,
@@ -2513,12 +3165,18 @@ static int write_shared_index(struct ind
 	int ret;
 
 	move_cache_to_base_index(istate);
+
+	trace2_region_enter_printf("index", "shared/do_write_index",
+				   the_repository, "%s", (*temp)->filename.buf);
 	ret = do_write_index(si->base, *temp, 1);
+	trace2_region_leave_printf("index", "shared/do_write_index",
+				   the_repository, "%s", (*temp)->filename.buf);
+
 	if (ret)
 		return ret;
 	ret = adjust_shared_perm(get_tempfile_path(*temp));
 	if (ret) {
-		error("cannot fix permission bits on %s", get_tempfile_path(*temp));
+		error(_("cannot fix permission bits on '%s'"), get_tempfile_path(*temp));
 		return ret;
 	}
 	ret = rename_tempfile(temp,
@@ -2567,6 +3225,9 @@ int write_locked_index(struct index_stat
 	int new_shared_index, ret;
 	struct split_index *si = istate->split_index;
 
+	if (git_env_bool("GIT_TEST_CHECK_CACHE_TREE", 0))
+		cache_tree_verify(the_repository, istate);
+
 	if ((flags & SKIP_IF_UNCHANGED) && !istate->cache_changed) {
 		if (flags & COMMIT_LOCK)
 			rollback_lock_file(lock);
@@ -2598,7 +3259,8 @@ int write_locked_index(struct index_stat
 		struct tempfile *temp;
 		int saved_errno;
 
-		temp = mks_tempfile(git_path("sharedindex_XXXXXX"));
+		/* Same initial permissions as the main .git/index file */
+		temp = mks_tempfile_sm(git_path("sharedindex_XXXXXX"), 0, 0666);
 		if (!temp) {
 			oidclr(&si->base_oid);
 			ret = do_write_locked_index(istate, lock, flags);
@@ -2618,7 +3280,7 @@ int write_locked_index(struct index_stat
 	ret = write_split_index(istate, lock, flags);
 
 	/* Freshen the shared index only if the split-index was written */
-	if (!ret && !new_shared_index) {
+	if (!ret && !new_shared_index && !is_null_oid(&si->base_oid)) {
 		const char *shared_index = git_path("sharedindex.%s",
 						    oid_to_hex(&si->base_oid));
 		freshen_shared_index(shared_index, 1);
@@ -2632,34 +3294,38 @@ out:
 
 /*
  * Read the index file that is potentially unmerged into given
- * index_state, dropping any unmerged entries.  Returns true if
- * the index is unmerged.  Callers who want to refuse to work
- * from an unmerged state can call this and check its return value,
- * instead of calling read_cache().
+ * index_state, dropping any unmerged entries to stage #0 (potentially
+ * resulting in a path appearing as both a file and a directory in the
+ * index; the caller is responsible to clear out the extra entries
+ * before writing the index to a tree).  Returns true if the index is
+ * unmerged.  Callers who want to refuse to work from an unmerged
+ * state can call this and check its return value, instead of calling
+ * read_cache().
  */
-int read_index_unmerged(struct index_state *istate)
+int repo_read_index_unmerged(struct repository *repo)
 {
+	struct index_state *istate;
 	int i;
 	int unmerged = 0;
 
-	read_index(istate);
+	repo_read_index(repo);
+	istate = repo->index;
 	for (i = 0; i < istate->cache_nr; i++) {
 		struct cache_entry *ce = istate->cache[i];
 		struct cache_entry *new_ce;
-		int size, len;
+		int len;
 
 		if (!ce_stage(ce))
 			continue;
 		unmerged = 1;
 		len = ce_namelen(ce);
-		size = cache_entry_size(len);
-		new_ce = xcalloc(1, size);
+		new_ce = make_empty_cache_entry(istate, len);
 		memcpy(new_ce->name, ce->name, len);
 		new_ce->ce_flags = create_ce_flags(0) | CE_CONFLICTED;
 		new_ce->ce_namelen = len;
 		new_ce->ce_mode = ce->ce_mode;
-		if (add_index_entry(istate, new_ce, 0))
-			return error("%s: cannot drop to stage #0",
+		if (add_index_entry(istate, new_ce, ADD_CACHE_SKIP_DFCHECK))
+			return error(_("%s: cannot drop to stage #0"),
 				     new_ce->name);
 	}
 	return unmerged;
@@ -2761,4 +3427,220 @@ void move_index_extensions(struct index_
 {
 	dst->untracked = src->untracked;
 	src->untracked = NULL;
+	dst->cache_tree = src->cache_tree;
+	src->cache_tree = NULL;
+}
+
+struct cache_entry *dup_cache_entry(const struct cache_entry *ce,
+				    struct index_state *istate)
+{
+	unsigned int size = ce_size(ce);
+	int mem_pool_allocated;
+	struct cache_entry *new_entry = make_empty_cache_entry(istate, ce_namelen(ce));
+	mem_pool_allocated = new_entry->mem_pool_allocated;
+
+	memcpy(new_entry, ce, size);
+	new_entry->mem_pool_allocated = mem_pool_allocated;
+	return new_entry;
+}
+
+void discard_cache_entry(struct cache_entry *ce)
+{
+	if (ce && should_validate_cache_entries())
+		memset(ce, 0xCD, cache_entry_size(ce->ce_namelen));
+
+	if (ce && ce->mem_pool_allocated)
+		return;
+
+	free(ce);
+}
+
+int should_validate_cache_entries(void)
+{
+	static int validate_index_cache_entries = -1;
+
+	if (validate_index_cache_entries < 0) {
+		if (getenv("GIT_TEST_VALIDATE_INDEX_CACHE_ENTRIES"))
+			validate_index_cache_entries = 1;
+		else
+			validate_index_cache_entries = 0;
+	}
+
+	return validate_index_cache_entries;
+}
+
+#define EOIE_SIZE (4 + GIT_SHA1_RAWSZ) /* <4-byte offset> + <20-byte hash> */
+#define EOIE_SIZE_WITH_HEADER (4 + 4 + EOIE_SIZE) /* <4-byte signature> + <4-byte length> + EOIE_SIZE */
+
+static size_t read_eoie_extension(const char *mmap, size_t mmap_size)
+{
+	/*
+	 * The end of index entries (EOIE) extension is guaranteed to be last
+	 * so that it can be found by scanning backwards from the EOF.
+	 *
+	 * "EOIE"
+	 * <4-byte length>
+	 * <4-byte offset>
+	 * <20-byte hash>
+	 */
+	const char *index, *eoie;
+	uint32_t extsize;
+	size_t offset, src_offset;
+	unsigned char hash[GIT_MAX_RAWSZ];
+	git_hash_ctx c;
+
+	/* ensure we have an index big enough to contain an EOIE extension */
+	if (mmap_size < sizeof(struct cache_header) + EOIE_SIZE_WITH_HEADER + the_hash_algo->rawsz)
+		return 0;
+
+	/* validate the extension signature */
+	index = eoie = mmap + mmap_size - EOIE_SIZE_WITH_HEADER - the_hash_algo->rawsz;
+	if (CACHE_EXT(index) != CACHE_EXT_ENDOFINDEXENTRIES)
+		return 0;
+	index += sizeof(uint32_t);
+
+	/* validate the extension size */
+	extsize = get_be32(index);
+	if (extsize != EOIE_SIZE)
+		return 0;
+	index += sizeof(uint32_t);
+
+	/*
+	 * Validate the offset we're going to look for the first extension
+	 * signature is after the index header and before the eoie extension.
+	 */
+	offset = get_be32(index);
+	if (mmap + offset < mmap + sizeof(struct cache_header))
+		return 0;
+	if (mmap + offset >= eoie)
+		return 0;
+	index += sizeof(uint32_t);
+
+	/*
+	 * The hash is computed over extension types and their sizes (but not
+	 * their contents).  E.g. if we have "TREE" extension that is N-bytes
+	 * long, "REUC" extension that is M-bytes long, followed by "EOIE",
+	 * then the hash would be:
+	 *
+	 * SHA-1("TREE" + <binary representation of N> +
+	 *	 "REUC" + <binary representation of M>)
+	 */
+	src_offset = offset;
+	the_hash_algo->init_fn(&c);
+	while (src_offset < mmap_size - the_hash_algo->rawsz - EOIE_SIZE_WITH_HEADER) {
+		/* After an array of active_nr index entries,
+		 * there can be arbitrary number of extended
+		 * sections, each of which is prefixed with
+		 * extension name (4-byte) and section length
+		 * in 4-byte network byte order.
+		 */
+		uint32_t extsize;
+		memcpy(&extsize, mmap + src_offset + 4, 4);
+		extsize = ntohl(extsize);
+
+		/* verify the extension size isn't so large it will wrap around */
+		if (src_offset + 8 + extsize < src_offset)
+			return 0;
+
+		the_hash_algo->update_fn(&c, mmap + src_offset, 8);
+
+		src_offset += 8;
+		src_offset += extsize;
+	}
+	the_hash_algo->final_fn(hash, &c);
+	if (!hasheq(hash, (const unsigned char *)index))
+		return 0;
+
+	/* Validate that the extension offsets returned us back to the eoie extension. */
+	if (src_offset != mmap_size - the_hash_algo->rawsz - EOIE_SIZE_WITH_HEADER)
+		return 0;
+
+	return offset;
+}
+
+static void write_eoie_extension(struct strbuf *sb, git_hash_ctx *eoie_context, size_t offset)
+{
+	uint32_t buffer;
+	unsigned char hash[GIT_MAX_RAWSZ];
+
+	/* offset */
+	put_be32(&buffer, offset);
+	strbuf_add(sb, &buffer, sizeof(uint32_t));
+
+	/* hash */
+	the_hash_algo->final_fn(hash, eoie_context);
+	strbuf_add(sb, hash, the_hash_algo->rawsz);
+}
+
+#define IEOT_VERSION	(1)
+
+static struct index_entry_offset_table *read_ieot_extension(const char *mmap, size_t mmap_size, size_t offset)
+{
+	const char *index = NULL;
+	uint32_t extsize, ext_version;
+	struct index_entry_offset_table *ieot;
+	int i, nr;
+
+	/* find the IEOT extension */
+	if (!offset)
+		return NULL;
+	while (offset <= mmap_size - the_hash_algo->rawsz - 8) {
+		extsize = get_be32(mmap + offset + 4);
+		if (CACHE_EXT((mmap + offset)) == CACHE_EXT_INDEXENTRYOFFSETTABLE) {
+			index = mmap + offset + 4 + 4;
+			break;
+		}
+		offset += 8;
+		offset += extsize;
+	}
+	if (!index)
+		return NULL;
+
+	/* validate the version is IEOT_VERSION */
+	ext_version = get_be32(index);
+	if (ext_version != IEOT_VERSION) {
+		error("invalid IEOT version %d", ext_version);
+		return NULL;
+	}
+	index += sizeof(uint32_t);
+
+	/* extension size - version bytes / bytes per entry */
+	nr = (extsize - sizeof(uint32_t)) / (sizeof(uint32_t) + sizeof(uint32_t));
+	if (!nr) {
+		error("invalid number of IEOT entries %d", nr);
+		return NULL;
+	}
+	ieot = xmalloc(sizeof(struct index_entry_offset_table)
+		       + (nr * sizeof(struct index_entry_offset)));
+	ieot->nr = nr;
+	for (i = 0; i < nr; i++) {
+		ieot->entries[i].offset = get_be32(index);
+		index += sizeof(uint32_t);
+		ieot->entries[i].nr = get_be32(index);
+		index += sizeof(uint32_t);
+	}
+
+	return ieot;
+}
+
+static void write_ieot_extension(struct strbuf *sb, struct index_entry_offset_table *ieot)
+{
+	uint32_t buffer;
+	int i;
+
+	/* version */
+	put_be32(&buffer, IEOT_VERSION);
+	strbuf_add(sb, &buffer, sizeof(uint32_t));
+
+	/* ieot */
+	for (i = 0; i < ieot->nr; i++) {
+
+		/* offset */
+		put_be32(&buffer, ieot->entries[i].offset);
+		strbuf_add(sb, &buffer, sizeof(uint32_t));
+
+		/* count */
+		put_be32(&buffer, ieot->entries[i].nr);
+		strbuf_add(sb, &buffer, sizeof(uint32_t));
+	}
 }
diff -pruN 1.2.1+git2.18.0-1/git/README.md 1.2.3+git2.25.1-1/git/README.md
--- 1.2.1+git2.18.0-1/git/README.md	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/README.md	2020-02-17 04:47:35.000000000 +0000
@@ -1,3 +1,5 @@
+[![Build Status](https://dev.azure.com/git/git/_apis/build/status/git.git)](https://dev.azure.com/git/git/_build/latest?definitionId=11)
+
 Git - fast, scalable, distributed revision control system
 =========================================================
 
@@ -17,7 +19,7 @@ including full documentation and Git rel
 
 See [Documentation/gittutorial.txt][] to get started, then see
 [Documentation/giteveryday.txt][] for a useful minimum set of commands, and
-Documentation/git-<commandname>.txt for documentation of each command.
+`Documentation/git-<commandname>.txt` for documentation of each command.
 If git has been correctly installed, then the tutorial can also be
 read with `man gittutorial` or `git help tutorial`, and the
 documentation of each command with `man git-<commandname>` or `git help
@@ -33,7 +35,7 @@ requests, comments and patches to git@vg
 [Documentation/SubmittingPatches][] for instructions on patch submission).
 To subscribe to the list, send an email with just "subscribe git" in
 the body to majordomo@vger.kernel.org. The mailing list archives are
-available at <https://public-inbox.org/git/>,
+available at <https://lore.kernel.org/git/>,
 <http://marc.info/?l=git> and other archival sites.
 
 Issues which are security relevant should be disclosed privately to
diff -pruN 1.2.1+git2.18.0-1/git/rebase-interactive.c 1.2.3+git2.25.1-1/git/rebase-interactive.c
--- 1.2.1+git2.18.0-1/git/rebase-interactive.c	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/rebase-interactive.c	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,189 @@
+#include "cache.h"
+#include "commit.h"
+#include "sequencer.h"
+#include "rebase-interactive.h"
+#include "strbuf.h"
+#include "commit-slab.h"
+#include "config.h"
+
+enum missing_commit_check_level {
+	MISSING_COMMIT_CHECK_IGNORE = 0,
+	MISSING_COMMIT_CHECK_WARN,
+	MISSING_COMMIT_CHECK_ERROR
+};
+
+static enum missing_commit_check_level get_missing_commit_check_level(void)
+{
+	const char *value;
+
+	if (git_config_get_value("rebase.missingcommitscheck", &value) ||
+			!strcasecmp("ignore", value))
+		return MISSING_COMMIT_CHECK_IGNORE;
+	if (!strcasecmp("warn", value))
+		return MISSING_COMMIT_CHECK_WARN;
+	if (!strcasecmp("error", value))
+		return MISSING_COMMIT_CHECK_ERROR;
+	warning(_("unrecognized setting %s for option "
+		  "rebase.missingCommitsCheck. Ignoring."), value);
+	return MISSING_COMMIT_CHECK_IGNORE;
+}
+
+void append_todo_help(unsigned keep_empty, int command_count,
+		      const char *shortrevisions, const char *shortonto,
+		      struct strbuf *buf)
+{
+	const char *msg = _("\nCommands:\n"
+"p, pick <commit> = use commit\n"
+"r, reword <commit> = use commit, but edit the commit message\n"
+"e, edit <commit> = use commit, but stop for amending\n"
+"s, squash <commit> = use commit, but meld into previous commit\n"
+"f, fixup <commit> = like \"squash\", but discard this commit's log message\n"
+"x, exec <command> = run command (the rest of the line) using shell\n"
+"b, break = stop here (continue rebase later with 'git rebase --continue')\n"
+"d, drop <commit> = remove commit\n"
+"l, label <label> = label current HEAD with a name\n"
+"t, reset <label> = reset HEAD to a label\n"
+"m, merge [-C <commit> | -c <commit>] <label> [# <oneline>]\n"
+".       create a merge commit using the original merge commit's\n"
+".       message (or the oneline, if no original merge commit was\n"
+".       specified). Use -c <commit> to reword the commit message.\n"
+"\n"
+"These lines can be re-ordered; they are executed from top to bottom.\n");
+	unsigned edit_todo = !(shortrevisions && shortonto);
+
+	if (!edit_todo) {
+		strbuf_addch(buf, '\n');
+		strbuf_commented_addf(buf, Q_("Rebase %s onto %s (%d command)",
+					      "Rebase %s onto %s (%d commands)",
+					      command_count),
+				      shortrevisions, shortonto, command_count);
+	}
+
+	strbuf_add_commented_lines(buf, msg, strlen(msg));
+
+	if (get_missing_commit_check_level() == MISSING_COMMIT_CHECK_ERROR)
+		msg = _("\nDo not remove any line. Use 'drop' "
+			 "explicitly to remove a commit.\n");
+	else
+		msg = _("\nIf you remove a line here "
+			 "THAT COMMIT WILL BE LOST.\n");
+
+	strbuf_add_commented_lines(buf, msg, strlen(msg));
+
+	if (edit_todo)
+		msg = _("\nYou are editing the todo file "
+			"of an ongoing interactive rebase.\n"
+			"To continue rebase after editing, run:\n"
+			"    git rebase --continue\n\n");
+	else
+		msg = _("\nHowever, if you remove everything, "
+			"the rebase will be aborted.\n\n");
+
+	strbuf_add_commented_lines(buf, msg, strlen(msg));
+
+	if (!keep_empty) {
+		msg = _("Note that empty commits are commented out");
+		strbuf_add_commented_lines(buf, msg, strlen(msg));
+	}
+}
+
+int edit_todo_list(struct repository *r, struct todo_list *todo_list,
+		   struct todo_list *new_todo, const char *shortrevisions,
+		   const char *shortonto, unsigned flags)
+{
+	const char *todo_file = rebase_path_todo();
+	unsigned initial = shortrevisions && shortonto;
+
+	/* If the user is editing the todo list, we first try to parse
+	 * it.  If there is an error, we do not return, because the user
+	 * might want to fix it in the first place. */
+	if (!initial)
+		todo_list_parse_insn_buffer(r, todo_list->buf.buf, todo_list);
+
+	if (todo_list_write_to_file(r, todo_list, todo_file, shortrevisions, shortonto,
+				    -1, flags | TODO_LIST_SHORTEN_IDS | TODO_LIST_APPEND_TODO_HELP))
+		return error_errno(_("could not write '%s'"), todo_file);
+
+	if (initial && copy_file(rebase_path_todo_backup(), todo_file, 0666))
+		return error(_("could not copy '%s' to '%s'."), todo_file,
+			     rebase_path_todo_backup());
+
+	if (launch_sequence_editor(todo_file, &new_todo->buf, NULL))
+		return -2;
+
+	strbuf_stripspace(&new_todo->buf, 1);
+	if (initial && new_todo->buf.len == 0)
+		return -3;
+
+	/* For the initial edit, the todo list gets parsed in
+	 * complete_action(). */
+	if (!initial)
+		return todo_list_parse_insn_buffer(r, new_todo->buf.buf, new_todo);
+
+	return 0;
+}
+
+define_commit_slab(commit_seen, unsigned char);
+/*
+ * Check if the user dropped some commits by mistake
+ * Behaviour determined by rebase.missingCommitsCheck.
+ * Check if there is an unrecognized command or a
+ * bad SHA-1 in a command.
+ */
+int todo_list_check(struct todo_list *old_todo, struct todo_list *new_todo)
+{
+	enum missing_commit_check_level check_level = get_missing_commit_check_level();
+	struct strbuf missing = STRBUF_INIT;
+	int res = 0, i;
+	struct commit_seen commit_seen;
+
+	init_commit_seen(&commit_seen);
+
+	if (check_level == MISSING_COMMIT_CHECK_IGNORE)
+		goto leave_check;
+
+	/* Mark the commits in git-rebase-todo as seen */
+	for (i = 0; i < new_todo->nr; i++) {
+		struct commit *commit = new_todo->items[i].commit;
+		if (commit)
+			*commit_seen_at(&commit_seen, commit) = 1;
+	}
+
+	/* Find commits in git-rebase-todo.backup yet unseen */
+	for (i = old_todo->nr - 1; i >= 0; i--) {
+		struct todo_item *item = old_todo->items + i;
+		struct commit *commit = item->commit;
+		if (commit && !*commit_seen_at(&commit_seen, commit)) {
+			strbuf_addf(&missing, " - %s %.*s\n",
+				    find_unique_abbrev(&commit->object.oid, DEFAULT_ABBREV),
+				    item->arg_len,
+				    todo_item_get_arg(old_todo, item));
+			*commit_seen_at(&commit_seen, commit) = 1;
+		}
+	}
+
+	/* Warn about missing commits */
+	if (!missing.len)
+		goto leave_check;
+
+	if (check_level == MISSING_COMMIT_CHECK_ERROR)
+		res = 1;
+
+	fprintf(stderr,
+		_("Warning: some commits may have been dropped accidentally.\n"
+		"Dropped commits (newer to older):\n"));
+
+	/* Make the list user-friendly and display */
+	fputs(missing.buf, stderr);
+	strbuf_release(&missing);
+
+	fprintf(stderr, _("To avoid this message, use \"drop\" to "
+		"explicitly remove a commit.\n\n"
+		"Use 'git config rebase.missingCommitsCheck' to change "
+		"the level of warnings.\n"
+		"The possible behaviours are: ignore, warn, error.\n\n"));
+
+leave_check:
+	clear_commit_seen(&commit_seen);
+	return res;
+}
diff -pruN 1.2.1+git2.18.0-1/git/rebase-interactive.h 1.2.3+git2.25.1-1/git/rebase-interactive.h
--- 1.2.1+git2.18.0-1/git/rebase-interactive.h	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/rebase-interactive.h	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,16 @@
+#ifndef REBASE_INTERACTIVE_H
+#define REBASE_INTERACTIVE_H
+
+struct strbuf;
+struct repository;
+struct todo_list;
+
+void append_todo_help(unsigned keep_empty, int command_count,
+		      const char *shortrevisions, const char *shortonto,
+		      struct strbuf *buf);
+int edit_todo_list(struct repository *r, struct todo_list *todo_list,
+		   struct todo_list *new_todo, const char *shortrevisions,
+		   const char *shortonto, unsigned flags);
+int todo_list_check(struct todo_list *old_todo, struct todo_list *new_todo);
+
+#endif
diff -pruN 1.2.1+git2.18.0-1/git/ref-filter.c 1.2.3+git2.25.1-1/git/ref-filter.c
--- 1.2.1+git2.18.0-1/git/ref-filter.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/ref-filter.c	2020-02-17 04:47:35.000000000 +0000
@@ -3,6 +3,8 @@
 #include "parse-options.h"
 #include "refs.h"
 #include "wildmatch.h"
+#include "object-store.h"
+#include "repository.h"
 #include "commit.h"
 #include "remote.h"
 #include "color.h"
@@ -16,6 +18,11 @@
 #include "trailer.h"
 #include "wt-status.h"
 #include "commit-slab.h"
+#include "commit-graph.h"
+#include "commit-reach.h"
+#include "worktree.h"
+#include "hashmap.h"
+#include "argv-array.h"
 
 static struct ref_msg {
 	const char *gone;
@@ -40,6 +47,7 @@ void setup_ref_filter_porcelain_msg(void
 
 typedef enum { FIELD_STR, FIELD_ULONG, FIELD_TIME } cmp_type;
 typedef enum { COMPARE_EQUAL, COMPARE_UNEQUAL, COMPARE_NONE } cmp_status;
+typedef enum { SOURCE_NONE = 0, SOURCE_OBJ, SOURCE_OTHER } info_source;
 
 struct align {
 	align_type position;
@@ -59,6 +67,41 @@ struct refname_atom {
 	int lstrip, rstrip;
 };
 
+static struct expand_data {
+	struct object_id oid;
+	enum object_type type;
+	unsigned long size;
+	off_t disk_size;
+	struct object_id delta_base_oid;
+	void *content;
+
+	struct object_info info;
+} oi, oi_deref;
+
+struct ref_to_worktree_entry {
+	struct hashmap_entry ent;
+	struct worktree *wt; /* key is wt->head_ref */
+};
+
+static int ref_to_worktree_map_cmpfnc(const void *unused_lookupdata,
+				      const struct hashmap_entry *eptr,
+				      const struct hashmap_entry *kptr,
+				      const void *keydata_aka_refname)
+{
+	const struct ref_to_worktree_entry *e, *k;
+
+	e = container_of(eptr, const struct ref_to_worktree_entry, ent);
+	k = container_of(kptr, const struct ref_to_worktree_entry, ent);
+
+	return strcmp(e->wt->head_ref,
+		keydata_aka_refname ? keydata_aka_refname : k->wt->head_ref);
+}
+
+static struct ref_to_worktree_map {
+	struct hashmap map;
+	struct worktree **worktrees;
+} ref_to_worktree_map;
+
 /*
  * An atom is a valid field atom listed below, possibly prefixed with
  * a "*" to denote deref_tag().
@@ -72,6 +115,7 @@ struct refname_atom {
 static struct used_atom {
 	const char *name;
 	cmp_type type;
+	info_source source;
 	union {
 		char color[COLOR_MAXLEN];
 		struct align align;
@@ -199,6 +243,48 @@ static int remote_ref_atom_parser(const
 	return 0;
 }
 
+static int objecttype_atom_parser(const struct ref_format *format, struct used_atom *atom,
+				  const char *arg, struct strbuf *err)
+{
+	if (arg)
+		return strbuf_addf_ret(err, -1, _("%%(objecttype) does not take arguments"));
+	if (*atom->name == '*')
+		oi_deref.info.typep = &oi_deref.type;
+	else
+		oi.info.typep = &oi.type;
+	return 0;
+}
+
+static int objectsize_atom_parser(const struct ref_format *format, struct used_atom *atom,
+				  const char *arg, struct strbuf *err)
+{
+	if (!arg) {
+		if (*atom->name == '*')
+			oi_deref.info.sizep = &oi_deref.size;
+		else
+			oi.info.sizep = &oi.size;
+	} else if (!strcmp(arg, "disk")) {
+		if (*atom->name == '*')
+			oi_deref.info.disk_sizep = &oi_deref.disk_size;
+		else
+			oi.info.disk_sizep = &oi.disk_size;
+	} else
+		return strbuf_addf_ret(err, -1, _("unrecognized %%(objectsize) argument: %s"), arg);
+	return 0;
+}
+
+static int deltabase_atom_parser(const struct ref_format *format, struct used_atom *atom,
+				 const char *arg, struct strbuf *err)
+{
+	if (arg)
+		return strbuf_addf_ret(err, -1, _("%%(deltabase) does not take arguments"));
+	if (*atom->name == '*')
+		oi_deref.info.delta_base_sha1 = oi_deref.delta_base_oid.hash;
+	else
+		oi.info.delta_base_sha1 = oi.delta_base_oid.hash;
+	return 0;
+}
+
 static int body_atom_parser(const struct ref_format *format, struct used_atom *atom,
 			    const char *arg, struct strbuf *err)
 {
@@ -223,6 +309,8 @@ static int trailers_atom_parser(const st
 	struct string_list params = STRING_LIST_INIT_DUP;
 	int i;
 
+	atom->u.contents.trailer_opts.no_divider = 1;
+
 	if (arg) {
 		string_list_split(&params, arg, ',', -1);
 		for (i = 0; i < params.nr; i++) {
@@ -379,49 +467,56 @@ static int head_atom_parser(const struct
 
 static struct {
 	const char *name;
+	info_source source;
 	cmp_type cmp_type;
 	int (*parser)(const struct ref_format *format, struct used_atom *atom,
 		      const char *arg, struct strbuf *err);
 } valid_atom[] = {
-	{ "refname" , FIELD_STR, refname_atom_parser },
-	{ "objecttype" },
-	{ "objectsize", FIELD_ULONG },
-	{ "objectname", FIELD_STR, objectname_atom_parser },
-	{ "tree" },
-	{ "parent" },
-	{ "numparent", FIELD_ULONG },
-	{ "object" },
-	{ "type" },
-	{ "tag" },
-	{ "author" },
-	{ "authorname" },
-	{ "authoremail" },
-	{ "authordate", FIELD_TIME },
-	{ "committer" },
-	{ "committername" },
-	{ "committeremail" },
-	{ "committerdate", FIELD_TIME },
-	{ "tagger" },
-	{ "taggername" },
-	{ "taggeremail" },
-	{ "taggerdate", FIELD_TIME },
-	{ "creator" },
-	{ "creatordate", FIELD_TIME },
-	{ "subject", FIELD_STR, subject_atom_parser },
-	{ "body", FIELD_STR, body_atom_parser },
-	{ "trailers", FIELD_STR, trailers_atom_parser },
-	{ "contents", FIELD_STR, contents_atom_parser },
-	{ "upstream", FIELD_STR, remote_ref_atom_parser },
-	{ "push", FIELD_STR, remote_ref_atom_parser },
-	{ "symref", FIELD_STR, refname_atom_parser },
-	{ "flag" },
-	{ "HEAD", FIELD_STR, head_atom_parser },
-	{ "color", FIELD_STR, color_atom_parser },
-	{ "align", FIELD_STR, align_atom_parser },
-	{ "end" },
-	{ "if", FIELD_STR, if_atom_parser },
-	{ "then" },
-	{ "else" },
+	{ "refname", SOURCE_NONE, FIELD_STR, refname_atom_parser },
+	{ "objecttype", SOURCE_OTHER, FIELD_STR, objecttype_atom_parser },
+	{ "objectsize", SOURCE_OTHER, FIELD_ULONG, objectsize_atom_parser },
+	{ "objectname", SOURCE_OTHER, FIELD_STR, objectname_atom_parser },
+	{ "deltabase", SOURCE_OTHER, FIELD_STR, deltabase_atom_parser },
+	{ "tree", SOURCE_OBJ },
+	{ "parent", SOURCE_OBJ },
+	{ "numparent", SOURCE_OBJ, FIELD_ULONG },
+	{ "object", SOURCE_OBJ },
+	{ "type", SOURCE_OBJ },
+	{ "tag", SOURCE_OBJ },
+	{ "author", SOURCE_OBJ },
+	{ "authorname", SOURCE_OBJ },
+	{ "authoremail", SOURCE_OBJ },
+	{ "authordate", SOURCE_OBJ, FIELD_TIME },
+	{ "committer", SOURCE_OBJ },
+	{ "committername", SOURCE_OBJ },
+	{ "committeremail", SOURCE_OBJ },
+	{ "committerdate", SOURCE_OBJ, FIELD_TIME },
+	{ "tagger", SOURCE_OBJ },
+	{ "taggername", SOURCE_OBJ },
+	{ "taggeremail", SOURCE_OBJ },
+	{ "taggerdate", SOURCE_OBJ, FIELD_TIME },
+	{ "creator", SOURCE_OBJ },
+	{ "creatordate", SOURCE_OBJ, FIELD_TIME },
+	{ "subject", SOURCE_OBJ, FIELD_STR, subject_atom_parser },
+	{ "body", SOURCE_OBJ, FIELD_STR, body_atom_parser },
+	{ "trailers", SOURCE_OBJ, FIELD_STR, trailers_atom_parser },
+	{ "contents", SOURCE_OBJ, FIELD_STR, contents_atom_parser },
+	{ "upstream", SOURCE_NONE, FIELD_STR, remote_ref_atom_parser },
+	{ "push", SOURCE_NONE, FIELD_STR, remote_ref_atom_parser },
+	{ "symref", SOURCE_NONE, FIELD_STR, refname_atom_parser },
+	{ "flag", SOURCE_NONE },
+	{ "HEAD", SOURCE_NONE, FIELD_STR, head_atom_parser },
+	{ "color", SOURCE_NONE, FIELD_STR, color_atom_parser },
+	{ "worktreepath", SOURCE_NONE },
+	{ "align", SOURCE_NONE, FIELD_STR, align_atom_parser },
+	{ "end", SOURCE_NONE },
+	{ "if", SOURCE_NONE, FIELD_STR, if_atom_parser },
+	{ "then", SOURCE_NONE },
+	{ "else", SOURCE_NONE },
+	/*
+	 * Please update $__git_ref_fieldlist in git-completion.bash
+	 * when you add new atoms
+	 */
 };
 
 #define REF_FORMATTING_STATE_INIT  { 0, NULL }
@@ -490,6 +585,10 @@ static int parse_ref_filter_atom(const s
 	if (ARRAY_SIZE(valid_atom) <= i)
 		return strbuf_addf_ret(err, -1, _("unknown field name: %.*s"),
 				       (int)(ep-atom), atom);
+	if (valid_atom[i].source != SOURCE_NONE && !have_git_dir())
+		return strbuf_addf_ret(err, -1,
+				       _("not a git repository, but the field '%.*s' requires access to object data"),
+				       (int)(ep-atom), atom);
 
 	/* Add it in, including the deref prefix */
 	at = used_atom_cnt;
@@ -497,6 +596,13 @@ static int parse_ref_filter_atom(const s
 	REALLOC_ARRAY(used_atom, used_atom_cnt);
 	used_atom[at].name = xmemdupz(atom, ep - atom);
 	used_atom[at].type = valid_atom[i].cmp_type;
+	used_atom[at].source = valid_atom[i].source;
+	if (used_atom[at].source == SOURCE_OBJ) {
+		if (*atom == '*')
+			oi_deref.info.contentp = &oi_deref.content;
+		else
+			oi.info.contentp = &oi.content;
+	}
 	if (arg) {
 		arg = used_atom[at].name + (arg - atom) + 1;
 		if (!*arg) {
@@ -792,24 +898,6 @@ int verify_ref_format(struct ref_format
 	return 0;
 }
 
-/*
- * Given an object name, read the object data and size, and return a
- * "struct object".  If the object data we are returning is also borrowed
- * by the "struct object" representation, set *eaten as well---it is a
- * signal from parse_object_buffer to us not to free the buffer.
- */
-static void *get_obj(const struct object_id *oid, struct object **obj, unsigned long *sz, int *eaten)
-{
-	enum object_type type;
-	void *buf = read_object_file(oid, &type, sz);
-
-	if (buf)
-		*obj = parse_object_buffer(oid, type, *sz, buf, eaten);
-	else
-		*obj = NULL;
-	return buf;
-}
-
 static int grab_objectname(const char *name, const struct object_id *oid,
 			   struct atom_value *v, struct used_atom *atom)
 {
@@ -830,7 +918,7 @@ static int grab_objectname(const char *n
 }
 
 /* See grab_values */
-static void grab_common_values(struct atom_value *val, int deref, struct object *obj, void *buf, unsigned long sz)
+static void grab_common_values(struct atom_value *val, int deref, struct expand_data *oi)
 {
 	int i;
 
@@ -842,18 +930,22 @@ static void grab_common_values(struct at
 		if (deref)
 			name++;
 		if (!strcmp(name, "objecttype"))
-			v->s = type_name(obj->type);
-		else if (!strcmp(name, "objectsize")) {
-			v->value = sz;
-			v->s = xstrfmt("%lu", sz);
-		}
+			v->s = xstrdup(type_name(oi->type));
+		else if (!strcmp(name, "objectsize:disk")) {
+			v->value = oi->disk_size;
+			v->s = xstrfmt("%"PRIuMAX, (uintmax_t)oi->disk_size);
+		} else if (!strcmp(name, "objectsize")) {
+			v->value = oi->size;
+			v->s = xstrfmt("%"PRIuMAX , (uintmax_t)oi->size);
+		} else if (!strcmp(name, "deltabase"))
+			v->s = xstrdup(oid_to_hex(&oi->delta_base_oid));
 		else if (deref)
-			grab_objectname(name, &obj->oid, v, &used_atom[i]);
+			grab_objectname(name, &oi->oid, v, &used_atom[i]);
 	}
 }
 
 /* See grab_values */
-static void grab_tag_values(struct atom_value *val, int deref, struct object *obj, void *buf, unsigned long sz)
+static void grab_tag_values(struct atom_value *val, int deref, struct object *obj)
 {
 	int i;
 	struct tag *tag = (struct tag *) obj;
@@ -866,16 +958,16 @@ static void grab_tag_values(struct atom_
 		if (deref)
 			name++;
 		if (!strcmp(name, "tag"))
-			v->s = tag->tag;
+			v->s = xstrdup(tag->tag);
 		else if (!strcmp(name, "type") && tag->tagged)
-			v->s = type_name(tag->tagged->type);
+			v->s = xstrdup(type_name(tag->tagged->type));
 		else if (!strcmp(name, "object") && tag->tagged)
 			v->s = xstrdup(oid_to_hex(&tag->tagged->oid));
 	}
 }
 
 /* See grab_values */
-static void grab_commit_values(struct atom_value *val, int deref, struct object *obj, void *buf, unsigned long sz)
+static void grab_commit_values(struct atom_value *val, int deref, struct object *obj)
 {
 	int i;
 	struct commit *commit = (struct commit *) obj;
@@ -908,7 +1000,7 @@ static void grab_commit_values(struct at
 	}
 }
 
-static const char *find_wholine(const char *who, int wholen, const char *buf, unsigned long sz)
+static const char *find_wholine(const char *who, int wholen, const char *buf)
 {
 	const char *eol;
 	while (*buf) {
@@ -939,7 +1031,7 @@ static const char *copy_name(const char
 		if (!strncmp(cp, " <", 2))
 			return xmemdupz(buf, cp - buf);
 	}
-	return "";
+	return xstrdup("");
 }
 
 static const char *copy_email(const char *buf)
@@ -947,10 +1039,10 @@ static const char *copy_email(const char
 	const char *email = strchr(buf, '<');
 	const char *eoemail;
 	if (!email)
-		return "";
+		return xstrdup("");
 	eoemail = strchr(email, '>');
 	if (!eoemail)
-		return "";
+		return xstrdup("");
 	return xmemdupz(email, eoemail + 1 - email);
 }
 
@@ -999,12 +1091,12 @@ static void grab_date(const char *buf, s
 	v->value = timestamp;
 	return;
  bad:
-	v->s = "";
+	v->s = xstrdup("");
 	v->value = 0;
 }
 
 /* See grab_values */
-static void grab_person(const char *who, struct atom_value *val, int deref, struct object *obj, void *buf, unsigned long sz)
+static void grab_person(const char *who, struct atom_value *val, int deref, void *buf)
 {
 	int i;
 	int wholen = strlen(who);
@@ -1025,7 +1117,7 @@ static void grab_person(const char *who,
 		    !starts_with(name + wholen, "date"))
 			continue;
 		if (!wholine)
-			wholine = find_wholine(who, wholen, buf, sz);
+			wholine = find_wholine(who, wholen, buf);
 		if (!wholine)
 			return; /* no point looking for it */
 		if (name[wholen] == 0)
@@ -1045,7 +1137,7 @@ static void grab_person(const char *who,
 	if (strcmp(who, "tagger") && strcmp(who, "committer"))
 		return; /* "author" for commit object is not wanted */
 	if (!wholine)
-		wholine = find_wholine(who, wholen, buf, sz);
+		wholine = find_wholine(who, wholen, buf);
 	if (!wholine)
 		return;
 	for (i = 0; i < used_atom_cnt; i++) {
@@ -1063,7 +1155,7 @@ static void grab_person(const char *who,
 	}
 }
 
-static void find_subpos(const char *buf, unsigned long sz,
+static void find_subpos(const char *buf,
 			const char **sub, unsigned long *sublen,
 			const char **body, unsigned long *bodylen,
 			unsigned long *nonsiglen,
@@ -1132,7 +1224,7 @@ static void append_lines(struct strbuf *
 }
 
 /* See grab_values */
-static void grab_sub_body_contents(struct atom_value *val, int deref, struct object *obj, void *buf, unsigned long sz)
+static void grab_sub_body_contents(struct atom_value *val, int deref, void *buf)
 {
 	int i;
 	const char *subpos = NULL, *bodypos = NULL, *sigpos = NULL;
@@ -1152,7 +1244,7 @@ static void grab_sub_body_contents(struc
 		    !starts_with(name, "contents"))
 			continue;
 		if (!subpos)
-			find_subpos(buf, sz,
+			find_subpos(buf,
 				    &subpos, &sublen,
 				    &bodypos, &bodylen, &nonsiglen,
 				    &sigpos, &siglen);
@@ -1194,7 +1286,7 @@ static void fill_missing_values(struct a
 	for (i = 0; i < used_atom_cnt; i++) {
 		struct atom_value *v = &val[i];
 		if (v->s == NULL)
-			v->s = "";
+			v->s = xstrdup("");
 	}
 }
 
@@ -1205,20 +1297,19 @@ static void fill_missing_values(struct a
  * pointed at by the ref itself; otherwise it is the object the
  * ref (which is a tag) refers to.
  */
-static void grab_values(struct atom_value *val, int deref, struct object *obj, void *buf, unsigned long sz)
+static void grab_values(struct atom_value *val, int deref, struct object *obj, void *buf)
 {
-	grab_common_values(val, deref, obj, buf, sz);
 	switch (obj->type) {
 	case OBJ_TAG:
-		grab_tag_values(val, deref, obj, buf, sz);
-		grab_sub_body_contents(val, deref, obj, buf, sz);
-		grab_person("tagger", val, deref, obj, buf, sz);
+		grab_tag_values(val, deref, obj);
+		grab_sub_body_contents(val, deref, buf);
+		grab_person("tagger", val, deref, buf);
 		break;
 	case OBJ_COMMIT:
-		grab_commit_values(val, deref, obj, buf, sz);
-		grab_sub_body_contents(val, deref, obj, buf, sz);
-		grab_person("author", val, deref, obj, buf, sz);
-		grab_person("committer", val, deref, obj, buf, sz);
+		grab_commit_values(val, deref, obj);
+		grab_sub_body_contents(val, deref, buf);
+		grab_person("author", val, deref, buf);
+		grab_person("committer", val, deref, buf);
 		break;
 	case OBJ_TREE:
 		/* grab_tree_values(val, deref, obj, buf, sz); */
@@ -1241,7 +1332,8 @@ static inline char *copy_advance(char *d
 static const char *lstrip_ref_components(const char *refname, int len)
 {
 	long remaining = len;
-	const char *start = refname;
+	const char *start = xstrdup(refname);
+	const char *to_free = start;
 
 	if (len < 0) {
 		int i;
@@ -1262,20 +1354,24 @@ static const char *lstrip_ref_components
 	while (remaining > 0) {
 		switch (*start++) {
 		case '\0':
-			return "";
+			free((char *)to_free);
+			return xstrdup("");
 		case '/':
 			remaining--;
 			break;
 		}
 	}
 
+	start = xstrdup(start);
+	free((char *)to_free);
 	return start;
 }
 
 static const char *rstrip_ref_components(const char *refname, int len)
 {
 	long remaining = len;
-	char *start = xstrdup(refname);
+	const char *start = xstrdup(refname);
+	const char *to_free = start;
 
 	if (len < 0) {
 		int i;
@@ -1295,9 +1391,10 @@ static const char *rstrip_ref_components
 
 	while (remaining-- > 0) {
 		char *p = strrchr(start, '/');
-		if (p == NULL)
-			return "";
-		else
+		if (p == NULL) {
+			free((char *)to_free);
+			return xstrdup("");
+		} else
 			p[0] = '\0';
 	}
 	return start;
@@ -1312,7 +1409,7 @@ static const char *show_ref(struct refna
 	else if (atom->option == R_RSTRIP)
 		return rstrip_ref_components(refname, atom->rstrip);
 	else
-		return refname;
+		return xstrdup(refname);
 }
 
 static void fill_remote_ref_details(struct used_atom *atom, const char *refname,
@@ -1323,10 +1420,11 @@ static void fill_remote_ref_details(stru
 		*s = show_ref(&atom->u.remote_ref.refname, refname);
 	else if (atom->u.remote_ref.option == RR_TRACK) {
 		if (stat_tracking_info(branch, &num_ours, &num_theirs,
-				       NULL, AHEAD_BEHIND_FULL) < 0) {
+				       NULL, atom->u.remote_ref.push,
+				       AHEAD_BEHIND_FULL) < 0) {
 			*s = xstrdup(msgs.gone);
 		} else if (!num_ours && !num_theirs)
-			*s = "";
+			*s = xstrdup("");
 		else if (!num_ours)
 			*s = xstrfmt(msgs.behind, num_theirs);
 		else if (!num_theirs)
@@ -1341,36 +1439,32 @@ static void fill_remote_ref_details(stru
 		}
 	} else if (atom->u.remote_ref.option == RR_TRACKSHORT) {
 		if (stat_tracking_info(branch, &num_ours, &num_theirs,
-				       NULL, AHEAD_BEHIND_FULL) < 0)
+				       NULL, atom->u.remote_ref.push,
+				       AHEAD_BEHIND_FULL) < 0) {
+			*s = xstrdup("");
 			return;
-
+		}
 		if (!num_ours && !num_theirs)
-			*s = "=";
+			*s = xstrdup("=");
 		else if (!num_ours)
-			*s = "<";
+			*s = xstrdup("<");
 		else if (!num_theirs)
-			*s = ">";
+			*s = xstrdup(">");
 		else
-			*s = "<>";
+			*s = xstrdup("<>");
 	} else if (atom->u.remote_ref.option == RR_REMOTE_NAME) {
 		int explicit;
 		const char *remote = atom->u.remote_ref.push ?
 			pushremote_for_branch(branch, &explicit) :
 			remote_for_branch(branch, &explicit);
-		if (explicit)
-			*s = xstrdup(remote);
-		else
-			*s = "";
+		*s = xstrdup(explicit ? remote : "");
 	} else if (atom->u.remote_ref.option == RR_REMOTE_REF) {
 		int explicit;
 		const char *merge;
 
 		merge = remote_ref_for_branch(branch, atom->u.remote_ref.push,
 					      &explicit);
-		if (explicit)
-			*s = xstrdup(merge);
-		else
-			*s = "";
+		*s = xstrdup(explicit ? merge : "");
 	} else
 		BUG("unhandled RR_* enum");
 }
@@ -1380,36 +1474,36 @@ char *get_head_description(void)
 	struct strbuf desc = STRBUF_INIT;
 	struct wt_status_state state;
 	memset(&state, 0, sizeof(state));
-	wt_status_get_state(&state, 1);
+	wt_status_get_state(the_repository, &state, 1);
+
+	/*
+	 * The ( character must be hard-coded and not part of a localizable
+	 * string, since the description is used as a sort key and compared
+	 * with ref names.
+	 */
+	strbuf_addch(&desc, '(');
 	if (state.rebase_in_progress ||
 	    state.rebase_interactive_in_progress) {
 		if (state.branch)
-			strbuf_addf(&desc, _("(no branch, rebasing %s)"),
+			strbuf_addf(&desc, _("no branch, rebasing %s"),
 				    state.branch);
 		else
-			strbuf_addf(&desc, _("(no branch, rebasing detached HEAD %s)"),
+			strbuf_addf(&desc, _("no branch, rebasing detached HEAD %s"),
 				    state.detached_from);
 	} else if (state.bisect_in_progress)
-		strbuf_addf(&desc, _("(no branch, bisect started on %s)"),
+		strbuf_addf(&desc, _("no branch, bisect started on %s"),
 			    state.branch);
 	else if (state.detached_from) {
 		if (state.detached_at)
-			/*
-			 * TRANSLATORS: make sure this matches "HEAD
-			 * detached at " in wt-status.c
-			 */
-			strbuf_addf(&desc, _("(HEAD detached at %s)"),
-				state.detached_from);
+			strbuf_addstr(&desc, HEAD_DETACHED_AT);
 		else
-			/*
-			 * TRANSLATORS: make sure this matches "HEAD
-			 * detached from " in wt-status.c
-			 */
-			strbuf_addf(&desc, _("(HEAD detached from %s)"),
-				state.detached_from);
+			strbuf_addstr(&desc, HEAD_DETACHED_FROM);
+		strbuf_addstr(&desc, state.detached_from);
 	}
 	else
-		strbuf_addstr(&desc, _("(no branch)"));
+		strbuf_addstr(&desc, _("no branch"));
+	strbuf_addch(&desc, ')');
+
 	free(state.branch);
 	free(state.onto);
 	free(state.detached_from);
@@ -1419,7 +1513,7 @@ char *get_head_description(void)
 static const char *get_symref(struct used_atom *atom, struct ref_array_item *ref)
 {
 	if (!ref->symref)
-		return "";
+		return xstrdup("");
 	else
 		return show_ref(&atom->u.refname, ref->symref);
 }
@@ -1431,24 +1525,83 @@ static const char *get_refname(struct us
 	return show_ref(&atom->u.refname, ref->refname);
 }
 
-static int get_object(struct ref_array_item *ref, const struct object_id *oid,
-		       int deref, struct object **obj, struct strbuf *err)
+static int get_object(struct ref_array_item *ref, int deref, struct object **obj,
+		      struct expand_data *oi, struct strbuf *err)
 {
-	int eaten;
-	int ret = 0;
-	unsigned long size;
-	void *buf = get_obj(oid, obj, &size, &eaten);
-	if (!buf)
-		ret = strbuf_addf_ret(err, -1, _("missing object %s for %s"),
-				      oid_to_hex(oid), ref->refname);
-	else if (!*obj)
-		ret = strbuf_addf_ret(err, -1, _("parse_object_buffer failed on %s for %s"),
-				      oid_to_hex(oid), ref->refname);
-	else
-		grab_values(ref->value, deref, *obj, buf, size);
+	/* parse_object_buffer() will set eaten to 0 if free() will be needed */
+	int eaten = 1;
+	if (oi->info.contentp) {
+		/* We need to know that to use parse_object_buffer properly */
+		oi->info.sizep = &oi->size;
+		oi->info.typep = &oi->type;
+	}
+	if (oid_object_info_extended(the_repository, &oi->oid, &oi->info,
+				     OBJECT_INFO_LOOKUP_REPLACE))
+		return strbuf_addf_ret(err, -1, _("missing object %s for %s"),
+				       oid_to_hex(&oi->oid), ref->refname);
+	if (oi->info.disk_sizep && oi->disk_size < 0)
+		BUG("Object size is less than zero.");
+
+	if (oi->info.contentp) {
+		*obj = parse_object_buffer(the_repository, &oi->oid, oi->type, oi->size, oi->content, &eaten);
+		if (!obj) {
+			if (!eaten)
+				free(oi->content);
+			return strbuf_addf_ret(err, -1, _("parse_object_buffer failed on %s for %s"),
+					       oid_to_hex(&oi->oid), ref->refname);
+		}
+		grab_values(ref->value, deref, *obj, oi->content);
+	}
+
+	grab_common_values(ref->value, deref, oi);
 	if (!eaten)
-		free(buf);
-	return ret;
+		free(oi->content);
+	return 0;
+}
+
+static void populate_worktree_map(struct hashmap *map, struct worktree **worktrees)
+{
+	int i;
+
+	for (i = 0; worktrees[i]; i++) {
+		if (worktrees[i]->head_ref) {
+			struct ref_to_worktree_entry *entry;
+			entry = xmalloc(sizeof(*entry));
+			entry->wt = worktrees[i];
+			hashmap_entry_init(&entry->ent,
+					strhash(worktrees[i]->head_ref));
+
+			hashmap_add(map, &entry->ent);
+		}
+	}
+}
+
+static void lazy_init_worktree_map(void)
+{
+	if (ref_to_worktree_map.worktrees)
+		return;
+
+	ref_to_worktree_map.worktrees = get_worktrees(0);
+	hashmap_init(&(ref_to_worktree_map.map), ref_to_worktree_map_cmpfnc, NULL, 0);
+	populate_worktree_map(&(ref_to_worktree_map.map), ref_to_worktree_map.worktrees);
+}
+
+static char *get_worktree_path(const struct used_atom *atom, const struct ref_array_item *ref)
+{
+	struct hashmap_entry entry, *e;
+	struct ref_to_worktree_entry *lookup_result;
+
+	lazy_init_worktree_map();
+
+	hashmap_entry_init(&entry, strhash(ref->refname));
+	e = hashmap_get(&(ref_to_worktree_map.map), &entry, ref->refname);
+
+	if (!e)
+		return xstrdup("");
+
+	lookup_result = container_of(e, struct ref_to_worktree_entry, ent);
+
+	return xstrdup(lookup_result->wt->path);
 }
 
 /*
@@ -1458,7 +1611,7 @@ static int populate_value(struct ref_arr
 {
 	struct object *obj;
 	int i;
-	const struct object_id *tagged;
+	struct object_info empty = OBJECT_INFO_INIT;
 
 	ref->value = xcalloc(used_atom_cnt, sizeof(struct atom_value));
 
@@ -1466,7 +1619,7 @@ static int populate_value(struct ref_arr
 		ref->symref = resolve_refdup(ref->refname, RESOLVE_REF_READING,
 					     NULL, NULL);
 		if (!ref->symref)
-			ref->symref = "";
+			ref->symref = xstrdup("");
 	}
 
 	/* Fill in specials first */
@@ -1488,22 +1641,34 @@ static int populate_value(struct ref_arr
 
 		if (starts_with(name, "refname"))
 			refname = get_refname(atom, ref);
+		else if (!strcmp(name, "worktreepath")) {
+			if (ref->kind == FILTER_REFS_BRANCHES)
+				v->s = get_worktree_path(atom, ref);
+			else
+				v->s = xstrdup("");
+			continue;
+		}
 		else if (starts_with(name, "symref"))
 			refname = get_symref(atom, ref);
 		else if (starts_with(name, "upstream")) {
 			const char *branch_name;
 			/* only local branches may have an upstream */
 			if (!skip_prefix(ref->refname, "refs/heads/",
-					 &branch_name))
+					 &branch_name)) {
+				v->s = xstrdup("");
 				continue;
+			}
 			branch = branch_get(branch_name);
 
 			refname = branch_get_upstream(branch, NULL);
 			if (refname)
 				fill_remote_ref_details(atom, refname, branch, &v->s);
+			else
+				v->s = xstrdup("");
 			continue;
 		} else if (atom->u.remote_ref.push) {
 			const char *branch_name;
+			v->s = xstrdup("");
 			if (!skip_prefix(ref->refname, "refs/heads/",
 					 &branch_name))
 				continue;
@@ -1516,10 +1681,12 @@ static int populate_value(struct ref_arr
 				if (!refname)
 					continue;
 			}
+			/* We will definitely re-init v->s on the next line. */
+			free((char *)v->s);
 			fill_remote_ref_details(atom, refname, branch, &v->s);
 			continue;
 		} else if (starts_with(name, "color:")) {
-			v->s = atom->u.color;
+			v->s = xstrdup(atom->u.color);
 			continue;
 		} else if (!strcmp(name, "flag")) {
 			char buf[256], *cp = buf;
@@ -1528,7 +1695,7 @@ static int populate_value(struct ref_arr
 			if (ref->flag & REF_ISPACKED)
 				cp = copy_advance(cp, ",packed");
 			if (cp == buf)
-				v->s = "";
+				v->s = xstrdup("");
 			else {
 				*cp = '\0';
 				v->s = xstrdup(buf + 1);
@@ -1538,47 +1705,60 @@ static int populate_value(struct ref_arr
 			continue;
 		} else if (!strcmp(name, "HEAD")) {
 			if (atom->u.head && !strcmp(ref->refname, atom->u.head))
-				v->s = "*";
+				v->s = xstrdup("*");
 			else
-				v->s = " ";
+				v->s = xstrdup(" ");
 			continue;
 		} else if (starts_with(name, "align")) {
 			v->handler = align_atom_handler;
+			v->s = xstrdup("");
 			continue;
 		} else if (!strcmp(name, "end")) {
 			v->handler = end_atom_handler;
+			v->s = xstrdup("");
 			continue;
 		} else if (starts_with(name, "if")) {
 			const char *s;
-
 			if (skip_prefix(name, "if:", &s))
 				v->s = xstrdup(s);
+			else
+				v->s = xstrdup("");
 			v->handler = if_atom_handler;
 			continue;
 		} else if (!strcmp(name, "then")) {
 			v->handler = then_atom_handler;
+			v->s = xstrdup("");
 			continue;
 		} else if (!strcmp(name, "else")) {
 			v->handler = else_atom_handler;
+			v->s = xstrdup("");
 			continue;
 		} else
 			continue;
 
 		if (!deref)
-			v->s = refname;
+			v->s = xstrdup(refname);
 		else
 			v->s = xstrfmt("%s^{}", refname);
+		free((char *)refname);
 	}
 
 	for (i = 0; i < used_atom_cnt; i++) {
 		struct atom_value *v = &ref->value[i];
-		if (v->s == NULL)
-			break;
+		if (v->s == NULL && used_atom[i].source == SOURCE_NONE)
+			return strbuf_addf_ret(err, -1, _("missing object %s for %s"),
+					       oid_to_hex(&ref->objectname), ref->refname);
 	}
-	if (used_atom_cnt <= i)
+
+	if (need_tagged)
+		oi.info.contentp = &oi.content;
+	if (!memcmp(&oi.info, &empty, sizeof(empty)) &&
+	    !memcmp(&oi_deref.info, &empty, sizeof(empty)))
 		return 0;
 
-	if (get_object(ref, &ref->objectname, 0, &obj, err))
+
+	oi.oid = ref->objectname;
+	if (get_object(ref, 0, &obj, &oi, err))
 		return -1;
 
 	/*
@@ -1592,7 +1772,7 @@ static int populate_value(struct ref_arr
 	 * If it is a tag object, see if we use a value that derefs
 	 * the object, and if we do grab the object it refers to.
 	 */
-	tagged = &((struct tag *)obj)->tagged->oid;
+	oi_deref.oid = *get_tagged_oid((struct tag *)obj);
 
 	/*
 	 * NEEDSWORK: This derefs tag only once, which
@@ -1600,7 +1780,7 @@ static int populate_value(struct ref_arr
 	 * is not consistent with what deref_tag() does
 	 * which peels the onion to the core.
 	 */
-	return get_object(ref, tagged, 1, &obj, err);
+	return get_object(ref, 1, &obj, &oi_deref, err);
 }
 
 /*
@@ -1620,129 +1800,6 @@ static int get_ref_atom_value(struct ref
 }
 
 /*
- * Unknown has to be "0" here, because that's the default value for
- * contains_cache slab entries that have not yet been assigned.
- */
-enum contains_result {
-	CONTAINS_UNKNOWN = 0,
-	CONTAINS_NO,
-	CONTAINS_YES
-};
-
-define_commit_slab(contains_cache, enum contains_result);
-
-struct ref_filter_cbdata {
-	struct ref_array *array;
-	struct ref_filter *filter;
-	struct contains_cache contains_cache;
-	struct contains_cache no_contains_cache;
-};
-
-/*
- * Mimicking the real stack, this stack lives on the heap, avoiding stack
- * overflows.
- *
- * At each recursion step, the stack items points to the commits whose
- * ancestors are to be inspected.
- */
-struct contains_stack {
-	int nr, alloc;
-	struct contains_stack_entry {
-		struct commit *commit;
-		struct commit_list *parents;
-	} *contains_stack;
-};
-
-static int in_commit_list(const struct commit_list *want, struct commit *c)
-{
-	for (; want; want = want->next)
-		if (!oidcmp(&want->item->object.oid, &c->object.oid))
-			return 1;
-	return 0;
-}
-
-/*
- * Test whether the candidate or one of its parents is contained in the list.
- * Do not recurse to find out, though, but return -1 if inconclusive.
- */
-static enum contains_result contains_test(struct commit *candidate,
-					  const struct commit_list *want,
-					  struct contains_cache *cache)
-{
-	enum contains_result *cached = contains_cache_at(cache, candidate);
-
-	/* If we already have the answer cached, return that. */
-	if (*cached)
-		return *cached;
-
-	/* or are we it? */
-	if (in_commit_list(want, candidate)) {
-		*cached = CONTAINS_YES;
-		return CONTAINS_YES;
-	}
-
-	/* Otherwise, we don't know; prepare to recurse */
-	parse_commit_or_die(candidate);
-	return CONTAINS_UNKNOWN;
-}
-
-static void push_to_contains_stack(struct commit *candidate, struct contains_stack *contains_stack)
-{
-	ALLOC_GROW(contains_stack->contains_stack, contains_stack->nr + 1, contains_stack->alloc);
-	contains_stack->contains_stack[contains_stack->nr].commit = candidate;
-	contains_stack->contains_stack[contains_stack->nr++].parents = candidate->parents;
-}
-
-static enum contains_result contains_tag_algo(struct commit *candidate,
-					      const struct commit_list *want,
-					      struct contains_cache *cache)
-{
-	struct contains_stack contains_stack = { 0, 0, NULL };
-	enum contains_result result = contains_test(candidate, want, cache);
-
-	if (result != CONTAINS_UNKNOWN)
-		return result;
-
-	push_to_contains_stack(candidate, &contains_stack);
-	while (contains_stack.nr) {
-		struct contains_stack_entry *entry = &contains_stack.contains_stack[contains_stack.nr - 1];
-		struct commit *commit = entry->commit;
-		struct commit_list *parents = entry->parents;
-
-		if (!parents) {
-			*contains_cache_at(cache, commit) = CONTAINS_NO;
-			contains_stack.nr--;
-		}
-		/*
-		 * If we just popped the stack, parents->item has been marked,
-		 * therefore contains_test will return a meaningful yes/no.
-		 */
-		else switch (contains_test(parents->item, want, cache)) {
-		case CONTAINS_YES:
-			*contains_cache_at(cache, commit) = CONTAINS_YES;
-			contains_stack.nr--;
-			break;
-		case CONTAINS_NO:
-			entry->parents = parents->next;
-			break;
-		case CONTAINS_UNKNOWN:
-			push_to_contains_stack(parents->item, &contains_stack);
-			break;
-		}
-	}
-	free(contains_stack.contains_stack);
-	return contains_test(candidate, want, cache);
-}
-
-static int commit_contains(struct ref_filter *filter, struct commit *commit,
-			   struct commit_list *list, struct contains_cache *cache)
-{
-	if (filter->with_commit_tag_algo)
-		return contains_tag_algo(commit, list, cache) == CONTAINS_YES;
-	return is_descendant_of(commit, list);
-}
-
-/*
  * Return 1 if the refname matches one of the patterns, otherwise 0.
  * A pattern can be a literal prefix (e.g. a refname "refs/heads/master"
  * matches a pattern "refs/heads/mas") or a wildcard (e.g. the same ref
@@ -1797,7 +1854,7 @@ static int match_name_as_path(const stru
 		     refname[plen] == '/' ||
 		     p[plen-1] == '/'))
 			return 1;
-		if (!wildmatch(p, refname, WM_PATHNAME))
+		if (!wildmatch(p, refname, flags))
 			return 1;
 	}
 	return 0;
@@ -1813,21 +1870,62 @@ static int filter_pattern_match(struct r
 	return match_pattern(filter, refname);
 }
 
-/*
- * Find the longest prefix of pattern we can pass to
- * `for_each_fullref_in()`, namely the part of pattern preceding the
- * first glob character. (Note that `for_each_fullref_in()` is
- * perfectly happy working with a prefix that doesn't end at a
- * pathname component boundary.)
- */
-static void find_longest_prefix(struct strbuf *out, const char *pattern)
+static int qsort_strcmp(const void *va, const void *vb)
+{
+	const char *a = *(const char **)va;
+	const char *b = *(const char **)vb;
+
+	return strcmp(a, b);
+}
+
+static void find_longest_prefixes_1(struct string_list *out,
+				  struct strbuf *prefix,
+				  const char **patterns, size_t nr)
+{
+	size_t i;
+
+	for (i = 0; i < nr; i++) {
+		char c = patterns[i][prefix->len];
+		if (!c || is_glob_special(c)) {
+			string_list_append(out, prefix->buf);
+			return;
+		}
+	}
+
+	i = 0;
+	while (i < nr) {
+		size_t end;
+
+		/*
+		* Set "end" to the index of the element _after_ the last one
+		* in our group.
+		*/
+		for (end = i + 1; end < nr; end++) {
+			if (patterns[i][prefix->len] != patterns[end][prefix->len])
+				break;
+		}
+
+		strbuf_addch(prefix, patterns[i][prefix->len]);
+		find_longest_prefixes_1(out, prefix, patterns + i, end - i);
+		strbuf_setlen(prefix, prefix->len - 1);
+
+		i = end;
+	}
+}
+
+static void find_longest_prefixes(struct string_list *out,
+				  const char **patterns)
 {
-	const char *p;
+	struct argv_array sorted = ARGV_ARRAY_INIT;
+	struct strbuf prefix = STRBUF_INIT;
+
+	argv_array_pushv(&sorted, patterns);
+	QSORT(sorted.argv, sorted.argc, qsort_strcmp);
 
-	for (p = pattern; *p && !is_glob_special(*p); p++)
-		;
+	find_longest_prefixes_1(out, &prefix, sorted.argv, sorted.argc);
 
-	strbuf_add(out, pattern, p - pattern);
+	argv_array_clear(&sorted);
+	strbuf_release(&prefix);
 }
 
 /*
@@ -1840,7 +1938,8 @@ static int for_each_fullref_in_pattern(s
 				       void *cb_data,
 				       int broken)
 {
-	struct strbuf prefix = STRBUF_INIT;
+	struct string_list prefixes = STRING_LIST_INIT_DUP;
+	struct string_list_item *prefix;
 	int ret;
 
 	if (!filter->match_as_path) {
@@ -1852,26 +1951,29 @@ static int for_each_fullref_in_pattern(s
 		return for_each_fullref_in("", cb, cb_data, broken);
 	}
 
-	if (!filter->name_patterns[0]) {
-		/* no patterns; we have to look at everything */
+	if (filter->ignore_case) {
+		/*
+		 * we can't handle case-insensitive comparisons,
+		 * so just return everything and let the caller
+		 * sort it out.
+		 */
 		return for_each_fullref_in("", cb, cb_data, broken);
 	}
 
-	if (filter->name_patterns[1]) {
-		/*
-		 * multiple patterns; in theory this could still work as long
-		 * as the patterns are disjoint. We'd just make multiple calls
-		 * to for_each_ref(). But if they're not disjoint, we'd end up
-		 * reporting the same ref multiple times. So let's punt on that
-		 * for now.
-		 */
+	if (!filter->name_patterns[0]) {
+		/* no patterns; we have to look at everything */
 		return for_each_fullref_in("", cb, cb_data, broken);
 	}
 
-	find_longest_prefix(&prefix, filter->name_patterns[0]);
+	find_longest_prefixes(&prefixes, filter->name_patterns);
 
-	ret = for_each_fullref_in(prefix.buf, cb, cb_data, broken);
-	strbuf_release(&prefix);
+	for_each_string_list_item(prefix, &prefixes) {
+		ret = for_each_fullref_in(prefix->string, cb, cb_data, broken);
+		if (ret)
+			break;
+	}
+
+	string_list_clear(&prefixes, 0);
 	return ret;
 }
 
@@ -1897,11 +1999,11 @@ static const struct object_id *match_poi
 
 	if (oid_array_lookup(points_at, oid) >= 0)
 		return oid;
-	obj = parse_object(oid);
+	obj = parse_object(the_repository, oid);
 	if (!obj)
 		die(_("malformed object at '%s'"), refname);
 	if (obj->type == OBJ_TAG)
-		tagged_oid = &((struct tag *)obj)->tagged->oid;
+		tagged_oid = get_tagged_oid((struct tag *)obj);
 	if (tagged_oid && oid_array_lookup(points_at, tagged_oid) >= 0)
 		return tagged_oid;
 	return NULL;
@@ -1968,6 +2070,13 @@ static int filter_ref_kind(struct ref_fi
 	return ref_kind_from_refname(refname);
 }
 
+struct ref_filter_cbdata {
+	struct ref_array *array;
+	struct ref_filter *filter;
+	struct contains_cache contains_cache;
+	struct contains_cache no_contains_cache;
+};
+
 /*
  * A call-back given to for_each_ref().  Filter refs and keep them for
  * later object processing.
@@ -2007,7 +2116,8 @@ static int ref_filter_handler(const char
 	 * non-commits early. The actual filtering is done later.
 	 */
 	if (filter->merge_commit || filter->with_commit || filter->no_commit || filter->verbose) {
-		commit = lookup_commit_reference_gently(oid, 1);
+		commit = lookup_commit_reference_gently(the_repository, oid,
+							1);
 		if (!commit)
 			return 0;
 		/* We perform the filtering for the '--contains' option... */
@@ -2037,6 +2147,12 @@ static int ref_filter_handler(const char
 static void free_array_item(struct ref_array_item *item)
 {
 	free((char *)item->symref);
+	if (item->value) {
+		int i;
+		for (i = 0; i < used_atom_cnt; i++)
+			free((char *)item->value[i].s);
+		free(item->value);
+	}
 	free(item);
 }
 
@@ -2049,6 +2165,18 @@ void ref_array_clear(struct ref_array *a
 		free_array_item(array->items[i]);
 	FREE_AND_NULL(array->items);
 	array->nr = array->alloc = 0;
+
+	for (i = 0; i < used_atom_cnt; i++)
+		free((char *)used_atom[i].name);
+	FREE_AND_NULL(used_atom);
+	used_atom_cnt = 0;
+
+	if (ref_to_worktree_map.worktrees) {
+		hashmap_free_entries(&(ref_to_worktree_map.map),
+					struct ref_to_worktree_entry, ent);
+		free_worktrees(ref_to_worktree_map.worktrees);
+		ref_to_worktree_map.worktrees = NULL;
+	}
 }
 
 static void do_merge_filter(struct ref_filter_cbdata *ref_cbdata)
@@ -2059,7 +2187,7 @@ static void do_merge_filter(struct ref_f
 	struct ref_array *array = ref_cbdata->array;
 	struct commit **to_clear = xcalloc(sizeof(struct commit *), array->nr);
 
-	init_revisions(&revs, NULL);
+	repo_init_revisions(the_repository, &revs, NULL);
 
 	for (i = 0; i < array->nr; i++) {
 		struct ref_array_item *item = array->items[i];
@@ -2337,8 +2465,13 @@ void parse_ref_sorting(struct ref_sortin
 
 int parse_opt_ref_sorting(const struct option *opt, const char *arg, int unset)
 {
-	if (!arg) /* should --no-sort void the list ? */
-		return -1;
+	/*
+	 * NEEDSWORK: We should probably clear the list in this case, but we've
+	 * already munged the global used_atoms list, which would need to be
+	 * undone.
+	 */
+	BUG_ON_OPT_NEG(unset);
+
 	parse_ref_sorting(opt->value, arg);
 	return 0;
 }
@@ -2349,11 +2482,15 @@ int parse_opt_merge_filter(const struct
 	struct object_id oid;
 	int no_merged = starts_with(opt->long_name, "no");
 
+	BUG_ON_OPT_NEG(unset);
+
 	if (rf->merge) {
 		if (no_merged) {
-			return opterror(opt, "is incompatible with --merged", 0);
+			return error(_("option `%s' is incompatible with --merged"),
+				     opt->long_name);
 		} else {
-			return opterror(opt, "is incompatible with --no-merged", 0);
+			return error(_("option `%s' is incompatible with --no-merged"),
+				     opt->long_name);
 		}
 	}
 
@@ -2364,9 +2501,10 @@ int parse_opt_merge_filter(const struct
 	if (get_oid(arg, &oid))
 		die(_("malformed object name %s"), arg);
 
-	rf->merge_commit = lookup_commit_reference_gently(&oid, 0);
+	rf->merge_commit = lookup_commit_reference_gently(the_repository,
+							  &oid, 0);
 	if (!rf->merge_commit)
-		return opterror(opt, "must point to a commit", 0);
+		return error(_("option `%s' must point to a commit"), opt->long_name);
 
 	return 0;
 }
diff -pruN 1.2.1+git2.18.0-1/git/ref-filter.h 1.2.3+git2.25.1-1/git/ref-filter.h
--- 1.2.1+git2.18.0-1/git/ref-filter.h	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/ref-filter.h	2020-02-17 04:47:35.000000000 +0000
@@ -96,6 +96,11 @@ struct ref_format {
 #define OPT_MERGED(f, h) _OPT_MERGED_NO_MERGED("merged", f, h)
 #define OPT_NO_MERGED(f, h) _OPT_MERGED_NO_MERGED("no-merged", f, h)
 
+#define OPT_REF_SORT(var) \
+	OPT_CALLBACK_F(0, "sort", (var), \
+		       N_("key"), N_("field name to sort on"), \
+		       PARSE_OPT_NONEG, parse_opt_ref_sorting)
+
 /*
  * API for filtering a set of refs. Based on the type of refs the user
  * has requested, we iterate through those refs and apply filters
diff -pruN 1.2.1+git2.18.0-1/git/reflog-walk.c 1.2.3+git2.25.1-1/git/reflog-walk.c
--- 1.2.1+git2.18.0-1/git/reflog-walk.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/reflog-walk.c	2020-02-17 04:47:35.000000000 +0000
@@ -128,7 +128,7 @@ int add_reflog_for_walk(struct reflog_wa
 	enum selector_type selector = SELECTOR_NONE;
 
 	if (commit->object.flags & UNINTERESTING)
-		die ("Cannot walk reflogs for %s", name);
+		die("cannot walk reflogs for %s", name);
 
 	branch = xstrdup(name);
 	if (at && at[1] == '{') {
@@ -153,7 +153,7 @@ int add_reflog_for_walk(struct reflog_wa
 			free(branch);
 			branch = resolve_refdup("HEAD", 0, NULL, NULL);
 			if (!branch)
-				die ("No current branch");
+				die("no current branch");
 
 		}
 		reflogs = read_complete_reflog(branch);
@@ -305,7 +305,8 @@ static struct commit *next_reflog_commit
 {
 	for (; log->recno >= 0; log->recno--) {
 		struct reflog_info *entry = &log->reflogs->items[log->recno];
-		struct object *obj = parse_object(&entry->noid);
+		struct object *obj = parse_object(the_repository,
+						  &entry->noid);
 
 		if (obj && obj->type == OBJ_COMMIT)
 			return (struct commit *)obj;
diff -pruN 1.2.1+git2.18.0-1/git/reflog-walk.h 1.2.3+git2.25.1-1/git/reflog-walk.h
--- 1.2.1+git2.18.0-1/git/reflog-walk.h	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/reflog-walk.h	2020-02-17 04:47:35.000000000 +0000
@@ -3,23 +3,24 @@
 
 #include "cache.h"
 
+struct commit;
 struct reflog_walk_info;
 
-extern void init_reflog_walk(struct reflog_walk_info **info);
-extern int add_reflog_for_walk(struct reflog_walk_info *info,
-		struct commit *commit, const char *name);
-extern void show_reflog_message(struct reflog_walk_info *info, int,
-				const struct date_mode *, int force_date);
-extern void get_reflog_message(struct strbuf *sb,
-		struct reflog_walk_info *reflog_info);
-extern const char *get_reflog_ident(struct reflog_walk_info *reflog_info);
-extern timestamp_t get_reflog_timestamp(struct reflog_walk_info *reflog_info);
-extern void get_reflog_selector(struct strbuf *sb,
-		struct reflog_walk_info *reflog_info,
-		const struct date_mode *dmode, int force_date,
-		int shorten);
+void init_reflog_walk(struct reflog_walk_info **info);
+int add_reflog_for_walk(struct reflog_walk_info *info,
+			struct commit *commit, const char *name);
+void show_reflog_message(struct reflog_walk_info *info, int,
+			 const struct date_mode *, int force_date);
+void get_reflog_message(struct strbuf *sb,
+			struct reflog_walk_info *reflog_info);
+const char *get_reflog_ident(struct reflog_walk_info *reflog_info);
+timestamp_t get_reflog_timestamp(struct reflog_walk_info *reflog_info);
+void get_reflog_selector(struct strbuf *sb,
+			 struct reflog_walk_info *reflog_info,
+			 const struct date_mode *dmode, int force_date,
+			 int shorten);
 
-extern int reflog_walk_empty(struct reflog_walk_info *walk);
+int reflog_walk_empty(struct reflog_walk_info *walk);
 
 struct commit *next_reflog_entry(struct reflog_walk_info *reflog_info);
 
diff -pruN 1.2.1+git2.18.0-1/git/refs/files-backend.c 1.2.3+git2.25.1-1/git/refs/files-backend.c
--- 1.2.1+git2.18.0-1/git/refs/files-backend.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/refs/files-backend.c	2020-02-17 04:47:35.000000000 +0000
@@ -10,6 +10,7 @@
 #include "../object.h"
 #include "../dir.h"
 #include "../chdir-notify.h"
+#include "worktree.h"
 
 /*
  * This backend uses the following flags in `ref_update::flags` for
@@ -149,6 +150,25 @@ static struct files_ref_store *files_dow
 	return refs;
 }
 
+static void files_reflog_path_other_worktrees(struct files_ref_store *refs,
+					      struct strbuf *sb,
+					      const char *refname)
+{
+	const char *real_ref;
+	const char *worktree_name;
+	int length;
+
+	if (parse_worktree_ref(refname, &worktree_name, &length, &real_ref))
+		BUG("refname %s is not a other-worktree ref", refname);
+
+	if (worktree_name)
+		strbuf_addf(sb, "%s/worktrees/%.*s/logs/%s", refs->gitcommondir,
+			    length, worktree_name, real_ref);
+	else
+		strbuf_addf(sb, "%s/logs/%s", refs->gitcommondir,
+			    real_ref);
+}
+
 static void files_reflog_path(struct files_ref_store *refs,
 			      struct strbuf *sb,
 			      const char *refname)
@@ -158,6 +178,10 @@ static void files_reflog_path(struct fil
 	case REF_TYPE_PSEUDOREF:
 		strbuf_addf(sb, "%s/logs/%s", refs->gitdir, refname);
 		break;
+	case REF_TYPE_OTHER_PSEUDOREF:
+	case REF_TYPE_MAIN_PSEUDOREF:
+		files_reflog_path_other_worktrees(refs, sb, refname);
+		break;
 	case REF_TYPE_NORMAL:
 		strbuf_addf(sb, "%s/logs/%s", refs->gitcommondir, refname);
 		break;
@@ -176,6 +200,11 @@ static void files_ref_path(struct files_
 	case REF_TYPE_PSEUDOREF:
 		strbuf_addf(sb, "%s/%s", refs->gitdir, refname);
 		break;
+	case REF_TYPE_MAIN_PSEUDOREF:
+		if (!skip_prefix(refname, "main-worktree/", &refname))
+			BUG("ref %s is not a main pseudoref", refname);
+		/* fallthrough */
+	case REF_TYPE_OTHER_PSEUDOREF:
 	case REF_TYPE_NORMAL:
 		strbuf_addf(sb, "%s/%s", refs->gitcommondir, refname);
 		break;
@@ -186,6 +215,33 @@ static void files_ref_path(struct files_
 }
 
 /*
+ * Manually add refs/bisect, refs/rewritten and refs/worktree, which, being
+ * per-worktree, might not appear in the directory listing for
+ * refs/ in the main repo.
+ */
+static void add_per_worktree_entries_to_dir(struct ref_dir *dir, const char *dirname)
+{
+	const char *prefixes[] = { "refs/bisect/", "refs/worktree/", "refs/rewritten/" };
+	int ip;
+
+	if (strcmp(dirname, "refs/"))
+		return;
+
+	for (ip = 0; ip < ARRAY_SIZE(prefixes); ip++) {
+		const char *prefix = prefixes[ip];
+		int prefix_len = strlen(prefix);
+		struct ref_entry *child_entry;
+		int pos;
+
+		pos = search_ref_dir(dir, prefix, prefix_len);
+		if (pos >= 0)
+			continue;
+		child_entry = create_dir_entry(dir->cache, prefix, prefix_len, 1);
+		add_entry_to_dir(dir, child_entry);
+	}
+}
+
+/*
  * Read the loose references from the namespace dirname into dir
  * (without recursing).  dirname must end with '/'.  dir must be the
  * directory entry corresponding to dirname.
@@ -268,20 +324,7 @@ static void loose_fill_ref_dir(struct re
 	strbuf_release(&path);
 	closedir(d);
 
-	/*
-	 * Manually add refs/bisect, which, being per-worktree, might
-	 * not appear in the directory listing for refs/ in the main
-	 * repo.
-	 */
-	if (!strcmp(dirname, "refs/")) {
-		int pos = search_ref_dir(dir, "refs/bisect/", 12);
-
-		if (pos < 0) {
-			struct ref_entry *child_entry = create_dir_entry(
-					dir->cache, "refs/bisect/", 12, 1);
-			add_entry_to_dir(dir, child_entry);
-		}
-	}
+	add_per_worktree_entries_to_dir(dir, dirname);
 }
 
 static struct ref_cache *get_loose_ref_cache(struct files_ref_store *refs)
@@ -363,7 +406,7 @@ stat_ref:
 	/* Follow "normalized" - ie "refs/.." symlinks by hand */
 	if (S_ISLNK(st.st_mode)) {
 		strbuf_reset(&sb_contents);
-		if (strbuf_readlink(&sb_contents, path, 0) < 0) {
+		if (strbuf_readlink(&sb_contents, path, st.st_size) < 0) {
 			if (errno == ENOENT || errno == EINVAL)
 				/* inconsistent with lstat; retry */
 				goto stat_ref;
@@ -841,7 +884,7 @@ static int verify_lock(struct ref_store
 			return 0;
 		}
 	}
-	if (old_oid && oidcmp(&lock->old_oid, old_oid)) {
+	if (old_oid && !oideq(&lock->old_oid, old_oid)) {
 		strbuf_addf(err, "ref '%s' is at %s but expected %s",
 			    lock->ref_name,
 			    oid_to_hex(&lock->old_oid),
@@ -1284,7 +1327,7 @@ static int files_copy_or_rename_ref(stru
 {
 	struct files_ref_store *refs =
 		files_downcast(ref_store, REF_STORE_WRITE, "rename_ref");
-	struct object_id oid, orig_oid;
+	struct object_id orig_oid;
 	int flag = 0, logmoved = 0;
 	struct ref_lock *lock;
 	struct stat loginfo;
@@ -1352,7 +1395,7 @@ static int files_copy_or_rename_ref(stru
 	 */
 	if (!copy && !refs_read_ref_full(&refs->base, newrefname,
 				RESOLVE_REF_READING | RESOLVE_REF_NO_RECURSE,
-				&oid, NULL) &&
+				NULL, NULL) &&
 	    refs_delete_ref(&refs->base, NULL, newrefname,
 			    NULL, REF_NO_DEREF)) {
 		if (errno == EISDIR) {
@@ -1582,26 +1625,17 @@ static int log_ref_write_fd(int fd, cons
 			    const struct object_id *new_oid,
 			    const char *committer, const char *msg)
 {
-	int msglen, written;
-	unsigned maxlen, len;
-	char *logrec;
-
-	msglen = msg ? strlen(msg) : 0;
-	maxlen = strlen(committer) + msglen + 100;
-	logrec = xmalloc(maxlen);
-	len = xsnprintf(logrec, maxlen, "%s %s %s\n",
-			oid_to_hex(old_oid),
-			oid_to_hex(new_oid),
-			committer);
-	if (msglen)
-		len += copy_reflog_msg(logrec + len - 1, msg) - 1;
-
-	written = len <= maxlen ? write_in_full(fd, logrec, len) : -1;
-	free(logrec);
-	if (written < 0)
-		return -1;
+	struct strbuf sb = STRBUF_INIT;
+	int ret = 0;
 
-	return 0;
+	strbuf_addf(&sb, "%s %s %s", oid_to_hex(old_oid), oid_to_hex(new_oid), committer);
+	if (msg && *msg)
+		copy_reflog_msg(&sb, msg);
+	strbuf_addch(&sb, '\n');
+	if (write_in_full(fd, sb.buf, sb.len) < 0)
+		ret = -1;
+	strbuf_release(&sb);
+	return ret;
 }
 
 static int files_log_ref_write(struct files_ref_store *refs,
@@ -1660,7 +1694,7 @@ static int write_ref_to_lockfile(struct
 	struct object *o;
 	int fd;
 
-	o = parse_object(oid);
+	o = parse_object(the_repository, oid);
 	if (!o) {
 		strbuf_addf(err,
 			    "trying to write ref '%s' with nonexistent object %s",
@@ -1676,7 +1710,7 @@ static int write_ref_to_lockfile(struct
 		return -1;
 	}
 	fd = get_lock_file_fd(&lock->lk);
-	if (write_in_full(fd, oid_to_hex(oid), GIT_SHA1_HEXSZ) < 0 ||
+	if (write_in_full(fd, oid_to_hex(oid), the_hash_algo->hexsz) < 0 ||
 	    write_in_full(fd, &term, 1) < 0 ||
 	    close_ref_gently(lock) < 0) {
 		strbuf_addf(err,
@@ -2109,13 +2143,24 @@ static struct ref_iterator_vtable files_
 static struct ref_iterator *reflog_iterator_begin(struct ref_store *ref_store,
 						  const char *gitdir)
 {
-	struct files_reflog_iterator *iter = xcalloc(1, sizeof(*iter));
-	struct ref_iterator *ref_iterator = &iter->base;
+	struct dir_iterator *diter;
+	struct files_reflog_iterator *iter;
+	struct ref_iterator *ref_iterator;
 	struct strbuf sb = STRBUF_INIT;
 
-	base_ref_iterator_init(ref_iterator, &files_reflog_iterator_vtable, 0);
 	strbuf_addf(&sb, "%s/logs", gitdir);
-	iter->dir_iterator = dir_iterator_begin(sb.buf);
+
+	diter = dir_iterator_begin(sb.buf, 0);
+	if (!diter) {
+		strbuf_release(&sb);
+		return empty_ref_iterator_begin();
+	}
+
+	iter = xcalloc(1, sizeof(*iter));
+	ref_iterator = &iter->base;
+
+	base_ref_iterator_init(ref_iterator, &files_reflog_iterator_vtable, 0);
+	iter->dir_iterator = diter;
 	iter->ref_store = ref_store;
 	strbuf_release(&sb);
 
@@ -2226,8 +2271,7 @@ static int split_head_update(struct ref_
  * Note that the new update will itself be subject to splitting when
  * the iteration gets to it.
  */
-static int split_symref_update(struct files_ref_store *refs,
-			       struct ref_update *update,
+static int split_symref_update(struct ref_update *update,
 			       const char *referent,
 			       struct ref_transaction *transaction,
 			       struct string_list *affected_refnames,
@@ -2316,7 +2360,7 @@ static int check_old_oid(struct ref_upda
 			 struct strbuf *err)
 {
 	if (!(update->flags & REF_HAVE_OLD) ||
-		   !oidcmp(oid, &update->old_oid))
+		   oideq(oid, &update->old_oid))
 		return 0;
 
 	if (is_null_oid(&update->old_oid))
@@ -2421,7 +2465,7 @@ static int lock_ref_for_update(struct fi
 			 * of processing the split-off update, so we
 			 * don't have to do it here.
 			 */
-			ret = split_symref_update(refs, update,
+			ret = split_symref_update(update,
 						  referent.buf, transaction,
 						  affected_refnames, err);
 			if (ret)
@@ -2452,7 +2496,7 @@ static int lock_ref_for_update(struct fi
 	    !(update->flags & REF_DELETING) &&
 	    !(update->flags & REF_LOG_ONLY)) {
 		if (!(update->type & REF_ISSYMREF) &&
-		    !oidcmp(&lock->old_oid, &update->new_oid)) {
+		    oideq(&lock->old_oid, &update->new_oid)) {
 			/*
 			 * The reference already has the desired
 			 * value, so we don't need to write it.
@@ -2668,18 +2712,32 @@ static int files_transaction_prepare(str
 		if (is_packed_transaction_needed(refs->packed_ref_store,
 						 packed_transaction)) {
 			ret = ref_transaction_prepare(packed_transaction, err);
+			/*
+			 * A failure during the prepare step will abort
+			 * itself, but not free. Do that now, and disconnect
+			 * from the files_transaction so it does not try to
+			 * abort us when we hit the cleanup code below.
+			 */
+			if (ret) {
+				ref_transaction_free(packed_transaction);
+				backend_data->packed_transaction = NULL;
+			}
 		} else {
 			/*
 			 * We can skip rewriting the `packed-refs`
 			 * file. But we do need to leave it locked, so
 			 * that somebody else doesn't pack a reference
 			 * that we are trying to delete.
+			 *
+			 * We need to disconnect our transaction from
+			 * backend_data, since the abort (whether successful or
+			 * not) will free it.
 			 */
+			backend_data->packed_transaction = NULL;
 			if (ref_transaction_abort(packed_transaction, err)) {
 				ret = TRANSACTION_GENERIC_ERROR;
 				goto cleanup;
 			}
-			backend_data->packed_transaction = NULL;
 		}
 	}
 
@@ -3070,7 +3128,7 @@ static int files_reflog_expire(struct re
 			rollback_lock_file(&reflog_lock);
 		} else if (update &&
 			   (write_in_full(get_lock_file_fd(&lock->lk),
-				oid_to_hex(&cb.last_kept_oid), GIT_SHA1_HEXSZ) < 0 ||
+				oid_to_hex(&cb.last_kept_oid), the_hash_algo->hexsz) < 0 ||
 			    write_str_in_full(get_lock_file_fd(&lock->lk), "\n") < 0 ||
 			    close_ref_gently(lock) < 0)) {
 			status |= error("couldn't write %s",
diff -pruN 1.2.1+git2.18.0-1/git/refs/iterator.c 1.2.3+git2.25.1-1/git/refs/iterator.c
--- 1.2.1+git2.18.0-1/git/refs/iterator.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/refs/iterator.c	2020-02-17 04:47:35.000000000 +0000
@@ -407,15 +407,15 @@ struct ref_iterator *prefix_ref_iterator
 
 struct ref_iterator *current_ref_iter = NULL;
 
-int do_for_each_ref_iterator(struct ref_iterator *iter,
-			     each_ref_fn fn, void *cb_data)
+int do_for_each_repo_ref_iterator(struct repository *r, struct ref_iterator *iter,
+				  each_repo_ref_fn fn, void *cb_data)
 {
 	int retval = 0, ok;
 	struct ref_iterator *old_ref_iter = current_ref_iter;
 
 	current_ref_iter = iter;
 	while ((ok = ref_iterator_advance(iter)) == ITER_OK) {
-		retval = fn(iter->refname, iter->oid, iter->flags, cb_data);
+		retval = fn(r, iter->refname, iter->oid, iter->flags, cb_data);
 		if (retval) {
 			/*
 			 * If ref_iterator_abort() returns ITER_ERROR,
diff -pruN 1.2.1+git2.18.0-1/git/refs/packed-backend.c 1.2.3+git2.25.1-1/git/refs/packed-backend.c
--- 1.2.1+git2.18.0-1/git/refs/packed-backend.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/refs/packed-backend.c	2020-02-17 04:47:35.000000000 +0000
@@ -274,8 +274,8 @@ struct snapshot_record {
 static int cmp_packed_ref_records(const void *v1, const void *v2)
 {
 	const struct snapshot_record *e1 = v1, *e2 = v2;
-	const char *r1 = e1->start + GIT_SHA1_HEXSZ + 1;
-	const char *r2 = e2->start + GIT_SHA1_HEXSZ + 1;
+	const char *r1 = e1->start + the_hash_algo->hexsz + 1;
+	const char *r2 = e2->start + the_hash_algo->hexsz + 1;
 
 	while (1) {
 		if (*r1 == '\n')
@@ -297,7 +297,7 @@ static int cmp_packed_ref_records(const
  */
 static int cmp_record_to_refname(const char *rec, const char *refname)
 {
-	const char *r1 = rec + GIT_SHA1_HEXSZ + 1;
+	const char *r1 = rec + the_hash_algo->hexsz + 1;
 	const char *r2 = refname;
 
 	while (1) {
@@ -344,7 +344,7 @@ static void sort_snapshot(struct snapsho
 		if (!eol)
 			/* The safety check should prevent this. */
 			BUG("unterminated line found in packed-refs");
-		if (eol - pos < GIT_SHA1_HEXSZ + 2)
+		if (eol - pos < the_hash_algo->hexsz + 2)
 			die_invalid_line(snapshot->refs->path,
 					 pos, eof - pos);
 		eol++;
@@ -456,7 +456,7 @@ static void verify_buffer_safe(struct sn
 		return;
 
 	last_line = find_start_of_record(start, eof - 1);
-	if (*(eof - 1) != '\n' || eof - last_line < GIT_SHA1_HEXSZ + 2)
+	if (*(eof - 1) != '\n' || eof - last_line < the_hash_algo->hexsz + 2)
 		die_invalid_line(snapshot->refs->path,
 				 last_line, eof - last_line);
 }
@@ -499,6 +499,7 @@ static int load_contents(struct snapshot
 	size = xsize_t(st.st_size);
 
 	if (!size) {
+		close(fd);
 		return 0;
 	} else if (mmap_strategy == MMAP_NONE || size <= SMALL_FILE_SIZE) {
 		snapshot->buf = xmalloc(size);
@@ -795,7 +796,7 @@ static int next_record(struct packed_ref
 
 	iter->base.flags = REF_ISPACKED;
 
-	if (iter->eof - p < GIT_SHA1_HEXSZ + 2 ||
+	if (iter->eof - p < the_hash_algo->hexsz + 2 ||
 	    parse_oid_hex(p, &iter->oid, &p) ||
 	    !isspace(*p++))
 		die_invalid_line(iter->snapshot->refs->path,
@@ -825,7 +826,7 @@ static int next_record(struct packed_ref
 
 	if (iter->pos < iter->eof && *iter->pos == '^') {
 		p = iter->pos + 1;
-		if (iter->eof - p < GIT_SHA1_HEXSZ + 1 ||
+		if (iter->eof - p < the_hash_algo->hexsz + 1 ||
 		    parse_oid_hex(p, &iter->peeled, &p) ||
 		    *p++ != '\n')
 			die_invalid_line(iter->snapshot->refs->path,
@@ -1011,14 +1012,23 @@ int packed_refs_lock(struct ref_store *r
 	}
 
 	/*
-	 * Now that we hold the `packed-refs` lock, make sure that our
-	 * snapshot matches the current version of the file. Normally
-	 * `get_snapshot()` does that for us, but that function
-	 * assumes that when the file is locked, any existing snapshot
-	 * is still valid. We've just locked the file, but it might
-	 * have changed the moment *before* we locked it.
+	 * There is a stat-validity problem might cause `update-ref -d`
+	 * lost the newly commit of a ref, because a new `packed-refs`
+	 * file might has the same on-disk file attributes such as
+	 * timestamp, file size and inode value, but has a changed
+	 * ref value.
+	 *
+	 * This could happen with a very small chance when
+	 * `update-ref -d` is called and at the same time another
+	 * `pack-refs --all` process is running.
+	 *
+	 * Now that we hold the `packed-refs` lock, it is important
+	 * to make sure we could read the latest version of
+	 * `packed-refs` file no matter we have just mmap it or not.
+	 * So what need to do is clear the snapshot if we hold it
+	 * already.
 	 */
-	validate_snapshot(refs);
+	clear_snapshot(refs);
 
 	/*
 	 * Now make sure that the packed-refs file as it exists in the
@@ -1159,7 +1169,7 @@ static int write_with_updates(struct pac
 						    "reference already exists",
 						    update->refname);
 					goto error;
-				} else if (oidcmp(&update->old_oid, iter->oid)) {
+				} else if (!oideq(&update->old_oid, iter->oid)) {
 					strbuf_addf(err, "cannot update ref '%s': "
 						    "is at %s but expected %s",
 						    update->refname,
diff -pruN 1.2.1+git2.18.0-1/git/refs/packed-backend.h 1.2.3+git2.25.1-1/git/refs/packed-backend.h
--- 1.2.1+git2.18.0-1/git/refs/packed-backend.h	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/refs/packed-backend.h	2020-02-17 04:47:35.000000000 +0000
@@ -1,6 +1,8 @@
 #ifndef REFS_PACKED_BACKEND_H
 #define REFS_PACKED_BACKEND_H
 
+struct ref_transaction;
+
 /*
  * Support for storing references in a `packed-refs` file.
  *
diff -pruN 1.2.1+git2.18.0-1/git/refs/ref-cache.c 1.2.3+git2.25.1-1/git/refs/ref-cache.c
--- 1.2.1+git2.18.0-1/git/refs/ref-cache.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/refs/ref-cache.c	2020-02-17 04:47:35.000000000 +0000
@@ -272,7 +272,7 @@ static int is_dup_ref(const struct ref_e
 		/* This is impossible by construction */
 		die("Reference directory conflict: %s", ref1->name);
 
-	if (oidcmp(&ref1->u.value.oid, &ref2->u.value.oid))
+	if (!oideq(&ref1->u.value.oid, &ref2->u.value.oid))
 		die("Duplicated ref, and SHA1s don't match: %s", ref1->name);
 
 	warning("Duplicated ref: %s", ref1->name);
diff -pruN 1.2.1+git2.18.0-1/git/refs/ref-cache.h 1.2.3+git2.25.1-1/git/refs/ref-cache.h
--- 1.2.1+git2.18.0-1/git/refs/ref-cache.h	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/refs/ref-cache.h	2020-02-17 04:47:35.000000000 +0000
@@ -1,7 +1,10 @@
 #ifndef REFS_REF_CACHE_H
 #define REFS_REF_CACHE_H
 
+#include "cache.h"
+
 struct ref_dir;
+struct ref_store;
 
 /*
  * If this ref_cache is filled lazily, this function is used to load
diff -pruN 1.2.1+git2.18.0-1/git/refs/refs-internal.h 1.2.3+git2.25.1-1/git/refs/refs-internal.h
--- 1.2.1+git2.18.0-1/git/refs/refs-internal.h	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/refs/refs-internal.h	2020-02-17 04:47:35.000000000 +0000
@@ -1,6 +1,12 @@
 #ifndef REFS_REFS_INTERNAL_H
 #define REFS_REFS_INTERNAL_H
 
+#include "cache.h"
+#include "refs.h"
+#include "iterator.h"
+
+struct ref_transaction;
+
 /*
  * Data structures and functions for the internal use of the refs
  * module. Code outside of the refs module should use only the public
@@ -91,11 +97,10 @@ enum peel_status {
 enum peel_status peel_object(const struct object_id *name, struct object_id *oid);
 
 /*
- * Copy the reflog message msg to buf, which has been allocated sufficiently
- * large, while cleaning up the whitespaces.  Especially, convert LF to space,
- * because reflog file is one line per entry.
+ * Copy the reflog message msg to sb while cleaning up the whitespaces.
+ * Especially, convert LF to space, because reflog file is one line per entry.
  */
-int copy_reflog_msg(char *buf, const char *msg);
+void copy_reflog_msg(struct strbuf *sb, const char *msg);
 
 /**
  * Information needed for a single ref update. Set new_oid to the new
@@ -257,7 +262,7 @@ int refs_rename_ref_available(struct ref
  * after calling ref_iterator_advance() again or calling
  * ref_iterator_abort(), you must make a copy. When the iteration has
  * been exhausted, ref_iterator_advance() releases any resources
- * assocated with the iteration, frees the ref_iterator object, and
+ * associated with the iteration, frees the ref_iterator object, and
  * returns ITER_DONE. If you want to abort the iteration early, call
  * ref_iterator_abort(), which also frees the ref_iterator object and
  * any associated resources. If there was an internal error advancing
@@ -281,7 +286,7 @@ int refs_rename_ref_available(struct ref
  *
  *             // Access information about the current reference:
  *             if (!(iter->flags & REF_ISSYMREF))
- *                     printf("%s is %s\n", iter->refname, oid_to_hex(&iter->oid));
+ *                     printf("%s is %s\n", iter->refname, oid_to_hex(iter->oid));
  *
  *             // If you need to peel the reference:
  *             ref_iterator_peel(iter, &oid);
@@ -473,8 +478,9 @@ extern struct ref_iterator *current_ref_
  * adapter between the callback style of reference iteration and the
  * iterator style.
  */
-int do_for_each_ref_iterator(struct ref_iterator *iter,
-			     each_ref_fn fn, void *cb_data);
+int do_for_each_repo_ref_iterator(struct repository *r,
+				  struct ref_iterator *iter,
+				  each_repo_ref_fn fn, void *cb_data);
 
 /*
  * Only include per-worktree refs in a do_for_each_ref*() iteration.
diff -pruN 1.2.1+git2.18.0-1/git/refs.c 1.2.3+git2.25.1-1/git/refs.c
--- 1.2.1+git2.18.0-1/git/refs.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/refs.c	2020-02-17 04:47:35.000000000 +0000
@@ -9,6 +9,7 @@
 #include "iterator.h"
 #include "refs.h"
 #include "refs/refs-internal.h"
+#include "object-store.h"
 #include "object.h"
 #include "tag.h"
 #include "submodule.h"
@@ -62,7 +63,7 @@ static unsigned char refname_disposition
  * not legal.  It is legal if it is something reasonable to have under
  * ".git/refs/"; We do not like it if:
  *
- * - any path component of it begins with ".", or
+ * - it begins with ".", or
  * - it has double dots "..", or
  * - it has ASCII control characters, or
  * - it has ":", "?", "[", "\", "^", "~", SP, or TAB anywhere, or
@@ -70,31 +71,63 @@ static unsigned char refname_disposition
  * - it ends with a "/", or
  * - it ends with ".lock", or
  * - it contains a "@{" portion
+ *
+ * When sanitized is not NULL, instead of rejecting the input refname
+ * as an error, try to come up with a usable replacement for the input
+ * refname in it.
  */
-static int check_refname_component(const char *refname, int *flags)
+static int check_refname_component(const char *refname, int *flags,
+				   struct strbuf *sanitized)
 {
 	const char *cp;
 	char last = '\0';
+	size_t component_start = 0; /* garbage - not a reasonable initial value */
+
+	if (sanitized)
+		component_start = sanitized->len;
 
 	for (cp = refname; ; cp++) {
 		int ch = *cp & 255;
 		unsigned char disp = refname_disposition[ch];
+
+		if (sanitized && disp != 1)
+			strbuf_addch(sanitized, ch);
+
 		switch (disp) {
 		case 1:
 			goto out;
 		case 2:
-			if (last == '.')
-				return -1; /* Refname contains "..". */
+			if (last == '.') { /* Refname contains "..". */
+				if (sanitized)
+					/* collapse ".." to single "." */
+					strbuf_setlen(sanitized, sanitized->len - 1);
+				else
+					return -1;
+			}
 			break;
 		case 3:
-			if (last == '@')
-				return -1; /* Refname contains "@{". */
+			if (last == '@') { /* Refname contains "@{". */
+				if (sanitized)
+					sanitized->buf[sanitized->len-1] = '-';
+				else
+					return -1;
+			}
 			break;
 		case 4:
-			return -1;
+			/* forbidden char */
+			if (sanitized)
+				sanitized->buf[sanitized->len-1] = '-';
+			else
+				return -1;
+			break;
 		case 5:
-			if (!(*flags & REFNAME_REFSPEC_PATTERN))
-				return -1; /* refspec can't be a pattern */
+			if (!(*flags & REFNAME_REFSPEC_PATTERN)) {
+				/* refspec can't be a pattern */
+				if (sanitized)
+					sanitized->buf[sanitized->len-1] = '-';
+				else
+					return -1;
+			}
 
 			/*
 			 * Unset the pattern flag so that we only accept
@@ -108,26 +141,48 @@ static int check_refname_component(const
 out:
 	if (cp == refname)
 		return 0; /* Component has zero length. */
-	if (refname[0] == '.')
-		return -1; /* Component starts with '.'. */
+
+	if (refname[0] == '.') { /* Component starts with '.'. */
+		if (sanitized)
+			sanitized->buf[component_start] = '-';
+		else
+			return -1;
+	}
 	if (cp - refname >= LOCK_SUFFIX_LEN &&
-	    !memcmp(cp - LOCK_SUFFIX_LEN, LOCK_SUFFIX, LOCK_SUFFIX_LEN))
-		return -1; /* Refname ends with ".lock". */
+	    !memcmp(cp - LOCK_SUFFIX_LEN, LOCK_SUFFIX, LOCK_SUFFIX_LEN)) {
+		if (!sanitized)
+			return -1;
+		/* Refname ends with ".lock". */
+		while (strbuf_strip_suffix(sanitized, LOCK_SUFFIX)) {
+			/* try again in case we have .lock.lock */
+		}
+	}
 	return cp - refname;
 }
 
-int check_refname_format(const char *refname, int flags)
+static int check_or_sanitize_refname(const char *refname, int flags,
+				     struct strbuf *sanitized)
 {
 	int component_len, component_count = 0;
 
-	if (!strcmp(refname, "@"))
+	if (!strcmp(refname, "@")) {
 		/* Refname is a single character '@'. */
-		return -1;
+		if (sanitized)
+			strbuf_addch(sanitized, '-');
+		else
+			return -1;
+	}
 
 	while (1) {
+		if (sanitized && sanitized->len)
+			strbuf_complete(sanitized, '/');
+
 		/* We are at the start of a path component. */
-		component_len = check_refname_component(refname, &flags);
-		if (component_len <= 0)
+		component_len = check_refname_component(refname, &flags,
+							sanitized);
+		if (sanitized && component_len == 0)
+			; /* OK, omit empty component */
+		else if (component_len <= 0)
 			return -1;
 
 		component_count++;
@@ -137,13 +192,29 @@ int check_refname_format(const char *ref
 		refname += component_len + 1;
 	}
 
-	if (refname[component_len - 1] == '.')
-		return -1; /* Refname ends with '.'. */
+	if (refname[component_len - 1] == '.') {
+		/* Refname ends with '.'. */
+		if (sanitized)
+			; /* omit ending dot */
+		else
+			return -1;
+	}
 	if (!(flags & REFNAME_ALLOW_ONELEVEL) && component_count < 2)
 		return -1; /* Refname has only one component. */
 	return 0;
 }
 
+int check_refname_format(const char *refname, int flags)
+{
+	return check_or_sanitize_refname(refname, flags, NULL);
+}
+
+void sanitize_refname_component(const char *refname, struct strbuf *out)
+{
+	if (check_or_sanitize_refname(refname, REFNAME_ALLOW_ONELEVEL, out))
+		BUG("sanitizing refname '%s' check returned error", refname);
+}
+
 int refname_is_safe(const char *refname)
 {
 	const char *rest;
@@ -187,8 +258,8 @@ int ref_resolves_to_object(const char *r
 {
 	if (flags & REF_ISBROKEN)
 		return 0;
-	if (!has_sha1_file(oid->hash)) {
-		error("%s does not point to a valid object!", refname);
+	if (!has_object_file(oid)) {
+		error(_("%s does not point to a valid object!"), refname);
 		return 0;
 	}
 	return 1;
@@ -216,6 +287,7 @@ char *resolve_refdup(const char *refname
 /* The argument to filter_refs */
 struct ref_filter {
 	const char *pattern;
+	const char *prefix;
 	each_ref_fn *fn;
 	void *cb_data;
 };
@@ -239,9 +311,14 @@ int read_ref(const char *refname, struct
 	return read_ref_full(refname, RESOLVE_REF_READING, oid, NULL);
 }
 
+static int refs_ref_exists(struct ref_store *refs, const char *refname)
+{
+	return !!refs_resolve_ref_unsafe(refs, refname, RESOLVE_REF_READING, NULL, NULL);
+}
+
 int ref_exists(const char *refname)
 {
-	return !!resolve_ref_unsafe(refname, RESOLVE_REF_READING, NULL, NULL);
+	return refs_ref_exists(get_main_ref_store(the_repository), refname);
 }
 
 static int match_ref_pattern(const char *refname,
@@ -295,16 +372,18 @@ static int filter_refs(const char *refna
 
 	if (wildmatch(filter->pattern, refname, 0))
 		return 0;
+	if (filter->prefix)
+		skip_prefix(refname, filter->prefix, &refname);
 	return filter->fn(refname, oid, flags, filter->cb_data);
 }
 
 enum peel_status peel_object(const struct object_id *name, struct object_id *oid)
 {
-	struct object *o = lookup_unknown_object(name->hash);
+	struct object *o = lookup_unknown_object(name);
 
 	if (o->type == OBJ_NONE) {
 		int type = oid_object_info(the_repository, name, NULL);
-		if (type < 0 || !object_as_type(o, type, 0))
+		if (type < 0 || !object_as_type(the_repository, o, type, 0))
 			return PEEL_INVALID;
 	}
 
@@ -457,6 +536,7 @@ int for_each_glob_ref_in(each_ref_fn fn,
 	}
 
 	filter.pattern = real_pattern.buf;
+	filter.prefix = prefix;
 	filter.fn = fn;
 	filter.cb_data = cb_data;
 	ret = for_each_ref(filter_refs, &filter);
@@ -489,16 +569,24 @@ static const char *ref_rev_parse_rules[]
 	NULL
 };
 
+#define NUM_REV_PARSE_RULES (ARRAY_SIZE(ref_rev_parse_rules) - 1)
+
+/*
+ * Is it possible that the caller meant full_name with abbrev_name?
+ * If so return a non-zero value to signal "yes"; the magnitude of
+ * the returned value gives the precedence used for disambiguation.
+ *
+ * If abbrev_name cannot mean full_name, return 0.
+ */
 int refname_match(const char *abbrev_name, const char *full_name)
 {
 	const char **p;
 	const int abbrev_name_len = strlen(abbrev_name);
+	const int num_rules = NUM_REV_PARSE_RULES;
 
-	for (p = ref_rev_parse_rules; *p; p++) {
-		if (!strcmp(full_name, mkpath(*p, abbrev_name_len, abbrev_name))) {
-			return 1;
-		}
-	}
+	for (p = ref_rev_parse_rules; *p; p++)
+		if (!strcmp(full_name, mkpath(*p, abbrev_name_len, abbrev_name)))
+			return &ref_rev_parse_rules[num_rules] - p;
 
 	return 0;
 }
@@ -521,10 +609,11 @@ void expand_ref_prefix(struct argv_array
  * later free()ing) if the string passed in is a magic short-hand form
  * to name a branch.
  */
-static char *substitute_branch_name(const char **string, int *len)
+static char *substitute_branch_name(struct repository *r,
+				    const char **string, int *len)
 {
 	struct strbuf buf = STRBUF_INIT;
-	int ret = interpret_branch_name(*string, *len, &buf, 0);
+	int ret = repo_interpret_branch_name(r, *string, *len, &buf, 0);
 
 	if (ret == *len) {
 		size_t size;
@@ -536,15 +625,22 @@ static char *substitute_branch_name(cons
 	return NULL;
 }
 
-int dwim_ref(const char *str, int len, struct object_id *oid, char **ref)
+int repo_dwim_ref(struct repository *r, const char *str, int len,
+		  struct object_id *oid, char **ref)
 {
-	char *last_branch = substitute_branch_name(&str, &len);
-	int   refs_found  = expand_ref(str, len, oid, ref);
+	char *last_branch = substitute_branch_name(r, &str, &len);
+	int   refs_found  = expand_ref(r, str, len, oid, ref);
 	free(last_branch);
 	return refs_found;
 }
 
-int expand_ref(const char *str, int len, struct object_id *oid, char **ref)
+int dwim_ref(const char *str, int len, struct object_id *oid, char **ref)
+{
+	return repo_dwim_ref(the_repository, str, len, oid, ref);
+}
+
+int expand_ref(struct repository *repo, const char *str, int len,
+	       struct object_id *oid, char **ref)
 {
 	const char **p, *r;
 	int refs_found = 0;
@@ -559,26 +655,29 @@ int expand_ref(const char *str, int len,
 		this_result = refs_found ? &oid_from_ref : oid;
 		strbuf_reset(&fullref);
 		strbuf_addf(&fullref, *p, len, str);
-		r = resolve_ref_unsafe(fullref.buf, RESOLVE_REF_READING,
-				       this_result, &flag);
+		r = refs_resolve_ref_unsafe(get_main_ref_store(repo),
+					    fullref.buf, RESOLVE_REF_READING,
+					    this_result, &flag);
 		if (r) {
 			if (!refs_found++)
 				*ref = xstrdup(r);
 			if (!warn_ambiguous_refs)
 				break;
 		} else if ((flag & REF_ISSYMREF) && strcmp(fullref.buf, "HEAD")) {
-			warning("ignoring dangling symref %s.", fullref.buf);
+			warning(_("ignoring dangling symref %s"), fullref.buf);
 		} else if ((flag & REF_ISBROKEN) && strchr(fullref.buf, '/')) {
-			warning("ignoring broken ref %s.", fullref.buf);
+			warning(_("ignoring broken ref %s"), fullref.buf);
 		}
 	}
 	strbuf_release(&fullref);
 	return refs_found;
 }
 
-int dwim_log(const char *str, int len, struct object_id *oid, char **log)
+int repo_dwim_log(struct repository *r, const char *str, int len,
+		  struct object_id *oid, char **log)
 {
-	char *last_branch = substitute_branch_name(&str, &len);
+	struct ref_store *refs = get_main_ref_store(r);
+	char *last_branch = substitute_branch_name(r, &str, &len);
 	const char **p;
 	int logs_found = 0;
 	struct strbuf path = STRBUF_INIT;
@@ -590,13 +689,15 @@ int dwim_log(const char *str, int len, s
 
 		strbuf_reset(&path);
 		strbuf_addf(&path, *p, len, str);
-		ref = resolve_ref_unsafe(path.buf, RESOLVE_REF_READING,
-					 &hash, NULL);
+		ref = refs_resolve_ref_unsafe(refs, path.buf,
+					      RESOLVE_REF_READING,
+					      &hash, NULL);
 		if (!ref)
 			continue;
-		if (reflog_exists(path.buf))
+		if (refs_reflog_exists(refs, path.buf))
 			it = path.buf;
-		else if (strcmp(ref, path.buf) && reflog_exists(ref))
+		else if (strcmp(ref, path.buf) &&
+			 refs_reflog_exists(refs, ref))
 			it = ref;
 		else
 			continue;
@@ -612,9 +713,15 @@ int dwim_log(const char *str, int len, s
 	return logs_found;
 }
 
+int dwim_log(const char *str, int len, struct object_id *oid, char **log)
+{
+	return repo_dwim_log(the_repository, str, len, oid, log);
+}
+
 static int is_per_worktree_ref(const char *refname)
 {
 	return !strcmp(refname, "HEAD") ||
+		starts_with(refname, "refs/worktree/") ||
 		starts_with(refname, "refs/bisect/") ||
 		starts_with(refname, "refs/rewritten/");
 }
@@ -631,13 +738,34 @@ static int is_pseudoref_syntax(const cha
 	return 1;
 }
 
+static int is_main_pseudoref_syntax(const char *refname)
+{
+	return skip_prefix(refname, "main-worktree/", &refname) &&
+		*refname &&
+		is_pseudoref_syntax(refname);
+}
+
+static int is_other_pseudoref_syntax(const char *refname)
+{
+	if (!skip_prefix(refname, "worktrees/", &refname))
+		return 0;
+	refname = strchr(refname, '/');
+	if (!refname || !refname[1])
+		return 0;
+	return is_pseudoref_syntax(refname + 1);
+}
+
 enum ref_type ref_type(const char *refname)
 {
 	if (is_per_worktree_ref(refname))
 		return REF_TYPE_PER_WORKTREE;
 	if (is_pseudoref_syntax(refname))
 		return REF_TYPE_PSEUDOREF;
-       return REF_TYPE_NORMAL;
+	if (is_main_pseudoref_syntax(refname))
+		return REF_TYPE_MAIN_PSEUDOREF;
+	if (is_other_pseudoref_syntax(refname))
+		return REF_TYPE_OTHER_PSEUDOREF;
+	return REF_TYPE_NORMAL;
 }
 
 long get_files_ref_lock_timeout_ms(void)
@@ -673,7 +801,7 @@ static int write_pseudoref(const char *p
 	fd = hold_lock_file_for_update_timeout(&lock, filename, 0,
 					       get_files_ref_lock_timeout_ms());
 	if (fd < 0) {
-		strbuf_addf(err, "could not open '%s' for writing: %s",
+		strbuf_addf(err, _("could not open '%s' for writing: %s"),
 			    filename, strerror(errno));
 		goto done;
 	}
@@ -683,18 +811,18 @@ static int write_pseudoref(const char *p
 
 		if (read_ref(pseudoref, &actual_old_oid)) {
 			if (!is_null_oid(old_oid)) {
-				strbuf_addf(err, "could not read ref '%s'",
+				strbuf_addf(err, _("could not read ref '%s'"),
 					    pseudoref);
 				rollback_lock_file(&lock);
 				goto done;
 			}
 		} else if (is_null_oid(old_oid)) {
-			strbuf_addf(err, "ref '%s' already exists",
+			strbuf_addf(err, _("ref '%s' already exists"),
 				    pseudoref);
 			rollback_lock_file(&lock);
 			goto done;
-		} else if (oidcmp(&actual_old_oid, old_oid)) {
-			strbuf_addf(err, "unexpected object ID when writing '%s'",
+		} else if (!oideq(&actual_old_oid, old_oid)) {
+			strbuf_addf(err, _("unexpected object ID when writing '%s'"),
 				    pseudoref);
 			rollback_lock_file(&lock);
 			goto done;
@@ -702,7 +830,7 @@ static int write_pseudoref(const char *p
 	}
 
 	if (write_in_full(fd, buf.buf, buf.len) < 0) {
-		strbuf_addf(err, "could not write to '%s'", filename);
+		strbuf_addf(err, _("could not write to '%s'"), filename);
 		rollback_lock_file(&lock);
 		goto done;
 	}
@@ -734,9 +862,9 @@ static int delete_pseudoref(const char *
 			return -1;
 		}
 		if (read_ref(pseudoref, &actual_old_oid))
-			die("could not read ref '%s'", pseudoref);
-		if (oidcmp(&actual_old_oid, old_oid)) {
-			error("unexpected object ID when deleting '%s'",
+			die(_("could not read ref '%s'"), pseudoref);
+		if (!oideq(&actual_old_oid, old_oid)) {
+			error(_("unexpected object ID when deleting '%s'"),
 			      pseudoref);
 			rollback_lock_file(&lock);
 			return -1;
@@ -786,25 +914,21 @@ int delete_ref(const char *msg, const ch
 			       old_oid, flags);
 }
 
-int copy_reflog_msg(char *buf, const char *msg)
+void copy_reflog_msg(struct strbuf *sb, const char *msg)
 {
-	char *cp = buf;
 	char c;
 	int wasspace = 1;
 
-	*cp++ = '\t';
+	strbuf_addch(sb, '\t');
 	while ((c = *msg++)) {
 		if (wasspace && isspace(c))
 			continue;
 		wasspace = isspace(c);
 		if (wasspace)
 			c = ' ';
-		*cp++ = c;
+		strbuf_addch(sb, c);
 	}
-	while (buf < cp && isspace(cp[-1]))
-		cp--;
-	*cp++ = '\n';
-	return cp - buf;
+	strbuf_rtrim(sb);
 }
 
 int should_autocreate_reflog(const char *refname)
@@ -870,14 +994,14 @@ static int read_ref_at_ent(struct object
 		 */
 		if (!is_null_oid(&cb->ooid)) {
 			oidcpy(cb->oid, noid);
-			if (oidcmp(&cb->ooid, noid))
-				warning("Log for ref %s has gap after %s.",
+			if (!oideq(&cb->ooid, noid))
+				warning(_("log for ref %s has gap after %s"),
 					cb->refname, show_date(cb->date, cb->tz, DATE_MODE(RFC2822)));
 		}
 		else if (cb->date == cb->at_time)
 			oidcpy(cb->oid, noid);
-		else if (oidcmp(noid, cb->oid))
-			warning("Log for ref %s unexpectedly ended on %s.",
+		else if (!oideq(noid, cb->oid))
+			warning(_("log for ref %s unexpectedly ended on %s"),
 				cb->refname, show_date(cb->date, cb->tz,
 						       DATE_MODE(RFC2822)));
 		oidcpy(&cb->ooid, ooid);
@@ -913,7 +1037,8 @@ static int read_ref_at_ent_oldest(struct
 	return 1;
 }
 
-int read_ref_at(const char *refname, unsigned int flags, timestamp_t at_time, int cnt,
+int read_ref_at(struct ref_store *refs, const char *refname,
+		unsigned int flags, timestamp_t at_time, int cnt,
 		struct object_id *oid, char **msg,
 		timestamp_t *cutoff_time, int *cutoff_tz, int *cutoff_cnt)
 {
@@ -929,18 +1054,18 @@ int read_ref_at(const char *refname, uns
 	cb.cutoff_cnt = cutoff_cnt;
 	cb.oid = oid;
 
-	for_each_reflog_ent_reverse(refname, read_ref_at_ent, &cb);
+	refs_for_each_reflog_ent_reverse(refs, refname, read_ref_at_ent, &cb);
 
 	if (!cb.reccnt) {
 		if (flags & GET_OID_QUIETLY)
 			exit(128);
 		else
-			die("Log for %s is empty.", refname);
+			die(_("log for %s is empty"), refname);
 	}
 	if (cb.found_it)
 		return 0;
 
-	for_each_reflog_ent(refname, read_ref_at_ent_oldest, &cb);
+	refs_for_each_reflog_ent(refs, refname, read_ref_at_ent_oldest, &cb);
 
 	return 1;
 }
@@ -1027,7 +1152,7 @@ int ref_transaction_update(struct ref_tr
 	if ((new_oid && !is_null_oid(new_oid)) ?
 	    check_refname_format(refname, REFNAME_ALLOW_ONELEVEL) :
 	    !refname_is_safe(refname)) {
-		strbuf_addf(err, "refusing to update ref with bad name '%s'",
+		strbuf_addf(err, _("refusing to update ref with bad name '%s'"),
 			    refname);
 		return -1;
 	}
@@ -1103,7 +1228,7 @@ int refs_update_ref(struct ref_store *re
 		}
 	}
 	if (ret) {
-		const char *str = "update_ref failed for ref '%s': %s";
+		const char *str = _("update_ref failed for ref '%s': %s");
 
 		switch (onerr) {
 		case UPDATE_REFS_MSG_ON_ERR:
@@ -1133,7 +1258,8 @@ int update_ref(const char *msg, const ch
 			       old_oid, flags, onerr);
 }
 
-char *shorten_unambiguous_ref(const char *refname, int strict)
+char *refs_shorten_unambiguous_ref(struct ref_store *refs,
+				   const char *refname, int strict)
 {
 	int i;
 	static char **scanf_fmts;
@@ -1211,7 +1337,7 @@ char *shorten_unambiguous_ref(const char
 			strbuf_reset(&resolved_buf);
 			strbuf_addf(&resolved_buf, rule,
 				    short_name_len, short_name);
-			if (ref_exists(resolved_buf.buf))
+			if (refs_ref_exists(refs, resolved_buf.buf))
 				break;
 		}
 
@@ -1230,6 +1356,12 @@ char *shorten_unambiguous_ref(const char
 	return xstrdup(refname);
 }
 
+char *shorten_unambiguous_ref(const char *refname, int strict)
+{
+	return refs_shorten_unambiguous_ref(get_main_ref_store(the_repository),
+					    refname, strict);
+}
+
 static struct string_list *hide_refs;
 
 int parse_hide_refs_config(const char *var, const char *value, const char *section)
@@ -1389,17 +1521,50 @@ struct ref_iterator *refs_ref_iterator_b
  * non-zero value, stop the iteration and return that value;
  * otherwise, return 0.
  */
+static int do_for_each_repo_ref(struct repository *r, const char *prefix,
+				each_repo_ref_fn fn, int trim, int flags,
+				void *cb_data)
+{
+	struct ref_iterator *iter;
+	struct ref_store *refs = get_main_ref_store(r);
+
+	if (!refs)
+		return 0;
+
+	iter = refs_ref_iterator_begin(refs, prefix, trim, flags);
+
+	return do_for_each_repo_ref_iterator(r, iter, fn, cb_data);
+}
+
+struct do_for_each_ref_help {
+	each_ref_fn *fn;
+	void *cb_data;
+};
+
+static int do_for_each_ref_helper(struct repository *r,
+				  const char *refname,
+				  const struct object_id *oid,
+				  int flags,
+				  void *cb_data)
+{
+	struct do_for_each_ref_help *hp = cb_data;
+
+	return hp->fn(refname, oid, flags, hp->cb_data);
+}
+
 static int do_for_each_ref(struct ref_store *refs, const char *prefix,
 			   each_ref_fn fn, int trim, int flags, void *cb_data)
 {
 	struct ref_iterator *iter;
+	struct do_for_each_ref_help hp = { fn, cb_data };
 
 	if (!refs)
 		return 0;
 
 	iter = refs_ref_iterator_begin(refs, prefix, trim, flags);
 
-	return do_for_each_ref_iterator(iter, fn, cb_data);
+	return do_for_each_repo_ref_iterator(the_repository, iter,
+					do_for_each_ref_helper, &hp);
 }
 
 int refs_for_each_ref(struct ref_store *refs, each_ref_fn fn, void *cb_data)
@@ -1444,12 +1609,11 @@ int refs_for_each_fullref_in(struct ref_
 	return do_for_each_ref(refs, prefix, fn, 0, flag, cb_data);
 }
 
-int for_each_replace_ref(struct repository *r, each_ref_fn fn, void *cb_data)
+int for_each_replace_ref(struct repository *r, each_repo_ref_fn fn, void *cb_data)
 {
-	return do_for_each_ref(get_main_ref_store(r),
-			       git_replace_ref_base, fn,
-			       strlen(git_replace_ref_base),
-			       DO_FOR_EACH_INCLUDE_BROKEN, cb_data);
+	return do_for_each_repo_ref(r, git_replace_ref_base, fn,
+				    strlen(git_replace_ref_base),
+				    DO_FOR_EACH_INCLUDE_BROKEN, cb_data);
 }
 
 int for_each_namespaced_ref(each_ref_fn fn, void *cb_data)
@@ -1608,7 +1772,7 @@ int resolve_gitlink_ref(const char *subm
 
 struct ref_store_hash_entry
 {
-	struct hashmap_entry ent; /* must be the first member! */
+	struct hashmap_entry ent;
 
 	struct ref_store *refs;
 
@@ -1617,11 +1781,16 @@ struct ref_store_hash_entry
 };
 
 static int ref_store_hash_cmp(const void *unused_cmp_data,
-			      const void *entry, const void *entry_or_key,
+			      const struct hashmap_entry *eptr,
+			      const struct hashmap_entry *entry_or_key,
 			      const void *keydata)
 {
-	const struct ref_store_hash_entry *e1 = entry, *e2 = entry_or_key;
-	const char *name = keydata ? keydata : e2->name;
+	const struct ref_store_hash_entry *e1, *e2;
+	const char *name;
+
+	e1 = container_of(eptr, const struct ref_store_hash_entry, ent);
+	e2 = container_of(entry_or_key, const struct ref_store_hash_entry, ent);
+	name = keydata ? keydata : e2->name;
 
 	return strcmp(e1->name, name);
 }
@@ -1632,7 +1801,7 @@ static struct ref_store_hash_entry *allo
 	struct ref_store_hash_entry *entry;
 
 	FLEX_ALLOC_STR(entry, name, name);
-	hashmap_entry_init(entry, strhash(name));
+	hashmap_entry_init(&entry->ent, strhash(name));
 	entry->refs = refs;
 	return entry;
 }
@@ -1651,12 +1820,15 @@ static struct ref_store *lookup_ref_stor
 					      const char *name)
 {
 	struct ref_store_hash_entry *entry;
+	unsigned int hash;
 
 	if (!map->tablesize)
 		/* It's initialized on demand in register_ref_store(). */
 		return NULL;
 
-	entry = hashmap_get_from_hash(map, strhash(name), name);
+	hash = strhash(name);
+	entry = hashmap_get_entry_from_hash(map, hash, name,
+					struct ref_store_hash_entry, ent);
 	return entry ? entry->refs : NULL;
 }
 
@@ -1699,10 +1871,13 @@ static void register_ref_store_map(struc
 				   struct ref_store *refs,
 				   const char *name)
 {
+	struct ref_store_hash_entry *entry;
+
 	if (!map->tablesize)
 		hashmap_init(map, ref_store_hash_cmp, NULL, 0);
 
-	if (hashmap_put(map, alloc_ref_store_hash_entry(name, refs)))
+	entry = alloc_ref_store_hash_entry(name, refs);
+	if (hashmap_put(map, &entry->ent))
 		BUG("%s ref_store '%s' initialized twice", type, name);
 }
 
@@ -1845,7 +2020,7 @@ int ref_update_reject_duplicates(struct
 
 		if (!cmp) {
 			strbuf_addf(err,
-				    "multiple updates for ref '%s' not allowed.",
+				    _("multiple updates for ref '%s' not allowed"),
 				    refnames->items[i].string);
 			return 1;
 		} else if (cmp > 0) {
@@ -1973,13 +2148,13 @@ int refs_verify_refname_available(struct
 			continue;
 
 		if (!refs_read_raw_ref(refs, dirname.buf, &oid, &referent, &type)) {
-			strbuf_addf(err, "'%s' exists; cannot create '%s'",
+			strbuf_addf(err, _("'%s' exists; cannot create '%s'"),
 				    dirname.buf, refname);
 			goto cleanup;
 		}
 
 		if (extras && string_list_has_string(extras, dirname.buf)) {
-			strbuf_addf(err, "cannot process '%s' and '%s' at the same time",
+			strbuf_addf(err, _("cannot process '%s' and '%s' at the same time"),
 				    refname, dirname.buf);
 			goto cleanup;
 		}
@@ -2003,7 +2178,7 @@ int refs_verify_refname_available(struct
 		    string_list_has_string(skip, iter->refname))
 			continue;
 
-		strbuf_addf(err, "'%s' exists; cannot create '%s'",
+		strbuf_addf(err, _("'%s' exists; cannot create '%s'"),
 			    iter->refname, refname);
 		ref_iterator_abort(iter);
 		goto cleanup;
@@ -2014,7 +2189,7 @@ int refs_verify_refname_available(struct
 
 	extra_refname = find_descendant_ref(dirname.buf, extras, skip);
 	if (extra_refname)
-		strbuf_addf(err, "cannot process '%s' and '%s' at the same time",
+		strbuf_addf(err, _("cannot process '%s' and '%s' at the same time"),
 			    refname, extra_refname);
 	else
 		ret = 0;
@@ -2028,10 +2203,12 @@ cleanup:
 int refs_for_each_reflog(struct ref_store *refs, each_ref_fn fn, void *cb_data)
 {
 	struct ref_iterator *iter;
+	struct do_for_each_ref_help hp = { fn, cb_data };
 
 	iter = refs->be->reflog_iterator_begin(refs);
 
-	return do_for_each_ref_iterator(iter, fn, cb_data);
+	return do_for_each_repo_ref_iterator(the_repository, iter,
+					     do_for_each_ref_helper, &hp);
 }
 
 int for_each_reflog(each_ref_fn fn, void *cb_data)
diff -pruN 1.2.1+git2.18.0-1/git/refs.h 1.2.3+git2.25.1-1/git/refs.h
--- 1.2.1+git2.18.0-1/git/refs.h	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/refs.h	2020-02-17 04:47:35.000000000 +0000
@@ -3,8 +3,10 @@
 
 struct object_id;
 struct ref_store;
+struct repository;
 struct strbuf;
 struct string_list;
+struct string_list_item;
 struct worktree;
 
 /*
@@ -109,7 +111,7 @@ int should_autocreate_reflog(const char
 
 int is_branch(const char *refname);
 
-extern int refs_init_db(struct strbuf *err);
+int refs_init_db(struct strbuf *err);
 
 /*
  * If refname is a non-symbolic reference that refers to a tag object,
@@ -146,7 +148,9 @@ int refname_match(const char *abbrev_nam
 struct argv_array;
 void expand_ref_prefix(struct argv_array *prefixes, const char *prefix);
 
-int expand_ref(const char *str, int len, struct object_id *oid, char **ref);
+int expand_ref(struct repository *r, const char *str, int len, struct object_id *oid, char **ref);
+int repo_dwim_ref(struct repository *r, const char *str, int len, struct object_id *oid, char **ref);
+int repo_dwim_log(struct repository *r, const char *str, int len, struct object_id *oid, char **ref);
 int dwim_ref(const char *str, int len, struct object_id *oid, char **ref);
 int dwim_log(const char *str, int len, struct object_id *oid, char **ref);
 
@@ -275,6 +279,16 @@ typedef int each_ref_fn(const char *refn
 			const struct object_id *oid, int flags, void *cb_data);
 
 /*
+ * The same as each_ref_fn, but also with a repository argument that
+ * contains the repository associated with the callback.
+ */
+typedef int each_repo_ref_fn(struct repository *r,
+			     const char *refname,
+			     const struct object_id *oid,
+			     int flags,
+			     void *cb_data);
+
+/*
  * The following functions invoke the specified callback function for
  * each reference indicated.  If the function ever returns a nonzero
  * value, stop the iteration and return that value.  Please note that
@@ -296,19 +310,35 @@ int refs_for_each_branch_ref(struct ref_
 int refs_for_each_remote_ref(struct ref_store *refs,
 			     each_ref_fn fn, void *cb_data);
 
+/* just iterates the head ref. */
 int head_ref(each_ref_fn fn, void *cb_data);
+
+/* iterates all refs. */
 int for_each_ref(each_ref_fn fn, void *cb_data);
+
+/**
+ * iterates all refs which have a defined prefix and strips that prefix from
+ * the passed variable refname.
+ */
 int for_each_ref_in(const char *prefix, each_ref_fn fn, void *cb_data);
+
 int refs_for_each_fullref_in(struct ref_store *refs, const char *prefix,
 			     each_ref_fn fn, void *cb_data,
 			     unsigned int broken);
 int for_each_fullref_in(const char *prefix, each_ref_fn fn, void *cb_data,
 			unsigned int broken);
+
+/**
+ * iterate refs from the respective area.
+ */
 int for_each_tag_ref(each_ref_fn fn, void *cb_data);
 int for_each_branch_ref(each_ref_fn fn, void *cb_data);
 int for_each_remote_ref(each_ref_fn fn, void *cb_data);
-int for_each_replace_ref(struct repository *r, each_ref_fn fn, void *cb_data);
+int for_each_replace_ref(struct repository *r, each_repo_ref_fn fn, void *cb_data);
+
+/* iterates all refs that match the specified glob pattern. */
 int for_each_glob_ref(each_ref_fn fn, const char *pattern, void *cb_data);
+
 int for_each_glob_ref_in(each_ref_fn fn, const char *pattern,
 			 const char *prefix, void *cb_data);
 
@@ -374,7 +404,8 @@ int refs_create_reflog(struct ref_store
 int safe_create_reflog(const char *refname, int force_create, struct strbuf *err);
 
 /** Reads log for the value of ref during at_time. **/
-int read_ref_at(const char *refname, unsigned int flags,
+int read_ref_at(struct ref_store *refs,
+		const char *refname, unsigned int flags,
 		timestamp_t at_time, int cnt,
 		struct object_id *oid, char **msg,
 		timestamp_t *cutoff_time, int *cutoff_tz, int *cutoff_cnt);
@@ -448,8 +479,16 @@ int for_each_reflog(each_ref_fn fn, void
  */
 int check_refname_format(const char *refname, int flags);
 
+/*
+ * Apply the rules from check_refname_format, but mutate the result until it
+ * is acceptable, and place the result in "out".
+ */
+void sanitize_refname_component(const char *refname, struct strbuf *out);
+
 const char *prettify_refname(const char *refname);
 
+char *refs_shorten_unambiguous_ref(struct ref_store *refs,
+				   const char *refname, int strict);
 char *shorten_unambiguous_ref(const char *refname, int strict);
 
 /** rename ref, return 0 on success **/
@@ -702,9 +741,11 @@ int parse_hide_refs_config(const char *v
 int ref_is_hidden(const char *, const char *);
 
 enum ref_type {
-	REF_TYPE_PER_WORKTREE,
-	REF_TYPE_PSEUDOREF,
-	REF_TYPE_NORMAL,
+	REF_TYPE_PER_WORKTREE,	  /* refs inside refs/ but not shared       */
+	REF_TYPE_PSEUDOREF,	  /* refs outside refs/ in current worktree */
+	REF_TYPE_MAIN_PSEUDOREF,  /* pseudo refs from the main worktree     */
+	REF_TYPE_OTHER_PSEUDOREF, /* pseudo refs from other worktrees       */
+	REF_TYPE_NORMAL,	  /* normal/shared refs inside refs/        */
 };
 
 enum ref_type ref_type(const char *refname);
@@ -766,6 +807,41 @@ int reflog_expire(const char *refname, c
 int ref_storage_backend_exists(const char *name);
 
 struct ref_store *get_main_ref_store(struct repository *r);
+
+/**
+ * Submodules
+ * ----------
+ *
+ * If you want to iterate the refs of a submodule you first need to add the
+ * submodules object database. You can do this by a code-snippet like
+ * this:
+ *
+ * 	const char *path = "path/to/submodule"
+ * 	if (add_submodule_odb(path))
+ * 		die("Error submodule '%s' not populated.", path);
+ *
+ * `add_submodule_odb()` will return zero on success. If you
+ * do not do this you will get an error for each ref that it does not point
+ * to a valid object.
+ *
+ * Note: As a side-effect of this you cannot safely assume that all
+ * objects you lookup are available in superproject. All submodule objects
+ * will be available the same way as the superprojects objects.
+ *
+ * Example:
+ * --------
+ *
+ * ----
+ * static int handle_remote_ref(const char *refname,
+ * 		const unsigned char *sha1, int flags, void *cb_data)
+ * {
+ * 	struct strbuf *output = cb_data;
+ * 	strbuf_addf(output, "%s\n", refname);
+ * 	return 0;
+ * }
+ *
+ */
+
 /*
  * Return the ref_store instance for the specified submodule. For the
  * main repository, use submodule==NULL; such a call cannot fail. For
diff -pruN 1.2.1+git2.18.0-1/git/refspec.c 1.2.3+git2.25.1-1/git/refspec.c
--- 1.2.1+git2.18.0-1/git/refspec.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/refspec.c	2020-02-17 04:47:35.000000000 +0000
@@ -72,7 +72,7 @@ static int parse_refspec(struct refspec_
 		/* LHS */
 		if (!*item->src)
 			; /* empty is ok; it means "HEAD" */
-		else if (llen == GIT_SHA1_HEXSZ && !get_oid_hex(item->src, &unused))
+		else if (llen == the_hash_algo->hexsz && !get_oid_hex(item->src, &unused))
 			item->exact_sha1 = 1; /* ok */
 		else if (!check_refname_format(item->src, flags))
 			; /* valid looking ref is ok */
@@ -124,12 +124,17 @@ static int parse_refspec(struct refspec_
 	return 1;
 }
 
-void refspec_item_init(struct refspec_item *item, const char *refspec, int fetch)
+int refspec_item_init(struct refspec_item *item, const char *refspec, int fetch)
 {
 	memset(item, 0, sizeof(*item));
+	return parse_refspec(item, refspec, fetch);
+}
 
-	if (!parse_refspec(item, refspec, fetch))
-		die("Invalid refspec '%s'", refspec);
+void refspec_item_init_or_die(struct refspec_item *item, const char *refspec,
+			      int fetch)
+{
+	if (!refspec_item_init(item, refspec, fetch))
+		die(_("invalid refspec '%s'"), refspec);
 }
 
 void refspec_item_clear(struct refspec_item *item)
@@ -152,7 +157,7 @@ void refspec_append(struct refspec *rs,
 {
 	struct refspec_item item;
 
-	refspec_item_init(&item, refspec, rs->fetch);
+	refspec_item_init_or_die(&item, refspec, rs->fetch);
 
 	ALLOC_GROW(rs->items, rs->nr + 1, rs->alloc);
 	rs->items[rs->nr++] = item;
@@ -191,7 +196,7 @@ void refspec_clear(struct refspec *rs)
 int valid_fetch_refspec(const char *fetch_refspec_str)
 {
 	struct refspec_item refspec;
-	int ret = parse_refspec(&refspec, fetch_refspec_str, REFSPEC_FETCH);
+	int ret = refspec_item_init(&refspec, fetch_refspec_str, REFSPEC_FETCH);
 	refspec_item_clear(&refspec);
 	return ret;
 }
diff -pruN 1.2.1+git2.18.0-1/git/refspec.h 1.2.3+git2.25.1-1/git/refspec.h
--- 1.2.1+git2.18.0-1/git/refspec.h	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/refspec.h	2020-02-17 04:47:35.000000000 +0000
@@ -20,6 +20,22 @@ struct refspec_item {
 #define REFSPEC_INIT_FETCH { .fetch = REFSPEC_FETCH }
 #define REFSPEC_INIT_PUSH { .fetch = REFSPEC_PUSH }
 
+/**
+ * A struct refspec holds the parsed interpretation of a refspec.  If it will
+ * force updates (starts with a '+'), force is true.  If it is a pattern
+ * (sides end with '*') pattern is true.  src and dest are the two sides
+ * (including '*' characters if present); if there is only one side, it is src,
+ * and dst is NULL; if sides exist but are empty (i.e., the refspec either
+ * starts or ends with ':'), the corresponding side is "".
+ *
+ * An array of strings can be parsed into an array of struct refspecs using
+ * parse_fetch_refspec() or parse_push_refspec().
+ *
+ * remote_find_tracking(), given a remote and a struct refspec with either src
+ * or dst filled out, will fill out the other such that the result is in the
+ * "fetch" specification for the remote (note that this evaluates patterns and
+ * returns a single result).
+ */
 struct refspec {
 	struct refspec_item *items;
 	int alloc;
@@ -32,7 +48,10 @@ struct refspec {
 	int fetch;
 };
 
-void refspec_item_init(struct refspec_item *item, const char *refspec, int fetch);
+int refspec_item_init(struct refspec_item *item, const char *refspec,
+		      int fetch);
+void refspec_item_init_or_die(struct refspec_item *item, const char *refspec,
+			      int fetch);
 void refspec_item_clear(struct refspec_item *item);
 void refspec_init(struct refspec *rs, int fetch);
 void refspec_append(struct refspec *rs, const char *refspec);
diff -pruN 1.2.1+git2.18.0-1/git/RelNotes 1.2.3+git2.25.1-1/git/RelNotes
--- 1.2.1+git2.18.0-1/git/RelNotes	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/RelNotes	2020-02-17 04:47:35.000000000 +0000
@@ -1,583 +1,55 @@
-Git 2.18 Release Notes
-======================
+Git 2.25.1 Release Notes
+========================
 
-Updates since v2.17
--------------------
-
-UI, Workflows & Features
-
- * Rename detection logic that is used in "merge" and "cherry-pick" has
-   learned to guess when all of x/a, x/b and x/c have moved to z/a,
-   z/b and z/c, it is likely that x/d added in the meantime would also
-   want to move to z/d by taking the hint that the entire directory
-   'x' moved to 'z'.  A bug causing dirty files involved in a rename
-   to be overwritten during merge has also been fixed as part of this
-   work.  Incidentally, this also avoids updating a file in the
-   working tree after a (non-trivial) merge whose result matches what
-   our side originally had.
-
- * "git filter-branch" learned to use a different exit code to allow
-   the callers to tell the case where there was no new commits to
-   rewrite from other error cases.
-
- * When built with more recent cURL, GIT_SSL_VERSION can now specify
-   "tlsv1.3" as its value.
-
- * "git gui" learned that "~/.ssh/id_ecdsa.pub" and
-   "~/.ssh/id_ed25519.pub" are also possible SSH key files.
-   (merge 2e2f0288ef bb/git-gui-ssh-key-files later to maint).
-
- * "git gui" performs commit upon CTRL/CMD+ENTER but the
-   CTRL/CMD+KP_ENTER (i.e. enter key on the numpad) did not have the
-   same key binding.  It now does.
-   (merge 28a1d94a06 bp/git-gui-bind-kp-enter later to maint).
-
- * "git gui" has been taught to work with old versions of tk (like
-   8.5.7) that do not support "ttk::style theme use" as a way to query
-   the current theme.
-   (merge 4891961105 cb/git-gui-ttk-style later to maint).
-
- * "git rebase" has learned to honor "--signoff" option when using
-   backends other than "am" (but not "--preserve-merges").
-
- * "git branch --list" during an interrupted "rebase -i" now lets
-   users distinguish the case where a detached HEAD is being rebased
-   and a normal branch is being rebased.
-
- * "git mergetools" learned talking to guiffy.
-
- * The scripts in contrib/emacs/ have outlived their usefulness and
-   have been replaced with a stub that errors out and tells the user
-   there are replacements.
-
- * The new "working-tree-encoding" attribute can ask Git to convert the
-   contents to the specified encoding when checking out to the working
-   tree (and the other way around when checking in).
-
- * The "git config" command uses separate options e.g. "--int",
-   "--bool", etc. to specify what type the caller wants the value to
-   be interpreted as.  A new "--type=<typename>" option has been
-   introduced, which would make it cleaner to define new types.
-
- * "git config --get" learned the "--default" option, to help the
-   calling script.  Building on top of the above changes, the
-   "git config" learns "--type=color" type.  Taken together, you can
-   do things like "git config --get foo.color --default blue" and get
-   the ANSI color sequence for the color given to foo.color variable,
-   or "blue" if the variable does not exist.
-
- * "git ls-remote" learned an option to allow sorting its output based
-   on the refnames being shown.
-
- * The command line completion (in contrib/) has been taught that "git
-   stash save" has been deprecated ("git stash push" is the preferred
-   spelling in the new world) and does not offer it as a possible
-   completion candidate when "git stash push" can be.
-
- * "git gc --prune=nonsense" spent long time repacking and then
-   silently failed when underlying "git prune --expire=nonsense"
-   failed to parse its command line.  This has been corrected.
-
- * Error messages from "git push" can be painted for more visibility.
-
- * "git http-fetch" (deprecated) had an optional and experimental
-   "feature" to fetch only commits and/or trees, which nobody used.
-   This has been removed.
-
- * The functionality of "$GIT_DIR/info/grafts" has been superseded by
-   the "refs/replace/" mechanism for some time now, but the internal
-   code had support for it in many places, which has been cleaned up
-   in order to drop support of the "grafts" mechanism.
-
- * "git worktree add" learned to check out an existing branch.
-
- * "git --no-pager cmd" did not have short-and-sweet single letter
-   option. Now it does as "-P".
-   (merge 7213c28818 js/no-pager-shorthand later to maint).
-
- * "git rebase" learned "--rebase-merges" to transplant the whole
-   topology of commit graph elsewhere.
-
- * "git status" learned to pay attention to UI related diff
-   configuration variables such as diff.renames.
-
- * The command line completion mechanism (in contrib/) learned to load
-   custom completion file for "git $command" where $command is a
-   custom "git-$command" that the end user has on the $PATH when using
-   newer version of bash-completion.
-
- * "git send-email" can sometimes offer confirmation dialog "Send this
-   email?" with choices 'Yes', 'No', 'Quit', and 'All'.  A new action
-   'Edit' has been added to this dialog's choice.
-
- * With merge.renames configuration set to false, the recursive merge
-   strategy can be told not to spend cycles trying to find renamed
-   paths and merge them accordingly.
-
- * "git status" learned to honor a new status.renames configuration to
-   skip rename detection, which could be useful for those who want to
-   do so without disabling the default rename detection done by the
-   "git diff" command.
-
- * Command line completion (in contrib/) learned to complete pathnames
-   for various commands better.
-
- * "git blame" learns to unhighlight uninteresting metadata from the
-   originating commit on lines that are the same as the previous one,
-   and also paint lines in different colors depending on the age of
-   the commit.
-
- * Transfer protocol v2 learned to support the partial clone.
-
- * When a short hexadecimal string is used to name an object but there
-   are multiple objects that share the string as the prefix of their
-   names, the code lists these ambiguous candidates in a help message.
-   These object names are now sorted according to their types for
-   easier eyeballing.
-
- * "git fetch $there $refspec" that talks over protocol v2 can take
-   advantage of server-side ref filtering; the code has been extended
-   so that this mechanism triggers also when fetching with configured
-   refspec.
-
- * Our HTTP client code used to advertise that we accept gzip encoding
-   from the other side; instead, just let cURL library to advertise
-   and negotiate the best one.
-
- * "git p4" learned to "unshelve" shelved commit from P4.
-   (merge 123f631761 ld/p4-unshelve later to maint).
-
-
-Performance, Internal Implementation, Development Support etc.
-
- * A "git fetch" from a repository with insane number of refs into a
-   repository that is already up-to-date still wasted too many cycles
-   making many lstat(2) calls to see if these objects at the tips
-   exist as loose objects locally.  These lstat(2) calls are optimized
-   away by enumerating all loose objects beforehand.
-   It is unknown if the new strategy negatively affects existing use
-   cases, fetching into a repository with many loose objects from a
-   repository with small number of refs.
-
- * Git can be built to use either v1 or v2 of the PCRE library, and so
-   far, the build-time configuration USE_LIBPCRE=YesPlease instructed
-   the build procedure to use v1, but now it means v2.  USE_LIBPCRE1
-   and USE_LIBPCRE2 can be used to explicitly choose which version to
-   use, as before.
-
- * The build procedure learned to optionally use symbolic links
-   (instead of hardlinks and copies) to install "git-foo" for built-in
-   commands, whose binaries are all identical.
-
- * Conversion from uchar[20] to struct object_id continues.
-
- * The way "git worktree prune" worked internally has been simplified,
-   by assuming how "git worktree move" moves an existing worktree to a
-   different place.
-
- * Code clean-up for the "repository" abstraction.
-   (merge 00a3da2a13 nd/remove-ignore-env-field later to maint).
-
- * Code to find the length to uniquely abbreviate object names based
-   on packfile content, which is a relatively recent addtion, has been
-   optimized to use the same fan-out table.
-
- * The mechanism to use parse-options API to automate the command line
-   completion continues to get extended and polished.
-
- * Copies of old scripted Porcelain commands in contrib/examples/ have
-   been removed.
-
- * Some tests that rely on the exact hardcoded values of object names
-   have been updated in preparation for hash function migration.
-
- * Perf-test update.
-
- * Test helper update.
-
- * The effort continues to refactor the internal global data structure
-   to make it possible to open multiple repositories, work with and
-   then close them,
-
- * Small test-helper programs have been consolidated into a single
-   binary.
-
- * API clean-up around ref-filter code.
-
- * Shell completion (in contrib) that gives list of paths have been
-   optimized somewhat.
-
- * The index file is updated to record the fsmonitor section after a
-   full scan was made, to avoid wasting the effort that has already
-   spent.
-
- * Performance measuring framework in t/perf learned to help bisecting
-   performance regressions.
-
- * Some multi-word source filenames are being renamed to separate
-   words with dashes instead of underscores.
-
- * An reusable "memory pool" implementation has been extracted from
-   fast-import.c, which in turn has become the first user of the
-   mem-pool API.
-
- * A build-time option has been added to allow Git to be told to refer
-   to its associated files relative to the main binary, in the same
-   way that has been possible on Windows for quite some time, for
-   Linux, BSDs and Darwin.
-
- * Precompute and store information necessary for ancestry traversal
-   in a separate file to optimize graph walking.
-
- * The effort to pass the repository in-core structure throughout the
-   API continues.  This round deals with the code that implements the
-   refs/replace/ mechanism.
-
- * The build procedure "make DEVELOPER=YesPlease" learned to enable a
-   bit more warning options depending on the compiler used to help
-   developers more.  There also is "make DEVOPTS=tokens" knob
-   available now, for those who want to help fixing warnings we
-   usually ignore, for example.
-
- * A new version of the transport protocol is being worked on.
-
- * The code to interface to GPG has been restructured somewhat to make
-   it cleaner to integrate with other types of signature systems later.
-
- * The code has been taught to use the duplicated information stored
-   in the commit-graph file to learn the tree object name for a commit
-   to avoid opening and parsing the commit object when it makes sense
-   to do so.
-
- * "git gc" in a large repository takes a lot of time as it considers
-   to repack all objects into one pack by default.  The command has
-   been taught to pretend as if the largest existing packfile is
-   marked with ".keep" so that it is left untouched while objects in
-   other packs and loose ones are repacked.
-
- * The transport protocol v2 is getting updated further.
-
- * The codepath around object-info API has been taught to take the
-   repository object (which in turn tells the API which object store
-   the objects are to be located).
-
- * "git pack-objects" needs to allocate tons of "struct object_entry"
-   while doing its work, and shrinking its size helps the performance
-   quite a bit.
-
- * The implementation of "git rebase -i --root" has been updated to use
-   the sequencer machinery more.
-
- * Developer support update, by using BUG() macro instead of die() to
-   mark codepaths that should not happen more clearly.
-
- * Developer support.  Use newer GCC on one of the builds done at
-   TravisCI.org to get more warnings and errors diagnosed.
-
- * Conversion from uchar[20] to struct object_id continues.
-
- * By code restructuring of submodule merge in merge-recursive,
-   informational messages from the codepath are now given using the
-   same mechanism as other output, and honor the merge.verbosity
-   configuration.  The code also learned to give a few new messages
-   when a submodule three-way merge resolves cleanly when one side
-   records a descendant of the commit chosen by the other side.
-
- * Avoid unchecked snprintf() to make future code auditing easier.
-   (merge ac4896f007 jk/snprintf-truncation later to maint).
-
- * Many tests hardcode the raw object names, which would change once
-   we migrate away from SHA-1.  While some of them must test against
-   exact object names, most of them do not have to use hardcoded
-   constants in the test.  The latter kind of tests have been updated
-   to test the moral equivalent of the original without hardcoding the
-   actual object names.
+Fixes since v2.25
+-----------------
 
- * The list of commands with their various attributes were spread
-   across a few places in the build procedure, but it now is getting a
-   bit more consolidated to allow more automation.
+ * "git commit" gives output similar to "git status" when there is
+   nothing to commit, but without honoring the advise.statusHints
+   configuration variable, which has been corrected.
+
+ * has_object_file() said "no" given an object registered to the
+   system via pretend_object_file(), making it inconsistent with
+   read_object_file(), causing lazy fetch to attempt fetching an
+   empty tree from promisor remotes.
+
+ * The code that tries to skip over the entries for the paths in a
+   single directory using the cache-tree was not careful enough
+   against corrupt index file.
 
- * Quite a many tests assumed that newly created refs are made as
-   loose refs using the files backend, which have been updated to use
-   proper plumbing like rev-parse and update-ref, to avoid breakage
-   once we start using different ref backends.
+ * Complete an update to tutorial that encourages "git switch" over
+   "git checkout" that was done only half-way.
 
+ * Reduce unnecessary round-trip when running "ls-remote" over the
+   stateless RPC mechanism.
 
-Also contains various documentation updates and code clean-ups.
+ * "git restore --staged" did not correctly update the cache-tree
+   structure, resulting in bogus trees to be written afterwards, which
+   has been corrected.
 
+ * The code recently added to move to the entry beyond the ones in the
+   same directory in the index in the sparse-cone mode did not count
+   the number of entries to skip over incorrectly, which has been
+   corrected.
 
-Fixes since v2.17
------------------
+ * Work around test breakages caused by custom regex engine used in
+   libasan, when address sanitizer is used with more recent versions
+   of gcc and clang.
 
- * "git shortlog cruft" aborted with a BUG message when run outside a
-   Git repository.  The command has been taught to complain about
-   extra and unwanted arguments on its command line instead in such a
-   case.
-   (merge 4aa0161e83 ma/shortlog-revparse later to maint).
-
- * "git stash push -u -- <pathspec>" gave an unnecessary and confusing
-   error message when there was no tracked files that match the
-   <pathspec>, which has been fixed.
-   (merge 353278687e tg/stash-untracked-with-pathspec-fix later to maint).
-
- * "git tag --contains no-such-commit" gave a full list of options
-   after giving an error message.
-   (merge 3bb0923f06 ps/contains-id-error-message later to maint).
-
- * "diff-highlight" filter (in contrib/) learned to understand "git log
-   --graph" output better.
-   (merge 4551fbba14 jk/diff-highlight-graph-fix later to maint).
+ * "git fetch --refmap=" option has got a better documentation.
 
- * when refs that do not point at committish are given, "git
-   filter-branch" gave a misleading error messages.  This has been
-   corrected.
-   (merge f78ab355e7 yk/filter-branch-non-committish-refs later to maint).
+ * Corner case bugs in "git clean" that stems from a (necessarily for
+   performance reasons) awkward calling convention in the directory
+   enumeration API has been corrected.
 
- * "git submodule status" misbehaved on a submodule that has been
-   removed from the working tree.
-   (merge 74b6bda32f rs/status-with-removed-submodule later to maint).
-
- * When credential helper exits very quickly without reading its
-   input, it used to cause Git to die with SIGPIPE, which has been
-   fixed.
-   (merge a0d51e8d0e eb/cred-helper-ignore-sigpipe later to maint).
-
- * "git rebase --keep-empty" still removed an empty commit if the
-   other side contained an empty commit (due to the "does an
-   equivalent patch exist already?" check), which has been corrected.
-   (merge 3d946165e1 pw/rebase-keep-empty-fixes later to maint).
-
- * Some codepaths, including the refs API, get and keep relative
-   paths, that go out of sync when the process does chdir(2).  The
-   chdir-notify API is introduced to let these codepaths adjust these
-   cached paths to the new current directory.
-   (merge fb9c2d2703 jk/relative-directory-fix later to maint).
-
- * "cd sub/dir && git commit ../path" ought to record the changes to
-   the file "sub/path", but this regressed long time ago.
-   (merge 86238e07ef bw/commit-partial-from-subdirectory-fix later to maint).
-
- * Recent introduction of "--log-destination" option to "git daemon"
-   did not work well when the daemon was run under "--inetd" mode.
-   (merge e67d906d73 lw/daemon-log-destination later to maint).
-
- * Small fix to the autoconf build procedure.
-   (merge 249482daf0 es/fread-reads-dir-autoconf-fix later to maint).
-
- * Fix an unexploitable (because the oversized contents are not under
-   attacker's control) buffer overflow.
-   (merge d8579accfa bp/fsmonitor-bufsize-fix later to maint).
-
- * Recent simplification of build procedure forgot a bit of tweak to
-   the build procedure of contrib/mw-to-git/
-   (merge d8698987f3 ab/simplify-perl-makefile later to maint).
-
- * Moving a submodule that itself has submodule in it with "git mv"
-   forgot to make necessary adjustment to the nested sub-submodules;
-   now the codepath learned to recurse into the submodules.
-
- * "git config --unset a.b", when "a.b" is the last variable in an
-   otherwise empty section "a", left an empty section "a" behind, and
-   worse yet, a subsequent "git config a.c value" did not reuse that
-   empty shell and instead created a new one.  These have been
-   (partially) corrected.
-   (merge c71d8bb38a js/empty-config-section-fix later to maint).
-
- * "git worktree remove" learned that "-f" is a shorthand for
-   "--force" option, just like for "git worktree add".
-   (merge d228eea514 sb/worktree-remove-opt-force later to maint).
-
- * The completion script (in contrib/) learned to clear cached list of
-   command line options upon dot-sourcing it again in a more efficient
-   way.
-   (merge 94408dc71c sg/completion-clear-cached later to maint).
+ * "git grep --no-index" should not get affected by the contents of
+   the .gitmodules file but when "--recurse-submodules" is given or
+   the "submodule.recurse" variable is set, it did.  Now these
+   settings are ignored in the "--no-index" mode.
 
- * "git svn" had a minor thinko/typo which has been fixed.
-   (merge 51db271587 ab/git-svn-get-record-typofix later to maint).
+ * Technical details of the bundle format has been documented.
 
- * During a "rebase -i" session, the code could give older timestamp
-   to commits created by later "pick" than an earlier "reword", which
-   has been corrected.
-   (merge 12f7babd6b js/ident-date-fix later to maint).
+ * Unhelpful warning messages during documentation build have been
+   squelched.
 
- * "git submodule status" did not check the symbolic revision name it
-   computed for the submodule HEAD is not the NULL, and threw it at
-   printf routines, which has been corrected.
-   (merge 0b5e2ea7cf nd/submodule-status-fix later to maint).
-
- * When fed input that already has In-Reply-To: and/or References:
-   headers and told to add the same information, "git send-email"
-   added these headers separately, instead of appending to an existing
-   one, which is a violation of the RFC.  This has been corrected.
-   (merge 256be1d3f0 sa/send-email-dedup-some-headers later to maint).
-
- * "git fast-export" had a regression in v2.15.0 era where it skipped
-   some merge commits in certain cases, which has been corrected.
-   (merge be011bbe00 ma/fast-export-skip-merge-fix later to maint).
-
- * The code did not propagate the terminal width to subprocesses via
-   COLUMNS environment variable, which it now does.  This caused
-   trouble to "git column" helper subprocess when "git tag --column=row"
-   tried to list the existing tags on a display with non-default width.
-   (merge b5d5a567fb nd/term-columns later to maint).
-
- * We learned that our source files with ".pl" and ".py" extensions
-   are Perl and Python files respectively and changes to them are
-   better viewed as such with appropriate diff drivers.
-   (merge 7818b619e2 ab/perl-python-attrs later to maint).
-
- * "git rebase -i" sometimes left intermediate "# This is a
-   combination of N commits" message meant for the human consumption
-   inside an editor in the final result in certain corner cases, which
-   has been fixed.
-   (merge 15ef69314d js/rebase-i-clean-msg-after-fixup-continue later to maint).
-
- * A test to see if the filesystem normalizes UTF-8 filename has been
-   updated to check what we need to know in a more direct way, i.e. a
-   path created in NFC form can be accessed with NFD form (or vice
-   versa) to cope with APFS as well as HFS.
-   (merge 742ae10e35 tb/test-apfs-utf8-normalization later to maint).
-
- * "git format-patch --cover --attach" created a broken MIME multipart
-   message for the cover letter, which has been fixed by keeping the
-   cover letter as plain text file.
-   (merge 50cd54ef4e bc/format-patch-cover-no-attach later to maint).
-
- * The split-index feature had a long-standing and dormant bug in
-   certain use of the in-core merge machinery, which has been fixed.
-   (merge 7db118303a en/unpack-trees-split-index-fix later to maint).
-
- * Asciidoctor gives a reasonable imitation for AsciiDoc, but does not
-   render illustration in a literal block correctly when indented with
-   HT by default. The problem is fixed by forcing 8-space tabs.
-   (merge 379805051d bc/asciidoctor-tab-width later to maint).
-
- * Code clean-up to adjust to a more recent lockfile API convention that
-   allows lockfile instances kept on the stack.
-   (merge 0fa5a2ed8d ma/lockfile-cleanup later to maint).
-
- * the_repository->index is not a allocated piece of memory but
-   repo_clear() indiscriminately attempted to free(3) it, which has
-   been corrected.
-   (merge 74373b5f10 nd/repo-clear-keep-the-index later to maint).
-
- * Code clean-up to avoid non-standard-conformant pointer arithmetic.
-   (merge c112084af9 rs/no-null-ptr-arith-in-fast-export later to maint).
-
- * Code clean-up to turn history traversal more robust in a
-   semi-corrupt repository.
-   (merge 8702b30fd7 jk/unavailable-can-be-missing later to maint).
-
- * "git update-ref A B" is supposed to ensure that ref A does not yet
-   exist when B is a NULL OID, but this check was not done correctly
-   for pseudo-refs outside refs/ hierarchy, e.g. MERGE_HEAD.
-
- * "git submodule update" and "git submodule add" supported the
-   "--reference" option to borrow objects from a neighbouring local
-   repository like "git clone" does, but lacked the more recent
-   invention "--dissociate".  Also "git submodule add" has been taught
-   to take the "--progress" option.
-   (merge a0ef29341a cf/submodule-progress-dissociate later to maint).
-
- * Update credential-netrc helper (in contrib/) to allow customizing
-   the GPG used to decrypt the encrypted .netrc file.
-   (merge 786ef50a23 lm/credential-netrc later to maint).
-
- * "git submodule update" attempts two different kinds of "git fetch"
-   against the upstream repository to grab a commit bound at the
-   submodule's path, but it incorrectly gave up if the first kind
-   (i.e. a normal fetch) failed, making the second "last resort" one
-   (i.e. fetching an exact commit object by object name) ineffective.
-   This has been corrected.
-   (merge e30d833671 sb/submodule-update-try-harder later to maint).
-
- * Error behaviour of "git grep" when it cannot read the index was
-   inconsistent with other commands that uses the index, which has
-   been corrected to error out early.
-   (merge b2aa84c789 sb/grep-die-on-unreadable-index later to maint).
-
- * We used to call regfree() after regcomp() failed in some codepaths,
-   which have been corrected.
-   (merge 17154b1576 ma/regex-no-regfree-after-comp-fail later to maint).
-
- * The import-tars script (in contrib/) has been taught to handle
-   tarballs with overly long paths that use PAX extended headers.
-   (merge 12ecea46e3 pa/import-tars-long-names later to maint).
-
- * "git rev-parse Y..." etc. misbehaved when given endpoints were
-   not committishes.
-   (merge 0ed556d38f en/rev-parse-invalid-range later to maint).
-
- * "git pull --recurse-submodules --rebase", when the submodule
-   repository's history did not have anything common between ours and
-   the upstream's, failed to execute.  We need to fetch from them to
-   continue even in such a case.
-   (merge 4d36f88be7 jt/submodule-pull-recurse-rebase later to maint).
-
- * "git remote update" can take both a single remote nickname and a
-   nickname for remote groups, but only one of them was documented.
-   (merge a97447a42a nd/remote-update-doc later to maint).
-
- * "index-pack --strict" has been taught to make sure that it runs the
-   final object integrity checks after making the freshly indexed
-   packfile available to itself.
-   (merge 3737746120 jk/index-pack-maint later to maint).
-
- * Make zlib inflate codepath more robust against versions of zlib
-   that clobber unused portion of outbuf.
-   (merge b611396e97 jl/zlib-restore-nul-termination later to maint).
-
- * Fix old merge glitch in Documentation during v2.13-rc0 era.
-   (merge 28cb06020b mw/doc-merge-enumfix later to maint).
-
- * The code to read compressed bitmap was not careful to avoid reading
-   past the end of the file, which has been corrected.
-   (merge 1140bf01ec jk/ewah-bounds-check later to maint).
-
- * "make NO_ICONV=NoThanks" did not override NEEDS_LIBICONV
-   (i.e. linkage of -lintl, -liconv, etc. that are platform-specific
-   tweaks), which has been corrected.
-   (merge fdb1fbbc7d es/make-no-iconv later to maint).
-
- * Other minor doc, test and build updates and code cleanups.
-   (merge 248f66ed8e nd/trace-with-env later to maint).
-   (merge 14ced5562c ys/bisect-object-id-missing-conversion-fix later to maint).
-   (merge 5988eb631a ab/doc-hash-brokenness later to maint).
-   (merge a4d4e32a70 pk/test-avoid-pipe-hiding-exit-status later to maint).
-   (merge 05e293c1ac jk/flockfile-stdio later to maint).
-   (merge e9184b0789 jk/t5561-missing-curl later to maint).
-   (merge b1801b85a3 nd/worktree-move later to maint).
-   (merge bbd374dd20 ak/bisect-doc-typofix later to maint).
-   (merge 4855f06fb3 mn/send-email-credential-doc later to maint).
-   (merge 8523b1e355 en/doc-typoes later to maint).
-   (merge 43b44ccfe7 js/t5404-path-fix later to maint).
-   (merge decf711fc1 ps/test-chmtime-get later to maint).
-   (merge 22d11a6e8e es/worktree-docs later to maint).
-   (merge 92a5dbbc22 tg/use-git-contacts later to maint).
-   (merge adc887221f tq/t1510 later to maint).
-   (merge bed21a8ad6 sg/doc-gc-quote-mismatch-fix later to maint).
-   (merge 73364e4f10 tz/doc-git-urls-reference later to maint).
-   (merge cd1e606bad bc/mailmap-self later to maint).
-   (merge f7997e3682 ao/config-api-doc later to maint).
-   (merge ee930754d8 jk/apply-p-doc later to maint).
-   (merge 011b648646 nd/pack-format-doc later to maint).
-   (merge 87a6bb701a sg/t5310-jgit-bitmap-test later to maint).
-   (merge f6b82970aa sg/t5516-fixes later to maint).
-   (merge 4362da078e sg/t7005-spaces-in-filenames-cleanup later to maint).
-   (merge 7d0ee47c11 js/test-unset-prereq later to maint).
-   (merge 5356a3c354 ah/misc-doc-updates later to maint).
-   (merge 92c4a7a129 nd/completion-aliasfiletype-typofix later to maint).
-   (merge 58bd77b66a nd/pack-unreachable-objects-doc later to maint).
-   (merge 4ed79d5203 sg/t6500-no-redirect-of-stdin later to maint).
-   (merge 17b8a2d6cd jk/config-blob-sans-repo later to maint).
-   (merge 590551ca2c rd/tag-doc-lightweight later to maint).
-   (merge 44f560fc16 rd/init-typo later to maint).
-   (merge f156a0934a rd/p4-doc-markup-env later to maint).
-   (merge 2a00502b14 tg/doc-sec-list later to maint).
-   (merge 47cc91310a jk/submodule-fsck-loose-fixup later to maint).
-   (merge efde7b725c rd/comment-typofix-in-sha1-file later to maint).
-   (merge 7eedad15df rd/diff-options-typofix later to maint).
-   (merge 58ebd936cc km/doc-workflows-typofix later to maint).
-   (merge 30aa96cdf8 rd/doc-remote-tracking-with-hyphen later to maint).
-   (merge cf317877e3 ks/branch-set-upstream later to maint).
-   (merge 8de19d6be8 sg/t7406-chain-fix later to maint).
+Also contains various documentation updates, code clean-ups and minor fixups.
diff -pruN 1.2.1+git2.18.0-1/git/remote.c 1.2.3+git2.25.1-1/git/remote.c
--- 1.2.1+git2.18.0-1/git/remote.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/remote.c	2020-02-17 04:47:35.000000000 +0000
@@ -3,6 +3,7 @@
 #include "remote.h"
 #include "refs.h"
 #include "refspec.h"
+#include "object-store.h"
 #include "commit.h"
 #include "diff.h"
 #include "revision.h"
@@ -11,6 +12,8 @@
 #include "string-list.h"
 #include "mergesort.h"
 #include "argv-array.h"
+#include "commit-reach.h"
+#include "advice.h"
 
 enum map_direction { FROM_SRC, FROM_DST };
 
@@ -108,14 +111,16 @@ struct remotes_hash_key {
 };
 
 static int remotes_hash_cmp(const void *unused_cmp_data,
-			    const void *entry,
-			    const void *entry_or_key,
+			    const struct hashmap_entry *eptr,
+			    const struct hashmap_entry *entry_or_key,
 			    const void *keydata)
 {
-	const struct remote *a = entry;
-	const struct remote *b = entry_or_key;
+	const struct remote *a, *b;
 	const struct remotes_hash_key *key = keydata;
 
+	a = container_of(eptr, const struct remote, ent);
+	b = container_of(entry_or_key, const struct remote, ent);
+
 	if (key)
 		return strncmp(a->name, key->str, key->len) || a->name[key->len];
 	else
@@ -132,7 +137,7 @@ static struct remote *make_remote(const
 {
 	struct remote *ret, *replaced;
 	struct remotes_hash_key lookup;
-	struct hashmap_entry lookup_entry;
+	struct hashmap_entry lookup_entry, *e;
 
 	if (!len)
 		len = strlen(name);
@@ -142,8 +147,9 @@ static struct remote *make_remote(const
 	lookup.len = len;
 	hashmap_entry_init(&lookup_entry, memhash(name, len));
 
-	if ((ret = hashmap_get(&remotes_hash, &lookup_entry, &lookup)) != NULL)
-		return ret;
+	e = hashmap_get(&remotes_hash, &lookup_entry, &lookup);
+	if (e)
+		return container_of(e, struct remote, ent);
 
 	ret = xcalloc(1, sizeof(struct remote));
 	ret->prune = -1;  /* unspecified */
@@ -155,8 +161,8 @@ static struct remote *make_remote(const
 	ALLOC_GROW(remotes, remotes_nr + 1, remotes_alloc);
 	remotes[remotes_nr++] = ret;
 
-	hashmap_entry_init(ret, lookup_entry.hash);
-	replaced = hashmap_put(&remotes_hash, ret);
+	hashmap_entry_init(&ret->ent, lookup_entry.hash);
+	replaced = hashmap_put_entry(&remotes_hash, ret, ent);
 	assert(replaced == NULL);  /* no previous entry overwritten */
 	return ret;
 }
@@ -334,14 +340,14 @@ static int handle_config(const char *key
 		if (!name)
 			return 0;
 		if (!strcmp(subkey, "insteadof")) {
-			rewrite = make_rewrite(&rewrites, name, namelen);
 			if (!value)
 				return config_error_nonbool(key);
+			rewrite = make_rewrite(&rewrites, name, namelen);
 			add_instead_of(rewrite, xstrdup(value));
 		} else if (!strcmp(subkey, "pushinsteadof")) {
-			rewrite = make_rewrite(&rewrites_push, name, namelen);
 			if (!value)
 				return config_error_nonbool(key);
+			rewrite = make_rewrite(&rewrites_push, name, namelen);
 			add_instead_of(rewrite, xstrdup(value));
 		}
 	}
@@ -357,7 +363,7 @@ static int handle_config(const char *key
 		return 0;
 	/* Handle remote.<name>.* variables */
 	if (*name == '/') {
-		warning("Config remote shorthand cannot begin with '/': %s",
+		warning(_("config remote shorthand cannot begin with '/': %s"),
 			name);
 		return 0;
 	}
@@ -404,7 +410,7 @@ static int handle_config(const char *key
 		if (!remote->receivepack)
 			remote->receivepack = v;
 		else
-			error("more than one receivepack given, using the first");
+			error(_("more than one receivepack given, using the first"));
 	} else if (!strcmp(subkey, "uploadpack")) {
 		const char *v;
 		if (git_config_string(&v, key, value))
@@ -412,7 +418,7 @@ static int handle_config(const char *key
 		if (!remote->uploadpack)
 			remote->uploadpack = v;
 		else
-			error("more than one uploadpack given, using the first");
+			error(_("more than one uploadpack given, using the first"));
 	} else if (!strcmp(subkey, "tagopt")) {
 		if (!strcmp(value, "--no-tags"))
 			remote->fetch_tags = -1;
@@ -618,7 +624,7 @@ static void handle_duplicate(struct ref
 			 * FETCH_HEAD_IGNORE entries always appear at
 			 * the end of the list.
 			 */
-			die(_("Internal error"));
+			BUG("Internal error");
 		}
 	}
 	free(ref2->peer_ref);
@@ -678,7 +684,7 @@ static int match_name_with_pattern(const
 	size_t namelen;
 	int ret;
 	if (!kstar)
-		die("Key '%s' of pattern had no '*'", key);
+		die(_("key '%s' of pattern had no '*'"), key);
 	klen = kstar - key;
 	ksuffixlen = strlen(kstar + 1);
 	namelen = strlen(name);
@@ -688,7 +694,7 @@ static int match_name_with_pattern(const
 		struct strbuf sb = STRBUF_INIT;
 		const char *vstar = strchr(value, '*');
 		if (!vstar)
-			die("Value '%s' of pattern has no '*'", value);
+			die(_("value '%s' of pattern has no '*'"), value);
 		strbuf_add(&sb, value, vstar - value);
 		strbuf_add(&sb, name + klen, namelen - klen - ksuffixlen);
 		strbuf_addstr(&sb, vstar + 1);
@@ -705,7 +711,7 @@ static void query_refspecs_multiple(stru
 	int find_src = !query->src;
 
 	if (find_src && !query->dst)
-		error("query_refspecs_multiple: need either src or dst");
+		BUG("query_refspecs_multiple: need either src or dst");
 
 	for (i = 0; i < rs->nr; i++) {
 		struct refspec_item *refspec = &rs->items[i];
@@ -733,7 +739,7 @@ int query_refspecs(struct refspec *rs, s
 	char **result = find_src ? &query->src : &query->dst;
 
 	if (find_src && !query->dst)
-		return error("query_refspecs: need either src or dst");
+		BUG("query_refspecs: need either src or dst");
 
 	for (i = 0; i < rs->nr; i++) {
 		struct refspec_item *refspec = &rs->items[i];
@@ -817,11 +823,11 @@ struct ref *copy_ref_list(const struct r
 	return ret;
 }
 
-static void free_ref(struct ref *ref)
+void free_one_ref(struct ref *ref)
 {
 	if (!ref)
 		return;
-	free_ref(ref->peer_ref);
+	free_one_ref(ref->peer_ref);
 	free(ref->remote_status);
 	free(ref->symref);
 	free(ref);
@@ -832,7 +838,7 @@ void free_refs(struct ref *ref)
 	struct ref *next;
 	while (ref) {
 		next = ref->next;
-		free_ref(ref);
+		free_one_ref(ref);
 		ref = next;
 	}
 }
@@ -966,12 +972,13 @@ static char *guess_ref(const char *name,
 	if (!r)
 		return NULL;
 
-	if (starts_with(r, "refs/heads/"))
+	if (starts_with(r, "refs/heads/")) {
 		strbuf_addstr(&buf, "refs/heads/");
-	else if (starts_with(r, "refs/tags/"))
+	} else if (starts_with(r, "refs/tags/")) {
 		strbuf_addstr(&buf, "refs/tags/");
-	else
+	} else {
 		return NULL;
+	}
 
 	strbuf_addstr(&buf, name);
 	return strbuf_detach(&buf, NULL);
@@ -993,12 +1000,68 @@ static int match_explicit_lhs(struct ref
 		 * way to delete 'other' ref at the remote end.
 		 */
 		if (try_explicit_object_name(rs->src, match) < 0)
-			return error("src refspec %s does not match any.", rs->src);
+			return error(_("src refspec %s does not match any"), rs->src);
 		if (allocated_match)
 			*allocated_match = 1;
 		return 0;
 	default:
-		return error("src refspec %s matches more than one.", rs->src);
+		return error(_("src refspec %s matches more than one"), rs->src);
+	}
+}
+
+static void show_push_unqualified_ref_name_error(const char *dst_value,
+						 const char *matched_src_name)
+{
+	struct object_id oid;
+	enum object_type type;
+
+	/*
+	 * TRANSLATORS: "matches '%s'%" is the <dst> part of "git push
+	 * <remote> <src>:<dst>" push, and "being pushed ('%s')" is
+	 * the <src>.
+	 */
+	error(_("The destination you provided is not a full refname (i.e.,\n"
+		"starting with \"refs/\"). We tried to guess what you meant by:\n"
+		"\n"
+		"- Looking for a ref that matches '%s' on the remote side.\n"
+		"- Checking if the <src> being pushed ('%s')\n"
+		"  is a ref in \"refs/{heads,tags}/\". If so we add a corresponding\n"
+		"  refs/{heads,tags}/ prefix on the remote side.\n"
+		"\n"
+		"Neither worked, so we gave up. You must fully qualify the ref."),
+	      dst_value, matched_src_name);
+
+	if (!advice_push_unqualified_ref_name)
+		return;
+
+	if (get_oid(matched_src_name, &oid))
+		BUG("'%s' is not a valid object, "
+		    "match_explicit_lhs() should catch this!",
+		    matched_src_name);
+	type = oid_object_info(the_repository, &oid, NULL);
+	if (type == OBJ_COMMIT) {
+		advise(_("The <src> part of the refspec is a commit object.\n"
+			 "Did you mean to create a new branch by pushing to\n"
+			 "'%s:refs/heads/%s'?"),
+		       matched_src_name, dst_value);
+	} else if (type == OBJ_TAG) {
+		advise(_("The <src> part of the refspec is a tag object.\n"
+			 "Did you mean to create a new tag by pushing to\n"
+			 "'%s:refs/tags/%s'?"),
+		       matched_src_name, dst_value);
+	} else if (type == OBJ_TREE) {
+		advise(_("The <src> part of the refspec is a tree object.\n"
+			 "Did you mean to tag a new tree by pushing to\n"
+			 "'%s:refs/tags/%s'?"),
+		       matched_src_name, dst_value);
+	} else if (type == OBJ_BLOB) {
+		advise(_("The <src> part of the refspec is a blob object.\n"
+			 "Did you mean to tag a new blob by pushing to\n"
+			 "'%s:refs/tags/%s'?"),
+		       matched_src_name, dst_value);
+	} else {
+		BUG("'%s' should be commit/tag/tree/blob, is '%d'",
+		    matched_src_name, type);
 	}
 }
 
@@ -1028,7 +1091,7 @@ static int match_explicit(struct ref *sr
 		if (!dst_value ||
 		    ((flag & REF_ISSYMREF) &&
 		     !starts_with(dst_value, "refs/heads/")))
-			die("%s cannot be resolved to branch.",
+			die(_("%s cannot be resolved to branch"),
 			    matched_src->name);
 	}
 
@@ -1036,33 +1099,30 @@ static int match_explicit(struct ref *sr
 	case 1:
 		break;
 	case 0:
-		if (starts_with(dst_value, "refs/"))
+		if (starts_with(dst_value, "refs/")) {
 			matched_dst = make_linked_ref(dst_value, dst_tail);
-		else if (is_null_oid(&matched_src->new_oid))
-			error("unable to delete '%s': remote ref does not exist",
+		} else if (is_null_oid(&matched_src->new_oid)) {
+			error(_("unable to delete '%s': remote ref does not exist"),
 			      dst_value);
-		else if ((dst_guess = guess_ref(dst_value, matched_src))) {
+		} else if ((dst_guess = guess_ref(dst_value, matched_src))) {
 			matched_dst = make_linked_ref(dst_guess, dst_tail);
 			free(dst_guess);
-		} else
-			error("unable to push to unqualified destination: %s\n"
-			      "The destination refspec neither matches an "
-			      "existing ref on the remote nor\n"
-			      "begins with refs/, and we are unable to "
-			      "guess a prefix based on the source ref.",
-			      dst_value);
+		} else {
+			show_push_unqualified_ref_name_error(dst_value,
+							     matched_src->name);
+		}
 		break;
 	default:
 		matched_dst = NULL;
-		error("dst refspec %s matches more than one.",
+		error(_("dst refspec %s matches more than one"),
 		      dst_value);
 		break;
 	}
 	if (!matched_dst)
 		return -1;
 	if (matched_dst->peer_ref)
-		return error("dst ref %s receives from more than one src.",
-		      matched_dst->name);
+		return error(_("dst ref %s receives from more than one src"),
+			     matched_dst->name);
 	else {
 		matched_dst->peer_ref = allocated_src ?
 					matched_src :
@@ -1148,7 +1208,7 @@ static void add_to_tips(struct tips *tip
 
 	if (is_null_oid(oid))
 		return;
-	commit = lookup_commit_reference_gently(oid, 1);
+	commit = lookup_commit_reference_gently(the_repository, oid, 1);
 	if (!commit || (commit->object.flags & TMP_MARK))
 		return;
 	commit->object.flags |= TMP_MARK;
@@ -1203,14 +1263,42 @@ static void add_missing_tags(struct ref
 	 * sent to the other side.
 	 */
 	if (sent_tips.nr) {
+		const int reachable_flag = 1;
+		struct commit_list *found_commits;
+		struct commit **src_commits;
+		int nr_src_commits = 0, alloc_src_commits = 16;
+		ALLOC_ARRAY(src_commits, alloc_src_commits);
+
 		for_each_string_list_item(item, &src_tag) {
 			struct ref *ref = item->util;
+			struct commit *commit;
+
+			if (is_null_oid(&ref->new_oid))
+				continue;
+			commit = lookup_commit_reference_gently(the_repository,
+								&ref->new_oid,
+								1);
+			if (!commit)
+				/* not pushing a commit, which is not an error */
+				continue;
+
+			ALLOC_GROW(src_commits, nr_src_commits + 1, alloc_src_commits);
+			src_commits[nr_src_commits++] = commit;
+		}
+
+		found_commits = get_reachable_subset(sent_tips.tip, sent_tips.nr,
+						     src_commits, nr_src_commits,
+						     reachable_flag);
+
+		for_each_string_list_item(item, &src_tag) {
 			struct ref *dst_ref;
+			struct ref *ref = item->util;
 			struct commit *commit;
 
 			if (is_null_oid(&ref->new_oid))
 				continue;
-			commit = lookup_commit_reference_gently(&ref->new_oid,
+			commit = lookup_commit_reference_gently(the_repository,
+								&ref->new_oid,
 								1);
 			if (!commit)
 				/* not pushing a commit, which is not an error */
@@ -1220,7 +1308,7 @@ static void add_missing_tags(struct ref
 			 * Is this tag, which they do not have, reachable from
 			 * any of the commits we are sending?
 			 */
-			if (!in_merge_bases_many(commit, sent_tips.nr, sent_tips.tip))
+			if (!(commit->object.flags & reachable_flag))
 				continue;
 
 			/* Add it in */
@@ -1228,7 +1316,12 @@ static void add_missing_tags(struct ref
 			oidcpy(&dst_ref->new_oid, &ref->new_oid);
 			dst_ref->peer_ref = copy_ref(ref);
 		}
+
+		clear_commit_marks_many(nr_src_commits, src_commits, reachable_flag);
+		free(src_commits);
+		free_commit_list(found_commits);
 	}
+
 	string_list_clear(&src_tag, 0);
 	free(sent_tips.tip);
 }
@@ -1386,7 +1479,7 @@ void set_ref_status_for_push(struct ref
 
 		ref->deletion = is_null_oid(&ref->new_oid);
 		if (!ref->deletion &&
-			!oidcmp(&ref->old_oid, &ref->new_oid)) {
+			oideq(&ref->old_oid, &ref->new_oid)) {
 			ref->status = REF_STATUS_UPTODATE;
 			continue;
 		}
@@ -1401,7 +1494,7 @@ void set_ref_status_for_push(struct ref
 		 * branch.
 		 */
 		if (ref->expect_old_sha1) {
-			if (oidcmp(&ref->old_oid, &ref->old_oid_expect))
+			if (!oideq(&ref->old_oid, &ref->old_oid_expect))
 				reject_reason = REF_STATUS_REJECT_STALE;
 			else
 				/* If the ref isn't stale then force the update. */
@@ -1434,8 +1527,8 @@ void set_ref_status_for_push(struct ref
 				reject_reason = REF_STATUS_REJECT_ALREADY_EXISTS;
 			else if (!has_object_file(&ref->old_oid))
 				reject_reason = REF_STATUS_REJECT_FETCH_FIRST;
-			else if (!lookup_commit_reference_gently(&ref->old_oid, 1) ||
-				 !lookup_commit_reference_gently(&ref->new_oid, 1))
+			else if (!lookup_commit_reference_gently(the_repository, &ref->old_oid, 1) ||
+				 !lookup_commit_reference_gently(the_repository, &ref->new_oid, 1))
 				reject_reason = REF_STATUS_REJECT_NEEDS_FORCE;
 			else if (!ref_newer(&ref->new_oid, &ref->old_oid))
 				reject_reason = REF_STATUS_REJECT_NONFASTFORWARD;
@@ -1687,11 +1780,18 @@ static struct ref *get_expanded_map(cons
 static const struct ref *find_ref_by_name_abbrev(const struct ref *refs, const char *name)
 {
 	const struct ref *ref;
+	const struct ref *best_match = NULL;
+	int best_score = 0;
+
 	for (ref = refs; ref; ref = ref->next) {
-		if (refname_match(name, ref->name))
-			return ref;
+		int score = refname_match(name, ref->name);
+
+		if (best_score < score) {
+			best_match = ref;
+			best_score = score;
+		}
 	}
-	return NULL;
+	return best_match;
 }
 
 struct ref *get_remote_ref(const struct ref *remote_refs, const char *name)
@@ -1735,11 +1835,12 @@ int get_fetch_map(const struct ref *remo
 		if (refspec->exact_sha1) {
 			ref_map = alloc_ref(name);
 			get_oid_hex(name, &ref_map->old_oid);
+			ref_map->exact_oid = 1;
 		} else {
 			ref_map = get_remote_ref(remote_refs, name);
 		}
 		if (!missing_ok && !ref_map)
-			die("Couldn't find remote ref %s", name);
+			die(_("couldn't find remote ref %s"), name);
 		if (ref_map) {
 			ref_map->peer_ref = get_local_ref(refspec->dst);
 			if (ref_map->peer_ref && refspec->force)
@@ -1752,7 +1853,7 @@ int get_fetch_map(const struct ref *remo
 			if (!starts_with((*rmp)->peer_ref->name, "refs/") ||
 			    check_refname_format((*rmp)->peer_ref->name, 0)) {
 				struct ref *ignore = *rmp;
-				error("* Ignoring funny ref '%s' locally",
+				error(_("* Ignoring funny ref '%s' locally"),
 				      (*rmp)->peer_ref->name);
 				*rmp = (*rmp)->next;
 				free(ignore->peer_ref);
@@ -1781,95 +1882,38 @@ int resolve_remote_symref(struct ref *re
 	return 1;
 }
 
-static void unmark_and_free(struct commit_list *list, unsigned int mark)
-{
-	while (list) {
-		struct commit *commit = pop_commit(&list);
-		commit->object.flags &= ~mark;
-	}
-}
-
-int ref_newer(const struct object_id *new_oid, const struct object_id *old_oid)
-{
-	struct object *o;
-	struct commit *old_commit, *new_commit;
-	struct commit_list *list, *used;
-	int found = 0;
-
-	/*
-	 * Both new_commit and old_commit must be commit-ish and new_commit is descendant of
-	 * old_commit.  Otherwise we require --force.
-	 */
-	o = deref_tag(parse_object(old_oid), NULL, 0);
-	if (!o || o->type != OBJ_COMMIT)
-		return 0;
-	old_commit = (struct commit *) o;
-
-	o = deref_tag(parse_object(new_oid), NULL, 0);
-	if (!o || o->type != OBJ_COMMIT)
-		return 0;
-	new_commit = (struct commit *) o;
-
-	if (parse_commit(new_commit) < 0)
-		return 0;
-
-	used = list = NULL;
-	commit_list_insert(new_commit, &list);
-	while (list) {
-		new_commit = pop_most_recent_commit(&list, TMP_MARK);
-		commit_list_insert(new_commit, &used);
-		if (new_commit == old_commit) {
-			found = 1;
-			break;
-		}
-	}
-	unmark_and_free(list, TMP_MARK);
-	unmark_and_free(used, TMP_MARK);
-	return found;
-}
-
 /*
- * Lookup the upstream branch for the given branch and if present, optionally
- * compute the commit ahead/behind values for the pair.
+ * Compute the commit ahead/behind values for the pair branch_name, base.
  *
  * If abf is AHEAD_BEHIND_FULL, compute the full ahead/behind and return the
  * counts in *num_ours and *num_theirs.  If abf is AHEAD_BEHIND_QUICK, skip
  * the (potentially expensive) a/b computation (*num_ours and *num_theirs are
  * set to zero).
  *
- * The name of the upstream branch (or NULL if no upstream is defined) is
- * returned via *upstream_name, if it is not itself NULL.
- *
- * Returns -1 if num_ours and num_theirs could not be filled in (e.g., no
- * upstream defined, or ref does not exist).  Returns 0 if the commits are
- * identical.  Returns 1 if commits are different.
+ * Returns -1 if num_ours and num_theirs could not be filled in (e.g., ref
+ * does not exist).  Returns 0 if the commits are identical.  Returns 1 if
+ * commits are different.
  */
-int stat_tracking_info(struct branch *branch, int *num_ours, int *num_theirs,
-		       const char **upstream_name, enum ahead_behind_flags abf)
+
+static int stat_branch_pair(const char *branch_name, const char *base,
+			     int *num_ours, int *num_theirs,
+			     enum ahead_behind_flags abf)
 {
 	struct object_id oid;
 	struct commit *ours, *theirs;
 	struct rev_info revs;
-	const char *base;
 	struct argv_array argv = ARGV_ARRAY_INIT;
 
-	/* Cannot stat unless we are marked to build on top of somebody else. */
-	base = branch_get_upstream(branch, NULL);
-	if (upstream_name)
-		*upstream_name = base;
-	if (!base)
-		return -1;
-
 	/* Cannot stat if what we used to build on no longer exists */
 	if (read_ref(base, &oid))
 		return -1;
-	theirs = lookup_commit_reference(&oid);
+	theirs = lookup_commit_reference(the_repository, &oid);
 	if (!theirs)
 		return -1;
 
-	if (read_ref(branch->refname, &oid))
+	if (read_ref(branch_name, &oid))
 		return -1;
-	ours = lookup_commit_reference(&oid);
+	ours = lookup_commit_reference(the_repository, &oid);
 	if (!ours)
 		return -1;
 
@@ -1881,7 +1925,7 @@ int stat_tracking_info(struct branch *br
 	if (abf == AHEAD_BEHIND_QUICK)
 		return 1;
 	if (abf != AHEAD_BEHIND_FULL)
-		BUG("stat_tracking_info: invalid abf '%d'", abf);
+		BUG("stat_branch_pair: invalid abf '%d'", abf);
 
 	/* Run "rev-list --left-right ours...theirs" internally... */
 	argv_array_push(&argv, ""); /* ignored */
@@ -1891,10 +1935,10 @@ int stat_tracking_info(struct branch *br
 			 oid_to_hex(&theirs->object.oid));
 	argv_array_push(&argv, "--");
 
-	init_revisions(&revs, NULL);
+	repo_init_revisions(the_repository, &revs, NULL);
 	setup_revisions(argv.argc, argv.argv, &revs, NULL);
 	if (prepare_revision_walk(&revs))
-		die("revision walk setup failed");
+		die(_("revision walk setup failed"));
 
 	/* ... and count the commits on each side. */
 	while (1) {
@@ -1916,6 +1960,42 @@ int stat_tracking_info(struct branch *br
 }
 
 /*
+ * Lookup the tracking branch for the given branch and if present, optionally
+ * compute the commit ahead/behind values for the pair.
+ *
+ * If for_push is true, the tracking branch refers to the push branch,
+ * otherwise it refers to the upstream branch.
+ *
+ * The name of the tracking branch (or NULL if it is not defined) is
+ * returned via *tracking_name, if it is not itself NULL.
+ *
+ * If abf is AHEAD_BEHIND_FULL, compute the full ahead/behind and return the
+ * counts in *num_ours and *num_theirs.  If abf is AHEAD_BEHIND_QUICK, skip
+ * the (potentially expensive) a/b computation (*num_ours and *num_theirs are
+ * set to zero).
+ *
+ * Returns -1 if num_ours and num_theirs could not be filled in (e.g., no
+ * upstream defined, or ref does not exist).  Returns 0 if the commits are
+ * identical.  Returns 1 if commits are different.
+ */
+int stat_tracking_info(struct branch *branch, int *num_ours, int *num_theirs,
+		       const char **tracking_name, int for_push,
+		       enum ahead_behind_flags abf)
+{
+	const char *base;
+
+	/* Cannot stat unless we are marked to build on top of somebody else. */
+	base = for_push ? branch_get_push(branch, NULL) :
+		branch_get_upstream(branch, NULL);
+	if (tracking_name)
+		*tracking_name = base;
+	if (!base)
+		return -1;
+
+	return stat_branch_pair(branch->refname, base, num_ours, num_theirs, abf);
+}
+
+/*
  * Return true when there is anything to report, otherwise false.
  */
 int format_tracking_info(struct branch *branch, struct strbuf *sb,
@@ -1926,7 +2006,7 @@ int format_tracking_info(struct branch *
 	char *base;
 	int upstream_is_gone = 0;
 
-	sti = stat_tracking_info(branch, &ours, &theirs, &full_base, abf);
+	sti = stat_tracking_info(branch, &ours, &theirs, &full_base, 0, abf);
 	if (sti < 0) {
 		if (!full_base)
 			return 0;
@@ -2037,7 +2117,7 @@ struct ref *guess_remote_head(const stru
 	/* If refs/heads/master could be right, it is. */
 	if (!all) {
 		r = find_ref_by_name(refs, "refs/heads/master");
-		if (r && !oidcmp(&r->old_oid, &head->old_oid))
+		if (r && oideq(&r->old_oid, &head->old_oid))
 			return copy_ref(r);
 	}
 
@@ -2045,7 +2125,7 @@ struct ref *guess_remote_head(const stru
 	for (r = refs; r; r = r->next) {
 		if (r != head &&
 		    starts_with(r->name, "refs/heads/") &&
-		    !oidcmp(&r->old_oid, &head->old_oid)) {
+		    oideq(&r->old_oid, &head->old_oid)) {
 			*tail = copy_ref(r);
 			tail = &((*tail)->next);
 			if (!all)
@@ -2167,7 +2247,8 @@ static int parse_push_cas_option(struct
 	else if (!colon[1])
 		oidclr(&entry->expect);
 	else if (get_oid(colon + 1, &entry->expect))
-		return error("cannot parse expected object name '%s'", colon + 1);
+		return error(_("cannot parse expected object name '%s'"),
+			     colon + 1);
 	return 0;
 }
 
diff -pruN 1.2.1+git2.18.0-1/git/remote-curl.c 1.2.3+git2.25.1-1/git/remote-curl.c
--- 1.2.1+git2.18.0-1/git/remote-curl.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/remote-curl.c	2020-02-17 04:47:35.000000000 +0000
@@ -16,6 +16,7 @@
 #include "send-pack.h"
 #include "protocol.h"
 #include "quote.h"
+#include "transport.h"
 
 static struct remote *remote;
 /* always ends with a trailing slash */
@@ -39,7 +40,8 @@ struct options {
 		push_cert : 2,
 		deepen_relative : 1,
 		from_promisor : 1,
-		no_dependents : 1;
+		no_dependents : 1,
+		atomic : 1;
 };
 static struct options options;
 static struct string_list cas_options = STRING_LIST_INIT_DUP;
@@ -147,13 +149,21 @@ static int set_option(const char *name,
 		else
 			return -1;
 		return 0;
+	} else if (!strcmp(name, "atomic")) {
+		if (!strcmp(value, "true"))
+			options.atomic = 1;
+		else if (!strcmp(value, "false"))
+			options.atomic = 0;
+		else
+			return -1;
+		return 0;
 	} else if (!strcmp(name, "push-option")) {
 		if (*value != '"')
 			string_list_append(&options.push_options, value);
 		else {
 			struct strbuf unquoted = STRBUF_INIT;
 			if (unquote_c_style(&unquoted, value, NULL) < 0)
-				die("invalid quoting in push-option value");
+				die(_("invalid quoting in push-option value: '%s'"), value);
 			string_list_append_nodup(&options.push_options,
 						 strbuf_detach(&unquoted, NULL));
 		}
@@ -178,7 +188,7 @@ static int set_option(const char *name,
 		options.no_dependents = 1;
 		return 0;
 	} else if (!strcmp(name, "filter")) {
-		options.filter = xstrdup(value);;
+		options.filter = xstrdup(value);
 		return 0;
 	} else {
 		return 1 /* unsupported */;
@@ -204,7 +214,8 @@ static struct ref *parse_git_refs(struct
 
 	packet_reader_init(&reader, -1, heads->buf, heads->len,
 			   PACKET_READ_CHOMP_NEWLINE |
-			   PACKET_READ_GENTLE_ON_EOF);
+			   PACKET_READ_GENTLE_ON_EOF |
+			   PACKET_READ_DIE_ON_ERR_PACKET);
 
 	heads->version = discover_version(&reader);
 	switch (heads->version) {
@@ -248,9 +259,9 @@ static struct ref *parse_info_refs(struc
 		if (data[i] == '\t')
 			mid = &data[i];
 		if (data[i] == '\n') {
-			if (mid - start != 40)
-				die("%sinfo/refs not valid: is this a git repository?",
-				    url.buf);
+			if (mid - start != the_hash_algo->hexsz)
+				die(_("%sinfo/refs not valid: is this a git repository?"),
+				    transport_anonymize_url(url.buf));
 			data[i] = 0;
 			ref_name = mid + 1;
 			ref = alloc_ref(ref_name);
@@ -330,9 +341,63 @@ static int get_protocol_http_header(enum
 	return 0;
 }
 
+static void check_smart_http(struct discovery *d, const char *service,
+			     struct strbuf *type)
+{
+	const char *p;
+	struct packet_reader reader;
+
+	/*
+	 * If we don't see x-$service-advertisement, then it's not smart-http.
+	 * But once we do, we commit to it and assume any other protocol
+	 * violations are hard errors.
+	 */
+	if (!skip_prefix(type->buf, "application/x-", &p) ||
+	    !skip_prefix(p, service, &p) ||
+	    strcmp(p, "-advertisement"))
+		return;
+
+	packet_reader_init(&reader, -1, d->buf, d->len,
+			   PACKET_READ_CHOMP_NEWLINE |
+			   PACKET_READ_DIE_ON_ERR_PACKET);
+	if (packet_reader_read(&reader) != PACKET_READ_NORMAL)
+		die(_("invalid server response; expected service, got flush packet"));
+
+	if (skip_prefix(reader.line, "# service=", &p) && !strcmp(p, service)) {
+		/*
+		 * The header can include additional metadata lines, up
+		 * until a packet flush marker.  Ignore these now, but
+		 * in the future we might start to scan them.
+		 */
+		for (;;) {
+			packet_reader_read(&reader);
+			if (reader.pktlen <= 0) {
+				break;
+			}
+		}
+
+		/*
+		 * v0 smart http; callers expect us to soak up the
+		 * service and header packets
+		 */
+		d->buf = reader.src_buffer;
+		d->len = reader.src_len;
+		d->proto_git = 1;
+
+	} else if (!strcmp(reader.line, "version 2")) {
+		/*
+		 * v2 smart http; do not consume version packet, which will
+		 * be handled elsewhere.
+		 */
+		d->proto_git = 1;
+
+	} else {
+		die(_("invalid server response; got '%s'"), reader.line);
+	}
+}
+
 static struct discovery *discover_refs(const char *service, int for_push)
 {
-	struct strbuf exp = STRBUF_INIT;
 	struct strbuf type = STRBUF_INIT;
 	struct strbuf charset = STRBUF_INIT;
 	struct strbuf buffer = STRBUF_INIT;
@@ -380,7 +445,6 @@ static struct discovery *discover_refs(c
 	http_options.extra_headers = &extra_headers;
 	http_options.initial_request = 1;
 	http_options.no_cache = 1;
-	http_options.keep_error = 1;
 
 	http_ret = http_get_strbuf(refs_url.buf, &buffer, &http_options);
 	switch (http_ret) {
@@ -388,55 +452,31 @@ static struct discovery *discover_refs(c
 		break;
 	case HTTP_MISSING_TARGET:
 		show_http_message(&type, &charset, &buffer);
-		die("repository '%s' not found", url.buf);
+		die(_("repository '%s' not found"),
+		    transport_anonymize_url(url.buf));
 	case HTTP_NOAUTH:
 		show_http_message(&type, &charset, &buffer);
-		die("Authentication failed for '%s'", url.buf);
+		die(_("Authentication failed for '%s'"),
+		    transport_anonymize_url(url.buf));
 	default:
 		show_http_message(&type, &charset, &buffer);
-		die("unable to access '%s': %s", url.buf, curl_errorstr);
+		die(_("unable to access '%s': %s"),
+		    transport_anonymize_url(url.buf), curl_errorstr);
 	}
 
-	if (options.verbosity && !starts_with(refs_url.buf, url.buf))
-		warning(_("redirecting to %s"), url.buf);
+	if (options.verbosity && !starts_with(refs_url.buf, url.buf)) {
+		char *u = transport_anonymize_url(url.buf);
+		warning(_("redirecting to %s"), u);
+		free(u);
+	}
 
 	last= xcalloc(1, sizeof(*last_discovery));
 	last->service = xstrdup(service);
 	last->buf_alloc = strbuf_detach(&buffer, &last->len);
 	last->buf = last->buf_alloc;
 
-	strbuf_addf(&exp, "application/x-%s-advertisement", service);
-	if (maybe_smart &&
-	    (5 <= last->len && last->buf[4] == '#') &&
-	    !strbuf_cmp(&exp, &type)) {
-		char *line;
-
-		/*
-		 * smart HTTP response; validate that the service
-		 * pkt-line matches our request.
-		 */
-		line = packet_read_line_buf(&last->buf, &last->len, NULL);
-		if (!line)
-			die("invalid server response; expected service, got flush packet");
-
-		strbuf_reset(&exp);
-		strbuf_addf(&exp, "# service=%s", service);
-		if (strcmp(line, exp.buf))
-			die("invalid server response; got '%s'", line);
-		strbuf_release(&exp);
-
-		/* The header can include additional metadata lines, up
-		 * until a packet flush marker.  Ignore these now, but
-		 * in the future we might start to scan them.
-		 */
-		while (packet_read_line_buf(&last->buf, &last->len, NULL))
-			;
-
-		last->proto_git = 1;
-	} else if (maybe_smart &&
-		   last->len > 5 && starts_with(last->buf + 4, "version 2")) {
-		last->proto_git = 1;
-	}
+	if (maybe_smart)
+		check_smart_http(last, service, &type);
 
 	if (last->proto_git)
 		last->refs = parse_git_refs(last, for_push);
@@ -444,7 +484,6 @@ static struct discovery *discover_refs(c
 		last->refs = parse_info_refs(last);
 
 	strbuf_release(&refs_url);
-	strbuf_release(&exp);
 	strbuf_release(&type);
 	strbuf_release(&charset);
 	strbuf_release(&effective_url);
@@ -482,8 +521,6 @@ static void output_refs(struct ref *refs
 
 struct rpc_state {
 	const char *service_name;
-	const char **argv;
-	struct strbuf *stdin_preamble;
 	char *service_url;
 	char *hdr_content_type;
 	char *hdr_accept;
@@ -495,25 +532,121 @@ struct rpc_state {
 	int in;
 	int out;
 	int any_written;
-	struct strbuf result;
 	unsigned gzip_request : 1;
 	unsigned initial_buffer : 1;
+
+	/*
+	 * Whenever a pkt-line is read into buf, append the 4 characters
+	 * denoting its length before appending the payload.
+	 */
+	unsigned write_line_lengths : 1;
+
+	/*
+	 * Used by rpc_out; initialize to 0. This is true if a flush has been
+	 * read, but the corresponding line length (if write_line_lengths is
+	 * true) and EOF have not been sent to libcurl. Since each flush marks
+	 * the end of a request, each flush must be completely sent before any
+	 * further reading occurs.
+	 */
+	unsigned flush_read_but_not_sent : 1;
 };
 
+/*
+ * Appends the result of reading from rpc->out to the string represented by
+ * rpc->buf and rpc->len if there is enough space. Returns 1 if there was
+ * enough space, 0 otherwise.
+ *
+ * If rpc->write_line_lengths is true, appends the line length as a 4-byte
+ * hexadecimal string before appending the result described above.
+ *
+ * Writes the total number of bytes appended into appended.
+ */
+static int rpc_read_from_out(struct rpc_state *rpc, int options,
+			     size_t *appended,
+			     enum packet_read_status *status) {
+	size_t left;
+	char *buf;
+	int pktlen_raw;
+
+	if (rpc->write_line_lengths) {
+		left = rpc->alloc - rpc->len - 4;
+		buf = rpc->buf + rpc->len + 4;
+	} else {
+		left = rpc->alloc - rpc->len;
+		buf = rpc->buf + rpc->len;
+	}
+
+	if (left < LARGE_PACKET_MAX)
+		return 0;
+
+	*status = packet_read_with_status(rpc->out, NULL, NULL, buf,
+			left, &pktlen_raw, options);
+	if (*status != PACKET_READ_EOF) {
+		*appended = pktlen_raw + (rpc->write_line_lengths ? 4 : 0);
+		rpc->len += *appended;
+	}
+
+	if (rpc->write_line_lengths) {
+		switch (*status) {
+		case PACKET_READ_EOF:
+			if (!(options & PACKET_READ_GENTLE_ON_EOF))
+				die(_("shouldn't have EOF when not gentle on EOF"));
+			break;
+		case PACKET_READ_NORMAL:
+			set_packet_header(buf - 4, *appended);
+			break;
+		case PACKET_READ_DELIM:
+			memcpy(buf - 4, "0001", 4);
+			break;
+		case PACKET_READ_FLUSH:
+			memcpy(buf - 4, "0000", 4);
+			break;
+		}
+	}
+
+	return 1;
+}
+
 static size_t rpc_out(void *ptr, size_t eltsize,
 		size_t nmemb, void *buffer_)
 {
 	size_t max = eltsize * nmemb;
 	struct rpc_state *rpc = buffer_;
 	size_t avail = rpc->len - rpc->pos;
+	enum packet_read_status status;
 
 	if (!avail) {
 		rpc->initial_buffer = 0;
-		avail = packet_read(rpc->out, NULL, NULL, rpc->buf, rpc->alloc, 0);
-		if (!avail)
-			return 0;
+		rpc->len = 0;
 		rpc->pos = 0;
-		rpc->len = avail;
+		if (!rpc->flush_read_but_not_sent) {
+			if (!rpc_read_from_out(rpc, 0, &avail, &status))
+				BUG("The entire rpc->buf should be larger than LARGE_PACKET_MAX");
+			if (status == PACKET_READ_FLUSH)
+				rpc->flush_read_but_not_sent = 1;
+		}
+		/*
+		 * If flush_read_but_not_sent is true, we have already read one
+		 * full request but have not fully sent it + EOF, which is why
+		 * we need to refrain from reading.
+		 */
+	}
+	if (rpc->flush_read_but_not_sent) {
+		if (!avail) {
+			/*
+			 * The line length either does not need to be sent at
+			 * all or has already been completely sent. Now we can
+			 * return 0, indicating EOF, meaning that the flush has
+			 * been fully sent.
+			 */
+			rpc->flush_read_but_not_sent = 0;
+			return 0;
+		}
+		/*
+		 * If avail is non-zerp, the line length for the flush still
+		 * hasn't been fully sent. Proceed with sending the line
+		 * length.
+		 */
 	}
 
 	if (max < avail)
@@ -537,7 +670,7 @@ static curlioerr rpc_ioctl(CURL *handle,
 			rpc->pos = 0;
 			return CURLIOE_OK;
 		}
-		error("unable to rewind rpc post data - try increasing http.postBuffer");
+		error(_("unable to rewind rpc post data - try increasing http.postBuffer"));
 		return CURLIOE_FAILRESTART;
 
 	default:
@@ -546,14 +679,30 @@ static curlioerr rpc_ioctl(CURL *handle,
 }
 #endif
 
+struct rpc_in_data {
+	struct rpc_state *rpc;
+	struct active_request_slot *slot;
+};
+
+/*
+ * A callback for CURLOPT_WRITEFUNCTION. The return value is the bytes consumed
+ * from ptr.
+ */
 static size_t rpc_in(char *ptr, size_t eltsize,
 		size_t nmemb, void *buffer_)
 {
 	size_t size = eltsize * nmemb;
-	struct rpc_state *rpc = buffer_;
+	struct rpc_in_data *data = buffer_;
+	long response_code;
+
+	if (curl_easy_getinfo(data->slot->curl, CURLINFO_RESPONSE_CODE,
+			      &response_code) != CURLE_OK)
+		return size;
+	if (response_code >= 300)
+		return size;
 	if (size)
-		rpc->any_written = 1;
-	write_or_die(rpc->in, ptr, size);
+		data->rpc->any_written = 1;
+	write_or_die(data->rpc->in, ptr, size);
 	return size;
 }
 
@@ -581,7 +730,7 @@ static int run_slot(struct active_reques
 				strbuf_addstr(&msg, curl_errorstr);
 			}
 		}
-		error("RPC failed; %s", msg.buf);
+		error(_("RPC failed; %s"), msg.buf);
 		strbuf_release(&msg);
 	}
 
@@ -617,13 +766,19 @@ static int probe_rpc(struct rpc_state *r
 	return err;
 }
 
-static curl_off_t xcurl_off_t(ssize_t len) {
-	if (len > maximum_signed_value_of_type(curl_off_t))
-		die("cannot handle pushes this big");
-	return (curl_off_t) len;
+static curl_off_t xcurl_off_t(size_t len)
+{
+	uintmax_t size = len;
+	if (size > maximum_signed_value_of_type(curl_off_t))
+		die(_("cannot handle pushes this big"));
+	return (curl_off_t)size;
 }
 
-static int post_rpc(struct rpc_state *rpc)
+/*
+ * If flush_received is true, do not attempt to read any more; just use what's
+ * in rpc->buf.
+ */
+static int post_rpc(struct rpc_state *rpc, int flush_received)
 {
 	struct active_request_slot *slot;
 	struct curl_slist *headers = http_copy_default_headers();
@@ -632,26 +787,25 @@ static int post_rpc(struct rpc_state *rp
 	size_t gzip_size = 0;
 	int err, large_request = 0;
 	int needs_100_continue = 0;
+	struct rpc_in_data rpc_in_data;
 
 	/* Try to load the entire request, if we can fit it into the
 	 * allocated buffer space we can use HTTP/1.0 and avoid the
 	 * chunked encoding mess.
 	 */
-	while (1) {
-		size_t left = rpc->alloc - rpc->len;
-		char *buf = rpc->buf + rpc->len;
-		int n;
-
-		if (left < LARGE_PACKET_MAX) {
-			large_request = 1;
-			use_gzip = 0;
-			break;
+	if (!flush_received) {
+		while (1) {
+			size_t n;
+			enum packet_read_status status;
+
+			if (!rpc_read_from_out(rpc, 0, &n, &status)) {
+				large_request = 1;
+				use_gzip = 0;
+				break;
+			}
+			if (status == PACKET_READ_FLUSH)
+				break;
 		}
-
-		n = packet_read(rpc->out, NULL, NULL, buf, left, 0);
-		if (!n)
-			break;
-		rpc->len += n;
 	}
 
 	if (large_request) {
@@ -714,7 +868,7 @@ retry:
 
 	} else if (use_gzip && 1024 < rpc->len) {
 		/* The client backend isn't giving us compressed data so
-		 * we can try to deflate it ourselves, this may save on.
+		 * we can try to deflate it ourselves, this may save on
 		 * the transfer time.
 		 */
 		git_zstream stream;
@@ -731,11 +885,11 @@ retry:
 
 		ret = git_deflate(&stream, Z_FINISH);
 		if (ret != Z_STREAM_END)
-			die("cannot deflate request; zlib deflate error %d", ret);
+			die(_("cannot deflate request; zlib deflate error %d"), ret);
 
 		ret = git_deflate_end_gently(&stream);
 		if (ret != Z_OK)
-			die("cannot deflate request; zlib end error %d", ret);
+			die(_("cannot deflate request; zlib end error %d"), ret);
 
 		gzip_size = stream.total_out;
 
@@ -764,7 +918,10 @@ retry:
 
 	curl_easy_setopt(slot->curl, CURLOPT_HTTPHEADER, headers);
 	curl_easy_setopt(slot->curl, CURLOPT_WRITEFUNCTION, rpc_in);
-	curl_easy_setopt(slot->curl, CURLOPT_FILE, rpc);
+	rpc_in_data.rpc = rpc;
+	rpc_in_data.slot = slot;
+	curl_easy_setopt(slot->curl, CURLOPT_FILE, &rpc_in_data);
+	curl_easy_setopt(slot->curl, CURLOPT_FAILONERROR, 0);
 
 
 	rpc->any_written = 0;
@@ -784,22 +941,22 @@ retry:
 	return err;
 }
 
-static int rpc_service(struct rpc_state *rpc, struct discovery *heads)
+static int rpc_service(struct rpc_state *rpc, struct discovery *heads,
+		       const char **client_argv, const struct strbuf *preamble,
+		       struct strbuf *rpc_result)
 {
 	const char *svc = rpc->service_name;
 	struct strbuf buf = STRBUF_INIT;
-	struct strbuf *preamble = rpc->stdin_preamble;
 	struct child_process client = CHILD_PROCESS_INIT;
 	int err = 0;
 
 	client.in = -1;
 	client.out = -1;
 	client.git_cmd = 1;
-	client.argv = rpc->argv;
+	client.argv = client_argv;
 	if (start_command(&client))
 		exit(1);
-	if (preamble)
-		write_or_die(client.in, preamble->buf, preamble->len);
+	write_or_die(client.in, preamble->buf, preamble->len);
 	if (heads)
 		write_or_die(client.in, heads->buf, heads->len);
 
@@ -807,7 +964,6 @@ static int rpc_service(struct rpc_state
 	rpc->buf = xmalloc(rpc->alloc);
 	rpc->in = client.in;
 	rpc->out = client.out;
-	strbuf_init(&rpc->result, 0);
 
 	strbuf_addf(&buf, "%s%s", url.buf, svc);
 	rpc->service_url = strbuf_detach(&buf, NULL);
@@ -829,13 +985,13 @@ static int rpc_service(struct rpc_state
 			break;
 		rpc->pos = 0;
 		rpc->len = n;
-		err |= post_rpc(rpc);
+		err |= post_rpc(rpc, 0);
 	}
 
 	close(client.in);
 	client.in = -1;
 	if (!err) {
-		strbuf_read(&rpc->result, client.out, 0);
+		strbuf_read(rpc_result, client.out, 0);
 	} else {
 		char buf[4096];
 		for (;;)
@@ -864,7 +1020,7 @@ static int fetch_dumb(int nr_heads, stru
 
 	ALLOC_ARRAY(targets, nr_heads);
 	if (options.depth || options.deepen_since)
-		die("dumb http transport does not support shallow capabilities");
+		die(_("dumb http transport does not support shallow capabilities"));
 	for (i = 0; i < nr_heads; i++)
 		targets[i] = xstrdup(oid_to_hex(&to_fetch[i]->old_oid));
 
@@ -878,7 +1034,7 @@ static int fetch_dumb(int nr_heads, stru
 		free(targets[i]);
 	free(targets);
 
-	return ret ? error("fetch failed.") : 0;
+	return ret ? error(_("fetch failed.")) : 0;
 }
 
 static int fetch_git(struct discovery *heads,
@@ -888,6 +1044,7 @@ static int fetch_git(struct discovery *h
 	struct strbuf preamble = STRBUF_INIT;
 	int i, err;
 	struct argv_array args = ARGV_ARRAY_INIT;
+	struct strbuf rpc_result = STRBUF_INIT;
 
 	argv_array_pushl(&args, "fetch-pack", "--stateless-rpc",
 			 "--stdin", "--lock-pack", NULL);
@@ -925,7 +1082,7 @@ static int fetch_git(struct discovery *h
 	for (i = 0; i < nr_heads; i++) {
 		struct ref *ref = to_fetch[i];
 		if (!*ref->name)
-			die("cannot fetch by sha1 over smart http");
+			die(_("cannot fetch by sha1 over smart http"));
 		packet_buf_write(&preamble, "%s %s\n",
 				 oid_to_hex(&ref->old_oid), ref->name);
 	}
@@ -933,14 +1090,12 @@ static int fetch_git(struct discovery *h
 
 	memset(&rpc, 0, sizeof(rpc));
 	rpc.service_name = "git-upload-pack",
-	rpc.argv = args.argv;
-	rpc.stdin_preamble = &preamble;
 	rpc.gzip_request = 1;
 
-	err = rpc_service(&rpc, heads);
-	if (rpc.result.len)
-		write_or_die(1, rpc.result.buf, rpc.result.len);
-	strbuf_release(&rpc.result);
+	err = rpc_service(&rpc, heads, args.argv, &preamble, &rpc_result);
+	if (rpc_result.len)
+		write_or_die(1, rpc_result.buf, rpc_result.len);
+	strbuf_release(&rpc_result);
 	strbuf_release(&preamble);
 	argv_array_clear(&args);
 	return err;
@@ -968,15 +1123,16 @@ static void parse_fetch(struct strbuf *b
 			const char *name;
 			struct ref *ref;
 			struct object_id old_oid;
+			const char *q;
 
-			if (get_oid_hex(p, &old_oid))
-				die("protocol error: expected sha/ref, got %s'", p);
-			if (p[GIT_SHA1_HEXSZ] == ' ')
-				name = p + GIT_SHA1_HEXSZ + 1;
-			else if (!p[GIT_SHA1_HEXSZ])
+			if (parse_oid_hex(p, &old_oid, &q))
+				die(_("protocol error: expected sha/ref, got '%s'"), p);
+			if (*q == ' ')
+				name = q + 1;
+			else if (!*q)
 				name = "";
 			else
-				die("protocol error: expected sha/ref, got %s'", p);
+				die(_("protocol error: expected sha/ref, got '%s'"), p);
 
 			ref = alloc_ref(name);
 			oidcpy(&ref->old_oid, &old_oid);
@@ -988,7 +1144,7 @@ static void parse_fetch(struct strbuf *b
 			to_fetch[nr_heads++] = ref;
 		}
 		else
-			die("http transport does not support %s", buf->buf);
+			die(_("http transport does not support %s"), buf->buf);
 
 		strbuf_reset(buf);
 		if (strbuf_getline_lf(buf, stdin) == EOF)
@@ -1007,7 +1163,7 @@ static void parse_fetch(struct strbuf *b
 	strbuf_reset(buf);
 }
 
-static int push_dav(int nr_spec, char **specs)
+static int push_dav(int nr_spec, const char **specs)
 {
 	struct child_process child = CHILD_PROCESS_INIT;
 	size_t i;
@@ -1024,17 +1180,18 @@ static int push_dav(int nr_spec, char **
 		argv_array_push(&child.args, specs[i]);
 
 	if (run_command(&child))
-		die("git-http-push failed");
+		die(_("git-http-push failed"));
 	return 0;
 }
 
-static int push_git(struct discovery *heads, int nr_spec, char **specs)
+static int push_git(struct discovery *heads, int nr_spec, const char **specs)
 {
 	struct rpc_state rpc;
 	int i, err;
 	struct argv_array args;
 	struct string_list_item *cas_option;
 	struct strbuf preamble = STRBUF_INIT;
+	struct strbuf rpc_result = STRBUF_INIT;
 
 	argv_array_init(&args);
 	argv_array_pushl(&args, "send-pack", "--stateless-rpc", "--helper-status",
@@ -1048,6 +1205,8 @@ static int push_git(struct discovery *he
 		argv_array_push(&args, "--signed=yes");
 	else if (options.push_cert == SEND_PACK_PUSH_CERT_IF_ASKED)
 		argv_array_push(&args, "--signed=if-asked");
+	if (options.atomic)
+		argv_array_push(&args, "--atomic");
 	if (options.verbosity == 0)
 		argv_array_push(&args, "--quiet");
 	else if (options.verbosity > 1)
@@ -1067,19 +1226,17 @@ static int push_git(struct discovery *he
 
 	memset(&rpc, 0, sizeof(rpc));
 	rpc.service_name = "git-receive-pack",
-	rpc.argv = args.argv;
-	rpc.stdin_preamble = &preamble;
 
-	err = rpc_service(&rpc, heads);
-	if (rpc.result.len)
-		write_or_die(1, rpc.result.buf, rpc.result.len);
-	strbuf_release(&rpc.result);
+	err = rpc_service(&rpc, heads, args.argv, &preamble, &rpc_result);
+	if (rpc_result.len)
+		write_or_die(1, rpc_result.buf, rpc_result.len);
+	strbuf_release(&rpc_result);
 	strbuf_release(&preamble);
 	argv_array_clear(&args);
 	return err;
 }
 
-static int push(int nr_spec, char **specs)
+static int push(int nr_spec, const char **specs)
 {
 	struct discovery *heads = discover_refs("git-receive-pack", 1);
 	int ret;
@@ -1094,16 +1251,14 @@ static int push(int nr_spec, char **spec
 
 static void parse_push(struct strbuf *buf)
 {
-	char **specs = NULL;
-	int alloc_spec = 0, nr_spec = 0, i, ret;
+	struct argv_array specs = ARGV_ARRAY_INIT;
+	int ret;
 
 	do {
-		if (starts_with(buf->buf, "push ")) {
-			ALLOC_GROW(specs, nr_spec + 1, alloc_spec);
-			specs[nr_spec++] = xstrdup(buf->buf + 5);
-		}
+		if (starts_with(buf->buf, "push "))
+			argv_array_push(&specs, buf->buf + 5);
 		else
-			die("http transport does not support %s", buf->buf);
+			die(_("http transport does not support %s"), buf->buf);
 
 		strbuf_reset(buf);
 		if (strbuf_getline_lf(buf, stdin) == EOF)
@@ -1112,7 +1267,7 @@ static void parse_push(struct strbuf *bu
 			break;
 	} while (1);
 
-	ret = push(nr_spec, specs);
+	ret = push(specs.argc, specs.argv);
 	printf("\n");
 	fflush(stdout);
 
@@ -1120,169 +1275,14 @@ static void parse_push(struct strbuf *bu
 		exit(128); /* error already reported */
 
  free_specs:
-	for (i = 0; i < nr_spec; i++)
-		free(specs[i]);
-	free(specs);
-}
-
-/*
- * Used to represent the state of a connection to an HTTP server when
- * communicating using git's wire-protocol version 2.
- */
-struct proxy_state {
-	char *service_name;
-	char *service_url;
-	struct curl_slist *headers;
-	struct strbuf request_buffer;
-	int in;
-	int out;
-	struct packet_reader reader;
-	size_t pos;
-	int seen_flush;
-};
-
-static void proxy_state_init(struct proxy_state *p, const char *service_name,
-			     enum protocol_version version)
-{
-	struct strbuf buf = STRBUF_INIT;
-
-	memset(p, 0, sizeof(*p));
-	p->service_name = xstrdup(service_name);
-
-	p->in = 0;
-	p->out = 1;
-	strbuf_init(&p->request_buffer, 0);
-
-	strbuf_addf(&buf, "%s%s", url.buf, p->service_name);
-	p->service_url = strbuf_detach(&buf, NULL);
-
-	p->headers = http_copy_default_headers();
-
-	strbuf_addf(&buf, "Content-Type: application/x-%s-request", p->service_name);
-	p->headers = curl_slist_append(p->headers, buf.buf);
-	strbuf_reset(&buf);
-
-	strbuf_addf(&buf, "Accept: application/x-%s-result", p->service_name);
-	p->headers = curl_slist_append(p->headers, buf.buf);
-	strbuf_reset(&buf);
-
-	p->headers = curl_slist_append(p->headers, "Transfer-Encoding: chunked");
-
-	/* Add the Git-Protocol header */
-	if (get_protocol_http_header(version, &buf))
-		p->headers = curl_slist_append(p->headers, buf.buf);
-
-	packet_reader_init(&p->reader, p->in, NULL, 0,
-			   PACKET_READ_GENTLE_ON_EOF);
-
-	strbuf_release(&buf);
-}
-
-static void proxy_state_clear(struct proxy_state *p)
-{
-	free(p->service_name);
-	free(p->service_url);
-	curl_slist_free_all(p->headers);
-	strbuf_release(&p->request_buffer);
-}
-
-/*
- * CURLOPT_READFUNCTION callback function.
- * Attempts to copy over a single packet-line at a time into the
- * curl provided buffer.
- */
-static size_t proxy_in(char *buffer, size_t eltsize,
-		       size_t nmemb, void *userdata)
-{
-	size_t max;
-	struct proxy_state *p = userdata;
-	size_t avail = p->request_buffer.len - p->pos;
-
-
-	if (eltsize != 1)
-		BUG("curl read callback called with size = %"PRIuMAX" != 1",
-		    (uintmax_t)eltsize);
-	max = nmemb;
-
-	if (!avail) {
-		if (p->seen_flush) {
-			p->seen_flush = 0;
-			return 0;
-		}
-
-		strbuf_reset(&p->request_buffer);
-		switch (packet_reader_read(&p->reader)) {
-		case PACKET_READ_EOF:
-			die("unexpected EOF when reading from parent process");
-		case PACKET_READ_NORMAL:
-			packet_buf_write_len(&p->request_buffer, p->reader.line,
-					     p->reader.pktlen);
-			break;
-		case PACKET_READ_DELIM:
-			packet_buf_delim(&p->request_buffer);
-			break;
-		case PACKET_READ_FLUSH:
-			packet_buf_flush(&p->request_buffer);
-			p->seen_flush = 1;
-			break;
-		}
-		p->pos = 0;
-		avail = p->request_buffer.len;
-	}
-
-	if (max < avail)
-		avail = max;
-	memcpy(buffer, p->request_buffer.buf + p->pos, avail);
-	p->pos += avail;
-	return avail;
-}
-
-static size_t proxy_out(char *buffer, size_t eltsize,
-			size_t nmemb, void *userdata)
-{
-	size_t size;
-	struct proxy_state *p = userdata;
-
-	if (eltsize != 1)
-		BUG("curl read callback called with size = %"PRIuMAX" != 1",
-		    (uintmax_t)eltsize);
-	size = nmemb;
-
-	write_or_die(p->out, buffer, size);
-	return size;
-}
-
-/* Issues a request to the HTTP server configured in `p` */
-static int proxy_request(struct proxy_state *p)
-{
-	struct active_request_slot *slot;
-
-	slot = get_active_slot();
-
-	curl_easy_setopt(slot->curl, CURLOPT_ENCODING, "");
-	curl_easy_setopt(slot->curl, CURLOPT_NOBODY, 0);
-	curl_easy_setopt(slot->curl, CURLOPT_POST, 1);
-	curl_easy_setopt(slot->curl, CURLOPT_URL, p->service_url);
-	curl_easy_setopt(slot->curl, CURLOPT_HTTPHEADER, p->headers);
-
-	/* Setup function to read request from client */
-	curl_easy_setopt(slot->curl, CURLOPT_READFUNCTION, proxy_in);
-	curl_easy_setopt(slot->curl, CURLOPT_READDATA, p);
-
-	/* Setup function to write server response to client */
-	curl_easy_setopt(slot->curl, CURLOPT_WRITEFUNCTION, proxy_out);
-	curl_easy_setopt(slot->curl, CURLOPT_WRITEDATA, p);
-
-	if (run_slot(slot, NULL) != HTTP_OK)
-		return -1;
-
-	return 0;
+	argv_array_clear(&specs);
 }
 
 static int stateless_connect(const char *service_name)
 {
 	struct discovery *discover;
-	struct proxy_state p;
+	struct rpc_state rpc;
+	struct strbuf buf = STRBUF_INIT;
 
 	/*
 	 * Run the info/refs request and see if the server supports protocol
@@ -1302,23 +1302,58 @@ static int stateless_connect(const char
 		fflush(stdout);
 	}
 
-	proxy_state_init(&p, service_name, discover->version);
+	rpc.service_name = service_name;
+	rpc.service_url = xstrfmt("%s%s", url.buf, rpc.service_name);
+	rpc.hdr_content_type = xstrfmt("Content-Type: application/x-%s-request", rpc.service_name);
+	rpc.hdr_accept = xstrfmt("Accept: application/x-%s-result", rpc.service_name);
+	if (get_protocol_http_header(discover->version, &buf)) {
+		rpc.protocol_header = strbuf_detach(&buf, NULL);
+	} else {
+		rpc.protocol_header = NULL;
+		strbuf_release(&buf);
+	}
+	rpc.buf = xmalloc(http_post_buffer);
+	rpc.alloc = http_post_buffer;
+	rpc.len = 0;
+	rpc.pos = 0;
+	rpc.in = 1;
+	rpc.out = 0;
+	rpc.any_written = 0;
+	rpc.gzip_request = 1;
+	rpc.initial_buffer = 0;
+	rpc.write_line_lengths = 1;
+	rpc.flush_read_but_not_sent = 0;
 
 	/*
 	 * Dump the capability listing that we got from the server earlier
 	 * during the info/refs request.
 	 */
-	write_or_die(p.out, discover->buf, discover->len);
+	write_or_die(rpc.in, discover->buf, discover->len);
+
+	/* Until we see EOF keep sending POSTs */
+	while (1) {
+		size_t avail;
+		enum packet_read_status status;
 
-	/* Peek the next packet line.  Until we see EOF keep sending POSTs */
-	while (packet_reader_peek(&p.reader) != PACKET_READ_EOF) {
-		if (proxy_request(&p)) {
+		if (!rpc_read_from_out(&rpc, PACKET_READ_GENTLE_ON_EOF, &avail,
+				       &status))
+			BUG("The entire rpc->buf should be larger than LARGE_PACKET_MAX");
+		if (status == PACKET_READ_EOF)
+			break;
+		if (post_rpc(&rpc, status == PACKET_READ_FLUSH))
 			/* We would have an err here */
 			break;
-		}
+		/* Reset the buffer for next request */
+		rpc.len = 0;
 	}
 
-	proxy_state_clear(&p);
+	free(rpc.service_url);
+	free(rpc.hdr_content_type);
+	free(rpc.hdr_accept);
+	free(rpc.protocol_header);
+	free(rpc.buf);
+	strbuf_release(&buf);
+
 	return 0;
 }
 
@@ -1329,7 +1364,7 @@ int cmd_main(int argc, const char **argv
 
 	setup_git_directory_gently(&nongit);
 	if (argc < 2) {
-		error("remote-curl: usage: git remote-curl <remote> [<url>]");
+		error(_("remote-curl: usage: git remote-curl <remote> [<url>]"));
 		return 1;
 	}
 
@@ -1339,6 +1374,13 @@ int cmd_main(int argc, const char **argv
 	string_list_init(&options.deepen_not, 1);
 	string_list_init(&options.push_options, 1);
 
+	/*
+	 * Just report "remote-curl" here (folding all the various aliases
+	 * ("git-remote-http", "git-remote-https", and etc.) here since they
+	 * are all just copies of the same actual executable.
+	 */
+	trace2_cmd_name("remote-curl");
+
 	remote = remote_get(argv[1]);
 
 	if (argc > 2) {
@@ -1354,14 +1396,14 @@ int cmd_main(int argc, const char **argv
 
 		if (strbuf_getline_lf(&buf, stdin) == EOF) {
 			if (ferror(stdin))
-				error("remote-curl: error reading command stream from git");
+				error(_("remote-curl: error reading command stream from git"));
 			return 1;
 		}
 		if (buf.len == 0)
 			break;
 		if (starts_with(buf.buf, "fetch ")) {
 			if (nongit)
-				die("remote-curl: fetch attempted without a local repo");
+				die(_("remote-curl: fetch attempted without a local repo"));
 			parse_fetch(&buf);
 
 		} else if (!strcmp(buf.buf, "list") || starts_with(buf.buf, "list ")) {
@@ -1401,7 +1443,7 @@ int cmd_main(int argc, const char **argv
 			if (!stateless_connect(arg))
 				break;
 		} else {
-			error("remote-curl: unknown command '%s' from git", buf.buf);
+			error(_("remote-curl: unknown command '%s' from git"), buf.buf);
 			return 1;
 		}
 		strbuf_reset(&buf);
diff -pruN 1.2.1+git2.18.0-1/git/remote.h 1.2.3+git2.25.1-1/git/remote.h
--- 1.2.1+git2.18.0-1/git/remote.h	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/remote.h	2020-02-17 04:47:35.000000000 +0000
@@ -1,10 +1,19 @@
 #ifndef REMOTE_H
 #define REMOTE_H
 
+#include "cache.h"
 #include "parse-options.h"
 #include "hashmap.h"
 #include "refspec.h"
 
+/**
+ * The API gives access to the configuration related to remotes. It handles
+ * all three configuration mechanisms historically and currently used by Git,
+ * and presents the information in a uniform fashion. Note that the code also
+ * handles plain URLs without any configuration, giving them just the default
+ * information.
+ */
+
 enum {
 	REMOTE_UNCONFIGURED = 0,
 	REMOTE_CONFIG,
@@ -13,18 +22,24 @@ enum {
 };
 
 struct remote {
-	struct hashmap_entry ent;  /* must be first */
+	struct hashmap_entry ent;
 
+	/* The user's nickname for the remote */
 	const char *name;
+
 	int origin, configured_in_repo;
 
 	const char *foreign_vcs;
 
+	/* An array of all of the url_nr URLs configured for the remote */
 	const char **url;
+
 	int url_nr;
 	int url_alloc;
 
+	/* An array of all of the pushurl_nr push URLs configured for the remote */
 	const char **pushurl;
+
 	int pushurl_nr;
 	int pushurl_alloc;
 
@@ -33,32 +48,47 @@ struct remote {
 	struct refspec fetch;
 
 	/*
+	 * The setting for whether to fetch tags (as a separate rule from the
+	 * configured refspecs);
 	 * -1 to never fetch tags
 	 * 0 to auto-follow tags on heuristic (default)
 	 * 1 to always auto-follow tags
 	 * 2 to always fetch tags
 	 */
 	int fetch_tags;
+
 	int skip_default_update;
 	int mirror;
 	int prune;
 	int prune_tags;
 
+	/**
+	 * The configured helper programs to run on the remote side, for
+	 * Git-native protocols.
+	 */
 	const char *receivepack;
 	const char *uploadpack;
 
-	/*
-	 * for curl remotes only
-	 */
+	/* The proxy to use for curl (http, https, ftp, etc.) URLs. */
 	char *http_proxy;
+
+	/* The method used for authenticating against `http_proxy`. */
 	char *http_proxy_authmethod;
 };
 
+/**
+ * struct remotes can be found by name with remote_get().
+ * remote_get(NULL) will return the default remote, given the current branch
+ * and configuration.
+ */
 struct remote *remote_get(const char *name);
+
 struct remote *pushremote_get(const char *name);
 int remote_is_configured(struct remote *remote, int in_repo);
 
 typedef int each_remote_fn(struct remote *remote, void *priv);
+
+/* iterate through struct remotes */
 int for_each_remote(each_remote_fn fn, void *priv);
 
 int remote_has_url(struct remote *remote, const char *url);
@@ -73,6 +103,7 @@ struct ref {
 		force:1,
 		forced_update:1,
 		expect_old_sha1:1,
+		exact_oid:1,
 		deletion:1;
 
 	enum {
@@ -117,39 +148,40 @@ struct ref {
 #define REF_HEADS	(1u << 1)
 #define REF_TAGS	(1u << 2)
 
-extern struct ref *find_ref_by_name(const struct ref *list, const char *name);
+struct ref *find_ref_by_name(const struct ref *list, const char *name);
 
 struct ref *alloc_ref(const char *name);
 struct ref *copy_ref(const struct ref *ref);
 struct ref *copy_ref_list(const struct ref *ref);
 void sort_ref_list(struct ref **, int (*cmp)(const void *, const void *));
-extern int count_refspec_match(const char *, struct ref *refs, struct ref **matched_ref);
+int count_refspec_match(const char *, struct ref *refs, struct ref **matched_ref);
 int ref_compare_name(const void *, const void *);
 
 int check_ref_type(const struct ref *ref, int flags);
 
 /*
- * Frees the entire list and peers of elements.
+ * Free a single ref and its peer, or an entire list of refs and their peers,
+ * respectively.
  */
+void free_one_ref(struct ref *ref);
 void free_refs(struct ref *ref);
 
 struct oid_array;
 struct packet_reader;
 struct argv_array;
 struct string_list;
-extern struct ref **get_remote_heads(struct packet_reader *reader,
-				     struct ref **list, unsigned int flags,
-				     struct oid_array *extra_have,
-				     struct oid_array *shallow_points);
+struct ref **get_remote_heads(struct packet_reader *reader,
+			      struct ref **list, unsigned int flags,
+			      struct oid_array *extra_have,
+			      struct oid_array *shallow_points);
 
 /* Used for protocol v2 in order to retrieve refs from a remote */
-extern struct ref **get_remote_refs(int fd_out, struct packet_reader *reader,
-				    struct ref **list, int for_push,
-				    const struct argv_array *ref_prefixes,
-				    const struct string_list *server_options);
+struct ref **get_remote_refs(int fd_out, struct packet_reader *reader,
+			     struct ref **list, int for_push,
+			     const struct argv_array *ref_prefixes,
+			     const struct string_list *server_options);
 
 int resolve_remote_symref(struct ref *ref, struct ref *list);
-int ref_newer(const struct object_id *new_oid, const struct object_id *old_oid);
 
 /*
  * Remove and free all but the first of any entries in the input list
@@ -191,16 +223,36 @@ struct ref *get_remote_ref(const struct
  */
 int remote_find_tracking(struct remote *remote, struct refspec_item *refspec);
 
+/**
+ * struct branch holds the configuration for a branch. It can be looked up with
+ * branch_get(name) for "refs/heads/{name}", or with branch_get(NULL) for HEAD.
+ */
 struct branch {
+
+	/* The short name of the branch. */
 	const char *name;
+
+	/* The full path for the branch ref. */
 	const char *refname;
 
+	/* The name of the remote listed in the configuration. */
 	const char *remote_name;
+
 	const char *pushremote_name;
 
+	/* An array of the "merge" lines in the configuration. */
 	const char **merge_name;
+
+	/**
+	 * An array of the struct refspecs used for the merge lines. That is,
+	 * merge[i]->dst is a local tracking ref which should be merged into this
+	 * branch by default.
+	 */
 	struct refspec_item **merge;
+
+	/* The number of merge configurations */
 	int merge_nr;
+
 	int merge_alloc;
 
 	const char *push_tracking_ref;
@@ -212,7 +264,9 @@ const char *pushremote_for_branch(struct
 const char *remote_ref_for_branch(struct branch *branch, int for_push,
 				  int *explicit);
 
+/* returns true if the given branch has merge configuration given. */
 int branch_has_merge_config(struct branch *branch);
+
 int branch_merge_matches(struct branch *, int n, const char *);
 
 /**
@@ -252,7 +306,8 @@ enum ahead_behind_flags {
 
 /* Reporting of tracking info */
 int stat_tracking_info(struct branch *branch, int *num_ours, int *num_theirs,
-		       const char **upstream_name, enum ahead_behind_flags abf);
+		       const char **upstream_name, int for_push,
+		       enum ahead_behind_flags abf);
 int format_tracking_info(struct branch *branch, struct strbuf *sb,
 			 enum ahead_behind_flags abf);
 
@@ -286,9 +341,9 @@ struct push_cas_option {
 	int alloc;
 };
 
-extern int parseopt_push_cas_option(const struct option *, const char *arg, int unset);
+int parseopt_push_cas_option(const struct option *, const char *arg, int unset);
 
-extern int is_empty_cas(const struct push_cas_option *);
+int is_empty_cas(const struct push_cas_option *);
 void apply_push_cas(struct push_cas_option *, struct remote *, struct ref *);
 
 #endif
diff -pruN 1.2.1+git2.18.0-1/git/remote-testsvn.c 1.2.3+git2.25.1-1/git/remote-testsvn.c
--- 1.2.1+git2.18.0-1/git/remote-testsvn.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/remote-testsvn.c	2020-02-17 04:47:35.000000000 +0000
@@ -1,6 +1,7 @@
 #include "cache.h"
 #include "refs.h"
 #include "remote.h"
+#include "object-store.h"
 #include "strbuf.h"
 #include "url.h"
 #include "exec-cmd.h"
diff -pruN 1.2.1+git2.18.0-1/git/replace-object.c 1.2.3+git2.25.1-1/git/replace-object.c
--- 1.2.1+git2.18.0-1/git/replace-object.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/replace-object.c	2020-02-17 04:47:35.000000000 +0000
@@ -6,7 +6,8 @@
 #include "repository.h"
 #include "commit.h"
 
-static int register_replace_ref(const char *refname,
+static int register_replace_ref(struct repository *r,
+				const char *refname,
 				const struct object_id *oid,
 				int flag, void *cb_data)
 {
@@ -17,7 +18,7 @@ static int register_replace_ref(const ch
 
 	if (get_oid_hex(hash, &repl_obj->original.oid)) {
 		free(repl_obj);
-		warning("bad replace ref name: %s", refname);
+		warning(_("bad replace ref name: %s"), refname);
 		return 0;
 	}
 
@@ -25,13 +26,13 @@ static int register_replace_ref(const ch
 	oidcpy(&repl_obj->replacement, oid);
 
 	/* Register new object */
-	if (oidmap_put(the_repository->objects->replace_map, repl_obj))
-		die("duplicate replace ref: %s", refname);
+	if (oidmap_put(r->objects->replace_map, repl_obj))
+		die(_("duplicate replace ref: %s"), refname);
 
 	return 0;
 }
 
-static void prepare_replace_object(struct repository *r)
+void prepare_replace_object(struct repository *r)
 {
 	if (r->objects->replace_map)
 		return;
@@ -51,7 +52,7 @@ static void prepare_replace_object(struc
  * replacement object's name (replaced recursively, if necessary).
  * The return value is either oid or a pointer to a
  * permanently-allocated value.  This function always respects replace
- * references, regardless of the value of check_replace_refs.
+ * references, regardless of the value of read_replace_refs.
  */
 const struct object_id *do_lookup_replace_object(struct repository *r,
 						 const struct object_id *oid)
@@ -69,5 +70,5 @@ const struct object_id *do_lookup_replac
 			return cur;
 		cur = &repl_obj->replacement;
 	}
-	die("replace depth too high for object %s", oid_to_hex(oid));
+	die(_("replace depth too high for object %s"), oid_to_hex(oid));
 }
diff -pruN 1.2.1+git2.18.0-1/git/replace-object.h 1.2.3+git2.25.1-1/git/replace-object.h
--- 1.2.1+git2.18.0-1/git/replace-object.h	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/replace-object.h	2020-02-17 04:47:35.000000000 +0000
@@ -10,12 +10,14 @@ struct replace_object {
 	struct object_id replacement;
 };
 
+void prepare_replace_object(struct repository *r);
+
 /*
  * This internal function is only declared here for the benefit of
  * lookup_replace_object().  Please do not call it directly.
  */
-extern const struct object_id *do_lookup_replace_object(struct repository *r,
-							const struct object_id *oid);
+const struct object_id *do_lookup_replace_object(struct repository *r,
+						 const struct object_id *oid);
 
 /*
  * If object sha1 should be replaced, return the replacement object's
@@ -26,7 +28,7 @@ extern const struct object_id *do_lookup
 static inline const struct object_id *lookup_replace_object(struct repository *r,
 							    const struct object_id *oid)
 {
-	if (!check_replace_refs ||
+	if (!read_replace_refs ||
 	    (r->objects->replace_map &&
 	     r->objects->replace_map->map.tablesize == 0))
 		return oid;
diff -pruN 1.2.1+git2.18.0-1/git/repo-settings.c 1.2.3+git2.25.1-1/git/repo-settings.c
--- 1.2.1+git2.18.0-1/git/repo-settings.c	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/repo-settings.c	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,68 @@
+#include "cache.h"
+#include "config.h"
+#include "repository.h"
+
+#define UPDATE_DEFAULT_BOOL(s,v) do { if (s == -1) { s = v; } } while(0)
+
+void prepare_repo_settings(struct repository *r)
+{
+	int value;
+	char *strval;
+
+	if (r->settings.initialized)
+		return;
+
+	/* Defaults */
+	memset(&r->settings, -1, sizeof(r->settings));
+
+	if (!repo_config_get_bool(r, "core.commitgraph", &value))
+		r->settings.core_commit_graph = value;
+	if (!repo_config_get_bool(r, "gc.writecommitgraph", &value))
+		r->settings.gc_write_commit_graph = value;
+	UPDATE_DEFAULT_BOOL(r->settings.core_commit_graph, 1);
+	UPDATE_DEFAULT_BOOL(r->settings.gc_write_commit_graph, 1);
+
+	if (!repo_config_get_int(r, "index.version", &value))
+		r->settings.index_version = value;
+	if (!repo_config_get_maybe_bool(r, "core.untrackedcache", &value)) {
+		if (value == 0)
+			r->settings.core_untracked_cache = UNTRACKED_CACHE_REMOVE;
+		else
+			r->settings.core_untracked_cache = UNTRACKED_CACHE_WRITE;
+	} else if (!repo_config_get_string(r, "core.untrackedcache", &strval)) {
+		if (!strcasecmp(strval, "keep"))
+			r->settings.core_untracked_cache = UNTRACKED_CACHE_KEEP;
+
+		free(strval);
+	}
+
+	if (!repo_config_get_string(r, "fetch.negotiationalgorithm", &strval)) {
+		if (!strcasecmp(strval, "skipping"))
+			r->settings.fetch_negotiation_algorithm = FETCH_NEGOTIATION_SKIPPING;
+		else
+			r->settings.fetch_negotiation_algorithm = FETCH_NEGOTIATION_DEFAULT;
+	}
+
+	if (!repo_config_get_bool(r, "pack.usesparse", &value))
+		r->settings.pack_use_sparse = value;
+	if (!repo_config_get_bool(r, "feature.manyfiles", &value) && value) {
+		UPDATE_DEFAULT_BOOL(r->settings.index_version, 4);
+		UPDATE_DEFAULT_BOOL(r->settings.core_untracked_cache, UNTRACKED_CACHE_WRITE);
+	}
+	if (!repo_config_get_bool(r, "fetch.writecommitgraph", &value))
+		r->settings.fetch_write_commit_graph = value;
+	if (!repo_config_get_bool(r, "feature.experimental", &value) && value) {
+		UPDATE_DEFAULT_BOOL(r->settings.pack_use_sparse, 1);
+		UPDATE_DEFAULT_BOOL(r->settings.fetch_negotiation_algorithm, FETCH_NEGOTIATION_SKIPPING);
+		UPDATE_DEFAULT_BOOL(r->settings.fetch_write_commit_graph, 1);
+	}
+	UPDATE_DEFAULT_BOOL(r->settings.fetch_write_commit_graph, 0);
+
+	/* Hack for test programs like test-dump-untracked-cache */
+	if (ignore_untracked_cache_config)
+		r->settings.core_untracked_cache = UNTRACKED_CACHE_KEEP;
+	else
+		UPDATE_DEFAULT_BOOL(r->settings.core_untracked_cache, UNTRACKED_CACHE_KEEP);
+
+	UPDATE_DEFAULT_BOOL(r->settings.fetch_negotiation_algorithm, FETCH_NEGOTIATION_DEFAULT);
+}
diff -pruN 1.2.1+git2.18.0-1/git/repository.c 1.2.3+git2.25.1-1/git/repository.c
--- 1.2.1+git2.18.0-1/git/repository.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/repository.c	2020-02-17 04:47:35.000000000 +0000
@@ -1,12 +1,20 @@
+/*
+ * not really _using_ the compat macros, just make sure the_index
+ * declaration matches the definition in this file.
+ */
+#define USE_THE_INDEX_COMPATIBILITY_MACROS
 #include "cache.h"
 #include "repository.h"
 #include "object-store.h"
 #include "config.h"
+#include "object.h"
+#include "lockfile.h"
 #include "submodule-config.h"
 
 /* The main repository */
 static struct repository the_repo;
 struct repository *the_repository;
+struct index_state the_index;
 
 void initialize_the_repository(void)
 {
@@ -14,6 +22,8 @@ void initialize_the_repository(void)
 
 	the_repo.index = &the_index;
 	the_repo.objects = raw_object_store_new();
+	the_repo.parsed_objects = parsed_object_pool_new();
+
 	repo_set_hash_algo(&the_repo, GIT_HASH_SHA1);
 }
 
@@ -60,8 +70,14 @@ void repo_set_gitdir(struct repository *
 	free(old_gitdir);
 
 	repo_set_commondir(repo, o->commondir);
-	expand_base_dir(&repo->objects->objectdir, o->object_dir,
+
+	if (!repo->objects->odb) {
+		repo->objects->odb = xcalloc(1, sizeof(*repo->objects->odb));
+		repo->objects->odb_tail = &repo->objects->odb->next;
+	}
+	expand_base_dir(&repo->objects->odb->path, o->object_dir,
 			repo->commondir, "objects");
+
 	free(repo->objects->alternate_db);
 	repo->objects->alternate_db = xstrdup_or_null(o->alternate_db);
 	expand_base_dir(&repo->graft_file, o->graft_file,
@@ -110,6 +126,8 @@ out:
 void repo_set_worktree(struct repository *repo, const char *path)
 {
 	repo->worktree = real_pathdup(path, 1);
+
+	trace2_def_repo(repo);
 }
 
 static int read_and_verify_repository_format(struct repository_format *format,
@@ -139,10 +157,11 @@ int repo_init(struct repository *repo,
 	      const char *gitdir,
 	      const char *worktree)
 {
-	struct repository_format format;
+	struct repository_format format = REPOSITORY_FORMAT_INIT;
 	memset(repo, 0, sizeof(*repo));
 
 	repo->objects = raw_object_store_new();
+	repo->parsed_objects = parsed_object_pool_new();
 
 	if (repo_init_gitdir(repo, gitdir))
 		goto error;
@@ -155,6 +174,7 @@ int repo_init(struct repository *repo,
 	if (worktree)
 		repo_set_worktree(repo, worktree);
 
+	clear_repository_format(&format);
 	return 0;
 
 error:
@@ -162,34 +182,27 @@ error:
 	return -1;
 }
 
-/*
- * Initialize 'submodule' as the submodule given by 'path' in parent repository
- * 'superproject'.
- * Return 0 upon success and a non-zero value upon failure.
- */
-int repo_submodule_init(struct repository *submodule,
+int repo_submodule_init(struct repository *subrepo,
 			struct repository *superproject,
-			const char *path)
+			const struct submodule *sub)
 {
-	const struct submodule *sub;
 	struct strbuf gitdir = STRBUF_INIT;
 	struct strbuf worktree = STRBUF_INIT;
 	int ret = 0;
 
-	sub = submodule_from_path(superproject, &null_oid, path);
 	if (!sub) {
 		ret = -1;
 		goto out;
 	}
 
-	strbuf_repo_worktree_path(&gitdir, superproject, "%s/.git", path);
-	strbuf_repo_worktree_path(&worktree, superproject, "%s", path);
+	strbuf_repo_worktree_path(&gitdir, superproject, "%s/.git", sub->path);
+	strbuf_repo_worktree_path(&worktree, superproject, "%s", sub->path);
 
-	if (repo_init(submodule, gitdir.buf, worktree.buf)) {
+	if (repo_init(subrepo, gitdir.buf, worktree.buf)) {
 		/*
-		 * If initilization fails then it may be due to the submodule
+		 * If initialization fails then it may be due to the submodule
 		 * not being populated in the superproject's worktree.  Instead
-		 * we can try to initilize the submodule by finding it's gitdir
+		 * we can try to initialize the submodule by finding it's gitdir
 		 * in the superproject's 'modules' directory.  In this case the
 		 * submodule would not have a worktree.
 		 */
@@ -197,16 +210,16 @@ int repo_submodule_init(struct repositor
 		strbuf_repo_git_path(&gitdir, superproject,
 				     "modules/%s", sub->name);
 
-		if (repo_init(submodule, gitdir.buf, NULL)) {
+		if (repo_init(subrepo, gitdir.buf, NULL)) {
 			ret = -1;
 			goto out;
 		}
 	}
 
-	submodule->submodule_prefix = xstrfmt("%s%s/",
-					      superproject->submodule_prefix ?
-					      superproject->submodule_prefix :
-					      "", path);
+	subrepo->submodule_prefix = xstrfmt("%s%s/",
+					    superproject->submodule_prefix ?
+					    superproject->submodule_prefix :
+					    "", sub->path);
 
 out:
 	strbuf_release(&gitdir);
@@ -226,6 +239,9 @@ void repo_clear(struct repository *repo)
 	raw_object_store_clear(repo->objects);
 	FREE_AND_NULL(repo->objects);
 
+	parsed_object_pool_clear(repo->parsed_objects);
+	FREE_AND_NULL(repo->parsed_objects);
+
 	if (repo->config) {
 		git_configset_clear(repo->config);
 		FREE_AND_NULL(repo->config);
@@ -250,3 +266,12 @@ int repo_read_index(struct repository *r
 
 	return read_index_from(repo->index, repo->index_file, repo->gitdir);
 }
+
+int repo_hold_locked_index(struct repository *repo,
+			   struct lock_file *lf,
+			   int flags)
+{
+	if (!repo->index_file)
+		BUG("the repo hasn't been setup");
+	return hold_lock_file_for_update(lf, repo->index_file, flags);
+}
diff -pruN 1.2.1+git2.18.0-1/git/repository.h 1.2.3+git2.25.1-1/git/repository.h
--- 1.2.1+git2.18.0-1/git/repository.h	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/repository.h	2020-02-17 04:47:35.000000000 +0000
@@ -1,12 +1,44 @@
 #ifndef REPOSITORY_H
 #define REPOSITORY_H
 
+#include "path.h"
+
 struct config_set;
 struct git_hash_algo;
 struct index_state;
+struct lock_file;
+struct pathspec;
 struct raw_object_store;
 struct submodule_cache;
 
+enum untracked_cache_setting {
+	UNTRACKED_CACHE_UNSET = -1,
+	UNTRACKED_CACHE_REMOVE = 0,
+	UNTRACKED_CACHE_KEEP = 1,
+	UNTRACKED_CACHE_WRITE = 2
+};
+
+enum fetch_negotiation_setting {
+	FETCH_NEGOTIATION_UNSET = -1,
+	FETCH_NEGOTIATION_NONE = 0,
+	FETCH_NEGOTIATION_DEFAULT = 1,
+	FETCH_NEGOTIATION_SKIPPING = 2,
+};
+
+struct repo_settings {
+	int initialized;
+
+	int core_commit_graph;
+	int gc_write_commit_graph;
+	int fetch_write_commit_graph;
+
+	int index_version;
+	enum untracked_cache_setting core_untracked_cache;
+
+	int pack_use_sparse;
+	enum fetch_negotiation_setting fetch_negotiation_algorithm;
+};
+
 struct repository {
 	/* Environment */
 	/*
@@ -26,10 +58,24 @@ struct repository {
 	 */
 	struct raw_object_store *objects;
 
+	/*
+	 * All objects in this repository that have been parsed. This structure
+	 * owns all objects it references, so users of "struct object *"
+	 * generally do not need to free them; instead, when a repository is no
+	 * longer used, call parsed_object_pool_clear() on this structure, which
+	 * is called by the repositories repo_clear on its desconstruction.
+	 */
+	struct parsed_object_pool *parsed_objects;
+
 	/* The store in which the refs are held. */
 	struct ref_store *refs;
 
 	/*
+	 * Contains path to often used file names.
+	 */
+	struct path_cache cached_paths;
+
+	/*
 	 * Path to the repository's graft file.
 	 * Cannot be NULL after initialization.
 	 */
@@ -54,6 +100,8 @@ struct repository {
 	 */
 	char *submodule_prefix;
 
+	struct repo_settings settings;
+
 	/* Subsystems */
 	/*
 	 * Repository's config which contains key-value pairs from the usual
@@ -74,6 +122,12 @@ struct repository {
 	/* Repository's current hash algorithm, as serialized on disk. */
 	const struct git_hash_algo *hash_algo;
 
+	/* A unique-id for tracing purposes. */
+	int trace2_repo_id;
+
+	/* True if commit-graph has been disabled within this process. */
+	int commit_graph_disabled;
+
 	/* Configurations */
 
 	/* Indicate if a repository has a different 'commondir' from 'gitdir' */
@@ -94,28 +148,48 @@ struct set_gitdir_args {
 	const char *alternate_db;
 };
 
-extern void repo_set_gitdir(struct repository *repo,
-			    const char *root,
-			    const struct set_gitdir_args *extra_args);
-extern void repo_set_worktree(struct repository *repo, const char *path);
-extern void repo_set_hash_algo(struct repository *repo, int algo);
-extern void initialize_the_repository(void);
-extern int repo_init(struct repository *r,
-		     const char *gitdir,
-		     const char *worktree);
-extern int repo_submodule_init(struct repository *submodule,
-			       struct repository *superproject,
-			       const char *path);
-extern void repo_clear(struct repository *repo);
+void repo_set_gitdir(struct repository *repo, const char *root,
+		     const struct set_gitdir_args *extra_args);
+void repo_set_worktree(struct repository *repo, const char *path);
+void repo_set_hash_algo(struct repository *repo, int algo);
+void initialize_the_repository(void);
+int repo_init(struct repository *r, const char *gitdir, const char *worktree);
+
+/*
+ * Initialize the repository 'subrepo' as the submodule given by the
+ * struct submodule 'sub' in parent repository 'superproject'.
+ * Return 0 upon success and a non-zero value upon failure, which may happen
+ * if the submodule is not found, or 'sub' is NULL.
+ */
+struct submodule;
+int repo_submodule_init(struct repository *subrepo,
+			struct repository *superproject,
+			const struct submodule *sub);
+void repo_clear(struct repository *repo);
 
 /*
  * Populates the repository's index from its index_file, an index struct will
  * be allocated if needed.
  *
  * Return the number of index entries in the populated index or a value less
- * than zero if an error occured.  If the repository's index has already been
+ * than zero if an error occurred.  If the repository's index has already been
  * populated then the number of entries will simply be returned.
  */
-extern int repo_read_index(struct repository *repo);
+int repo_read_index(struct repository *repo);
+int repo_hold_locked_index(struct repository *repo,
+			   struct lock_file *lf,
+			   int flags);
+
+int repo_read_index_preload(struct repository *,
+			    const struct pathspec *pathspec,
+			    unsigned refresh_flags);
+int repo_read_index_unmerged(struct repository *);
+/*
+ * Opportunistically update the index but do not complain if we can't.
+ * The lockfile is always committed or rolled back.
+ */
+void repo_update_index_if_able(struct repository *, struct lock_file *);
+
+void prepare_repo_settings(struct repository *r);
 
 #endif /* REPOSITORY_H */
diff -pruN 1.2.1+git2.18.0-1/git/rerere.c 1.2.3+git2.25.1-1/git/rerere.c
--- 1.2.1+git2.18.0-1/git/rerere.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/rerere.c	2020-02-17 04:47:35.000000000 +0000
@@ -9,6 +9,7 @@
 #include "ll-merge.h"
 #include "attr.h"
 #include "pathspec.h"
+#include "object-store.h"
 #include "sha1-lookup.h"
 
 #define RESOLVED 0
@@ -28,7 +29,7 @@ static int rerere_dir_alloc;
 #define RR_HAS_POSTIMAGE 1
 #define RR_HAS_PREIMAGE 2
 static struct rerere_dir {
-	unsigned char sha1[20];
+	unsigned char hash[GIT_MAX_HEXSZ];
 	int status_alloc, status_nr;
 	unsigned char *status;
 } **rerere_dir;
@@ -51,7 +52,7 @@ static void free_rerere_id(struct string
 
 static const char *rerere_id_hex(const struct rerere_id *id)
 {
-	return sha1_to_hex(id->collection->sha1);
+	return hash_to_hex(id->collection->hash);
 }
 
 static void fit_variant(struct rerere_dir *rr_dir, int variant)
@@ -114,7 +115,7 @@ static int is_rr_file(const char *name,
 static void scan_rerere_dir(struct rerere_dir *rr_dir)
 {
 	struct dirent *de;
-	DIR *dir = opendir(git_path("rr-cache/%s", sha1_to_hex(rr_dir->sha1)));
+	DIR *dir = opendir(git_path("rr-cache/%s", hash_to_hex(rr_dir->hash)));
 
 	if (!dir)
 		return;
@@ -132,24 +133,24 @@ static void scan_rerere_dir(struct rerer
 	closedir(dir);
 }
 
-static const unsigned char *rerere_dir_sha1(size_t i, void *table)
+static const unsigned char *rerere_dir_hash(size_t i, void *table)
 {
 	struct rerere_dir **rr_dir = table;
-	return rr_dir[i]->sha1;
+	return rr_dir[i]->hash;
 }
 
 static struct rerere_dir *find_rerere_dir(const char *hex)
 {
-	unsigned char sha1[20];
+	unsigned char hash[GIT_MAX_RAWSZ];
 	struct rerere_dir *rr_dir;
 	int pos;
 
-	if (get_sha1_hex(hex, sha1))
+	if (get_sha1_hex(hex, hash))
 		return NULL; /* BUG */
-	pos = sha1_pos(sha1, rerere_dir, rerere_dir_nr, rerere_dir_sha1);
+	pos = sha1_pos(hash, rerere_dir, rerere_dir_nr, rerere_dir_hash);
 	if (pos < 0) {
 		rr_dir = xmalloc(sizeof(*rr_dir));
-		hashcpy(rr_dir->sha1, sha1);
+		hashcpy(rr_dir->hash, hash);
 		rr_dir->status = NULL;
 		rr_dir->status_nr = 0;
 		rr_dir->status_alloc = 0;
@@ -185,9 +186,9 @@ static struct rerere_id *new_rerere_id_h
 	return id;
 }
 
-static struct rerere_id *new_rerere_id(unsigned char *sha1)
+static struct rerere_id *new_rerere_id(unsigned char *hash)
 {
-	return new_rerere_id_hex(sha1_to_hex(sha1));
+	return new_rerere_id_hex(hash_to_hex(hash));
 }
 
 /*
@@ -197,35 +198,36 @@ static struct rerere_id *new_rerere_id(u
  * work on (i.e. what is left by the previous invocation of "git
  * rerere" during the current conflict resolution session).
  */
-static void read_rr(struct string_list *rr)
+static void read_rr(struct repository *r, struct string_list *rr)
 {
 	struct strbuf buf = STRBUF_INIT;
-	FILE *in = fopen_or_warn(git_path_merge_rr(), "r");
+	FILE *in = fopen_or_warn(git_path_merge_rr(r), "r");
 
 	if (!in)
 		return;
 	while (!strbuf_getwholeline(&buf, in, '\0')) {
 		char *path;
-		unsigned char sha1[20];
+		unsigned char hash[GIT_MAX_RAWSZ];
 		struct rerere_id *id;
 		int variant;
+		const unsigned hexsz = the_hash_algo->hexsz;
 
 		/* There has to be the hash, tab, path and then NUL */
-		if (buf.len < 42 || get_sha1_hex(buf.buf, sha1))
-			die("corrupt MERGE_RR");
+		if (buf.len < hexsz + 2 || get_sha1_hex(buf.buf, hash))
+			die(_("corrupt MERGE_RR"));
 
-		if (buf.buf[40] != '.') {
+		if (buf.buf[hexsz] != '.') {
 			variant = 0;
-			path = buf.buf + 40;
+			path = buf.buf + hexsz;
 		} else {
 			errno = 0;
-			variant = strtol(buf.buf + 41, &path, 10);
+			variant = strtol(buf.buf + hexsz + 1, &path, 10);
 			if (errno)
-				die("corrupt MERGE_RR");
+				die(_("corrupt MERGE_RR"));
 		}
 		if (*(path++) != '\t')
-			die("corrupt MERGE_RR");
-		buf.buf[40] = '\0';
+			die(_("corrupt MERGE_RR"));
+		buf.buf[hexsz] = '\0';
 		id = new_rerere_id_hex(buf.buf);
 		id->variant = variant;
 		string_list_insert(rr, path)->util = id;
@@ -259,12 +261,12 @@ static int write_rr(struct string_list *
 				    rr->items[i].string, 0);
 
 		if (write_in_full(out_fd, buf.buf, buf.len) < 0)
-			die("unable to write rerere record");
+			die(_("unable to write rerere record"));
 
 		strbuf_release(&buf);
 	}
 	if (commit_lock_file(&write_lock) != 0)
-		die("unable to write rerere record");
+		die(_("unable to write rerere record"));
 	return 0;
 }
 
@@ -302,38 +304,6 @@ static void rerere_io_putstr(const char
 		ferr_puts(str, io->output, &io->wrerror);
 }
 
-/*
- * Write a conflict marker to io->output (if defined).
- */
-static void rerere_io_putconflict(int ch, int size, struct rerere_io *io)
-{
-	char buf[64];
-
-	while (size) {
-		if (size <= sizeof(buf) - 2) {
-			memset(buf, ch, size);
-			buf[size] = '\n';
-			buf[size + 1] = '\0';
-			size = 0;
-		} else {
-			int sz = sizeof(buf) - 1;
-
-			/*
-			 * Make sure we will not write everything out
-			 * in this round by leaving at least 1 byte
-			 * for the next round, giving the next round
-			 * a chance to add the terminating LF.  Yuck.
-			 */
-			if (size <= sz)
-				sz -= (sz - size) + 1;
-			memset(buf, ch, sz);
-			buf[sz] = '\0';
-			size -= sz;
-		}
-		rerere_io_putstr(buf, io);
-	}
-}
-
 static void rerere_io_putmem(const char *mem, size_t sz, struct rerere_io *io)
 {
 	if (io->output)
@@ -384,134 +354,157 @@ static int is_cmarker(char *buf, int mar
 	return isspace(*buf);
 }
 
-/*
- * Read contents a file with conflicts, normalize the conflicts
- * by (1) discarding the common ancestor version in diff3-style,
- * (2) reordering our side and their side so that whichever sorts
- * alphabetically earlier comes before the other one, while
- * computing the "conflict ID", which is just an SHA-1 hash of
- * one side of the conflict, NUL, the other side of the conflict,
- * and NUL concatenated together.
- *
- * Return the number of conflict hunks found.
- *
- * NEEDSWORK: the logic and theory of operation behind this conflict
- * normalization may deserve to be documented somewhere, perhaps in
- * Documentation/technical/rerere.txt.
- */
-static int handle_path(unsigned char *sha1, struct rerere_io *io, int marker_size)
+static void rerere_strbuf_putconflict(struct strbuf *buf, int ch, size_t size)
+{
+	strbuf_addchars(buf, ch, size);
+	strbuf_addch(buf, '\n');
+}
+
+static int handle_conflict(struct strbuf *out, struct rerere_io *io,
+			   int marker_size, git_hash_ctx *ctx)
 {
-	git_SHA_CTX ctx;
-	int hunk_no = 0;
 	enum {
-		RR_CONTEXT = 0, RR_SIDE_1, RR_SIDE_2, RR_ORIGINAL
-	} hunk = RR_CONTEXT;
+		RR_SIDE_1 = 0, RR_SIDE_2, RR_ORIGINAL
+	} hunk = RR_SIDE_1;
 	struct strbuf one = STRBUF_INIT, two = STRBUF_INIT;
-	struct strbuf buf = STRBUF_INIT;
-
-	if (sha1)
-		git_SHA1_Init(&ctx);
+	struct strbuf buf = STRBUF_INIT, conflict = STRBUF_INIT;
+	int has_conflicts = -1;
 
 	while (!io->getline(&buf, io)) {
 		if (is_cmarker(buf.buf, '<', marker_size)) {
-			if (hunk != RR_CONTEXT)
-				goto bad;
-			hunk = RR_SIDE_1;
+			if (handle_conflict(&conflict, io, marker_size, NULL) < 0)
+				break;
+			if (hunk == RR_SIDE_1)
+				strbuf_addbuf(&one, &conflict);
+			else
+				strbuf_addbuf(&two, &conflict);
+			strbuf_release(&conflict);
 		} else if (is_cmarker(buf.buf, '|', marker_size)) {
 			if (hunk != RR_SIDE_1)
-				goto bad;
+				break;
 			hunk = RR_ORIGINAL;
 		} else if (is_cmarker(buf.buf, '=', marker_size)) {
 			if (hunk != RR_SIDE_1 && hunk != RR_ORIGINAL)
-				goto bad;
+				break;
 			hunk = RR_SIDE_2;
 		} else if (is_cmarker(buf.buf, '>', marker_size)) {
 			if (hunk != RR_SIDE_2)
-				goto bad;
+				break;
 			if (strbuf_cmp(&one, &two) > 0)
 				strbuf_swap(&one, &two);
-			hunk_no++;
-			hunk = RR_CONTEXT;
-			rerere_io_putconflict('<', marker_size, io);
-			rerere_io_putmem(one.buf, one.len, io);
-			rerere_io_putconflict('=', marker_size, io);
-			rerere_io_putmem(two.buf, two.len, io);
-			rerere_io_putconflict('>', marker_size, io);
-			if (sha1) {
-				git_SHA1_Update(&ctx, one.buf ? one.buf : "",
-					    one.len + 1);
-				git_SHA1_Update(&ctx, two.buf ? two.buf : "",
-					    two.len + 1);
+			has_conflicts = 1;
+			rerere_strbuf_putconflict(out, '<', marker_size);
+			strbuf_addbuf(out, &one);
+			rerere_strbuf_putconflict(out, '=', marker_size);
+			strbuf_addbuf(out, &two);
+			rerere_strbuf_putconflict(out, '>', marker_size);
+			if (ctx) {
+				the_hash_algo->update_fn(ctx, one.buf ?
+							 one.buf : "",
+							 one.len + 1);
+				the_hash_algo->update_fn(ctx, two.buf ?
+							 two.buf : "",
+							 two.len + 1);
 			}
-			strbuf_reset(&one);
-			strbuf_reset(&two);
+			break;
 		} else if (hunk == RR_SIDE_1)
 			strbuf_addbuf(&one, &buf);
 		else if (hunk == RR_ORIGINAL)
 			; /* discard */
 		else if (hunk == RR_SIDE_2)
 			strbuf_addbuf(&two, &buf);
-		else
-			rerere_io_putstr(buf.buf, io);
-		continue;
-	bad:
-		hunk = 99; /* force error exit */
-		break;
 	}
 	strbuf_release(&one);
 	strbuf_release(&two);
 	strbuf_release(&buf);
 
-	if (sha1)
-		git_SHA1_Final(sha1, &ctx);
-	if (hunk != RR_CONTEXT)
-		return -1;
-	return hunk_no;
+	return has_conflicts;
+}
+
+/*
+ * Read contents a file with conflicts, normalize the conflicts
+ * by (1) discarding the common ancestor version in diff3-style,
+ * (2) reordering our side and their side so that whichever sorts
+ * alphabetically earlier comes before the other one, while
+ * computing the "conflict ID", which is just an SHA-1 hash of
+ * one side of the conflict, NUL, the other side of the conflict,
+ * and NUL concatenated together.
+ *
+ * Return 1 if conflict hunks are found, 0 if there are no conflict
+ * hunks and -1 if an error occurred.
+ */
+static int handle_path(unsigned char *hash, struct rerere_io *io, int marker_size)
+{
+	git_hash_ctx ctx;
+	struct strbuf buf = STRBUF_INIT, out = STRBUF_INIT;
+	int has_conflicts = 0;
+	if (hash)
+		the_hash_algo->init_fn(&ctx);
+
+	while (!io->getline(&buf, io)) {
+		if (is_cmarker(buf.buf, '<', marker_size)) {
+			has_conflicts = handle_conflict(&out, io, marker_size,
+							hash ? &ctx : NULL);
+			if (has_conflicts < 0)
+				break;
+			rerere_io_putmem(out.buf, out.len, io);
+			strbuf_reset(&out);
+		} else
+			rerere_io_putstr(buf.buf, io);
+	}
+	strbuf_release(&buf);
+	strbuf_release(&out);
+
+	if (hash)
+		the_hash_algo->final_fn(hash, &ctx);
+
+	return has_conflicts;
 }
 
 /*
  * Scan the path for conflicts, do the "handle_path()" thing above, and
  * return the number of conflict hunks found.
  */
-static int handle_file(const char *path, unsigned char *sha1, const char *output)
+static int handle_file(struct index_state *istate,
+		       const char *path, unsigned char *hash, const char *output)
 {
-	int hunk_no = 0;
+	int has_conflicts = 0;
 	struct rerere_io_file io;
-	int marker_size = ll_merge_marker_size(path);
+	int marker_size = ll_merge_marker_size(istate, path);
 
 	memset(&io, 0, sizeof(io));
 	io.io.getline = rerere_file_getline;
 	io.input = fopen(path, "r");
 	io.io.wrerror = 0;
 	if (!io.input)
-		return error_errno("Could not open %s", path);
+		return error_errno(_("could not open '%s'"), path);
 
 	if (output) {
 		io.io.output = fopen(output, "w");
 		if (!io.io.output) {
-			error_errno("Could not write %s", output);
+			error_errno(_("could not write '%s'"), output);
 			fclose(io.input);
 			return -1;
 		}
 	}
 
-	hunk_no = handle_path(sha1, (struct rerere_io *)&io, marker_size);
+	has_conflicts = handle_path(hash, (struct rerere_io *)&io, marker_size);
 
 	fclose(io.input);
 	if (io.io.wrerror)
-		error("There were errors while writing %s (%s)",
+		error(_("there were errors while writing '%s' (%s)"),
 		      path, strerror(io.io.wrerror));
 	if (io.io.output && fclose(io.io.output))
-		io.io.wrerror = error_errno("Failed to flush %s", path);
+		io.io.wrerror = error_errno(_("failed to flush '%s'"), path);
 
-	if (hunk_no < 0) {
+	if (has_conflicts < 0) {
 		if (output)
 			unlink_or_warn(output);
-		return error("Could not parse conflict hunks in %s", path);
+		return error(_("could not parse conflict hunks in '%s'"), path);
 	}
 	if (io.io.wrerror)
 		return -1;
-	return hunk_no;
+	return has_conflicts;
 }
 
 /*
@@ -522,9 +515,9 @@ static int handle_file(const char *path,
  * stages we have already looked at in this invocation of this
  * function.
  */
-static int check_one_conflict(int i, int *type)
+static int check_one_conflict(struct index_state *istate, int i, int *type)
 {
-	const struct cache_entry *e = active_cache[i];
+	const struct cache_entry *e = istate->cache[i];
 
 	if (!ce_stage(e)) {
 		*type = RESOLVED;
@@ -532,13 +525,13 @@ static int check_one_conflict(int i, int
 	}
 
 	*type = PUNTED;
-	while (ce_stage(active_cache[i]) == 1)
+	while (i < istate->cache_nr && ce_stage(istate->cache[i]) == 1)
 		i++;
 
 	/* Only handle regular files with both stages #2 and #3 */
-	if (i + 1 < active_nr) {
-		const struct cache_entry *e2 = active_cache[i];
-		const struct cache_entry *e3 = active_cache[i + 1];
+	if (i + 1 < istate->cache_nr) {
+		const struct cache_entry *e2 = istate->cache[i];
+		const struct cache_entry *e3 = istate->cache[i + 1];
 		if (ce_stage(e2) == 2 &&
 		    ce_stage(e3) == 3 &&
 		    ce_same_name(e, e3) &&
@@ -548,7 +541,7 @@ static int check_one_conflict(int i, int
 	}
 
 	/* Skip the entries with the same name */
-	while (i < active_nr && ce_same_name(e, active_cache[i]))
+	while (i < istate->cache_nr && ce_same_name(e, istate->cache[i]))
 		i++;
 	return i;
 }
@@ -564,16 +557,17 @@ static int check_one_conflict(int i, int
  * are identical to the previous round, might want to be handled,
  * though.
  */
-static int find_conflict(struct string_list *conflict)
+static int find_conflict(struct repository *r, struct string_list *conflict)
 {
 	int i;
-	if (read_cache() < 0)
-		return error("Could not read index");
 
-	for (i = 0; i < active_nr;) {
+	if (repo_read_index(r) < 0)
+		return error(_("index file corrupt"));
+
+	for (i = 0; i < r->index->cache_nr;) {
 		int conflict_type;
-		const struct cache_entry *e = active_cache[i];
-		i = check_one_conflict(i, &conflict_type);
+		const struct cache_entry *e = r->index->cache[i];
+		i = check_one_conflict(r->index, i, &conflict_type);
 		if (conflict_type == THREE_STAGED)
 			string_list_insert(conflict, (const char *)e->name);
 	}
@@ -595,18 +589,19 @@ static int find_conflict(struct string_l
  * NEEDSWORK: we may want to fix the caller that implements "rerere
  * remaining" to do this without abusing merge_rr.
  */
-int rerere_remaining(struct string_list *merge_rr)
+int rerere_remaining(struct repository *r, struct string_list *merge_rr)
 {
 	int i;
-	if (setup_rerere(merge_rr, RERERE_READONLY))
+
+	if (setup_rerere(r, merge_rr, RERERE_READONLY))
 		return 0;
-	if (read_cache() < 0)
-		return error("Could not read index");
+	if (repo_read_index(r) < 0)
+		return error(_("index file corrupt"));
 
-	for (i = 0; i < active_nr;) {
+	for (i = 0; i < r->index->cache_nr;) {
 		int conflict_type;
-		const struct cache_entry *e = active_cache[i];
-		i = check_one_conflict(i, &conflict_type);
+		const struct cache_entry *e = r->index->cache[i];
+		i = check_one_conflict(r->index, i, &conflict_type);
 		if (conflict_type == PUNTED)
 			string_list_insert(merge_rr, (const char *)e->name);
 		else if (conflict_type == RESOLVED) {
@@ -626,7 +621,8 @@ int rerere_remaining(struct string_list
  * if that recorded conflict resolves cleanly what we
  * got in the "cur".
  */
-static int try_merge(const struct rerere_id *id, const char *path,
+static int try_merge(struct index_state *istate,
+		     const struct rerere_id *id, const char *path,
 		     mmfile_t *cur, mmbuffer_t *result)
 {
 	int ret;
@@ -640,7 +636,8 @@ static int try_merge(const struct rerere
 		 * A three-way merge. Note that this honors user-customizable
 		 * low-level merge driver settings.
 		 */
-		ret = ll_merge(result, path, &base, NULL, cur, "", &other, "", NULL);
+		ret = ll_merge(result, path, &base, NULL, cur, "", &other, "",
+			       istate, NULL);
 
 	free(base.ptr);
 	free(other.ptr);
@@ -658,7 +655,7 @@ static int try_merge(const struct rerere
  * Returns 0 for successful replay of recorded resolution, or non-zero
  * for failure.
  */
-static int merge(const struct rerere_id *id, const char *path)
+static int merge(struct index_state *istate, const struct rerere_id *id, const char *path)
 {
 	FILE *f;
 	int ret;
@@ -669,13 +666,13 @@ static int merge(const struct rerere_id
 	 * Normalize the conflicts in path and write it out to
 	 * "thisimage" temporary file.
 	 */
-	if ((handle_file(path, NULL, rerere_path(id, "thisimage")) < 0) ||
+	if ((handle_file(istate, path, NULL, rerere_path(id, "thisimage")) < 0) ||
 	    read_mmfile(&cur, rerere_path(id, "thisimage"))) {
 		ret = 1;
 		goto out;
 	}
 
-	ret = try_merge(id, path, &cur, &result);
+	ret = try_merge(istate, id, path, &cur, &result);
 	if (ret)
 		goto out;
 
@@ -684,17 +681,17 @@ static int merge(const struct rerere_id
 	 * Mark that "postimage" was used to help gc.
 	 */
 	if (utime(rerere_path(id, "postimage"), NULL) < 0)
-		warning_errno("failed utime() on %s",
+		warning_errno(_("failed utime() on '%s'"),
 			      rerere_path(id, "postimage"));
 
 	/* Update "path" with the resolution */
 	f = fopen(path, "w");
 	if (!f)
-		return error_errno("Could not open %s", path);
+		return error_errno(_("could not open '%s'"), path);
 	if (fwrite(result.ptr, result.size, 1, f) != 1)
-		error_errno("Could not write %s", path);
+		error_errno(_("could not write '%s'"), path);
 	if (fclose(f))
-		return error_errno("Writing %s failed", path);
+		return error_errno(_("writing '%s' failed"), path);
 
 out:
 	free(cur.ptr);
@@ -703,24 +700,24 @@ out:
 	return ret;
 }
 
-static void update_paths(struct string_list *update)
+static void update_paths(struct repository *r, struct string_list *update)
 {
 	struct lock_file index_lock = LOCK_INIT;
 	int i;
 
-	hold_locked_index(&index_lock, LOCK_DIE_ON_ERROR);
+	repo_hold_locked_index(r, &index_lock, LOCK_DIE_ON_ERROR);
 
 	for (i = 0; i < update->nr; i++) {
 		struct string_list_item *item = &update->items[i];
-		if (add_file_to_cache(item->string, 0))
+		if (add_file_to_index(r->index, item->string, 0))
 			exit(128);
-		fprintf(stderr, "Staged '%s' using previous resolution.\n",
+		fprintf_ln(stderr, _("Staged '%s' using previous resolution."),
 			item->string);
 	}
 
-	if (write_locked_index(&the_index, &index_lock,
+	if (write_locked_index(r->index, &index_lock,
 			       COMMIT_LOCK | SKIP_IF_UNCHANGED))
-		die("Unable to write new index file");
+		die(_("unable to write new index file"));
 }
 
 static void remove_variant(struct rerere_id *id)
@@ -737,7 +734,8 @@ static void remove_variant(struct rerere
  * only have the preimage for that conflict, in which case the result
  * needs to be recorded as a resolution in a postimage file.
  */
-static void do_rerere_one_path(struct string_list_item *rr_item,
+static void do_rerere_one_path(struct index_state *istate,
+			       struct string_list_item *rr_item,
 			       struct string_list *update)
 {
 	const char *path = rr_item->string;
@@ -749,10 +747,10 @@ static void do_rerere_one_path(struct st
 
 	/* Has the user resolved it already? */
 	if (variant >= 0) {
-		if (!handle_file(path, NULL, NULL)) {
+		if (!handle_file(istate, path, NULL, NULL)) {
 			copy_file(rerere_path(id, "postimage"), path, 0666);
 			id->collection->status[variant] |= RR_HAS_POSTIMAGE;
-			fprintf(stderr, "Recorded resolution for '%s'.\n", path);
+			fprintf_ln(stderr, _("Recorded resolution for '%s'."), path);
 			free_rerere_id(rr_item);
 			rr_item->util = NULL;
 			return;
@@ -773,7 +771,7 @@ static void do_rerere_one_path(struct st
 			continue;
 
 		vid.variant = variant;
-		if (merge(&vid, path))
+		if (merge(istate, &vid, path))
 			continue; /* failed to replay */
 
 		/*
@@ -786,9 +784,9 @@ static void do_rerere_one_path(struct st
 		if (rerere_autoupdate)
 			string_list_insert(update, path);
 		else
-			fprintf(stderr,
-				"Resolved '%s' using previous resolution.\n",
-				path);
+			fprintf_ln(stderr,
+				   _("Resolved '%s' using previous resolution."),
+				   path);
 		free_rerere_id(rr_item);
 		rr_item->util = NULL;
 		return;
@@ -798,24 +796,25 @@ static void do_rerere_one_path(struct st
 	assign_variant(id);
 
 	variant = id->variant;
-	handle_file(path, NULL, rerere_path(id, "preimage"));
+	handle_file(istate, path, NULL, rerere_path(id, "preimage"));
 	if (id->collection->status[variant] & RR_HAS_POSTIMAGE) {
 		const char *path = rerere_path(id, "postimage");
 		if (unlink(path))
-			die_errno("cannot unlink stray '%s'", path);
+			die_errno(_("cannot unlink stray '%s'"), path);
 		id->collection->status[variant] &= ~RR_HAS_POSTIMAGE;
 	}
 	id->collection->status[variant] |= RR_HAS_PREIMAGE;
-	fprintf(stderr, "Recorded preimage for '%s'\n", path);
+	fprintf_ln(stderr, _("Recorded preimage for '%s'"), path);
 }
 
-static int do_plain_rerere(struct string_list *rr, int fd)
+static int do_plain_rerere(struct repository *r,
+			   struct string_list *rr, int fd)
 {
 	struct string_list conflict = STRING_LIST_INIT_DUP;
 	struct string_list update = STRING_LIST_INIT_DUP;
 	int i;
 
-	find_conflict(&conflict);
+	find_conflict(r, &conflict);
 
 	/*
 	 * MERGE_RR records paths with conflicts immediately after
@@ -825,23 +824,24 @@ static int do_plain_rerere(struct string
 	 */
 	for (i = 0; i < conflict.nr; i++) {
 		struct rerere_id *id;
-		unsigned char sha1[20];
+		unsigned char hash[GIT_MAX_RAWSZ];
 		const char *path = conflict.items[i].string;
 		int ret;
 
-		if (string_list_has_string(rr, path))
-			continue;
-
 		/*
 		 * Ask handle_file() to scan and assign a
 		 * conflict ID.  No need to write anything out
 		 * yet.
 		 */
-		ret = handle_file(path, sha1, NULL);
+		ret = handle_file(r->index, path, hash, NULL);
+		if (ret != 0 && string_list_has_string(rr, path)) {
+			remove_variant(string_list_lookup(rr, path)->util);
+			string_list_remove(rr, path, 1);
+		}
 		if (ret < 1)
 			continue;
 
-		id = new_rerere_id(sha1);
+		id = new_rerere_id(hash);
 		string_list_insert(rr, path)->util = id;
 
 		/* Ensure that the directory exists. */
@@ -849,10 +849,10 @@ static int do_plain_rerere(struct string
 	}
 
 	for (i = 0; i < rr->nr; i++)
-		do_rerere_one_path(&rr->items[i], &update);
+		do_rerere_one_path(r->index, &rr->items[i], &update);
 
 	if (update.nr)
-		update_paths(&update);
+		update_paths(r, &update);
 
 	return write_rr(rr, fd);
 }
@@ -878,11 +878,11 @@ static int is_rerere_enabled(void)
 		return rr_cache_exists;
 
 	if (!rr_cache_exists && mkdir_in_gitdir(git_path_rr_cache()))
-		die("Could not create directory %s", git_path_rr_cache());
+		die(_("could not create directory '%s'"), git_path_rr_cache());
 	return 1;
 }
 
-int setup_rerere(struct string_list *merge_rr, int flags)
+int setup_rerere(struct repository *r, struct string_list *merge_rr, int flags)
 {
 	int fd;
 
@@ -895,9 +895,10 @@ int setup_rerere(struct string_list *mer
 	if (flags & RERERE_READONLY)
 		fd = 0;
 	else
-		fd = hold_lock_file_for_update(&write_lock, git_path_merge_rr(),
+		fd = hold_lock_file_for_update(&write_lock,
+					       git_path_merge_rr(r),
 					       LOCK_DIE_ON_ERROR);
-	read_rr(merge_rr);
+	read_rr(r, merge_rr);
 	return fd;
 }
 
@@ -906,15 +907,15 @@ int setup_rerere(struct string_list *mer
  * perform mergy operations, possibly leaving conflicted index entries
  * and working tree files.
  */
-int rerere(int flags)
+int repo_rerere(struct repository *r, int flags)
 {
 	struct string_list merge_rr = STRING_LIST_INIT_DUP;
 	int fd, status;
 
-	fd = setup_rerere(&merge_rr, flags);
+	fd = setup_rerere(r, &merge_rr, flags);
 	if (fd < 0)
 		return 0;
-	status = do_plain_rerere(&merge_rr, fd);
+	status = do_plain_rerere(r, &merge_rr, fd);
 	free_rerere_dirs();
 	return status;
 }
@@ -951,29 +952,30 @@ static int rerere_mem_getline(struct str
 	return 0;
 }
 
-static int handle_cache(const char *path, unsigned char *sha1, const char *output)
+static int handle_cache(struct index_state *istate,
+			const char *path, unsigned char *hash, const char *output)
 {
 	mmfile_t mmfile[3] = {{NULL}};
 	mmbuffer_t result = {NULL, 0};
 	const struct cache_entry *ce;
-	int pos, len, i, hunk_no;
+	int pos, len, i, has_conflicts;
 	struct rerere_io_mem io;
-	int marker_size = ll_merge_marker_size(path);
+	int marker_size = ll_merge_marker_size(istate, path);
 
 	/*
 	 * Reproduce the conflicted merge in-core
 	 */
 	len = strlen(path);
-	pos = cache_name_pos(path, len);
+	pos = index_name_pos(istate, path, len);
 	if (0 <= pos)
 		return -1;
 	pos = -pos - 1;
 
-	while (pos < active_nr) {
+	while (pos < istate->cache_nr) {
 		enum object_type type;
 		unsigned long size;
 
-		ce = active_cache[pos++];
+		ce = istate->cache[pos++];
 		if (ce_namelen(ce) != len || memcmp(ce->name, path, len))
 			break;
 		i = ce_stage(ce) - 1;
@@ -993,7 +995,8 @@ static int handle_cache(const char *path
 	 */
 	ll_merge(&result, path, &mmfile[0], NULL,
 		 &mmfile[1], "ours",
-		 &mmfile[2], "theirs", NULL);
+		 &mmfile[2], "theirs",
+		 istate, NULL);
 	for (i = 0; i < 3; i++)
 		free(mmfile[i].ptr);
 
@@ -1010,18 +1013,20 @@ static int handle_cache(const char *path
 	 * Grab the conflict ID and optionally write the original
 	 * contents with conflict markers out.
 	 */
-	hunk_no = handle_path(sha1, (struct rerere_io *)&io, marker_size);
+	has_conflicts = handle_path(hash, (struct rerere_io *)&io, marker_size);
 	strbuf_release(&io.input);
 	if (io.io.output)
 		fclose(io.io.output);
-	return hunk_no;
+	return has_conflicts;
 }
 
-static int rerere_forget_one_path(const char *path, struct string_list *rr)
+static int rerere_forget_one_path(struct index_state *istate,
+				  const char *path,
+				  struct string_list *rr)
 {
 	const char *filename;
 	struct rerere_id *id;
-	unsigned char sha1[20];
+	unsigned char hash[GIT_MAX_RAWSZ];
 	int ret;
 	struct string_list_item *item;
 
@@ -1029,12 +1034,12 @@ static int rerere_forget_one_path(const
 	 * Recreate the original conflict from the stages in the
 	 * index and compute the conflict ID
 	 */
-	ret = handle_cache(path, sha1, NULL);
+	ret = handle_cache(istate, path, hash, NULL);
 	if (ret < 1)
-		return error("Could not parse conflict hunks in '%s'", path);
+		return error(_("could not parse conflict hunks in '%s'"), path);
 
 	/* Nuke the recorded resolution for the conflict */
-	id = new_rerere_id(sha1);
+	id = new_rerere_id(hash);
 
 	for (id->variant = 0;
 	     id->variant < id->collection->status_nr;
@@ -1046,13 +1051,13 @@ static int rerere_forget_one_path(const
 		if (!has_rerere_resolution(id))
 			continue;
 
-		handle_cache(path, sha1, rerere_path(id, "thisimage"));
+		handle_cache(istate, path, hash, rerere_path(id, "thisimage"));
 		if (read_mmfile(&cur, rerere_path(id, "thisimage"))) {
 			free(cur.ptr);
-			error("Failed to update conflicted state in '%s'", path);
+			error(_("failed to update conflicted state in '%s'"), path);
 			goto fail_exit;
 		}
-		cleanly_resolved = !try_merge(id, path, &cur, &result);
+		cleanly_resolved = !try_merge(istate, id, path, &cur, &result);
 		free(result.ptr);
 		free(cur.ptr);
 		if (cleanly_resolved)
@@ -1060,16 +1065,16 @@ static int rerere_forget_one_path(const
 	}
 
 	if (id->collection->status_nr <= id->variant) {
-		error("no remembered resolution for '%s'", path);
+		error(_("no remembered resolution for '%s'"), path);
 		goto fail_exit;
 	}
 
 	filename = rerere_path(id, "postimage");
 	if (unlink(filename)) {
 		if (errno == ENOENT)
-			error("no remembered resolution for %s", path);
+			error(_("no remembered resolution for '%s'"), path);
 		else
-			error_errno("cannot unlink %s", filename);
+			error_errno(_("cannot unlink '%s'"), filename);
 		goto fail_exit;
 	}
 
@@ -1078,8 +1083,8 @@ static int rerere_forget_one_path(const
 	 * conflict in the working tree, run us again to record
 	 * the postimage.
 	 */
-	handle_cache(path, sha1, rerere_path(id, "preimage"));
-	fprintf(stderr, "Updated preimage for '%s'\n", path);
+	handle_cache(istate, path, hash, rerere_path(id, "preimage"));
+	fprintf_ln(stderr, _("Updated preimage for '%s'"), path);
 
 	/*
 	 * And remember that we can record resolution for this
@@ -1088,7 +1093,7 @@ static int rerere_forget_one_path(const
 	item = string_list_insert(rr, path);
 	free_rerere_id(item);
 	item->util = id;
-	fprintf(stderr, "Forgot resolution for %s\n", path);
+	fprintf(stderr, _("Forgot resolution for '%s'\n"), path);
 	return 0;
 
 fail_exit:
@@ -1096,16 +1101,16 @@ fail_exit:
 	return -1;
 }
 
-int rerere_forget(struct pathspec *pathspec)
+int rerere_forget(struct repository *r, struct pathspec *pathspec)
 {
 	int i, fd;
 	struct string_list conflict = STRING_LIST_INIT_DUP;
 	struct string_list merge_rr = STRING_LIST_INIT_DUP;
 
-	if (read_cache() < 0)
-		return error("Could not read index");
+	if (repo_read_index(r) < 0)
+		return error(_("index file corrupt"));
 
-	fd = setup_rerere(&merge_rr, RERERE_NOAUTOUPDATE);
+	fd = setup_rerere(r, &merge_rr, RERERE_NOAUTOUPDATE);
 	if (fd < 0)
 		return 0;
 
@@ -1114,14 +1119,14 @@ int rerere_forget(struct pathspec *paths
 	 * recover the original conflicted state and then
 	 * find the conflicted paths.
 	 */
-	unmerge_cache(pathspec);
-	find_conflict(&conflict);
+	unmerge_index(r->index, pathspec);
+	find_conflict(r, &conflict);
 	for (i = 0; i < conflict.nr; i++) {
 		struct string_list_item *it = &conflict.items[i];
-		if (!match_pathspec(pathspec, it->string,
+		if (!match_pathspec(r->index, pathspec, it->string,
 				    strlen(it->string), 0, NULL, 0))
 			continue;
-		rerere_forget_one_path(it->string, &merge_rr);
+		rerere_forget_one_path(r->index, it->string, &merge_rr);
 	}
 	return write_rr(&merge_rr, fd);
 }
@@ -1173,7 +1178,7 @@ static void prune_one(struct rerere_id *
 		unlink_rr_item(id);
 }
 
-void rerere_gc(struct string_list *rr)
+void rerere_gc(struct repository *r, struct string_list *rr)
 {
 	struct string_list to_remove = STRING_LIST_INIT_DUP;
 	DIR *dir;
@@ -1183,7 +1188,7 @@ void rerere_gc(struct string_list *rr)
 	timestamp_t cutoff_noresolve = now - 15 * 86400;
 	timestamp_t cutoff_resolve = now - 60 * 86400;
 
-	if (setup_rerere(rr, 0) < 0)
+	if (setup_rerere(r, rr, 0) < 0)
 		return;
 
 	git_config_get_expiry_in_days("gc.rerereresolved", &cutoff_resolve, now);
@@ -1191,7 +1196,7 @@ void rerere_gc(struct string_list *rr)
 	git_config(git_default_config, NULL);
 	dir = opendir(git_path("rr-cache"));
 	if (!dir)
-		die_errno("unable to open rr-cache directory");
+		die_errno(_("unable to open rr-cache directory"));
 	/* Collect stale conflict IDs ... */
 	while ((e = readdir(dir))) {
 		struct rerere_dir *rr_dir;
@@ -1231,11 +1236,11 @@ void rerere_gc(struct string_list *rr)
  *
  * NEEDSWORK: shouldn't we be calling this from "reset --hard"?
  */
-void rerere_clear(struct string_list *merge_rr)
+void rerere_clear(struct repository *r, struct string_list *merge_rr)
 {
 	int i;
 
-	if (setup_rerere(merge_rr, 0) < 0)
+	if (setup_rerere(r, merge_rr, 0) < 0)
 		return;
 
 	for (i = 0; i < merge_rr->nr; i++) {
@@ -1245,6 +1250,6 @@ void rerere_clear(struct string_list *me
 			rmdir(rerere_path(id, NULL));
 		}
 	}
-	unlink_or_warn(git_path_merge_rr());
+	unlink_or_warn(git_path_merge_rr(r));
 	rollback_lock_file(&write_lock);
 }
diff -pruN 1.2.1+git2.18.0-1/git/rerere.h 1.2.3+git2.25.1-1/git/rerere.h
--- 1.2.1+git2.18.0-1/git/rerere.h	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/rerere.h	2020-02-17 04:47:35.000000000 +0000
@@ -4,6 +4,7 @@
 #include "string-list.h"
 
 struct pathspec;
+struct repository;
 
 #define RERERE_AUTOUPDATE   01
 #define RERERE_NOAUTOUPDATE 02
@@ -22,19 +23,22 @@ struct rerere_id {
 	int variant;
 };
 
-extern int setup_rerere(struct string_list *, int);
-extern int rerere(int);
+int setup_rerere(struct repository *,struct string_list *, int);
+#ifndef NO_THE_REPOSITORY_COMPATIBILITY_MACROS
+#define rerere(flags) repo_rerere(the_repository, flags)
+#endif
+int repo_rerere(struct repository *, int);
 /*
  * Given the conflict ID and the name of a "file" used for replaying
  * the recorded resolution (e.g. "preimage", "postimage"), return the
  * path to that filesystem entity.  With "file" specified with NULL,
  * return the path to the directory that houses these files.
  */
-extern const char *rerere_path(const struct rerere_id *, const char *file);
-extern int rerere_forget(struct pathspec *);
-extern int rerere_remaining(struct string_list *);
-extern void rerere_clear(struct string_list *);
-extern void rerere_gc(struct string_list *);
+const char *rerere_path(const struct rerere_id *, const char *file);
+int rerere_forget(struct repository *, struct pathspec *);
+int rerere_remaining(struct repository *, struct string_list *);
+void rerere_clear(struct repository *, struct string_list *);
+void rerere_gc(struct repository *, struct string_list *);
 
 #define OPT_RERERE_AUTOUPDATE(v) OPT_UYN(0, "rerere-autoupdate", (v), \
 	N_("update the index with reused conflict resolution if possible"))
diff -pruN 1.2.1+git2.18.0-1/git/resolve-undo.c 1.2.3+git2.25.1-1/git/resolve-undo.c
--- 1.2.1+git2.18.0-1/git/resolve-undo.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/resolve-undo.c	2020-02-17 04:47:35.000000000 +0000
@@ -146,7 +146,9 @@ int unmerge_index_entry_at(struct index_
 		struct cache_entry *nce;
 		if (!ru->mode[i])
 			continue;
-		nce = make_cache_entry(ru->mode[i], ru->oid[i].hash,
+		nce = make_cache_entry(istate,
+				       ru->mode[i],
+				       &ru->oid[i],
 				       name, i + 1, 0);
 		if (matched)
 			nce->ce_flags |= CE_MATCHED;
@@ -186,7 +188,7 @@ void unmerge_index(struct index_state *i
 
 	for (i = 0; i < istate->cache_nr; i++) {
 		const struct cache_entry *ce = istate->cache[i];
-		if (!ce_path_match(ce, pathspec, NULL))
+		if (!ce_path_match(istate, ce, pathspec, NULL))
 			continue;
 		i = unmerge_index_entry_at(istate, i);
 	}
diff -pruN 1.2.1+git2.18.0-1/git/resolve-undo.h 1.2.3+git2.25.1-1/git/resolve-undo.h
--- 1.2.1+git2.18.0-1/git/resolve-undo.h	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/resolve-undo.h	2020-02-17 04:47:35.000000000 +0000
@@ -1,17 +1,19 @@
 #ifndef RESOLVE_UNDO_H
 #define RESOLVE_UNDO_H
 
+#include "cache.h"
+
 struct resolve_undo_info {
 	unsigned int mode[3];
 	struct object_id oid[3];
 };
 
-extern void record_resolve_undo(struct index_state *, struct cache_entry *);
-extern void resolve_undo_write(struct strbuf *, struct string_list *);
-extern struct string_list *resolve_undo_read(const char *, unsigned long);
-extern void resolve_undo_clear_index(struct index_state *);
-extern int unmerge_index_entry_at(struct index_state *, int);
-extern void unmerge_index(struct index_state *, const struct pathspec *);
-extern void unmerge_marked_index(struct index_state *);
+void record_resolve_undo(struct index_state *, struct cache_entry *);
+void resolve_undo_write(struct strbuf *, struct string_list *);
+struct string_list *resolve_undo_read(const char *, unsigned long);
+void resolve_undo_clear_index(struct index_state *);
+int unmerge_index_entry_at(struct index_state *, int);
+void unmerge_index(struct index_state *, const struct pathspec *);
+void unmerge_marked_index(struct index_state *);
 
 #endif
diff -pruN 1.2.1+git2.18.0-1/git/revision.c 1.2.3+git2.25.1-1/git/revision.c
--- 1.2.1+git2.18.0-1/git/revision.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/revision.c	2020-02-17 04:47:35.000000000 +0000
@@ -1,4 +1,5 @@
 #include "cache.h"
+#include "object-store.h"
 #include "tag.h"
 #include "blob.h"
 #include "tree.h"
@@ -23,12 +24,19 @@
 #include "packfile.h"
 #include "worktree.h"
 #include "argv-array.h"
+#include "commit-reach.h"
+#include "commit-graph.h"
+#include "prio-queue.h"
+#include "hashmap.h"
+#include "utf8.h"
 
 volatile show_early_output_fn_t show_early_output;
 
 static const char *term_bad;
 static const char *term_good;
 
+implement_shared_commit_slab(revision_sources, char *);
+
 void show_object_with_name(FILE *out, struct object *obj, const char *name)
 {
 	const char *p;
@@ -48,7 +56,8 @@ static void mark_blob_uninteresting(stru
 	blob->object.flags |= UNINTERESTING;
 }
 
-static void mark_tree_contents_uninteresting(struct tree *tree)
+static void mark_tree_contents_uninteresting(struct repository *r,
+					     struct tree *tree)
 {
 	struct tree_desc desc;
 	struct name_entry entry;
@@ -60,10 +69,10 @@ static void mark_tree_contents_uninteres
 	while (tree_entry(&desc, &entry)) {
 		switch (object_type(entry.mode)) {
 		case OBJ_TREE:
-			mark_tree_uninteresting(lookup_tree(entry.oid));
+			mark_tree_uninteresting(r, lookup_tree(r, &entry.oid));
 			break;
 		case OBJ_BLOB:
-			mark_blob_uninteresting(lookup_blob(entry.oid));
+			mark_blob_uninteresting(lookup_blob(r, &entry.oid));
 			break;
 		default:
 			/* Subproject commit - not in this repository */
@@ -78,7 +87,7 @@ static void mark_tree_contents_uninteres
 	free_tree_buffer(tree);
 }
 
-void mark_tree_uninteresting(struct tree *tree)
+void mark_tree_uninteresting(struct repository *r, struct tree *tree)
 {
 	struct object *obj;
 
@@ -89,7 +98,153 @@ void mark_tree_uninteresting(struct tree
 	if (obj->flags & UNINTERESTING)
 		return;
 	obj->flags |= UNINTERESTING;
-	mark_tree_contents_uninteresting(tree);
+	mark_tree_contents_uninteresting(r, tree);
+}
+
+struct path_and_oids_entry {
+	struct hashmap_entry ent;
+	char *path;
+	struct oidset trees;
+};
+
+static int path_and_oids_cmp(const void *hashmap_cmp_fn_data,
+			     const struct hashmap_entry *eptr,
+			     const struct hashmap_entry *entry_or_key,
+			     const void *keydata)
+{
+	const struct path_and_oids_entry *e1, *e2;
+
+	e1 = container_of(eptr, const struct path_and_oids_entry, ent);
+	e2 = container_of(entry_or_key, const struct path_and_oids_entry, ent);
+
+	return strcmp(e1->path, e2->path);
+}
+
+static void paths_and_oids_init(struct hashmap *map)
+{
+	hashmap_init(map, path_and_oids_cmp, NULL, 0);
+}
+
+static void paths_and_oids_clear(struct hashmap *map)
+{
+	struct hashmap_iter iter;
+	struct path_and_oids_entry *entry;
+
+	hashmap_for_each_entry(map, &iter, entry, ent /* member name */) {
+		oidset_clear(&entry->trees);
+		free(entry->path);
+	}
+
+	hashmap_free_entries(map, struct path_and_oids_entry, ent);
+}
+
+static void paths_and_oids_insert(struct hashmap *map,
+				  const char *path,
+				  const struct object_id *oid)
+{
+	int hash = strhash(path);
+	struct path_and_oids_entry key;
+	struct path_and_oids_entry *entry;
+
+	hashmap_entry_init(&key.ent, hash);
+
+	/* use a shallow copy for the lookup */
+	key.path = (char *)path;
+	oidset_init(&key.trees, 0);
+
+	entry = hashmap_get_entry(map, &key, ent, NULL);
+	if (!entry) {
+		entry = xcalloc(1, sizeof(struct path_and_oids_entry));
+		hashmap_entry_init(&entry->ent, hash);
+		entry->path = xstrdup(key.path);
+		oidset_init(&entry->trees, 16);
+		hashmap_put(map, &entry->ent);
+	}
+
+	oidset_insert(&entry->trees, oid);
+}
+
+static void add_children_by_path(struct repository *r,
+				 struct tree *tree,
+				 struct hashmap *map)
+{
+	struct tree_desc desc;
+	struct name_entry entry;
+
+	if (!tree)
+		return;
+
+	if (parse_tree_gently(tree, 1) < 0)
+		return;
+
+	init_tree_desc(&desc, tree->buffer, tree->size);
+	while (tree_entry(&desc, &entry)) {
+		switch (object_type(entry.mode)) {
+		case OBJ_TREE:
+			paths_and_oids_insert(map, entry.path, &entry.oid);
+
+			if (tree->object.flags & UNINTERESTING) {
+				struct tree *child = lookup_tree(r, &entry.oid);
+				if (child)
+					child->object.flags |= UNINTERESTING;
+			}
+			break;
+		case OBJ_BLOB:
+			if (tree->object.flags & UNINTERESTING) {
+				struct blob *child = lookup_blob(r, &entry.oid);
+				if (child)
+					child->object.flags |= UNINTERESTING;
+			}
+			break;
+		default:
+			/* Subproject commit - not in this repository */
+			break;
+		}
+	}
+
+	free_tree_buffer(tree);
+}
+
+void mark_trees_uninteresting_sparse(struct repository *r,
+				     struct oidset *trees)
+{
+	unsigned has_interesting = 0, has_uninteresting = 0;
+	struct hashmap map;
+	struct hashmap_iter map_iter;
+	struct path_and_oids_entry *entry;
+	struct object_id *oid;
+	struct oidset_iter iter;
+
+	oidset_iter_init(trees, &iter);
+	while ((!has_interesting || !has_uninteresting) &&
+	       (oid = oidset_iter_next(&iter))) {
+		struct tree *tree = lookup_tree(r, oid);
+
+		if (!tree)
+			continue;
+
+		if (tree->object.flags & UNINTERESTING)
+			has_uninteresting = 1;
+		else
+			has_interesting = 1;
+	}
+
+	/* Do not walk unless we have both types of trees. */
+	if (!has_uninteresting || !has_interesting)
+		return;
+
+	paths_and_oids_init(&map);
+
+	oidset_iter_init(trees, &iter);
+	while ((oid = oidset_iter_next(&iter))) {
+		struct tree *tree = lookup_tree(r, oid);
+		add_children_by_path(r, tree, &map);
+	}
+
+	hashmap_for_each_entry(&map, &map_iter, entry, ent /* member name */)
+		mark_trees_uninteresting_sparse(r, &entry->trees);
+
+	paths_and_oids_clear(&map);
 }
 
 struct commit_stack {
@@ -194,7 +349,7 @@ void add_head_to_pending(struct rev_info
 	struct object *obj;
 	if (get_oid("HEAD", &oid))
 		return;
-	obj = parse_object(&oid);
+	obj = parse_object(revs->repo, &oid);
 	if (!obj)
 		return;
 	add_pending_object(revs, obj, "HEAD");
@@ -206,7 +361,20 @@ static struct object *get_reference(stru
 {
 	struct object *object;
 
-	object = parse_object(oid);
+	/*
+	 * If the repository has commit graphs, repo_parse_commit() avoids
+	 * reading the object buffer, so use it whenever possible.
+	 */
+	if (oid_object_info(revs->repo, oid, NULL) == OBJ_COMMIT) {
+		struct commit *c = lookup_commit(revs->repo, oid);
+		if (!repo_parse_commit(revs->repo, c))
+			object = (struct object *) c;
+		else
+			object = NULL;
+	} else {
+		object = parse_object(revs->repo, oid);
+	}
+
 	if (!object) {
 		if (revs->ignore_missing)
 			return object;
@@ -241,12 +409,13 @@ static struct commit *handle_commit(stru
 		struct tag *tag = (struct tag *) object;
 		if (revs->tag_objects && !(flags & UNINTERESTING))
 			add_pending_object(revs, object, tag->tag);
-		if (!tag->tagged)
-			die("bad tag");
-		object = parse_object(&tag->tagged->oid);
+		object = parse_object(revs->repo, get_tagged_oid(tag));
 		if (!object) {
 			if (revs->ignore_missing_links || (flags & UNINTERESTING))
 				return NULL;
+			if (revs->exclude_promisor_objects &&
+			    is_promisor_object(&tag->tagged->oid))
+				return NULL;
 			die("bad object %s", oid_to_hex(&tag->tagged->oid));
 		}
 		object->flags |= flags;
@@ -265,14 +434,21 @@ static struct commit *handle_commit(stru
 	 */
 	if (object->type == OBJ_COMMIT) {
 		struct commit *commit = (struct commit *)object;
+
 		if (parse_commit(commit) < 0)
 			die("unable to parse commit %s", name);
 		if (flags & UNINTERESTING) {
 			mark_parents_uninteresting(commit);
-			revs->limited = 1;
+
+			if (!revs->topo_order || !generation_numbers_enabled(the_repository))
+				revs->limited = 1;
+		}
+		if (revs->sources) {
+			char **slot = revision_sources_at(revs->sources, commit);
+
+			if (!*slot)
+				*slot = xstrdup(name);
 		}
-		if (revs->show_source && !commit->util)
-			commit->util = xstrdup(name);
 		return commit;
 	}
 
@@ -285,7 +461,7 @@ static struct commit *handle_commit(stru
 		if (!revs->tree_objects)
 			return NULL;
 		if (flags & UNINTERESTING) {
-			mark_tree_contents_uninteresting(tree);
+			mark_tree_contents_uninteresting(revs->repo, tree);
 			return NULL;
 		}
 		add_pending_object_with_path(revs, object, name, mode, path);
@@ -740,26 +916,11 @@ static void try_to_simplify_commit(struc
 		commit->object.flags |= TREESAME;
 }
 
-static void commit_list_insert_by_date_cached(struct commit *p, struct commit_list **head,
-		    struct commit_list *cached_base, struct commit_list **cache)
-{
-	struct commit_list *new_entry;
-
-	if (cached_base && p->date < cached_base->item->date)
-		new_entry = commit_list_insert_by_date(p, &cached_base->next);
-	else
-		new_entry = commit_list_insert_by_date(p, head);
-
-	if (cache && (!*cache || p->date < (*cache)->item->date))
-		*cache = new_entry;
-}
-
-static int add_parents_to_list(struct rev_info *revs, struct commit *commit,
-		    struct commit_list **list, struct commit_list **cache_ptr)
+static int process_parents(struct rev_info *revs, struct commit *commit,
+			   struct commit_list **list, struct prio_queue *queue)
 {
 	struct commit_list *parent = commit->parents;
 	unsigned left_flag;
-	struct commit_list *cached_base = cache_ptr ? *cache_ptr : NULL;
 
 	if (commit->object.flags & ADDED)
 		return 0;
@@ -794,7 +955,10 @@ static int add_parents_to_list(struct re
 			if (p->object.flags & SEEN)
 				continue;
 			p->object.flags |= SEEN;
-			commit_list_insert_by_date_cached(p, list, cached_base, cache_ptr);
+			if (list)
+				commit_list_insert_by_date(p, list);
+			if (queue)
+				prio_queue_put(queue, p);
 		}
 		return 0;
 	}
@@ -824,12 +988,19 @@ static int add_parents_to_list(struct re
 			}
 			return -1;
 		}
-		if (revs->show_source && !p->util)
-			p->util = commit->util;
+		if (revs->sources) {
+			char **slot = revision_sources_at(revs->sources, p);
+
+			if (!*slot)
+				*slot = *revision_sources_at(revs->sources, commit);
+		}
 		p->object.flags |= left_flag;
 		if (!(p->object.flags & SEEN)) {
 			p->object.flags |= SEEN;
-			commit_list_insert_by_date_cached(p, list, cached_base, cache_ptr);
+			if (list)
+				commit_list_insert_by_date(p, list);
+			if (queue)
+				prio_queue_put(queue, p);
 		}
 		if (revs->first_parent_only)
 			break;
@@ -861,7 +1032,7 @@ static void cherry_pick_list(struct comm
 		return;
 
 	left_first = left_count < right_count;
-	init_patch_ids(&ids);
+	init_patch_ids(revs->repo, &ids);
 	ids.diffopts.pathspec = revs->diffopt.pathspec;
 
 	/* Compute patch-ids for one side */
@@ -1073,7 +1244,7 @@ static int limit_list(struct rev_info *r
 
 		if (revs->max_age != -1 && (commit->date < revs->max_age))
 			obj->flags |= UNINTERESTING;
-		if (add_parents_to_list(revs, commit, &list, NULL) < 0)
+		if (process_parents(revs, commit, &list, NULL) < 0)
 			return -1;
 		if (obj->flags & UNINTERESTING) {
 			mark_parents_uninteresting(commit);
@@ -1160,7 +1331,7 @@ struct all_refs_cb {
 	int warned_bad_reflog;
 	struct rev_info *all_revs;
 	const char *name_for_errormsg;
-	struct ref_store *refs;
+	struct worktree *wt;
 };
 
 int ref_excluded(struct string_list *ref_excludes, const char *path)
@@ -1197,7 +1368,7 @@ static void init_all_refs_cb(struct all_
 	cb->all_revs = revs;
 	cb->all_flags = flags;
 	revs->rev_input_given = 1;
-	cb->refs = NULL;
+	cb->wt = NULL;
 }
 
 void clear_ref_exclusion(struct string_list **ref_excludes_p)
@@ -1237,7 +1408,7 @@ static void handle_one_reflog_commit(str
 {
 	struct all_refs_cb *cb = cb_data;
 	if (!is_null_oid(oid)) {
-		struct object *o = parse_object(oid);
+		struct object *o = parse_object(cb->all_revs->repo, oid);
 		if (o) {
 			o->flags |= cb->all_flags;
 			/* ??? CMDLINEFLAGS ??? */
@@ -1260,14 +1431,20 @@ static int handle_one_reflog_ent(struct
 	return 0;
 }
 
-static int handle_one_reflog(const char *path, const struct object_id *oid,
+static int handle_one_reflog(const char *refname_in_wt,
+			     const struct object_id *oid,
 			     int flag, void *cb_data)
 {
 	struct all_refs_cb *cb = cb_data;
+	struct strbuf refname = STRBUF_INIT;
+
 	cb->warned_bad_reflog = 0;
-	cb->name_for_errormsg = path;
-	refs_for_each_reflog_ent(cb->refs, path,
+	strbuf_worktree_ref(cb->wt, &refname, refname_in_wt);
+	cb->name_for_errormsg = refname.buf;
+	refs_for_each_reflog_ent(get_main_ref_store(the_repository),
+				 refname.buf,
 				 handle_one_reflog_ent, cb_data);
+	strbuf_release(&refname);
 	return 0;
 }
 
@@ -1282,8 +1459,8 @@ static void add_other_reflogs_to_pending
 		if (wt->is_current)
 			continue;
 
-		cb->refs = get_worktree_ref_store(wt);
-		refs_for_each_reflog(cb->refs,
+		cb->wt = wt;
+		refs_for_each_reflog(get_worktree_ref_store(wt),
 				     handle_one_reflog,
 				     cb);
 	}
@@ -1296,7 +1473,7 @@ void add_reflogs_to_pending(struct rev_i
 
 	cb.all_revs = revs;
 	cb.all_flags = flags;
-	cb.refs = get_main_ref_store(the_repository);
+	cb.wt = NULL;
 	for_each_reflog(handle_one_reflog, &cb);
 
 	if (!revs->single_worktree)
@@ -1304,13 +1481,14 @@ void add_reflogs_to_pending(struct rev_i
 }
 
 static void add_cache_tree(struct cache_tree *it, struct rev_info *revs,
-			   struct strbuf *path)
+			   struct strbuf *path, unsigned int flags)
 {
 	size_t baselen = path->len;
 	int i;
 
 	if (it->entry_count >= 0) {
-		struct tree *tree = lookup_tree(&it->oid);
+		struct tree *tree = lookup_tree(revs->repo, &it->oid);
+		tree->object.flags |= flags;
 		add_pending_object_with_path(revs, &tree->object, "",
 					     040000, path->buf);
 	}
@@ -1318,14 +1496,15 @@ static void add_cache_tree(struct cache_
 	for (i = 0; i < it->subtree_nr; i++) {
 		struct cache_tree_sub *sub = it->down[i];
 		strbuf_addf(path, "%s%s", baselen ? "/" : "", sub->name);
-		add_cache_tree(sub->cache_tree, revs, path);
+		add_cache_tree(sub->cache_tree, revs, path, flags);
 		strbuf_setlen(path, baselen);
 	}
 
 }
 
 static void do_add_index_objects_to_pending(struct rev_info *revs,
-					    struct index_state *istate)
+					    struct index_state *istate,
+					    unsigned int flags)
 {
 	int i;
 
@@ -1336,16 +1515,17 @@ static void do_add_index_objects_to_pend
 		if (S_ISGITLINK(ce->ce_mode))
 			continue;
 
-		blob = lookup_blob(&ce->oid);
+		blob = lookup_blob(revs->repo, &ce->oid);
 		if (!blob)
 			die("unable to add index blob to traversal");
+		blob->object.flags |= flags;
 		add_pending_object_with_path(revs, &blob->object, "",
 					     ce->ce_mode, ce->name);
 	}
 
 	if (istate->cache_tree) {
 		struct strbuf path = STRBUF_INIT;
-		add_cache_tree(istate->cache_tree, revs, &path);
+		add_cache_tree(istate->cache_tree, revs, &path, flags);
 		strbuf_release(&path);
 	}
 }
@@ -1354,8 +1534,8 @@ void add_index_objects_to_pending(struct
 {
 	struct worktree **worktrees, **p;
 
-	read_cache();
-	do_add_index_objects_to_pending(revs, &the_index);
+	repo_read_index(revs->repo);
+	do_add_index_objects_to_pending(revs, revs->repo->index, flags);
 
 	if (revs->single_worktree)
 		return;
@@ -1371,12 +1551,38 @@ void add_index_objects_to_pending(struct
 		if (read_index_from(&istate,
 				    worktree_git_path(wt, "index"),
 				    get_worktree_git_dir(wt)) > 0)
-			do_add_index_objects_to_pending(revs, &istate);
+			do_add_index_objects_to_pending(revs, &istate, flags);
 		discard_index(&istate);
 	}
 	free_worktrees(worktrees);
 }
 
+struct add_alternate_refs_data {
+	struct rev_info *revs;
+	unsigned int flags;
+};
+
+static void add_one_alternate_ref(const struct object_id *oid,
+				  void *vdata)
+{
+	const char *name = ".alternate";
+	struct add_alternate_refs_data *data = vdata;
+	struct object *obj;
+
+	obj = get_reference(data->revs, name, oid, data->flags);
+	add_rev_cmdline(data->revs, obj, name, REV_CMD_REV, data->flags);
+	add_pending_object(data->revs, obj, name);
+}
+
+static void add_alternate_refs_to_pending(struct rev_info *revs,
+					  unsigned int flags)
+{
+	struct add_alternate_refs_data data;
+	data.revs = revs;
+	data.flags = flags;
+	for_each_alternate_ref(add_one_alternate_ref, &data);
+}
+
 static int add_parents_only(struct rev_info *revs, const char *arg_, int flags,
 			    int exclude_parent)
 {
@@ -1423,13 +1629,17 @@ static int add_parents_only(struct rev_i
 	return 1;
 }
 
-void init_revisions(struct rev_info *revs, const char *prefix)
+void repo_init_revisions(struct repository *r,
+			 struct rev_info *revs,
+			 const char *prefix)
 {
 	memset(revs, 0, sizeof(*revs));
 
+	revs->repo = r;
 	revs->abbrev = DEFAULT_ABBREV;
 	revs->ignore_merges = 1;
 	revs->simplify_history = 1;
+	revs->pruning.repo = r;
 	revs->pruning.flags.recursive = 1;
 	revs->pruning.flags.quick = 1;
 	revs->pruning.add_remove = file_add_remove;
@@ -1448,22 +1658,22 @@ void init_revisions(struct rev_info *rev
 	revs->commit_format = CMIT_FMT_DEFAULT;
 	revs->expand_tabs_in_log_default = 8;
 
-	init_grep_defaults();
-	grep_init(&revs->grep_filter, prefix);
+	init_grep_defaults(revs->repo);
+	grep_init(&revs->grep_filter, revs->repo, prefix);
 	revs->grep_filter.status_only = 1;
 
-	diff_setup(&revs->diffopt);
+	repo_diff_setup(revs->repo, &revs->diffopt);
 	if (prefix && !revs->diffopt.prefix) {
 		revs->diffopt.prefix = prefix;
 		revs->diffopt.prefix_length = strlen(prefix);
 	}
 
-	revs->notes_opt.use_default_notes = -1;
+	init_display_notes(&revs->notes_opt);
 }
 
 static void add_pending_commit_list(struct rev_info *revs,
-                                    struct commit_list *commit_list,
-                                    unsigned int flags)
+				    struct commit_list *commit_list,
+				    unsigned int flags)
 {
 	while (commit_list) {
 		struct object *object = &commit_list->item->object;
@@ -1480,6 +1690,7 @@ static void prepare_show_merge(struct re
 	struct object_id oid;
 	const char **prune = NULL;
 	int i, prune_num = 1; /* counting terminating NULL */
+	struct index_state *istate = revs->repo->index;
 
 	if (get_oid("HEAD", &oid))
 		die("--merge without HEAD?");
@@ -1495,20 +1706,20 @@ static void prepare_show_merge(struct re
 	free_commit_list(bases);
 	head->object.flags |= SYMMETRIC_LEFT;
 
-	if (!active_nr)
-		read_cache();
-	for (i = 0; i < active_nr; i++) {
-		const struct cache_entry *ce = active_cache[i];
+	if (!istate->cache_nr)
+		repo_read_index(revs->repo);
+	for (i = 0; i < istate->cache_nr; i++) {
+		const struct cache_entry *ce = istate->cache[i];
 		if (!ce_stage(ce))
 			continue;
-		if (ce_path_match(ce, &revs->prune_data, NULL)) {
+		if (ce_path_match(istate, ce, &revs->prune_data, NULL)) {
 			prune_num++;
 			REALLOC_ARRAY(prune, prune_num);
 			prune[prune_num-2] = ce->name;
 			prune[prune_num-1] = NULL;
 		}
-		while ((i+1 < active_nr) &&
-		       ce_same_name(ce, active_cache[i+1]))
+		while ((i+1 < istate->cache_nr) &&
+		       ce_same_name(ce, istate->cache[i+1]))
 			i++;
 	}
 	clear_pathspec(&revs->prune_data);
@@ -1555,8 +1766,8 @@ static int handle_dotdot_1(const char *a
 	if (!*b_name)
 		b_name = "HEAD";
 
-	if (get_oid_with_context(a_name, oc_flags, &a_oid, a_oc) ||
-	    get_oid_with_context(b_name, oc_flags, &b_oid, b_oc))
+	if (get_oid_with_context(revs->repo, a_name, oc_flags, &a_oid, a_oc) ||
+	    get_oid_with_context(revs->repo, b_name, oc_flags, &b_oid, b_oc))
 		return -1;
 
 	if (!cant_be_filename) {
@@ -1565,8 +1776,8 @@ static int handle_dotdot_1(const char *a
 		*dotdot = '\0';
 	}
 
-	a_obj = parse_object(&a_oid);
-	b_obj = parse_object(&b_oid);
+	a_obj = parse_object(revs->repo, &a_oid);
+	b_obj = parse_object(revs->repo, &b_oid);
 	if (!a_obj || !b_obj)
 		return dotdot_missing(arg, dotdot, revs, symmetric);
 
@@ -1579,8 +1790,8 @@ static int handle_dotdot_1(const char *a
 		struct commit *a, *b;
 		struct commit_list *exclude;
 
-		a = lookup_commit_reference(&a_obj->oid);
-		b = lookup_commit_reference(&b_obj->oid);
+		a = lookup_commit_reference(revs->repo, &a_obj->oid);
+		b = lookup_commit_reference(revs->repo, &b_obj->oid);
 		if (!a || !b)
 			return dotdot_missing(arg, dotdot, revs, symmetric);
 
@@ -1690,18 +1901,20 @@ int handle_revision_arg(const char *arg_
 	if (revarg_opt & REVARG_COMMITTISH)
 		get_sha1_flags |= GET_OID_COMMITTISH;
 
-	if (get_oid_with_context(arg, get_sha1_flags, &oid, &oc))
+	if (get_oid_with_context(revs->repo, arg, get_sha1_flags, &oid, &oc))
 		return revs->ignore_missing ? 0 : -1;
 	if (!cant_be_filename)
 		verify_non_filename(revs->prefix, arg);
 	object = get_reference(revs, arg, &oid, flags ^ local_flags);
+	if (!object)
+		return revs->ignore_missing ? 0 : -1;
 	add_rev_cmdline(revs, object, arg_, REV_CMD_REV, flags ^ local_flags);
 	add_pending_object_with_path(revs, object, arg, oc.mode, oc.path);
 	free(oc.path);
 	return 0;
 }
 
-static void read_pathspec_from_stdin(struct rev_info *revs, struct strbuf *sb,
+static void read_pathspec_from_stdin(struct strbuf *sb,
 				     struct argv_array *prune)
 {
 	while (strbuf_getline(sb, stdin) != EOF)
@@ -1735,7 +1948,7 @@ static void read_revisions_from_stdin(st
 			die("bad revision '%s'", sb.buf);
 	}
 	if (seen_dashdash)
-		read_pathspec_from_stdin(revs, &sb, prune);
+		read_pathspec_from_stdin(&sb, prune);
 
 	strbuf_release(&sb);
 	warn_on_object_refname_ambiguity = save_warning;
@@ -1757,7 +1970,8 @@ static void add_message_grep(struct rev_
 }
 
 static int handle_revision_opt(struct rev_info *revs, int argc, const char **argv,
-			       int *unkc, const char **unkv)
+			       int *unkc, const char **unkv,
+			       const struct setup_revision_opt* opt)
 {
 	const char *arg = argv[0];
 	const char *optarg;
@@ -1771,6 +1985,7 @@ static int handle_revision_opt(struct re
 	    !strcmp(arg, "--no-walk") || !strcmp(arg, "--do-walk") ||
 	    !strcmp(arg, "--bisect") || starts_with(arg, "--glob=") ||
 	    !strcmp(arg, "--indexed-objects") ||
+	    !strcmp(arg, "--alternate-refs") ||
 	    starts_with(arg, "--exclude=") ||
 	    starts_with(arg, "--branches=") || starts_with(arg, "--tags=") ||
 	    starts_with(arg, "--remotes=") || starts_with(arg, "--no-walk="))
@@ -1851,7 +2066,6 @@ static int handle_revision_opt(struct re
 		revs->simplify_by_decoration = 1;
 		revs->limited = 1;
 		revs->prune = 1;
-		load_ref_decorations(NULL, DECORATE_SHORT_REFS);
 	} else if (!strcmp(arg, "--date-order")) {
 		revs->sort_order = REV_SORT_BY_COMMIT_DATE;
 		revs->topo_order = 1;
@@ -1957,6 +2171,9 @@ static int handle_revision_opt(struct re
 		revs->diff = 1;
 		revs->dense_combined_merges = 0;
 		revs->combine_merges = 1;
+	} else if (!strcmp(arg, "--combined-all-paths")) {
+		revs->diff = 1;
+		revs->combined_all_paths = 1;
 	} else if (!strcmp(arg, "--cc")) {
 		revs->diff = 1;
 		revs->dense_combined_merges = 1;
@@ -1986,9 +2203,8 @@ static int handle_revision_opt(struct re
 			die("'%s': not a non-negative integer", arg);
 		revs->expand_tabs_in_log = val;
 	} else if (!strcmp(arg, "--show-notes") || !strcmp(arg, "--notes")) {
-		revs->show_notes = 1;
+		enable_default_display_notes(&revs->notes_opt, &revs->show_notes);
 		revs->show_notes_given = 1;
-		revs->notes_opt.use_default_notes = 1;
 	} else if (!strcmp(arg, "--show-signature")) {
 		revs->show_signature = 1;
 	} else if (!strcmp(arg, "--no-show-signature")) {
@@ -2003,25 +2219,14 @@ static int handle_revision_opt(struct re
 		revs->track_first_time = 1;
 	} else if (skip_prefix(arg, "--show-notes=", &optarg) ||
 		   skip_prefix(arg, "--notes=", &optarg)) {
-		struct strbuf buf = STRBUF_INIT;
-		revs->show_notes = 1;
-		revs->show_notes_given = 1;
 		if (starts_with(arg, "--show-notes=") &&
 		    revs->notes_opt.use_default_notes < 0)
 			revs->notes_opt.use_default_notes = 1;
-		strbuf_addstr(&buf, optarg);
-		expand_notes_ref(&buf);
-		string_list_append(&revs->notes_opt.extra_notes_refs,
-				   strbuf_detach(&buf, NULL));
+		enable_ref_display_notes(&revs->notes_opt, &revs->show_notes, optarg);
+		revs->show_notes_given = 1;
 	} else if (!strcmp(arg, "--no-notes")) {
-		revs->show_notes = 0;
+		disable_display_notes(&revs->notes_opt, &revs->show_notes);
 		revs->show_notes_given = 1;
-		revs->notes_opt.use_default_notes = -1;
-		/* we have been strdup'ing ourselves, so trick
-		 * string_list into free()ing strings */
-		revs->notes_opt.extra_notes_refs.strdup_strings = 1;
-		string_list_clear(&revs->notes_opt.extra_notes_refs, 0);
-		revs->notes_opt.extra_notes_refs.strdup_strings = 0;
 	} else if (!strcmp(arg, "--standard-notes")) {
 		revs->show_notes_given = 1;
 		revs->notes_opt.use_default_notes = 1;
@@ -2117,7 +2322,8 @@ static int handle_revision_opt(struct re
 		revs->limited = 1;
 	} else if (!strcmp(arg, "--ignore-missing")) {
 		revs->ignore_missing = 1;
-	} else if (!strcmp(arg, "--exclude-promisor-objects")) {
+	} else if (opt && opt->allow_exclude_promisor_objects &&
+		   !strcmp(arg, "--exclude-promisor-objects")) {
 		if (fetch_if_missing)
 			BUG("exclude_promisor_objects can only be used when fetch_if_missing is 0");
 		revs->exclude_promisor_objects = 1;
@@ -2138,7 +2344,7 @@ void parse_revision_opt(struct rev_info
 			const char * const usagestr[])
 {
 	int n = handle_revision_opt(revs, ctx->argc, ctx->argv,
-				    &ctx->cpidx, ctx->out);
+				    &ctx->cpidx, ctx->out, NULL);
 	if (n <= 0) {
 		error("unknown option `%s'", ctx->argv[0]);
 		usage_with_options(usagestr, options);
@@ -2188,7 +2394,7 @@ static int handle_revision_pseudo_opt(co
 			BUG("--single-worktree cannot be used together with submodule");
 		refs = get_submodule_ref_store(submodule);
 	} else
-		refs = get_main_ref_store(the_repository);
+		refs = get_main_ref_store(revs->repo);
 
 	/*
 	 * NOTE!
@@ -2253,6 +2459,8 @@ static int handle_revision_pseudo_opt(co
 		add_reflogs_to_pending(revs, *flags);
 	} else if (!strcmp(arg, "--indexed-objects")) {
 		add_index_objects_to_pending(revs, *flags);
+	} else if (!strcmp(arg, "--alternate-refs")) {
+		add_alternate_refs_to_pending(revs, *flags);
 	} else if (!strcmp(arg, "--not")) {
 		*flags ^= UNINTERESTING | BOTTOM;
 	} else if (!strcmp(arg, "--no-walk")) {
@@ -2302,9 +2510,10 @@ static void NORETURN diagnose_missing_de
  */
 int setup_revisions(int argc, const char **argv, struct rev_info *revs, struct setup_revision_opt *opt)
 {
-	int i, flags, left, seen_dashdash, read_from_stdin, got_rev_arg = 0, revarg_opt;
+	int i, flags, left, seen_dashdash, got_rev_arg = 0, revarg_opt;
 	struct argv_array prune_data = ARGV_ARRAY_INIT;
 	const char *submodule = NULL;
+	int seen_end_of_options = 0;
 
 	if (opt)
 		submodule = opt->submodule;
@@ -2332,10 +2541,9 @@ int setup_revisions(int argc, const char
 	revarg_opt = opt ? opt->revarg_opt : 0;
 	if (seen_dashdash)
 		revarg_opt |= REVARG_CANNOT_BE_FILENAME;
-	read_from_stdin = 0;
 	for (left = i = 1; i < argc; i++) {
 		const char *arg = argv[i];
-		if (*arg == '-') {
+		if (!seen_end_of_options && *arg == '-') {
 			int opts;
 
 			opts = handle_revision_pseudo_opt(submodule,
@@ -2351,13 +2559,19 @@ int setup_revisions(int argc, const char
 					argv[left++] = arg;
 					continue;
 				}
-				if (read_from_stdin++)
+				if (revs->read_from_stdin++)
 					die("--stdin given twice?");
 				read_revisions_from_stdin(revs, &prune_data);
 				continue;
 			}
 
-			opts = handle_revision_opt(revs, argc - i, argv + i, &left, argv);
+			if (!strcmp(arg, "--end-of-options")) {
+				seen_end_of_options = 1;
+				continue;
+			}
+
+			opts = handle_revision_opt(revs, argc - i, argv + i,
+						   &left, argv, opt);
 			if (opts > 0) {
 				i += opts - 1;
 				continue;
@@ -2419,7 +2633,7 @@ int setup_revisions(int argc, const char
 		struct object_id oid;
 		struct object *object;
 		struct object_context oc;
-		if (get_oid_with_context(revs->def, 0, &oid, &oc))
+		if (get_oid_with_context(revs->repo, revs->def, 0, &oid, &oc))
 			diagnose_missing_default(revs->def);
 		object = get_reference(revs, revs->def, &oid, 0);
 		add_pending_object_with_mode(revs, object, revs->def, oc.mode);
@@ -2438,7 +2652,7 @@ int setup_revisions(int argc, const char
 	if (revs->diffopt.objfind)
 		revs->simplify_history = 0;
 
-	if (revs->topo_order)
+	if (revs->topo_order && !generation_numbers_enabled(the_repository))
 		revs->limited = 1;
 
 	if (revs->prune_data.nr) {
@@ -2452,6 +2666,9 @@ int setup_revisions(int argc, const char
 	}
 	if (revs->combine_merges)
 		revs->ignore_merges = 0;
+	if (revs->combined_all_paths && !revs->combine_merges)
+		die("--combined-all-paths makes no sense without -c or --cc");
+
 	revs->diffopt.abbrev = revs->abbrev;
 
 	if (revs->line_level_traverse) {
@@ -2463,6 +2680,8 @@ int setup_revisions(int argc, const char
 
 	grep_commit_pattern_type(GREP_PATTERN_TYPE_UNSPECIFIED,
 				 &revs->grep_filter);
+	if (!is_encoding_utf8(get_log_output_encoding()))
+		revs->grep_filter.ignore_locale = 1;
 	compile_grep_patterns(&revs->grep_filter);
 
 	if (revs->reverse && revs->reflog_info)
@@ -2488,6 +2707,10 @@ int setup_revisions(int argc, const char
 	if (revs->first_parent_only && revs->bisect)
 		die(_("--first-parent is incompatible with --bisect"));
 
+	if (revs->line_level_traverse &&
+	    (revs->diffopt.output_format & ~(DIFF_FORMAT_PATCH | DIFF_FORMAT_NO_OUTPUT)))
+		die(_("-L does not yet support diff formats besides -p and -s"));
+
 	if (revs->expand_tabs_in_log < 0)
 		revs->expand_tabs_in_log = revs->expand_tabs_in_log_default;
 
@@ -2547,7 +2770,7 @@ static struct merge_simplify_state *loca
 	return st;
 }
 
-static int mark_redundant_parents(struct rev_info *revs, struct commit *commit)
+static int mark_redundant_parents(struct commit *commit)
 {
 	struct commit_list *h = reduce_heads(commit->parents);
 	int i = 0, marked = 0;
@@ -2583,7 +2806,7 @@ static int mark_redundant_parents(struct
 	return marked;
 }
 
-static int mark_treesame_root_parents(struct rev_info *revs, struct commit *commit)
+static int mark_treesame_root_parents(struct commit *commit)
 {
 	struct commit_list *p;
 	int marked = 0;
@@ -2775,8 +2998,8 @@ static struct commit_list **simplify_one
 	 * Detect and simplify both cases.
 	 */
 	if (1 < cnt) {
-		int marked = mark_redundant_parents(revs, commit);
-		marked += mark_treesame_root_parents(revs, commit);
+		int marked = mark_redundant_parents(commit);
+		marked += mark_treesame_root_parents(commit);
 		if (marked)
 			marked -= leave_one_treesame_to_parent(revs, commit);
 		if (marked)
@@ -2863,19 +3086,250 @@ static void set_children(struct rev_info
 
 void reset_revision_walk(void)
 {
-	clear_object_flags(SEEN | ADDED | SHOWN);
+	clear_object_flags(SEEN | ADDED | SHOWN | TOPO_WALK_EXPLORED | TOPO_WALK_INDEGREE);
 }
 
 static int mark_uninteresting(const struct object_id *oid,
 			      struct packed_git *pack,
 			      uint32_t pos,
-			      void *unused)
+			      void *cb)
 {
-	struct object *o = parse_object(oid);
+	struct rev_info *revs = cb;
+	struct object *o = parse_object(revs->repo, oid);
 	o->flags |= UNINTERESTING | SEEN;
 	return 0;
 }
 
+define_commit_slab(indegree_slab, int);
+define_commit_slab(author_date_slab, timestamp_t);
+
+struct topo_walk_info {
+	uint32_t min_generation;
+	struct prio_queue explore_queue;
+	struct prio_queue indegree_queue;
+	struct prio_queue topo_queue;
+	struct indegree_slab indegree;
+	struct author_date_slab author_date;
+};
+
+static inline void test_flag_and_insert(struct prio_queue *q, struct commit *c, int flag)
+{
+	if (c->object.flags & flag)
+		return;
+
+	c->object.flags |= flag;
+	prio_queue_put(q, c);
+}
+
+static void explore_walk_step(struct rev_info *revs)
+{
+	struct topo_walk_info *info = revs->topo_walk_info;
+	struct commit_list *p;
+	struct commit *c = prio_queue_get(&info->explore_queue);
+
+	if (!c)
+		return;
+
+	if (parse_commit_gently(c, 1) < 0)
+		return;
+
+	if (revs->sort_order == REV_SORT_BY_AUTHOR_DATE)
+		record_author_date(&info->author_date, c);
+
+	if (revs->max_age != -1 && (c->date < revs->max_age))
+		c->object.flags |= UNINTERESTING;
+
+	if (process_parents(revs, c, NULL, NULL) < 0)
+		return;
+
+	if (c->object.flags & UNINTERESTING)
+		mark_parents_uninteresting(c);
+
+	for (p = c->parents; p; p = p->next)
+		test_flag_and_insert(&info->explore_queue, p->item, TOPO_WALK_EXPLORED);
+}
+
+static void explore_to_depth(struct rev_info *revs,
+			     uint32_t gen_cutoff)
+{
+	struct topo_walk_info *info = revs->topo_walk_info;
+	struct commit *c;
+	while ((c = prio_queue_peek(&info->explore_queue)) &&
+	       c->generation >= gen_cutoff)
+		explore_walk_step(revs);
+}
+
+static void indegree_walk_step(struct rev_info *revs)
+{
+	struct commit_list *p;
+	struct topo_walk_info *info = revs->topo_walk_info;
+	struct commit *c = prio_queue_get(&info->indegree_queue);
+
+	if (!c)
+		return;
+
+	if (parse_commit_gently(c, 1) < 0)
+		return;
+
+	explore_to_depth(revs, c->generation);
+
+	for (p = c->parents; p; p = p->next) {
+		struct commit *parent = p->item;
+		int *pi = indegree_slab_at(&info->indegree, parent);
+
+		if (*pi)
+			(*pi)++;
+		else
+			*pi = 2;
+
+		test_flag_and_insert(&info->indegree_queue, parent, TOPO_WALK_INDEGREE);
+
+		if (revs->first_parent_only)
+			return;
+	}
+}
+
+static void compute_indegrees_to_depth(struct rev_info *revs,
+				       uint32_t gen_cutoff)
+{
+	struct topo_walk_info *info = revs->topo_walk_info;
+	struct commit *c;
+	while ((c = prio_queue_peek(&info->indegree_queue)) &&
+	       c->generation >= gen_cutoff)
+		indegree_walk_step(revs);
+}
+
+static void reset_topo_walk(struct rev_info *revs)
+{
+	struct topo_walk_info *info = revs->topo_walk_info;
+
+	clear_prio_queue(&info->explore_queue);
+	clear_prio_queue(&info->indegree_queue);
+	clear_prio_queue(&info->topo_queue);
+	clear_indegree_slab(&info->indegree);
+	clear_author_date_slab(&info->author_date);
+
+	FREE_AND_NULL(revs->topo_walk_info);
+}
+
+static void init_topo_walk(struct rev_info *revs)
+{
+	struct topo_walk_info *info;
+	struct commit_list *list;
+	if (revs->topo_walk_info)
+		reset_topo_walk(revs);
+
+	revs->topo_walk_info = xmalloc(sizeof(struct topo_walk_info));
+	info = revs->topo_walk_info;
+	memset(info, 0, sizeof(struct topo_walk_info));
+
+	init_indegree_slab(&info->indegree);
+	memset(&info->explore_queue, 0, sizeof(info->explore_queue));
+	memset(&info->indegree_queue, 0, sizeof(info->indegree_queue));
+	memset(&info->topo_queue, 0, sizeof(info->topo_queue));
+
+	switch (revs->sort_order) {
+	default: /* REV_SORT_IN_GRAPH_ORDER */
+		info->topo_queue.compare = NULL;
+		break;
+	case REV_SORT_BY_COMMIT_DATE:
+		info->topo_queue.compare = compare_commits_by_commit_date;
+		break;
+	case REV_SORT_BY_AUTHOR_DATE:
+		init_author_date_slab(&info->author_date);
+		info->topo_queue.compare = compare_commits_by_author_date;
+		info->topo_queue.cb_data = &info->author_date;
+		break;
+	}
+
+	info->explore_queue.compare = compare_commits_by_gen_then_commit_date;
+	info->indegree_queue.compare = compare_commits_by_gen_then_commit_date;
+
+	info->min_generation = GENERATION_NUMBER_INFINITY;
+	for (list = revs->commits; list; list = list->next) {
+		struct commit *c = list->item;
+
+		if (parse_commit_gently(c, 1))
+			continue;
+
+		test_flag_and_insert(&info->explore_queue, c, TOPO_WALK_EXPLORED);
+		test_flag_and_insert(&info->indegree_queue, c, TOPO_WALK_INDEGREE);
+
+		if (c->generation < info->min_generation)
+			info->min_generation = c->generation;
+
+		*(indegree_slab_at(&info->indegree, c)) = 1;
+
+		if (revs->sort_order == REV_SORT_BY_AUTHOR_DATE)
+			record_author_date(&info->author_date, c);
+	}
+	compute_indegrees_to_depth(revs, info->min_generation);
+
+	for (list = revs->commits; list; list = list->next) {
+		struct commit *c = list->item;
+
+		if (*(indegree_slab_at(&info->indegree, c)) == 1)
+			prio_queue_put(&info->topo_queue, c);
+	}
+
+	/*
+	 * This is unfortunate; the initial tips need to be shown
+	 * in the order given from the revision traversal machinery.
+	 */
+	if (revs->sort_order == REV_SORT_IN_GRAPH_ORDER)
+		prio_queue_reverse(&info->topo_queue);
+}
+
+static struct commit *next_topo_commit(struct rev_info *revs)
+{
+	struct commit *c;
+	struct topo_walk_info *info = revs->topo_walk_info;
+
+	/* pop next off of topo_queue */
+	c = prio_queue_get(&info->topo_queue);
+
+	if (c)
+		*(indegree_slab_at(&info->indegree, c)) = 0;
+
+	return c;
+}
+
+static void expand_topo_walk(struct rev_info *revs, struct commit *commit)
+{
+	struct commit_list *p;
+	struct topo_walk_info *info = revs->topo_walk_info;
+	if (process_parents(revs, commit, NULL, NULL) < 0) {
+		if (!revs->ignore_missing_links)
+			die("Failed to traverse parents of commit %s",
+			    oid_to_hex(&commit->object.oid));
+	}
+
+	for (p = commit->parents; p; p = p->next) {
+		struct commit *parent = p->item;
+		int *pi;
+
+		if (parent->object.flags & UNINTERESTING)
+			continue;
+
+		if (parse_commit_gently(parent, 1) < 0)
+			continue;
+
+		if (parent->generation < info->min_generation) {
+			info->min_generation = parent->generation;
+			compute_indegrees_to_depth(revs, info->min_generation);
+		}
+
+		pi = indegree_slab_at(&info->indegree, parent);
+
+		(*pi)--;
+		if (*pi == 1)
+			prio_queue_put(&info->topo_queue, parent);
+
+		if (revs->first_parent_only)
+			return;
+	}
+}
+
 int prepare_revision_walk(struct rev_info *revs)
 {
 	int i;
@@ -2904,7 +3358,7 @@ int prepare_revision_walk(struct rev_inf
 		revs->treesame.name = "treesame";
 
 	if (revs->exclude_promisor_objects) {
-		for_each_packed_object(mark_uninteresting, NULL,
+		for_each_packed_object(mark_uninteresting, revs,
 				       FOR_EACH_OBJECT_PROMISOR_ONLY);
 	}
 
@@ -2912,11 +3366,13 @@ int prepare_revision_walk(struct rev_inf
 		commit_list_sort_by_date(&revs->commits);
 	if (revs->no_walk)
 		return 0;
-	if (revs->limited)
+	if (revs->limited) {
 		if (limit_list(revs) < 0)
 			return -1;
-	if (revs->topo_order)
-		sort_in_topological_order(&revs->commits, revs->sort_order);
+		if (revs->topo_order)
+			sort_in_topological_order(&revs->commits, revs->sort_order);
+	} else if (revs->topo_order)
+		init_topo_walk(revs);
 	if (revs->line_level_traverse)
 		line_log_filter(revs);
 	if (revs->simplify_merges)
@@ -2926,14 +3382,14 @@ int prepare_revision_walk(struct rev_inf
 	return 0;
 }
 
-static enum rewrite_result rewrite_one(struct rev_info *revs, struct commit **pp)
+static enum rewrite_result rewrite_one_1(struct rev_info *revs,
+					 struct commit **pp,
+					 struct prio_queue *queue)
 {
-	struct commit_list *cache = NULL;
-
 	for (;;) {
 		struct commit *p = *pp;
 		if (!revs->limited)
-			if (add_parents_to_list(revs, p, &revs->commits, &cache) < 0)
+			if (process_parents(revs, p, NULL, queue) < 0)
 				return rewrite_one_error;
 		if (p->object.flags & UNINTERESTING)
 			return rewrite_one_ok;
@@ -2947,6 +3403,31 @@ static enum rewrite_result rewrite_one(s
 	}
 }
 
+static void merge_queue_into_list(struct prio_queue *q, struct commit_list **list)
+{
+	while (q->nr) {
+		struct commit *item = prio_queue_peek(q);
+		struct commit_list *p = *list;
+
+		if (p && p->item->date >= item->date)
+			list = &p->next;
+		else {
+			p = commit_list_insert(item, list);
+			list = &p->next; /* skip newly added item */
+			prio_queue_get(q); /* pop item */
+		}
+	}
+}
+
+static enum rewrite_result rewrite_one(struct rev_info *revs, struct commit **pp)
+{
+	struct prio_queue queue = { compare_commits_by_commit_date };
+	enum rewrite_result ret = rewrite_one_1(revs, pp, &queue);
+	merge_queue_into_list(&queue, &revs->commits);
+	clear_prio_queue(&queue);
+	return ret;
+}
+
 int rewrite_parents(struct rev_info *revs, struct commit *commit,
 	rewrite_parent_fn_t rewrite_parent)
 {
@@ -3222,7 +3703,7 @@ static void track_linear(struct rev_info
 		struct commit_list *p;
 		for (p = revs->previous_parents; p; p = p->next)
 			if (p->item == NULL || /* first commit */
-			    !oidcmp(&p->item->object.oid, &commit->object.oid))
+			    oideq(&p->item->object.oid, &commit->object.oid))
 				break;
 		revs->linear = p != NULL;
 	}
@@ -3241,6 +3722,8 @@ static struct commit *get_revision_1(str
 
 		if (revs->reflog_info)
 			commit = next_reflog_entry(revs->reflog_info);
+		else if (revs->topo_walk_info)
+			commit = next_topo_commit(revs);
 		else
 			commit = pop_commit(&revs->commits);
 
@@ -3262,7 +3745,9 @@ static struct commit *get_revision_1(str
 
 			if (revs->reflog_info)
 				try_to_simplify_commit(revs, commit);
-			else if (add_parents_to_list(revs, commit, &revs->commits, NULL) < 0) {
+			else if (revs->topo_walk_info)
+				expand_topo_walk(revs, commit);
+			else if (process_parents(revs, commit, &revs->commits, NULL) < 0) {
 				if (!revs->ignore_missing_links)
 					die("Failed to traverse parents of commit %s",
 						oid_to_hex(&commit->object.oid));
@@ -3463,7 +3948,7 @@ struct commit *get_revision(struct rev_i
 	return c;
 }
 
-char *get_revision_mark(const struct rev_info *revs, const struct commit *commit)
+const char *get_revision_mark(const struct rev_info *revs, const struct commit *commit)
 {
 	if (commit->object.flags & BOUNDARY)
 		return "-";
@@ -3485,7 +3970,7 @@ char *get_revision_mark(const struct rev
 
 void put_revision_mark(const struct rev_info *revs, const struct commit *commit)
 {
-	char *mark = get_revision_mark(revs, commit);
+	const char *mark = get_revision_mark(revs, commit);
 	if (!strlen(mark))
 		return;
 	fputs(mark, stdout);
diff -pruN 1.2.1+git2.18.0-1/git/revision.h 1.2.3+git2.25.1-1/git/revision.h
--- 1.2.1+git2.18.0-1/git/revision.h	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/revision.h	2020-02-17 04:47:35.000000000 +0000
@@ -1,11 +1,26 @@
 #ifndef REVISION_H
 #define REVISION_H
 
+#include "commit.h"
 #include "parse-options.h"
 #include "grep.h"
 #include "notes.h"
 #include "pretty.h"
 #include "diff.h"
+#include "commit-slab-decl.h"
+
+/**
+ * The revision walking API offers functions to build a list of revisions
+ * and then iterate over that list.
+ *
+ * Calling sequence
+ * ----------------
+ *
+ * The walking API has a given calling sequence: first you need to initialize
+ * a rev_info structure, then add revisions to control what kind of revision
+ * list do you want to get, finally you can iterate over the revision list.
+ *
+ */
 
 /* Remember to update object flag allocation in object.h */
 #define SEEN		(1u<<0)
@@ -19,16 +34,29 @@
 #define SYMMETRIC_LEFT	(1u<<8)
 #define PATCHSAME	(1u<<9)
 #define BOTTOM		(1u<<10)
+/*
+ * Indicates object was reached by traversal. i.e. not given by user on
+ * command-line or stdin.
+ * NEEDSWORK: NOT_USER_GIVEN doesn't apply to commits because we only support
+ * filtering trees and blobs, but it may be useful to support filtering commits
+ * in the future.
+ */
+#define NOT_USER_GIVEN	(1u<<25)
 #define TRACK_LINEAR	(1u<<26)
-#define ALL_REV_FLAGS	(((1u<<11)-1) | TRACK_LINEAR)
+#define ALL_REV_FLAGS	(((1u<<11)-1) | NOT_USER_GIVEN | TRACK_LINEAR)
+
+#define TOPO_WALK_EXPLORED	(1u<<27)
+#define TOPO_WALK_INDEGREE	(1u<<28)
 
 #define DECORATE_SHORT_REFS	1
 #define DECORATE_FULL_REFS	2
 
-struct rev_info;
 struct log_info;
+struct repository;
+struct rev_info;
 struct string_list;
 struct saved_parents;
+define_shared_commit_slab(revision_sources, char *);
 
 struct rev_cmdline_info {
 	unsigned int nr;
@@ -52,10 +80,14 @@ struct rev_cmdline_info {
 #define REVISION_WALK_NO_WALK_SORTED 1
 #define REVISION_WALK_NO_WALK_UNSORTED 2
 
+struct oidset;
+struct topo_walk_info;
+
 struct rev_info {
 	/* Starting list */
 	struct commit_list *commits;
 	struct object_array pending;
+	struct repository *repo;
 
 	/* Parents of shown commits */
 	struct object_array boundary_commits;
@@ -78,6 +110,11 @@ struct rev_info {
 	 */
 	int rev_input_given;
 
+	/*
+	 * Whether we read from stdin due to the --stdin option.
+	 */
+	int read_from_stdin;
+
 	/* topo-sort */
 	enum rev_sort_order sort_order;
 
@@ -111,7 +148,6 @@ struct rev_info {
 			right_only:1,
 			rewrite_parents:1,
 			print_parents:1,
-			show_source:1,
 			show_decorations:1,
 			reverse:1,
 			reverse_output_stage:1,
@@ -123,6 +159,21 @@ struct rev_info {
 			line_level_traverse:1,
 			tree_blobs_in_commit_order:1,
 
+			/*
+			 * Blobs are shown without regard for their existence.
+			 * But not so for trees: unless exclude_promisor_objects
+			 * is set and the tree in question is a promisor object;
+			 * OR ignore_missing_links is set, the revision walker
+			 * dies with a "bad tree object HASH" message when
+			 * encountering a missing tree. For callers that can
+			 * handle missing trees and want them to be filterable
+			 * and showable, set this to true. The revision walker
+			 * will filter and show such a missing tree as usual,
+			 * but will not attempt to recurse into this tree
+			 * object.
+			 */
+			do_not_die_on_missing_tree:1,
+
 			/* for internal use only */
 			exclude_promisor_objects:1;
 
@@ -134,14 +185,15 @@ struct rev_info {
 			verbose_header:1,
 			ignore_merges:1,
 			combine_merges:1,
+			combined_all_paths:1,
 			dense_combined_merges:1,
 			always_show_header:1;
 
 	/* Format info */
+	int		show_notes;
 	unsigned int	shown_one:1,
 			shown_dashes:1,
 			show_merge:1,
-			show_notes:1,
 			show_notes_given:1,
 			show_signature:1,
 			pretty_given:1,
@@ -211,6 +263,17 @@ struct rev_info {
 	/* notes-specific options: which refs to show */
 	struct display_notes_opt notes_opt;
 
+	/* interdiff */
+	const struct object_id *idiff_oid1;
+	const struct object_id *idiff_oid2;
+	const char *idiff_title;
+
+	/* range-diff */
+	const char *rdiff1;
+	const char *rdiff2;
+	int creation_factor;
+	const char *rdiff_title;
+
 	/* commit counts */
 	int count_left;
 	int count_right;
@@ -224,9 +287,13 @@ struct rev_info {
 
 	struct commit_list *previous_parents;
 	const char *break_bar;
+
+	struct revision_sources *sources;
+
+	struct topo_walk_info *topo_walk_info;
 };
 
-extern int ref_excluded(struct string_list *, const char *path);
+int ref_excluded(struct string_list *, const char *path);
 void clear_ref_exclusion(struct string_list **);
 void add_ref_exclusion(struct string_list **, const char *exclude);
 
@@ -243,44 +310,97 @@ extern volatile show_early_output_fn_t s
 struct setup_revision_opt {
 	const char *def;
 	void (*tweak)(struct rev_info *, struct setup_revision_opt *);
-	const char *submodule;
-	int assume_dashdash;
+	const char *submodule;	/* TODO: drop this and use rev_info->repo */
+	unsigned int	assume_dashdash:1,
+			allow_exclude_promisor_objects:1;
 	unsigned revarg_opt;
 };
 
-extern void init_revisions(struct rev_info *revs, const char *prefix);
-extern int setup_revisions(int argc, const char **argv, struct rev_info *revs,
-			   struct setup_revision_opt *);
-extern void parse_revision_opt(struct rev_info *revs, struct parse_opt_ctx_t *ctx,
-			       const struct option *options,
-			       const char * const usagestr[]);
+#ifndef NO_THE_REPOSITORY_COMPATIBILITY_MACROS
+#define init_revisions(revs, prefix) repo_init_revisions(the_repository, revs, prefix)
+#endif
+
+/**
+ * Initialize a rev_info structure with default values. The third parameter may
+ * be NULL or can be prefix path, and then the `.prefix` variable will be set
+ * to it. This is typically the first function you want to call when you want
+ * to deal with a revision list. After calling this function, you are free to
+ * customize options, like set `.ignore_merges` to 0 if you don't want to
+ * ignore merges, and so on.
+ */
+void repo_init_revisions(struct repository *r,
+			 struct rev_info *revs,
+			 const char *prefix);
+
+/**
+ * Parse revision information, filling in the `rev_info` structure, and
+ * removing the used arguments from the argument list. Returns the number
+ * of arguments left that weren't recognized, which are also moved to the
+ * head of the argument list. The last parameter is used in case no
+ * parameter given by the first two arguments.
+ */
+int setup_revisions(int argc, const char **argv, struct rev_info *revs,
+		    struct setup_revision_opt *);
+
+void parse_revision_opt(struct rev_info *revs, struct parse_opt_ctx_t *ctx,
+			const struct option *options,
+			const char * const usagestr[]);
 #define REVARG_CANNOT_BE_FILENAME 01
 #define REVARG_COMMITTISH 02
-extern int handle_revision_arg(const char *arg, struct rev_info *revs,
-			       int flags, unsigned revarg_opt);
+int handle_revision_arg(const char *arg, struct rev_info *revs,
+			int flags, unsigned revarg_opt);
 
-extern void reset_revision_walk(void);
-extern int prepare_revision_walk(struct rev_info *revs);
-extern struct commit *get_revision(struct rev_info *revs);
-extern char *get_revision_mark(const struct rev_info *revs,
-			       const struct commit *commit);
-extern void put_revision_mark(const struct rev_info *revs,
-			      const struct commit *commit);
+/**
+ * Reset the flags used by the revision walking api. You can use this to do
+ * multiple sequential revision walks.
+ */
+void reset_revision_walk(void);
+
+/**
+ * Prepares the rev_info structure for a walk. You should check if it returns
+ * any error (non-zero return code) and if it does not, you can start using
+ * get_revision() to do the iteration.
+ */
+int prepare_revision_walk(struct rev_info *revs);
+
+/**
+ * Takes a pointer to a `rev_info` structure and iterates over it, returning a
+ * `struct commit *` each time you call it. The end of the revision list is
+ * indicated by returning a NULL pointer.
+ */
+struct commit *get_revision(struct rev_info *revs);
 
-extern void mark_parents_uninteresting(struct commit *commit);
-extern void mark_tree_uninteresting(struct tree *tree);
+const char *get_revision_mark(const struct rev_info *revs,
+			      const struct commit *commit);
+void put_revision_mark(const struct rev_info *revs,
+		       const struct commit *commit);
 
-extern void show_object_with_name(FILE *, struct object *, const char *);
+void mark_parents_uninteresting(struct commit *commit);
+void mark_tree_uninteresting(struct repository *r, struct tree *tree);
+void mark_trees_uninteresting_sparse(struct repository *r, struct oidset *trees);
+
+void show_object_with_name(FILE *, struct object *, const char *);
+
+/**
+ * This function can be used if you want to add commit objects as revision
+ * information. You can use the `UNINTERESTING` object flag to indicate if
+ * you want to include or exclude the given commit (and commits reachable
+ * from the given commit) from the revision list.
+ *
+ * NOTE: If you have the commits as a string list then you probably want to
+ * use setup_revisions(), instead of parsing each string and using this
+ * function.
+ */
+void add_pending_object(struct rev_info *revs,
+			struct object *obj, const char *name);
 
-extern void add_pending_object(struct rev_info *revs,
-			       struct object *obj, const char *name);
-extern void add_pending_oid(struct rev_info *revs,
-			    const char *name, const struct object_id *oid,
-			    unsigned int flags);
-
-extern void add_head_to_pending(struct rev_info *);
-extern void add_reflogs_to_pending(struct rev_info *, unsigned int flags);
-extern void add_index_objects_to_pending(struct rev_info *, unsigned int flags);
+void add_pending_oid(struct rev_info *revs,
+		     const char *name, const struct object_id *oid,
+		     unsigned int flags);
+
+void add_head_to_pending(struct rev_info *);
+void add_reflogs_to_pending(struct rev_info *, unsigned int flags);
+void add_index_objects_to_pending(struct rev_info *, unsigned int flags);
 
 enum commit_action {
 	commit_ignore,
@@ -288,10 +408,10 @@ enum commit_action {
 	commit_error
 };
 
-extern enum commit_action get_commit_action(struct rev_info *revs,
-					    struct commit *commit);
-extern enum commit_action simplify_commit(struct rev_info *revs,
-					  struct commit *commit);
+enum commit_action get_commit_action(struct rev_info *revs,
+				     struct commit *commit);
+enum commit_action simplify_commit(struct rev_info *revs,
+				   struct commit *commit);
 
 enum rewrite_result {
 	rewrite_one_ok,
@@ -301,8 +421,9 @@ enum rewrite_result {
 
 typedef enum rewrite_result (*rewrite_parent_fn_t)(struct rev_info *revs, struct commit **pp);
 
-extern int rewrite_parents(struct rev_info *revs, struct commit *commit,
-	rewrite_parent_fn_t rewrite_parent);
+int rewrite_parents(struct rev_info *revs,
+		    struct commit *commit,
+		    rewrite_parent_fn_t rewrite_parent);
 
 /*
  * The log machinery saves the original parent list so that
@@ -313,6 +434,6 @@ extern int rewrite_parents(struct rev_in
  * get_saved_parents() will transparently return commit->parents if
  * history simplification is off.
  */
-extern struct commit_list *get_saved_parents(struct rev_info *revs, const struct commit *commit);
+struct commit_list *get_saved_parents(struct rev_info *revs, const struct commit *commit);
 
 #endif
diff -pruN 1.2.1+git2.18.0-1/git/run-command.c 1.2.3+git2.25.1-1/git/run-command.c
--- 1.2.1+git2.18.0-1/git/run-command.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/run-command.c	2020-02-17 04:47:35.000000000 +0000
@@ -213,15 +213,36 @@ static char *locate_in_PATH(const char *
 static int exists_in_PATH(const char *file)
 {
 	char *r = locate_in_PATH(file);
+	int found = r != NULL;
 	free(r);
-	return r != NULL;
+	return found;
 }
 
 int sane_execvp(const char *file, char * const argv[])
 {
+#ifndef GIT_WINDOWS_NATIVE
+	/*
+	 * execvp() doesn't return, so we all we can do is tell trace2
+	 * what we are about to do and let it leave a hint in the log
+	 * (unless of course the execvp() fails).
+	 *
+	 * we skip this for Windows because the compat layer already
+	 * has to emulate the execvp() call anyway.
+	 */
+	int exec_id = trace2_exec(file, (const char **)argv);
+#endif
+
 	if (!execvp(file, argv))
 		return 0; /* cannot happen ;-) */
 
+#ifndef GIT_WINDOWS_NATIVE
+	{
+		int ec = errno;
+		trace2_exec_result(exec_id, ec);
+		errno = ec;
+	}
+#endif
+
 	/*
 	 * When a command can't be found because one of the directories
 	 * listed in $PATH is unsearchable, execvp reports EACCES, but
@@ -380,7 +401,7 @@ static void child_err_spew(struct child_
 	set_error_routine(old_errfn);
 }
 
-static void prepare_cmd(struct argv_array *out, const struct child_process *cmd)
+static int prepare_cmd(struct argv_array *out, const struct child_process *cmd)
 {
 	if (!cmd->argv[0])
 		BUG("command is empty");
@@ -392,8 +413,7 @@ static void prepare_cmd(struct argv_arra
 	argv_array_push(out, SHELL_PATH);
 
 	if (cmd->git_cmd) {
-		argv_array_push(out, "git");
-		argv_array_pushv(out, cmd->argv);
+		prepare_git_cmd(out, cmd->argv);
 	} else if (cmd->use_shell) {
 		prepare_shell_cmd(out, cmd->argv);
 	} else {
@@ -403,16 +423,22 @@ static void prepare_cmd(struct argv_arra
 	/*
 	 * If there are no '/' characters in the command then perform a path
 	 * lookup and use the resolved path as the command to exec.  If there
-	 * are no '/' characters or if the command wasn't found in the path,
-	 * have exec attempt to invoke the command directly.
+	 * are '/' characters, we have exec attempt to invoke the command
+	 * directly.
 	 */
 	if (!strchr(out->argv[1], '/')) {
 		char *program = locate_in_PATH(out->argv[1]);
 		if (program) {
 			free((char *)out->argv[1]);
 			out->argv[1] = program;
+		} else {
+			argv_array_clear(out);
+			errno = ENOENT;
+			return -1;
 		}
 	}
+
+	return 0;
 }
 
 static char **prep_childenv(const char *const *deltaenv)
@@ -706,6 +732,7 @@ fail_pipe:
 		cmd->err = fderr[0];
 	}
 
+	trace2_child_start(cmd);
 	trace_run_command(cmd);
 
 	fflush(NULL);
@@ -719,6 +746,14 @@ fail_pipe:
 	struct child_err cerr;
 	struct atfork_state as;
 
+	if (prepare_cmd(&argv, cmd) < 0) {
+		failed_errno = errno;
+		cmd->pid = -1;
+		if (!cmd->silent_exec_failure)
+			error_errno("cannot run %s", cmd->argv[0]);
+		goto end_of_spawn;
+	}
+
 	if (pipe(notify_pipe))
 		notify_pipe[0] = notify_pipe[1] = -1;
 
@@ -729,7 +764,6 @@ fail_pipe:
 		set_cloexec(null_fd);
 	}
 
-	prepare_cmd(&argv, cmd);
 	childenv = prep_childenv(cmd->env);
 	atfork_prepare(&as);
 
@@ -857,6 +891,8 @@ fail_pipe:
 	argv_array_clear(&argv);
 	free(childenv);
 }
+end_of_spawn:
+
 #else
 {
 	int fhin = 0, fhout = 1, fherr = 2;
@@ -911,6 +947,8 @@ fail_pipe:
 #endif
 
 	if (cmd->pid < 0) {
+		trace2_child_exit(cmd, -1);
+
 		if (need_in)
 			close_pair(fdin);
 		else if (cmd->in)
@@ -949,13 +987,16 @@ fail_pipe:
 int finish_command(struct child_process *cmd)
 {
 	int ret = wait_or_whine(cmd->pid, cmd->argv[0], 0);
+	trace2_child_exit(cmd, ret);
 	child_process_clear(cmd);
 	return ret;
 }
 
 int finish_command_in_signal(struct child_process *cmd)
 {
-	return wait_or_whine(cmd->pid, cmd->argv[0], 1);
+	int ret = wait_or_whine(cmd->pid, cmd->argv[0], 1);
+	trace2_child_exit(cmd, ret);
+	return ret;
 }
 
 
@@ -977,8 +1018,19 @@ int run_command_v_opt(const char **argv,
 	return run_command_v_opt_cd_env(argv, opt, NULL, NULL);
 }
 
+int run_command_v_opt_tr2(const char **argv, int opt, const char *tr2_class)
+{
+	return run_command_v_opt_cd_env_tr2(argv, opt, NULL, NULL, tr2_class);
+}
+
 int run_command_v_opt_cd_env(const char **argv, int opt, const char *dir, const char *const *env)
 {
+	return run_command_v_opt_cd_env_tr2(argv, opt, dir, env, NULL);
+}
+
+int run_command_v_opt_cd_env_tr2(const char **argv, int opt, const char *dir,
+				 const char *const *env, const char *tr2_class)
+{
 	struct child_process cmd = CHILD_PROCESS_INIT;
 	cmd.argv = argv;
 	cmd.no_stdin = opt & RUN_COMMAND_NO_STDIN ? 1 : 0;
@@ -989,6 +1041,7 @@ int run_command_v_opt_cd_env(const char
 	cmd.clean_on_exit = opt & RUN_CLEAN_ON_EXIT ? 1 : 0;
 	cmd.dir = dir;
 	cmd.env = env;
+	cmd.trace2_child_class = tr2_class;
 	return run_command(&cmd);
 }
 
@@ -1213,7 +1266,7 @@ int start_async(struct async *async)
 	{
 		int err = pthread_create(&async->tid, NULL, run_thread, async);
 		if (err) {
-			error_errno("cannot create thread");
+			error(_("cannot create async thread: %s"), strerror(err));
 			goto error;
 		}
 	}
@@ -1246,6 +1299,15 @@ int finish_async(struct async *async)
 #endif
 }
 
+int async_with_fork(void)
+{
+#ifdef NO_PTHREADS
+	return 1;
+#else
+	return 0;
+#endif
+}
+
 const char *find_hook(const char *name)
 {
 	static struct strbuf path = STRBUF_INIT;
@@ -1295,6 +1357,7 @@ int run_hook_ve(const char *const *env,
 	hook.env = env;
 	hook.no_stdin = 1;
 	hook.stdout_to_stderr = 1;
+	hook.trace2_hook_name = name;
 
 	return run_command(&hook);
 }
@@ -1783,3 +1846,21 @@ int run_processes_parallel(int n,
 	pp_cleanup(&pp);
 	return 0;
 }
+
+int run_processes_parallel_tr2(int n, get_next_task_fn get_next_task,
+			       start_failure_fn start_failure,
+			       task_finished_fn task_finished, void *pp_cb,
+			       const char *tr2_category, const char *tr2_label)
+{
+	int result;
+
+	trace2_region_enter_printf(tr2_category, tr2_label, NULL, "max:%d",
+				   ((n < 1) ? online_cpus() : n));
+
+	result = run_processes_parallel(n, get_next_task, start_failure,
+					task_finished, pp_cb);
+
+	trace2_region_leave(tr2_category, tr2_label, NULL);
+
+	return result;
+}
diff -pruN 1.2.1+git2.18.0-1/git/run-command.h 1.2.3+git2.25.1-1/git/run-command.h
--- 1.2.1+git2.18.0-1/git/run-command.h	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/run-command.h	2020-02-17 04:47:35.000000000 +0000
@@ -1,21 +1,77 @@
 #ifndef RUN_COMMAND_H
 #define RUN_COMMAND_H
 
-#ifndef NO_PTHREADS
-#include <pthread.h>
-#endif
+#include "thread-utils.h"
 
 #include "argv-array.h"
 
+/**
+ * The run-command API offers a versatile tool to run sub-processes with
+ * redirected input and output as well as with a modified environment
+ * and an alternate current directory.
+ *
+ * A similar API offers the capability to run a function asynchronously,
+ * which is primarily used to capture the output that the function
+ * produces in the caller in order to process it.
+ */
+
+
+/**
+ * This describes the arguments, redirections, and environment of a
+ * command to run in a sub-process.
+ *
+ * The caller:
+ *
+ * 1. allocates and clears (using child_process_init() or
+ *    CHILD_PROCESS_INIT) a struct child_process variable;
+ * 2. initializes the members;
+ * 3. calls start_command();
+ * 4. processes the data;
+ * 5. closes file descriptors (if necessary; see below);
+ * 6. calls finish_command().
+ *
+ * Special forms of redirection are available by setting these members
+ * to 1:
+ *
+ *  .no_stdin, .no_stdout, .no_stderr: The respective channel is
+ *		redirected to /dev/null.
+ *
+ *	.stdout_to_stderr: stdout of the child is redirected to its
+ *		stderr. This happens after stderr is itself redirected.
+ *		So stdout will follow stderr to wherever it is
+ *		redirected.
+ */
 struct child_process {
+
+	/**
+	 * The .argv member is set up as an array of string pointers (NULL
+	 * terminated), of which .argv[0] is the program name to run (usually
+	 * without a path). If the command to run is a git command, set argv[0] to
+	 * the command name without the 'git-' prefix and set .git_cmd = 1.
+	 *
+	 * Note that the ownership of the memory pointed to by .argv stays with the
+	 * caller, but it should survive until `finish_command` completes. If the
+	 * .argv member is NULL, `start_command` will point it at the .args
+	 * `argv_array` (so you may use one or the other, but you must use exactly
+	 * one). The memory in .args will be cleaned up automatically during
+	 * `finish_command` (or during `start_command` when it is unsuccessful).
+	 *
+	 */
 	const char **argv;
+
 	struct argv_array args;
 	struct argv_array env_array;
 	pid_t pid;
+
+	int trace2_child_id;
+	uint64_t trace2_child_us_start;
+	const char *trace2_child_class;
+	const char *trace2_hook_name;
+
 	/*
 	 * Using .in, .out, .err:
-	 * - Specify 0 for no redirections (child inherits stdin, stdout,
-	 *   stderr from parent).
+	 * - Specify 0 for no redirections. No new file descriptor is allocated.
+	 * (child inherits stdin, stdout, stderr from parent).
 	 * - Specify -1 to have a pipe allocated as follows:
 	 *     .in: returns the writable pipe end; parent writes to it,
 	 *          the readable pipe end becomes child's stdin
@@ -33,13 +89,43 @@ struct child_process {
 	int in;
 	int out;
 	int err;
+
+	/**
+	 * To specify a new initial working directory for the sub-process,
+	 * specify it in the .dir member.
+	 */
 	const char *dir;
+
+	/**
+	 * To modify the environment of the sub-process, specify an array of
+	 * string pointers (NULL terminated) in .env:
+	 *
+	 * - If the string is of the form "VAR=value", i.e. it contains '='
+	 *   the variable is added to the child process's environment.
+	 *
+	 * - If the string does not contain '=', it names an environment
+	 *   variable that will be removed from the child process's environment.
+	 *
+	 * If the .env member is NULL, `start_command` will point it at the
+	 * .env_array `argv_array` (so you may use one or the other, but not both).
+	 * The memory in .env_array will be cleaned up automatically during
+	 * `finish_command` (or during `start_command` when it is unsuccessful).
+	 */
 	const char *const *env;
+
 	unsigned no_stdin:1;
 	unsigned no_stdout:1;
 	unsigned no_stderr:1;
-	unsigned git_cmd:1; /* if this is to be git sub-command */
+    unsigned git_cmd:1; /* if this is to be git sub-command */
+
+	/**
+	 * If the program cannot be found, the functions return -1 and set
+	 * errno to ENOENT. Normally, an error message is printed, but if
+	 * .silent_exec_failure is set to 1, no message is printed for this
+	 * special error condition.
+	 */
 	unsigned silent_exec_failure:1;
+
 	unsigned stdout_to_stderr:1;
 	unsigned use_shell:1;
 	unsigned clean_on_exit:1;
@@ -49,13 +135,63 @@ struct child_process {
 };
 
 #define CHILD_PROCESS_INIT { NULL, ARGV_ARRAY_INIT, ARGV_ARRAY_INIT }
+
+/**
+ * The functions: child_process_init, start_command, finish_command,
+ * run_command, run_command_v_opt, run_command_v_opt_cd_env, child_process_clear
+ * do the following:
+ *
+ * - If a system call failed, errno is set and -1 is returned. A diagnostic
+ *   is printed.
+ *
+ * - If the program was not found, then -1 is returned and errno is set to
+ *   ENOENT; a diagnostic is printed only if .silent_exec_failure is 0.
+ *
+ * - Otherwise, the program is run. If it terminates regularly, its exit
+ *   code is returned. No diagnostic is printed, even if the exit code is
+ *   non-zero.
+ *
+ * - If the program terminated due to a signal, then the return value is the
+ *   signal number + 128, ie. the same value that a POSIX shell's $? would
+ *   report.  A diagnostic is printed.
+ *
+ */
+
+/**
+ * Initialize a struct child_process variable.
+ */
 void child_process_init(struct child_process *);
+
+/**
+ * Release the memory associated with the struct child_process.
+ * Most users of the run-command API don't need to call this
+ * function explicitly because `start_command` invokes it on
+ * failure and `finish_command` calls it automatically already.
+ */
 void child_process_clear(struct child_process *);
-extern int is_executable(const char *name);
 
+int is_executable(const char *name);
+
+/**
+ * Start a sub-process. Takes a pointer to a `struct child_process`
+ * that specifies the details and returns pipe FDs (if requested).
+ * See below for details.
+ */
 int start_command(struct child_process *);
+
+/**
+ * Wait for the completion of a sub-process that was started with
+ * start_command().
+ */
 int finish_command(struct child_process *);
+
 int finish_command_in_signal(struct child_process *);
+
+/**
+ * A convenience function that encapsulates a sequence of
+ * start_command() followed by finish_command(). Takes a pointer
+ * to a `struct child_process` that specifies the details.
+ */
 int run_command(struct child_process *);
 
 /*
@@ -63,10 +199,24 @@ int run_command(struct child_process *);
  * or disabled. Note that this points to static storage that will be
  * overwritten by further calls to find_hook and run_hook_*.
  */
-extern const char *find_hook(const char *name);
+const char *find_hook(const char *name);
+
+/**
+ * Run a hook.
+ * The first argument is a pathname to an index file, or NULL
+ * if the hook uses the default index file or no index is needed.
+ * The second argument is the name of the hook.
+ * The further arguments correspond to the hook arguments.
+ * The last argument has to be NULL to terminate the arguments list.
+ * If the hook does not exist or is not executable, the return
+ * value will be zero.
+ * If it is executable, the hook will be executed and the exit
+ * status of the hook is returned.
+ * On execution, .stdout_to_stderr and .no_stdin will be set.
+ */
 LAST_ARG_MUST_BE_NULL
-extern int run_hook_le(const char *const *env, const char *name, ...);
-extern int run_hook_ve(const char *const *env, const char *name, va_list args);
+int run_hook_le(const char *const *env, const char *name, ...);
+int run_hook_ve(const char *const *env, const char *name, va_list args);
 
 #define RUN_COMMAND_NO_STDIN 1
 #define RUN_GIT_CMD	     2	/*If this is to be git sub-command */
@@ -74,13 +224,27 @@ extern int run_hook_ve(const char *const
 #define RUN_SILENT_EXEC_FAILURE 8
 #define RUN_USING_SHELL 16
 #define RUN_CLEAN_ON_EXIT 32
-int run_command_v_opt(const char **argv, int opt);
 
+/**
+ * Convenience functions that encapsulate a sequence of
+ * start_command() followed by finish_command(). The argument argv
+ * specifies the program and its arguments. The argument opt is zero
+ * or more of the flags `RUN_COMMAND_NO_STDIN`, `RUN_GIT_CMD`,
+ * `RUN_COMMAND_STDOUT_TO_STDERR`, or `RUN_SILENT_EXEC_FAILURE`
+ * that correspond to the members .no_stdin, .git_cmd,
+ * .stdout_to_stderr, .silent_exec_failure of `struct child_process`.
+ * The argument dir corresponds the member .dir. The argument env
+ * corresponds to the member .env.
+ */
+int run_command_v_opt(const char **argv, int opt);
+int run_command_v_opt_tr2(const char **argv, int opt, const char *tr2_class);
 /*
  * env (the environment) is to be formatted like environ: "VAR=VALUE".
  * To unset an environment variable use just "VAR".
  */
 int run_command_v_opt_cd_env(const char **argv, int opt, const char *dir, const char *const *env);
+int run_command_v_opt_cd_env_tr2(const char **argv, int opt, const char *dir,
+				 const char *const *env, const char *tr2_class);
 
 /**
  * Execute the given command, sending "in" to its stdin, and capturing its
@@ -119,15 +283,84 @@ static inline int capture_command(struct
  * It is expected that no synchronization and mutual exclusion between
  * the caller and the feed function is necessary so that the function
  * can run in a thread without interfering with the caller.
+ *
+ * The caller:
+ *
+ * 1. allocates and clears (memset(&asy, 0, sizeof(asy));) a
+ *    struct async variable;
+ * 2. initializes .proc and .data;
+ * 3. calls start_async();
+ * 4. processes communicates with proc through .in and .out;
+ * 5. closes .in and .out;
+ * 6. calls finish_async().
+ *
+ * There are serious restrictions on what the asynchronous function can do
+ * because this facility is implemented by a thread in the same address
+ * space on most platforms (when pthreads is available), but by a pipe to
+ * a forked process otherwise:
+ *
+ * - It cannot change the program's state (global variables, environment,
+ *   etc.) in a way that the caller notices; in other words, .in and .out
+ *   are the only communication channels to the caller.
+ *
+ * - It must not change the program's state that the caller of the
+ *   facility also uses.
+ *
  */
 struct async {
-	/*
-	 * proc reads from in; closes it before return
-	 * proc writes to out; closes it before return
-	 * returns 0 on success, non-zero on failure
+
+	/**
+	 * The function pointer in .proc has the following signature:
+	 *
+	 *	int proc(int in, int out, void *data);
+	 *
+	 * - in, out specifies a set of file descriptors to which the function
+	 *  must read/write the data that it needs/produces.  The function
+	 *  *must* close these descriptors before it returns.  A descriptor
+	 *  may be -1 if the caller did not configure a descriptor for that
+	 *  direction.
+	 *
+	 * - data is the value that the caller has specified in the .data member
+	 *  of struct async.
+	 *
+	 * - The return value of the function is 0 on success and non-zero
+	 *  on failure. If the function indicates failure, finish_async() will
+	 *  report failure as well.
+	 *
 	 */
 	int (*proc)(int in, int out, void *data);
+
 	void *data;
+
+	/**
+	 * The members .in, .out are used to provide a set of fd's for
+	 * communication between the caller and the callee as follows:
+	 *
+	 * - Specify 0 to have no file descriptor passed.  The callee will
+	 *   receive -1 in the corresponding argument.
+	 *
+	 * - Specify < 0 to have a pipe allocated; start_async() replaces
+	 *   with the pipe FD in the following way:
+	 *
+	 * 	.in: Returns the writable pipe end into which the caller
+	 * 	writes; the readable end of the pipe becomes the function's
+	 * 	in argument.
+	 *
+	 * 	.out: Returns the readable pipe end from which the caller
+	 * 	reads; the writable end of the pipe becomes the function's
+	 * 	out argument.
+	 *
+	 *   The caller of start_async() must close the returned FDs after it
+	 *   has completed reading from/writing from them.
+	 *
+	 * - Specify a file descriptor > 0 to be used by the function:
+	 *
+	 * 	.in: The FD must be readable; it becomes the function's in.
+	 * 	.out: The FD must be writable; it becomes the function's out.
+	 *
+	 *   The specified FD is closed by start_async(), even if it fails to
+	 *   run the function.
+	 */
 	int in;		/* caller writes here and closes it */
 	int out;	/* caller reads from here and closes it */
 #ifdef NO_PTHREADS
@@ -140,9 +373,21 @@ struct async {
 	int isolate_sigpipe;
 };
 
+/**
+ * Run a function asynchronously. Takes a pointer to a `struct
+ * async` that specifies the details and returns a set of pipe FDs
+ * for communication with the function. See below for details.
+ */
 int start_async(struct async *async);
+
+/**
+ * Wait for the completion of an asynchronous function that was
+ * started with start_async().
+ */
 int finish_async(struct async *async);
+
 int in_async(void);
+int async_with_fork(void);
 void check_pipe(int err);
 
 /**
@@ -221,5 +466,8 @@ int run_processes_parallel(int n,
 			   start_failure_fn,
 			   task_finished_fn,
 			   void *pp_cb);
+int run_processes_parallel_tr2(int n, get_next_task_fn, start_failure_fn,
+			       task_finished_fn, void *pp_cb,
+			       const char *tr2_category, const char *tr2_label);
 
 #endif
diff -pruN 1.2.1+git2.18.0-1/git/send-pack.c 1.2.3+git2.25.1-1/git/send-pack.c
--- 1.2.1+git2.18.0-1/git/send-pack.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/send-pack.c	2020-02-17 04:47:35.000000000 +0000
@@ -2,6 +2,7 @@
 #include "config.h"
 #include "commit.h"
 #include "refs.h"
+#include "object-store.h"
 #include "pkt-line.h"
 #include "sideband.h"
 #include "run-command.h"
@@ -39,7 +40,10 @@ int option_parse_push_signed(const struc
 
 static void feed_object(const struct object_id *oid, FILE *fh, int negative)
 {
-	if (negative && !has_sha1_file(oid->hash))
+	if (negative &&
+	    !has_object_file_with_flags(oid,
+					OBJECT_INFO_SKIP_FETCH_OBJECT |
+					OBJECT_INFO_QUICK))
 		return;
 
 	if (negative)
@@ -75,7 +79,7 @@ static int pack_objects(int fd, struct r
 		argv_array_push(&po.args, "-q");
 	if (args->progress)
 		argv_array_push(&po.args, "--progress");
-	if (is_repository_shallow())
+	if (is_repository_shallow(the_repository))
 		argv_array_push(&po.args, "--shallow");
 	po.in = -1;
 	po.out = args->stateless_rpc ? -1 : fd;
@@ -134,38 +138,36 @@ static int pack_objects(int fd, struct r
 	return 0;
 }
 
-static int receive_unpack_status(int in)
+static int receive_unpack_status(struct packet_reader *reader)
 {
-	const char *line = packet_read_line(in, NULL);
-	if (!line)
+	if (packet_reader_read(reader) != PACKET_READ_NORMAL)
 		return error(_("unexpected flush packet while reading remote unpack status"));
-	if (!skip_prefix(line, "unpack ", &line))
-		return error(_("unable to parse remote unpack status: %s"), line);
-	if (strcmp(line, "ok"))
-		return error(_("remote unpack failed: %s"), line);
+	if (!skip_prefix(reader->line, "unpack ", &reader->line))
+		return error(_("unable to parse remote unpack status: %s"), reader->line);
+	if (strcmp(reader->line, "ok"))
+		return error(_("remote unpack failed: %s"), reader->line);
 	return 0;
 }
 
-static int receive_status(int in, struct ref *refs)
+static int receive_status(struct packet_reader *reader, struct ref *refs)
 {
 	struct ref *hint;
 	int ret;
 
 	hint = NULL;
-	ret = receive_unpack_status(in);
+	ret = receive_unpack_status(reader);
 	while (1) {
-		char *refname;
+		const char *refname;
 		char *msg;
-		char *line = packet_read_line(in, NULL);
-		if (!line)
+		if (packet_reader_read(reader) != PACKET_READ_NORMAL)
 			break;
-		if (!starts_with(line, "ok ") && !starts_with(line, "ng ")) {
-			error("invalid ref status from remote: %s", line);
+		if (!starts_with(reader->line, "ok ") && !starts_with(reader->line, "ng ")) {
+			error("invalid ref status from remote: %s", reader->line);
 			ret = -1;
 			break;
 		}
 
-		refname = line + 3;
+		refname = reader->line + 3;
 		msg = strchr(refname, ' ');
 		if (msg)
 			*msg++ = '\0';
@@ -186,7 +188,7 @@ static int receive_status(int in, struct
 			continue;
 		}
 
-		if (line[0] == 'o' && line[1] == 'k')
+		if (reader->line[0] == 'o' && reader->line[1] == 'k')
 			hint->status = REF_STATUS_OK;
 		else {
 			hint->status = REF_STATUS_REMOTE_REJECT;
@@ -202,9 +204,8 @@ static int receive_status(int in, struct
 static int sideband_demux(int in, int out, void *data)
 {
 	int *fd = data, ret;
-#ifdef NO_PTHREADS
-	close(fd[1]);
-#endif
+	if (async_with_fork())
+		close(fd[1]);
 	ret = recv_sideband("send-pack", fd[0], out);
 	close(out);
 	return ret;
@@ -220,7 +221,7 @@ static int advertise_shallow_grafts_cb(c
 
 static void advertise_shallow_grafts_buf(struct strbuf *sb)
 {
-	if (!is_repository_shallow())
+	if (!is_repository_shallow(the_repository))
 		return;
 	for_each_commit_graft(advertise_shallow_grafts_cb, sb);
 }
@@ -390,6 +391,7 @@ int send_pack(struct send_pack_args *arg
 	int ret;
 	struct async demux;
 	const char *push_cert_nonce = NULL;
+	struct packet_reader reader;
 
 	/* Does the other end support the reporting? */
 	if (server_supports("report-status"))
@@ -537,7 +539,7 @@ int send_pack(struct send_pack_args *arg
 	}
 
 	if (args->stateless_rpc) {
-		if (!args->dry_run && (cmds_sent || is_repository_shallow())) {
+		if (!args->dry_run && (cmds_sent || is_repository_shallow(the_repository))) {
 			packet_buf_flush(&req_buf);
 			send_sideband(out, -1, req_buf.buf, req_buf.len, LARGE_PACKET_MAX);
 		}
@@ -559,10 +561,12 @@ int send_pack(struct send_pack_args *arg
 		in = demux.out;
 	}
 
+	packet_reader_init(&reader, in, NULL, 0,
+			   PACKET_READ_CHOMP_NEWLINE |
+			   PACKET_READ_DIE_ON_ERR_PACKET);
+
 	if (need_pack_data && cmds_sent) {
 		if (pack_objects(out, remote_refs, extra_have, args) < 0) {
-			for (ref = remote_refs; ref; ref = ref->next)
-				ref->status = REF_STATUS_NONE;
 			if (args->stateless_rpc)
 				close(out);
 			if (git_connection_is_socket(conn))
@@ -570,10 +574,12 @@ int send_pack(struct send_pack_args *arg
 
 			/*
 			 * Do not even bother with the return value; we know we
-			 * are failing, and just want the error() side effects.
+			 * are failing, and just want the error() side effects,
+			 * as well as marking refs with their remote status (if
+			 * we get one).
 			 */
 			if (status_report)
-				receive_unpack_status(in);
+				receive_status(&reader, remote_refs);
 
 			if (use_sideband) {
 				close(demux.out);
@@ -590,7 +596,7 @@ int send_pack(struct send_pack_args *arg
 		packet_flush(out);
 
 	if (status_report && cmds_sent)
-		ret = receive_status(in, remote_refs);
+		ret = receive_status(&reader, remote_refs);
 	else
 		ret = 0;
 	if (args->stateless_rpc)
diff -pruN 1.2.1+git2.18.0-1/git/send-pack.h 1.2.3+git2.25.1-1/git/send-pack.h
--- 1.2.1+git2.18.0-1/git/send-pack.h	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/send-pack.h	2020-02-17 04:47:35.000000000 +0000
@@ -3,6 +3,10 @@
 
 #include "string-list.h"
 
+struct child_process;
+struct oid_array;
+struct ref;
+
 /* Possible values for push_cert field in send_pack_args. */
 #define SEND_PACK_PUSH_CERT_NEVER 0
 #define SEND_PACK_PUSH_CERT_IF_ASKED 1
diff -pruN 1.2.1+git2.18.0-1/git/sequencer.c 1.2.3+git2.25.1-1/git/sequencer.c
--- 1.2.1+git2.18.0-1/git/sequencer.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/sequencer.c	2020-02-17 04:47:35.000000000 +0000
@@ -2,6 +2,7 @@
 #include "config.h"
 #include "lockfile.h"
 #include "dir.h"
+#include "object-store.h"
 #include "object.h"
 #include "commit.h"
 #include "sequencer.h"
@@ -27,11 +28,14 @@
 #include "worktree.h"
 #include "oidmap.h"
 #include "oidset.h"
+#include "commit-slab.h"
 #include "alias.h"
+#include "commit-reach.h"
+#include "rebase-interactive.h"
 
 #define GIT_REFLOG_ACTION "GIT_REFLOG_ACTION"
 
-const char sign_off_header[] = "Signed-off-by: ";
+static const char sign_off_header[] = "Signed-off-by: ";
 static const char cherry_picked_prefix[] = "(cherry picked from commit ";
 
 GIT_PATH_FUNC(git_path_commit_editmsg, "COMMIT_EDITMSG")
@@ -50,7 +54,9 @@ static GIT_PATH_FUNC(rebase_path, "rebas
  * the lines are processed, they are removed from the front of this
  * file and written to the tail of 'done'.
  */
-static GIT_PATH_FUNC(rebase_path_todo, "rebase-merge/git-rebase-todo")
+GIT_PATH_FUNC(rebase_path_todo, "rebase-merge/git-rebase-todo")
+GIT_PATH_FUNC(rebase_path_todo_backup, "rebase-merge/git-rebase-todo.backup")
+
 /*
  * The rebase command lines that have already been processed. A line
  * is moved here when it is first handled, before any associated user
@@ -61,12 +67,12 @@ static GIT_PATH_FUNC(rebase_path_done, "
  * The file to keep track of how many commands were already processed (e.g.
  * for the prompt).
  */
-static GIT_PATH_FUNC(rebase_path_msgnum, "rebase-merge/msgnum");
+static GIT_PATH_FUNC(rebase_path_msgnum, "rebase-merge/msgnum")
 /*
  * The file to keep track of how many commands are to be processed in total
  * (e.g. for the prompt).
  */
-static GIT_PATH_FUNC(rebase_path_msgtotal, "rebase-merge/end");
+static GIT_PATH_FUNC(rebase_path_msgtotal, "rebase-merge/end")
 /*
  * The commit message that is planned to be used for any changes that
  * need to be committed following a user interaction.
@@ -125,7 +131,7 @@ static GIT_PATH_FUNC(rebase_path_rewritt
 	"rebase-merge/rewritten-pending")
 
 /*
- * The path of the file containig the OID of the "squash onto" commit, i.e.
+ * The path of the file containing the OID of the "squash onto" commit, i.e.
  * the dummy commit used for `reset [new root]`.
  */
 static GIT_PATH_FUNC(rebase_path_squash_onto, "rebase-merge/squash-onto")
@@ -138,11 +144,12 @@ static GIT_PATH_FUNC(rebase_path_refs_to
 
 /*
  * The following files are written by git-rebase just after parsing the
- * command-line (and are only consumed, not modified, by the sequencer).
+ * command-line.
  */
 static GIT_PATH_FUNC(rebase_path_gpg_sign_opt, "rebase-merge/gpg_sign_opt")
 static GIT_PATH_FUNC(rebase_path_orig_head, "rebase-merge/orig-head")
 static GIT_PATH_FUNC(rebase_path_verbose, "rebase-merge/verbose")
+static GIT_PATH_FUNC(rebase_path_quiet, "rebase-merge/quiet")
 static GIT_PATH_FUNC(rebase_path_signoff, "rebase-merge/signoff")
 static GIT_PATH_FUNC(rebase_path_head_name, "rebase-merge/head-name")
 static GIT_PATH_FUNC(rebase_path_onto, "rebase-merge/onto")
@@ -150,6 +157,7 @@ static GIT_PATH_FUNC(rebase_path_autosta
 static GIT_PATH_FUNC(rebase_path_strategy, "rebase-merge/strategy")
 static GIT_PATH_FUNC(rebase_path_strategy_opts, "rebase-merge/strategy_opts")
 static GIT_PATH_FUNC(rebase_path_allow_rerere_autoupdate, "rebase-merge/allow_rerere_autoupdate")
+static GIT_PATH_FUNC(rebase_path_reschedule_failed_exec, "rebase-merge/reschedule-failed-exec")
 
 static int git_sequencer_config(const char *k, const char *v, void *cb)
 {
@@ -163,18 +171,24 @@ static int git_sequencer_config(const ch
 		if (status)
 			return status;
 
-		if (!strcmp(s, "verbatim"))
+		if (!strcmp(s, "verbatim")) {
 			opts->default_msg_cleanup = COMMIT_MSG_CLEANUP_NONE;
-		else if (!strcmp(s, "whitespace"))
+			opts->explicit_cleanup = 1;
+		} else if (!strcmp(s, "whitespace")) {
 			opts->default_msg_cleanup = COMMIT_MSG_CLEANUP_SPACE;
-		else if (!strcmp(s, "strip"))
+			opts->explicit_cleanup = 1;
+		} else if (!strcmp(s, "strip")) {
 			opts->default_msg_cleanup = COMMIT_MSG_CLEANUP_ALL;
-		else if (!strcmp(s, "scissors"))
-			opts->default_msg_cleanup = COMMIT_MSG_CLEANUP_SPACE;
-		else
+			opts->explicit_cleanup = 1;
+		} else if (!strcmp(s, "scissors")) {
+			opts->default_msg_cleanup = COMMIT_MSG_CLEANUP_SCISSORS;
+			opts->explicit_cleanup = 1;
+		} else {
 			warning(_("invalid commit message cleanup mode '%s'"),
 				  s);
+		}
 
+		free((char *)s);
 		return status;
 	}
 
@@ -222,13 +236,16 @@ static const char *get_todo_path(const s
  * Returns 3 when sob exists within conforming footer as last entry
  */
 static int has_conforming_footer(struct strbuf *sb, struct strbuf *sob,
-	int ignore_footer)
+	size_t ignore_footer)
 {
+	struct process_trailer_options opts = PROCESS_TRAILER_OPTIONS_INIT;
 	struct trailer_info info;
-	int i;
+	size_t i;
 	int found_sob = 0, found_sob_last = 0;
 
-	trailer_info_get(&info, sb->buf);
+	opts.no_divider = 1;
+
+	trailer_info_get(&info, sb->buf, &opts);
 
 	if (info.trailer_start == info.trailer_end)
 		return 0;
@@ -262,7 +279,7 @@ static const char *gpg_sign_opt_quoted(s
 int sequencer_remove_state(struct replay_opts *opts)
 {
 	struct strbuf buf = STRBUF_INIT;
-	int i;
+	int i, ret = 0;
 
 	if (is_rebase_i(opts) &&
 	    strbuf_read_file(&buf, rebase_path_refs_to_delete(), 0) > 0) {
@@ -271,8 +288,10 @@ int sequencer_remove_state(struct replay
 			char *eol = strchr(p, '\n');
 			if (eol)
 				*eol = '\0';
-			if (delete_ref("(rebase -i) cleanup", p, NULL, 0) < 0)
+			if (delete_ref("(rebase -i) cleanup", p, NULL, 0) < 0) {
 				warning(_("could not delete '%s'"), p);
+				ret = -1;
+			}
 			if (!eol)
 				break;
 			p = eol + 1;
@@ -288,10 +307,11 @@ int sequencer_remove_state(struct replay
 
 	strbuf_reset(&buf);
 	strbuf_addstr(&buf, get_dir(opts));
-	remove_dir_recursively(&buf, 0);
+	if (remove_dir_recursively(&buf, 0))
+		ret = error(_("could not remove '%s'"), buf.buf);
 	strbuf_release(&buf);
 
-	return 0;
+	return ret;
 }
 
 static const char *action_name(const struct replay_opts *opts)
@@ -304,7 +324,7 @@ static const char *action_name(const str
 	case REPLAY_INTERACTIVE_REBASE:
 		return N_("rebase -i");
 	}
-	die(_("Unknown action: %d"), opts->action);
+	die(_("unknown action: %d"), opts->action);
 }
 
 struct commit_message {
@@ -344,7 +364,8 @@ static void free_message(struct commit *
 	unuse_commit_buffer(commit, msg->message);
 }
 
-static void print_advice(int show_hint, struct replay_opts *opts)
+static void print_advice(struct repository *r, int show_hint,
+			 struct replay_opts *opts)
 {
 	char *msg = getenv("GIT_CHERRY_PICK_HELP");
 
@@ -355,7 +376,7 @@ static void print_advice(int show_hint,
 		 * (typically rebase --interactive) wants to take care
 		 * of the commit itself so remove CHERRY_PICK_HEAD
 		 */
-		unlink(git_path_cherry_pick_head());
+		unlink(git_path_cherry_pick_head(r));
 		return;
 	}
 
@@ -428,14 +449,14 @@ static int read_oneliner(struct strbuf *
 	return 1;
 }
 
-static struct tree *empty_tree(void)
+static struct tree *empty_tree(struct repository *r)
 {
-	return lookup_tree(the_hash_algo->empty_tree);
+	return lookup_tree(r, the_hash_algo->empty_tree);
 }
 
-static int error_dirty_index(struct replay_opts *opts)
+static int error_dirty_index(struct repository *repo, struct replay_opts *opts)
 {
-	if (read_cache_unmerged())
+	if (repo_read_index_unmerged(repo))
 		return error_resolve_conflict(_(action_name(opts)));
 
 	error(_("your local changes would be overwritten by %s."),
@@ -460,15 +481,18 @@ static void update_abort_safety_file(voi
 		write_file(git_path_abort_safety_file(), "%s", "");
 }
 
-static int fast_forward_to(const struct object_id *to, const struct object_id *from,
-			int unborn, struct replay_opts *opts)
+static int fast_forward_to(struct repository *r,
+			   const struct object_id *to,
+			   const struct object_id *from,
+			   int unborn,
+			   struct replay_opts *opts)
 {
 	struct ref_transaction *transaction;
 	struct strbuf sb = STRBUF_INIT;
 	struct strbuf err = STRBUF_INIT;
 
-	read_cache();
-	if (checkout_fast_forward(from, to, 1))
+	repo_read_index(r);
+	if (checkout_fast_forward(r, from, to, 1))
 		return -1; /* the callee should have complained already */
 
 	strbuf_addf(&sb, _("%s: fast-forward"), _(action_name(opts)));
@@ -494,40 +518,85 @@ static int fast_forward_to(const struct
 	return 0;
 }
 
-void append_conflicts_hint(struct strbuf *msgbuf)
+enum commit_msg_cleanup_mode get_cleanup_mode(const char *cleanup_arg,
+	int use_editor)
+{
+	if (!cleanup_arg || !strcmp(cleanup_arg, "default"))
+		return use_editor ? COMMIT_MSG_CLEANUP_ALL :
+				    COMMIT_MSG_CLEANUP_SPACE;
+	else if (!strcmp(cleanup_arg, "verbatim"))
+		return COMMIT_MSG_CLEANUP_NONE;
+	else if (!strcmp(cleanup_arg, "whitespace"))
+		return COMMIT_MSG_CLEANUP_SPACE;
+	else if (!strcmp(cleanup_arg, "strip"))
+		return COMMIT_MSG_CLEANUP_ALL;
+	else if (!strcmp(cleanup_arg, "scissors"))
+		return use_editor ? COMMIT_MSG_CLEANUP_SCISSORS :
+				    COMMIT_MSG_CLEANUP_SPACE;
+	else
+		die(_("Invalid cleanup mode %s"), cleanup_arg);
+}
+
+/*
+ * NB using int rather than enum cleanup_mode to stop clang's
+ * -Wtautological-constant-out-of-range-compare complaining that the comparison
+ * is always true.
+ */
+static const char *describe_cleanup_mode(int cleanup_mode)
+{
+	static const char *modes[] = { "whitespace",
+				       "verbatim",
+				       "scissors",
+				       "strip" };
+
+	if (cleanup_mode < ARRAY_SIZE(modes))
+		return modes[cleanup_mode];
+
+	BUG("invalid cleanup_mode provided (%d)", cleanup_mode);
+}
+
+void append_conflicts_hint(struct index_state *istate,
+	struct strbuf *msgbuf, enum commit_msg_cleanup_mode cleanup_mode)
 {
 	int i;
 
+	if (cleanup_mode == COMMIT_MSG_CLEANUP_SCISSORS) {
+		strbuf_addch(msgbuf, '\n');
+		wt_status_append_cut_line(msgbuf);
+		strbuf_addch(msgbuf, comment_line_char);
+	}
+
 	strbuf_addch(msgbuf, '\n');
 	strbuf_commented_addf(msgbuf, "Conflicts:\n");
-	for (i = 0; i < active_nr;) {
-		const struct cache_entry *ce = active_cache[i++];
+	for (i = 0; i < istate->cache_nr;) {
+		const struct cache_entry *ce = istate->cache[i++];
 		if (ce_stage(ce)) {
 			strbuf_commented_addf(msgbuf, "\t%s\n", ce->name);
-			while (i < active_nr && !strcmp(ce->name,
-							active_cache[i]->name))
+			while (i < istate->cache_nr &&
+			       !strcmp(ce->name, istate->cache[i]->name))
 				i++;
 		}
 	}
 }
 
-static int do_recursive_merge(struct commit *base, struct commit *next,
+static int do_recursive_merge(struct repository *r,
+			      struct commit *base, struct commit *next,
 			      const char *base_label, const char *next_label,
 			      struct object_id *head, struct strbuf *msgbuf,
 			      struct replay_opts *opts)
 {
 	struct merge_options o;
-	struct tree *result, *next_tree, *base_tree, *head_tree;
+	struct tree *next_tree, *base_tree, *head_tree;
 	int clean;
 	char **xopt;
 	struct lock_file index_lock = LOCK_INIT;
 
-	if (hold_locked_index(&index_lock, LOCK_REPORT_ON_ERROR) < 0)
+	if (repo_hold_locked_index(r, &index_lock, LOCK_REPORT_ON_ERROR) < 0)
 		return -1;
 
-	read_cache();
+	repo_read_index(r);
 
-	init_merge_options(&o);
+	init_merge_options(&o, r);
 	o.ancestor = base ? base_label : "(empty tree)";
 	o.branch1 = "HEAD";
 	o.branch2 = next ? next_label : "(empty tree)";
@@ -536,25 +605,24 @@ static int do_recursive_merge(struct com
 	o.show_rename_progress = 1;
 
 	head_tree = parse_tree_indirect(head);
-	next_tree = next ? get_commit_tree(next) : empty_tree();
-	base_tree = base ? get_commit_tree(base) : empty_tree();
+	next_tree = next ? get_commit_tree(next) : empty_tree(r);
+	base_tree = base ? get_commit_tree(base) : empty_tree(r);
 
 	for (xopt = opts->xopts; xopt != opts->xopts + opts->xopts_nr; xopt++)
 		parse_merge_opt(&o, *xopt);
 
 	clean = merge_trees(&o,
 			    head_tree,
-			    next_tree, base_tree, &result);
+			    next_tree, base_tree);
 	if (is_rebase_i(opts) && clean <= 0)
 		fputs(o.obuf.buf, stdout);
 	strbuf_release(&o.obuf);
-	diff_warn_rename_limit("merge.renamelimit", o.needed_rename_limit, 0);
 	if (clean < 0) {
 		rollback_lock_file(&index_lock);
 		return clean;
 	}
 
-	if (write_locked_index(&the_index, &index_lock,
+	if (write_locked_index(r->index, &index_lock,
 			       COMMIT_LOCK | SKIP_IF_UNCHANGED))
 		/*
 		 * TRANSLATORS: %s will be "revert", "cherry-pick" or
@@ -564,34 +632,36 @@ static int do_recursive_merge(struct com
 			_(action_name(opts)));
 
 	if (!clean)
-		append_conflicts_hint(msgbuf);
+		append_conflicts_hint(r->index, msgbuf,
+				      opts->default_msg_cleanup);
 
 	return !clean;
 }
 
-static struct object_id *get_cache_tree_oid(void)
+static struct object_id *get_cache_tree_oid(struct index_state *istate)
 {
-	if (!active_cache_tree)
-		active_cache_tree = cache_tree();
+	if (!istate->cache_tree)
+		istate->cache_tree = cache_tree();
 
-	if (!cache_tree_fully_valid(active_cache_tree))
-		if (cache_tree_update(&the_index, 0)) {
+	if (!cache_tree_fully_valid(istate->cache_tree))
+		if (cache_tree_update(istate, 0)) {
 			error(_("unable to update cache tree"));
 			return NULL;
 		}
 
-	return &active_cache_tree->oid;
+	return &istate->cache_tree->oid;
 }
 
-static int is_index_unchanged(void)
+static int is_index_unchanged(struct repository *r)
 {
 	struct object_id head_oid, *cache_tree_oid;
 	struct commit *head_commit;
+	struct index_state *istate = r->index;
 
 	if (!resolve_ref_unsafe("HEAD", RESOLVE_REF_READING, &head_oid, NULL))
 		return error(_("could not resolve HEAD commit"));
 
-	head_commit = lookup_commit(&head_oid);
+	head_commit = lookup_commit(r, &head_oid);
 
 	/*
 	 * If head_commit is NULL, check_commit, called from
@@ -604,10 +674,10 @@ static int is_index_unchanged(void)
 	if (parse_commit(head_commit))
 		return -1;
 
-	if (!(cache_tree_oid = get_cache_tree_oid()))
+	if (!(cache_tree_oid = get_cache_tree_oid(istate)))
 		return -1;
 
-	return !oidcmp(cache_tree_oid, get_commit_tree_oid(head_commit));
+	return oideq(cache_tree_oid, get_commit_tree_oid(head_commit));
 }
 
 static int write_author_script(const char *message)
@@ -636,7 +706,7 @@ missing_author:
 		else if (*message != '\'')
 			strbuf_addch(&buf, *(message++));
 		else
-			strbuf_addf(&buf, "'\\\\%c'", *(message++));
+			strbuf_addf(&buf, "'\\%c'", *(message++));
 	strbuf_addstr(&buf, "'\nGIT_AUTHOR_EMAIL='");
 	while (*message && *message != '\n' && *message != '\r')
 		if (skip_prefix(message, "> ", &message))
@@ -644,45 +714,144 @@ missing_author:
 		else if (*message != '\'')
 			strbuf_addch(&buf, *(message++));
 		else
-			strbuf_addf(&buf, "'\\\\%c'", *(message++));
+			strbuf_addf(&buf, "'\\%c'", *(message++));
 	strbuf_addstr(&buf, "'\nGIT_AUTHOR_DATE='@");
 	while (*message && *message != '\n' && *message != '\r')
 		if (*message != '\'')
 			strbuf_addch(&buf, *(message++));
 		else
-			strbuf_addf(&buf, "'\\\\%c'", *(message++));
+			strbuf_addf(&buf, "'\\%c'", *(message++));
+	strbuf_addch(&buf, '\'');
 	res = write_message(buf.buf, buf.len, rebase_path_author_script(), 1);
 	strbuf_release(&buf);
 	return res;
 }
 
+/**
+ * Take a series of KEY='VALUE' lines where VALUE part is
+ * sq-quoted, and append <KEY, VALUE> at the end of the string list
+ */
+static int parse_key_value_squoted(char *buf, struct string_list *list)
+{
+	while (*buf) {
+		struct string_list_item *item;
+		char *np;
+		char *cp = strchr(buf, '=');
+		if (!cp) {
+			np = strchrnul(buf, '\n');
+			return error(_("no key present in '%.*s'"),
+				     (int) (np - buf), buf);
+		}
+		np = strchrnul(cp, '\n');
+		*cp++ = '\0';
+		item = string_list_append(list, buf);
+
+		buf = np + (*np == '\n');
+		*np = '\0';
+		cp = sq_dequote(cp);
+		if (!cp)
+			return error(_("unable to dequote value of '%s'"),
+				     item->string);
+		item->util = xstrdup(cp);
+	}
+	return 0;
+}
+
+/**
+ * Reads and parses the state directory's "author-script" file, and sets name,
+ * email and date accordingly.
+ * Returns 0 on success, -1 if the file could not be parsed.
+ *
+ * The author script is of the format:
+ *
+ *	GIT_AUTHOR_NAME='$author_name'
+ *	GIT_AUTHOR_EMAIL='$author_email'
+ *	GIT_AUTHOR_DATE='$author_date'
+ *
+ * where $author_name, $author_email and $author_date are quoted. We are strict
+ * with our parsing, as the file was meant to be eval'd in the now-removed
+ * git-am.sh/git-rebase--interactive.sh scripts, and thus if the file differs
+ * from what this function expects, it is better to bail out than to do
+ * something that the user does not expect.
+ */
+int read_author_script(const char *path, char **name, char **email, char **date,
+		       int allow_missing)
+{
+	struct strbuf buf = STRBUF_INIT;
+	struct string_list kv = STRING_LIST_INIT_DUP;
+	int retval = -1; /* assume failure */
+	int i, name_i = -2, email_i = -2, date_i = -2, err = 0;
+
+	if (strbuf_read_file(&buf, path, 256) <= 0) {
+		strbuf_release(&buf);
+		if (errno == ENOENT && allow_missing)
+			return 0;
+		else
+			return error_errno(_("could not open '%s' for reading"),
+					   path);
+	}
+
+	if (parse_key_value_squoted(buf.buf, &kv))
+		goto finish;
+
+	for (i = 0; i < kv.nr; i++) {
+		if (!strcmp(kv.items[i].string, "GIT_AUTHOR_NAME")) {
+			if (name_i != -2)
+				name_i = error(_("'GIT_AUTHOR_NAME' already given"));
+			else
+				name_i = i;
+		} else if (!strcmp(kv.items[i].string, "GIT_AUTHOR_EMAIL")) {
+			if (email_i != -2)
+				email_i = error(_("'GIT_AUTHOR_EMAIL' already given"));
+			else
+				email_i = i;
+		} else if (!strcmp(kv.items[i].string, "GIT_AUTHOR_DATE")) {
+			if (date_i != -2)
+				date_i = error(_("'GIT_AUTHOR_DATE' already given"));
+			else
+				date_i = i;
+		} else {
+			err = error(_("unknown variable '%s'"),
+				    kv.items[i].string);
+		}
+	}
+	if (name_i == -2)
+		error(_("missing 'GIT_AUTHOR_NAME'"));
+	if (email_i == -2)
+		error(_("missing 'GIT_AUTHOR_EMAIL'"));
+	if (date_i == -2)
+		error(_("missing 'GIT_AUTHOR_DATE'"));
+	if (date_i < 0 || email_i < 0 || date_i < 0 || err)
+		goto finish;
+	*name = kv.items[name_i].util;
+	*email = kv.items[email_i].util;
+	*date = kv.items[date_i].util;
+	retval = 0;
+finish:
+	string_list_clear(&kv, !!retval);
+	strbuf_release(&buf);
+	return retval;
+}
+
 /*
- * Read a list of environment variable assignments (such as the author-script
- * file) into an environment block. Returns -1 on error, 0 otherwise.
+ * Read a GIT_AUTHOR_NAME, GIT_AUTHOR_EMAIL AND GIT_AUTHOR_DATE from a
+ * file with shell quoting into struct argv_array. Returns -1 on
+ * error, 0 otherwise.
  */
 static int read_env_script(struct argv_array *env)
 {
-	struct strbuf script = STRBUF_INIT;
-	int i, count = 0;
-	char *p, *p2;
+	char *name, *email, *date;
 
-	if (strbuf_read_file(&script, rebase_path_author_script(), 256) <= 0)
+	if (read_author_script(rebase_path_author_script(),
+			       &name, &email, &date, 0))
 		return -1;
 
-	for (p = script.buf; *p; p++)
-		if (skip_prefix(p, "'\\\\''", (const char **)&p2))
-			strbuf_splice(&script, p - script.buf, p2 - p, "'", 1);
-		else if (*p == '\'')
-			strbuf_splice(&script, p-- - script.buf, 1, "", 0);
-		else if (*p == '\n') {
-			*p = '\0';
-			count++;
-		}
-
-	for (i = 0, p = script.buf; i < count; i++) {
-		argv_array_push(env, p);
-		p += strlen(p) + 1;
-	}
+	argv_array_pushf(env, "GIT_AUTHOR_NAME=%s", name);
+	argv_array_pushf(env, "GIT_AUTHOR_EMAIL=%s", email);
+	argv_array_pushf(env, "GIT_AUTHOR_DATE=%s", date);
+	free(name);
+	free(email);
+	free(date);
 
 	return 0;
 }
@@ -699,52 +868,6 @@ static char *get_author(const char *mess
 	return NULL;
 }
 
-/* Read author-script and return an ident line (author <email> timestamp) */
-static const char *read_author_ident(struct strbuf *buf)
-{
-	const char *keys[] = {
-		"GIT_AUTHOR_NAME=", "GIT_AUTHOR_EMAIL=", "GIT_AUTHOR_DATE="
-	};
-	char *in, *out, *eol;
-	int i = 0, len;
-
-	if (strbuf_read_file(buf, rebase_path_author_script(), 256) <= 0)
-		return NULL;
-
-	/* dequote values and construct ident line in-place */
-	for (in = out = buf->buf; i < 3 && in - buf->buf < buf->len; i++) {
-		if (!skip_prefix(in, keys[i], (const char **)&in)) {
-			warning("could not parse '%s' (looking for '%s'",
-				rebase_path_author_script(), keys[i]);
-			return NULL;
-		}
-
-		eol = strchrnul(in, '\n');
-		*eol = '\0';
-		sq_dequote(in);
-		len = strlen(in);
-
-		if (i > 0) /* separate values by spaces */
-			*(out++) = ' ';
-		if (i == 1) /* email needs to be surrounded by <...> */
-			*(out++) = '<';
-		memmove(out, in, len);
-		out += len;
-		if (i == 1) /* email needs to be surrounded by <...> */
-			*(out++) = '>';
-		in = eol + 1;
-	}
-
-	if (i < 3) {
-		warning("could not parse '%s' (looking for '%s')",
-			rebase_path_author_script(), keys[i]);
-		return NULL;
-	}
-
-	buf->len = out - buf->buf;
-	return buf->buf;
-}
-
 static const char staged_changes_advice[] =
 N_("you have staged changes in your working tree\n"
 "If these changes are meant to be squashed into the previous commit, run:\n"
@@ -766,6 +889,23 @@ N_("you have staged changes in your work
 #define VERIFY_MSG  (1<<4)
 #define CREATE_ROOT_COMMIT (1<<5)
 
+static int run_command_silent_on_success(struct child_process *cmd)
+{
+	struct strbuf buf = STRBUF_INIT;
+	int rc;
+
+	cmd->stdout_to_stderr = 1;
+	rc = pipe_command(cmd,
+			  NULL, 0,
+			  NULL, 0,
+			  &buf, 0);
+
+	if (rc)
+		fputs(buf.buf, stderr);
+	strbuf_release(&buf);
+	return rc;
+}
+
 /*
  * If we are cherry-pick, and if the merge did not result in
  * hand-editing, we will hit this commit and inherit the original
@@ -778,60 +918,20 @@ N_("you have staged changes in your work
  * interactive rebase: in that case, we will want to retain the
  * author metadata.
  */
-static int run_git_commit(const char *defmsg, struct replay_opts *opts,
+static int run_git_commit(struct repository *r,
+			  const char *defmsg,
+			  struct replay_opts *opts,
 			  unsigned int flags)
 {
 	struct child_process cmd = CHILD_PROCESS_INIT;
-	const char *value;
-
-	if ((flags & CREATE_ROOT_COMMIT) && !(flags & AMEND_MSG)) {
-		struct strbuf msg = STRBUF_INIT, script = STRBUF_INIT;
-		const char *author = is_rebase_i(opts) ?
-			read_author_ident(&script) : NULL;
-		struct object_id root_commit, *cache_tree_oid;
-		int res = 0;
-
-		if (!defmsg)
-			BUG("root commit without message");
-
-		if (!(cache_tree_oid = get_cache_tree_oid()))
-			res = -1;
-
-		if (!res)
-			res = strbuf_read_file(&msg, defmsg, 0);
-
-		if (res <= 0)
-			res = error_errno(_("could not read '%s'"), defmsg);
-		else
-			res = commit_tree(msg.buf, msg.len, cache_tree_oid,
-					  NULL, &root_commit, author,
-					  opts->gpg_sign);
-
-		strbuf_release(&msg);
-		strbuf_release(&script);
-		if (!res) {
-			update_ref(NULL, "CHERRY_PICK_HEAD", &root_commit, NULL,
-				   REF_NO_DEREF, UPDATE_REFS_MSG_ON_ERR);
-			res = update_ref(NULL, "HEAD", &root_commit, NULL, 0,
-					 UPDATE_REFS_MSG_ON_ERR);
-		}
-		return res < 0 ? error(_("writing root commit")) : 0;
-	}
 
 	cmd.git_cmd = 1;
 
-	if (is_rebase_i(opts)) {
-		if (!(flags & EDIT_MSG)) {
-			cmd.stdout_to_stderr = 1;
-			cmd.err = -1;
-		}
-
-		if (read_env_script(&cmd.env_array)) {
-			const char *gpg_opt = gpg_sign_opt_quoted(opts);
+	if (is_rebase_i(opts) && read_env_script(&cmd.env_array)) {
+		const char *gpg_opt = gpg_sign_opt_quoted(opts);
 
-			return error(_(staged_changes_advice),
-				     gpg_opt, gpg_opt);
-		}
+		return error(_(staged_changes_advice),
+			     gpg_opt, gpg_opt);
 	}
 
 	argv_array_push(&cmd.args, "commit");
@@ -852,30 +952,19 @@ static int run_git_commit(const char *de
 		argv_array_push(&cmd.args, "-e");
 	else if (!(flags & CLEANUP_MSG) &&
 		 !opts->signoff && !opts->record_origin &&
-		 git_config_get_value("commit.cleanup", &value))
+		 !opts->explicit_cleanup)
 		argv_array_push(&cmd.args, "--cleanup=verbatim");
 
 	if ((flags & ALLOW_EMPTY))
 		argv_array_push(&cmd.args, "--allow-empty");
 
-	if (opts->allow_empty_message)
+	if (!(flags & EDIT_MSG))
 		argv_array_push(&cmd.args, "--allow-empty-message");
 
-	if (cmd.err == -1) {
-		/* hide stderr on success */
-		struct strbuf buf = STRBUF_INIT;
-		int rc = pipe_command(&cmd,
-				      NULL, 0,
-				      /* stdout is already redirected */
-				      NULL, 0,
-				      &buf, 0);
-		if (rc)
-			fputs(buf.buf, stderr);
-		strbuf_release(&buf);
-		return rc;
-	}
-
-	return run_command(&cmd);
+	if (is_rebase_i(opts) && !(flags & EDIT_MSG))
+		return run_command_silent_on_success(&cmd);
+	else
+		return run_command(&cmd);
 }
 
 static int rest_is_empty(const struct strbuf *sb, int start)
@@ -904,6 +993,16 @@ static int rest_is_empty(const struct st
 	return 1;
 }
 
+void cleanup_message(struct strbuf *msgbuf,
+	enum commit_msg_cleanup_mode cleanup_mode, int verbose)
+{
+	if (verbose || /* Truncate the message just before the diff, if any. */
+	    cleanup_mode == COMMIT_MSG_CLEANUP_SCISSORS)
+		strbuf_setlen(msgbuf, wt_status_locate_end(msgbuf->buf, msgbuf->len));
+	if (cleanup_mode != COMMIT_MSG_CLEANUP_NONE)
+		strbuf_stripspace(msgbuf, cleanup_mode == COMMIT_MSG_CLEANUP_ALL);
+}
+
 /*
  * Find out if the message in the strbuf contains only whitespace and
  * Signed-off-by lines.
@@ -994,6 +1093,7 @@ static int run_rewrite_hook(const struct
 	proc.argv = argv;
 	proc.in = -1;
 	proc.stdout_to_stderr = 1;
+	proc.trace2_hook_name = "post-rewrite";
 
 	code = start_command(&proc);
 	if (code)
@@ -1007,7 +1107,8 @@ static int run_rewrite_hook(const struct
 	return finish_command(&proc);
 }
 
-void commit_post_rewrite(const struct commit *old_head,
+void commit_post_rewrite(struct repository *r,
+			 const struct commit *old_head,
 			 const struct object_id *new_head)
 {
 	struct notes_rewrite_cfg *cfg;
@@ -1016,32 +1117,31 @@ void commit_post_rewrite(const struct co
 	if (cfg) {
 		/* we are amending, so old_head is not NULL */
 		copy_note_for_rewrite(cfg, &old_head->object.oid, new_head);
-		finish_copy_notes_for_rewrite(cfg, "Notes added by 'git commit --amend'");
+		finish_copy_notes_for_rewrite(r, cfg, "Notes added by 'git commit --amend'");
 	}
 	run_rewrite_hook(&old_head->object.oid, new_head);
 }
 
-static int run_prepare_commit_msg_hook(struct strbuf *msg, const char *commit)
+static int run_prepare_commit_msg_hook(struct repository *r,
+				       struct strbuf *msg,
+				       const char *commit)
 {
-	struct argv_array hook_env = ARGV_ARRAY_INIT;
-	int ret;
-	const char *name;
+	int ret = 0;
+	const char *name, *arg1 = NULL, *arg2 = NULL;
 
 	name = git_path_commit_editmsg();
 	if (write_message(msg->buf, msg->len, name, 0))
 		return -1;
 
-	argv_array_pushf(&hook_env, "GIT_INDEX_FILE=%s", get_index_file());
-	argv_array_push(&hook_env, "GIT_EDITOR=:");
-	if (commit)
-		ret = run_hook_le(hook_env.argv, "prepare-commit-msg", name,
-				  "commit", commit, NULL);
-	else
-		ret = run_hook_le(hook_env.argv, "prepare-commit-msg", name,
-				  "message", NULL);
-	if (ret)
+	if (commit) {
+		arg1 = "commit";
+		arg2 = commit;
+	} else {
+		arg1 = "message";
+	}
+	if (run_commit_hook(0, r->index_file, "prepare-commit-msg", name,
+			    arg1, arg2, NULL))
 		ret = error(_("'prepare-commit-msg' hook failed"));
-	argv_array_clear(&hook_env);
 
 	return ret;
 }
@@ -1087,7 +1187,9 @@ static const char *implicit_ident_advice
 
 }
 
-void print_commit_summary(const char *prefix, const struct object_id *oid,
+void print_commit_summary(struct repository *r,
+			  const char *prefix,
+			  const struct object_id *oid,
 			  unsigned int flags)
 {
 	struct rev_info rev;
@@ -1098,7 +1200,7 @@ void print_commit_summary(const char *pr
 	struct strbuf author_ident = STRBUF_INIT;
 	struct strbuf committer_ident = STRBUF_INIT;
 
-	commit = lookup_commit(oid);
+	commit = lookup_commit(r, oid);
 	if (!commit)
 		die(_("couldn't look up newly created commit"));
 	if (parse_commit(commit))
@@ -1131,7 +1233,7 @@ void print_commit_summary(const char *pr
 	strbuf_release(&author_ident);
 	strbuf_release(&committer_ident);
 
-	init_revisions(&rev, prefix);
+	repo_init_revisions(r, &rev, prefix);
 	setup_revisions(0, NULL, &rev, NULL);
 
 	rev.diff = 1;
@@ -1165,7 +1267,7 @@ void print_commit_summary(const char *pr
 	strbuf_release(&format);
 }
 
-static int parse_head(struct commit **head)
+static int parse_head(struct repository *r, struct commit **head)
 {
 	struct commit *current_head;
 	struct object_id oid;
@@ -1173,10 +1275,10 @@ static int parse_head(struct commit **he
 	if (get_oid("HEAD", &oid)) {
 		current_head = NULL;
 	} else {
-		current_head = lookup_commit_reference(&oid);
+		current_head = lookup_commit_reference(r, &oid);
 		if (!current_head)
 			return error(_("could not parse HEAD"));
-		if (oidcmp(&oid, &current_head->object.oid)) {
+		if (!oideq(&oid, &current_head->object.oid)) {
 			warning(_("HEAD %s is not a commit!"),
 				oid_to_hex(&oid));
 		}
@@ -1197,12 +1299,13 @@ static int parse_head(struct commit **he
  *   0 - success
  *   1 - run 'git commit'
  */
-static int try_to_commit(struct strbuf *msg, const char *author,
+static int try_to_commit(struct repository *r,
+			 struct strbuf *msg, const char *author,
 			 struct replay_opts *opts, unsigned int flags,
 			 struct object_id *oid)
 {
 	struct object_id tree;
-	struct commit *current_head;
+	struct commit *current_head = NULL;
 	struct commit_list *parents = NULL;
 	struct commit_extra_header *extra = NULL;
 	struct strbuf err = STRBUF_INIT;
@@ -1212,7 +1315,7 @@ static int try_to_commit(struct strbuf *
 	enum commit_msg_cleanup_mode cleanup;
 	int res = 0;
 
-	if (parse_head(&current_head))
+	if (parse_head(r, &current_head))
 		return -1;
 
 	if (flags & AMEND_MSG) {
@@ -1237,24 +1340,41 @@ static int try_to_commit(struct strbuf *
 		}
 		parents = copy_commit_list(current_head->parents);
 		extra = read_commit_extra_headers(current_head, exclude_gpgsig);
-	} else if (current_head) {
+	} else if (current_head &&
+		   (!(flags & CREATE_ROOT_COMMIT) || (flags & AMEND_MSG))) {
 		commit_list_insert(current_head, &parents);
 	}
 
-	if (write_cache_as_tree(&tree, 0, NULL)) {
+	if (write_index_as_tree(&tree, r->index, r->index_file, 0, NULL)) {
 		res = error(_("git write-tree failed to write a tree"));
 		goto out;
 	}
 
-	if (!(flags & ALLOW_EMPTY) && !oidcmp(current_head ?
-					      get_commit_tree_oid(current_head) :
-					      the_hash_algo->empty_tree, &tree)) {
-		res = 1; /* run 'git commit' to display error message */
-		goto out;
+	if (!(flags & ALLOW_EMPTY)) {
+		struct commit *first_parent = current_head;
+
+		if (flags & AMEND_MSG) {
+			if (current_head->parents) {
+				first_parent = current_head->parents->item;
+				if (repo_parse_commit(r, first_parent)) {
+					res = error(_("could not parse HEAD commit"));
+					goto out;
+				}
+			} else {
+				first_parent = NULL;
+			}
+		}
+		if (oideq(first_parent
+			  ? get_commit_tree_oid(first_parent)
+			  : the_hash_algo->empty_tree,
+			  &tree)) {
+			res = 1; /* run 'git commit' to display error message */
+			goto out;
+		}
 	}
 
 	if (find_hook("prepare-commit-msg")) {
-		res = run_prepare_commit_msg_hook(msg, hook_commit);
+		res = run_prepare_commit_msg_hook(r, msg, hook_commit);
 		if (res)
 			goto out;
 		if (strbuf_read_file(&commit_msg, git_path_commit_editmsg(),
@@ -1267,12 +1387,17 @@ static int try_to_commit(struct strbuf *
 		msg = &commit_msg;
 	}
 
-	cleanup = (flags & CLEANUP_MSG) ? COMMIT_MSG_CLEANUP_ALL :
-					  opts->default_msg_cleanup;
+	if (flags & CLEANUP_MSG)
+		cleanup = COMMIT_MSG_CLEANUP_ALL;
+	else if ((opts->signoff || opts->record_origin) &&
+		 !opts->explicit_cleanup)
+		cleanup = COMMIT_MSG_CLEANUP_SPACE;
+	else
+		cleanup = opts->default_msg_cleanup;
 
 	if (cleanup != COMMIT_MSG_CLEANUP_NONE)
 		strbuf_stripspace(msg, cleanup == COMMIT_MSG_CLEANUP_ALL);
-	if (!opts->allow_empty_message && message_is_empty(msg, cleanup)) {
+	if ((flags & EDIT_MSG) && message_is_empty(msg, cleanup)) {
 		res = 1; /* run 'git commit' to display error message */
 		goto out;
 	}
@@ -1291,8 +1416,9 @@ static int try_to_commit(struct strbuf *
 		goto out;
 	}
 
+	run_commit_hook(0, r->index_file, "post-commit", NULL);
 	if (flags & AMEND_MSG)
-		commit_post_rewrite(current_head, oid);
+		commit_post_rewrite(r, current_head, oid);
 
 out:
 	free_commit_extra_headers(extra);
@@ -1303,13 +1429,13 @@ out:
 	return res;
 }
 
-static int do_commit(const char *msg_file, const char *author,
+static int do_commit(struct repository *r,
+		     const char *msg_file, const char *author,
 		     struct replay_opts *opts, unsigned int flags)
 {
 	int res = 1;
 
-	if (!(flags & EDIT_MSG) && !(flags & VERIFY_MSG) &&
-	    !(flags & CREATE_ROOT_COMMIT)) {
+	if (!(flags & EDIT_MSG) && !(flags & VERIFY_MSG)) {
 		struct object_id oid;
 		struct strbuf sb = STRBUF_INIT;
 
@@ -1318,20 +1444,20 @@ static int do_commit(const char *msg_fil
 					     "from '%s'"),
 					   msg_file);
 
-		res = try_to_commit(msg_file ? &sb : NULL, author, opts, flags,
-				    &oid);
+		res = try_to_commit(r, msg_file ? &sb : NULL,
+				    author, opts, flags, &oid);
 		strbuf_release(&sb);
 		if (!res) {
-			unlink(git_path_cherry_pick_head());
-			unlink(git_path_merge_msg());
+			unlink(git_path_cherry_pick_head(r));
+			unlink(git_path_merge_msg(r));
 			if (!is_rebase_i(opts))
-				print_commit_summary(NULL, &oid,
+				print_commit_summary(r, NULL, &oid,
 						SUMMARY_SHOW_AUTHOR_DATE);
 			return res;
 		}
 	}
 	if (res == 1)
-		return run_git_commit(msg_file, opts, flags);
+		return run_git_commit(r, msg_file, opts, flags);
 
 	return res;
 }
@@ -1353,13 +1479,15 @@ static int is_original_commit_empty(stru
 		ptree_oid = the_hash_algo->empty_tree; /* commit is root */
 	}
 
-	return !oidcmp(ptree_oid, get_commit_tree_oid(commit));
+	return oideq(ptree_oid, get_commit_tree_oid(commit));
 }
 
 /*
  * Do we run "git commit" with "--allow-empty"?
  */
-static int allow_empty(struct replay_opts *opts, struct commit *commit)
+static int allow_empty(struct repository *r,
+		       struct replay_opts *opts,
+		       struct commit *commit)
 {
 	int index_unchanged, empty_commit;
 
@@ -1376,7 +1504,7 @@ static int allow_empty(struct replay_opt
 	if (!opts->allow_empty)
 		return 0; /* let "git commit" barf as necessary */
 
-	index_unchanged = is_index_unchanged();
+	index_unchanged = is_index_unchanged(r);
 	if (index_unchanged < 0)
 		return index_unchanged;
 	if (!index_unchanged)
@@ -1394,31 +1522,6 @@ static int allow_empty(struct replay_opt
 		return 1;
 }
 
-/*
- * Note that ordering matters in this enum. Not only must it match the mapping
- * below, it is also divided into several sections that matter.  When adding
- * new commands, make sure you add it in the right section.
- */
-enum todo_command {
-	/* commands that handle commits */
-	TODO_PICK = 0,
-	TODO_REVERT,
-	TODO_EDIT,
-	TODO_REWORD,
-	TODO_FIXUP,
-	TODO_SQUASH,
-	/* commands that do something else than handling a single commit */
-	TODO_EXEC,
-	TODO_LABEL,
-	TODO_RESET,
-	TODO_MERGE,
-	/* commands that do nothing but are counted for reporting progress */
-	TODO_NOOP,
-	TODO_DROP,
-	/* comments (not counted for reporting progress) */
-	TODO_COMMENT
-};
-
 static struct {
 	char c;
 	const char *str;
@@ -1430,6 +1533,7 @@ static struct {
 	{ 'f', "fixup" },
 	{ 's', "squash" },
 	{ 'x', "exec" },
+	{ 'b', "break" },
 	{ 'l', "label" },
 	{ 't', "reset" },
 	{ 'm', "merge" },
@@ -1442,7 +1546,7 @@ static const char *command_to_string(con
 {
 	if (command < TODO_COMMENT)
 		return todo_command_info[command].str;
-	die("Unknown command: %d", command);
+	die(_("unknown command: %d"), command);
 }
 
 static char command_to_char(const enum todo_command command)
@@ -1478,12 +1582,15 @@ static int is_pick_or_similar(enum todo_
 	}
 }
 
-static int update_squash_messages(enum todo_command command,
-		struct commit *commit, struct replay_opts *opts)
+static int update_squash_messages(struct repository *r,
+				  enum todo_command command,
+				  struct commit *commit,
+				  struct replay_opts *opts)
 {
 	struct strbuf buf = STRBUF_INIT;
 	int res;
 	const char *message, *body;
+	const char *encoding = get_commit_output_encoding();
 
 	if (opts->current_fixup_count > 0) {
 		struct strbuf header = STRBUF_INIT;
@@ -1508,9 +1615,9 @@ static int update_squash_messages(enum t
 
 		if (get_oid("HEAD", &head))
 			return error(_("need a HEAD to fixup"));
-		if (!(head_commit = lookup_commit_reference(&head)))
+		if (!(head_commit = lookup_commit_reference(r, &head)))
 			return error(_("could not read HEAD"));
-		if (!(head_message = get_commit_buffer(head_commit, NULL)))
+		if (!(head_message = logmsg_reencode(head_commit, NULL, encoding)))
 			return error(_("could not read HEAD's commit message"));
 
 		find_commit_subject(head_message, &body);
@@ -1531,7 +1638,7 @@ static int update_squash_messages(enum t
 		unuse_commit_buffer(head_commit, head_message);
 	}
 
-	if (!(message = get_commit_buffer(commit, NULL)))
+	if (!(message = logmsg_reencode(commit, NULL, encoding)))
 		return error(_("could not read commit message of %s"),
 			     oid_to_hex(&commit->object.oid));
 	find_commit_subject(message, &body);
@@ -1540,13 +1647,13 @@ static int update_squash_messages(enum t
 		unlink(rebase_path_fixup_msg());
 		strbuf_addf(&buf, "\n%c ", comment_line_char);
 		strbuf_addf(&buf, _("This is the commit message #%d:"),
-			    ++opts->current_fixup_count);
+			    ++opts->current_fixup_count + 1);
 		strbuf_addstr(&buf, "\n\n");
 		strbuf_addstr(&buf, body);
 	} else if (command == TODO_FIXUP) {
 		strbuf_addf(&buf, "\n%c ", comment_line_char);
 		strbuf_addf(&buf, _("The commit message #%d will be skipped:"),
-			    ++opts->current_fixup_count);
+			    ++opts->current_fixup_count + 1);
 		strbuf_addstr(&buf, "\n\n");
 		strbuf_add_commented_lines(&buf, body, strlen(body));
 	} else
@@ -1569,7 +1676,8 @@ static int update_squash_messages(enum t
 	return res;
 }
 
-static void flush_rewritten_pending(void) {
+static void flush_rewritten_pending(void)
+{
 	struct strbuf buf = STRBUF_INIT;
 	struct object_id newoid;
 	FILE *out;
@@ -1594,7 +1702,8 @@ static void flush_rewritten_pending(void
 }
 
 static void record_in_rewritten(struct object_id *oid,
-		enum todo_command next_command) {
+		enum todo_command next_command)
+{
 	FILE *out = fopen_or_warn(rebase_path_rewritten_pending(), "a");
 
 	if (!out)
@@ -1607,18 +1716,21 @@ static void record_in_rewritten(struct o
 		flush_rewritten_pending();
 }
 
-static int do_pick_commit(enum todo_command command, struct commit *commit,
-		struct replay_opts *opts, int final_fixup)
+static int do_pick_commit(struct repository *r,
+			  enum todo_command command,
+			  struct commit *commit,
+			  struct replay_opts *opts,
+			  int final_fixup, int *check_todo)
 {
 	unsigned int flags = opts->edit ? EDIT_MSG : 0;
-	const char *msg_file = opts->edit ? NULL : git_path_merge_msg();
+	const char *msg_file = opts->edit ? NULL : git_path_merge_msg(r);
 	struct object_id head;
 	struct commit *base, *next, *parent;
 	const char *base_label, *next_label;
 	char *author = NULL;
 	struct commit_message msg = { NULL, NULL, NULL, NULL };
 	struct strbuf msgbuf = STRBUF_INIT;
-	int res, unborn = 0, allow;
+	int res, unborn = 0, reword = 0, allow;
 
 	if (opts->no_commit) {
 		/*
@@ -1627,24 +1739,24 @@ static int do_pick_commit(enum todo_comm
 		 * that represents the "current" state for merge-recursive
 		 * to work on.
 		 */
-		if (write_cache_as_tree(&head, 0, NULL))
+		if (write_index_as_tree(&head, r->index, r->index_file, 0, NULL))
 			return error(_("your index file is unmerged."));
 	} else {
 		unborn = get_oid("HEAD", &head);
 		/* Do we want to generate a root commit? */
 		if (is_pick_or_similar(command) && opts->have_squash_onto &&
-		    !oidcmp(&head, &opts->squash_onto)) {
+		    oideq(&head, &opts->squash_onto)) {
 			if (is_fixup(command))
 				return error(_("cannot fixup root commit"));
 			flags |= CREATE_ROOT_COMMIT;
 			unborn = 1;
 		} else if (unborn)
 			oidcpy(&head, the_hash_algo->empty_tree);
-		if (index_differs_from(unborn ? empty_tree_oid_hex() : "HEAD",
+		if (index_differs_from(r, unborn ? empty_tree_oid_hex() : "HEAD",
 				       NULL, 0))
-			return error_dirty_index(opts);
+			return error_dirty_index(r, opts);
 	}
-	discard_cache();
+	discard_index(r->index);
 
 	if (!commit->parents)
 		parent = NULL;
@@ -1665,9 +1777,13 @@ static int do_pick_commit(enum todo_comm
 			return error(_("commit %s does not have parent %d"),
 				oid_to_hex(&commit->object.oid), opts->mainline);
 		parent = p->item;
-	} else if (0 < opts->mainline)
-		return error(_("mainline was specified but commit %s is not a merge."),
-			oid_to_hex(&commit->object.oid));
+	} else if (1 < opts->mainline)
+		/*
+		 *  Non-first parent explicitly specified as mainline for
+		 *  non-merge commit
+		 */
+		return error(_("commit %s does not have parent %d"),
+			     oid_to_hex(&commit->object.oid), opts->mainline);
 	else
 		parent = commit->parents->item;
 
@@ -1676,15 +1792,15 @@ static int do_pick_commit(enum todo_comm
 			oid_to_hex(&commit->object.oid));
 
 	if (opts->allow_ff && !is_fixup(command) &&
-	    ((parent && !oidcmp(&parent->object.oid, &head)) ||
+	    ((parent && oideq(&parent->object.oid, &head)) ||
 	     (!parent && unborn))) {
 		if (is_rebase_i(opts))
 			write_author_script(msg.message);
-		res = fast_forward_to(&commit->object.oid, &head, unborn,
+		res = fast_forward_to(r, &commit->object.oid, &head, unborn,
 			opts);
 		if (res || command != TODO_REWORD)
 			goto leave;
-		flags |= EDIT_MSG | AMEND_MSG | VERIFY_MSG;
+		reword = 1;
 		msg_file = NULL;
 		goto fast_forward_edit;
 	}
@@ -1742,9 +1858,9 @@ static int do_pick_commit(enum todo_comm
 	}
 
 	if (command == TODO_REWORD)
-		flags |= EDIT_MSG | VERIFY_MSG;
+		reword = 1;
 	else if (is_fixup(command)) {
-		if (update_squash_messages(command, commit, opts))
+		if (update_squash_messages(r, command, commit, opts))
 			return -1;
 		flags |= AMEND_MSG;
 		if (!final_fixup)
@@ -1753,12 +1869,12 @@ static int do_pick_commit(enum todo_comm
 			flags |= CLEANUP_MSG;
 			msg_file = rebase_path_fixup_msg();
 		} else {
-			const char *dest = git_path_squash_msg();
+			const char *dest = git_path_squash_msg(r);
 			unlink(dest);
 			if (copy_file(dest, rebase_path_squash_msg(), 0666))
 				return error(_("could not rename '%s' to '%s'"),
 					     rebase_path_squash_msg(), dest);
-			unlink(git_path_merge_msg());
+			unlink(git_path_merge_msg(r));
 			msg_file = dest;
 			flags |= EDIT_MSG;
 		}
@@ -1770,22 +1886,23 @@ static int do_pick_commit(enum todo_comm
 	if (is_rebase_i(opts) && write_author_script(msg.message) < 0)
 		res = -1;
 	else if (!opts->strategy || !strcmp(opts->strategy, "recursive") || command == TODO_REVERT) {
-		res = do_recursive_merge(base, next, base_label, next_label,
+		res = do_recursive_merge(r, base, next, base_label, next_label,
 					 &head, &msgbuf, opts);
 		if (res < 0)
-			return res;
+			goto leave;
+
 		res |= write_message(msgbuf.buf, msgbuf.len,
-				     git_path_merge_msg(), 0);
+				     git_path_merge_msg(r), 0);
 	} else {
 		struct commit_list *common = NULL;
 		struct commit_list *remotes = NULL;
 
 		res = write_message(msgbuf.buf, msgbuf.len,
-				    git_path_merge_msg(), 0);
+				    git_path_merge_msg(r), 0);
 
 		commit_list_insert(base, &common);
 		commit_list_insert(next, &remotes);
-		res |= try_merge_command(opts->strategy,
+		res |= try_merge_command(r, opts->strategy,
 					 opts->xopts_nr, (const char **)opts->xopts,
 					common, oid_to_hex(&head), remotes);
 		free_commit_list(common);
@@ -1813,25 +1930,33 @@ static int do_pick_commit(enum todo_comm
 		      ? _("could not revert %s... %s")
 		      : _("could not apply %s... %s"),
 		      short_commit_name(commit), msg.subject);
-		print_advice(res == 1, opts);
-		rerere(opts->allow_rerere_auto);
+		print_advice(r, res == 1, opts);
+		repo_rerere(r, opts->allow_rerere_auto);
 		goto leave;
 	}
 
-	allow = allow_empty(opts, commit);
+	allow = allow_empty(r, opts, commit);
 	if (allow < 0) {
 		res = allow;
 		goto leave;
 	} else if (allow)
 		flags |= ALLOW_EMPTY;
 	if (!opts->no_commit) {
-fast_forward_edit:
 		if (author || command == TODO_REVERT || (flags & AMEND_MSG))
-			res = do_commit(msg_file, author, opts, flags);
+			res = do_commit(r, msg_file, author, opts, flags);
 		else
 			res = error(_("unable to parse commit author"));
+		*check_todo = !!(flags & EDIT_MSG);
+		if (!res && reword) {
+fast_forward_edit:
+			res = run_git_commit(r, NULL, opts, EDIT_MSG |
+					     VERIFY_MSG | AMEND_MSG |
+					     (flags & ALLOW_EMPTY));
+			*check_todo = 1;
+		}
 	}
 
+
 	if (!res && final_fixup) {
 		unlink(rebase_path_fixup_msg());
 		unlink(rebase_path_squash_msg());
@@ -1860,23 +1985,22 @@ static int prepare_revs(struct replay_op
 	if (prepare_revision_walk(opts->revs))
 		return error(_("revision walk setup failed"));
 
-	if (!opts->revs->commits)
-		return error(_("empty commit set passed"));
 	return 0;
 }
 
-static int read_and_refresh_cache(struct replay_opts *opts)
+static int read_and_refresh_cache(struct repository *r,
+				  struct replay_opts *opts)
 {
 	struct lock_file index_lock = LOCK_INIT;
-	int index_fd = hold_locked_index(&index_lock, 0);
-	if (read_index_preload(&the_index, NULL) < 0) {
+	int index_fd = repo_hold_locked_index(r, &index_lock, 0);
+	if (repo_read_index(r) < 0) {
 		rollback_lock_file(&index_lock);
 		return error(_("git %s: failed to read the index"),
 			_(action_name(opts)));
 	}
-	refresh_index(&the_index, REFRESH_QUIET|REFRESH_UNMERGED, NULL, NULL, NULL);
+	refresh_index(r->index, REFRESH_QUIET|REFRESH_UNMERGED, NULL, NULL, NULL);
 	if (index_fd >= 0) {
-		if (write_locked_index(&the_index, &index_lock,
+		if (write_locked_index(r->index, &index_lock,
 				       COMMIT_LOCK | SKIP_IF_UNCHANGED)) {
 			return error(_("git %s: failed to refresh the index"),
 				_(action_name(opts)));
@@ -1889,26 +2013,7 @@ enum todo_item_flags {
 	TODO_EDIT_MERGE_MSG = 1
 };
 
-struct todo_item {
-	enum todo_command command;
-	struct commit *commit;
-	unsigned int flags;
-	const char *arg;
-	int arg_len;
-	size_t offset_in_buf;
-};
-
-struct todo_list {
-	struct strbuf buf;
-	struct todo_item *items;
-	int nr, alloc, current;
-	int done_nr, total_nr;
-	struct stat_data stat;
-};
-
-#define TODO_LIST_INIT { STRBUF_INIT }
-
-static void todo_list_release(struct todo_list *todo_list)
+void todo_list_release(struct todo_list *todo_list)
 {
 	strbuf_release(&todo_list->buf);
 	FREE_AND_NULL(todo_list->items);
@@ -1918,10 +2023,30 @@ static void todo_list_release(struct tod
 static struct todo_item *append_new_todo(struct todo_list *todo_list)
 {
 	ALLOC_GROW(todo_list->items, todo_list->nr + 1, todo_list->alloc);
+	todo_list->total_nr++;
 	return todo_list->items + todo_list->nr++;
 }
 
-static int parse_insn_line(struct todo_item *item, const char *bol, char *eol)
+const char *todo_item_get_arg(struct todo_list *todo_list,
+			      struct todo_item *item)
+{
+	return todo_list->buf.buf + item->arg_offset;
+}
+
+static int is_command(enum todo_command command, const char **bol)
+{
+	const char *str = todo_command_info[command].str;
+	const char nick = todo_command_info[command].c;
+	const char *p = *bol + 1;
+
+	return skip_prefix(*bol, str, bol) ||
+		((nick && **bol == nick) &&
+		 (*p == ' ' || *p == '\t' || *p == '\n' || *p == '\r' || !*p) &&
+		 (*bol = p));
+}
+
+static int parse_insn_line(struct repository *r, struct todo_item *item,
+			   const char *buf, const char *bol, char *eol)
 {
 	struct object_id commit_oid;
 	char *end_of_object_name;
@@ -1935,17 +2060,13 @@ static int parse_insn_line(struct todo_i
 	if (bol == eol || *bol == '\r' || *bol == comment_line_char) {
 		item->command = TODO_COMMENT;
 		item->commit = NULL;
-		item->arg = bol;
+		item->arg_offset = bol - buf;
 		item->arg_len = eol - bol;
 		return 0;
 	}
 
 	for (i = 0; i < TODO_COMMENT; i++)
-		if (skip_prefix(bol, todo_command_info[i].str, &bol)) {
-			item->command = i;
-			break;
-		} else if (bol[1] == ' ' && *bol == todo_command_info[i].c) {
-			bol++;
+		if (is_command(i, &bol)) {
 			item->command = i;
 			break;
 		}
@@ -1956,12 +2077,12 @@ static int parse_insn_line(struct todo_i
 	padding = strspn(bol, " \t");
 	bol += padding;
 
-	if (item->command == TODO_NOOP) {
+	if (item->command == TODO_NOOP || item->command == TODO_BREAK) {
 		if (bol != eol)
 			return error(_("%s does not accept arguments: '%s'"),
 				     command_to_string(item->command), bol);
 		item->commit = NULL;
-		item->arg = bol;
+		item->arg_offset = bol - buf;
 		item->arg_len = eol - bol;
 		return 0;
 	}
@@ -1973,7 +2094,7 @@ static int parse_insn_line(struct todo_i
 	if (item->command == TODO_EXEC || item->command == TODO_LABEL ||
 	    item->command == TODO_RESET) {
 		item->commit = NULL;
-		item->arg = bol;
+		item->arg_offset = bol - buf;
 		item->arg_len = (int)(eol - bol);
 		return 0;
 	}
@@ -1987,7 +2108,7 @@ static int parse_insn_line(struct todo_i
 		} else {
 			item->flags |= TODO_EDIT_MERGE_MSG;
 			item->commit = NULL;
-			item->arg = bol;
+			item->arg_offset = bol - buf;
 			item->arg_len = (int)(eol - bol);
 			return 0;
 		}
@@ -1999,22 +2120,54 @@ static int parse_insn_line(struct todo_i
 	status = get_oid(bol, &commit_oid);
 	*end_of_object_name = saved;
 
-	item->arg = end_of_object_name + strspn(end_of_object_name, " \t");
-	item->arg_len = (int)(eol - item->arg);
+	bol = end_of_object_name + strspn(end_of_object_name, " \t");
+	item->arg_offset = bol - buf;
+	item->arg_len = (int)(eol - bol);
 
 	if (status < 0)
-		return -1;
+		return error(_("could not parse '%.*s'"),
+			     (int)(end_of_object_name - bol), bol);
 
-	item->commit = lookup_commit_reference(&commit_oid);
+	item->commit = lookup_commit_reference(r, &commit_oid);
 	return !item->commit;
 }
 
-static int parse_insn_buffer(char *buf, struct todo_list *todo_list)
+int sequencer_get_last_command(struct repository *r, enum replay_action *action)
+{
+	const char *todo_file, *bol;
+	struct strbuf buf = STRBUF_INIT;
+	int ret = 0;
+
+	todo_file = git_path_todo_file();
+	if (strbuf_read_file(&buf, todo_file, 0) < 0) {
+		if (errno == ENOENT || errno == ENOTDIR)
+			return -1;
+		else
+			return error_errno("unable to open '%s'", todo_file);
+	}
+	bol = buf.buf + strspn(buf.buf, " \t\r\n");
+	if (is_command(TODO_PICK, &bol) && (*bol == ' ' || *bol == '\t'))
+		*action = REPLAY_PICK;
+	else if (is_command(TODO_REVERT, &bol) &&
+		 (*bol == ' ' || *bol == '\t'))
+		*action = REPLAY_REVERT;
+	else
+		ret = -1;
+
+	strbuf_release(&buf);
+
+	return ret;
+}
+
+int todo_list_parse_insn_buffer(struct repository *r, char *buf,
+				struct todo_list *todo_list)
 {
 	struct todo_item *item;
 	char *p = buf, *next_p;
 	int i, res = 0, fixup_okay = file_exists(rebase_path_done());
 
+	todo_list->current = todo_list->nr = 0;
+
 	for (i = 1; *p; i++, p = next_p) {
 		char *eol = strchrnul(p, '\n');
 
@@ -2025,10 +2178,13 @@ static int parse_insn_buffer(char *buf,
 
 		item = append_new_todo(todo_list);
 		item->offset_in_buf = p - todo_list->buf.buf;
-		if (parse_insn_line(item, p, eol)) {
+		if (parse_insn_line(r, item, buf, p, eol)) {
 			res = error(_("invalid line %d: %.*s"),
 				i, (int)(eol - p), p);
-			item->command = TODO_NOOP;
+			item->command = TODO_COMMENT + 1;
+			item->arg_offset = p - buf;
+			item->arg_len = (int)(eol - p);
+			item->commit = NULL;
 		}
 
 		if (fixup_okay)
@@ -2086,8 +2242,72 @@ static ssize_t strbuf_read_file_or_whine
 	return len;
 }
 
-static int read_populate_todo(struct todo_list *todo_list,
-			struct replay_opts *opts)
+static int have_finished_the_last_pick(void)
+{
+	struct strbuf buf = STRBUF_INIT;
+	const char *eol;
+	const char *todo_path = git_path_todo_file();
+	int ret = 0;
+
+	if (strbuf_read_file(&buf, todo_path, 0) < 0) {
+		if (errno == ENOENT) {
+			return 0;
+		} else {
+			error_errno("unable to open '%s'", todo_path);
+			return 0;
+		}
+	}
+	/* If there is only one line then we are done */
+	eol = strchr(buf.buf, '\n');
+	if (!eol || !eol[1])
+		ret = 1;
+
+	strbuf_release(&buf);
+
+	return ret;
+}
+
+void sequencer_post_commit_cleanup(struct repository *r, int verbose)
+{
+	struct replay_opts opts = REPLAY_OPTS_INIT;
+	int need_cleanup = 0;
+
+	if (file_exists(git_path_cherry_pick_head(r))) {
+		if (!unlink(git_path_cherry_pick_head(r)) && verbose)
+			warning(_("cancelling a cherry picking in progress"));
+		opts.action = REPLAY_PICK;
+		need_cleanup = 1;
+	}
+
+	if (file_exists(git_path_revert_head(r))) {
+		if (!unlink(git_path_revert_head(r)) && verbose)
+			warning(_("cancelling a revert in progress"));
+		opts.action = REPLAY_REVERT;
+		need_cleanup = 1;
+	}
+
+	if (!need_cleanup)
+		return;
+
+	if (!have_finished_the_last_pick())
+		return;
+
+	sequencer_remove_state(&opts);
+}
+
+static void todo_list_write_total_nr(struct todo_list *todo_list)
+{
+	FILE *f = fopen_or_warn(rebase_path_msgtotal(), "w");
+
+	if (f) {
+		fprintf(f, "%d\n", todo_list->total_nr);
+		fclose(f);
+	}
+}
+
+static int read_populate_todo(struct repository *r,
+			      struct todo_list *todo_list,
+			      struct replay_opts *opts)
 {
 	struct stat st;
 	const char *todo_file = get_todo_path(opts);
@@ -2102,7 +2322,7 @@ static int read_populate_todo(struct tod
 		return error(_("could not stat '%s'"), todo_file);
 	fill_stat_data(&todo_list->stat, &st);
 
-	res = parse_insn_buffer(todo_list->buf.buf, todo_list);
+	res = todo_list_parse_insn_buffer(r, todo_list->buf.buf, todo_list);
 	if (res) {
 		if (is_rebase_i(opts))
 			return error(_("please fix this using "
@@ -2130,10 +2350,9 @@ static int read_populate_todo(struct tod
 
 	if (is_rebase_i(opts)) {
 		struct todo_list done = TODO_LIST_INIT;
-		FILE *f = fopen_or_warn(rebase_path_msgtotal(), "w");
 
 		if (strbuf_read_file(&done.buf, rebase_path_done(), 0) > 0 &&
-				!parse_insn_buffer(done.buf.buf, &done))
+		    !todo_list_parse_insn_buffer(r, done.buf.buf, &done))
 			todo_list->done_nr = count_commands(&done);
 		else
 			todo_list->done_nr = 0;
@@ -2142,10 +2361,7 @@ static int read_populate_todo(struct tod
 			+ count_commands(todo_list);
 		todo_list_release(&done);
 
-		if (f) {
-			fprintf(f, "%d\n", todo_list->total_nr);
-			fclose(f);
-		}
+		todo_list_write_total_nr(todo_list);
 	}
 
 	return 0;
@@ -2172,6 +2388,15 @@ static int populate_opts_cb(const char *
 		opts->no_commit = git_config_bool_or_int(key, value, &error_flag);
 	else if (!strcmp(key, "options.edit"))
 		opts->edit = git_config_bool_or_int(key, value, &error_flag);
+	else if (!strcmp(key, "options.allow-empty"))
+		opts->allow_empty =
+			git_config_bool_or_int(key, value, &error_flag);
+	else if (!strcmp(key, "options.allow-empty-message"))
+		opts->allow_empty_message =
+			git_config_bool_or_int(key, value, &error_flag);
+	else if (!strcmp(key, "options.keep-redundant-commits"))
+		opts->keep_redundant_commits =
+			git_config_bool_or_int(key, value, &error_flag);
 	else if (!strcmp(key, "options.signoff"))
 		opts->signoff = git_config_bool_or_int(key, value, &error_flag);
 	else if (!strcmp(key, "options.record-origin"))
@@ -2191,7 +2416,10 @@ static int populate_opts_cb(const char *
 		opts->allow_rerere_auto =
 			git_config_bool_or_int(key, value, &error_flag) ?
 				RERERE_AUTOUPDATE : RERERE_NOAUTOUPDATE;
-	else
+	else if (!strcmp(key, "options.default-msg-cleanup")) {
+		opts->explicit_cleanup = 1;
+		opts->default_msg_cleanup = get_cleanup_mode(value, 1);
+	} else
 		return error(_("invalid key: %s"), key);
 
 	if (!error_flag)
@@ -2200,18 +2428,16 @@ static int populate_opts_cb(const char *
 	return 0;
 }
 
-static void read_strategy_opts(struct replay_opts *opts, struct strbuf *buf)
+void parse_strategy_opts(struct replay_opts *opts, char *raw_opts)
 {
 	int i;
+	char *strategy_opts_string = raw_opts;
 
-	strbuf_reset(buf);
-	if (!read_oneliner(buf, rebase_path_strategy(), 0))
-		return;
-	opts->strategy = strbuf_detach(buf, NULL);
-	if (!read_oneliner(buf, rebase_path_strategy_opts(), 0))
-		return;
+	if (*strategy_opts_string == ' ')
+		strategy_opts_string++;
 
-	opts->xopts_nr = split_cmdline(buf->buf, (const char ***)&opts->xopts);
+	opts->xopts_nr = split_cmdline(strategy_opts_string,
+				       (const char ***)&opts->xopts);
 	for (i = 0; i < opts->xopts_nr; i++) {
 		const char *arg = opts->xopts[i];
 
@@ -2220,6 +2446,18 @@ static void read_strategy_opts(struct re
 	}
 }
 
+static void read_strategy_opts(struct replay_opts *opts, struct strbuf *buf)
+{
+	strbuf_reset(buf);
+	if (!read_oneliner(buf, rebase_path_strategy(), 0))
+		return;
+	opts->strategy = strbuf_detach(buf, NULL);
+	if (!read_oneliner(buf, rebase_path_strategy_opts(), 0))
+		return;
+
+	parse_strategy_opts(opts, buf->buf);
+}
+
 static int read_populate_opts(struct replay_opts *opts)
 {
 	if (is_rebase_i(opts)) {
@@ -2246,11 +2484,17 @@ static int read_populate_opts(struct rep
 		if (file_exists(rebase_path_verbose()))
 			opts->verbose = 1;
 
+		if (file_exists(rebase_path_quiet()))
+			opts->quiet = 1;
+
 		if (file_exists(rebase_path_signoff())) {
 			opts->allow_ff = 0;
 			opts->signoff = 1;
 		}
 
+		if (file_exists(rebase_path_reschedule_failed_exec()))
+			opts->reschedule_failed_exec = 1;
+
 		read_strategy_opts(opts, &buf);
 		strbuf_release(&buf);
 
@@ -2287,26 +2531,78 @@ static int read_populate_opts(struct rep
 	return 0;
 }
 
+static void write_strategy_opts(struct replay_opts *opts)
+{
+	int i;
+	struct strbuf buf = STRBUF_INIT;
+
+	for (i = 0; i < opts->xopts_nr; ++i)
+		strbuf_addf(&buf, " --%s", opts->xopts[i]);
+
+	write_file(rebase_path_strategy_opts(), "%s\n", buf.buf);
+	strbuf_release(&buf);
+}
+
+int write_basic_state(struct replay_opts *opts, const char *head_name,
+		      struct commit *onto, const char *orig_head)
+{
+	const char *quiet = getenv("GIT_QUIET");
+
+	if (head_name)
+		write_file(rebase_path_head_name(), "%s\n", head_name);
+	if (onto)
+		write_file(rebase_path_onto(), "%s\n",
+			   oid_to_hex(&onto->object.oid));
+	if (orig_head)
+		write_file(rebase_path_orig_head(), "%s\n", orig_head);
+
+	if (quiet)
+		write_file(rebase_path_quiet(), "%s\n", quiet);
+	if (opts->verbose)
+		write_file(rebase_path_verbose(), "%s", "");
+	if (opts->strategy)
+		write_file(rebase_path_strategy(), "%s\n", opts->strategy);
+	if (opts->xopts_nr > 0)
+		write_strategy_opts(opts);
+
+	if (opts->allow_rerere_auto == RERERE_AUTOUPDATE)
+		write_file(rebase_path_allow_rerere_autoupdate(), "--rerere-autoupdate\n");
+	else if (opts->allow_rerere_auto == RERERE_NOAUTOUPDATE)
+		write_file(rebase_path_allow_rerere_autoupdate(), "--no-rerere-autoupdate\n");
+
+	if (opts->gpg_sign)
+		write_file(rebase_path_gpg_sign_opt(), "-S%s\n", opts->gpg_sign);
+	if (opts->signoff)
+		write_file(rebase_path_signoff(), "--signoff\n");
+	if (opts->reschedule_failed_exec)
+		write_file(rebase_path_reschedule_failed_exec(), "%s", "");
+
+	return 0;
+}
+
 static int walk_revs_populate_todo(struct todo_list *todo_list,
 				struct replay_opts *opts)
 {
 	enum todo_command command = opts->action == REPLAY_PICK ?
 		TODO_PICK : TODO_REVERT;
 	const char *command_string = todo_command_info[command].str;
+	const char *encoding;
 	struct commit *commit;
 
 	if (prepare_revs(opts))
 		return -1;
 
+	encoding = get_log_output_encoding();
+
 	while ((commit = get_revision(opts->revs))) {
 		struct todo_item *item = append_new_todo(todo_list);
-		const char *commit_buffer = get_commit_buffer(commit, NULL);
+		const char *commit_buffer = logmsg_reencode(commit, NULL, encoding);
 		const char *subject;
 		int subject_len;
 
 		item->command = command;
 		item->commit = commit;
-		item->arg = NULL;
+		item->arg_offset = 0;
 		item->arg_len = 0;
 		item->offset_in_buf = todo_list->buf.len;
 		subject_len = find_commit_subject(commit_buffer, &subject);
@@ -2314,18 +2610,48 @@ static int walk_revs_populate_todo(struc
 			short_commit_name(commit), subject_len, subject);
 		unuse_commit_buffer(commit, commit_buffer);
 	}
+
+	if (!todo_list->nr)
+		return error(_("empty commit set passed"));
+
 	return 0;
 }
 
-static int create_seq_dir(void)
+static int create_seq_dir(struct repository *r)
 {
-	if (file_exists(git_path_seq_dir())) {
-		error(_("a cherry-pick or revert is already in progress"));
-		advise(_("try \"git cherry-pick (--continue | --quit | --abort)\""));
+	enum replay_action action;
+	const char *in_progress_error = NULL;
+	const char *in_progress_advice = NULL;
+	unsigned int advise_skip = file_exists(git_path_revert_head(r)) ||
+				file_exists(git_path_cherry_pick_head(r));
+
+	if (!sequencer_get_last_command(r, &action)) {
+		switch (action) {
+		case REPLAY_REVERT:
+			in_progress_error = _("revert is already in progress");
+			in_progress_advice =
+			_("try \"git revert (--continue | %s--abort | --quit)\"");
+			break;
+		case REPLAY_PICK:
+			in_progress_error = _("cherry-pick is already in progress");
+			in_progress_advice =
+			_("try \"git cherry-pick (--continue | %s--abort | --quit)\"");
+			break;
+		default:
+			BUG("unexpected action in create_seq_dir");
+		}
+	}
+	if (in_progress_error) {
+		error("%s", in_progress_error);
+		if (advice_sequencer_in_use)
+			advise(in_progress_advice,
+				advise_skip ? "--skip | " : "");
 		return -1;
-	} else if (mkdir(git_path_seq_dir(), 0777) < 0)
+	}
+	if (mkdir(git_path_seq_dir(), 0777) < 0)
 		return error_errno(_("could not create sequencer directory '%s'"),
 				   git_path_seq_dir());
+
 	return 0;
 }
 
@@ -2373,35 +2699,49 @@ static int rollback_is_safe(void)
 	if (get_oid("HEAD", &actual_head))
 		oidclr(&actual_head);
 
-	return !oidcmp(&actual_head, &expected_head);
+	return oideq(&actual_head, &expected_head);
 }
 
-static int reset_for_rollback(const struct object_id *oid)
+static int reset_merge(const struct object_id *oid)
 {
-	const char *argv[4];	/* reset --merge <arg> + NULL */
+	int ret;
+	struct argv_array argv = ARGV_ARRAY_INIT;
 
-	argv[0] = "reset";
-	argv[1] = "--merge";
-	argv[2] = oid_to_hex(oid);
-	argv[3] = NULL;
-	return run_command_v_opt(argv, RUN_GIT_CMD);
-}
+	argv_array_pushl(&argv, "reset", "--merge", NULL);
 
-static int rollback_single_pick(void)
+	if (!is_null_oid(oid))
+		argv_array_push(&argv, oid_to_hex(oid));
+
+	ret = run_command_v_opt(argv.argv, RUN_GIT_CMD);
+	argv_array_clear(&argv);
+
+	return ret;
+}
+
+static int rollback_single_pick(struct repository *r)
 {
 	struct object_id head_oid;
 
-	if (!file_exists(git_path_cherry_pick_head()) &&
-	    !file_exists(git_path_revert_head()))
+	if (!file_exists(git_path_cherry_pick_head(r)) &&
+	    !file_exists(git_path_revert_head(r)))
 		return error(_("no cherry-pick or revert in progress"));
 	if (read_ref_full("HEAD", 0, &head_oid, NULL))
 		return error(_("cannot resolve HEAD"));
 	if (is_null_oid(&head_oid))
 		return error(_("cannot abort from a branch yet to be born"));
-	return reset_for_rollback(&head_oid);
+	return reset_merge(&head_oid);
+}
+
+static int skip_single_pick(void)
+{
+	struct object_id head;
+
+	if (read_ref_full("HEAD", 0, &head, NULL))
+		return error(_("cannot resolve HEAD"));
+	return reset_merge(&head);
 }
 
-int sequencer_rollback(struct replay_opts *opts)
+int sequencer_rollback(struct repository *r, struct replay_opts *opts)
 {
 	FILE *f;
 	struct object_id oid;
@@ -2415,7 +2755,7 @@ int sequencer_rollback(struct replay_opt
 		 * If CHERRY_PICK_HEAD or REVERT_HEAD indicates
 		 * a single-cherry-pick in progress, abort that.
 		 */
-		return rollback_single_pick();
+		return rollback_single_pick(r);
 	}
 	if (!f)
 		return error_errno(_("cannot open '%s'"), git_path_head_file());
@@ -2441,7 +2781,7 @@ int sequencer_rollback(struct replay_opt
 		warning(_("You seem to have moved HEAD. "
 			  "Not rewinding, check your HEAD!"));
 	} else
-	if (reset_for_rollback(&oid))
+	if (reset_merge(&oid))
 		goto fail;
 	strbuf_release(&buf);
 	return sequencer_remove_state(opts);
@@ -2450,6 +2790,70 @@ fail:
 	return -1;
 }
 
+int sequencer_skip(struct repository *r, struct replay_opts *opts)
+{
+	enum replay_action action = -1;
+	sequencer_get_last_command(r, &action);
+
+	/*
+	 * Check whether the subcommand requested to skip the commit is actually
+	 * in progress and that it's safe to skip the commit.
+	 *
+	 * opts->action tells us which subcommand requested to skip the commit.
+	 * If the corresponding .git/<ACTION>_HEAD exists, we know that the
+	 * action is in progress and we can skip the commit.
+	 *
+	 * Otherwise we check that the last instruction was related to the
+	 * particular subcommand we're trying to execute and barf if that's not
+	 * the case.
+	 *
+	 * Finally we check that the rollback is "safe", i.e., has the HEAD
+	 * moved? In this case, it doesn't make sense to "reset the merge" and
+	 * "skip the commit" as the user already handled this by committing. But
+	 * we'd not want to barf here, instead give advice on how to proceed. We
+	 * only need to check that when .git/<ACTION>_HEAD doesn't exist because
+	 * it gets removed when the user commits, so if it still exists we're
+	 * sure the user can't have committed before.
+	 */
+	switch (opts->action) {
+	case REPLAY_REVERT:
+		if (!file_exists(git_path_revert_head(r))) {
+			if (action != REPLAY_REVERT)
+				return error(_("no revert in progress"));
+			if (!rollback_is_safe())
+				goto give_advice;
+		}
+		break;
+	case REPLAY_PICK:
+		if (!file_exists(git_path_cherry_pick_head(r))) {
+			if (action != REPLAY_PICK)
+				return error(_("no cherry-pick in progress"));
+			if (!rollback_is_safe())
+				goto give_advice;
+		}
+		break;
+	default:
+		BUG("unexpected action in sequencer_skip");
+	}
+
+	if (skip_single_pick())
+		return error(_("failed to skip the commit"));
+	if (!is_directory(git_path_seq_dir()))
+		return 0;
+
+	return sequencer_continue(r, opts);
+
+give_advice:
+	error(_("there is nothing to skip"));
+
+	if (advice_resolve_conflict) {
+		advise(_("have you committed already?\n"
+			 "try \"git %s --continue\""),
+			 action == REPLAY_REVERT ? "revert" : "cherry-pick");
+	}
+	return -1;
+}
+
 static int save_todo(struct todo_list *todo_list, struct replay_opts *opts)
 {
 	struct lock_file todo_lock = LOCK_INIT;
@@ -2497,40 +2901,65 @@ static int save_opts(struct replay_opts
 	int res = 0;
 
 	if (opts->no_commit)
-		res |= git_config_set_in_file_gently(opts_file, "options.no-commit", "true");
+		res |= git_config_set_in_file_gently(opts_file,
+					"options.no-commit", "true");
 	if (opts->edit)
-		res |= git_config_set_in_file_gently(opts_file, "options.edit", "true");
+		res |= git_config_set_in_file_gently(opts_file,
+					"options.edit", "true");
+	if (opts->allow_empty)
+		res |= git_config_set_in_file_gently(opts_file,
+					"options.allow-empty", "true");
+	if (opts->allow_empty_message)
+		res |= git_config_set_in_file_gently(opts_file,
+				"options.allow-empty-message", "true");
+	if (opts->keep_redundant_commits)
+		res |= git_config_set_in_file_gently(opts_file,
+				"options.keep-redundant-commits", "true");
 	if (opts->signoff)
-		res |= git_config_set_in_file_gently(opts_file, "options.signoff", "true");
+		res |= git_config_set_in_file_gently(opts_file,
+					"options.signoff", "true");
 	if (opts->record_origin)
-		res |= git_config_set_in_file_gently(opts_file, "options.record-origin", "true");
+		res |= git_config_set_in_file_gently(opts_file,
+					"options.record-origin", "true");
 	if (opts->allow_ff)
-		res |= git_config_set_in_file_gently(opts_file, "options.allow-ff", "true");
+		res |= git_config_set_in_file_gently(opts_file,
+					"options.allow-ff", "true");
 	if (opts->mainline) {
 		struct strbuf buf = STRBUF_INIT;
 		strbuf_addf(&buf, "%d", opts->mainline);
-		res |= git_config_set_in_file_gently(opts_file, "options.mainline", buf.buf);
+		res |= git_config_set_in_file_gently(opts_file,
+					"options.mainline", buf.buf);
 		strbuf_release(&buf);
 	}
 	if (opts->strategy)
-		res |= git_config_set_in_file_gently(opts_file, "options.strategy", opts->strategy);
+		res |= git_config_set_in_file_gently(opts_file,
+					"options.strategy", opts->strategy);
 	if (opts->gpg_sign)
-		res |= git_config_set_in_file_gently(opts_file, "options.gpg-sign", opts->gpg_sign);
+		res |= git_config_set_in_file_gently(opts_file,
+					"options.gpg-sign", opts->gpg_sign);
 	if (opts->xopts) {
 		int i;
 		for (i = 0; i < opts->xopts_nr; i++)
 			res |= git_config_set_multivar_in_file_gently(opts_file,
-							"options.strategy-option",
-							opts->xopts[i], "^$", 0);
+					"options.strategy-option",
+					opts->xopts[i], "^$", 0);
 	}
 	if (opts->allow_rerere_auto)
-		res |= git_config_set_in_file_gently(opts_file, "options.allow-rerere-auto",
-						     opts->allow_rerere_auto == RERERE_AUTOUPDATE ?
-						     "true" : "false");
+		res |= git_config_set_in_file_gently(opts_file,
+				"options.allow-rerere-auto",
+				opts->allow_rerere_auto == RERERE_AUTOUPDATE ?
+				"true" : "false");
+
+	if (opts->explicit_cleanup)
+		res |= git_config_set_in_file_gently(opts_file,
+				"options.default-msg-cleanup",
+				describe_cleanup_mode(opts->default_msg_cleanup));
 	return res;
 }
 
-static int make_patch(struct commit *commit, struct replay_opts *opts)
+static int make_patch(struct repository *r,
+		      struct commit *commit,
+		      struct replay_opts *opts)
 {
 	struct strbuf buf = STRBUF_INIT;
 	struct rev_info log_tree_opt;
@@ -2546,7 +2975,7 @@ static int make_patch(struct commit *com
 
 	strbuf_addf(&buf, "%s/patch", get_dir(opts));
 	memset(&log_tree_opt, 0, sizeof(log_tree_opt));
-	init_revisions(&log_tree_opt, NULL);
+	repo_init_revisions(r, &log_tree_opt, NULL);
 	log_tree_opt.abbrev = 0;
 	log_tree_opt.diff = 1;
 	log_tree_opt.diffopt.output_format = DIFF_FORMAT_PATCH;
@@ -2564,7 +2993,8 @@ static int make_patch(struct commit *com
 
 	strbuf_addf(&buf, "%s/message", get_dir(opts));
 	if (!file_exists(buf.buf)) {
-		const char *commit_buffer = get_commit_buffer(commit, NULL);
+		const char *encoding = get_commit_output_encoding();
+		const char *commit_buffer = logmsg_reencode(commit, NULL, encoding);
 		find_commit_subject(commit_buffer, &subject);
 		res |= write_message(subject, strlen(subject), buf.buf, 1);
 		unuse_commit_buffer(commit, commit_buffer);
@@ -2586,45 +3016,67 @@ static int intend_to_amend(void)
 	return write_message(p, strlen(p), rebase_path_amend(), 1);
 }
 
-static int error_with_patch(struct commit *commit,
-	const char *subject, int subject_len,
-	struct replay_opts *opts, int exit_code, int to_amend)
+static int error_with_patch(struct repository *r,
+			    struct commit *commit,
+			    const char *subject, int subject_len,
+			    struct replay_opts *opts,
+			    int exit_code, int to_amend)
 {
-	if (make_patch(commit, opts))
-		return -1;
+	if (commit) {
+		if (make_patch(r, commit, opts))
+			return -1;
+	} else if (copy_file(rebase_path_message(),
+			     git_path_merge_msg(r), 0666))
+		return error(_("unable to copy '%s' to '%s'"),
+			     git_path_merge_msg(r), rebase_path_message());
 
 	if (to_amend) {
 		if (intend_to_amend())
 			return -1;
 
-		fprintf(stderr, "You can amend the commit now, with\n"
-			"\n"
-			"  git commit --amend %s\n"
-			"\n"
-			"Once you are satisfied with your changes, run\n"
-			"\n"
-			"  git rebase --continue\n", gpg_sign_opt_quoted(opts));
-	} else if (exit_code)
-		fprintf(stderr, "Could not apply %s... %.*s\n",
-			short_commit_name(commit), subject_len, subject);
+		fprintf(stderr,
+			_("You can amend the commit now, with\n"
+			  "\n"
+			  "  git commit --amend %s\n"
+			  "\n"
+			  "Once you are satisfied with your changes, run\n"
+			  "\n"
+			  "  git rebase --continue\n"),
+			gpg_sign_opt_quoted(opts));
+	} else if (exit_code) {
+		if (commit)
+			fprintf_ln(stderr, _("Could not apply %s... %.*s"),
+				   short_commit_name(commit), subject_len, subject);
+		else
+			/*
+			 * We don't have the hash of the parent so
+			 * just print the line from the todo file.
+			 */
+			fprintf_ln(stderr, _("Could not merge %.*s"),
+				   subject_len, subject);
+	}
 
 	return exit_code;
 }
 
-static int error_failed_squash(struct commit *commit,
-	struct replay_opts *opts, int subject_len, const char *subject)
+static int error_failed_squash(struct repository *r,
+			       struct commit *commit,
+			       struct replay_opts *opts,
+			       int subject_len,
+			       const char *subject)
 {
 	if (copy_file(rebase_path_message(), rebase_path_squash_msg(), 0666))
 		return error(_("could not copy '%s' to '%s'"),
 			rebase_path_squash_msg(), rebase_path_message());
-	unlink(git_path_merge_msg());
-	if (copy_file(git_path_merge_msg(), rebase_path_message(), 0666))
+	unlink(git_path_merge_msg(r));
+	if (copy_file(git_path_merge_msg(r), rebase_path_message(), 0666))
 		return error(_("could not copy '%s' to '%s'"),
-			     rebase_path_message(), git_path_merge_msg());
-	return error_with_patch(commit, subject, subject_len, opts, 1, 0);
+			     rebase_path_message(),
+			     git_path_merge_msg(r));
+	return error_with_patch(r, commit, subject, subject_len, opts, 1, 0);
 }
 
-static int do_exec(const char *command_line)
+static int do_exec(struct repository *r, const char *command_line)
 {
 	struct argv_array child_env = ARGV_ARRAY_INIT;
 	const char *child_argv[] = { NULL, NULL };
@@ -2633,14 +3085,16 @@ static int do_exec(const char *command_l
 	fprintf(stderr, "Executing: %s\n", command_line);
 	child_argv[0] = command_line;
 	argv_array_pushf(&child_env, "GIT_DIR=%s", absolute_path(get_git_dir()));
+	argv_array_pushf(&child_env, "GIT_WORK_TREE=%s",
+			 absolute_path(get_git_work_tree()));
 	status = run_command_v_opt_cd_env(child_argv, RUN_USING_SHELL, NULL,
 					  child_env.argv);
 
 	/* force re-reading of the cache */
-	if (discard_cache() < 0 || read_cache() < 0)
+	if (discard_index(r->index) < 0 || repo_read_index(r) < 0)
 		return error(_("could not read index"));
 
-	dirty = require_clean_work_tree("rebase", NULL, 1, 1);
+	dirty = require_clean_work_tree(r, "rebase", NULL, 1, 1);
 
 	if (status) {
 		warning(_("execution failed: %s\n%s"
@@ -2706,9 +3160,9 @@ static int safe_append(const char *filen
 	return 0;
 }
 
-static int do_label(const char *name, int len)
+static int do_label(struct repository *r, const char *name, int len)
 {
-	struct ref_store *refs = get_main_ref_store(the_repository);
+	struct ref_store *refs = get_main_ref_store(r);
 	struct ref_transaction *transaction;
 	struct strbuf ref_name = STRBUF_INIT, err = STRBUF_INIT;
 	struct strbuf msg = STRBUF_INIT;
@@ -2716,7 +3170,7 @@ static int do_label(const char *name, in
 	struct object_id head_oid;
 
 	if (len == 1 && *name == '#')
-		return error("Illegal label name: '%.*s'", len, name);
+		return error(_("illegal label name: '%.*s'"), len, name);
 
 	strbuf_addf(&ref_name, "refs/rewritten/%.*s", len, name);
 	strbuf_addf(&msg, "rebase -i (label) '%.*s'", len, name);
@@ -2749,7 +3203,9 @@ static int do_label(const char *name, in
 static const char *reflog_message(struct replay_opts *opts,
 	const char *sub_action, const char *fmt, ...);
 
-static int do_reset(const char *name, int len, struct replay_opts *opts)
+static int do_reset(struct repository *r,
+		    const char *name, int len,
+		    struct replay_opts *opts)
 {
 	struct strbuf ref_name = STRBUF_INIT;
 	struct object_id oid;
@@ -2757,9 +3213,9 @@ static int do_reset(const char *name, in
 	struct tree_desc desc;
 	struct tree *tree;
 	struct unpack_trees_options unpack_tree_opts;
-	int ret = 0, i;
+	int ret = 0;
 
-	if (hold_locked_index(&lock, LOCK_REPORT_ON_ERROR) < 0)
+	if (repo_hold_locked_index(r, &lock, LOCK_REPORT_ON_ERROR) < 0)
 		return -1;
 
 	if (len == 10 && !strncmp("[new root]", name, len)) {
@@ -2777,10 +3233,13 @@ static int do_reset(const char *name, in
 		}
 		oidcpy(&oid, &opts->squash_onto);
 	} else {
+		int i;
+
 		/* Determine the length of the label */
 		for (i = 0; i < len; i++)
 			if (isspace(name[i]))
-				len = i;
+				break;
+		len = i;
 
 		strbuf_addf(&ref_name, "refs/rewritten/%.*s", len, name);
 		if (get_oid(ref_name.buf, &oid) &&
@@ -2795,19 +3254,19 @@ static int do_reset(const char *name, in
 	memset(&unpack_tree_opts, 0, sizeof(unpack_tree_opts));
 	setup_unpack_trees_porcelain(&unpack_tree_opts, "reset");
 	unpack_tree_opts.head_idx = 1;
-	unpack_tree_opts.src_index = &the_index;
-	unpack_tree_opts.dst_index = &the_index;
+	unpack_tree_opts.src_index = r->index;
+	unpack_tree_opts.dst_index = r->index;
 	unpack_tree_opts.fn = oneway_merge;
 	unpack_tree_opts.merge = 1;
 	unpack_tree_opts.update = 1;
 
-	if (read_cache_unmerged()) {
+	if (repo_read_index_unmerged(r)) {
 		rollback_lock_file(&lock);
 		strbuf_release(&ref_name);
 		return error_resolve_conflict(_(action_name(opts)));
 	}
 
-	if (!fill_tree_descriptor(&desc, &oid)) {
+	if (!fill_tree_descriptor(r, &desc, &oid)) {
 		error(_("failed to find tree of %s"), oid_to_hex(&oid));
 		rollback_lock_file(&lock);
 		free((void *)desc.buffer);
@@ -2823,9 +3282,9 @@ static int do_reset(const char *name, in
 	}
 
 	tree = parse_tree_indirect(&oid);
-	prime_cache_tree(&the_index, tree);
+	prime_cache_tree(r, r->index, tree);
 
-	if (write_locked_index(&the_index, &lock, COMMIT_LOCK) < 0)
+	if (write_locked_index(r->index, &lock, COMMIT_LOCK) < 0)
 		ret = error(_("could not write index"));
 	free((void *)desc.buffer);
 
@@ -2838,7 +3297,29 @@ static int do_reset(const char *name, in
 	return ret;
 }
 
-static int do_merge(struct commit *commit, const char *arg, int arg_len,
+static struct commit *lookup_label(const char *label, int len,
+				   struct strbuf *buf)
+{
+	struct commit *commit;
+
+	strbuf_reset(buf);
+	strbuf_addf(buf, "refs/rewritten/%.*s", len, label);
+	commit = lookup_commit_reference_by_name(buf->buf);
+	if (!commit) {
+		/* fall back to non-rewritten ref or commit */
+		strbuf_splice(buf, 0, strlen("refs/rewritten/"), "", 0);
+		commit = lookup_commit_reference_by_name(buf->buf);
+	}
+
+	if (!commit)
+		error(_("could not resolve '%s'"), buf->buf);
+
+	return commit;
+}
+
+static int do_merge(struct repository *r,
+		    struct commit *commit,
+		    const char *arg, int arg_len,
 		    int flags, struct replay_opts *opts)
 {
 	int run_commit_flags = (flags & TODO_EDIT_MERGE_MSG) ?
@@ -2846,12 +3327,16 @@ static int do_merge(struct commit *commi
 	struct strbuf ref_name = STRBUF_INIT;
 	struct commit *head_commit, *merge_commit, *i;
 	struct commit_list *bases, *j, *reversed = NULL;
+	struct commit_list *to_merge = NULL, **tail = &to_merge;
+	const char *strategy = !opts->xopts_nr &&
+		(!opts->strategy || !strcmp(opts->strategy, "recursive")) ?
+		NULL : opts->strategy;
 	struct merge_options o;
-	int merge_arg_len, oneline_offset, can_fast_forward, ret;
+	int merge_arg_len, oneline_offset, can_fast_forward, ret, k;
 	static struct lock_file lock;
 	const char *p;
 
-	if (hold_locked_index(&lock, LOCK_REPORT_ON_ERROR) < 0) {
+	if (repo_hold_locked_index(r, &lock, LOCK_REPORT_ON_ERROR) < 0) {
 		ret = -1;
 		goto leave_merge;
 	}
@@ -2862,43 +3347,57 @@ static int do_merge(struct commit *commi
 		goto leave_merge;
 	}
 
-	oneline_offset = arg_len;
-	merge_arg_len = strcspn(arg, " \t\n");
-	p = arg + merge_arg_len;
-	p += strspn(p, " \t\n");
-	if (*p == '#' && (!p[1] || isspace(p[1]))) {
-		p += 1 + strspn(p + 1, " \t\n");
-		oneline_offset = p - arg;
-	} else if (p - arg < arg_len)
-		BUG("octopus merges are not supported yet: '%s'", p);
-
-	strbuf_addf(&ref_name, "refs/rewritten/%.*s", merge_arg_len, arg);
-	merge_commit = lookup_commit_reference_by_name(ref_name.buf);
-	if (!merge_commit) {
-		/* fall back to non-rewritten ref or commit */
-		strbuf_splice(&ref_name, 0, strlen("refs/rewritten/"), "", 0);
-		merge_commit = lookup_commit_reference_by_name(ref_name.buf);
+	/*
+	 * For octopus merges, the arg starts with the list of revisions to be
+	 * merged. The list is optionally followed by '#' and the oneline.
+	 */
+	merge_arg_len = oneline_offset = arg_len;
+	for (p = arg; p - arg < arg_len; p += strspn(p, " \t\n")) {
+		if (!*p)
+			break;
+		if (*p == '#' && (!p[1] || isspace(p[1]))) {
+			p += 1 + strspn(p + 1, " \t\n");
+			oneline_offset = p - arg;
+			break;
+		}
+		k = strcspn(p, " \t\n");
+		if (!k)
+			continue;
+		merge_commit = lookup_label(p, k, &ref_name);
+		if (!merge_commit) {
+			ret = error(_("unable to parse '%.*s'"), k, p);
+			goto leave_merge;
+		}
+		tail = &commit_list_insert(merge_commit, tail)->next;
+		p += k;
+		merge_arg_len = p - arg;
 	}
 
-	if (!merge_commit) {
-		ret = error(_("could not resolve '%s'"), ref_name.buf);
+	if (!to_merge) {
+		ret = error(_("nothing to merge: '%.*s'"), arg_len, arg);
 		goto leave_merge;
 	}
 
 	if (opts->have_squash_onto &&
-	    !oidcmp(&head_commit->object.oid, &opts->squash_onto)) {
+	    oideq(&head_commit->object.oid, &opts->squash_onto)) {
 		/*
 		 * When the user tells us to "merge" something into a
 		 * "[new root]", let's simply fast-forward to the merge head.
 		 */
 		rollback_lock_file(&lock);
-		ret = fast_forward_to(&merge_commit->object.oid,
-				       &head_commit->object.oid, 0, opts);
+		if (to_merge->next)
+			ret = error(_("octopus merge cannot be executed on "
+				      "top of a [new root]"));
+		else
+			ret = fast_forward_to(r, &to_merge->item->object.oid,
+					      &head_commit->object.oid, 0,
+					      opts);
 		goto leave_merge;
 	}
 
 	if (commit) {
-		const char *message = get_commit_buffer(commit, NULL);
+		const char *encoding = get_commit_output_encoding();
+		const char *message = logmsg_reencode(commit, NULL, encoding);
 		const char *body;
 		int len;
 
@@ -2910,11 +3409,11 @@ static int do_merge(struct commit *commi
 		write_author_script(message);
 		find_commit_subject(message, &body);
 		len = strlen(body);
-		ret = write_message(body, len, git_path_merge_msg(), 0);
+		ret = write_message(body, len, git_path_merge_msg(r), 0);
 		unuse_commit_buffer(commit, message);
 		if (ret) {
 			error_errno(_("could not write '%s'"),
-				    git_path_merge_msg());
+				    git_path_merge_msg(r));
 			goto leave_merge;
 		}
 	} else {
@@ -2929,17 +3428,18 @@ static int do_merge(struct commit *commi
 			p = arg + oneline_offset;
 			len = arg_len - oneline_offset;
 		} else {
-			strbuf_addf(&buf, "Merge branch '%.*s'",
+			strbuf_addf(&buf, "Merge %s '%.*s'",
+				    to_merge->next ? "branches" : "branch",
 				    merge_arg_len, arg);
 			p = buf.buf;
 			len = buf.len;
 		}
 
-		ret = write_message(p, len, git_path_merge_msg(), 0);
+		ret = write_message(p, len, git_path_merge_msg(r), 0);
 		strbuf_release(&buf);
 		if (ret) {
 			error_errno(_("could not write '%s'"),
-				    git_path_merge_msg());
+				    git_path_merge_msg(r));
 			goto leave_merge;
 		}
 	}
@@ -2949,50 +3449,110 @@ static int do_merge(struct commit *commi
 	 * commit, we cannot fast-forward.
 	 */
 	can_fast_forward = opts->allow_ff && commit && commit->parents &&
-		!oidcmp(&commit->parents->item->object.oid,
-			&head_commit->object.oid);
+		oideq(&commit->parents->item->object.oid,
+		      &head_commit->object.oid);
 
 	/*
-	 * If the merge head is different from the original one, we cannot
+	 * If any merge head is different from the original one, we cannot
 	 * fast-forward.
 	 */
 	if (can_fast_forward) {
-		struct commit_list *second_parent = commit->parents->next;
+		struct commit_list *p = commit->parents->next;
 
-		if (second_parent && !second_parent->next &&
-		    oidcmp(&merge_commit->object.oid,
-			   &second_parent->item->object.oid))
+		for (j = to_merge; j && p; j = j->next, p = p->next)
+			if (!oideq(&j->item->object.oid,
+				   &p->item->object.oid)) {
+				can_fast_forward = 0;
+				break;
+			}
+		/*
+		 * If the number of merge heads differs from the original merge
+		 * commit, we cannot fast-forward.
+		 */
+		if (j || p)
 			can_fast_forward = 0;
 	}
 
-	if (can_fast_forward && commit->parents->next &&
-	    !commit->parents->next->next &&
-	    !oidcmp(&commit->parents->next->item->object.oid,
-		    &merge_commit->object.oid)) {
+	if (can_fast_forward) {
 		rollback_lock_file(&lock);
-		ret = fast_forward_to(&commit->object.oid,
+		ret = fast_forward_to(r, &commit->object.oid,
 				      &head_commit->object.oid, 0, opts);
+		if (flags & TODO_EDIT_MERGE_MSG) {
+			run_commit_flags |= AMEND_MSG;
+			goto fast_forward_edit;
+		}
 		goto leave_merge;
 	}
 
-	write_message(oid_to_hex(&merge_commit->object.oid), GIT_SHA1_HEXSZ,
-		      git_path_merge_head(), 0);
-	write_message("no-ff", 5, git_path_merge_mode(), 0);
+	if (strategy || to_merge->next) {
+		/* Octopus merge */
+		struct child_process cmd = CHILD_PROCESS_INIT;
+
+		if (read_env_script(&cmd.env_array)) {
+			const char *gpg_opt = gpg_sign_opt_quoted(opts);
 
+			ret = error(_(staged_changes_advice), gpg_opt, gpg_opt);
+			goto leave_merge;
+		}
+
+		cmd.git_cmd = 1;
+		argv_array_push(&cmd.args, "merge");
+		argv_array_push(&cmd.args, "-s");
+		if (!strategy)
+			argv_array_push(&cmd.args, "octopus");
+		else {
+			argv_array_push(&cmd.args, strategy);
+			for (k = 0; k < opts->xopts_nr; k++)
+				argv_array_pushf(&cmd.args,
+						 "-X%s", opts->xopts[k]);
+		}
+		argv_array_push(&cmd.args, "--no-edit");
+		argv_array_push(&cmd.args, "--no-ff");
+		argv_array_push(&cmd.args, "--no-log");
+		argv_array_push(&cmd.args, "--no-stat");
+		argv_array_push(&cmd.args, "-F");
+		argv_array_push(&cmd.args, git_path_merge_msg(r));
+		if (opts->gpg_sign)
+			argv_array_push(&cmd.args, opts->gpg_sign);
+
+		/* Add the tips to be merged */
+		for (j = to_merge; j; j = j->next)
+			argv_array_push(&cmd.args,
+					oid_to_hex(&j->item->object.oid));
+
+		strbuf_release(&ref_name);
+		unlink(git_path_cherry_pick_head(r));
+		rollback_lock_file(&lock);
+
+		rollback_lock_file(&lock);
+		ret = run_command(&cmd);
+
+		/* force re-reading of the cache */
+		if (!ret && (discard_index(r->index) < 0 ||
+			     repo_read_index(r) < 0))
+			ret = error(_("could not read index"));
+		goto leave_merge;
+	}
+
+	merge_commit = to_merge->item;
 	bases = get_merge_bases(head_commit, merge_commit);
-	if (bases && !oidcmp(&merge_commit->object.oid,
-			     &bases->item->object.oid)) {
+	if (bases && oideq(&merge_commit->object.oid,
+			   &bases->item->object.oid)) {
 		ret = 0;
 		/* skip merging an ancestor of HEAD */
 		goto leave_merge;
 	}
 
+	write_message(oid_to_hex(&merge_commit->object.oid), the_hash_algo->hexsz,
+		      git_path_merge_head(r), 0);
+	write_message("no-ff", 5, git_path_merge_mode(r), 0);
+
 	for (j = bases; j; j = j->next)
 		commit_list_insert(j->item, &reversed);
 	free_commit_list(bases);
 
-	read_cache();
-	init_merge_options(&o);
+	repo_read_index(r);
+	init_merge_options(&o, r);
 	o.branch1 = "HEAD";
 	o.branch2 = ref_name.buf;
 	o.buffer_output = 2;
@@ -3016,27 +3576,29 @@ static int do_merge(struct commit *commi
 	 */
 	ret = !ret;
 
-	if (active_cache_changed &&
-	    write_locked_index(&the_index, &lock, COMMIT_LOCK)) {
+	if (r->index->cache_changed &&
+	    write_locked_index(r->index, &lock, COMMIT_LOCK)) {
 		ret = error(_("merge: Unable to write new index file"));
 		goto leave_merge;
 	}
 
 	rollback_lock_file(&lock);
 	if (ret)
-		rerere(opts->allow_rerere_auto);
+		repo_rerere(r, opts->allow_rerere_auto);
 	else
 		/*
 		 * In case of problems, we now want to return a positive
 		 * value (a negative one would indicate that the `merge`
 		 * command needs to be rescheduled).
 		 */
-		ret = !!run_git_commit(git_path_merge_msg(), opts,
-				     run_commit_flags);
+	fast_forward_edit:
+		ret = !!run_git_commit(r, git_path_merge_msg(r), opts,
+				       run_commit_flags);
 
 leave_merge:
 	strbuf_release(&ref_name);
 	rollback_lock_file(&lock);
+	free_commit_list(to_merge);
 	return ret;
 }
 
@@ -3130,6 +3692,80 @@ static const char *reflog_message(struct
 	return buf.buf;
 }
 
+static int run_git_checkout(struct repository *r, struct replay_opts *opts,
+			    const char *commit, const char *action)
+{
+	struct child_process cmd = CHILD_PROCESS_INIT;
+	int ret;
+
+	cmd.git_cmd = 1;
+
+	argv_array_push(&cmd.args, "checkout");
+	argv_array_push(&cmd.args, commit);
+	argv_array_pushf(&cmd.env_array, GIT_REFLOG_ACTION "=%s", action);
+
+	if (opts->verbose)
+		ret = run_command(&cmd);
+	else
+		ret = run_command_silent_on_success(&cmd);
+
+	if (!ret)
+		discard_index(r->index);
+
+	return ret;
+}
+
+int prepare_branch_to_be_rebased(struct repository *r, struct replay_opts *opts,
+				 const char *commit)
+{
+	const char *action;
+
+	if (commit && *commit) {
+		action = reflog_message(opts, "start", "checkout %s", commit);
+		if (run_git_checkout(r, opts, commit, action))
+			return error(_("could not checkout %s"), commit);
+	}
+
+	return 0;
+}
+
+static int checkout_onto(struct repository *r, struct replay_opts *opts,
+			 const char *onto_name, const struct object_id *onto,
+			 const char *orig_head)
+{
+	struct object_id oid;
+	const char *action = reflog_message(opts, "start", "checkout %s", onto_name);
+
+	if (get_oid(orig_head, &oid))
+		return error(_("%s: not a valid OID"), orig_head);
+
+	if (run_git_checkout(r, opts, oid_to_hex(onto), action)) {
+		apply_autostash(opts);
+		sequencer_remove_state(opts);
+		return error(_("could not detach HEAD"));
+	}
+
+	return update_ref(NULL, "ORIG_HEAD", &oid, NULL, 0, UPDATE_REFS_MSG_ON_ERR);
+}
+
+static int stopped_at_head(struct repository *r)
+{
+	struct object_id head;
+	struct commit *commit;
+	struct commit_message message;
+
+	if (get_oid("HEAD", &head) ||
+	    !(commit = lookup_commit(r, &head)) ||
+	    parse_commit(commit) || get_message(commit, &message))
+		fprintf(stderr, _("Stopped at HEAD\n"));
+	else {
+		fprintf(stderr, _("Stopped at %s\n"), message.label);
+		free_message(commit, &message);
+	}
+	return 0;
+
+}
+
 static const char rescheduled_advice[] =
 N_("Could not execute the todo command\n"
 "\n"
@@ -3141,7 +3777,9 @@ N_("Could not execute the todo command\n
 "    git rebase --edit-todo\n"
 "    git rebase --continue\n");
 
-static int pick_commits(struct todo_list *todo_list, struct replay_opts *opts)
+static int pick_commits(struct repository *r,
+			struct todo_list *todo_list,
+			struct replay_opts *opts)
 {
 	int res = 0, reschedule = 0;
 
@@ -3149,11 +3787,14 @@ static int pick_commits(struct todo_list
 	if (opts->allow_ff)
 		assert(!(opts->signoff || opts->no_commit ||
 				opts->record_origin || opts->edit));
-	if (read_and_refresh_cache(opts))
+	if (read_and_refresh_cache(r, opts))
 		return -1;
 
 	while (todo_list->current < todo_list->nr) {
 		struct todo_item *item = todo_list->items + todo_list->current;
+		const char *arg = todo_item_get_arg(todo_list, item);
+		int check_todo = 0;
+
 		if (save_todo(todo_list, opts))
 			return -1;
 		if (is_rebase_i(opts)) {
@@ -3166,24 +3807,33 @@ static int pick_commits(struct todo_list
 					fprintf(f, "%d\n", todo_list->done_nr);
 					fclose(f);
 				}
-				fprintf(stderr, "Rebasing (%d/%d)%s",
-					todo_list->done_nr,
-					todo_list->total_nr,
-					opts->verbose ? "\n" : "\r");
+				if (!opts->quiet)
+					fprintf(stderr, "Rebasing (%d/%d)%s",
+						todo_list->done_nr,
+						todo_list->total_nr,
+						opts->verbose ? "\n" : "\r");
 			}
 			unlink(rebase_path_message());
 			unlink(rebase_path_author_script());
 			unlink(rebase_path_stopped_sha());
 			unlink(rebase_path_amend());
+			unlink(git_path_merge_head(r));
 			delete_ref(NULL, "REBASE_HEAD", NULL, REF_NO_DEREF);
+
+			if (item->command == TODO_BREAK) {
+				if (!opts->verbose)
+					term_clear_line();
+				return stopped_at_head(r);
+			}
 		}
 		if (item->command <= TODO_SQUASH) {
 			if (is_rebase_i(opts))
 				setenv("GIT_REFLOG_ACTION", reflog_message(opts,
 					command_to_string(item->command), NULL),
 					1);
-			res = do_pick_commit(item->command, item->commit,
-					opts, is_final_fixup(todo_list));
+			res = do_pick_commit(r, item->command, item->commit,
+					     opts, is_final_fixup(todo_list),
+					     &check_todo);
 			if (is_rebase_i(opts) && res < 0) {
 				/* Reschedule */
 				advise(_(rescheduled_advice),
@@ -3197,14 +3847,16 @@ static int pick_commits(struct todo_list
 			}
 			if (item->command == TODO_EDIT) {
 				struct commit *commit = item->commit;
-				if (!res)
+				if (!res) {
+					if (!opts->verbose)
+						term_clear_line();
 					fprintf(stderr,
 						_("Stopped at %s...  %.*s\n"),
 						short_commit_name(commit),
-						item->arg_len, item->arg);
-				return error_with_patch(commit,
-					item->arg, item->arg_len, opts, res,
-					!res);
+						item->arg_len, arg);
+				}
+				return error_with_patch(r, commit,
+					arg, item->arg_len, opts, res, !res);
 			}
 			if (is_rebase_i(opts) && !res)
 				record_in_rewritten(&item->commit->object.oid,
@@ -3212,43 +3864,53 @@ static int pick_commits(struct todo_list
 			if (res && is_fixup(item->command)) {
 				if (res == 1)
 					intend_to_amend();
-				return error_failed_squash(item->commit, opts,
-					item->arg_len, item->arg);
-			} else if (res && is_rebase_i(opts) && item->commit)
-				return res | error_with_patch(item->commit,
-					item->arg, item->arg_len, opts, res,
-					item->command == TODO_REWORD);
+				return error_failed_squash(r, item->commit, opts,
+					item->arg_len, arg);
+			} else if (res && is_rebase_i(opts) && item->commit) {
+				int to_amend = 0;
+				struct object_id oid;
+
+				/*
+				 * If we are rewording and have either
+				 * fast-forwarded already, or are about to
+				 * create a new root commit, we want to amend,
+				 * otherwise we do not.
+				 */
+				if (item->command == TODO_REWORD &&
+				    !get_oid("HEAD", &oid) &&
+				    (oideq(&item->commit->object.oid, &oid) ||
+				     (opts->have_squash_onto &&
+				      oideq(&opts->squash_onto, &oid))))
+					to_amend = 1;
+
+				return res | error_with_patch(r, item->commit,
+						arg, item->arg_len, opts,
+						res, to_amend);
+			}
 		} else if (item->command == TODO_EXEC) {
-			char *end_of_arg = (char *)(item->arg + item->arg_len);
+			char *end_of_arg = (char *)(arg + item->arg_len);
 			int saved = *end_of_arg;
-			struct stat st;
 
+			if (!opts->verbose)
+				term_clear_line();
 			*end_of_arg = '\0';
-			res = do_exec(item->arg);
+			res = do_exec(r, arg);
 			*end_of_arg = saved;
 
-			/* Reread the todo file if it has changed. */
-			if (res)
-				; /* fall through */
-			else if (stat(get_todo_path(opts), &st))
-				res = error_errno(_("could not stat '%s'"),
-						  get_todo_path(opts));
-			else if (match_stat_data(&todo_list->stat, &st)) {
-				todo_list_release(todo_list);
-				if (read_populate_todo(todo_list, opts))
-					res = -1; /* message was printed */
-				/* `current` will be incremented below */
-				todo_list->current = -1;
+			if (res) {
+				if (opts->reschedule_failed_exec)
+					reschedule = 1;
 			}
+			check_todo = 1;
 		} else if (item->command == TODO_LABEL) {
-			if ((res = do_label(item->arg, item->arg_len)))
+			if ((res = do_label(r, arg, item->arg_len)))
 				reschedule = 1;
 		} else if (item->command == TODO_RESET) {
-			if ((res = do_reset(item->arg, item->arg_len, opts)))
+			if ((res = do_reset(r, arg, item->arg_len, opts)))
 				reschedule = 1;
 		} else if (item->command == TODO_MERGE) {
-			if ((res = do_merge(item->commit,
-					    item->arg, item->arg_len,
+			if ((res = do_merge(r, item->commit,
+					    arg, item->arg_len,
 					    item->flags, opts)) < 0)
 				reschedule = 1;
 			else if (item->commit)
@@ -3256,10 +3918,9 @@ static int pick_commits(struct todo_list
 						    peek_command(todo_list, 1));
 			if (res > 0)
 				/* failed with merge conflicts */
-				return error_with_patch(item->commit,
-							item->arg,
-							item->arg_len, opts,
-							res, 0);
+				return error_with_patch(r, item->commit,
+							arg, item->arg_len,
+							opts, res, 0);
 		} else if (!is_noop(item->command))
 			return error(_("unknown command %d"), item->command);
 
@@ -3272,10 +3933,24 @@ static int pick_commits(struct todo_list
 			if (save_todo(todo_list, opts))
 				return -1;
 			if (item->commit)
-				return error_with_patch(item->commit,
-							item->arg,
-							item->arg_len, opts,
-							res, 0);
+				return error_with_patch(r,
+							item->commit,
+							arg, item->arg_len,
+							opts, res, 0);
+		} else if (is_rebase_i(opts) && check_todo && !res) {
+			struct stat st;
+
+			if (stat(get_todo_path(opts), &st)) {
+				res = error_errno(_("could not stat '%s'"),
+						  get_todo_path(opts));
+			} else if (match_stat_data(&todo_list->stat, &st)) {
+				/* Reread the todo file if it has changed. */
+				todo_list_release(todo_list);
+				if (read_populate_todo(r, todo_list, opts))
+					res = -1; /* message was printed */
+				/* `current` will be incremented below */
+				todo_list->current = -1;
+			}
 		}
 
 		todo_list->current++;
@@ -3337,7 +4012,7 @@ cleanup_head_ref:
 			struct object_id orig, head;
 
 			memset(&log_tree_opt, 0, sizeof(log_tree_opt));
-			init_revisions(&log_tree_opt, NULL);
+			repo_init_revisions(r, &log_tree_opt, NULL);
 			log_tree_opt.diff = 1;
 			log_tree_opt.diffopt.output_format =
 				DIFF_FORMAT_DIFFSTAT;
@@ -3372,6 +4047,7 @@ cleanup_head_ref:
 				hook.in = open(rebase_path_rewritten_list(),
 					O_RDONLY);
 				hook.stdout_to_stderr = 1;
+				hook.trace2_hook_name = "post-rewrite";
 				argv_array_push(&hook.args, post_rewrite_hook);
 				argv_array_push(&hook.args, "rebase");
 				/* we don't care if this hook failed */
@@ -3380,8 +4056,13 @@ cleanup_head_ref:
 		}
 		apply_autostash(opts);
 
-		fprintf(stderr, "Successfully rebased and updated %s.\n",
-			head_ref.buf);
+		if (!opts->quiet) {
+			if (!opts->verbose)
+				term_clear_line();
+			fprintf(stderr,
+				"Successfully rebased and updated %s.\n",
+				head_ref.buf);
+		}
 
 		strbuf_release(&buf);
 		strbuf_release(&head_ref);
@@ -3394,26 +4075,27 @@ cleanup_head_ref:
 	return sequencer_remove_state(opts);
 }
 
-static int continue_single_pick(void)
+static int continue_single_pick(struct repository *r)
 {
 	const char *argv[] = { "commit", NULL };
 
-	if (!file_exists(git_path_cherry_pick_head()) &&
-	    !file_exists(git_path_revert_head()))
+	if (!file_exists(git_path_cherry_pick_head(r)) &&
+	    !file_exists(git_path_revert_head(r)))
 		return error(_("no cherry-pick or revert in progress"));
 	return run_command_v_opt(argv, RUN_GIT_CMD);
 }
 
-static int commit_staged_changes(struct replay_opts *opts,
+static int commit_staged_changes(struct repository *r,
+				 struct replay_opts *opts,
 				 struct todo_list *todo_list)
 {
 	unsigned int flags = ALLOW_EMPTY | EDIT_MSG;
 	unsigned int final_fixup = 0, is_clean;
 
-	if (has_unstaged_changes(1))
+	if (has_unstaged_changes(r, 1))
 		return error(_("cannot rebase: You have unstaged changes."));
 
-	is_clean = !has_uncommitted_changes(0);
+	is_clean = !has_uncommitted_changes(r, 0);
 
 	if (file_exists(rebase_path_amend())) {
 		struct strbuf rev = STRBUF_INIT;
@@ -3426,7 +4108,7 @@ static int commit_staged_changes(struct
 		if (get_oid_hex(rev.buf, &to_amend))
 			return error(_("invalid contents: '%s'"),
 				rebase_path_amend());
-		if (!is_clean && oidcmp(&head, &to_amend))
+		if (!is_clean && !oideq(&head, &to_amend))
 			return error(_("\nYou have uncommitted changes in your "
 				       "working tree. Please, commit them\n"
 				       "first and then run 'git rebase "
@@ -3438,9 +4120,20 @@ static int commit_staged_changes(struct
 		 * the commit message and if there was a squash, let the user
 		 * edit it.
 		 */
-		if (is_clean && !oidcmp(&head, &to_amend) &&
-		    opts->current_fixup_count > 0 &&
-		    file_exists(rebase_path_stopped_sha())) {
+		if (!is_clean || !opts->current_fixup_count)
+			; /* this is not the final fixup */
+		else if (!oideq(&head, &to_amend) ||
+			 !file_exists(rebase_path_stopped_sha())) {
+			/* was a final fixup or squash done manually? */
+			if (!is_fixup(peek_command(todo_list, 0))) {
+				unlink(rebase_path_fixup_msg());
+				unlink(rebase_path_squash_msg());
+				unlink(rebase_path_current_fixups());
+				strbuf_reset(&opts->current_fixups);
+				opts->current_fixup_count = 0;
+			}
+		} else {
+			/* we are in a fixup/squash chain */
 			const char *p = opts->current_fixups.buf;
 			int len = opts->current_fixups.len;
 
@@ -3485,9 +4178,10 @@ static int commit_staged_changes(struct
 				 */
 				struct commit *commit;
 				const char *path = rebase_path_squash_msg();
+				const char *encoding = get_commit_output_encoding();
 
-				if (parse_head(&commit) ||
-				    !(p = get_commit_buffer(commit, NULL)) ||
+				if (parse_head(r, &commit) ||
+				    !(p = logmsg_reencode(commit, NULL, encoding)) ||
 				    write_message(p, strlen(p), path, 0)) {
 					unuse_commit_buffer(commit, p);
 					return error(_("could not write file: "
@@ -3502,7 +4196,7 @@ static int commit_staged_changes(struct
 	}
 
 	if (is_clean) {
-		const char *cherry_pick_head = git_path_cherry_pick_head();
+		const char *cherry_pick_head = git_path_cherry_pick_head(r);
 
 		if (file_exists(cherry_pick_head) && unlink(cherry_pick_head))
 			return error(_("could not remove CHERRY_PICK_HEAD"));
@@ -3510,10 +4204,11 @@ static int commit_staged_changes(struct
 			return 0;
 	}
 
-	if (run_git_commit(final_fixup ? NULL : rebase_path_message(),
+	if (run_git_commit(r, final_fixup ? NULL : rebase_path_message(),
 			   opts, flags))
 		return error(_("could not commit staged changes."));
 	unlink(rebase_path_amend());
+	unlink(git_path_merge_head(r));
 	if (final_fixup) {
 		unlink(rebase_path_fixup_msg());
 		unlink(rebase_path_squash_msg());
@@ -3530,36 +4225,38 @@ static int commit_staged_changes(struct
 	return 0;
 }
 
-int sequencer_continue(struct replay_opts *opts)
+int sequencer_continue(struct repository *r, struct replay_opts *opts)
 {
 	struct todo_list todo_list = TODO_LIST_INIT;
 	int res;
 
-	if (read_and_refresh_cache(opts))
+	if (read_and_refresh_cache(r, opts))
 		return -1;
 
 	if (read_populate_opts(opts))
 		return -1;
 	if (is_rebase_i(opts)) {
-		if ((res = read_populate_todo(&todo_list, opts)))
+		if ((res = read_populate_todo(r, &todo_list, opts)))
 			goto release_todo_list;
-		if (commit_staged_changes(opts, &todo_list))
-			return -1;
+		if (commit_staged_changes(r, opts, &todo_list)) {
+			res = -1;
+			goto release_todo_list;
+		}
 	} else if (!file_exists(get_todo_path(opts)))
-		return continue_single_pick();
-	else if ((res = read_populate_todo(&todo_list, opts)))
+		return continue_single_pick(r);
+	else if ((res = read_populate_todo(r, &todo_list, opts)))
 		goto release_todo_list;
 
 	if (!is_rebase_i(opts)) {
 		/* Verify that the conflict has been resolved */
-		if (file_exists(git_path_cherry_pick_head()) ||
-		    file_exists(git_path_revert_head())) {
-			res = continue_single_pick();
+		if (file_exists(git_path_cherry_pick_head(r)) ||
+		    file_exists(git_path_revert_head(r))) {
+			res = continue_single_pick(r);
 			if (res)
 				goto release_todo_list;
 		}
-		if (index_differs_from("HEAD", NULL, 0)) {
-			res = error_dirty_index(opts);
+		if (index_differs_from(r, "HEAD", NULL, 0)) {
+			res = error_dirty_index(r, opts);
 			goto release_todo_list;
 		}
 		todo_list.current++;
@@ -3573,27 +4270,33 @@ int sequencer_continue(struct replay_opt
 		strbuf_release(&buf);
 	}
 
-	res = pick_commits(&todo_list, opts);
+	res = pick_commits(r, &todo_list, opts);
 release_todo_list:
 	todo_list_release(&todo_list);
 	return res;
 }
 
-static int single_pick(struct commit *cmit, struct replay_opts *opts)
+static int single_pick(struct repository *r,
+		       struct commit *cmit,
+		       struct replay_opts *opts)
 {
+	int check_todo;
+
 	setenv(GIT_REFLOG_ACTION, action_name(opts), 0);
-	return do_pick_commit(opts->action == REPLAY_PICK ?
-		TODO_PICK : TODO_REVERT, cmit, opts, 0);
+	return do_pick_commit(r, opts->action == REPLAY_PICK ?
+			      TODO_PICK : TODO_REVERT, cmit, opts, 0,
+			      &check_todo);
 }
 
-int sequencer_pick_revisions(struct replay_opts *opts)
+int sequencer_pick_revisions(struct repository *r,
+			     struct replay_opts *opts)
 {
 	struct todo_list todo_list = TODO_LIST_INIT;
 	struct object_id oid;
 	int i, res;
 
 	assert(opts->revs);
-	if (read_and_refresh_cache(opts))
+	if (read_and_refresh_cache(r, opts))
 		return -1;
 
 	for (i = 0; i < opts->revs->pending.nr; i++) {
@@ -3605,8 +4308,8 @@ int sequencer_pick_revisions(struct repl
 			continue;
 
 		if (!get_oid(name, &oid)) {
-			if (!lookup_commit_reference_gently(&oid, 1)) {
-				enum object_type type = oid_object_info(the_repository,
+			if (!lookup_commit_reference_gently(r, &oid, 1)) {
+				enum object_type type = oid_object_info(r,
 									&oid,
 									NULL);
 				return error(_("%s: can't cherry-pick a %s"),
@@ -3631,9 +4334,11 @@ int sequencer_pick_revisions(struct repl
 		if (prepare_revision_walk(opts->revs))
 			return error(_("revision walk setup failed"));
 		cmit = get_revision(opts->revs);
-		if (!cmit || get_revision(opts->revs))
-			return error("BUG: expected exactly one commit from walk");
-		return single_pick(cmit, opts);
+		if (!cmit)
+			return error(_("empty commit set passed"));
+		if (get_revision(opts->revs))
+			BUG("unexpected extra commit from walk");
+		return single_pick(r, cmit, opts);
 	}
 
 	/*
@@ -3643,7 +4348,7 @@ int sequencer_pick_revisions(struct repl
 	 */
 
 	if (walk_revs_populate_todo(&todo_list, opts) ||
-			create_seq_dir() < 0)
+			create_seq_dir(r) < 0)
 		return -1;
 	if (get_oid("HEAD", &oid) && (opts->action == REPLAY_REVERT))
 		return error(_("can't revert as initial commit"));
@@ -3652,20 +4357,19 @@ int sequencer_pick_revisions(struct repl
 	if (save_opts(opts))
 		return -1;
 	update_abort_safety_file();
-	res = pick_commits(&todo_list, opts);
+	res = pick_commits(r, &todo_list, opts);
 	todo_list_release(&todo_list);
 	return res;
 }
 
-void append_signoff(struct strbuf *msgbuf, int ignore_footer, unsigned flag)
+void append_signoff(struct strbuf *msgbuf, size_t ignore_footer, unsigned flag)
 {
 	unsigned no_dup_sob = flag & APPEND_SIGNOFF_DEDUP;
 	struct strbuf sob = STRBUF_INIT;
 	int has_footer;
 
 	strbuf_addstr(&sob, sign_off_header);
-	strbuf_addstr(&sob, fmt_name(getenv("GIT_COMMITTER_NAME"),
-				getenv("GIT_COMMITTER_EMAIL")));
+	strbuf_addstr(&sob, fmt_name(WANT_COMMITTER_IDENT));
 	strbuf_addch(&sob, '\n');
 
 	if (!ignore_footer)
@@ -3723,9 +4427,14 @@ struct labels_entry {
 	char label[FLEX_ARRAY];
 };
 
-static int labels_cmp(const void *fndata, const struct labels_entry *a,
-		      const struct labels_entry *b, const void *key)
+static int labels_cmp(const void *fndata, const struct hashmap_entry *eptr,
+		      const struct hashmap_entry *entry_or_key, const void *key)
 {
+	const struct labels_entry *a, *b;
+
+	a = container_of(eptr, const struct labels_entry, entry);
+	b = container_of(entry_or_key, const struct labels_entry, entry);
+
 	return key ? strcmp(a->label, key) : strcmp(a->label, b->label);
 }
 
@@ -3746,7 +4455,6 @@ static const char *label_oid(struct obje
 	struct labels_entry *labels_entry;
 	struct string_entry *string_entry;
 	struct object_id dummy;
-	size_t len;
 	int i;
 
 	string_entry = oidmap_get(&state->commit2label, oid);
@@ -3766,11 +4474,11 @@ static const char *label_oid(struct obje
 	 * abbreviation for any uninteresting commit's names that does not
 	 * clash with any other label.
 	 */
+	strbuf_reset(&state->buf);
 	if (!label) {
 		char *p;
 
-		strbuf_reset(&state->buf);
-		strbuf_grow(&state->buf, GIT_SHA1_HEXSZ);
+		strbuf_grow(&state->buf, GIT_MAX_HEXSZ);
 		label = p = state->buf.buf;
 
 		find_unique_abbrev_r(p, oid, default_abbrev);
@@ -3783,7 +4491,7 @@ static const char *label_oid(struct obje
 			size_t i = strlen(p) + 1;
 
 			oid_to_hex_r(p, oid);
-			for (; i < GIT_SHA1_HEXSZ; i++) {
+			for (; i < the_hash_algo->hexsz; i++) {
 				char save = p[i];
 				p[i] = '\0';
 				if (!hashmap_get_from_hash(&state->labels,
@@ -3792,37 +4500,60 @@ static const char *label_oid(struct obje
 				p[i] = save;
 			}
 		}
-	} else if (((len = strlen(label)) == the_hash_algo->hexsz &&
-		    !get_oid_hex(label, &dummy)) ||
-		   (len == 1 && *label == '#') ||
-		   hashmap_get_from_hash(&state->labels,
-					 strihash(label), label)) {
+	} else {
+		struct strbuf *buf = &state->buf;
+
 		/*
-		 * If the label already exists, or if the label is a valid full
-		 * OID, or the label is a '#' (which we use as a separator
-		 * between merge heads and oneline), we append a dash and a
-		 * number to make it unique.
+		 * Sanitize labels by replacing non-alpha-numeric characters
+		 * (including white-space ones) by dashes, as they might be
+		 * illegal in file names (and hence in ref names).
+		 *
+		 * Note that we retain non-ASCII UTF-8 characters (identified
+		 * via the most significant bit). They should be all acceptable
+		 * in file names. We do not validate the UTF-8 here, that's not
+		 * the job of this function.
 		 */
-		struct strbuf *buf = &state->buf;
+		for (; *label; label++)
+			if ((*label & 0x80) || isalnum(*label))
+				strbuf_addch(buf, *label);
+			/* avoid leading dash and double-dashes */
+			else if (buf->len && buf->buf[buf->len - 1] != '-')
+				strbuf_addch(buf, '-');
+		if (!buf->len) {
+			strbuf_addstr(buf, "rev-");
+			strbuf_add_unique_abbrev(buf, oid, default_abbrev);
+		}
+		label = buf->buf;
 
-		strbuf_reset(buf);
-		strbuf_add(buf, label, len);
+		if ((buf->len == the_hash_algo->hexsz &&
+		     !get_oid_hex(label, &dummy)) ||
+		    (buf->len == 1 && *label == '#') ||
+		    hashmap_get_from_hash(&state->labels,
+					  strihash(label), label)) {
+			/*
+			 * If the label already exists, or if the label is a
+			 * valid full OID, or the label is a '#' (which we use
+			 * as a separator between merge heads and oneline), we
+			 * append a dash and a number to make it unique.
+			 */
+			size_t len = buf->len;
 
-		for (i = 2; ; i++) {
-			strbuf_setlen(buf, len);
-			strbuf_addf(buf, "-%d", i);
-			if (!hashmap_get_from_hash(&state->labels,
-						   strihash(buf->buf),
-						   buf->buf))
-				break;
-		}
+			for (i = 2; ; i++) {
+				strbuf_setlen(buf, len);
+				strbuf_addf(buf, "-%d", i);
+				if (!hashmap_get_from_hash(&state->labels,
+							   strihash(buf->buf),
+							   buf->buf))
+					break;
+			}
 
-		label = buf->buf;
+			label = buf->buf;
+		}
 	}
 
 	FLEX_ALLOC_STR(labels_entry, label, label);
-	hashmap_entry_init(labels_entry, strihash(label));
-	hashmap_add(&state->labels, labels_entry);
+	hashmap_entry_init(&labels_entry->entry, strihash(label));
+	hashmap_add(&state->labels, &labels_entry->entry);
 
 	FLEX_ALLOC_STR(string_entry, string, label);
 	oidcpy(&string_entry->entry.oid, oid);
@@ -3832,11 +4563,12 @@ static const char *label_oid(struct obje
 }
 
 static int make_script_with_merges(struct pretty_print_context *pp,
-				   struct rev_info *revs, FILE *out,
+				   struct rev_info *revs, struct strbuf *out,
 				   unsigned flags)
 {
 	int keep_empty = flags & TODO_LIST_KEEP_EMPTY;
 	int rebase_cousins = flags & TODO_LIST_REBASE_COUSINS;
+	int root_with_onto = flags & TODO_LIST_ROOT_WITH_ONTO;
 	struct strbuf buf = STRBUF_INIT, oneline = STRBUF_INIT;
 	struct strbuf label = STRBUF_INIT;
 	struct commit_list *commits = NULL, **tail = &commits, *iter;
@@ -3856,14 +4588,19 @@ static int make_script_with_merges(struc
 
 	oidmap_init(&commit2todo, 0);
 	oidmap_init(&state.commit2label, 0);
-	hashmap_init(&state.labels, (hashmap_cmp_fn) labels_cmp, NULL, 0);
+	hashmap_init(&state.labels, labels_cmp, NULL, 0);
 	strbuf_init(&state.buf, 32);
 
 	if (revs->cmdline.nr && (revs->cmdline.rev[0].flags & BOTTOM)) {
+		struct labels_entry *onto_label_entry;
 		struct object_id *oid = &revs->cmdline.rev[0].item->oid;
 		FLEX_ALLOC_STR(entry, string, "onto");
 		oidcpy(&entry->entry.oid, oid);
 		oidmap_put(&state.commit2label, entry);
+
+		FLEX_ALLOC_STR(onto_label_entry, label, "onto");
+		hashmap_entry_init(&onto_label_entry->entry, strihash("onto"));
+		hashmap_add(&state.labels, &onto_label_entry->entry);
 	}
 
 	/*
@@ -3874,7 +4611,6 @@ static int make_script_with_merges(struc
 	 */
 	while ((commit = get_revision(revs))) {
 		struct commit_list *to_merge;
-		int is_octopus;
 		const char *p1, *p2;
 		struct object_id *oid;
 		int is_empty;
@@ -3906,11 +4642,6 @@ static int make_script_with_merges(struc
 			continue;
 		}
 
-		is_octopus = to_merge && to_merge->next;
-
-		if (is_octopus)
-			BUG("Octopus merges not yet supported");
-
 		/* Create a label */
 		strbuf_reset(&label);
 		if (skip_prefix(oneline.buf, "Merge ", &p1) &&
@@ -3924,21 +4655,21 @@ static int make_script_with_merges(struc
 		else
 			strbuf_addbuf(&label, &oneline);
 
-		for (p1 = label.buf; *p1; p1++)
-			if (isspace(*p1))
-				*(char *)p1 = '-';
-
 		strbuf_reset(&buf);
 		strbuf_addf(&buf, "%s -C %s",
 			    cmd_merge, oid_to_hex(&commit->object.oid));
 
-		/* label the tip of merged branch */
-		oid = &to_merge->item->object.oid;
-		strbuf_addch(&buf, ' ');
+		/* label the tips of merged branches */
+		for (; to_merge; to_merge = to_merge->next) {
+			oid = &to_merge->item->object.oid;
+			strbuf_addch(&buf, ' ');
+
+			if (!oidset_contains(&interesting, oid)) {
+				strbuf_addstr(&buf, label_oid(oid, NULL,
+							      &state));
+				continue;
+			}
 
-		if (!oidset_contains(&interesting, oid))
-			strbuf_addstr(&buf, label_oid(oid, NULL, &state));
-		else {
 			tips_tail = &commit_list_insert(to_merge->item,
 							tips_tail)->next;
 
@@ -3962,13 +4693,11 @@ static int make_script_with_merges(struc
 			struct object_id *oid = &parent->item->object.oid;
 			if (!oidset_contains(&interesting, oid))
 				continue;
-			if (!oidset_contains(&child_seen, oid))
-				oidset_insert(&child_seen, oid);
-			else
+			if (oidset_insert(&child_seen, oid))
 				label_oid(oid, "branch-point", &state);
 		}
 
-		/* Add HEAD as implict "tip of branch" */
+		/* Add HEAD as implicit "tip of branch" */
 		if (!iter->next)
 			tips_tail = &commit_list_insert(iter->item,
 							tips_tail)->next;
@@ -3981,7 +4710,7 @@ static int make_script_with_merges(struc
 	 * gathering commits not yet shown, reversing the list on the fly,
 	 * then outputting that list (labeling revisions as needed).
 	 */
-	fprintf(out, "%s onto\n", cmd_label);
+	strbuf_addf(out, "%s onto\n", cmd_label);
 	for (iter = tips; iter; iter = iter->next) {
 		struct commit_list *list = NULL, *iter2;
 
@@ -3991,9 +4720,9 @@ static int make_script_with_merges(struc
 		entry = oidmap_get(&state.commit2label, &commit->object.oid);
 
 		if (entry)
-			fprintf(out, "\n# Branch %s\n", entry->string);
+			strbuf_addf(out, "\n%c Branch %s\n", comment_line_char, entry->string);
 		else
-			fprintf(out, "\n");
+			strbuf_addch(out, '\n');
 
 		while (oidset_contains(&interesting, &commit->object.oid) &&
 		       !oidset_contains(&shown, &commit->object.oid)) {
@@ -4006,8 +4735,9 @@ static int make_script_with_merges(struc
 		}
 
 		if (!commit)
-			fprintf(out, "%s %s\n", cmd_reset,
-				rebase_cousins ? "onto" : "[new root]");
+			strbuf_addf(out, "%s %s\n", cmd_reset,
+				    rebase_cousins || root_with_onto ?
+				    "onto" : "[new root]");
 		else {
 			const char *to = NULL;
 
@@ -4020,12 +4750,12 @@ static int make_script_with_merges(struc
 					       &state);
 
 			if (!to || !strcmp(to, "onto"))
-				fprintf(out, "%s onto\n", cmd_reset);
+				strbuf_addf(out, "%s onto\n", cmd_reset);
 			else {
 				strbuf_reset(&oneline);
 				pretty_print_commit(pp, commit, &oneline);
-				fprintf(out, "%s %s # %s\n",
-					cmd_reset, to, oneline.buf);
+				strbuf_addf(out, "%s %s # %s\n",
+					    cmd_reset, to, oneline.buf);
 			}
 		}
 
@@ -4034,11 +4764,11 @@ static int make_script_with_merges(struc
 			entry = oidmap_get(&commit2todo, oid);
 			/* only show if not already upstream */
 			if (entry)
-				fprintf(out, "%s\n", entry->string);
+				strbuf_addf(out, "%s\n", entry->string);
 			entry = oidmap_get(&state.commit2label, oid);
 			if (entry)
-				fprintf(out, "%s %s\n",
-					cmd_label, entry->string);
+				strbuf_addf(out, "%s %s\n",
+					    cmd_label, entry->string);
 			oidset_insert(&shown, oid);
 		}
 
@@ -4054,25 +4784,24 @@ static int make_script_with_merges(struc
 
 	oidmap_free(&commit2todo, 1);
 	oidmap_free(&state.commit2label, 1);
-	hashmap_free(&state.labels, 1);
+	hashmap_free_entries(&state.labels, struct labels_entry, entry);
 	strbuf_release(&state.buf);
 
 	return 0;
 }
 
-int sequencer_make_script(FILE *out, int argc, const char **argv,
-			  unsigned flags)
+int sequencer_make_script(struct repository *r, struct strbuf *out, int argc,
+			  const char **argv, unsigned flags)
 {
 	char *format = NULL;
 	struct pretty_print_context pp = {0};
-	struct strbuf buf = STRBUF_INIT;
 	struct rev_info revs;
 	struct commit *commit;
 	int keep_empty = flags & TODO_LIST_KEEP_EMPTY;
 	const char *insn = flags & TODO_LIST_ABBREVIATE_CMDS ? "p" : "pick";
 	int rebase_merges = flags & TODO_LIST_REBASE_MERGES;
 
-	init_revisions(&revs, NULL);
+	repo_init_revisions(r, &revs, NULL);
 	revs.verbose_header = 1;
 	if (!rebase_merges)
 		revs.max_parents = 1;
@@ -4108,16 +4837,13 @@ int sequencer_make_script(FILE *out, int
 
 		if (!is_empty && (commit->object.flags & PATCHSAME))
 			continue;
-		strbuf_reset(&buf);
 		if (!keep_empty && is_empty)
-			strbuf_addf(&buf, "%c ", comment_line_char);
-		strbuf_addf(&buf, "%s %s ", insn,
+			strbuf_addf(out, "%c ", comment_line_char);
+		strbuf_addf(out, "%s %s ", insn,
 			    oid_to_hex(&commit->object.oid));
-		pretty_print_commit(&pp, commit, &buf);
-		strbuf_addch(&buf, '\n');
-		fputs(buf.buf, out);
+		pretty_print_commit(&pp, commit, out);
+		strbuf_addch(out, '\n');
 	}
-	strbuf_release(&buf);
 	return 0;
 }
 
@@ -4125,70 +4851,95 @@ int sequencer_make_script(FILE *out, int
  * Add commands after pick and (series of) squash/fixup commands
  * in the todo list.
  */
-int sequencer_add_exec_commands(const char *commands)
+void todo_list_add_exec_commands(struct todo_list *todo_list,
+				 struct string_list *commands)
 {
-	const char *todo_file = rebase_path_todo();
-	struct todo_list todo_list = TODO_LIST_INIT;
-	struct todo_item *item;
-	struct strbuf *buf = &todo_list.buf;
-	size_t offset = 0, commands_len = strlen(commands);
-	int i, first;
-
-	if (strbuf_read_file(&todo_list.buf, todo_file, 0) < 0)
-		return error(_("could not read '%s'."), todo_file);
+	struct strbuf *buf = &todo_list->buf;
+	size_t base_offset = buf->len;
+	int i, insert, nr = 0, alloc = 0;
+	struct todo_item *items = NULL, *base_items = NULL;
+
+	base_items = xcalloc(commands->nr, sizeof(struct todo_item));
+	for (i = 0; i < commands->nr; i++) {
+		size_t command_len = strlen(commands->items[i].string);
+
+		strbuf_addstr(buf, commands->items[i].string);
+		strbuf_addch(buf, '\n');
+
+		base_items[i].command = TODO_EXEC;
+		base_items[i].offset_in_buf = base_offset;
+		base_items[i].arg_offset = base_offset + strlen("exec ");
+		base_items[i].arg_len = command_len - strlen("exec ");
 
-	if (parse_insn_buffer(todo_list.buf.buf, &todo_list)) {
-		todo_list_release(&todo_list);
-		return error(_("unusable todo list: '%s'"), todo_file);
+		base_offset += command_len + 1;
 	}
 
-	first = 1;
-	/* insert <commands> before every pick except the first one */
-	for (item = todo_list.items, i = 0; i < todo_list.nr; i++, item++) {
-		if (item->command == TODO_PICK && !first) {
-			strbuf_insert(buf, item->offset_in_buf + offset,
-				      commands, commands_len);
-			offset += commands_len;
+	/*
+	 * Insert <commands> after every pick. Here, fixup/squash chains
+	 * are considered part of the pick, so we insert the commands *after*
+	 * those chains if there are any.
+	 *
+	 * As we insert the exec commands immediately after rearranging
+	 * any fixups and before the user edits the list, a fixup chain
+	 * can never contain comments (any comments are empty picks that
+	 * have been commented out because the user did not specify
+	 * --keep-empty).  So, it is safe to insert an exec command
+	 * without looking at the command following a comment.
+	 */
+	insert = 0;
+	for (i = 0; i < todo_list->nr; i++) {
+		enum todo_command command = todo_list->items[i].command;
+		if (insert && !is_fixup(command)) {
+			ALLOC_GROW(items, nr + commands->nr, alloc);
+			COPY_ARRAY(items + nr, base_items, commands->nr);
+			nr += commands->nr;
+
+			insert = 0;
 		}
-		first = 0;
+
+		ALLOC_GROW(items, nr + 1, alloc);
+		items[nr++] = todo_list->items[i];
+
+		if (command == TODO_PICK || command == TODO_MERGE)
+			insert = 1;
 	}
 
-	/* append final <commands> */
-	strbuf_add(buf, commands, commands_len);
+	/* insert or append final <commands> */
+	if (insert || nr == todo_list->nr) {
+		ALLOC_GROW(items, nr + commands->nr, alloc);
+		COPY_ARRAY(items + nr, base_items, commands->nr);
+		nr += commands->nr;
+	}
 
-	i = write_message(buf->buf, buf->len, todo_file, 0);
-	todo_list_release(&todo_list);
-	return i;
+	free(base_items);
+	FREE_AND_NULL(todo_list->items);
+	todo_list->items = items;
+	todo_list->nr = nr;
+	todo_list->alloc = alloc;
 }
 
-int transform_todos(unsigned flags)
+static void todo_list_to_strbuf(struct repository *r, struct todo_list *todo_list,
+				struct strbuf *buf, int num, unsigned flags)
 {
-	const char *todo_file = rebase_path_todo();
-	struct todo_list todo_list = TODO_LIST_INIT;
-	struct strbuf buf = STRBUF_INIT;
 	struct todo_item *item;
-	int i;
+	int i, max = todo_list->nr;
 
-	if (strbuf_read_file(&todo_list.buf, todo_file, 0) < 0)
-		return error(_("could not read '%s'."), todo_file);
+	if (num > 0 && num < max)
+		max = num;
 
-	if (parse_insn_buffer(todo_list.buf.buf, &todo_list)) {
-		todo_list_release(&todo_list);
-		return error(_("unusable todo list: '%s'"), todo_file);
-	}
-
-	for (item = todo_list.items, i = 0; i < todo_list.nr; i++, item++) {
+	for (item = todo_list->items, i = 0; i < max; i++, item++) {
 		/* if the item is not a command write it and continue */
 		if (item->command >= TODO_COMMENT) {
-			strbuf_addf(&buf, "%.*s\n", item->arg_len, item->arg);
+			strbuf_addf(buf, "%.*s\n", item->arg_len,
+				    todo_item_get_arg(todo_list, item));
 			continue;
 		}
 
 		/* add command to the buffer */
 		if (flags & TODO_LIST_ABBREVIATE_CMDS)
-			strbuf_addch(&buf, command_to_char(item->command));
+			strbuf_addch(buf, command_to_char(item->command));
 		else
-			strbuf_addstr(&buf, command_to_string(item->command));
+			strbuf_addstr(buf, command_to_string(item->command));
 
 		/* add commit id */
 		if (item->commit) {
@@ -4198,180 +4949,92 @@ int transform_todos(unsigned flags)
 
 			if (item->command == TODO_MERGE) {
 				if (item->flags & TODO_EDIT_MERGE_MSG)
-					strbuf_addstr(&buf, " -c");
+					strbuf_addstr(buf, " -c");
 				else
-					strbuf_addstr(&buf, " -C");
+					strbuf_addstr(buf, " -C");
 			}
 
-			strbuf_addf(&buf, " %s", oid);
+			strbuf_addf(buf, " %s", oid);
 		}
 
 		/* add all the rest */
 		if (!item->arg_len)
-			strbuf_addch(&buf, '\n');
+			strbuf_addch(buf, '\n');
 		else
-			strbuf_addf(&buf, " %.*s\n", item->arg_len, item->arg);
+			strbuf_addf(buf, " %.*s\n", item->arg_len,
+				    todo_item_get_arg(todo_list, item));
 	}
-
-	i = write_message(buf.buf, buf.len, todo_file, 0);
-	todo_list_release(&todo_list);
-	return i;
 }
 
-enum check_level {
-	CHECK_IGNORE = 0, CHECK_WARN, CHECK_ERROR
-};
-
-static enum check_level get_missing_commit_check_level(void)
+int todo_list_write_to_file(struct repository *r, struct todo_list *todo_list,
+			    const char *file, const char *shortrevisions,
+			    const char *shortonto, int num, unsigned flags)
 {
-	const char *value;
+	int res;
+	struct strbuf buf = STRBUF_INIT;
 
-	if (git_config_get_value("rebase.missingcommitscheck", &value) ||
-			!strcasecmp("ignore", value))
-		return CHECK_IGNORE;
-	if (!strcasecmp("warn", value))
-		return CHECK_WARN;
-	if (!strcasecmp("error", value))
-		return CHECK_ERROR;
-	warning(_("unrecognized setting %s for option "
-		  "rebase.missingCommitsCheck. Ignoring."), value);
-	return CHECK_IGNORE;
-}
+	todo_list_to_strbuf(r, todo_list, &buf, num, flags);
+	if (flags & TODO_LIST_APPEND_TODO_HELP)
+		append_todo_help(flags & TODO_LIST_KEEP_EMPTY, count_commands(todo_list),
+				 shortrevisions, shortonto, &buf);
 
-/*
- * Check if the user dropped some commits by mistake
- * Behaviour determined by rebase.missingCommitsCheck.
- * Check if there is an unrecognized command or a
- * bad SHA-1 in a command.
- */
-int check_todo_list(void)
-{
-	enum check_level check_level = get_missing_commit_check_level();
-	struct strbuf todo_file = STRBUF_INIT;
-	struct todo_list todo_list = TODO_LIST_INIT;
-	struct strbuf missing = STRBUF_INIT;
-	int advise_to_edit_todo = 0, res = 0, i;
+	res = write_message(buf.buf, buf.len, file, 0);
+	strbuf_release(&buf);
 
-	strbuf_addstr(&todo_file, rebase_path_todo());
-	if (strbuf_read_file_or_whine(&todo_list.buf, todo_file.buf) < 0) {
-		res = -1;
-		goto leave_check;
-	}
-	advise_to_edit_todo = res =
-		parse_insn_buffer(todo_list.buf.buf, &todo_list);
+	return res;
+}
 
-	if (res || check_level == CHECK_IGNORE)
-		goto leave_check;
+static const char edit_todo_list_advice[] =
+N_("You can fix this with 'git rebase --edit-todo' "
+"and then run 'git rebase --continue'.\n"
+"Or you can abort the rebase with 'git rebase"
+" --abort'.\n");
 
-	/* Mark the commits in git-rebase-todo as seen */
-	for (i = 0; i < todo_list.nr; i++) {
-		struct commit *commit = todo_list.items[i].commit;
-		if (commit)
-			commit->util = (void *)1;
-	}
+int check_todo_list_from_file(struct repository *r)
+{
+	struct todo_list old_todo = TODO_LIST_INIT, new_todo = TODO_LIST_INIT;
+	int res = 0;
 
-	todo_list_release(&todo_list);
-	strbuf_addstr(&todo_file, ".backup");
-	if (strbuf_read_file_or_whine(&todo_list.buf, todo_file.buf) < 0) {
+	if (strbuf_read_file_or_whine(&new_todo.buf, rebase_path_todo()) < 0) {
 		res = -1;
-		goto leave_check;
+		goto out;
 	}
-	strbuf_release(&todo_file);
-	res = !!parse_insn_buffer(todo_list.buf.buf, &todo_list);
 
-	/* Find commits in git-rebase-todo.backup yet unseen */
-	for (i = todo_list.nr - 1; i >= 0; i--) {
-		struct todo_item *item = todo_list.items + i;
-		struct commit *commit = item->commit;
-		if (commit && !commit->util) {
-			strbuf_addf(&missing, " - %s %.*s\n",
-				    short_commit_name(commit),
-				    item->arg_len, item->arg);
-			commit->util = (void *)1;
-		}
+	if (strbuf_read_file_or_whine(&old_todo.buf, rebase_path_todo_backup()) < 0) {
+		res = -1;
+		goto out;
 	}
 
-	/* Warn about missing commits */
-	if (!missing.len)
-		goto leave_check;
-
-	if (check_level == CHECK_ERROR)
-		advise_to_edit_todo = res = 1;
-
-	fprintf(stderr,
-		_("Warning: some commits may have been dropped accidentally.\n"
-		"Dropped commits (newer to older):\n"));
-
-	/* Make the list user-friendly and display */
-	fputs(missing.buf, stderr);
-	strbuf_release(&missing);
-
-	fprintf(stderr, _("To avoid this message, use \"drop\" to "
-		"explicitly remove a commit.\n\n"
-		"Use 'git config rebase.missingCommitsCheck' to change "
-		"the level of warnings.\n"
-		"The possible behaviours are: ignore, warn, error.\n\n"));
-
-leave_check:
-	strbuf_release(&todo_file);
-	todo_list_release(&todo_list);
-
-	if (advise_to_edit_todo)
-		fprintf(stderr,
-			_("You can fix this with 'git rebase --edit-todo' "
-			  "and then run 'git rebase --continue'.\n"
-			  "Or you can abort the rebase with 'git rebase"
-			  " --abort'.\n"));
+	res = todo_list_parse_insn_buffer(r, old_todo.buf.buf, &old_todo);
+	if (!res)
+		res = todo_list_parse_insn_buffer(r, new_todo.buf.buf, &new_todo);
+	if (!res)
+		res = todo_list_check(&old_todo, &new_todo);
+	if (res)
+		fprintf(stderr, _(edit_todo_list_advice));
+out:
+	todo_list_release(&old_todo);
+	todo_list_release(&new_todo);
 
 	return res;
 }
 
-static int rewrite_file(const char *path, const char *buf, size_t len)
-{
-	int rc = 0;
-	int fd = open(path, O_WRONLY | O_TRUNC);
-	if (fd < 0)
-		return error_errno(_("could not open '%s' for writing"), path);
-	if (write_in_full(fd, buf, len) < 0)
-		rc = error_errno(_("could not write to '%s'"), path);
-	if (close(fd) && !rc)
-		rc = error_errno(_("could not close '%s'"), path);
-	return rc;
-}
-
 /* skip picking commits whose parents are unchanged */
-int skip_unnecessary_picks(void)
+static int skip_unnecessary_picks(struct repository *r,
+				  struct todo_list *todo_list,
+				  struct object_id *base_oid)
 {
-	const char *todo_file = rebase_path_todo();
-	struct strbuf buf = STRBUF_INIT;
-	struct todo_list todo_list = TODO_LIST_INIT;
-	struct object_id onto_oid, *oid = &onto_oid, *parent_oid;
-	int fd, i;
-
-	if (!read_oneliner(&buf, rebase_path_onto(), 0))
-		return error(_("could not read 'onto'"));
-	if (get_oid(buf.buf, &onto_oid)) {
-		strbuf_release(&buf);
-		return error(_("need a HEAD to fixup"));
-	}
-	strbuf_release(&buf);
-
-	if (strbuf_read_file_or_whine(&todo_list.buf, todo_file) < 0)
-		return -1;
-	if (parse_insn_buffer(todo_list.buf.buf, &todo_list) < 0) {
-		todo_list_release(&todo_list);
-		return -1;
-	}
+	struct object_id *parent_oid;
+	int i;
 
-	for (i = 0; i < todo_list.nr; i++) {
-		struct todo_item *item = todo_list.items + i;
+	for (i = 0; i < todo_list->nr; i++) {
+		struct todo_item *item = todo_list->items + i;
 
 		if (item->command >= TODO_NOOP)
 			continue;
 		if (item->command != TODO_PICK)
 			break;
 		if (parse_commit(item->commit)) {
-			todo_list_release(&todo_list);
 			return error(_("could not parse commit '%s'"),
 				oid_to_hex(&item->commit->object.oid));
 		}
@@ -4380,46 +5043,118 @@ int skip_unnecessary_picks(void)
 		if (item->commit->parents->next)
 			break; /* merge commit */
 		parent_oid = &item->commit->parents->item->object.oid;
-		if (hashcmp(parent_oid->hash, oid->hash))
+		if (!oideq(parent_oid, base_oid))
 			break;
-		oid = &item->commit->object.oid;
+		oidcpy(base_oid, &item->commit->object.oid);
 	}
 	if (i > 0) {
-		int offset = get_item_line_offset(&todo_list, i);
 		const char *done_path = rebase_path_done();
 
-		fd = open(done_path, O_CREAT | O_WRONLY | O_APPEND, 0666);
-		if (fd < 0) {
-			error_errno(_("could not open '%s' for writing"),
-				    done_path);
-			todo_list_release(&todo_list);
-			return -1;
-		}
-		if (write_in_full(fd, todo_list.buf.buf, offset) < 0) {
+		if (todo_list_write_to_file(r, todo_list, done_path, NULL, NULL, i, 0)) {
 			error_errno(_("could not write to '%s'"), done_path);
-			todo_list_release(&todo_list);
-			close(fd);
 			return -1;
 		}
-		close(fd);
 
-		if (rewrite_file(rebase_path_todo(), todo_list.buf.buf + offset,
-				 todo_list.buf.len - offset) < 0) {
-			todo_list_release(&todo_list);
-			return -1;
-		}
+		MOVE_ARRAY(todo_list->items, todo_list->items + i, todo_list->nr - i);
+		todo_list->nr -= i;
+		todo_list->current = 0;
+		todo_list->done_nr += i;
 
-		todo_list.current = i;
-		if (is_fixup(peek_command(&todo_list, 0)))
-			record_in_rewritten(oid, peek_command(&todo_list, 0));
+		if (is_fixup(peek_command(todo_list, 0)))
+			record_in_rewritten(base_oid, peek_command(todo_list, 0));
 	}
 
-	todo_list_release(&todo_list);
-	printf("%s\n", oid_to_hex(oid));
-
 	return 0;
 }
 
+int complete_action(struct repository *r, struct replay_opts *opts, unsigned flags,
+		    const char *shortrevisions, const char *onto_name,
+		    struct commit *onto, const char *orig_head,
+		    struct string_list *commands, unsigned autosquash,
+		    struct todo_list *todo_list)
+{
+	const char *shortonto, *todo_file = rebase_path_todo();
+	struct todo_list new_todo = TODO_LIST_INIT;
+	struct strbuf *buf = &todo_list->buf;
+	struct object_id oid = onto->object.oid;
+	int res;
+
+	shortonto = find_unique_abbrev(&oid, DEFAULT_ABBREV);
+
+	if (buf->len == 0) {
+		struct todo_item *item = append_new_todo(todo_list);
+		item->command = TODO_NOOP;
+		item->commit = NULL;
+		item->arg_len = item->arg_offset = item->flags = item->offset_in_buf = 0;
+	}
+
+	if (autosquash && todo_list_rearrange_squash(todo_list))
+		return -1;
+
+	if (commands->nr)
+		todo_list_add_exec_commands(todo_list, commands);
+
+	if (count_commands(todo_list) == 0) {
+		apply_autostash(opts);
+		sequencer_remove_state(opts);
+
+		return error(_("nothing to do"));
+	}
+
+	res = edit_todo_list(r, todo_list, &new_todo, shortrevisions,
+			     shortonto, flags);
+	if (res == -1)
+		return -1;
+	else if (res == -2) {
+		apply_autostash(opts);
+		sequencer_remove_state(opts);
+
+		return -1;
+	} else if (res == -3) {
+		apply_autostash(opts);
+		sequencer_remove_state(opts);
+		todo_list_release(&new_todo);
+
+		return error(_("nothing to do"));
+	}
+
+	if (todo_list_parse_insn_buffer(r, new_todo.buf.buf, &new_todo) ||
+	    todo_list_check(todo_list, &new_todo)) {
+		fprintf(stderr, _(edit_todo_list_advice));
+		checkout_onto(r, opts, onto_name, &onto->object.oid, orig_head);
+		todo_list_release(&new_todo);
+
+		return -1;
+	}
+
+	if (opts->allow_ff && skip_unnecessary_picks(r, &new_todo, &oid)) {
+		todo_list_release(&new_todo);
+		return error(_("could not skip unnecessary pick commands"));
+	}
+
+	if (todo_list_write_to_file(r, &new_todo, todo_file, NULL, NULL, -1,
+				    flags & ~(TODO_LIST_SHORTEN_IDS))) {
+		todo_list_release(&new_todo);
+		return error_errno(_("could not write '%s'"), todo_file);
+	}
+
+	res = -1;
+
+	if (checkout_onto(r, opts, onto_name, &oid, orig_head))
+		goto cleanup;
+
+	if (require_clean_work_tree(r, "rebase", "", 1, 1))
+		goto cleanup;
+
+	todo_list_write_total_nr(&new_todo);
+	res = pick_commits(r, &new_todo, opts);
+
+cleanup:
+	todo_list_release(&new_todo);
+
+	return res;
+}
+
 struct subject2item_entry {
 	struct hashmap_entry entry;
 	int i;
@@ -4427,12 +5162,20 @@ struct subject2item_entry {
 };
 
 static int subject2item_cmp(const void *fndata,
-			    const struct subject2item_entry *a,
-			    const struct subject2item_entry *b, const void *key)
+			    const struct hashmap_entry *eptr,
+			    const struct hashmap_entry *entry_or_key,
+			    const void *key)
 {
+	const struct subject2item_entry *a, *b;
+
+	a = container_of(eptr, const struct subject2item_entry, entry);
+	b = container_of(entry_or_key, const struct subject2item_entry, entry);
+
 	return key ? strcmp(a->subject, key) : strcmp(a->subject, b->subject);
 }
 
+define_commit_slab(commit_todo_item, struct todo_item *);
+
 /*
  * Rearrange the todo list that has both "pick commit-id msg" and "pick
  * commit-id fixup!/squash! msg" in it so that the latter is put immediately
@@ -4442,21 +5185,15 @@ static int subject2item_cmp(const void *
  * message will have to be retrieved from the commit (as the oneline in the
  * script cannot be trusted) in order to normalize the autosquash arrangement.
  */
-int rearrange_squash(void)
+int todo_list_rearrange_squash(struct todo_list *todo_list)
 {
-	const char *todo_file = rebase_path_todo();
-	struct todo_list todo_list = TODO_LIST_INIT;
 	struct hashmap subject2item;
-	int res = 0, rearranged = 0, *next, *tail, i;
+	int rearranged = 0, *next, *tail, i, nr = 0, alloc = 0;
 	char **subjects;
+	struct commit_todo_item commit_todo;
+	struct todo_item *items = NULL;
 
-	if (strbuf_read_file_or_whine(&todo_list.buf, todo_file) < 0)
-		return -1;
-	if (parse_insn_buffer(todo_list.buf.buf, &todo_list) < 0) {
-		todo_list_release(&todo_list);
-		return -1;
-	}
-
+	init_commit_todo_item(&commit_todo);
 	/*
 	 * The hashmap maps onelines to the respective todo list index.
 	 *
@@ -4466,14 +5203,13 @@ int rearrange_squash(void)
 	 * In that case, last[i] will indicate the index of the latest item to
 	 * be moved to appear after the i'th.
 	 */
-	hashmap_init(&subject2item, (hashmap_cmp_fn) subject2item_cmp,
-		     NULL, todo_list.nr);
-	ALLOC_ARRAY(next, todo_list.nr);
-	ALLOC_ARRAY(tail, todo_list.nr);
-	ALLOC_ARRAY(subjects, todo_list.nr);
-	for (i = 0; i < todo_list.nr; i++) {
+	hashmap_init(&subject2item, subject2item_cmp, NULL, todo_list->nr);
+	ALLOC_ARRAY(next, todo_list->nr);
+	ALLOC_ARRAY(tail, todo_list->nr);
+	ALLOC_ARRAY(subjects, todo_list->nr);
+	for (i = 0; i < todo_list->nr; i++) {
 		struct strbuf buf = STRBUF_INIT;
-		struct todo_item *item = todo_list.items + i;
+		struct todo_item *item = todo_list->items + i;
 		const char *commit_buffer, *subject, *p;
 		size_t subject_len;
 		int i2 = -1;
@@ -4486,14 +5222,14 @@ int rearrange_squash(void)
 		}
 
 		if (is_fixup(item->command)) {
-			todo_list_release(&todo_list);
+			clear_commit_todo_item(&commit_todo);
 			return error(_("the script was already rearranged."));
 		}
 
-		item->commit->util = item;
+		*commit_todo_item_at(&commit_todo, item->commit) = item;
 
 		parse_commit(item->commit);
-		commit_buffer = get_commit_buffer(item->commit, NULL);
+		commit_buffer = logmsg_reencode(item->commit, NULL, "UTF-8");
 		find_commit_subject(commit_buffer, &subject);
 		format_subject(&buf, subject, " ");
 		subject = subjects[i] = strbuf_detach(&buf, &subject_len);
@@ -4510,17 +5246,20 @@ int rearrange_squash(void)
 					break;
 			}
 
-			if ((entry = hashmap_get_from_hash(&subject2item,
-							   strhash(p), p)))
+			entry = hashmap_get_entry_from_hash(&subject2item,
+						strhash(p), p,
+						struct subject2item_entry,
+						entry);
+			if (entry)
 				/* found by title */
 				i2 = entry->i;
 			else if (!strchr(p, ' ') &&
 				 (commit2 =
 				  lookup_commit_reference_by_name(p)) &&
-				 commit2->util)
+				 *commit_todo_item_at(&commit_todo, commit2))
 				/* found by commit name */
-				i2 = (struct todo_item *)commit2->util
-					- todo_list.items;
+				i2 = *commit_todo_item_at(&commit_todo, commit2)
+					- todo_list->items;
 			else {
 				/* copy can be a prefix of the commit subject */
 				for (i2 = 0; i2 < i; i2++)
@@ -4533,7 +5272,7 @@ int rearrange_squash(void)
 		}
 		if (i2 >= 0) {
 			rearranged = 1;
-			todo_list.items[i].command =
+			todo_list->items[i].command =
 				starts_with(subject, "fixup!") ?
 				TODO_FIXUP : TODO_SQUASH;
 			if (next[i2] < 0)
@@ -4545,16 +5284,15 @@ int rearrange_squash(void)
 						strhash(subject), subject)) {
 			FLEX_ALLOC_MEM(entry, subject, subject, subject_len);
 			entry->i = i;
-			hashmap_entry_init(entry, strhash(entry->subject));
-			hashmap_put(&subject2item, entry);
+			hashmap_entry_init(&entry->entry,
+					strhash(entry->subject));
+			hashmap_put(&subject2item, &entry->entry);
 		}
 	}
 
 	if (rearranged) {
-		struct strbuf buf = STRBUF_INIT;
-
-		for (i = 0; i < todo_list.nr; i++) {
-			enum todo_command command = todo_list.items[i].command;
+		for (i = 0; i < todo_list->nr; i++) {
+			enum todo_command command = todo_list->items[i].command;
 			int cur = i;
 
 			/*
@@ -4565,36 +5303,26 @@ int rearrange_squash(void)
 				continue;
 
 			while (cur >= 0) {
-				const char *bol =
-					get_item_line(&todo_list, cur);
-				const char *eol =
-					get_item_line(&todo_list, cur + 1);
-
-				/* replace 'pick', by 'fixup' or 'squash' */
-				command = todo_list.items[cur].command;
-				if (is_fixup(command)) {
-					strbuf_addstr(&buf,
-						todo_command_info[command].str);
-					bol += strcspn(bol, " \t");
-				}
-
-				strbuf_add(&buf, bol, eol - bol);
-
+				ALLOC_GROW(items, nr + 1, alloc);
+				items[nr++] = todo_list->items[cur];
 				cur = next[cur];
 			}
 		}
 
-		res = rewrite_file(todo_file, buf.buf, buf.len);
-		strbuf_release(&buf);
+		FREE_AND_NULL(todo_list->items);
+		todo_list->items = items;
+		todo_list->nr = nr;
+		todo_list->alloc = alloc;
 	}
 
 	free(next);
 	free(tail);
-	for (i = 0; i < todo_list.nr; i++)
+	for (i = 0; i < todo_list->nr; i++)
 		free(subjects[i]);
 	free(subjects);
-	hashmap_free(&subject2item, 1);
-	todo_list_release(&todo_list);
+	hashmap_free_entries(&subject2item, struct subject2item_entry, entry);
 
-	return res;
+	clear_commit_todo_item(&commit_todo);
+
+	return 0;
 }
diff -pruN 1.2.1+git2.18.0-1/git/sequencer.h 1.2.3+git2.25.1-1/git/sequencer.h
--- 1.2.1+git2.18.0-1/git/sequencer.h	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/sequencer.h	2020-02-17 04:47:35.000000000 +0000
@@ -1,8 +1,16 @@
 #ifndef SEQUENCER_H
 #define SEQUENCER_H
 
+#include "cache.h"
+#include "strbuf.h"
+
+struct commit;
+struct repository;
+
 const char *git_path_commit_editmsg(void);
 const char *git_path_seq_dir(void);
+const char *rebase_path_todo(void);
+const char *rebase_path_todo_backup(void);
 
 #define APPEND_SIGNOFF_DEDUP (1u << 0)
 
@@ -33,11 +41,14 @@ struct replay_opts {
 	int allow_empty_message;
 	int keep_redundant_commits;
 	int verbose;
+	int quiet;
+	int reschedule_failed_exec;
 
 	int mainline;
 
 	char *gpg_sign;
 	enum commit_msg_cleanup_mode default_msg_cleanup;
+	int explicit_cleanup;
 
 	/* Merge strategy */
 	char *strategy;
@@ -57,11 +68,68 @@ struct replay_opts {
 };
 #define REPLAY_OPTS_INIT { .action = -1, .current_fixups = STRBUF_INIT }
 
+/*
+ * Note that ordering matters in this enum. Not only must it match the mapping
+ * of todo_command_info (in sequencer.c), it is also divided into several
+ * sections that matter.  When adding new commands, make sure you add it in the
+ * right section.
+ */
+enum todo_command {
+	/* commands that handle commits */
+	TODO_PICK = 0,
+	TODO_REVERT,
+	TODO_EDIT,
+	TODO_REWORD,
+	TODO_FIXUP,
+	TODO_SQUASH,
+	/* commands that do something else than handling a single commit */
+	TODO_EXEC,
+	TODO_BREAK,
+	TODO_LABEL,
+	TODO_RESET,
+	TODO_MERGE,
+	/* commands that do nothing but are counted for reporting progress */
+	TODO_NOOP,
+	TODO_DROP,
+	/* comments (not counted for reporting progress) */
+	TODO_COMMENT
+};
+
+struct todo_item {
+	enum todo_command command;
+	struct commit *commit;
+	unsigned int flags;
+	int arg_len;
+	/* The offset of the command and its argument in the strbuf */
+	size_t offset_in_buf, arg_offset;
+};
+
+struct todo_list {
+	struct strbuf buf;
+	struct todo_item *items;
+	int nr, alloc, current;
+	int done_nr, total_nr;
+	struct stat_data stat;
+};
+
+#define TODO_LIST_INIT { STRBUF_INIT }
+
+int todo_list_parse_insn_buffer(struct repository *r, char *buf,
+				struct todo_list *todo_list);
+int todo_list_write_to_file(struct repository *r, struct todo_list *todo_list,
+			    const char *file, const char *shortrevisions,
+			    const char *shortonto, int num, unsigned flags);
+void todo_list_release(struct todo_list *todo_list);
+const char *todo_item_get_arg(struct todo_list *todo_list,
+			      struct todo_item *item);
+
 /* Call this to setup defaults before parsing command line options */
 void sequencer_init_config(struct replay_opts *opts);
-int sequencer_pick_revisions(struct replay_opts *opts);
-int sequencer_continue(struct replay_opts *opts);
-int sequencer_rollback(struct replay_opts *opts);
+int sequencer_pick_revisions(struct repository *repo,
+			     struct replay_opts *opts);
+int sequencer_continue(struct repository *repo, struct replay_opts *opts);
+int sequencer_rollback(struct repository *repo, struct replay_opts *opts);
+int sequencer_skip(struct repository *repo, struct replay_opts *opts);
 int sequencer_remove_state(struct replay_opts *opts);
 
 #define TODO_LIST_KEEP_EMPTY (1U << 0)
@@ -74,19 +142,42 @@ int sequencer_remove_state(struct replay
  * commits should be rebased onto the new base, this flag needs to be passed.
  */
 #define TODO_LIST_REBASE_COUSINS (1U << 4)
-int sequencer_make_script(FILE *out, int argc, const char **argv,
-			  unsigned flags);
+#define TODO_LIST_APPEND_TODO_HELP (1U << 5)
+/*
+ * When generating a script that rebases merges with `--root` *and* with
+ * `--onto`, we do not want to re-generate the root commits.
+ */
+#define TODO_LIST_ROOT_WITH_ONTO (1U << 6)
 
-int sequencer_add_exec_commands(const char *command);
-int transform_todos(unsigned flags);
-int check_todo_list(void);
-int skip_unnecessary_picks(void);
-int rearrange_squash(void);
 
-extern const char sign_off_header[];
+int sequencer_make_script(struct repository *r, struct strbuf *out, int argc,
+			  const char **argv, unsigned flags);
+
+void todo_list_add_exec_commands(struct todo_list *todo_list,
+				 struct string_list *commands);
+int check_todo_list_from_file(struct repository *r);
+int complete_action(struct repository *r, struct replay_opts *opts, unsigned flags,
+		    const char *shortrevisions, const char *onto_name,
+		    struct commit *onto, const char *orig_head, struct string_list *commands,
+		    unsigned autosquash, struct todo_list *todo_list);
+int todo_list_rearrange_squash(struct todo_list *todo_list);
+
+/*
+ * Append a signoff to the commit message in "msgbuf". The ignore_footer
+ * parameter specifies the number of bytes at the end of msgbuf that should
+ * not be considered at all. I.e., they are not checked for existing trailers,
+ * and the new signoff will be spliced into the buffer before those bytes.
+ */
+void append_signoff(struct strbuf *msgbuf, size_t ignore_footer, unsigned flag);
+
+void append_conflicts_hint(struct index_state *istate,
+		struct strbuf *msgbuf, enum commit_msg_cleanup_mode cleanup_mode);
+enum commit_msg_cleanup_mode get_cleanup_mode(const char *cleanup_arg,
+	int use_editor);
+
+void cleanup_message(struct strbuf *msgbuf,
+	enum commit_msg_cleanup_mode cleanup_mode, int verbose);
 
-void append_signoff(struct strbuf *msgbuf, int ignore_footer, unsigned flag);
-void append_conflicts_hint(struct strbuf *msgbuf);
 int message_is_empty(const struct strbuf *sb,
 		     enum commit_msg_cleanup_mode cleanup_mode);
 int template_untouched(const struct strbuf *sb, const char *template_file,
@@ -95,11 +186,26 @@ int update_head_with_reflog(const struct
 			    const struct object_id *new_head,
 			    const char *action, const struct strbuf *msg,
 			    struct strbuf *err);
-void commit_post_rewrite(const struct commit *current_head,
+void commit_post_rewrite(struct repository *r,
+			 const struct commit *current_head,
 			 const struct object_id *new_head);
 
+int prepare_branch_to_be_rebased(struct repository *r, struct replay_opts *opts,
+				 const char *commit);
+
 #define SUMMARY_INITIAL_COMMIT   (1 << 0)
 #define SUMMARY_SHOW_AUTHOR_DATE (1 << 1)
-void print_commit_summary(const char *prefix, const struct object_id *oid,
+void print_commit_summary(struct repository *repo,
+			  const char *prefix,
+			  const struct object_id *oid,
 			  unsigned int flags);
-#endif
+
+int read_author_script(const char *path, char **name, char **email, char **date,
+		       int allow_missing);
+void parse_strategy_opts(struct replay_opts *opts, char *raw_opts);
+int write_basic_state(struct replay_opts *opts, const char *head_name,
+		      struct commit *onto, const char *orig_head);
+void sequencer_post_commit_cleanup(struct repository *r, int verbose);
+int sequencer_get_last_command(struct repository* r,
+			       enum replay_action *action);
+#endif /* SEQUENCER_H */
diff -pruN 1.2.1+git2.18.0-1/git/serve.c 1.2.3+git2.25.1-1/git/serve.c
--- 1.2.1+git2.18.0-1/git/serve.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/serve.c	2020-02-17 04:47:35.000000000 +0000
@@ -167,7 +167,8 @@ static int process_request(void)
 
 	packet_reader_init(&reader, 0, NULL, 0,
 			   PACKET_READ_CHOMP_NEWLINE |
-			   PACKET_READ_GENTLE_ON_EOF);
+			   PACKET_READ_GENTLE_ON_EOF |
+			   PACKET_READ_DIE_ON_ERR_PACKET);
 
 	/*
 	 * Check to see if the client closed their end before sending another
@@ -175,7 +176,7 @@ static int process_request(void)
 	 */
 	if (packet_reader_peek(&reader) == PACKET_READ_EOF)
 		return 1;
-	reader.options = PACKET_READ_CHOMP_NEWLINE;
+	reader.options &= ~PACKET_READ_GENTLE_ON_EOF;
 
 	while (state != PROCESS_REQUEST_DONE) {
 		switch (packet_reader_peek(&reader)) {
diff -pruN 1.2.1+git2.18.0-1/git/serve.h 1.2.3+git2.25.1-1/git/serve.h
--- 1.2.1+git2.18.0-1/git/serve.h	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/serve.h	2020-02-17 04:47:35.000000000 +0000
@@ -2,14 +2,14 @@
 #define SERVE_H
 
 struct argv_array;
-extern int has_capability(const struct argv_array *keys, const char *capability,
-			  const char **value);
+int has_capability(const struct argv_array *keys, const char *capability,
+		   const char **value);
 
 struct serve_options {
 	unsigned advertise_capabilities;
 	unsigned stateless_rpc;
 };
 #define SERVE_OPTIONS_INIT { 0 }
-extern void serve(struct serve_options *options);
+void serve(struct serve_options *options);
 
 #endif /* SERVE_H */
diff -pruN 1.2.1+git2.18.0-1/git/server-info.c 1.2.3+git2.25.1-1/git/server-info.c
--- 1.2.1+git2.18.0-1/git/server-info.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/server-info.c	2020-02-17 04:47:35.000000000 +0000
@@ -1,4 +1,5 @@
 #include "cache.h"
+#include "dir.h"
 #include "repository.h"
 #include "refs.h"
 #include "object.h"
@@ -6,82 +7,174 @@
 #include "tag.h"
 #include "packfile.h"
 #include "object-store.h"
+#include "strbuf.h"
+
+struct update_info_ctx {
+	FILE *cur_fp;
+	FILE *old_fp; /* becomes NULL if it differs from cur_fp */
+	struct strbuf cur_sb;
+	struct strbuf old_sb;
+};
+
+static void uic_mark_stale(struct update_info_ctx *uic)
+{
+	fclose(uic->old_fp);
+	uic->old_fp = NULL;
+}
+
+static int uic_is_stale(const struct update_info_ctx *uic)
+{
+	return uic->old_fp == NULL;
+}
+
+static int uic_printf(struct update_info_ctx *uic, const char *fmt, ...)
+{
+	va_list ap;
+	int ret = -1;
+
+	va_start(ap, fmt);
+
+	if (uic_is_stale(uic)) {
+		ret = vfprintf(uic->cur_fp, fmt, ap);
+	} else {
+		ssize_t r;
+		struct strbuf *cur = &uic->cur_sb;
+		struct strbuf *old = &uic->old_sb;
+
+		strbuf_reset(cur);
+		strbuf_vinsertf(cur, 0, fmt, ap);
+
+		strbuf_reset(old);
+		strbuf_grow(old, cur->len);
+		r = fread(old->buf, 1, cur->len, uic->old_fp);
+		if (r != cur->len || memcmp(old->buf, cur->buf, r))
+			uic_mark_stale(uic);
+
+		if (fwrite(cur->buf, 1, cur->len, uic->cur_fp) == cur->len)
+			ret = 0;
+	}
+
+	va_end(ap);
+
+	return ret;
+}
 
 /*
  * Create the file "path" by writing to a temporary file and renaming
  * it into place. The contents of the file come from "generate", which
  * should return non-zero if it encounters an error.
  */
-static int update_info_file(char *path, int (*generate)(FILE *))
+static int update_info_file(char *path,
+			int (*generate)(struct update_info_ctx *),
+			int force)
 {
 	char *tmp = mkpathdup("%s_XXXXXX", path);
 	int ret = -1;
 	int fd = -1;
-	FILE *fp = NULL, *to_close;
+	FILE *to_close;
+	struct update_info_ctx uic = {
+		.cur_fp = NULL,
+		.old_fp = NULL,
+		.cur_sb = STRBUF_INIT,
+		.old_sb = STRBUF_INIT
+	};
 
 	safe_create_leading_directories(path);
 	fd = git_mkstemp_mode(tmp, 0666);
 	if (fd < 0)
 		goto out;
-	to_close = fp = fdopen(fd, "w");
-	if (!fp)
+	to_close = uic.cur_fp = fdopen(fd, "w");
+	if (!uic.cur_fp)
 		goto out;
 	fd = -1;
-	ret = generate(fp);
+
+	/* no problem on ENOENT and old_fp == NULL, it's stale, now */
+	if (!force)
+		uic.old_fp = fopen_or_warn(path, "r");
+
+	/*
+	 * uic_printf will compare incremental comparison against old_fp
+	 * and mark uic as stale if needed
+	 */
+	ret = generate(&uic);
 	if (ret)
 		goto out;
-	fp = NULL;
+
+	/* new file may be shorter than the old one, check here */
+	if (!uic_is_stale(&uic)) {
+		struct stat st;
+		long new_len = ftell(uic.cur_fp);
+		int old_fd = fileno(uic.old_fp);
+
+		if (new_len < 0) {
+			ret = -1;
+			goto out;
+		}
+		if (fstat(old_fd, &st) || (st.st_size != (size_t)new_len))
+			uic_mark_stale(&uic);
+	}
+
+	uic.cur_fp = NULL;
 	if (fclose(to_close))
 		goto out;
-	if (adjust_shared_perm(tmp) < 0)
-		goto out;
-	if (rename(tmp, path) < 0)
-		goto out;
+
+	if (uic_is_stale(&uic)) {
+		if (adjust_shared_perm(tmp) < 0)
+			goto out;
+		if (rename(tmp, path) < 0)
+			goto out;
+	} else {
+		unlink(tmp);
+	}
 	ret = 0;
 
 out:
 	if (ret) {
 		error_errno("unable to update %s", path);
-		if (fp)
-			fclose(fp);
+		if (uic.cur_fp)
+			fclose(uic.cur_fp);
 		else if (fd >= 0)
 			close(fd);
 		unlink(tmp);
 	}
 	free(tmp);
+	if (uic.old_fp)
+		fclose(uic.old_fp);
+	strbuf_release(&uic.old_sb);
+	strbuf_release(&uic.cur_sb);
 	return ret;
 }
 
 static int add_info_ref(const char *path, const struct object_id *oid,
 			int flag, void *cb_data)
 {
-	FILE *fp = cb_data;
-	struct object *o = parse_object(oid);
+	struct update_info_ctx *uic = cb_data;
+	struct object *o = parse_object(the_repository, oid);
 	if (!o)
 		return -1;
 
-	if (fprintf(fp, "%s	%s\n", oid_to_hex(oid), path) < 0)
+	if (uic_printf(uic, "%s	%s\n", oid_to_hex(oid), path) < 0)
 		return -1;
 
 	if (o->type == OBJ_TAG) {
-		o = deref_tag(o, path, 0);
+		o = deref_tag(the_repository, o, path, 0);
 		if (o)
-			if (fprintf(fp, "%s	%s^{}\n",
+			if (uic_printf(uic, "%s	%s^{}\n",
 				oid_to_hex(&o->oid), path) < 0)
 				return -1;
 	}
 	return 0;
 }
 
-static int generate_info_refs(FILE *fp)
+static int generate_info_refs(struct update_info_ctx *uic)
 {
-	return for_each_ref(add_info_ref, fp);
+	return for_each_ref(add_info_ref, uic);
 }
 
 static int update_info_refs(int force)
 {
 	char *path = git_pathdup("info/refs");
-	int ret = update_info_file(path, generate_info_refs);
+	int ret = update_info_file(path, generate_info_refs, force);
 	free(path);
 	return ret;
 }
@@ -91,19 +184,15 @@ static struct pack_info {
 	struct packed_git *p;
 	int old_num;
 	int new_num;
-	int nr_alloc;
 } **info;
 static int num_pack;
-static const char *objdir;
-static int objdirlen;
 
 static struct pack_info *find_pack_by_name(const char *name)
 {
 	int i;
 	for (i = 0; i < num_pack; i++) {
 		struct packed_git *p = info[i]->p;
-		/* skip "/pack/" after ".git/objects" */
-		if (!strcmp(p->pack_name + objdirlen + 6, name))
+		if (!strcmp(pack_basename(p), name))
 			return info[i];
 	}
 	return NULL;
@@ -112,9 +201,9 @@ static struct pack_info *find_pack_by_na
 /* Returns non-zero when we detect that the info in the
  * old file is useless.
  */
-static int parse_pack_def(const char *line, int old_cnt)
+static int parse_pack_def(const char *packname, int old_cnt)
 {
-	struct pack_info *i = find_pack_by_name(line + 2);
+	struct pack_info *i = find_pack_by_name(packname);
 	if (i) {
 		i->old_num = old_cnt;
 		return 0;
@@ -131,39 +220,40 @@ static int parse_pack_def(const char *li
 static int read_pack_info_file(const char *infofile)
 {
 	FILE *fp;
-	char line[1000];
+	struct strbuf line = STRBUF_INIT;
 	int old_cnt = 0;
+	int stale = 1;
 
 	fp = fopen_or_warn(infofile, "r");
 	if (!fp)
 		return 1; /* nonexistent is not an error. */
 
-	while (fgets(line, sizeof(line), fp)) {
-		int len = strlen(line);
-		if (len && line[len-1] == '\n')
-			line[--len] = 0;
+	while (strbuf_getline(&line, fp) != EOF) {
+		const char *arg;
 
-		if (!len)
+		if (!line.len)
 			continue;
 
-		switch (line[0]) {
-		case 'P': /* P name */
-			if (parse_pack_def(line, old_cnt++))
+		if (skip_prefix(line.buf, "P ", &arg)) {
+			/* P name */
+			if (parse_pack_def(arg, old_cnt++))
 				goto out_stale;
-			break;
-		case 'D': /* we used to emit D but that was misguided. */
-		case 'T': /* we used to emit T but nobody uses it. */
+		} else if (line.buf[0] == 'D') {
+			/* we used to emit D but that was misguided. */
 			goto out_stale;
-		default:
-			error("unrecognized: %s", line);
-			break;
+		} else if (line.buf[0] == 'T') {
+			/* we used to emit T but nobody uses it. */
+			goto out_stale;
+		} else {
+			error("unrecognized: %s", line.buf);
 		}
 	}
-	fclose(fp);
-	return 0;
+	stale = 0;
+
  out_stale:
+	strbuf_release(&line);
 	fclose(fp);
-	return 1;
+	return stale;
 }
 
 static int compare_info(const void *a_, const void *b_)
@@ -194,28 +284,21 @@ static void init_pack_info(const char *i
 {
 	struct packed_git *p;
 	int stale;
-	int i = 0;
-
-	objdir = get_object_directory();
-	objdirlen = strlen(objdir);
+	int i;
+	size_t alloc = 0;
 
-	for (p = get_packed_git(the_repository); p; p = p->next) {
+	for (p = get_all_packs(the_repository); p; p = p->next) {
 		/* we ignore things on alternate path since they are
 		 * not available to the pullers in general.
 		 */
-		if (!p->pack_local)
-			continue;
-		i++;
-	}
-	num_pack = i;
-	info = xcalloc(num_pack, sizeof(struct pack_info *));
-	for (i = 0, p = get_packed_git(the_repository); p; p = p->next) {
-		if (!p->pack_local)
+		if (!p->pack_local || !file_exists(p->pack_name))
 			continue;
+
+		i = num_pack++;
+		ALLOC_GROW(info, num_pack, alloc);
 		info[i] = xcalloc(1, sizeof(struct pack_info));
 		info[i]->p = p;
 		info[i]->old_num = -1;
-		i++;
 	}
 
 	if (infofile && !force)
@@ -241,14 +324,14 @@ static void free_pack_info(void)
 	free(info);
 }
 
-static int write_pack_info_file(FILE *fp)
+static int write_pack_info_file(struct update_info_ctx *uic)
 {
 	int i;
 	for (i = 0; i < num_pack; i++) {
-		if (fprintf(fp, "P %s\n", info[i]->p->pack_name + objdirlen + 6) < 0)
+		if (uic_printf(uic, "P %s\n", pack_basename(info[i]->p)) < 0)
 			return -1;
 	}
-	if (fputc('\n', fp) == EOF)
+	if (uic_printf(uic, "\n") < 0)
 		return -1;
 	return 0;
 }
@@ -259,7 +342,7 @@ static int update_info_packs(int force)
 	int ret;
 
 	init_pack_info(infofile, force);
-	ret = update_info_file(infofile, write_pack_info_file);
+	ret = update_info_file(infofile, write_pack_info_file, force);
 	free_pack_info();
 	free(infofile);
 	return ret;
diff -pruN 1.2.1+git2.18.0-1/git/setup.c 1.2.3+git2.25.1-1/git/setup.c
--- 1.2.1+git2.18.0-1/git/setup.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/setup.c	2020-02-17 04:47:35.000000000 +0000
@@ -4,6 +4,7 @@
 #include "dir.h"
 #include "string-list.h"
 #include "chdir-notify.h"
+#include "promisor-remote.h"
 
 static int inside_git_dir = -1;
 static int inside_work_tree = -1;
@@ -39,7 +40,7 @@ static int abspath_part_inside_repo(char
 	off = offset_1st_component(path);
 
 	/* check if work tree is already the prefix */
-	if (wtlen <= len && !strncmp(path, work_tree, wtlen)) {
+	if (wtlen <= len && !fspathncmp(path, work_tree, wtlen)) {
 		if (path[wtlen] == '/') {
 			memmove(path, path + wtlen + 1, len - wtlen);
 			return 0;
@@ -59,7 +60,7 @@ static int abspath_part_inside_repo(char
 		path++;
 		if (*path == '/') {
 			*path = '\0';
-			if (strcmp(real_path(path0), work_tree) == 0) {
+			if (fspathcmp(real_path(path0), work_tree) == 0) {
 				memmove(path0, path + 1, len - (path - path0));
 				return 0;
 			}
@@ -68,7 +69,7 @@ static int abspath_part_inside_repo(char
 	}
 
 	/* check whole path */
-	if (strcmp(real_path(path0), work_tree) == 0) {
+	if (fspathcmp(real_path(path0), work_tree) == 0) {
 		*path0 = '\0';
 		return 0;
 	}
@@ -164,7 +165,8 @@ int check_filename(const char *prefix, c
 	die_errno(_("failed to stat '%s'"), arg);
 }
 
-static void NORETURN die_verify_filename(const char *prefix,
+static void NORETURN die_verify_filename(struct repository *r,
+					 const char *prefix,
 					 const char *arg,
 					 int diagnose_misspelt_rev)
 {
@@ -179,7 +181,7 @@ static void NORETURN die_verify_filename
 	 * let maybe_die_on_misspelt_object_name() even trigger.
 	 */
 	if (!(arg[0] == ':' && !isalnum(arg[1])))
-		maybe_die_on_misspelt_object_name(arg, prefix);
+		maybe_die_on_misspelt_object_name(r, arg, prefix);
 
 	/* ... or fall back the most general message. */
 	die(_("ambiguous argument '%s': unknown revision or path not in the working tree.\n"
@@ -234,7 +236,7 @@ void verify_filename(const char *prefix,
 		die(_("option '%s' must come before non-option arguments"), arg);
 	if (looks_like_pathspec(arg) || check_filename(prefix, arg))
 		return;
-	die_verify_filename(prefix, arg, diagnose_misspelt_rev);
+	die_verify_filename(the_repository, prefix, arg, diagnose_misspelt_rev);
 }
 
 /*
@@ -402,6 +404,21 @@ void setup_work_tree(void)
 	initialized = 1;
 }
 
+static int read_worktree_config(const char *var, const char *value, void *vdata)
+{
+	struct repository_format *data = vdata;
+
+	if (strcmp(var, "core.bare") == 0) {
+		data->is_bare = git_config_bool(var, value);
+	} else if (strcmp(var, "core.worktree") == 0) {
+		if (!value)
+			return config_error_nonbool(var);
+		free(data->work_tree);
+		data->work_tree = xstrdup(value);
+	}
+	return 0;
+}
+
 static int check_repo_format(const char *var, const char *value, void *vdata)
 {
 	struct repository_format *data = vdata;
@@ -423,16 +440,13 @@ static int check_repo_format(const char
 			if (!value)
 				return config_error_nonbool(var);
 			data->partial_clone = xstrdup(value);
-		} else
+		} else if (!strcmp(ext, "worktreeconfig"))
+			data->worktree_config = git_config_bool(var, value);
+		else
 			string_list_append(&data->unknown_extensions, ext);
-	} else if (strcmp(var, "core.bare") == 0) {
-		data->is_bare = git_config_bool(var, value);
-	} else if (strcmp(var, "core.worktree") == 0) {
-		if (!value)
-			return config_error_nonbool(var);
-		data->work_tree = xstrdup(value);
 	}
-	return 0;
+
+	return read_worktree_config(var, value, vdata);
 }
 
 static int check_repository_format_gently(const char *gitdir, struct repository_format *candidate, int *nongit_ok)
@@ -465,8 +479,21 @@ static int check_repository_format_gentl
 	}
 
 	repository_format_precious_objects = candidate->precious_objects;
-	repository_format_partial_clone = candidate->partial_clone;
+	set_repository_format_partial_clone(candidate->partial_clone);
+	repository_format_worktree_config = candidate->worktree_config;
 	string_list_clear(&candidate->unknown_extensions, 0);
+
+	if (repository_format_worktree_config) {
+		/*
+		 * pick up core.bare and core.worktree from per-worktree
+		 * config if present
+		 */
+		strbuf_addf(&sb, "%s/config.worktree", gitdir);
+		git_config_from_file(read_worktree_config, sb.buf, candidate);
+		strbuf_release(&sb);
+		has_common = 0;
+	}
+
 	if (!has_common) {
 		if (candidate->is_bare != -1) {
 			is_bare_repository_cfg = candidate->is_bare;
@@ -475,27 +502,38 @@ static int check_repository_format_gentl
 		}
 		if (candidate->work_tree) {
 			free(git_work_tree_cfg);
-			git_work_tree_cfg = candidate->work_tree;
+			git_work_tree_cfg = xstrdup(candidate->work_tree);
 			inside_work_tree = -1;
 		}
-	} else {
-		free(candidate->work_tree);
 	}
 
 	return 0;
 }
 
+static void init_repository_format(struct repository_format *format)
+{
+	const struct repository_format fresh = REPOSITORY_FORMAT_INIT;
+
+	memcpy(format, &fresh, sizeof(fresh));
+}
+
 int read_repository_format(struct repository_format *format, const char *path)
 {
-	memset(format, 0, sizeof(*format));
-	format->version = -1;
-	format->is_bare = -1;
-	format->hash_algo = GIT_HASH_SHA1;
-	string_list_init(&format->unknown_extensions, 1);
+	clear_repository_format(format);
 	git_config_from_file(check_repo_format, path, format);
+	if (format->version == -1)
+		clear_repository_format(format);
 	return format->version;
 }
 
+void clear_repository_format(struct repository_format *format)
+{
+	string_list_clear(&format->unknown_extensions, 0);
+	free(format->work_tree);
+	free(format->partial_clone);
+	init_repository_format(format);
+}
+
 int verify_repository_format(const struct repository_format *format,
 			     struct strbuf *err)
 {
@@ -760,7 +798,7 @@ static const char *setup_discovered_git_
 		set_git_dir(gitdir);
 	inside_git_dir = 0;
 	inside_work_tree = 1;
-	if (offset == cwd->len)
+	if (offset >= cwd->len)
 		return NULL;
 
 	/* Make "offset" point past the '/' (already the case for root dirs) */
@@ -807,16 +845,6 @@ static const char *setup_bare_git_dir(st
 	return NULL;
 }
 
-static const char *setup_nongit(const char *cwd, int *nongit_ok)
-{
-	if (!nongit_ok)
-		die(_("not a git repository (or any of the parent directories): %s"), DEFAULT_GIT_DIR_ENVIRONMENT);
-	if (chdir(cwd))
-		die_errno(_("cannot come back to cwd"));
-	*nongit_ok = 1;
-	return NULL;
-}
-
 static dev_t get_device_or_die(const char *path, const char *prefix, int prefix_len)
 {
 	struct stat buf;
@@ -892,7 +920,7 @@ static enum discovery_result setup_git_d
 	const char *env_ceiling_dirs = getenv(CEILING_DIRECTORIES_ENVIRONMENT);
 	struct string_list ceiling_dirs = STRING_LIST_INIT_DUP;
 	const char *gitdirenv;
-	int ceil_offset = -1, min_offset = has_dos_drive_prefix(dir->buf) ? 3 : 1;
+	int ceil_offset = -1, min_offset = offset_1st_component(dir->buf);
 	dev_t current_device = 0;
 	int one_filesystem = 1;
 
@@ -920,6 +948,12 @@ static enum discovery_result setup_git_d
 	if (ceil_offset < 0)
 		ceil_offset = min_offset - 2;
 
+	if (min_offset && min_offset == dir->len &&
+	    !is_dir_sep(dir->buf[min_offset - 1])) {
+		strbuf_addch(dir, '/');
+		min_offset++;
+	}
+
 	/*
 	 * Test in the following order (relative to the dir):
 	 * - .git (file containing "gitdir: <path>")
@@ -983,7 +1017,7 @@ int discover_git_directory(struct strbuf
 	struct strbuf dir = STRBUF_INIT, err = STRBUF_INIT;
 	size_t gitdir_offset = gitdir->len, cwd_len;
 	size_t commondir_offset = commondir->len;
-	struct repository_format candidate;
+	struct repository_format candidate = REPOSITORY_FORMAT_INIT;
 
 	if (strbuf_getcwd(&dir))
 		return -1;
@@ -1020,9 +1054,11 @@ int discover_git_directory(struct strbuf
 		strbuf_release(&err);
 		strbuf_setlen(commondir, commondir_offset);
 		strbuf_setlen(gitdir, gitdir_offset);
+		clear_repository_format(&candidate);
 		return -1;
 	}
 
+	clear_repository_format(&candidate);
 	return 0;
 }
 
@@ -1030,8 +1066,8 @@ const char *setup_git_directory_gently(i
 {
 	static struct strbuf cwd = STRBUF_INIT;
 	struct strbuf dir = STRBUF_INIT, gitdir = STRBUF_INIT;
-	const char *prefix;
-	struct repository_format repo_fmt;
+	const char *prefix = NULL;
+	struct repository_format repo_fmt = REPOSITORY_FORMAT_INIT;
 
 	/*
 	 * We may have read an incomplete configuration before
@@ -1055,9 +1091,6 @@ const char *setup_git_directory_gently(i
 	strbuf_addbuf(&dir, &cwd);
 
 	switch (setup_git_directory_gently_1(&dir, &gitdir, 1)) {
-	case GIT_DIR_NONE:
-		prefix = NULL;
-		break;
 	case GIT_DIR_EXPLICIT:
 		prefix = setup_explicit_git_dir(gitdir.buf, &cwd, &repo_fmt, nongit_ok);
 		break;
@@ -1073,29 +1106,51 @@ const char *setup_git_directory_gently(i
 		prefix = setup_bare_git_dir(&cwd, dir.len, &repo_fmt, nongit_ok);
 		break;
 	case GIT_DIR_HIT_CEILING:
-		prefix = setup_nongit(cwd.buf, nongit_ok);
+		if (!nongit_ok)
+			die(_("not a git repository (or any of the parent directories): %s"),
+			    DEFAULT_GIT_DIR_ENVIRONMENT);
+		*nongit_ok = 1;
 		break;
 	case GIT_DIR_HIT_MOUNT_POINT:
-		if (nongit_ok) {
-			*nongit_ok = 1;
-			strbuf_release(&cwd);
-			strbuf_release(&dir);
-			return NULL;
-		}
-		die(_("not a git repository (or any parent up to mount point %s)\n"
-		      "Stopping at filesystem boundary (GIT_DISCOVERY_ACROSS_FILESYSTEM not set)."),
-		    dir.buf);
+		if (!nongit_ok)
+			die(_("not a git repository (or any parent up to mount point %s)\n"
+			      "Stopping at filesystem boundary (GIT_DISCOVERY_ACROSS_FILESYSTEM not set)."),
+			    dir.buf);
+		*nongit_ok = 1;
+		break;
+	case GIT_DIR_NONE:
+		/*
+		 * As a safeguard against setup_git_directory_gently_1 returning
+		 * this value, fallthrough to BUG. Otherwise it is possible to
+		 * set startup_info->have_repository to 1 when we did nothing to
+		 * find a repository.
+		 */
 	default:
 		BUG("unhandled setup_git_directory_1() result");
 	}
 
-	if (prefix)
-		setenv(GIT_PREFIX_ENVIRONMENT, prefix, 1);
-	else
+	/*
+	 * At this point, nongit_ok is stable. If it is non-NULL and points
+	 * to a non-zero value, then this means that we haven't found a
+	 * repository and that the caller expects startup_info to reflect
+	 * this.
+	 *
+	 * Regardless of the state of nongit_ok, startup_info->prefix and
+	 * the GIT_PREFIX environment variable must always match. For details
+	 * see Documentation/config/alias.txt.
+	 */
+	if (nongit_ok && *nongit_ok) {
+		startup_info->have_repository = 0;
+		startup_info->prefix = NULL;
 		setenv(GIT_PREFIX_ENVIRONMENT, "", 1);
-
-	startup_info->have_repository = !nongit_ok || !*nongit_ok;
-	startup_info->prefix = prefix;
+	} else {
+		startup_info->have_repository = 1;
+		startup_info->prefix = prefix;
+		if (prefix)
+			setenv(GIT_PREFIX_ENVIRONMENT, prefix, 1);
+		else
+			setenv(GIT_PREFIX_ENVIRONMENT, "", 1);
+	}
 
 	/*
 	 * Not all paths through the setup code will call 'set_git_dir()' (which
@@ -1108,7 +1163,10 @@ const char *setup_git_directory_gently(i
 	 * the user has set GIT_DIR.  It may be beneficial to disallow bogus
 	 * GIT_DIR values at some point in the future.
 	 */
-	if (startup_info->have_repository || getenv(GIT_DIR_ENVIRONMENT)) {
+	if (/* GIT_DIR_EXPLICIT, GIT_DIR_DISCOVERED, GIT_DIR_BARE */
+	    startup_info->have_repository ||
+	    /* GIT_DIR_EXPLICIT */
+	    getenv(GIT_DIR_ENVIRONMENT)) {
 		if (!the_repository->gitdir) {
 			const char *gitdir = getenv(GIT_DIR_ENVIRONMENT);
 			if (!gitdir)
@@ -1121,6 +1179,7 @@ const char *setup_git_directory_gently(i
 
 	strbuf_release(&dir);
 	strbuf_release(&gitdir);
+	clear_repository_format(&repo_fmt);
 
 	return prefix;
 }
@@ -1178,9 +1237,10 @@ int git_config_perm(const char *var, con
 
 void check_repository_format(void)
 {
-	struct repository_format repo_fmt;
+	struct repository_format repo_fmt = REPOSITORY_FORMAT_INIT;
 	check_repository_format_gently(get_git_dir(), &repo_fmt, NULL);
 	startup_info->have_repository = 1;
+	clear_repository_format(&repo_fmt);
 }
 
 /*
diff -pruN 1.2.1+git2.18.0-1/git/sha1-array.c 1.2.3+git2.25.1-1/git/sha1-array.c
--- 1.2.1+git2.18.0-1/git/sha1-array.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/sha1-array.c	2020-02-17 04:47:35.000000000 +0000
@@ -48,7 +48,7 @@ int oid_array_for_each(struct oid_array
 {
 	int i;
 
-	/* No oid_array_sort() here! See the api-oid-array.txt docs! */
+	/* No oid_array_sort() here! See sha1-array.h */
 
 	for (i = 0; i < array->nr; i++) {
 		int ret = fn(array->oid + i, data);
@@ -69,7 +69,7 @@ int oid_array_for_each_unique(struct oid
 
 	for (i = 0; i < array->nr; i++) {
 		int ret;
-		if (i > 0 && !oidcmp(array->oid + i, array->oid + i - 1))
+		if (i > 0 && oideq(array->oid + i, array->oid + i - 1))
 			continue;
 		ret = fn(array->oid + i, data);
 		if (ret)
@@ -77,3 +77,20 @@ int oid_array_for_each_unique(struct oid
 	}
 	return 0;
 }
+
+void oid_array_filter(struct oid_array *array,
+		      for_each_oid_fn want,
+		      void *cb_data)
+{
+	unsigned nr = array->nr, src, dst;
+	struct object_id *oids = array->oid;
+
+	for (src = dst = 0; src < nr; src++) {
+		if (want(&oids[src], cb_data)) {
+			if (src != dst)
+				oidcpy(&oids[dst], &oids[src]);
+			dst++;
+		}
+	}
+	array->nr = dst;
+}
diff -pruN 1.2.1+git2.18.0-1/git/sha1-array.h 1.2.3+git2.25.1-1/git/sha1-array.h
--- 1.2.1+git2.18.0-1/git/sha1-array.h	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/sha1-array.h	2020-02-17 04:47:35.000000000 +0000
@@ -1,6 +1,52 @@
 #ifndef SHA1_ARRAY_H
 #define SHA1_ARRAY_H
 
+/**
+ * The API provides storage and manipulation of sets of object identifiers.
+ * The emphasis is on storage and processing efficiency, making them suitable
+ * for large lists. Note that the ordering of items is not preserved over some
+ * operations.
+ *
+ * Examples
+ * --------
+ * -----------------------------------------
+ * int print_callback(const struct object_id *oid,
+ * 		    void *data)
+ * {
+ * 	printf("%s\n", oid_to_hex(oid));
+ * 	return 0; // always continue
+ * }
+ *
+ * void some_func(void)
+ * {
+ *     struct sha1_array hashes = OID_ARRAY_INIT;
+ *     struct object_id oid;
+ *
+ *     // Read objects into our set
+ *     while (read_object_from_stdin(oid.hash))
+ *         oid_array_append(&hashes, &oid);
+ *
+ *     // Check if some objects are in our set
+ *     while (read_object_from_stdin(oid.hash)) {
+ *         if (oid_array_lookup(&hashes, &oid) >= 0)
+ *             printf("it's in there!\n");
+ *
+ *          // Print the unique set of objects. We could also have
+ *          // avoided adding duplicate objects in the first place,
+ *          // but we would end up re-sorting the array repeatedly.
+ *          // Instead, this will sort once and then skip duplicates
+ *          // in linear time.
+ *
+ *         oid_array_for_each_unique(&hashes, print_callback, NULL);
+ *     }
+ */
+
+/**
+ * A single array of object IDs. This should be initialized by assignment from
+ * `OID_ARRAY_INIT`. The `oid` member contains the actual data. The `nr` member
+ * contains the number of items in the set. The `alloc` and `sorted` members
+ * are used internally, and should not be needed by API callers.
+ */
 struct oid_array {
 	struct object_id *oid;
 	int nr;
@@ -10,17 +56,54 @@ struct oid_array {
 
 #define OID_ARRAY_INIT { NULL, 0, 0, 0 }
 
+/**
+ * Add an item to the set. The object ID will be placed at the end of the array
+ * (but note that some operations below may lose this ordering).
+ */
 void oid_array_append(struct oid_array *array, const struct object_id *oid);
+
+/**
+ * Perform a binary search of the array for a specific object ID. If found,
+ * returns the offset (in number of elements) of the object ID. If not found,
+ * returns a negative integer. If the array is not sorted, this function has
+ * the side effect of sorting it.
+ */
 int oid_array_lookup(struct oid_array *array, const struct object_id *oid);
+
+/**
+ * Free all memory associated with the array and return it to the initial,
+ * empty state.
+ */
 void oid_array_clear(struct oid_array *array);
 
 typedef int (*for_each_oid_fn)(const struct object_id *oid,
 			       void *data);
+/**
+ * Iterate over each element of the list, executing the callback function for
+ * each one. Does not sort the list, so any custom hash order is retained.
+ * If the callback returns a non-zero value, the iteration ends immediately
+ * and the callback's return is propagated; otherwise, 0 is returned.
+ */
 int oid_array_for_each(struct oid_array *array,
 		       for_each_oid_fn fn,
 		       void *data);
+
+/**
+ * Iterate over each unique element of the list in sorted order, but otherwise
+ * behave like `oid_array_for_each`. If the array is not sorted, this function
+ * has the side effect of sorting it.
+ */
 int oid_array_for_each_unique(struct oid_array *array,
 			      for_each_oid_fn fn,
 			      void *data);
 
+/**
+ * Apply the callback function `want` to each entry in the array, retaining
+ * only the entries for which the function returns true. Preserve the order
+ * of the entries that are retained.
+ */
+void oid_array_filter(struct oid_array *array,
+		      for_each_oid_fn want,
+		      void *cbdata);
+
 #endif /* SHA1_ARRAY_H */
diff -pruN 1.2.1+git2.18.0-1/git/sha1dc/sha1.c 1.2.3+git2.25.1-1/git/sha1dc/sha1.c
--- 1.2.1+git2.18.0-1/git/sha1dc/sha1.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/sha1dc/sha1.c	2020-02-17 04:47:35.000000000 +0000
@@ -72,7 +72,7 @@
 /* Not under GCC-alike or glibc */
 #elif defined(_BYTE_ORDER) && defined(_BIG_ENDIAN) && defined(_LITTLE_ENDIAN)
 /*
- * *BSD and newlib (embeded linux, cygwin, etc).
+ * *BSD and newlib (embedded linux, cygwin, etc).
  * the defined(_BIG_ENDIAN) && defined(_LITTLE_ENDIAN) part prevents
  * this condition from matching with Solaris/sparc.
  * (Solaris defines only one endian macro)
@@ -93,13 +93,23 @@
 #define SHA1DC_BIGENDIAN
 
 /* Not under GCC-alike or glibc or *BSD or newlib or <processor whitelist> */
+#elif (defined(_AIX) || defined(__hpux))
+
+/*
+ * Defines Big Endian on a whitelist of OSs that are known to be Big
+ * Endian-only. See
+ * https://lore.kernel.org/git/93056823-2740-d072-1ebd-46b440b33d7e@felt.demon.nl/
+ */
+#define SHA1DC_BIGENDIAN
+
+/* Not under GCC-alike or glibc or *BSD or newlib or <processor whitelist> or <os whitelist> */
 #elif defined(SHA1DC_ON_INTEL_LIKE_PROCESSOR)
 /*
  * As a last resort before we do anything else we're not 100% sure
  * about below, we blacklist specific processors here. We could add
  * more, see e.g. https://wiki.debian.org/ArchitectureSpecificsMemo
  */
-#else /* Not under GCC-alike or glibc or *BSD or newlib or <processor whitelist>  or <processor blacklist> */
+#else /* Not under GCC-alike or glibc or *BSD or newlib or <processor whitelist> or <os whitelist> or <processor blacklist> */
 
 /* We do nothing more here for now */
 /*#error "Uncomment this to see if you fall through all the detection"*/
@@ -114,10 +124,11 @@
 #endif
 /*ENDIANNESS SELECTION*/
 
+#ifndef SHA1DC_FORCE_ALIGNED_ACCESS
 #if defined(SHA1DC_FORCE_UNALIGNED_ACCESS) || defined(SHA1DC_ON_INTEL_LIKE_PROCESSOR)
 #define SHA1DC_ALLOW_UNALIGNED_ACCESS
-#endif /*UNALIGNMENT DETECTION*/
-
+#endif /*UNALIGNED ACCESS DETECTION*/
+#endif /*FORCE ALIGNED ACCESS*/
 
 #define rotate_right(x,n) (((x)>>(n))|((x)<<(32-(n))))
 #define rotate_left(x,n)  (((x)<<(n))|((x)>>(32-(n))))
diff -pruN 1.2.1+git2.18.0-1/git/sha1dc_git.c 1.2.3+git2.25.1-1/git/sha1dc_git.c
--- 1.2.1+git2.18.0-1/git/sha1dc_git.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/sha1dc_git.c	2020-02-17 04:47:35.000000000 +0000
@@ -19,7 +19,7 @@ void git_SHA1DCFinal(unsigned char hash[
 	if (!SHA1DCFinal(hash, ctx))
 		return;
 	die("SHA-1 appears to be part of a collision attack: %s",
-	    sha1_to_hex(hash));
+	    hash_to_hex_algop(hash, &hash_algos[GIT_HASH_SHA1]));
 }
 
 /*
diff -pruN 1.2.1+git2.18.0-1/git/sha1-file.c 1.2.3+git2.25.1-1/git/sha1-file.c
--- 1.2.1+git2.18.0-1/git/sha1-file.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/sha1-file.c	2020-02-17 04:47:35.000000000 +0000
@@ -30,8 +30,8 @@
 #include "mergesort.h"
 #include "quote.h"
 #include "packfile.h"
-#include "fetch-object.h"
 #include "object-store.h"
+#include "promisor-remote.h"
 
 /* The maximum size for an object header. */
 #define MAX_HEADER_LEN 32
@@ -40,12 +40,21 @@
 #define EMPTY_TREE_SHA1_BIN_LITERAL \
 	 "\x4b\x82\x5d\xc6\x42\xcb\x6e\xb9\xa0\x60" \
 	 "\xe5\x4b\xf8\xd6\x92\x88\xfb\xee\x49\x04"
+#define EMPTY_TREE_SHA256_BIN_LITERAL \
+	"\x6e\xf1\x9b\x41\x22\x5c\x53\x69\xf1\xc1" \
+	"\x04\xd4\x5d\x8d\x85\xef\xa9\xb0\x57\xb5" \
+	"\x3b\x14\xb4\xb9\xb9\x39\xdd\x74\xde\xcc" \
+	"\x53\x21"
 
 #define EMPTY_BLOB_SHA1_BIN_LITERAL \
 	"\xe6\x9d\xe2\x9b\xb2\xd1\xd6\x43\x4b\x8b" \
 	"\x29\xae\x77\x5a\xd8\xc2\xe4\x8c\x53\x91"
+#define EMPTY_BLOB_SHA256_BIN_LITERAL \
+	"\x47\x3a\x0f\x4c\x3b\xe8\xa9\x36\x81\xa2" \
+	"\x67\xe3\xb1\xe9\xa7\xdc\xda\x11\x85\x43" \
+	"\x6f\xe1\x41\xf7\x74\x91\x20\xa3\x03\x72" \
+	"\x18\x13"
 
-const unsigned char null_sha1[GIT_MAX_RAWSZ];
 const struct object_id null_oid;
 static const struct object_id empty_tree_oid = {
 	EMPTY_TREE_SHA1_BIN_LITERAL
@@ -53,6 +62,12 @@ static const struct object_id empty_tree
 static const struct object_id empty_blob_oid = {
 	EMPTY_BLOB_SHA1_BIN_LITERAL
 };
+static const struct object_id empty_tree_oid_sha256 = {
+	EMPTY_TREE_SHA256_BIN_LITERAL
+};
+static const struct object_id empty_blob_oid_sha256 = {
+	EMPTY_BLOB_SHA256_BIN_LITERAL
+};
 
 static void git_hash_sha1_init(git_hash_ctx *ctx)
 {
@@ -69,19 +84,35 @@ static void git_hash_sha1_final(unsigned
 	git_SHA1_Final(hash, &ctx->sha1);
 }
 
+
+static void git_hash_sha256_init(git_hash_ctx *ctx)
+{
+	git_SHA256_Init(&ctx->sha256);
+}
+
+static void git_hash_sha256_update(git_hash_ctx *ctx, const void *data, size_t len)
+{
+	git_SHA256_Update(&ctx->sha256, data, len);
+}
+
+static void git_hash_sha256_final(unsigned char *hash, git_hash_ctx *ctx)
+{
+	git_SHA256_Final(hash, &ctx->sha256);
+}
+
 static void git_hash_unknown_init(git_hash_ctx *ctx)
 {
-	die("trying to init unknown hash");
+	BUG("trying to init unknown hash");
 }
 
 static void git_hash_unknown_update(git_hash_ctx *ctx, const void *data, size_t len)
 {
-	die("trying to update unknown hash");
+	BUG("trying to update unknown hash");
 }
 
 static void git_hash_unknown_final(unsigned char *hash, git_hash_ctx *ctx)
 {
-	die("trying to finalize unknown hash");
+	BUG("trying to finalize unknown hash");
 }
 
 const struct git_hash_algo hash_algos[GIT_HASH_NALGOS] = {
@@ -90,6 +121,7 @@ const struct git_hash_algo hash_algos[GI
 		0x00000000,
 		0,
 		0,
+		0,
 		git_hash_unknown_init,
 		git_hash_unknown_update,
 		git_hash_unknown_final,
@@ -97,17 +129,31 @@ const struct git_hash_algo hash_algos[GI
 		NULL,
 	},
 	{
-		"sha-1",
+		"sha1",
 		/* "sha1", big-endian */
 		0x73686131,
 		GIT_SHA1_RAWSZ,
 		GIT_SHA1_HEXSZ,
+		GIT_SHA1_BLKSZ,
 		git_hash_sha1_init,
 		git_hash_sha1_update,
 		git_hash_sha1_final,
 		&empty_tree_oid,
 		&empty_blob_oid,
 	},
+	{
+		"sha256",
+		/* "s256", big-endian */
+		0x73323536,
+		GIT_SHA256_RAWSZ,
+		GIT_SHA256_HEXSZ,
+		GIT_SHA256_BLKSZ,
+		git_hash_sha256_init,
+		git_hash_sha256_update,
+		git_hash_sha256_final,
+		&empty_tree_oid_sha256,
+		&empty_blob_oid_sha256,
+	}
 };
 
 const char *empty_tree_oid_hex(void)
@@ -122,9 +168,38 @@ const char *empty_blob_oid_hex(void)
 	return oid_to_hex_r(buf, the_hash_algo->empty_blob);
 }
 
+int hash_algo_by_name(const char *name)
+{
+	int i;
+	if (!name)
+		return GIT_HASH_UNKNOWN;
+	for (i = 1; i < GIT_HASH_NALGOS; i++)
+		if (!strcmp(name, hash_algos[i].name))
+			return i;
+	return GIT_HASH_UNKNOWN;
+}
+
+int hash_algo_by_id(uint32_t format_id)
+{
+	int i;
+	for (i = 1; i < GIT_HASH_NALGOS; i++)
+		if (format_id == hash_algos[i].format_id)
+			return i;
+	return GIT_HASH_UNKNOWN;
+}
+
+int hash_algo_by_length(int len)
+{
+	int i;
+	for (i = 1; i < GIT_HASH_NALGOS; i++)
+		if (len == hash_algos[i].rawsz)
+			return i;
+	return GIT_HASH_UNKNOWN;
+}
+
 /*
  * This is meant to hold a *small* number of objects that you would
- * want read_sha1_file() to be able to return, but yet you do not want
+ * want read_object_file() to be able to return, but yet you do not want
  * to write them into the object store (e.g. a browse-only
  * application).
  */
@@ -149,10 +224,10 @@ static struct cached_object *find_cached
 	struct cached_object *co = cached_objects;
 
 	for (i = 0; i < cached_object_nr; i++, co++) {
-		if (!oidcmp(&co->oid, oid))
+		if (oideq(&co->oid, oid))
 			return co;
 	}
-	if (!oidcmp(oid, the_hash_algo->empty_tree))
+	if (oideq(oid, the_hash_algo->empty_tree))
 		return &empty_tree;
 	return NULL;
 }
@@ -333,12 +408,12 @@ out:
 	return ret;
 }
 
-static void fill_sha1_path(struct strbuf *buf, const unsigned char *sha1)
+static void fill_loose_path(struct strbuf *buf, const struct object_id *oid)
 {
 	int i;
-	for (i = 0; i < 20; i++) {
+	for (i = 0; i < the_hash_algo->rawsz; i++) {
 		static char hex[] = "0123456789abcdef";
-		unsigned int val = sha1[i];
+		unsigned int val = oid->hash[i];
 		strbuf_addch(buf, hex[val >> 4]);
 		strbuf_addch(buf, hex[val & 0xf]);
 		if (!i)
@@ -346,25 +421,21 @@ static void fill_sha1_path(struct strbuf
 	}
 }
 
-void sha1_file_name(struct repository *r, struct strbuf *buf, const unsigned char *sha1)
+static const char *odb_loose_path(struct object_directory *odb,
+				  struct strbuf *buf,
+				  const struct object_id *oid)
 {
-	strbuf_addstr(buf, r->objects->objectdir);
+	strbuf_reset(buf);
+	strbuf_addstr(buf, odb->path);
 	strbuf_addch(buf, '/');
-	fill_sha1_path(buf, sha1);
-}
-
-struct strbuf *alt_scratch_buf(struct alternate_object_database *alt)
-{
-	strbuf_setlen(&alt->scratch, alt->base_len);
-	return &alt->scratch;
+	fill_loose_path(buf, oid);
+	return buf->buf;
 }
 
-static const char *alt_sha1_path(struct alternate_object_database *alt,
-				 const unsigned char *sha1)
+const char *loose_object_path(struct repository *r, struct strbuf *buf,
+			      const struct object_id *oid)
 {
-	struct strbuf *buf = alt_scratch_buf(alt);
-	fill_sha1_path(buf, sha1);
-	return buf->buf;
+	return odb_loose_path(r->objects->odb, buf, oid);
 }
 
 /*
@@ -374,12 +445,12 @@ static int alt_odb_usable(struct raw_obj
 			  struct strbuf *path,
 			  const char *normalized_objdir)
 {
-	struct alternate_object_database *alt;
+	struct object_directory *odb;
 
 	/* Detect cases where alternate disappeared */
 	if (!is_directory(path->buf)) {
-		error("object directory %s does not exist; "
-		      "check .git/objects/info/alternates.",
+		error(_("object directory %s does not exist; "
+			"check .git/objects/info/alternates"),
 		      path->buf);
 		return 0;
 	}
@@ -388,8 +459,8 @@ static int alt_odb_usable(struct raw_obj
 	 * Prevent the common mistake of listing the same
 	 * thing twice, or object directory itself.
 	 */
-	for (alt = o->alt_odb_list; alt; alt = alt->next) {
-		if (!fspathcmp(path->buf, alt->path))
+	for (odb = o->odb; odb; odb = odb->next) {
+		if (!fspathcmp(path->buf, odb->path))
 			return 0;
 	}
 	if (!fspathcmp(path->buf, normalized_objdir))
@@ -402,7 +473,7 @@ static int alt_odb_usable(struct raw_obj
  * Prepare alternate object database registry.
  *
  * The variable alt_odb_list points at the list of struct
- * alternate_object_database.  The elements on this list come from
+ * object_directory.  The elements on this list come from
  * non-empty elements from colon separated ALTERNATE_DB_ENVIRONMENT
  * environment variable, and $GIT_OBJECT_DIRECTORY/info/alternates,
  * whose contents is similar to that environment variable but can be
@@ -419,7 +490,7 @@ static void read_info_alternates(struct
 static int link_alt_odb_entry(struct repository *r, const char *entry,
 	const char *relative_base, int depth, const char *normalized_objdir)
 {
-	struct alternate_object_database *ent;
+	struct object_directory *ent;
 	struct strbuf pathbuf = STRBUF_INIT;
 
 	if (!is_absolute_path(entry) && relative_base) {
@@ -429,7 +500,7 @@ static int link_alt_odb_entry(struct rep
 	strbuf_addstr(&pathbuf, entry);
 
 	if (strbuf_normalize_path(&pathbuf) < 0 && relative_base) {
-		error("unable to normalize alternate object path: %s",
+		error(_("unable to normalize alternate object path: %s"),
 		      pathbuf.buf);
 		strbuf_release(&pathbuf);
 		return -1;
@@ -447,11 +518,12 @@ static int link_alt_odb_entry(struct rep
 		return -1;
 	}
 
-	ent = alloc_alt_odb(pathbuf.buf);
+	ent = xcalloc(1, sizeof(*ent));
+	ent->path = xstrdup(pathbuf.buf);
 
 	/* add the alternate entry */
-	*r->objects->alt_odb_tail = ent;
-	r->objects->alt_odb_tail = &(ent->next);
+	*r->objects->odb_tail = ent;
+	r->objects->odb_tail = &(ent->next);
 	ent->next = NULL;
 
 	/* recursively add alternates */
@@ -500,14 +572,14 @@ static void link_alt_odb_entries(struct
 		return;
 
 	if (depth > 5) {
-		error("%s: ignoring alternate object stores, nesting too deep.",
+		error(_("%s: ignoring alternate object stores, nesting too deep"),
 				relative_base);
 		return;
 	}
 
-	strbuf_add_absolute_path(&objdirbuf, r->objects->objectdir);
+	strbuf_add_absolute_path(&objdirbuf, r->objects->odb->path);
 	if (strbuf_normalize_path(&objdirbuf) < 0)
-		die("unable to normalize object directory: %s",
+		die(_("unable to normalize object directory: %s"),
 		    objdirbuf.buf);
 
 	while (*alt) {
@@ -540,18 +612,6 @@ static void read_info_alternates(struct
 	free(path);
 }
 
-struct alternate_object_database *alloc_alt_odb(const char *dir)
-{
-	struct alternate_object_database *ent;
-
-	FLEX_ALLOC_STR(ent, path, dir);
-	strbuf_init(&ent->scratch, 0);
-	strbuf_addf(&ent->scratch, "%s/", dir);
-	ent->base_len = ent->scratch.len;
-
-	return ent;
-}
-
 void add_to_alternates_file(const char *reference)
 {
 	struct lock_file lock = LOCK_INIT;
@@ -562,7 +622,7 @@ void add_to_alternates_file(const char *
 	hold_lock_file_for_update(&lock, alts, LOCK_DIE_ON_ERROR);
 	out = fdopen_lock_file(&lock, "w");
 	if (!out)
-		die_errno("unable to fdopen alternates lockfile");
+		die_errno(_("unable to fdopen alternates lockfile"));
 
 	in = fopen(alts, "r");
 	if (in) {
@@ -580,15 +640,15 @@ void add_to_alternates_file(const char *
 		fclose(in);
 	}
 	else if (errno != ENOENT)
-		die_errno("unable to read alternates file");
+		die_errno(_("unable to read alternates file"));
 
 	if (found) {
 		rollback_lock_file(&lock);
 	} else {
 		fprintf_or_die(out, "%s\n", reference);
 		if (commit_lock_file(&lock))
-			die_errno("unable to move new alternates file into place");
-		if (the_repository->objects->alt_odb_tail)
+			die_errno(_("unable to move new alternates file into place"));
+		if (the_repository->objects->loaded_alternates)
 			link_alt_odb_entries(the_repository, reference,
 					     '\n', NULL, 0);
 	}
@@ -682,13 +742,111 @@ out:
 	return ref_git;
 }
 
+static void fill_alternate_refs_command(struct child_process *cmd,
+					const char *repo_path)
+{
+	const char *value;
+
+	if (!git_config_get_value("core.alternateRefsCommand", &value)) {
+		cmd->use_shell = 1;
+
+		argv_array_push(&cmd->args, value);
+		argv_array_push(&cmd->args, repo_path);
+	} else {
+		cmd->git_cmd = 1;
+
+		argv_array_pushf(&cmd->args, "--git-dir=%s", repo_path);
+		argv_array_push(&cmd->args, "for-each-ref");
+		argv_array_push(&cmd->args, "--format=%(objectname)");
+
+		if (!git_config_get_value("core.alternateRefsPrefixes", &value)) {
+			argv_array_push(&cmd->args, "--");
+			argv_array_split(&cmd->args, value);
+		}
+	}
+
+	cmd->env = local_repo_env;
+	cmd->out = -1;
+}
+
+static void read_alternate_refs(const char *path,
+				alternate_ref_fn *cb,
+				void *data)
+{
+	struct child_process cmd = CHILD_PROCESS_INIT;
+	struct strbuf line = STRBUF_INIT;
+	FILE *fh;
+
+	fill_alternate_refs_command(&cmd, path);
+
+	if (start_command(&cmd))
+		return;
+
+	fh = xfdopen(cmd.out, "r");
+	while (strbuf_getline_lf(&line, fh) != EOF) {
+		struct object_id oid;
+		const char *p;
+
+		if (parse_oid_hex(line.buf, &oid, &p) || *p) {
+			warning(_("invalid line while parsing alternate refs: %s"),
+				line.buf);
+			break;
+		}
+
+		cb(&oid, data);
+	}
+
+	fclose(fh);
+	finish_command(&cmd);
+	strbuf_release(&line);
+}
+
+struct alternate_refs_data {
+	alternate_ref_fn *fn;
+	void *data;
+};
+
+static int refs_from_alternate_cb(struct object_directory *e,
+				  void *data)
+{
+	struct strbuf path = STRBUF_INIT;
+	size_t base_len;
+	struct alternate_refs_data *cb = data;
+
+	if (!strbuf_realpath(&path, e->path, 0))
+		goto out;
+	if (!strbuf_strip_suffix(&path, "/objects"))
+		goto out;
+	base_len = path.len;
+
+	/* Is this a git repository with refs? */
+	strbuf_addstr(&path, "/refs");
+	if (!is_directory(path.buf))
+		goto out;
+	strbuf_setlen(&path, base_len);
+
+	read_alternate_refs(path.buf, cb->fn, cb->data);
+
+out:
+	strbuf_release(&path);
+	return 0;
+}
+
+void for_each_alternate_ref(alternate_ref_fn fn, void *data)
+{
+	struct alternate_refs_data cb;
+	cb.fn = fn;
+	cb.data = data;
+	foreach_alt_odb(refs_from_alternate_cb, &cb);
+}
+
 int foreach_alt_odb(alt_odb_fn fn, void *cb)
 {
-	struct alternate_object_database *ent;
+	struct object_directory *ent;
 	int r = 0;
 
 	prepare_alt_odb(the_repository);
-	for (ent = the_repository->objects->alt_odb_list; ent; ent = ent->next) {
+	for (ent = the_repository->objects->odb->next; ent; ent = ent->next) {
 		r = fn(ent, cb);
 		if (r)
 			break;
@@ -698,13 +856,13 @@ int foreach_alt_odb(alt_odb_fn fn, void
 
 void prepare_alt_odb(struct repository *r)
 {
-	if (r->objects->alt_odb_tail)
+	if (r->objects->loaded_alternates)
 		return;
 
-	r->objects->alt_odb_tail = &r->objects->alt_odb_list;
 	link_alt_odb_entries(r, r->objects->alternate_db, PATH_SEP, NULL, 0);
 
-	read_info_alternates(r, r->objects->objectdir, 0);
+	read_info_alternates(r, r->objects->odb->path, 0);
+	r->objects->loaded_alternates = 1;
 }
 
 /* Returns 1 if we have successfully freshened the file, 0 otherwise. */
@@ -731,23 +889,27 @@ int check_and_freshen_file(const char *f
 	return 1;
 }
 
+static int check_and_freshen_odb(struct object_directory *odb,
+				 const struct object_id *oid,
+				 int freshen)
+{
+	static struct strbuf path = STRBUF_INIT;
+	odb_loose_path(odb, &path, oid);
+	return check_and_freshen_file(path.buf, freshen);
+}
+
 static int check_and_freshen_local(const struct object_id *oid, int freshen)
 {
-	static struct strbuf buf = STRBUF_INIT;
-
-	strbuf_reset(&buf);
-	sha1_file_name(the_repository, &buf, oid->hash);
-
-	return check_and_freshen_file(buf.buf, freshen);
+	return check_and_freshen_odb(the_repository->objects->odb, oid, freshen);
 }
 
 static int check_and_freshen_nonlocal(const struct object_id *oid, int freshen)
 {
-	struct alternate_object_database *alt;
+	struct object_directory *odb;
+
 	prepare_alt_odb(the_repository);
-	for (alt = the_repository->objects->alt_odb_list; alt; alt = alt->next) {
-		const char *path = alt_sha1_path(alt, oid->hash);
-		if (check_and_freshen_file(path, freshen))
+	for (odb = the_repository->objects->odb->next; odb; odb = odb->next) {
+		if (check_and_freshen_odb(odb, oid, freshen))
 			return 1;
 	}
 	return 0;
@@ -778,7 +940,7 @@ static void mmap_limit_check(size_t leng
 			limit = SIZE_MAX;
 	}
 	if (length > limit)
-		die("attempting to mmap %"PRIuMAX" over limit %"PRIuMAX,
+		die(_("attempting to mmap %"PRIuMAX" over limit %"PRIuMAX),
 		    (uintmax_t)length, (uintmax_t)limit);
 }
 
@@ -789,12 +951,8 @@ void *xmmap_gently(void *start, size_t l
 
 	mmap_limit_check(length);
 	ret = mmap(start, length, prot, flags, fd, offset);
-	if (ret == MAP_FAILED) {
-		if (!length)
-			return NULL;
-		release_pack_memory(length);
-		ret = mmap(start, length, prot, flags, fd, offset);
-	}
+	if (ret == MAP_FAILED && !length)
+		ret = NULL;
 	return ret;
 }
 
@@ -803,14 +961,14 @@ void *xmmap(void *start, size_t length,
 {
 	void *ret = xmmap_gently(start, length, prot, flags, fd, offset);
 	if (ret == MAP_FAILED)
-		die_errno("mmap failed");
+		die_errno(_("mmap failed"));
 	return ret;
 }
 
 /*
  * With an in-core object data in "map", rehash it to make sure the
- * object name actually matches "sha1" to detect object corruption.
- * With "map" == NULL, try reading the object named with "sha1" using
+ * object name actually matches "oid" to detect object corruption.
+ * With "map" == NULL, try reading the object named with "oid" using
  * the streaming interface and rehash it to do the same.
  */
 int check_object_signature(const struct object_id *oid, void *map,
@@ -825,7 +983,7 @@ int check_object_signature(const struct
 
 	if (map) {
 		hash_object_file(map, size, type, &real_oid);
-		return oidcmp(oid, &real_oid) ? -1 : 0;
+		return !oideq(oid, &real_oid) ? -1 : 0;
 	}
 
 	st = open_istream(oid, &obj_type, &size, NULL);
@@ -833,7 +991,7 @@ int check_object_signature(const struct
 		return -1;
 
 	/* Generate the header */
-	hdrlen = xsnprintf(hdr, sizeof(hdr), "%s %lu", type_name(obj_type), size) + 1;
+	hdrlen = xsnprintf(hdr, sizeof(hdr), "%s %"PRIuMAX , type_name(obj_type), (uintmax_t)size) + 1;
 
 	/* Sha1.. */
 	the_hash_algo->init_fn(&c);
@@ -852,7 +1010,7 @@ int check_object_signature(const struct
 	}
 	the_hash_algo->final_fn(real_oid.hash, &c);
 	close_istream(st);
-	return oidcmp(oid, &real_oid) ? -1 : 0;
+	return !oideq(oid, &real_oid) ? -1 : 0;
 }
 
 int git_open_cloexec(const char *name, int flags)
@@ -883,30 +1041,22 @@ int git_open_cloexec(const char *name, i
 }
 
 /*
- * Find "sha1" as a loose object in the local repository or in an alternate.
+ * Find "oid" as a loose object in the local repository or in an alternate.
  * Returns 0 on success, negative on failure.
  *
  * The "path" out-parameter will give the path of the object we found (if any).
  * Note that it may point to static storage and is only valid until another
- * call to sha1_file_name(), etc.
+ * call to stat_loose_object().
  */
-static int stat_sha1_file(struct repository *r, const unsigned char *sha1,
-			  struct stat *st, const char **path)
+static int stat_loose_object(struct repository *r, const struct object_id *oid,
+			     struct stat *st, const char **path)
 {
-	struct alternate_object_database *alt;
+	struct object_directory *odb;
 	static struct strbuf buf = STRBUF_INIT;
 
-	strbuf_reset(&buf);
-	sha1_file_name(r, &buf, sha1);
-	*path = buf.buf;
-
-	if (!lstat(*path, st))
-		return 0;
-
 	prepare_alt_odb(r);
-	errno = ENOENT;
-	for (alt = r->objects->alt_odb_list; alt; alt = alt->next) {
-		*path = alt_sha1_path(alt, sha1);
+	for (odb = r->objects->odb; odb; odb = odb->next) {
+		*path = odb_loose_path(odb, &buf, oid);
 		if (!lstat(*path, st))
 			return 0;
 	}
@@ -915,32 +1065,24 @@ static int stat_sha1_file(struct reposit
 }
 
 /*
- * Like stat_sha1_file(), but actually open the object and return the
+ * Like stat_loose_object(), but actually open the object and return the
  * descriptor. See the caveats on the "path" parameter above.
  */
-static int open_sha1_file(struct repository *r,
-			  const unsigned char *sha1, const char **path)
+static int open_loose_object(struct repository *r,
+			     const struct object_id *oid, const char **path)
 {
 	int fd;
-	struct alternate_object_database *alt;
-	int most_interesting_errno;
+	struct object_directory *odb;
+	int most_interesting_errno = ENOENT;
 	static struct strbuf buf = STRBUF_INIT;
 
-	strbuf_reset(&buf);
-	sha1_file_name(r, &buf, sha1);
-	*path = buf.buf;
-
-	fd = git_open(*path);
-	if (fd >= 0)
-		return fd;
-	most_interesting_errno = errno;
-
 	prepare_alt_odb(r);
-	for (alt = r->objects->alt_odb_list; alt; alt = alt->next) {
-		*path = alt_sha1_path(alt, sha1);
+	for (odb = r->objects->odb; odb; odb = odb->next) {
+		*path = odb_loose_path(odb, &buf, oid);
 		fd = git_open(*path);
 		if (fd >= 0)
 			return fd;
+
 		if (most_interesting_errno == ENOENT)
 			most_interesting_errno = errno;
 	}
@@ -948,12 +1090,25 @@ static int open_sha1_file(struct reposit
 	return -1;
 }
 
+static int quick_has_loose(struct repository *r,
+			   const struct object_id *oid)
+{
+	struct object_directory *odb;
+
+	prepare_alt_odb(r);
+	for (odb = r->objects->odb; odb; odb = odb->next) {
+		if (oid_array_lookup(odb_loose_cache(odb, oid), oid) >= 0)
+			return 1;
+	}
+	return 0;
+}
+
 /*
  * Map the loose object at "path" if it is not NULL, or the path found by
- * searching for a loose object named "sha1".
+ * searching for a loose object named "oid".
  */
-static void *map_sha1_file_1(struct repository *r, const char *path,
-			     const unsigned char *sha1, unsigned long *size)
+static void *map_loose_object_1(struct repository *r, const char *path,
+			     const struct object_id *oid, unsigned long *size)
 {
 	void *map;
 	int fd;
@@ -961,7 +1116,7 @@ static void *map_sha1_file_1(struct repo
 	if (path)
 		fd = git_open(path);
 	else
-		fd = open_sha1_file(r, sha1, &path);
+		fd = open_loose_object(r, oid, &path);
 	map = NULL;
 	if (fd >= 0) {
 		struct stat st;
@@ -970,7 +1125,8 @@ static void *map_sha1_file_1(struct repo
 			*size = xsize_t(st.st_size);
 			if (!*size) {
 				/* mmap() is forbidden on empty files */
-				error("object file %s is empty", path);
+				error(_("object file %s is empty"), path);
+				close(fd);
 				return NULL;
 			}
 			map = xmmap(NULL, *size, PROT_READ, MAP_PRIVATE, fd, 0);
@@ -980,15 +1136,16 @@ static void *map_sha1_file_1(struct repo
 	return map;
 }
 
-void *map_sha1_file(struct repository *r,
-		    const unsigned char *sha1, unsigned long *size)
+void *map_loose_object(struct repository *r,
+		       const struct object_id *oid,
+		       unsigned long *size)
 {
-	return map_sha1_file_1(r, NULL, sha1, size);
+	return map_loose_object_1(r, NULL, oid, size);
 }
 
-static int unpack_sha1_short_header(git_zstream *stream,
-				    unsigned char *map, unsigned long mapsize,
-				    void *buffer, unsigned long bufsiz)
+static int unpack_loose_short_header(git_zstream *stream,
+				     unsigned char *map, unsigned long mapsize,
+				     void *buffer, unsigned long bufsiz)
 {
 	/* Get the data stream */
 	memset(stream, 0, sizeof(*stream));
@@ -1001,12 +1158,12 @@ static int unpack_sha1_short_header(git_
 	return git_inflate(stream, 0);
 }
 
-int unpack_sha1_header(git_zstream *stream,
-		       unsigned char *map, unsigned long mapsize,
-		       void *buffer, unsigned long bufsiz)
+int unpack_loose_header(git_zstream *stream,
+			unsigned char *map, unsigned long mapsize,
+			void *buffer, unsigned long bufsiz)
 {
-	int status = unpack_sha1_short_header(stream, map, mapsize,
-					      buffer, bufsiz);
+	int status = unpack_loose_short_header(stream, map, mapsize,
+					       buffer, bufsiz);
 
 	if (status < Z_OK)
 		return status;
@@ -1017,13 +1174,13 @@ int unpack_sha1_header(git_zstream *stre
 	return 0;
 }
 
-static int unpack_sha1_header_to_strbuf(git_zstream *stream, unsigned char *map,
-					unsigned long mapsize, void *buffer,
-					unsigned long bufsiz, struct strbuf *header)
+static int unpack_loose_header_to_strbuf(git_zstream *stream, unsigned char *map,
+					 unsigned long mapsize, void *buffer,
+					 unsigned long bufsiz, struct strbuf *header)
 {
 	int status;
 
-	status = unpack_sha1_short_header(stream, map, mapsize, buffer, bufsiz);
+	status = unpack_loose_short_header(stream, map, mapsize, buffer, bufsiz);
 	if (status < Z_OK)
 		return -1;
 
@@ -1053,7 +1210,9 @@ static int unpack_sha1_header_to_strbuf(
 	return -1;
 }
 
-static void *unpack_sha1_rest(git_zstream *stream, void *buffer, unsigned long size, const unsigned char *sha1)
+static void *unpack_loose_rest(git_zstream *stream,
+			       void *buffer, unsigned long size,
+			       const struct object_id *oid)
 {
 	int bytes = strlen(buffer) + 1;
 	unsigned char *buf = xmallocz(size);
@@ -1090,10 +1249,10 @@ static void *unpack_sha1_rest(git_zstrea
 	}
 
 	if (status < 0)
-		error("corrupt loose object '%s'", sha1_to_hex(sha1));
+		error(_("corrupt loose object '%s'"), oid_to_hex(oid));
 	else if (stream->avail_in)
-		error("garbage at end of loose object '%s'",
-		      sha1_to_hex(sha1));
+		error(_("garbage at end of loose object '%s'"),
+		      oid_to_hex(oid));
 	free(buf);
 	return NULL;
 }
@@ -1103,8 +1262,8 @@ static void *unpack_sha1_rest(git_zstrea
  * too permissive for what we want to check. So do an anal
  * object header parse by hand.
  */
-static int parse_sha1_header_extended(const char *hdr, struct object_info *oi,
-			       unsigned int flags)
+static int parse_loose_header_extended(const char *hdr, struct object_info *oi,
+				       unsigned int flags)
 {
 	const char *type_buf = hdr;
 	unsigned long size;
@@ -1134,7 +1293,7 @@ static int parse_sha1_header_extended(co
 	if ((flags & OBJECT_INFO_ALLOW_UNKNOWN_TYPE) && (type < 0))
 		type = 0;
 	else if (type < 0)
-		die("invalid object type");
+		die(_("invalid object type"));
 	if (oi->typep)
 		*oi->typep = type;
 
@@ -1164,17 +1323,17 @@ static int parse_sha1_header_extended(co
 	return *hdr ? -1 : type;
 }
 
-int parse_sha1_header(const char *hdr, unsigned long *sizep)
+int parse_loose_header(const char *hdr, unsigned long *sizep)
 {
 	struct object_info oi = OBJECT_INFO_INIT;
 
 	oi.sizep = sizep;
-	return parse_sha1_header_extended(hdr, &oi, 0);
+	return parse_loose_header_extended(hdr, &oi, 0);
 }
 
-static int sha1_loose_object_info(struct repository *r,
-				  const unsigned char *sha1,
-				  struct object_info *oi, int flags)
+static int loose_object_info(struct repository *r,
+			     const struct object_id *oid,
+			     struct object_info *oi, int flags)
 {
 	int status = 0;
 	unsigned long mapsize;
@@ -1198,14 +1357,16 @@ static int sha1_loose_object_info(struct
 	if (!oi->typep && !oi->type_name && !oi->sizep && !oi->contentp) {
 		const char *path;
 		struct stat st;
-		if (stat_sha1_file(r, sha1, &st, &path) < 0)
+		if (!oi->disk_sizep && (flags & OBJECT_INFO_QUICK))
+			return quick_has_loose(r, oid) ? 0 : -1;
+		if (stat_loose_object(r, oid, &st, &path) < 0)
 			return -1;
 		if (oi->disk_sizep)
 			*oi->disk_sizep = st.st_size;
 		return 0;
 	}
 
-	map = map_sha1_file(r, sha1, &mapsize);
+	map = map_loose_object(r, oid, &mapsize);
 	if (!map)
 		return -1;
 
@@ -1215,24 +1376,24 @@ static int sha1_loose_object_info(struct
 	if (oi->disk_sizep)
 		*oi->disk_sizep = mapsize;
 	if ((flags & OBJECT_INFO_ALLOW_UNKNOWN_TYPE)) {
-		if (unpack_sha1_header_to_strbuf(&stream, map, mapsize, hdr, sizeof(hdr), &hdrbuf) < 0)
-			status = error("unable to unpack %s header with --allow-unknown-type",
-				       sha1_to_hex(sha1));
-	} else if (unpack_sha1_header(&stream, map, mapsize, hdr, sizeof(hdr)) < 0)
-		status = error("unable to unpack %s header",
-			       sha1_to_hex(sha1));
+		if (unpack_loose_header_to_strbuf(&stream, map, mapsize, hdr, sizeof(hdr), &hdrbuf) < 0)
+			status = error(_("unable to unpack %s header with --allow-unknown-type"),
+				       oid_to_hex(oid));
+	} else if (unpack_loose_header(&stream, map, mapsize, hdr, sizeof(hdr)) < 0)
+		status = error(_("unable to unpack %s header"),
+			       oid_to_hex(oid));
 	if (status < 0)
 		; /* Do nothing */
 	else if (hdrbuf.len) {
-		if ((status = parse_sha1_header_extended(hdrbuf.buf, oi, flags)) < 0)
-			status = error("unable to parse %s header with --allow-unknown-type",
-				       sha1_to_hex(sha1));
-	} else if ((status = parse_sha1_header_extended(hdr, oi, flags)) < 0)
-		status = error("unable to parse %s header", sha1_to_hex(sha1));
+		if ((status = parse_loose_header_extended(hdrbuf.buf, oi, flags)) < 0)
+			status = error(_("unable to parse %s header with --allow-unknown-type"),
+				       oid_to_hex(oid));
+	} else if ((status = parse_loose_header_extended(hdr, oi, flags)) < 0)
+		status = error(_("unable to parse %s header"), oid_to_hex(oid));
 
 	if (status >= 0 && oi->contentp) {
-		*oi->contentp = unpack_sha1_rest(&stream, hdr,
-						 *oi->sizep, sha1);
+		*oi->contentp = unpack_loose_rest(&stream, hdr,
+						  *oi->sizep, oid);
 		if (!*oi->contentp) {
 			git_inflate_end(&stream);
 			status = -1;
@@ -1256,6 +1417,7 @@ int oid_object_info_extended(struct repo
 			     struct object_info *oi, unsigned flags)
 {
 	static struct object_info blank_oi = OBJECT_INFO_INIT;
+	struct cached_object *co;
 	struct pack_entry e;
 	int rtype;
 	const struct object_id *real = oid;
@@ -1270,24 +1432,22 @@ int oid_object_info_extended(struct repo
 	if (!oi)
 		oi = &blank_oi;
 
-	if (!(flags & OBJECT_INFO_SKIP_CACHED)) {
-		struct cached_object *co = find_cached_object(real);
-		if (co) {
-			if (oi->typep)
-				*(oi->typep) = co->type;
-			if (oi->sizep)
-				*(oi->sizep) = co->size;
-			if (oi->disk_sizep)
-				*(oi->disk_sizep) = 0;
-			if (oi->delta_base_sha1)
-				hashclr(oi->delta_base_sha1);
-			if (oi->type_name)
-				strbuf_addstr(oi->type_name, type_name(co->type));
-			if (oi->contentp)
-				*oi->contentp = xmemdupz(co->buf, co->size);
-			oi->whence = OI_CACHED;
-			return 0;
-		}
+	co = find_cached_object(real);
+	if (co) {
+		if (oi->typep)
+			*(oi->typep) = co->type;
+		if (oi->sizep)
+			*(oi->sizep) = co->size;
+		if (oi->disk_sizep)
+			*(oi->disk_sizep) = 0;
+		if (oi->delta_base_sha1)
+			hashclr(oi->delta_base_sha1);
+		if (oi->type_name)
+			strbuf_addstr(oi->type_name, type_name(co->type));
+		if (oi->contentp)
+			*oi->contentp = xmemdupz(co->buf, co->size);
+		oi->whence = OI_CACHED;
+		return 0;
 	}
 
 	while (1) {
@@ -1298,7 +1458,7 @@ int oid_object_info_extended(struct repo
 			return -1;
 
 		/* Most likely it's a loose object. */
-		if (!sha1_loose_object_info(r, real->hash, oi, flags))
+		if (!loose_object_info(r, real, oi, flags))
 			return 0;
 
 		/* Not a loose object; someone else may have just packed it. */
@@ -1309,15 +1469,17 @@ int oid_object_info_extended(struct repo
 		}
 
 		/* Check if it is a missing object */
-		if (fetch_if_missing && repository_format_partial_clone &&
-		    !already_retried && r == the_repository) {
+		if (fetch_if_missing && has_promisor_remote() &&
+		    !already_retried && r == the_repository &&
+		    !(flags & OBJECT_INFO_SKIP_FETCH_OBJECT)) {
 			/*
-			 * TODO Investigate having fetch_object() return
-			 * TODO error/success and stopping the music here.
-			 * TODO Pass a repository struct through fetch_object,
-			 * such that arbitrary repositories work.
+			 * TODO Investigate checking promisor_remote_get_direct()
+			 * TODO return value and stopping on error here.
+			 * TODO Pass a repository struct through
+			 * promisor_remote_get_direct(), such that arbitrary
+			 * repositories work.
 			 */
-			fetch_object(repository_format_partial_clone, real->hash);
+			promisor_remote_get_direct(r, real, 1);
 			already_retried = 1;
 			continue;
 		}
@@ -1361,19 +1523,17 @@ int oid_object_info(struct repository *r
 	return type;
 }
 
-static void *read_object(const unsigned char *sha1, enum object_type *type,
+static void *read_object(struct repository *r,
+			 const struct object_id *oid, enum object_type *type,
 			 unsigned long *size)
 {
-	struct object_id oid;
 	struct object_info oi = OBJECT_INFO_INIT;
 	void *content;
 	oi.typep = type;
 	oi.sizep = size;
 	oi.contentp = &content;
 
-	hashcpy(oid.hash, sha1);
-
-	if (oid_object_info_extended(the_repository, &oid, &oi, 0) < 0)
+	if (oid_object_info_extended(r, oid, &oi, 0) < 0)
 		return NULL;
 	return content;
 }
@@ -1384,7 +1544,7 @@ int pretend_object_file(void *buf, unsig
 	struct cached_object *co;
 
 	hash_object_file(buf, len, type_name(type), oid);
-	if (has_sha1_file(oid->hash) || find_cached_object(oid))
+	if (has_object_file(oid) || find_cached_object(oid))
 		return 0;
 	ALLOC_GROW(cached_objects, cached_object_nr + 1, cached_object_alloc);
 	co = &cached_objects[cached_object_nr++];
@@ -1401,7 +1561,8 @@ int pretend_object_file(void *buf, unsig
  * deal with them should arrange to call read_object() and give error
  * messages themselves.
  */
-void *read_object_file_extended(const struct object_id *oid,
+void *read_object_file_extended(struct repository *r,
+				const struct object_id *oid,
 				enum object_type *type,
 				unsigned long *size,
 				int lookup_replace)
@@ -1411,33 +1572,34 @@ void *read_object_file_extended(const st
 	const char *path;
 	struct stat st;
 	const struct object_id *repl = lookup_replace ?
-		lookup_replace_object(the_repository, oid) : oid;
+		lookup_replace_object(r, oid) : oid;
 
 	errno = 0;
-	data = read_object(repl->hash, type, size);
+	data = read_object(r, repl, type, size);
 	if (data)
 		return data;
 
 	if (errno && errno != ENOENT)
-		die_errno("failed to read object %s", oid_to_hex(oid));
+		die_errno(_("failed to read object %s"), oid_to_hex(oid));
 
 	/* die if we replaced an object with one that does not exist */
 	if (repl != oid)
-		die("replacement %s not found for %s",
+		die(_("replacement %s not found for %s"),
 		    oid_to_hex(repl), oid_to_hex(oid));
 
-	if (!stat_sha1_file(the_repository, repl->hash, &st, &path))
-		die("loose object %s (stored in %s) is corrupt",
+	if (!stat_loose_object(r, repl, &st, &path))
+		die(_("loose object %s (stored in %s) is corrupt"),
 		    oid_to_hex(repl), path);
 
-	if ((p = has_packed_and_bad(repl->hash)) != NULL)
-		die("packed object %s (stored in %s) is corrupt",
+	if ((p = has_packed_and_bad(r, repl->hash)) != NULL)
+		die(_("packed object %s (stored in %s) is corrupt"),
 		    oid_to_hex(repl), p->pack_name);
 
 	return NULL;
 }
 
-void *read_object_with_reference(const struct object_id *oid,
+void *read_object_with_reference(struct repository *r,
+				 const struct object_id *oid,
 				 const char *required_type_name,
 				 unsigned long *size,
 				 struct object_id *actual_oid_return)
@@ -1453,7 +1615,7 @@ void *read_object_with_reference(const s
 		int ref_length = -1;
 		const char *ref_type = NULL;
 
-		buffer = read_object_file(&actual_oid, &type, &isize);
+		buffer = repo_read_object_file(r, &actual_oid, &type, &isize);
 		if (!buffer)
 			return NULL;
 		if (type == required_type) {
@@ -1473,7 +1635,7 @@ void *read_object_with_reference(const s
 		}
 		ref_length = strlen(ref_type);
 
-		if (ref_length + GIT_SHA1_HEXSZ > isize ||
+		if (ref_length + the_hash_algo->hexsz > isize ||
 		    memcmp(buffer, ref_type, ref_length) ||
 		    get_oid_hex((char *) buffer + ref_length, &actual_oid)) {
 			free(buffer);
@@ -1492,7 +1654,7 @@ static void write_object_file_prepare(co
 	git_hash_ctx c;
 
 	/* Generate the header */
-	*hdrlen = xsnprintf(hdr, *hdrlen, "%s %lu", type, len)+1;
+	*hdrlen = xsnprintf(hdr, *hdrlen, "%s %"PRIuMAX , type, (uintmax_t)len)+1;
 
 	/* Sha1.. */
 	the_hash_algo->init_fn(&c);
@@ -1533,21 +1695,21 @@ int finalize_object_file(const char *tmp
 	unlink_or_warn(tmpfile);
 	if (ret) {
 		if (ret != EEXIST) {
-			return error_errno("unable to write sha1 filename %s", filename);
+			return error_errno(_("unable to write file %s"), filename);
 		}
 		/* FIXME!!! Collision check here ? */
 	}
 
 out:
 	if (adjust_shared_perm(filename))
-		return error("unable to set permission to '%s'", filename);
+		return error(_("unable to set permission to '%s'"), filename);
 	return 0;
 }
 
 static int write_buffer(int fd, const void *buf, size_t len)
 {
 	if (write_in_full(fd, buf, len) < 0)
-		return error_errno("file write error");
+		return error_errno(_("file write error"));
 	return 0;
 }
 
@@ -1561,12 +1723,12 @@ int hash_object_file(const void *buf, un
 }
 
 /* Finalize a file on disk, and close it. */
-static void close_sha1_file(int fd)
+static void close_loose_object(int fd)
 {
 	if (fsync_object_files)
-		fsync_or_die(fd, "sha1 file");
+		fsync_or_die(fd, "loose object file");
 	if (close(fd) != 0)
-		die_errno("error when closing sha1 file");
+		die_errno(_("error when closing loose object file"));
 }
 
 /* Size of directory component, including the ending '/' */
@@ -1626,15 +1788,14 @@ static int write_loose_object(const stru
 	static struct strbuf tmp_file = STRBUF_INIT;
 	static struct strbuf filename = STRBUF_INIT;
 
-	strbuf_reset(&filename);
-	sha1_file_name(the_repository, &filename, oid->hash);
+	loose_object_path(the_repository, &filename, oid);
 
 	fd = create_tmpfile(&tmp_file, filename.buf);
 	if (fd < 0) {
 		if (errno == EACCES)
-			return error("insufficient permission for adding an object to repository database %s", get_object_directory());
+			return error(_("insufficient permission for adding an object to repository database %s"), get_object_directory());
 		else
-			return error_errno("unable to create temporary file");
+			return error_errno(_("unable to create temporary file"));
 	}
 
 	/* Set it up */
@@ -1658,31 +1819,31 @@ static int write_loose_object(const stru
 		ret = git_deflate(&stream, Z_FINISH);
 		the_hash_algo->update_fn(&c, in0, stream.next_in - in0);
 		if (write_buffer(fd, compressed, stream.next_out - compressed) < 0)
-			die("unable to write sha1 file");
+			die(_("unable to write loose object file"));
 		stream.next_out = compressed;
 		stream.avail_out = sizeof(compressed);
 	} while (ret == Z_OK);
 
 	if (ret != Z_STREAM_END)
-		die("unable to deflate new object %s (%d)", oid_to_hex(oid),
+		die(_("unable to deflate new object %s (%d)"), oid_to_hex(oid),
 		    ret);
 	ret = git_deflate_end_gently(&stream);
 	if (ret != Z_OK)
-		die("deflateEnd on object %s failed (%d)", oid_to_hex(oid),
+		die(_("deflateEnd on object %s failed (%d)"), oid_to_hex(oid),
 		    ret);
 	the_hash_algo->final_fn(parano_oid.hash, &c);
-	if (oidcmp(oid, &parano_oid) != 0)
-		die("confused by unstable object source data for %s",
+	if (!oideq(oid, &parano_oid))
+		die(_("confused by unstable object source data for %s"),
 		    oid_to_hex(oid));
 
-	close_sha1_file(fd);
+	close_loose_object(fd);
 
 	if (mtime) {
 		struct utimbuf utb;
 		utb.actime = mtime;
 		utb.modtime = mtime;
 		if (utime(tmp_file.buf, &utb) < 0)
-			warning_errno("failed utime() on %s", tmp_file.buf);
+			warning_errno(_("failed utime() on %s"), tmp_file.buf);
 	}
 
 	return finalize_object_file(tmp_file.buf, filename.buf);
@@ -1755,34 +1916,28 @@ int force_object_loose(const struct obje
 
 	if (has_loose_object(oid))
 		return 0;
-	buf = read_object(oid->hash, &type, &len);
+	buf = read_object(the_repository, oid, &type, &len);
 	if (!buf)
-		return error("cannot read sha1_file for %s", oid_to_hex(oid));
-	hdrlen = xsnprintf(hdr, sizeof(hdr), "%s %lu", type_name(type), len) + 1;
+		return error(_("cannot read object for %s"), oid_to_hex(oid));
+	hdrlen = xsnprintf(hdr, sizeof(hdr), "%s %"PRIuMAX , type_name(type), (uintmax_t)len) + 1;
 	ret = write_loose_object(oid, hdr, hdrlen, buf, len, mtime);
 	free(buf);
 
 	return ret;
 }
 
-int has_sha1_file_with_flags(const unsigned char *sha1, int flags)
+int repo_has_object_file_with_flags(struct repository *r,
+				    const struct object_id *oid, int flags)
 {
-	struct object_id oid;
 	if (!startup_info->have_repository)
 		return 0;
-	hashcpy(oid.hash, sha1);
-	return oid_object_info_extended(the_repository, &oid, NULL,
-					flags | OBJECT_INFO_SKIP_CACHED) >= 0;
+	return oid_object_info_extended(r, oid, NULL, flags) >= 0;
 }
 
-int has_object_file(const struct object_id *oid)
+int repo_has_object_file(struct repository *r,
+			 const struct object_id *oid)
 {
-	return has_sha1_file(oid->hash);
-}
-
-int has_object_file_with_flags(const struct object_id *oid, int flags)
-{
-	return has_sha1_file_with_flags(oid->hash, flags);
+	return repo_has_object_file_with_flags(r, oid, 0);
 }
 
 static void check_tree(const void *buf, size_t size)
@@ -1801,19 +1956,20 @@ static void check_commit(const void *buf
 {
 	struct commit c;
 	memset(&c, 0, sizeof(c));
-	if (parse_commit_buffer(&c, buf, size))
-		die("corrupt commit");
+	if (parse_commit_buffer(the_repository, &c, buf, size, 0))
+		die(_("corrupt commit"));
 }
 
 static void check_tag(const void *buf, size_t size)
 {
 	struct tag t;
 	memset(&t, 0, sizeof(t));
-	if (parse_tag_buffer(&t, buf, size))
-		die("corrupt tag");
+	if (parse_tag_buffer(the_repository, &t, buf, size))
+		die(_("corrupt tag"));
 }
 
-static int index_mem(struct object_id *oid, void *buf, size_t size,
+static int index_mem(struct index_state *istate,
+		     struct object_id *oid, void *buf, size_t size,
 		     enum object_type type,
 		     const char *path, unsigned flags)
 {
@@ -1828,7 +1984,7 @@ static int index_mem(struct object_id *o
 	 */
 	if ((type == OBJ_BLOB) && path) {
 		struct strbuf nbuf = STRBUF_INIT;
-		if (convert_to_git(&the_index, path, buf, size, &nbuf,
+		if (convert_to_git(istate, path, buf, size, &nbuf,
 				   get_conv_flags(flags))) {
 			buf = strbuf_detach(&nbuf, &size);
 			re_allocated = 1;
@@ -1852,17 +2008,20 @@ static int index_mem(struct object_id *o
 	return ret;
 }
 
-static int index_stream_convert_blob(struct object_id *oid, int fd,
-				     const char *path, unsigned flags)
+static int index_stream_convert_blob(struct index_state *istate,
+				     struct object_id *oid,
+				     int fd,
+				     const char *path,
+				     unsigned flags)
 {
 	int ret;
 	const int write_object = flags & HASH_WRITE_OBJECT;
 	struct strbuf sbuf = STRBUF_INIT;
 
 	assert(path);
-	assert(would_convert_to_git_filter_fd(path));
+	assert(would_convert_to_git_filter_fd(istate, path));
 
-	convert_to_git_filter_fd(&the_index, path, fd, &sbuf,
+	convert_to_git_filter_fd(istate, path, fd, &sbuf,
 				 get_conv_flags(flags));
 
 	if (write_object)
@@ -1875,14 +2034,15 @@ static int index_stream_convert_blob(str
 	return ret;
 }
 
-static int index_pipe(struct object_id *oid, int fd, enum object_type type,
+static int index_pipe(struct index_state *istate, struct object_id *oid,
+		      int fd, enum object_type type,
 		      const char *path, unsigned flags)
 {
 	struct strbuf sbuf = STRBUF_INIT;
 	int ret;
 
 	if (strbuf_read(&sbuf, fd, 4096) >= 0)
-		ret = index_mem(oid, sbuf.buf, sbuf.len, type, path, flags);
+		ret = index_mem(istate, oid, sbuf.buf, sbuf.len, type, path, flags);
 	else
 		ret = -1;
 	strbuf_release(&sbuf);
@@ -1891,29 +2051,30 @@ static int index_pipe(struct object_id *
 
 #define SMALL_FILE_SIZE (32*1024)
 
-static int index_core(struct object_id *oid, int fd, size_t size,
+static int index_core(struct index_state *istate,
+		      struct object_id *oid, int fd, size_t size,
 		      enum object_type type, const char *path,
 		      unsigned flags)
 {
 	int ret;
 
 	if (!size) {
-		ret = index_mem(oid, "", size, type, path, flags);
+		ret = index_mem(istate, oid, "", size, type, path, flags);
 	} else if (size <= SMALL_FILE_SIZE) {
 		char *buf = xmalloc(size);
 		ssize_t read_result = read_in_full(fd, buf, size);
 		if (read_result < 0)
-			ret = error_errno("read error while indexing %s",
+			ret = error_errno(_("read error while indexing %s"),
 					  path ? path : "<unknown>");
 		else if (read_result != size)
-			ret = error("short read while indexing %s",
+			ret = error(_("short read while indexing %s"),
 				    path ? path : "<unknown>");
 		else
-			ret = index_mem(oid, buf, size, type, path, flags);
+			ret = index_mem(istate, oid, buf, size, type, path, flags);
 		free(buf);
 	} else {
 		void *buf = xmmap(NULL, size, PROT_READ, MAP_PRIVATE, fd, 0);
-		ret = index_mem(oid, buf, size, type, path, flags);
+		ret = index_mem(istate, oid, buf, size, type, path, flags);
 		munmap(buf, size);
 	}
 	return ret;
@@ -1941,7 +2102,8 @@ static int index_stream(struct object_id
 	return index_bulk_checkin(oid, fd, size, type, path, flags);
 }
 
-int index_fd(struct object_id *oid, int fd, struct stat *st,
+int index_fd(struct index_state *istate, struct object_id *oid,
+	     int fd, struct stat *st,
 	     enum object_type type, const char *path, unsigned flags)
 {
 	int ret;
@@ -1950,14 +2112,14 @@ int index_fd(struct object_id *oid, int
 	 * Call xsize_t() only when needed to avoid potentially unnecessary
 	 * die() for large files.
 	 */
-	if (type == OBJ_BLOB && path && would_convert_to_git_filter_fd(path))
-		ret = index_stream_convert_blob(oid, fd, path, flags);
+	if (type == OBJ_BLOB && path && would_convert_to_git_filter_fd(istate, path))
+		ret = index_stream_convert_blob(istate, oid, fd, path, flags);
 	else if (!S_ISREG(st->st_mode))
-		ret = index_pipe(oid, fd, type, path, flags);
+		ret = index_pipe(istate, oid, fd, type, path, flags);
 	else if (st->st_size <= big_file_threshold || type != OBJ_BLOB ||
-		 (path && would_convert_to_git(&the_index, path)))
-		ret = index_core(oid, fd, xsize_t(st->st_size), type, path,
-				 flags);
+		 (path && would_convert_to_git(istate, path)))
+		ret = index_core(istate, oid, fd, xsize_t(st->st_size),
+				 type, path, flags);
 	else
 		ret = index_stream(oid, fd, xsize_t(st->st_size), type, path,
 				   flags);
@@ -1965,7 +2127,8 @@ int index_fd(struct object_id *oid, int
 	return ret;
 }
 
-int index_path(struct object_id *oid, const char *path, struct stat *st, unsigned flags)
+int index_path(struct index_state *istate, struct object_id *oid,
+	       const char *path, struct stat *st, unsigned flags)
 {
 	int fd;
 	struct strbuf sb = STRBUF_INIT;
@@ -1976,8 +2139,8 @@ int index_path(struct object_id *oid, co
 		fd = open(path, O_RDONLY);
 		if (fd < 0)
 			return error_errno("open(\"%s\")", path);
-		if (index_fd(oid, fd, st, OBJ_BLOB, path, flags) < 0)
-			return error("%s: failed to insert into database",
+		if (index_fd(istate, oid, fd, st, OBJ_BLOB, path, flags) < 0)
+			return error(_("%s: failed to insert into database"),
 				     path);
 		break;
 	case S_IFLNK:
@@ -1986,13 +2149,13 @@ int index_path(struct object_id *oid, co
 		if (!(flags & HASH_WRITE_OBJECT))
 			hash_object_file(sb.buf, sb.len, blob_type, oid);
 		else if (write_object_file(sb.buf, sb.len, blob_type, oid))
-			rc = error("%s: failed to insert into database", path);
+			rc = error(_("%s: failed to insert into database"), path);
 		strbuf_release(&sb);
 		break;
 	case S_IFDIR:
 		return resolve_gitlink_ref(path, "HEAD", oid);
 	default:
-		return error("%s: unsupported file type", path);
+		return error(_("%s: unsupported file type"), path);
 	}
 	return rc;
 }
@@ -2016,9 +2179,9 @@ void assert_oid_type(const struct object
 {
 	enum object_type type = oid_object_info(the_repository, oid, NULL);
 	if (type < 0)
-		die("%s is not a valid object", oid_to_hex(oid));
+		die(_("%s is not a valid object"), oid_to_hex(oid));
 	if (type != expect)
-		die("%s is not a valid '%s' object", oid_to_hex(oid),
+		die(_("%s is not a valid '%s' object"), oid_to_hex(oid),
 		    type_name(expect));
 }
 
@@ -2045,7 +2208,7 @@ int for_each_file_in_obj_subdir(unsigned
 	dir = opendir(path->buf);
 	if (!dir) {
 		if (errno != ENOENT)
-			r = error_errno("unable to open %s", path->buf);
+			r = error_errno(_("unable to open %s"), path->buf);
 		strbuf_setlen(path, origlen);
 		return r;
 	}
@@ -2062,9 +2225,9 @@ int for_each_file_in_obj_subdir(unsigned
 		namelen = strlen(de->d_name);
 		strbuf_setlen(path, baselen);
 		strbuf_add(path, de->d_name, namelen);
-		if (namelen == GIT_SHA1_HEXSZ - 2 &&
+		if (namelen == the_hash_algo->hexsz - 2 &&
 		    !hex_to_bytes(oid.hash + 1, de->d_name,
-				  GIT_SHA1_RAWSZ - 1)) {
+				  the_hash_algo->rawsz - 1)) {
 			if (obj_cb) {
 				r = obj_cb(&oid, path->buf, data);
 				if (r)
@@ -2126,52 +2289,73 @@ int for_each_loose_file_in_objdir(const
 	return r;
 }
 
-struct loose_alt_odb_data {
-	each_loose_object_fn *cb;
-	void *data;
-};
+int for_each_loose_object(each_loose_object_fn cb, void *data,
+			  enum for_each_object_flags flags)
+{
+	struct object_directory *odb;
+
+	prepare_alt_odb(the_repository);
+	for (odb = the_repository->objects->odb; odb; odb = odb->next) {
+		int r = for_each_loose_file_in_objdir(odb->path, cb, NULL,
+						      NULL, data);
+		if (r)
+			return r;
+
+		if (flags & FOR_EACH_OBJECT_LOCAL_ONLY)
+			break;
+	}
 
-static int loose_from_alt_odb(struct alternate_object_database *alt,
-			      void *vdata)
+	return 0;
+}
+
+static int append_loose_object(const struct object_id *oid, const char *path,
+			       void *data)
 {
-	struct loose_alt_odb_data *data = vdata;
+	oid_array_append(data, oid);
+	return 0;
+}
+
+struct oid_array *odb_loose_cache(struct object_directory *odb,
+				  const struct object_id *oid)
+{
+	int subdir_nr = oid->hash[0];
 	struct strbuf buf = STRBUF_INIT;
-	int r;
 
-	strbuf_addstr(&buf, alt->path);
-	r = for_each_loose_file_in_objdir_buf(&buf,
-					      data->cb, NULL, NULL,
-					      data->data);
+	if (subdir_nr < 0 ||
+	    subdir_nr >= ARRAY_SIZE(odb->loose_objects_subdir_seen))
+		BUG("subdir_nr out of range");
+
+	if (odb->loose_objects_subdir_seen[subdir_nr])
+		return &odb->loose_objects_cache[subdir_nr];
+
+	strbuf_addstr(&buf, odb->path);
+	for_each_file_in_obj_subdir(subdir_nr, &buf,
+				    append_loose_object,
+				    NULL, NULL,
+				    &odb->loose_objects_cache[subdir_nr]);
+	odb->loose_objects_subdir_seen[subdir_nr] = 1;
 	strbuf_release(&buf);
-	return r;
+	return &odb->loose_objects_cache[subdir_nr];
 }
 
-int for_each_loose_object(each_loose_object_fn cb, void *data, unsigned flags)
+void odb_clear_loose_cache(struct object_directory *odb)
 {
-	struct loose_alt_odb_data alt;
-	int r;
-
-	r = for_each_loose_file_in_objdir(get_object_directory(),
-					  cb, NULL, NULL, data);
-	if (r)
-		return r;
-
-	if (flags & FOR_EACH_OBJECT_LOCAL_ONLY)
-		return 0;
+	int i;
 
-	alt.cb = cb;
-	alt.data = data;
-	return foreach_alt_odb(loose_from_alt_odb, &alt);
+	for (i = 0; i < ARRAY_SIZE(odb->loose_objects_cache); i++)
+		oid_array_clear(&odb->loose_objects_cache[i]);
+	memset(&odb->loose_objects_subdir_seen, 0,
+	       sizeof(odb->loose_objects_subdir_seen));
 }
 
-static int check_stream_sha1(git_zstream *stream,
-			     const char *hdr,
-			     unsigned long size,
-			     const char *path,
-			     const unsigned char *expected_sha1)
+static int check_stream_oid(git_zstream *stream,
+			    const char *hdr,
+			    unsigned long size,
+			    const char *path,
+			    const struct object_id *expected_oid)
 {
 	git_hash_ctx c;
-	unsigned char real_sha1[GIT_MAX_RAWSZ];
+	struct object_id real_oid;
 	unsigned char buf[4096];
 	unsigned long total_read;
 	int status = Z_OK;
@@ -2187,10 +2371,11 @@ static int check_stream_sha1(git_zstream
 
 	/*
 	 * This size comparison must be "<=" to read the final zlib packets;
-	 * see the comment in unpack_sha1_rest for details.
+	 * see the comment in unpack_loose_rest for details.
 	 */
 	while (total_read <= size &&
-	       (status == Z_OK || status == Z_BUF_ERROR)) {
+	       (status == Z_OK ||
+		(status == Z_BUF_ERROR && !stream->avail_out))) {
 		stream->next_out = buf;
 		stream->avail_out = sizeof(buf);
 		if (size - total_read < stream->avail_out)
@@ -2202,19 +2387,19 @@ static int check_stream_sha1(git_zstream
 	git_inflate_end(stream);
 
 	if (status != Z_STREAM_END) {
-		error("corrupt loose object '%s'", sha1_to_hex(expected_sha1));
+		error(_("corrupt loose object '%s'"), oid_to_hex(expected_oid));
 		return -1;
 	}
 	if (stream->avail_in) {
-		error("garbage at end of loose object '%s'",
-		      sha1_to_hex(expected_sha1));
+		error(_("garbage at end of loose object '%s'"),
+		      oid_to_hex(expected_oid));
 		return -1;
 	}
 
-	the_hash_algo->final_fn(real_sha1, &c);
-	if (hashcmp(expected_sha1, real_sha1)) {
-		error("sha1 mismatch for %s (expected %s)", path,
-		      sha1_to_hex(expected_sha1));
+	the_hash_algo->final_fn(real_oid.hash, &c);
+	if (!oideq(expected_oid, &real_oid)) {
+		error(_("hash mismatch for %s (expected %s)"), path,
+		      oid_to_hex(expected_oid));
 		return -1;
 	}
 
@@ -2235,37 +2420,37 @@ int read_loose_object(const char *path,
 
 	*contents = NULL;
 
-	map = map_sha1_file_1(the_repository, path, NULL, &mapsize);
+	map = map_loose_object_1(the_repository, path, NULL, &mapsize);
 	if (!map) {
-		error_errno("unable to mmap %s", path);
+		error_errno(_("unable to mmap %s"), path);
 		goto out;
 	}
 
-	if (unpack_sha1_header(&stream, map, mapsize, hdr, sizeof(hdr)) < 0) {
-		error("unable to unpack header of %s", path);
+	if (unpack_loose_header(&stream, map, mapsize, hdr, sizeof(hdr)) < 0) {
+		error(_("unable to unpack header of %s"), path);
 		goto out;
 	}
 
-	*type = parse_sha1_header(hdr, size);
+	*type = parse_loose_header(hdr, size);
 	if (*type < 0) {
-		error("unable to parse header of %s", path);
+		error(_("unable to parse header of %s"), path);
 		git_inflate_end(&stream);
 		goto out;
 	}
 
 	if (*type == OBJ_BLOB && *size > big_file_threshold) {
-		if (check_stream_sha1(&stream, hdr, *size, path, expected_oid->hash) < 0)
+		if (check_stream_oid(&stream, hdr, *size, path, expected_oid) < 0)
 			goto out;
 	} else {
-		*contents = unpack_sha1_rest(&stream, hdr, *size, expected_oid->hash);
+		*contents = unpack_loose_rest(&stream, hdr, *size, expected_oid);
 		if (!*contents) {
-			error("unable to unpack contents of %s", path);
+			error(_("unable to unpack contents of %s"), path);
 			git_inflate_end(&stream);
 			goto out;
 		}
 		if (check_object_signature(expected_oid, *contents,
 					 *size, type_name(*type))) {
-			error("sha1 mismatch for %s (expected %s)", path,
+			error(_("hash mismatch for %s (expected %s)"), path,
 			      oid_to_hex(expected_oid));
 			free(*contents);
 			goto out;
diff -pruN 1.2.1+git2.18.0-1/git/sha1-lookup.c 1.2.3+git2.25.1-1/git/sha1-lookup.c
--- 1.2.1+git2.18.0-1/git/sha1-lookup.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/sha1-lookup.c	2020-02-17 04:47:35.000000000 +0000
@@ -50,7 +50,7 @@ static uint32_t take2(const unsigned cha
  * The sha1 of element i (between 0 and nr - 1) should be returned
  * by "fn(i, table)".
  */
-int sha1_pos(const unsigned char *sha1, void *table, size_t nr,
+int sha1_pos(const unsigned char *hash, void *table, size_t nr,
 	     sha1_access_fn fn)
 {
 	size_t hi = nr;
@@ -63,14 +63,14 @@ int sha1_pos(const unsigned char *sha1,
 	if (nr != 1) {
 		size_t lov, hiv, miv, ofs;
 
-		for (ofs = 0; ofs < 18; ofs += 2) {
+		for (ofs = 0; ofs < the_hash_algo->rawsz - 2; ofs += 2) {
 			lov = take2(fn(0, table) + ofs);
 			hiv = take2(fn(nr - 1, table) + ofs);
-			miv = take2(sha1 + ofs);
+			miv = take2(hash + ofs);
 			if (miv < lov)
 				return -1;
 			if (hiv < miv)
-				return -1 - nr;
+				return index_pos_to_insert_pos(nr);
 			if (lov != hiv) {
 				/*
 				 * At this point miv could be equal
@@ -88,7 +88,7 @@ int sha1_pos(const unsigned char *sha1,
 
 	do {
 		int cmp;
-		cmp = hashcmp(fn(mi, table), sha1);
+		cmp = hashcmp(fn(mi, table), hash);
 		if (!cmp)
 			return mi;
 		if (cmp > 0)
@@ -97,7 +97,7 @@ int sha1_pos(const unsigned char *sha1,
 			lo = mi + 1;
 		mi = lo + (hi - lo) / 2;
 	} while (lo < hi);
-	return -lo-1;
+	return index_pos_to_insert_pos(lo);
 }
 
 int bsearch_hash(const unsigned char *sha1, const uint32_t *fanout_nbo,
diff -pruN 1.2.1+git2.18.0-1/git/sha1-lookup.h 1.2.3+git2.25.1-1/git/sha1-lookup.h
--- 1.2.1+git2.18.0-1/git/sha1-lookup.h	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/sha1-lookup.h	2020-02-17 04:47:35.000000000 +0000
@@ -3,10 +3,10 @@
 
 typedef const unsigned char *sha1_access_fn(size_t index, void *table);
 
-extern int sha1_pos(const unsigned char *sha1,
-		    void *table,
-		    size_t nr,
-		    sha1_access_fn fn);
+int sha1_pos(const unsigned char *sha1,
+	     void *table,
+	     size_t nr,
+	     sha1_access_fn fn);
 
 /*
  * Searches for sha1 in table, using the given fanout table to determine the
diff -pruN 1.2.1+git2.18.0-1/git/sha1-name.c 1.2.3+git2.25.1-1/git/sha1-name.c
--- 1.2.1+git2.18.0-1/git/sha1-name.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/sha1-name.c	2020-02-17 04:47:35.000000000 +0000
@@ -12,16 +12,20 @@
 #include "packfile.h"
 #include "object-store.h"
 #include "repository.h"
+#include "submodule.h"
+#include "midx.h"
+#include "commit-reach.h"
 
-static int get_oid_oneline(const char *, struct object_id *, struct commit_list *);
+static int get_oid_oneline(struct repository *r, const char *, struct object_id *, struct commit_list *);
 
-typedef int (*disambiguate_hint_fn)(const struct object_id *, void *);
+typedef int (*disambiguate_hint_fn)(struct repository *, const struct object_id *, void *);
 
 struct disambiguate_state {
 	int len; /* length of prefix in hex chars */
 	char hex_pfx[GIT_MAX_HEXSZ + 1];
 	struct object_id bin_pfx;
 
+	struct repository *repo;
 	disambiguate_hint_fn fn;
 	void *cb_data;
 	struct object_id candidate;
@@ -36,7 +40,7 @@ struct disambiguate_state {
 static void update_candidates(struct disambiguate_state *ds, const struct object_id *current)
 {
 	if (ds->always_call_fn) {
-		ds->ambiguous = ds->fn(current, ds->cb_data) ? 1 : 0;
+		ds->ambiguous = ds->fn(ds->repo, current, ds->cb_data) ? 1 : 0;
 		return;
 	}
 	if (!ds->candidate_exists) {
@@ -44,7 +48,7 @@ static void update_candidates(struct dis
 		oidcpy(&ds->candidate, current);
 		ds->candidate_exists = 1;
 		return;
-	} else if (!oidcmp(&ds->candidate, current)) {
+	} else if (oideq(&ds->candidate, current)) {
 		/* the same as what we already have seen */
 		return;
 	}
@@ -56,7 +60,7 @@ static void update_candidates(struct dis
 	}
 
 	if (!ds->candidate_checked) {
-		ds->candidate_ok = ds->fn(&ds->candidate, ds->cb_data);
+		ds->candidate_ok = ds->fn(ds->repo, &ds->candidate, ds->cb_data);
 		ds->disambiguate_fn_used = 1;
 		ds->candidate_checked = 1;
 	}
@@ -69,7 +73,7 @@ static void update_candidates(struct dis
 	}
 
 	/* if we reach this point, we know ds->candidate satisfies fn */
-	if (ds->fn(current, ds->cb_data)) {
+	if (ds->fn(ds->repo, current, ds->cb_data)) {
 		/*
 		 * if both current and candidate satisfy fn, we cannot
 		 * disambiguate.
@@ -81,51 +85,23 @@ static void update_candidates(struct dis
 	/* otherwise, current can be discarded and candidate is still good */
 }
 
-static int append_loose_object(const struct object_id *oid, const char *path,
-			       void *data)
-{
-	oid_array_append(data, oid);
-	return 0;
-}
-
 static int match_sha(unsigned, const unsigned char *, const unsigned char *);
 
 static void find_short_object_filename(struct disambiguate_state *ds)
 {
-	int subdir_nr = ds->bin_pfx.hash[0];
-	struct alternate_object_database *alt;
-	static struct alternate_object_database *fakeent;
-
-	if (!fakeent) {
-		/*
-		 * Create a "fake" alternate object database that
-		 * points to our own object database, to make it
-		 * easier to get a temporary working space in
-		 * alt->name/alt->base while iterating over the
-		 * object databases including our own.
-		 */
-		fakeent = alloc_alt_odb(get_object_directory());
-	}
-	fakeent->next = the_repository->objects->alt_odb_list;
+	struct object_directory *odb;
 
-	for (alt = fakeent; alt && !ds->ambiguous; alt = alt->next) {
+	for (odb = ds->repo->objects->odb; odb && !ds->ambiguous; odb = odb->next) {
 		int pos;
+		struct oid_array *loose_objects;
 
-		if (!alt->loose_objects_subdir_seen[subdir_nr]) {
-			struct strbuf *buf = alt_scratch_buf(alt);
-			for_each_file_in_obj_subdir(subdir_nr, buf,
-						    append_loose_object,
-						    NULL, NULL,
-						    &alt->loose_objects_cache);
-			alt->loose_objects_subdir_seen[subdir_nr] = 1;
-		}
-
-		pos = oid_array_lookup(&alt->loose_objects_cache, &ds->bin_pfx);
+		loose_objects = odb_loose_cache(odb, &ds->bin_pfx);
+		pos = oid_array_lookup(loose_objects, &ds->bin_pfx);
 		if (pos < 0)
 			pos = -1 - pos;
-		while (!ds->ambiguous && pos < alt->loose_objects_cache.nr) {
+		while (!ds->ambiguous && pos < loose_objects->nr) {
 			const struct object_id *oid;
-			oid = alt->loose_objects_cache.oid + pos;
+			oid = loose_objects->oid + pos;
 			if (!match_sha(ds->len, ds->bin_pfx.hash, oid->hash))
 				break;
 			update_candidates(ds, oid);
@@ -149,12 +125,41 @@ static int match_sha(unsigned len, const
 	return 1;
 }
 
+static void unique_in_midx(struct multi_pack_index *m,
+			   struct disambiguate_state *ds)
+{
+	uint32_t num, i, first = 0;
+	const struct object_id *current = NULL;
+	num = m->num_objects;
+
+	if (!num)
+		return;
+
+	bsearch_midx(&ds->bin_pfx, m, &first);
+
+	/*
+	 * At this point, "first" is the location of the lowest object
+	 * with an object name that could match "bin_pfx".  See if we have
+	 * 0, 1 or more objects that actually match(es).
+	 */
+	for (i = first; i < num && !ds->ambiguous; i++) {
+		struct object_id oid;
+		current = nth_midxed_object_oid(&oid, m, i);
+		if (!match_sha(ds->len, ds->bin_pfx.hash, current->hash))
+			break;
+		update_candidates(ds, current);
+	}
+}
+
 static void unique_in_pack(struct packed_git *p,
 			   struct disambiguate_state *ds)
 {
 	uint32_t num, i, first = 0;
 	const struct object_id *current = NULL;
 
+	if (p->multi_pack_index)
+		return;
+
 	if (open_pack_index(p) || !p->num_objects)
 		return;
 
@@ -177,16 +182,17 @@ static void unique_in_pack(struct packed
 
 static void find_short_packed_object(struct disambiguate_state *ds)
 {
+	struct multi_pack_index *m;
 	struct packed_git *p;
 
-	for (p = get_packed_git(the_repository); p && !ds->ambiguous;
+	for (m = get_multi_pack_index(ds->repo); m && !ds->ambiguous;
+	     m = m->next)
+		unique_in_midx(m, ds);
+	for (p = get_packed_git(ds->repo); p && !ds->ambiguous;
 	     p = p->next)
 		unique_in_pack(p, ds);
 }
 
-#define SHORT_NAME_NOT_FOUND (-1)
-#define SHORT_NAME_AMBIGUOUS (-2)
-
 static int finish_object_disambiguation(struct disambiguate_state *ds,
 					struct object_id *oid)
 {
@@ -194,7 +200,7 @@ static int finish_object_disambiguation(
 		return SHORT_NAME_AMBIGUOUS;
 
 	if (!ds->candidate_exists)
-		return SHORT_NAME_NOT_FOUND;
+		return MISSING_OBJECT;
 
 	if (!ds->candidate_checked)
 		/*
@@ -212,7 +218,7 @@ static int finish_object_disambiguation(
 		 * same repository!
 		 */
 		ds->candidate_ok = (!ds->disambiguate_fn_used ||
-				    ds->fn(&ds->candidate, ds->cb_data));
+				    ds->fn(ds->repo, &ds->candidate, ds->cb_data));
 
 	if (!ds->candidate_ok)
 		return SHORT_NAME_AMBIGUOUS;
@@ -221,57 +227,67 @@ static int finish_object_disambiguation(
 	return 0;
 }
 
-static int disambiguate_commit_only(const struct object_id *oid, void *cb_data_unused)
+static int disambiguate_commit_only(struct repository *r,
+				    const struct object_id *oid,
+				    void *cb_data_unused)
 {
-	int kind = oid_object_info(the_repository, oid, NULL);
+	int kind = oid_object_info(r, oid, NULL);
 	return kind == OBJ_COMMIT;
 }
 
-static int disambiguate_committish_only(const struct object_id *oid, void *cb_data_unused)
+static int disambiguate_committish_only(struct repository *r,
+					const struct object_id *oid,
+					void *cb_data_unused)
 {
 	struct object *obj;
 	int kind;
 
-	kind = oid_object_info(the_repository, oid, NULL);
+	kind = oid_object_info(r, oid, NULL);
 	if (kind == OBJ_COMMIT)
 		return 1;
 	if (kind != OBJ_TAG)
 		return 0;
 
 	/* We need to do this the hard way... */
-	obj = deref_tag(parse_object(oid), NULL, 0);
+	obj = deref_tag(r, parse_object(r, oid), NULL, 0);
 	if (obj && obj->type == OBJ_COMMIT)
 		return 1;
 	return 0;
 }
 
-static int disambiguate_tree_only(const struct object_id *oid, void *cb_data_unused)
+static int disambiguate_tree_only(struct repository *r,
+				  const struct object_id *oid,
+				  void *cb_data_unused)
 {
-	int kind = oid_object_info(the_repository, oid, NULL);
+	int kind = oid_object_info(r, oid, NULL);
 	return kind == OBJ_TREE;
 }
 
-static int disambiguate_treeish_only(const struct object_id *oid, void *cb_data_unused)
+static int disambiguate_treeish_only(struct repository *r,
+				     const struct object_id *oid,
+				     void *cb_data_unused)
 {
 	struct object *obj;
 	int kind;
 
-	kind = oid_object_info(the_repository, oid, NULL);
+	kind = oid_object_info(r, oid, NULL);
 	if (kind == OBJ_TREE || kind == OBJ_COMMIT)
 		return 1;
 	if (kind != OBJ_TAG)
 		return 0;
 
 	/* We need to do this the hard way... */
-	obj = deref_tag(parse_object(oid), NULL, 0);
+	obj = deref_tag(r, parse_object(r, oid), NULL, 0);
 	if (obj && (obj->type == OBJ_TREE || obj->type == OBJ_COMMIT))
 		return 1;
 	return 0;
 }
 
-static int disambiguate_blob_only(const struct object_id *oid, void *cb_data_unused)
+static int disambiguate_blob_only(struct repository *r,
+				  const struct object_id *oid,
+				  void *cb_data_unused)
 {
-	int kind = oid_object_info(the_repository, oid, NULL);
+	int kind = oid_object_info(r, oid, NULL);
 	return kind == OBJ_BLOB;
 }
 
@@ -305,12 +321,13 @@ int set_disambiguate_hint_config(const c
 	return error("unknown hint type for '%s': %s", var, value);
 }
 
-static int init_object_disambiguation(const char *name, int len,
+static int init_object_disambiguation(struct repository *r,
+				      const char *name, int len,
 				      struct disambiguate_state *ds)
 {
 	int i;
 
-	if (len < MINIMUM_ABBREV || len > GIT_SHA1_HEXSZ)
+	if (len < MINIMUM_ABBREV || len > the_hash_algo->hexsz)
 		return -1;
 
 	memset(ds, 0, sizeof(*ds));
@@ -336,7 +353,8 @@ static int init_object_disambiguation(co
 
 	ds->len = len;
 	ds->hex_pfx[len] = '\0';
-	prepare_alt_odb(the_repository);
+	ds->repo = r;
+	prepare_alt_odb(r);
 	return 0;
 }
 
@@ -346,25 +364,25 @@ static int show_ambiguous_object(const s
 	struct strbuf desc = STRBUF_INIT;
 	int type;
 
-	if (ds->fn && !ds->fn(oid, ds->cb_data))
+	if (ds->fn && !ds->fn(ds->repo, oid, ds->cb_data))
 		return 0;
 
-	type = oid_object_info(the_repository, oid, NULL);
+	type = oid_object_info(ds->repo, oid, NULL);
 	if (type == OBJ_COMMIT) {
-		struct commit *commit = lookup_commit(oid);
+		struct commit *commit = lookup_commit(ds->repo, oid);
 		if (commit) {
 			struct pretty_print_context pp = {0};
 			pp.date_mode.type = DATE_SHORT;
 			format_commit_message(commit, " %ad - %s", &desc, &pp);
 		}
 	} else if (type == OBJ_TAG) {
-		struct tag *tag = lookup_tag(oid);
+		struct tag *tag = lookup_tag(ds->repo, oid);
 		if (!parse_tag(tag) && tag->tag)
 			strbuf_addf(&desc, " %s", tag->tag);
 	}
 
 	advise("  %s %s%s",
-	       find_unique_abbrev(oid, DEFAULT_ABBREV),
+	       repo_find_unique_abbrev(ds->repo, oid, DEFAULT_ABBREV),
 	       type_name(type) ? type_name(type) : "unknown type",
 	       desc.buf);
 
@@ -378,10 +396,18 @@ static int collect_ambiguous(const struc
 	return 0;
 }
 
-static int sort_ambiguous(const void *a, const void *b)
+static int repo_collect_ambiguous(struct repository *r,
+				  const struct object_id *oid,
+				  void *data)
+{
+	return collect_ambiguous(oid, data);
+}
+
+static int sort_ambiguous(const void *a, const void *b, void *ctx)
 {
-	int a_type = oid_object_info(the_repository, a, NULL);
-	int b_type = oid_object_info(the_repository, b, NULL);
+	struct repository *sort_ambiguous_repo = ctx;
+	int a_type = oid_object_info(sort_ambiguous_repo, a, NULL);
+	int b_type = oid_object_info(sort_ambiguous_repo, b, NULL);
 	int a_type_sort;
 	int b_type_sort;
 
@@ -406,14 +432,21 @@ static int sort_ambiguous(const void *a,
 	return a_type_sort > b_type_sort ? 1 : -1;
 }
 
-static int get_short_oid(const char *name, int len, struct object_id *oid,
-			  unsigned flags)
+static void sort_ambiguous_oid_array(struct repository *r, struct oid_array *a)
+{
+	QSORT_S(a->oid, a->nr, sort_ambiguous, r);
+}
+
+static enum get_oid_result get_short_oid(struct repository *r,
+					 const char *name, int len,
+					 struct object_id *oid,
+					 unsigned flags)
 {
 	int status;
 	struct disambiguate_state ds;
 	int quietly = !!(flags & GET_OID_QUIETLY);
 
-	if (init_object_disambiguation(name, len, &ds) < 0)
+	if (init_object_disambiguation(r, name, len, &ds) < 0)
 		return -1;
 
 	if (HAS_MULTI_BITS(flags & GET_OID_DISAMBIGUATORS))
@@ -436,6 +469,18 @@ static int get_short_oid(const char *nam
 	find_short_packed_object(&ds);
 	status = finish_object_disambiguation(&ds, oid);
 
+	/*
+	 * If we didn't find it, do the usual reprepare() slow-path,
+	 * since the object may have recently been added to the repository
+	 * or migrated from loose to packed.
+	 */
+	if (status == MISSING_OBJECT) {
+		reprepare_packed_git(r);
+		find_short_object_filename(&ds);
+		find_short_packed_object(&ds);
+		status = finish_object_disambiguation(&ds, oid);
+	}
+
 	if (!quietly && (status == SHORT_NAME_AMBIGUOUS)) {
 		struct oid_array collect = OID_ARRAY_INIT;
 
@@ -451,8 +496,8 @@ static int get_short_oid(const char *nam
 			ds.fn = NULL;
 
 		advise(_("The candidates are:"));
-		for_each_abbrev(ds.hex_pfx, collect_ambiguous, &collect);
-		QSORT(collect.oid, collect.nr, sort_ambiguous);
+		repo_for_each_abbrev(r, ds.hex_pfx, collect_ambiguous, &collect);
+		sort_ambiguous_oid_array(r, &collect);
 
 		if (oid_array_for_each(&collect, show_ambiguous_object, &ds))
 			BUG("show_ambiguous_object shouldn't return non-zero");
@@ -462,17 +507,18 @@ static int get_short_oid(const char *nam
 	return status;
 }
 
-int for_each_abbrev(const char *prefix, each_abbrev_fn fn, void *cb_data)
+int repo_for_each_abbrev(struct repository *r, const char *prefix,
+			 each_abbrev_fn fn, void *cb_data)
 {
 	struct oid_array collect = OID_ARRAY_INIT;
 	struct disambiguate_state ds;
 	int ret;
 
-	if (init_object_disambiguation(prefix, strlen(prefix), &ds) < 0)
+	if (init_object_disambiguation(r, prefix, strlen(prefix), &ds) < 0)
 		return -1;
 
 	ds.always_call_fn = 1;
-	ds.fn = collect_ambiguous;
+	ds.fn = repo_collect_ambiguous;
 	ds.cb_data = &collect;
 	find_short_object_filename(&ds);
 	find_short_packed_object(&ds);
@@ -499,6 +545,7 @@ struct min_abbrev_data {
 	unsigned int init_len;
 	unsigned int cur_len;
 	char *hex;
+	struct repository *repo;
 	const struct object_id *oid;
 };
 
@@ -527,6 +574,49 @@ static int extend_abbrev_len(const struc
 	return 0;
 }
 
+static int repo_extend_abbrev_len(struct repository *r,
+				  const struct object_id *oid,
+				  void *cb_data)
+{
+	return extend_abbrev_len(oid, cb_data);
+}
+
+static void find_abbrev_len_for_midx(struct multi_pack_index *m,
+				     struct min_abbrev_data *mad)
+{
+	int match = 0;
+	uint32_t num, first = 0;
+	struct object_id oid;
+	const struct object_id *mad_oid;
+
+	if (!m->num_objects)
+		return;
+
+	num = m->num_objects;
+	mad_oid = mad->oid;
+	match = bsearch_midx(mad_oid, m, &first);
+
+	/*
+	 * first is now the position in the packfile where we would insert
+	 * mad->hash if it does not exist (or the position of mad->hash if
+	 * it does exist). Hence, we consider a maximum of two objects
+	 * nearby for the abbreviation length.
+	 */
+	mad->init_len = 0;
+	if (!match) {
+		if (nth_midxed_object_oid(&oid, m, first))
+			extend_abbrev_len(&oid, mad);
+	} else if (first < num - 1) {
+		if (nth_midxed_object_oid(&oid, m, first + 1))
+			extend_abbrev_len(&oid, mad);
+	}
+	if (first > 0) {
+		if (nth_midxed_object_oid(&oid, m, first - 1))
+			extend_abbrev_len(&oid, mad);
+	}
+	mad->init_len = mad->cur_len;
+}
+
 static void find_abbrev_len_for_pack(struct packed_git *p,
 				     struct min_abbrev_data *mad)
 {
@@ -535,6 +625,9 @@ static void find_abbrev_len_for_pack(str
 	struct object_id oid;
 	const struct object_id *mad_oid;
 
+	if (p->multi_pack_index)
+		return;
+
 	if (open_pack_index(p) || !p->num_objects)
 		return;
 
@@ -565,19 +658,25 @@ static void find_abbrev_len_for_pack(str
 
 static void find_abbrev_len_packed(struct min_abbrev_data *mad)
 {
+	struct multi_pack_index *m;
 	struct packed_git *p;
 
-	for (p = get_packed_git(the_repository); p; p = p->next)
+	for (m = get_multi_pack_index(mad->repo); m; m = m->next)
+		find_abbrev_len_for_midx(m, mad);
+	for (p = get_packed_git(mad->repo); p; p = p->next)
 		find_abbrev_len_for_pack(p, mad);
 }
 
-int find_unique_abbrev_r(char *hex, const struct object_id *oid, int len)
+int repo_find_unique_abbrev_r(struct repository *r, char *hex,
+			      const struct object_id *oid, int len)
 {
 	struct disambiguate_state ds;
 	struct min_abbrev_data mad;
 	struct object_id oid_ret;
+	const unsigned hexsz = r->hash_algo->hexsz;
+
 	if (len < 0) {
-		unsigned long count = approximate_object_count();
+		unsigned long count = repo_approximate_object_count(r);
 		/*
 		 * Add one because the MSB only tells us the highest bit set,
 		 * not including the value of all the _other_ bits (so "15"
@@ -599,9 +698,10 @@ int find_unique_abbrev_r(char *hex, cons
 	}
 
 	oid_to_hex_r(hex, oid);
-	if (len == GIT_SHA1_HEXSZ || !len)
-		return GIT_SHA1_HEXSZ;
+	if (len == hexsz || !len)
+		return hexsz;
 
+	mad.repo = r;
 	mad.init_len = len;
 	mad.cur_len = len;
 	mad.hex = hex;
@@ -609,10 +709,10 @@ int find_unique_abbrev_r(char *hex, cons
 
 	find_abbrev_len_packed(&mad);
 
-	if (init_object_disambiguation(hex, mad.cur_len, &ds) < 0)
+	if (init_object_disambiguation(r, hex, mad.cur_len, &ds) < 0)
 		return -1;
 
-	ds.fn = extend_abbrev_len;
+	ds.fn = repo_extend_abbrev_len;
 	ds.always_call_fn = 1;
 	ds.cb_data = (void *)&mad;
 
@@ -623,13 +723,15 @@ int find_unique_abbrev_r(char *hex, cons
 	return mad.cur_len;
 }
 
-const char *find_unique_abbrev(const struct object_id *oid, int len)
+const char *repo_find_unique_abbrev(struct repository *r,
+				    const struct object_id *oid,
+				    int len)
 {
 	static int bufno;
 	static char hexbuffer[4][GIT_MAX_HEXSZ + 1];
 	char *hex = hexbuffer[bufno];
 	bufno = (bufno + 1) % ARRAY_SIZE(hexbuffer);
-	find_unique_abbrev_r(hex, oid, len);
+	repo_find_unique_abbrev_r(r, hex, oid, len);
 	return hex;
 }
 
@@ -684,11 +786,11 @@ static inline int push_mark(const char *
 	return at_mark(string, len, suffix, ARRAY_SIZE(suffix));
 }
 
-static int get_oid_1(const char *name, int len, struct object_id *oid, unsigned lookup_flags);
-static int interpret_nth_prior_checkout(const char *name, int namelen, struct strbuf *buf);
+static enum get_oid_result get_oid_1(struct repository *r, const char *name, int len, struct object_id *oid, unsigned lookup_flags);
+static int interpret_nth_prior_checkout(struct repository *r, const char *name, int namelen, struct strbuf *buf);
 
-static int get_oid_basic(const char *str, int len, struct object_id *oid,
-			  unsigned int flags)
+static int get_oid_basic(struct repository *r, const char *str, int len,
+			 struct object_id *oid, unsigned int flags)
 {
 	static const char *warn_msg = "refname '%.*s' is ambiguous.";
 	static const char *object_name_msg = N_(
@@ -696,7 +798,7 @@ static int get_oid_basic(const char *str
 	"because it will be ignored when you just specify 40-hex. These refs\n"
 	"may be created by mistake. For example,\n"
 	"\n"
-	"  git checkout -b $br $(git rev-parse ...)\n"
+	"  git switch -c $br $(git rev-parse ...)\n"
 	"\n"
 	"where \"$br\" is somehow empty and a 40-hex ref is created. Please\n"
 	"examine these refs and maybe delete them. Turn this message off by\n"
@@ -706,9 +808,9 @@ static int get_oid_basic(const char *str
 	int refs_found = 0;
 	int at, reflog_len, nth_prior = 0;
 
-	if (len == GIT_SHA1_HEXSZ && !get_oid_hex(str, oid)) {
+	if (len == r->hash_algo->hexsz && !get_oid_hex(str, oid)) {
 		if (warn_ambiguous_refs && warn_on_object_refname_ambiguity) {
-			refs_found = dwim_ref(str, len, &tmp_oid, &real_ref);
+			refs_found = repo_dwim_ref(r, str, len, &tmp_oid, &real_ref);
 			if (refs_found > 0) {
 				warning(warn_msg, len, str);
 				if (advice_object_name_warning)
@@ -749,8 +851,8 @@ static int get_oid_basic(const char *str
 		struct strbuf buf = STRBUF_INIT;
 		int detached;
 
-		if (interpret_nth_prior_checkout(str, len, &buf) > 0) {
-			detached = (buf.len == GIT_SHA1_HEXSZ && !get_oid_hex(buf.buf, oid));
+		if (interpret_nth_prior_checkout(r, str, len, &buf) > 0) {
+			detached = (buf.len == r->hash_algo->hexsz && !get_oid_hex(buf.buf, oid));
 			strbuf_release(&buf);
 			if (detached)
 				return 0;
@@ -759,18 +861,18 @@ static int get_oid_basic(const char *str
 
 	if (!len && reflog_len)
 		/* allow "@{...}" to mean the current branch reflog */
-		refs_found = dwim_ref("HEAD", 4, oid, &real_ref);
+		refs_found = repo_dwim_ref(r, "HEAD", 4, oid, &real_ref);
 	else if (reflog_len)
-		refs_found = dwim_log(str, len, oid, &real_ref);
+		refs_found = repo_dwim_log(r, str, len, oid, &real_ref);
 	else
-		refs_found = dwim_ref(str, len, oid, &real_ref);
+		refs_found = repo_dwim_ref(r, str, len, oid, &real_ref);
 
 	if (!refs_found)
 		return -1;
 
 	if (warn_ambiguous_refs && !(flags & GET_OID_QUIETLY) &&
 	    (refs_found > 1 ||
-	     !get_short_oid(str, len, &tmp_oid, GET_OID_QUIETLY)))
+	     !get_short_oid(r, str, len, &tmp_oid, GET_OID_QUIETLY)))
 		warning(warn_msg, len, str);
 
 	if (reflog_len) {
@@ -802,7 +904,8 @@ static int get_oid_basic(const char *str
 				return -1;
 			}
 		}
-		if (read_ref_at(real_ref, flags, at_time, nth, oid, NULL,
+		if (read_ref_at(get_main_ref_store(r),
+				real_ref, flags, at_time, nth, oid, NULL,
 				&co_time, &co_tz, &co_cnt)) {
 			if (!len) {
 				if (starts_with(real_ref, "refs/heads/")) {
@@ -834,71 +937,75 @@ static int get_oid_basic(const char *str
 	return 0;
 }
 
-static int get_parent(const char *name, int len,
-		      struct object_id *result, int idx)
+static enum get_oid_result get_parent(struct repository *r,
+				      const char *name, int len,
+				      struct object_id *result, int idx)
 {
 	struct object_id oid;
-	int ret = get_oid_1(name, len, &oid, GET_OID_COMMITTISH);
+	enum get_oid_result ret = get_oid_1(r, name, len, &oid,
+					    GET_OID_COMMITTISH);
 	struct commit *commit;
 	struct commit_list *p;
 
 	if (ret)
 		return ret;
-	commit = lookup_commit_reference(&oid);
+	commit = lookup_commit_reference(r, &oid);
 	if (parse_commit(commit))
-		return -1;
+		return MISSING_OBJECT;
 	if (!idx) {
 		oidcpy(result, &commit->object.oid);
-		return 0;
+		return FOUND;
 	}
 	p = commit->parents;
 	while (p) {
 		if (!--idx) {
 			oidcpy(result, &p->item->object.oid);
-			return 0;
+			return FOUND;
 		}
 		p = p->next;
 	}
-	return -1;
+	return MISSING_OBJECT;
 }
 
-static int get_nth_ancestor(const char *name, int len,
-			    struct object_id *result, int generation)
+static enum get_oid_result get_nth_ancestor(struct repository *r,
+					    const char *name, int len,
+					    struct object_id *result,
+					    int generation)
 {
 	struct object_id oid;
 	struct commit *commit;
 	int ret;
 
-	ret = get_oid_1(name, len, &oid, GET_OID_COMMITTISH);
+	ret = get_oid_1(r, name, len, &oid, GET_OID_COMMITTISH);
 	if (ret)
 		return ret;
-	commit = lookup_commit_reference(&oid);
+	commit = lookup_commit_reference(r, &oid);
 	if (!commit)
-		return -1;
+		return MISSING_OBJECT;
 
 	while (generation--) {
 		if (parse_commit(commit) || !commit->parents)
-			return -1;
+			return MISSING_OBJECT;
 		commit = commit->parents->item;
 	}
 	oidcpy(result, &commit->object.oid);
-	return 0;
+	return FOUND;
 }
 
-struct object *peel_to_type(const char *name, int namelen,
-			    struct object *o, enum object_type expected_type)
+struct object *repo_peel_to_type(struct repository *r, const char *name, int namelen,
+				 struct object *o, enum object_type expected_type)
 {
 	if (name && !namelen)
 		namelen = strlen(name);
 	while (1) {
-		if (!o || (!o->parsed && !parse_object(&o->oid)))
+		if (!o || (!o->parsed && !parse_object(r, &o->oid)))
 			return NULL;
 		if (expected_type == OBJ_ANY || o->type == expected_type)
 			return o;
 		if (o->type == OBJ_TAG)
 			o = ((struct tag*) o)->tagged;
 		else if (o->type == OBJ_COMMIT)
-			o = &(get_commit_tree(((struct commit *)o))->object);
+			o = &(repo_get_commit_tree(r, ((struct commit *)o))->object);
 		else {
 			if (name)
 				error("%.*s: expected %s type, but the object "
@@ -910,8 +1017,8 @@ struct object *peel_to_type(const char *
 	}
 }
 
-static int peel_onion(const char *name, int len, struct object_id *oid,
-		      unsigned lookup_flags)
+static int peel_onion(struct repository *r, const char *name, int len,
+		      struct object_id *oid, unsigned lookup_flags)
 {
 	struct object_id outer;
 	const char *sp;
@@ -961,15 +1068,15 @@ static int peel_onion(const char *name,
 	else if (expected_type == OBJ_TREE)
 		lookup_flags |= GET_OID_TREEISH;
 
-	if (get_oid_1(name, sp - name - 2, &outer, lookup_flags))
+	if (get_oid_1(r, name, sp - name - 2, &outer, lookup_flags))
 		return -1;
 
-	o = parse_object(&outer);
+	o = parse_object(r, &outer);
 	if (!o)
 		return -1;
 	if (!expected_type) {
-		o = deref_tag(o, name, sp - name - 2);
-		if (!o || (!o->parsed && !parse_object(&o->oid)))
+		o = deref_tag(r, o, name, sp - name - 2);
+		if (!o || (!o->parsed && !parse_object(r, &o->oid)))
 			return -1;
 		oidcpy(oid, &o->oid);
 		return 0;
@@ -980,7 +1087,7 @@ static int peel_onion(const char *name,
 	 * if we do not get the needed object, we should
 	 * barf.
 	 */
-	o = peel_to_type(name, len, o, expected_type);
+	o = repo_peel_to_type(r, name, len, o, expected_type);
 	if (!o)
 		return -1;
 
@@ -1000,14 +1107,16 @@ static int peel_onion(const char *name,
 
 		prefix = xstrndup(sp + 1, name + len - 1 - (sp + 1));
 		commit_list_insert((struct commit *)o, &list);
-		ret = get_oid_oneline(prefix, oid, list);
+		ret = get_oid_oneline(r, prefix, oid, list);
 		free(prefix);
 		return ret;
 	}
 	return 0;
 }
 
-static int get_describe_name(const char *name, int len, struct object_id *oid)
+static int get_describe_name(struct repository *r,
+			     const char *name, int len,
+			     struct object_id *oid)
 {
 	const char *cp;
 	unsigned flags = GET_OID_QUIETLY | GET_OID_COMMIT;
@@ -1021,14 +1130,18 @@ static int get_describe_name(const char
 			if (ch == 'g' && cp[-1] == '-') {
 				cp++;
 				len -= cp - name;
-				return get_short_oid(cp, len, oid, flags);
+				return get_short_oid(r,
+						     cp, len, oid, flags);
 			}
 		}
 	}
 	return -1;
 }
 
-static int get_oid_1(const char *name, int len, struct object_id *oid, unsigned lookup_flags)
+static enum get_oid_result get_oid_1(struct repository *r,
+				     const char *name, int len,
+				     struct object_id *oid,
+				     unsigned lookup_flags)
 {
 	int ret, has_suffix;
 	const char *cp;
@@ -1047,33 +1160,42 @@ static int get_oid_1(const char *name, i
 	}
 
 	if (has_suffix) {
-		int num = 0;
+		unsigned int num = 0;
 		int len1 = cp - name;
 		cp++;
-		while (cp < name + len)
-			num = num * 10 + *cp++ - '0';
+		while (cp < name + len) {
+			unsigned int digit = *cp++ - '0';
+			if (unsigned_mult_overflows(num, 10))
+				return MISSING_OBJECT;
+			num *= 10;
+			if (unsigned_add_overflows(num, digit))
+				return MISSING_OBJECT;
+			num += digit;
+		}
 		if (!num && len1 == len - 1)
 			num = 1;
+		else if (num > INT_MAX)
+			return MISSING_OBJECT;
 		if (has_suffix == '^')
-			return get_parent(name, len1, oid, num);
+			return get_parent(r, name, len1, oid, num);
 		/* else if (has_suffix == '~') -- goes without saying */
-		return get_nth_ancestor(name, len1, oid, num);
+		return get_nth_ancestor(r, name, len1, oid, num);
 	}
 
-	ret = peel_onion(name, len, oid, lookup_flags);
+	ret = peel_onion(r, name, len, oid, lookup_flags);
 	if (!ret)
-		return 0;
+		return FOUND;
 
-	ret = get_oid_basic(name, len, oid, lookup_flags);
+	ret = get_oid_basic(r, name, len, oid, lookup_flags);
 	if (!ret)
-		return 0;
+		return FOUND;
 
 	/* It could be describe output that is "SOMETHING-gXXXX" */
-	ret = get_describe_name(name, len, oid);
+	ret = get_describe_name(r, name, len, oid);
 	if (!ret)
-		return 0;
+		return FOUND;
 
-	return get_short_oid(name, len, oid, lookup_flags);
+	return get_short_oid(r, name, len, oid, lookup_flags);
 }
 
 /*
@@ -1092,15 +1214,22 @@ static int get_oid_1(const char *name, i
 /* Remember to update object flag allocation in object.h */
 #define ONELINE_SEEN (1u<<20)
 
+struct handle_one_ref_cb {
+	struct repository *repo;
+	struct commit_list **list;
+};
+
 static int handle_one_ref(const char *path, const struct object_id *oid,
 			  int flag, void *cb_data)
 {
-	struct commit_list **list = cb_data;
-	struct object *object = parse_object(oid);
+	struct handle_one_ref_cb *cb = cb_data;
+	struct commit_list **list = cb->list;
+	struct object *object = parse_object(cb->repo, oid);
 	if (!object)
 		return 0;
 	if (object->type == OBJ_TAG) {
-		object = deref_tag(object, path, strlen(path));
+		object = deref_tag(cb->repo, object, path,
+				   strlen(path));
 		if (!object)
 			return 0;
 	}
@@ -1110,8 +1239,9 @@ static int handle_one_ref(const char *pa
 	return 0;
 }
 
-static int get_oid_oneline(const char *prefix, struct object_id *oid,
-			    struct commit_list *list)
+static int get_oid_oneline(struct repository *r,
+			   const char *prefix, struct object_id *oid,
+			   struct commit_list *list)
 {
 	struct commit_list *backup = NULL, *l;
 	int found = 0;
@@ -1142,7 +1272,7 @@ static int get_oid_oneline(const char *p
 		int matches;
 
 		commit = pop_most_recent_commit(&list, ONELINE_SEEN);
-		if (!parse_object(&commit->object.oid))
+		if (!parse_object(r, &commit->object.oid))
 			continue;
 		buf = get_commit_buffer(commit, NULL);
 		p = strstr(buf, "\n\n");
@@ -1165,7 +1295,7 @@ static int get_oid_oneline(const char *p
 
 struct grab_nth_branch_switch_cbdata {
 	int remaining;
-	struct strbuf buf;
+	struct strbuf *sb;
 };
 
 static int grab_nth_branch_switch(struct object_id *ooid, struct object_id *noid,
@@ -1183,8 +1313,8 @@ static int grab_nth_branch_switch(struct
 		return 0;
 	if (--(cb->remaining) == 0) {
 		len = target - match;
-		strbuf_reset(&cb->buf);
-		strbuf_add(&cb->buf, match, len);
+		strbuf_reset(cb->sb);
+		strbuf_add(cb->sb, match, len);
 		return 1; /* we are done */
 	}
 	return 0;
@@ -1194,7 +1324,8 @@ static int grab_nth_branch_switch(struct
  * Parse @{-N} syntax, return the number of characters parsed
  * if successful; otherwise signal an error with negative value.
  */
-static int interpret_nth_prior_checkout(const char *name, int namelen,
+static int interpret_nth_prior_checkout(struct repository *r,
+					const char *name, int namelen,
 					struct strbuf *buf)
 {
 	long nth;
@@ -1216,20 +1347,21 @@ static int interpret_nth_prior_checkout(
 	if (nth <= 0)
 		return -1;
 	cb.remaining = nth;
-	strbuf_init(&cb.buf, 20);
+	cb.sb = buf;
 
-	retval = 0;
-	if (0 < for_each_reflog_ent_reverse("HEAD", grab_nth_branch_switch, &cb)) {
-		strbuf_reset(buf);
-		strbuf_addbuf(buf, &cb.buf);
+	retval = refs_for_each_reflog_ent_reverse(get_main_ref_store(r),
+			"HEAD", grab_nth_branch_switch, &cb);
+	if (0 < retval) {
 		retval = brace - name + 1;
-	}
+	} else
+		retval = 0;
 
-	strbuf_release(&cb.buf);
 	return retval;
 }
 
-int get_oid_mb(const char *name, struct object_id *oid)
+int repo_get_oid_mb(struct repository *r,
+		    const char *name,
+		    struct object_id *oid)
 {
 	struct commit *one, *two;
 	struct commit_list *mbs;
@@ -1239,28 +1371,28 @@ int get_oid_mb(const char *name, struct
 
 	dots = strstr(name, "...");
 	if (!dots)
-		return get_oid(name, oid);
+		return repo_get_oid(r, name, oid);
 	if (dots == name)
-		st = get_oid("HEAD", &oid_tmp);
+		st = repo_get_oid(r, "HEAD", &oid_tmp);
 	else {
 		struct strbuf sb;
 		strbuf_init(&sb, dots - name);
 		strbuf_add(&sb, name, dots - name);
-		st = get_oid_committish(sb.buf, &oid_tmp);
+		st = repo_get_oid_committish(r, sb.buf, &oid_tmp);
 		strbuf_release(&sb);
 	}
 	if (st)
 		return st;
-	one = lookup_commit_reference_gently(&oid_tmp, 0);
+	one = lookup_commit_reference_gently(r, &oid_tmp, 0);
 	if (!one)
 		return -1;
 
-	if (get_oid_committish(dots[3] ? (dots + 3) : "HEAD", &oid_tmp))
+	if (repo_get_oid_committish(r, dots[3] ? (dots + 3) : "HEAD", &oid_tmp))
 		return -1;
-	two = lookup_commit_reference_gently(&oid_tmp, 0);
+	two = lookup_commit_reference_gently(r, &oid_tmp, 0);
 	if (!two)
 		return -1;
-	mbs = get_merge_bases(one, two);
+	mbs = repo_get_merge_bases(r, one, two);
 	if (!mbs || mbs->next)
 		st = -1;
 	else {
@@ -1293,7 +1425,8 @@ static int interpret_empty_at(const char
 	return 1;
 }
 
-static int reinterpret(const char *name, int namelen, int len,
+static int reinterpret(struct repository *r,
+		       const char *name, int namelen, int len,
 		       struct strbuf *buf, unsigned allowed)
 {
 	/* we have extra data, which might need further processing */
@@ -1302,7 +1435,7 @@ static int reinterpret(const char *name,
 	int ret;
 
 	strbuf_add(buf, name + len, namelen - len);
-	ret = interpret_branch_name(buf->buf, buf->len, &tmp, allowed);
+	ret = repo_interpret_branch_name(r, buf->buf, buf->len, &tmp, allowed);
 	/* that data was not interpreted, remove our cruft */
 	if (ret < 0) {
 		strbuf_setlen(buf, used);
@@ -1315,9 +1448,9 @@ static int reinterpret(const char *name,
 	return ret - used + len;
 }
 
-static void set_shortened_ref(struct strbuf *buf, const char *ref)
+static void set_shortened_ref(struct repository *r, struct strbuf *buf, const char *ref)
 {
-	char *s = shorten_unambiguous_ref(ref, 0);
+	char *s = refs_shorten_unambiguous_ref(get_main_ref_store(r), ref, 0);
 	strbuf_reset(buf);
 	strbuf_addstr(buf, s);
 	free(s);
@@ -1338,7 +1471,8 @@ static int branch_interpret_allowed(cons
 	return 0;
 }
 
-static int interpret_branch_mark(const char *name, int namelen,
+static int interpret_branch_mark(struct repository *r,
+				 const char *name, int namelen,
 				 int at, struct strbuf *buf,
 				 int (*get_mark)(const char *, int),
 				 const char *(*get_data)(struct branch *,
@@ -1371,12 +1505,14 @@ static int interpret_branch_mark(const c
 	if (!branch_interpret_allowed(value, allowed))
 		return -1;
 
-	set_shortened_ref(buf, value);
+	set_shortened_ref(r, buf, value);
 	return len + at;
 }
 
-int interpret_branch_name(const char *name, int namelen, struct strbuf *buf,
-			  unsigned allowed)
+int repo_interpret_branch_name(struct repository *r,
+			       const char *name, int namelen,
+			       struct strbuf *buf,
+			       unsigned allowed)
 {
 	char *at;
 	const char *start;
@@ -1386,14 +1522,14 @@ int interpret_branch_name(const char *na
 		namelen = strlen(name);
 
 	if (!allowed || (allowed & INTERPRET_BRANCH_LOCAL)) {
-		len = interpret_nth_prior_checkout(name, namelen, buf);
+		len = interpret_nth_prior_checkout(r, name, namelen, buf);
 		if (!len) {
 			return len; /* syntax Ok, not enough switches */
 		} else if (len > 0) {
 			if (len == namelen)
 				return len; /* consumed all */
 			else
-				return reinterpret(name, namelen, len, buf, allowed);
+				return reinterpret(r, name, namelen, len, buf, allowed);
 		}
 	}
 
@@ -1404,17 +1540,17 @@ int interpret_branch_name(const char *na
 		if (!allowed || (allowed & INTERPRET_BRANCH_HEAD)) {
 			len = interpret_empty_at(name, namelen, at - name, buf);
 			if (len > 0)
-				return reinterpret(name, namelen, len, buf,
+				return reinterpret(r, name, namelen, len, buf,
 						   allowed);
 		}
 
-		len = interpret_branch_mark(name, namelen, at - name, buf,
+		len = interpret_branch_mark(r, name, namelen, at - name, buf,
 					    upstream_mark, branch_get_upstream,
 					    allowed);
 		if (len > 0)
 			return len;
 
-		len = interpret_branch_mark(name, namelen, at - name, buf,
+		len = interpret_branch_mark(r, name, namelen, at - name, buf,
 					    push_mark, branch_get_push,
 					    allowed);
 		if (len > 0)
@@ -1460,12 +1596,31 @@ int strbuf_check_branch_ref(struct strbu
  * This is like "get_oid_basic()", except it allows "object ID expressions",
  * notably "xyz^" for "parent of xyz"
  */
-int get_oid(const char *name, struct object_id *oid)
+int repo_get_oid(struct repository *r, const char *name, struct object_id *oid)
 {
 	struct object_context unused;
-	return get_oid_with_context(name, 0, oid, &unused);
+	return get_oid_with_context(r, name, 0, oid, &unused);
 }
 
+/*
+ * This returns a non-zero value if the string (built using printf
+ * format and the given arguments) is not a valid object.
+ */
+int get_oidf(struct object_id *oid, const char *fmt, ...)
+{
+	va_list ap;
+	int ret;
+	struct strbuf sb = STRBUF_INIT;
+
+	va_start(ap, fmt);
+	strbuf_vaddf(&sb, fmt, ap);
+	va_end(ap);
+
+	ret = get_oid(sb.buf, oid);
+	strbuf_release(&sb);
+
+	return ret;
+}
 
 /*
  * Many callers know that the user meant to name a commit-ish by
@@ -1477,50 +1632,61 @@ int get_oid(const char *name, struct obj
  * commit-ish. It is merely to give a hint to the disambiguation
  * machinery.
  */
-int get_oid_committish(const char *name, struct object_id *oid)
+int repo_get_oid_committish(struct repository *r,
+			    const char *name,
+			    struct object_id *oid)
 {
 	struct object_context unused;
-	return get_oid_with_context(name, GET_OID_COMMITTISH,
+	return get_oid_with_context(r, name, GET_OID_COMMITTISH,
 				    oid, &unused);
 }
 
-int get_oid_treeish(const char *name, struct object_id *oid)
+int repo_get_oid_treeish(struct repository *r,
+			 const char *name,
+			 struct object_id *oid)
 {
 	struct object_context unused;
-	return get_oid_with_context(name, GET_OID_TREEISH,
+	return get_oid_with_context(r, name, GET_OID_TREEISH,
 				    oid, &unused);
 }
 
-int get_oid_commit(const char *name, struct object_id *oid)
+int repo_get_oid_commit(struct repository *r,
+			const char *name,
+			struct object_id *oid)
 {
 	struct object_context unused;
-	return get_oid_with_context(name, GET_OID_COMMIT,
+	return get_oid_with_context(r, name, GET_OID_COMMIT,
 				    oid, &unused);
 }
 
-int get_oid_tree(const char *name, struct object_id *oid)
+int repo_get_oid_tree(struct repository *r,
+		      const char *name,
+		      struct object_id *oid)
 {
 	struct object_context unused;
-	return get_oid_with_context(name, GET_OID_TREE,
+	return get_oid_with_context(r, name, GET_OID_TREE,
 				    oid, &unused);
 }
 
-int get_oid_blob(const char *name, struct object_id *oid)
+int repo_get_oid_blob(struct repository *r,
+		      const char *name,
+		      struct object_id *oid)
 {
 	struct object_context unused;
-	return get_oid_with_context(name, GET_OID_BLOB,
+	return get_oid_with_context(r, name, GET_OID_BLOB,
 				    oid, &unused);
 }
 
 /* Must be called only when object_name:filename doesn't exist. */
-static void diagnose_invalid_oid_path(const char *prefix,
+static void diagnose_invalid_oid_path(struct repository *r,
+				      const char *prefix,
 				      const char *filename,
 				      const struct object_id *tree_oid,
 				      const char *object_name,
 				      int object_name_len)
 {
 	struct object_id oid;
-	unsigned mode;
+	unsigned short mode;
 
 	if (!prefix)
 		prefix = "";
@@ -1531,7 +1697,7 @@ static void diagnose_invalid_oid_path(co
 	if (is_missing_file_error(errno)) {
 		char *fullname = xstrfmt("%s%s", prefix, filename);
 
-		if (!get_tree_entry(tree_oid, fullname, &oid, &mode)) {
+		if (!get_tree_entry(r, tree_oid, fullname, &oid, &mode)) {
 			die("Path '%s' exists, but not '%s'.\n"
 			    "Did you mean '%.*s:%s' aka '%.*s:./%s'?",
 			    fullname,
@@ -1547,10 +1713,12 @@ static void diagnose_invalid_oid_path(co
 }
 
 /* Must be called only when :stage:filename doesn't exist. */
-static void diagnose_invalid_index_path(int stage,
+static void diagnose_invalid_index_path(struct repository *r,
+					int stage,
 					const char *prefix,
 					const char *filename)
 {
+	struct index_state *istate = r->index;
 	const struct cache_entry *ce;
 	int pos;
 	unsigned namelen = strlen(filename);
@@ -1560,11 +1728,11 @@ static void diagnose_invalid_index_path(
 		prefix = "";
 
 	/* Wrong stage number? */
-	pos = cache_name_pos(filename, namelen);
+	pos = index_name_pos(istate, filename, namelen);
 	if (pos < 0)
 		pos = -pos - 1;
-	if (pos < active_nr) {
-		ce = active_cache[pos];
+	if (pos < istate->cache_nr) {
+		ce = istate->cache[pos];
 		if (ce_namelen(ce) == namelen &&
 		    !memcmp(ce->name, filename, namelen))
 			die("Path '%s' is in the index, but not at stage %d.\n"
@@ -1576,11 +1744,11 @@ static void diagnose_invalid_index_path(
 	/* Confusion between relative and absolute filenames? */
 	strbuf_addstr(&fullname, prefix);
 	strbuf_addstr(&fullname, filename);
-	pos = cache_name_pos(fullname.buf, fullname.len);
+	pos = index_name_pos(istate, fullname.buf, fullname.len);
 	if (pos < 0)
 		pos = -pos - 1;
-	if (pos < active_nr) {
-		ce = active_cache[pos];
+	if (pos < istate->cache_nr) {
+		ce = istate->cache[pos];
 		if (ce_namelen(ce) == fullname.len &&
 		    !memcmp(ce->name, fullname.buf, fullname.len))
 			die("Path '%s' is in the index, but not '%s'.\n"
@@ -1590,7 +1758,7 @@ static void diagnose_invalid_index_path(
 			    ce_stage(ce), filename);
 	}
 
-	if (file_exists(filename))
+	if (repo_file_exists(r, filename))
 		die("Path '%s' exists on disk, but not in the index.", filename);
 	if (is_missing_file_error(errno))
 		die("Path '%s' does not exist (neither on disk nor in the index).",
@@ -1600,12 +1768,12 @@ static void diagnose_invalid_index_path(
 }
 
 
-static char *resolve_relative_path(const char *rel)
+static char *resolve_relative_path(struct repository *r, const char *rel)
 {
 	if (!starts_with(rel, "./") && !starts_with(rel, "../"))
 		return NULL;
 
-	if (!is_inside_work_tree())
+	if (r != the_repository || !is_inside_work_tree())
 		die("relative path syntax can't be used outside working tree.");
 
 	/* die() inside prefix_path() if resolved path is outside worktree */
@@ -1614,7 +1782,8 @@ static char *resolve_relative_path(const
 			   rel);
 }
 
-static int get_oid_with_context_1(const char *name,
+static enum get_oid_result get_oid_with_context_1(struct repository *repo,
+				  const char *name,
 				  unsigned flags,
 				  const char *prefix,
 				  struct object_id *oid,
@@ -1631,7 +1800,7 @@ static int get_oid_with_context_1(const
 	memset(oc, 0, sizeof(*oc));
 	oc->mode = S_IFINVALID;
 	strbuf_init(&oc->symlink_path, 0);
-	ret = get_oid_1(name, namelen, oid, flags);
+	ret = get_oid_1(repo, name, namelen, oid, flags);
 	if (!ret)
 		return ret;
 	/*
@@ -1647,11 +1816,15 @@ static int get_oid_with_context_1(const
 		char *new_path = NULL;
 		int pos;
 		if (!only_to_die && namelen > 2 && name[1] == '/') {
+			struct handle_one_ref_cb cb;
 			struct commit_list *list = NULL;
 
-			for_each_ref(handle_one_ref, &list);
+			cb.repo = repo;
+			cb.list = &list;
+			refs_for_each_ref(repo->refs, handle_one_ref, &cb);
+			refs_head_ref(repo->refs, handle_one_ref, &cb);
 			commit_list_sort_by_date(&list);
-			return get_oid_oneline(name + 2, oid, list);
+			return get_oid_oneline(repo, name + 2, oid, list);
 		}
 		if (namelen < 3 ||
 		    name[2] != ':' ||
@@ -1661,7 +1834,7 @@ static int get_oid_with_context_1(const
 			stage = name[1] - '0';
 			cp = name + 3;
 		}
-		new_path = resolve_relative_path(cp);
+		new_path = resolve_relative_path(repo, cp);
 		if (!new_path) {
 			namelen = namelen - (cp - name);
 		} else {
@@ -1672,13 +1845,13 @@ static int get_oid_with_context_1(const
 		if (flags & GET_OID_RECORD_PATH)
 			oc->path = xstrdup(cp);
 
-		if (!active_cache)
-			read_cache();
-		pos = cache_name_pos(cp, namelen);
+		if (!repo->index || !repo->index->cache)
+			repo_read_index(repo);
+		pos = index_name_pos(repo->index, cp, namelen);
 		if (pos < 0)
 			pos = -pos - 1;
-		while (pos < active_nr) {
-			ce = active_cache[pos];
+		while (pos < repo->index->cache_nr) {
+			ce = repo->index->cache[pos];
 			if (ce_namelen(ce) != namelen ||
 			    memcmp(ce->name, cp, namelen))
 				break;
@@ -1691,7 +1864,7 @@ static int get_oid_with_context_1(const
 			pos++;
 		}
 		if (only_to_die && name[1] && name[1] != '/')
-			diagnose_invalid_index_path(stage, prefix, cp);
+			diagnose_invalid_index_path(repo, stage, prefix, cp);
 		free(new_path);
 		return -1;
 	}
@@ -1711,22 +1884,22 @@ static int get_oid_with_context_1(const
 		sub_flags &= ~GET_OID_DISAMBIGUATORS;
 		sub_flags |= GET_OID_TREEISH;
 
-		if (!get_oid_1(name, len, &tree_oid, sub_flags)) {
+		if (!get_oid_1(repo, name, len, &tree_oid, sub_flags)) {
 			const char *filename = cp+1;
 			char *new_filename = NULL;
 
-			new_filename = resolve_relative_path(filename);
+			new_filename = resolve_relative_path(repo, filename);
 			if (new_filename)
 				filename = new_filename;
 			if (flags & GET_OID_FOLLOW_SYMLINKS) {
-				ret = get_tree_entry_follow_symlinks(&tree_oid,
+				ret = get_tree_entry_follow_symlinks(repo, &tree_oid,
 					filename, oid, &oc->symlink_path,
 					&oc->mode);
 			} else {
-				ret = get_tree_entry(&tree_oid, filename, oid,
+				ret = get_tree_entry(repo, &tree_oid, filename, oid,
 						     &oc->mode);
 				if (ret && only_to_die) {
-					diagnose_invalid_oid_path(prefix,
+					diagnose_invalid_oid_path(repo, prefix,
 								   filename,
 								   &tree_oid,
 								   name, len);
@@ -1752,16 +1925,23 @@ static int get_oid_with_context_1(const
  * exist in 'HEAD'" when given "HEAD:doc", or it may return in which case
  * you have a chance to diagnose the error further.
  */
-void maybe_die_on_misspelt_object_name(const char *name, const char *prefix)
+void maybe_die_on_misspelt_object_name(struct repository *r,
+				       const char *name,
+				       const char *prefix)
 {
 	struct object_context oc;
 	struct object_id oid;
-	get_oid_with_context_1(name, GET_OID_ONLY_TO_DIE, prefix, &oid, &oc);
+	get_oid_with_context_1(r, name, GET_OID_ONLY_TO_DIE,
+			       prefix, &oid, &oc);
 }
 
-int get_oid_with_context(const char *str, unsigned flags, struct object_id *oid, struct object_context *oc)
+enum get_oid_result get_oid_with_context(struct repository *repo,
+					 const char *str,
+					 unsigned flags,
+					 struct object_id *oid,
+					 struct object_context *oc)
 {
 	if (flags & GET_OID_FOLLOW_SYMLINKS && flags & GET_OID_ONLY_TO_DIE)
 		BUG("incompatible flags for get_sha1_with_context");
-	return get_oid_with_context_1(str, flags, NULL, oid, oc);
+	return get_oid_with_context_1(repo, str, flags, NULL, oid, oc);
 }
diff -pruN 1.2.1+git2.18.0-1/git/sha256/block/sha256.c 1.2.3+git2.25.1-1/git/sha256/block/sha256.c
--- 1.2.1+git2.18.0-1/git/sha256/block/sha256.c	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/sha256/block/sha256.c	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,196 @@
+#include "git-compat-util.h"
+#include "./sha256.h"
+
+#undef RND
+#undef BLKSIZE
+
+#define BLKSIZE blk_SHA256_BLKSIZE
+
+void blk_SHA256_Init(blk_SHA256_CTX *ctx)
+{
+	ctx->offset = 0;
+	ctx->size = 0;
+	ctx->state[0] = 0x6a09e667ul;
+	ctx->state[1] = 0xbb67ae85ul;
+	ctx->state[2] = 0x3c6ef372ul;
+	ctx->state[3] = 0xa54ff53aul;
+	ctx->state[4] = 0x510e527ful;
+	ctx->state[5] = 0x9b05688cul;
+	ctx->state[6] = 0x1f83d9abul;
+	ctx->state[7] = 0x5be0cd19ul;
+}
+
+static inline uint32_t ror(uint32_t x, unsigned n)
+{
+	return (x >> n) | (x << (32 - n));
+}
+
+static inline uint32_t ch(uint32_t x, uint32_t y, uint32_t z)
+{
+	return z ^ (x & (y ^ z));
+}
+
+static inline uint32_t maj(uint32_t x, uint32_t y, uint32_t z)
+{
+	return ((x | y) & z) | (x & y);
+}
+
+static inline uint32_t sigma0(uint32_t x)
+{
+	return ror(x, 2) ^ ror(x, 13) ^ ror(x, 22);
+}
+
+static inline uint32_t sigma1(uint32_t x)
+{
+	return ror(x, 6) ^ ror(x, 11) ^ ror(x, 25);
+}
+
+static inline uint32_t gamma0(uint32_t x)
+{
+	return ror(x, 7) ^ ror(x, 18) ^ (x >> 3);
+}
+
+static inline uint32_t gamma1(uint32_t x)
+{
+	return ror(x, 17) ^ ror(x, 19) ^ (x >> 10);
+}
+
+static void blk_SHA256_Transform(blk_SHA256_CTX *ctx, const unsigned char *buf)
+{
+
+	uint32_t S[8], W[64], t0, t1;
+	int i;
+
+	/* copy state into S */
+	for (i = 0; i < 8; i++)
+		S[i] = ctx->state[i];
+
+	/* copy the state into 512-bits into W[0..15] */
+	for (i = 0; i < 16; i++, buf += sizeof(uint32_t))
+		W[i] = get_be32(buf);
+
+	/* fill W[16..63] */
+	for (i = 16; i < 64; i++)
+		W[i] = gamma1(W[i - 2]) + W[i - 7] + gamma0(W[i - 15]) + W[i - 16];
+
+#define RND(a,b,c,d,e,f,g,h,i,ki)                    \
+	t0 = h + sigma1(e) + ch(e, f, g) + ki + W[i];   \
+	t1 = sigma0(a) + maj(a, b, c);                  \
+	d += t0;                                        \
+	h  = t0 + t1;
+
+	RND(S[0],S[1],S[2],S[3],S[4],S[5],S[6],S[7],0,0x428a2f98);
+	RND(S[7],S[0],S[1],S[2],S[3],S[4],S[5],S[6],1,0x71374491);
+	RND(S[6],S[7],S[0],S[1],S[2],S[3],S[4],S[5],2,0xb5c0fbcf);
+	RND(S[5],S[6],S[7],S[0],S[1],S[2],S[3],S[4],3,0xe9b5dba5);
+	RND(S[4],S[5],S[6],S[7],S[0],S[1],S[2],S[3],4,0x3956c25b);
+	RND(S[3],S[4],S[5],S[6],S[7],S[0],S[1],S[2],5,0x59f111f1);
+	RND(S[2],S[3],S[4],S[5],S[6],S[7],S[0],S[1],6,0x923f82a4);
+	RND(S[1],S[2],S[3],S[4],S[5],S[6],S[7],S[0],7,0xab1c5ed5);
+	RND(S[0],S[1],S[2],S[3],S[4],S[5],S[6],S[7],8,0xd807aa98);
+	RND(S[7],S[0],S[1],S[2],S[3],S[4],S[5],S[6],9,0x12835b01);
+	RND(S[6],S[7],S[0],S[1],S[2],S[3],S[4],S[5],10,0x243185be);
+	RND(S[5],S[6],S[7],S[0],S[1],S[2],S[3],S[4],11,0x550c7dc3);
+	RND(S[4],S[5],S[6],S[7],S[0],S[1],S[2],S[3],12,0x72be5d74);
+	RND(S[3],S[4],S[5],S[6],S[7],S[0],S[1],S[2],13,0x80deb1fe);
+	RND(S[2],S[3],S[4],S[5],S[6],S[7],S[0],S[1],14,0x9bdc06a7);
+	RND(S[1],S[2],S[3],S[4],S[5],S[6],S[7],S[0],15,0xc19bf174);
+	RND(S[0],S[1],S[2],S[3],S[4],S[5],S[6],S[7],16,0xe49b69c1);
+	RND(S[7],S[0],S[1],S[2],S[3],S[4],S[5],S[6],17,0xefbe4786);
+	RND(S[6],S[7],S[0],S[1],S[2],S[3],S[4],S[5],18,0x0fc19dc6);
+	RND(S[5],S[6],S[7],S[0],S[1],S[2],S[3],S[4],19,0x240ca1cc);
+	RND(S[4],S[5],S[6],S[7],S[0],S[1],S[2],S[3],20,0x2de92c6f);
+	RND(S[3],S[4],S[5],S[6],S[7],S[0],S[1],S[2],21,0x4a7484aa);
+	RND(S[2],S[3],S[4],S[5],S[6],S[7],S[0],S[1],22,0x5cb0a9dc);
+	RND(S[1],S[2],S[3],S[4],S[5],S[6],S[7],S[0],23,0x76f988da);
+	RND(S[0],S[1],S[2],S[3],S[4],S[5],S[6],S[7],24,0x983e5152);
+	RND(S[7],S[0],S[1],S[2],S[3],S[4],S[5],S[6],25,0xa831c66d);
+	RND(S[6],S[7],S[0],S[1],S[2],S[3],S[4],S[5],26,0xb00327c8);
+	RND(S[5],S[6],S[7],S[0],S[1],S[2],S[3],S[4],27,0xbf597fc7);
+	RND(S[4],S[5],S[6],S[7],S[0],S[1],S[2],S[3],28,0xc6e00bf3);
+	RND(S[3],S[4],S[5],S[6],S[7],S[0],S[1],S[2],29,0xd5a79147);
+	RND(S[2],S[3],S[4],S[5],S[6],S[7],S[0],S[1],30,0x06ca6351);
+	RND(S[1],S[2],S[3],S[4],S[5],S[6],S[7],S[0],31,0x14292967);
+	RND(S[0],S[1],S[2],S[3],S[4],S[5],S[6],S[7],32,0x27b70a85);
+	RND(S[7],S[0],S[1],S[2],S[3],S[4],S[5],S[6],33,0x2e1b2138);
+	RND(S[6],S[7],S[0],S[1],S[2],S[3],S[4],S[5],34,0x4d2c6dfc);
+	RND(S[5],S[6],S[7],S[0],S[1],S[2],S[3],S[4],35,0x53380d13);
+	RND(S[4],S[5],S[6],S[7],S[0],S[1],S[2],S[3],36,0x650a7354);
+	RND(S[3],S[4],S[5],S[6],S[7],S[0],S[1],S[2],37,0x766a0abb);
+	RND(S[2],S[3],S[4],S[5],S[6],S[7],S[0],S[1],38,0x81c2c92e);
+	RND(S[1],S[2],S[3],S[4],S[5],S[6],S[7],S[0],39,0x92722c85);
+	RND(S[0],S[1],S[2],S[3],S[4],S[5],S[6],S[7],40,0xa2bfe8a1);
+	RND(S[7],S[0],S[1],S[2],S[3],S[4],S[5],S[6],41,0xa81a664b);
+	RND(S[6],S[7],S[0],S[1],S[2],S[3],S[4],S[5],42,0xc24b8b70);
+	RND(S[5],S[6],S[7],S[0],S[1],S[2],S[3],S[4],43,0xc76c51a3);
+	RND(S[4],S[5],S[6],S[7],S[0],S[1],S[2],S[3],44,0xd192e819);
+	RND(S[3],S[4],S[5],S[6],S[7],S[0],S[1],S[2],45,0xd6990624);
+	RND(S[2],S[3],S[4],S[5],S[6],S[7],S[0],S[1],46,0xf40e3585);
+	RND(S[1],S[2],S[3],S[4],S[5],S[6],S[7],S[0],47,0x106aa070);
+	RND(S[0],S[1],S[2],S[3],S[4],S[5],S[6],S[7],48,0x19a4c116);
+	RND(S[7],S[0],S[1],S[2],S[3],S[4],S[5],S[6],49,0x1e376c08);
+	RND(S[6],S[7],S[0],S[1],S[2],S[3],S[4],S[5],50,0x2748774c);
+	RND(S[5],S[6],S[7],S[0],S[1],S[2],S[3],S[4],51,0x34b0bcb5);
+	RND(S[4],S[5],S[6],S[7],S[0],S[1],S[2],S[3],52,0x391c0cb3);
+	RND(S[3],S[4],S[5],S[6],S[7],S[0],S[1],S[2],53,0x4ed8aa4a);
+	RND(S[2],S[3],S[4],S[5],S[6],S[7],S[0],S[1],54,0x5b9cca4f);
+	RND(S[1],S[2],S[3],S[4],S[5],S[6],S[7],S[0],55,0x682e6ff3);
+	RND(S[0],S[1],S[2],S[3],S[4],S[5],S[6],S[7],56,0x748f82ee);
+	RND(S[7],S[0],S[1],S[2],S[3],S[4],S[5],S[6],57,0x78a5636f);
+	RND(S[6],S[7],S[0],S[1],S[2],S[3],S[4],S[5],58,0x84c87814);
+	RND(S[5],S[6],S[7],S[0],S[1],S[2],S[3],S[4],59,0x8cc70208);
+	RND(S[4],S[5],S[6],S[7],S[0],S[1],S[2],S[3],60,0x90befffa);
+	RND(S[3],S[4],S[5],S[6],S[7],S[0],S[1],S[2],61,0xa4506ceb);
+	RND(S[2],S[3],S[4],S[5],S[6],S[7],S[0],S[1],62,0xbef9a3f7);
+	RND(S[1],S[2],S[3],S[4],S[5],S[6],S[7],S[0],63,0xc67178f2);
+
+	for (i = 0; i < 8; i++)
+		ctx->state[i] += S[i];
+}
+
+void blk_SHA256_Update(blk_SHA256_CTX *ctx, const void *data, size_t len)
+{
+	unsigned int len_buf = ctx->size & 63;
+
+	ctx->size += len;
+
+	/* Read the data into buf and process blocks as they get full */
+	if (len_buf) {
+		unsigned int left = 64 - len_buf;
+		if (len < left)
+			left = len;
+		memcpy(len_buf + ctx->buf, data, left);
+		len_buf = (len_buf + left) & 63;
+		len -= left;
+		data = ((const char *)data + left);
+		if (len_buf)
+			return;
+		blk_SHA256_Transform(ctx, ctx->buf);
+	}
+	while (len >= 64) {
+		blk_SHA256_Transform(ctx, data);
+		data = ((const char *)data + 64);
+		len -= 64;
+	}
+	if (len)
+		memcpy(ctx->buf, data, len);
+}
+
+void blk_SHA256_Final(unsigned char *digest, blk_SHA256_CTX *ctx)
+{
+	static const unsigned char pad[64] = { 0x80 };
+	unsigned int padlen[2];
+	int i;
+
+	/* Pad with a binary 1 (ie 0x80), then zeroes, then length */
+	padlen[0] = htonl((uint32_t)(ctx->size >> 29));
+	padlen[1] = htonl((uint32_t)(ctx->size << 3));
+
+	i = ctx->size & 63;
+	blk_SHA256_Update(ctx, pad, 1 + (63 & (55 - i)));
+	blk_SHA256_Update(ctx, padlen, 8);
+
+	/* copy output */
+	for (i = 0; i < 8; i++, digest += sizeof(uint32_t))
+		put_be32(digest, ctx->state[i]);
+}
diff -pruN 1.2.1+git2.18.0-1/git/sha256/block/sha256.h 1.2.3+git2.25.1-1/git/sha256/block/sha256.h
--- 1.2.1+git2.18.0-1/git/sha256/block/sha256.h	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/sha256/block/sha256.h	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,24 @@
+#ifndef SHA256_BLOCK_SHA256_H
+#define SHA256_BLOCK_SHA256_H
+
+#define blk_SHA256_BLKSIZE 64
+
+struct blk_SHA256_CTX {
+	uint32_t state[8];
+	uint64_t size;
+	uint32_t offset;
+	uint8_t buf[blk_SHA256_BLKSIZE];
+};
+
+typedef struct blk_SHA256_CTX blk_SHA256_CTX;
+
+void blk_SHA256_Init(blk_SHA256_CTX *ctx);
+void blk_SHA256_Update(blk_SHA256_CTX *ctx, const void *data, size_t len);
+void blk_SHA256_Final(unsigned char *digest, blk_SHA256_CTX *ctx);
+
+#define platform_SHA256_CTX blk_SHA256_CTX
+#define platform_SHA256_Init blk_SHA256_Init
+#define platform_SHA256_Update blk_SHA256_Update
+#define platform_SHA256_Final blk_SHA256_Final
+
+#endif
diff -pruN 1.2.1+git2.18.0-1/git/sha256/gcrypt.h 1.2.3+git2.25.1-1/git/sha256/gcrypt.h
--- 1.2.1+git2.18.0-1/git/sha256/gcrypt.h	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/sha256/gcrypt.h	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,30 @@
+#ifndef SHA256_GCRYPT_H
+#define SHA256_GCRYPT_H
+
+#include <gcrypt.h>
+
+#define SHA256_DIGEST_SIZE 32
+
+typedef gcry_md_hd_t gcrypt_SHA256_CTX;
+
+inline void gcrypt_SHA256_Init(gcrypt_SHA256_CTX *ctx)
+{
+	gcry_md_open(ctx, GCRY_MD_SHA256, 0);
+}
+
+inline void gcrypt_SHA256_Update(gcrypt_SHA256_CTX *ctx, const void *data, size_t len)
+{
+	gcry_md_write(*ctx, data, len);
+}
+
+inline void gcrypt_SHA256_Final(unsigned char *digest, gcrypt_SHA256_CTX *ctx)
+{
+	memcpy(digest, gcry_md_read(*ctx, GCRY_MD_SHA256), SHA256_DIGEST_SIZE);
+}
+
+#define platform_SHA256_CTX gcrypt_SHA256_CTX
+#define platform_SHA256_Init gcrypt_SHA256_Init
+#define platform_SHA256_Update gcrypt_SHA256_Update
+#define platform_SHA256_Final gcrypt_SHA256_Final
+
+#endif
diff -pruN 1.2.1+git2.18.0-1/git/shallow.c 1.2.3+git2.25.1-1/git/shallow.c
--- 1.2.1+git2.18.0-1/git/shallow.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/shallow.c	2020-02-17 04:47:35.000000000 +0000
@@ -1,6 +1,8 @@
 #include "cache.h"
+#include "repository.h"
 #include "tempfile.h"
 #include "lockfile.h"
+#include "object-store.h"
 #include "commit.h"
 #include "tag.h"
 #include "pkt-line.h"
@@ -10,70 +12,78 @@
 #include "diff.h"
 #include "revision.h"
 #include "commit-slab.h"
-#include "revision.h"
 #include "list-objects.h"
+#include "commit-reach.h"
 
-static int is_shallow = -1;
-static struct stat_validity shallow_stat;
-static char *alternate_shallow_file;
-
-void set_alternate_shallow_file(const char *path, int override)
+void set_alternate_shallow_file(struct repository *r, const char *path, int override)
 {
-	if (is_shallow != -1)
+	if (r->parsed_objects->is_shallow != -1)
 		BUG("is_repository_shallow must not be called before set_alternate_shallow_file");
-	if (alternate_shallow_file && !override)
+	if (r->parsed_objects->alternate_shallow_file && !override)
 		return;
-	free(alternate_shallow_file);
-	alternate_shallow_file = xstrdup_or_null(path);
+	free(r->parsed_objects->alternate_shallow_file);
+	r->parsed_objects->alternate_shallow_file = xstrdup_or_null(path);
 }
 
-int register_shallow(const struct object_id *oid)
+int register_shallow(struct repository *r, const struct object_id *oid)
 {
 	struct commit_graft *graft =
 		xmalloc(sizeof(struct commit_graft));
-	struct commit *commit = lookup_commit(oid);
+	struct commit *commit = lookup_commit(the_repository, oid);
 
 	oidcpy(&graft->oid, oid);
 	graft->nr_parent = -1;
 	if (commit && commit->object.parsed)
 		commit->parents = NULL;
-	return register_commit_graft(graft, 0);
+	return register_commit_graft(r, graft, 0);
 }
 
-int is_repository_shallow(void)
+int is_repository_shallow(struct repository *r)
 {
+	/*
+	 * NEEDSWORK: This function updates
+	 * r->parsed_objects->{is_shallow,shallow_stat} as a side effect but
+	 * there is no corresponding function to clear them when the shallow
+	 * file is updated.
+	 */
+
 	FILE *fp;
 	char buf[1024];
-	const char *path = alternate_shallow_file;
+	const char *path = r->parsed_objects->alternate_shallow_file;
 
-	if (is_shallow >= 0)
-		return is_shallow;
+	if (r->parsed_objects->is_shallow >= 0)
+		return r->parsed_objects->is_shallow;
 
 	if (!path)
-		path = git_path_shallow();
+		path = git_path_shallow(r);
 	/*
 	 * fetch-pack sets '--shallow-file ""' as an indicator that no
 	 * shallow file should be used. We could just open it and it
 	 * will likely fail. But let's do an explicit check instead.
 	 */
 	if (!*path || (fp = fopen(path, "r")) == NULL) {
-		stat_validity_clear(&shallow_stat);
-		is_shallow = 0;
-		return is_shallow;
+		stat_validity_clear(r->parsed_objects->shallow_stat);
+		r->parsed_objects->is_shallow = 0;
+		return r->parsed_objects->is_shallow;
 	}
-	stat_validity_update(&shallow_stat, fileno(fp));
-	is_shallow = 1;
+	stat_validity_update(r->parsed_objects->shallow_stat, fileno(fp));
+	r->parsed_objects->is_shallow = 1;
 
 	while (fgets(buf, sizeof(buf), fp)) {
 		struct object_id oid;
 		if (get_oid_hex(buf, &oid))
 			die("bad shallow line: %s", buf);
-		register_shallow(&oid);
+		register_shallow(r, &oid);
 	}
 	fclose(fp);
-	return is_shallow;
+	return r->parsed_objects->is_shallow;
 }
 
+/*
+ * TODO: use "int" elemtype instead of "int *" when/if commit-slab
+ * supports a "valid" flag.
+ */
+define_commit_slab(commit_depth, int *);
 struct commit_list *get_shallow_commits(struct object_array *heads, int depth,
 		int shallow_flag, int not_shallow_flag)
 {
@@ -82,32 +92,38 @@ struct commit_list *get_shallow_commits(
 	struct object_array stack = OBJECT_ARRAY_INIT;
 	struct commit *commit = NULL;
 	struct commit_graft *graft;
+	struct commit_depth depths;
 
+	init_commit_depth(&depths);
 	while (commit || i < heads->nr || stack.nr) {
 		struct commit_list *p;
 		if (!commit) {
 			if (i < heads->nr) {
+				int **depth_slot;
 				commit = (struct commit *)
-					deref_tag(heads->objects[i++].item, NULL, 0);
+					deref_tag(the_repository,
+						  heads->objects[i++].item,
+						  NULL, 0);
 				if (!commit || commit->object.type != OBJ_COMMIT) {
 					commit = NULL;
 					continue;
 				}
-				if (!commit->util)
-					commit->util = xmalloc(sizeof(int));
-				*(int *)commit->util = 0;
+				depth_slot = commit_depth_at(&depths, commit);
+				if (!*depth_slot)
+					*depth_slot = xmalloc(sizeof(int));
+				**depth_slot = 0;
 				cur_depth = 0;
 			} else {
 				commit = (struct commit *)
 					object_array_pop(&stack);
-				cur_depth = *(int *)commit->util;
+				cur_depth = **commit_depth_at(&depths, commit);
 			}
 		}
 		parse_commit_or_die(commit);
 		cur_depth++;
 		if ((depth != INFINITE_DEPTH && cur_depth >= depth) ||
-		    (is_repository_shallow() && !commit->parents &&
-		     (graft = lookup_commit_graft(&commit->object.oid)) != NULL &&
+		    (is_repository_shallow(the_repository) && !commit->parents &&
+		     (graft = lookup_commit_graft(the_repository, &commit->object.oid)) != NULL &&
 		     graft->nr_parent < 0)) {
 			commit_list_insert(commit, &result);
 			commit->object.flags |= shallow_flag;
@@ -116,25 +132,33 @@ struct commit_list *get_shallow_commits(
 		}
 		commit->object.flags |= not_shallow_flag;
 		for (p = commit->parents, commit = NULL; p; p = p->next) {
-			if (!p->item->util) {
-				int *pointer = xmalloc(sizeof(int));
-				p->item->util = pointer;
-				*pointer =  cur_depth;
+			int **depth_slot = commit_depth_at(&depths, p->item);
+			if (!*depth_slot) {
+				*depth_slot = xmalloc(sizeof(int));
+				**depth_slot = cur_depth;
 			} else {
-				int *pointer = p->item->util;
-				if (cur_depth >= *pointer)
+				if (cur_depth >= **depth_slot)
 					continue;
-				*pointer = cur_depth;
+				**depth_slot = cur_depth;
 			}
 			if (p->next)
 				add_object_array(&p->item->object,
 						NULL, &stack);
 			else {
 				commit = p->item;
-				cur_depth = *(int *)commit->util;
+				cur_depth = **commit_depth_at(&depths, commit);
 			}
 		}
 	}
+	for (i = 0; i < depths.slab_count; i++) {
+		int j;
+
+		if (!depths.slab[i])
+			continue;
+		for (j = 0; j < depths.slab_size; j++)
+			free(depths.slab[i][j]);
+	}
+	clear_commit_depth(&depths);
 
 	return result;
 }
@@ -165,9 +189,9 @@ struct commit_list *get_shallow_commits_
 	 */
 	clear_object_flags(both_flags);
 
-	is_repository_shallow(); /* make sure shallows are read */
+	is_repository_shallow(the_repository); /* make sure shallows are read */
 
-	init_revisions(&revs, NULL);
+	repo_init_revisions(the_repository, &revs, NULL);
 	save_commit_buffer = 0;
 	setup_revisions(ac, av, &revs, NULL);
 
@@ -175,6 +199,9 @@ struct commit_list *get_shallow_commits_
 		die("revision walk setup failed");
 	traverse_commit_list(&revs, show_commit, NULL, &not_shallow_list);
 
+	if (!not_shallow_list)
+		die("no commits selected for shallow requests");
+
 	/* Mark all reachable commits as NOT_SHALLOW */
 	for (p = not_shallow_list; p; p = p->next)
 		p->item->object.flags |= not_shallow_flag;
@@ -215,17 +242,19 @@ struct commit_list *get_shallow_commits_
 	return result;
 }
 
-static void check_shallow_file_for_update(void)
+static void check_shallow_file_for_update(struct repository *r)
 {
-	if (is_shallow == -1)
+	if (r->parsed_objects->is_shallow == -1)
 		BUG("shallow must be initialized by now");
 
-	if (!stat_validity_check(&shallow_stat, git_path_shallow()))
+	if (!stat_validity_check(r->parsed_objects->shallow_stat,
+				 git_path_shallow(r)))
 		die("shallow file has changed since we read it");
 }
 
 #define SEEN_ONLY 1
 #define VERBOSE   2
+#define QUICK 4
 
 struct write_shallow_data {
 	struct strbuf *out;
@@ -240,8 +269,11 @@ static int write_one_shallow(const struc
 	const char *hex = oid_to_hex(&graft->oid);
 	if (graft->nr_parent != -1)
 		return 0;
-	if (data->flags & SEEN_ONLY) {
-		struct commit *c = lookup_commit(&graft->oid);
+	if (data->flags & QUICK) {
+		if (!has_object_file(&graft->oid))
+			return 0;
+	} else if (data->flags & SEEN_ONLY) {
+		struct commit *c = lookup_commit(the_repository, &graft->oid);
 		if (!c || !(c->object.flags & SEEN)) {
 			if (data->flags & VERBOSE)
 				printf("Removing %s from .git/shallow\n",
@@ -315,9 +347,10 @@ void setup_alternate_shallow(struct lock
 	struct strbuf sb = STRBUF_INIT;
 	int fd;
 
-	fd = hold_lock_file_for_update(shallow_lock, git_path_shallow(),
+	fd = hold_lock_file_for_update(shallow_lock,
+				       git_path_shallow(the_repository),
 				       LOCK_DIE_ON_ERROR);
-	check_shallow_file_for_update();
+	check_shallow_file_for_update(the_repository);
 	if (write_shallow_commits(&sb, 0, extra)) {
 		if (write_in_full(fd, sb.buf, sb.len) < 0)
 			die_errno("failed to write to %s",
@@ -342,36 +375,44 @@ static int advertise_shallow_grafts_cb(c
 
 void advertise_shallow_grafts(int fd)
 {
-	if (!is_repository_shallow())
+	if (!is_repository_shallow(the_repository))
 		return;
 	for_each_commit_graft(advertise_shallow_grafts_cb, &fd);
 }
 
 /*
  * mark_reachable_objects() should have been run prior to this and all
- * reachable commits marked as "SEEN".
+ * reachable commits marked as "SEEN", except when quick_prune is non-zero,
+ * in which case lines are excised from the shallow file if they refer to
+ * commits that do not exist (any longer).
  */
-void prune_shallow(int show_only)
+void prune_shallow(unsigned options)
 {
 	struct lock_file shallow_lock = LOCK_INIT;
 	struct strbuf sb = STRBUF_INIT;
+	unsigned flags = SEEN_ONLY;
 	int fd;
 
-	if (show_only) {
-		write_shallow_commits_1(&sb, 0, NULL, SEEN_ONLY | VERBOSE);
+	if (options & PRUNE_QUICK)
+		flags |= QUICK;
+
+	if (options & PRUNE_SHOW_ONLY) {
+		flags |= VERBOSE;
+		write_shallow_commits_1(&sb, 0, NULL, flags);
 		strbuf_release(&sb);
 		return;
 	}
-	fd = hold_lock_file_for_update(&shallow_lock, git_path_shallow(),
+	fd = hold_lock_file_for_update(&shallow_lock,
+				       git_path_shallow(the_repository),
 				       LOCK_DIE_ON_ERROR);
-	check_shallow_file_for_update();
-	if (write_shallow_commits_1(&sb, 0, NULL, SEEN_ONLY)) {
+	check_shallow_file_for_update(the_repository);
+	if (write_shallow_commits_1(&sb, 0, NULL, flags)) {
 		if (write_in_full(fd, sb.buf, sb.len) < 0)
 			die_errno("failed to write to %s",
 				  get_lock_file_path(&shallow_lock));
 		commit_lock_file(&shallow_lock);
 	} else {
-		unlink(git_path_shallow());
+		unlink(git_path_shallow(the_repository));
 		rollback_lock_file(&shallow_lock);
 	}
 	strbuf_release(&sb);
@@ -396,7 +437,8 @@ void prepare_shallow_info(struct shallow
 	for (i = 0; i < sa->nr; i++) {
 		if (has_object_file(sa->oid + i)) {
 			struct commit_graft *graft;
-			graft = lookup_commit_graft(&sa->oid[i]);
+			graft = lookup_commit_graft(the_repository,
+						    &sa->oid[i]);
 			if (graft && graft->nr_parent < 0)
 				continue;
 			info->ours[info->nr_ours++] = i;
@@ -471,7 +513,8 @@ static void paint_down(struct paint_info
 	struct commit_list *head = NULL;
 	int bitmap_nr = DIV_ROUND_UP(info->nr_bits, 32);
 	size_t bitmap_size = st_mult(sizeof(uint32_t), bitmap_nr);
-	struct commit *c = lookup_commit_reference_gently(oid, 1);
+	struct commit *c = lookup_commit_reference_gently(the_repository, oid,
+							  1);
 	uint32_t *tmp; /* to be freed before return */
 	uint32_t *bitmap;
 
@@ -533,7 +576,8 @@ static void paint_down(struct paint_info
 static int mark_uninteresting(const char *refname, const struct object_id *oid,
 			      int flags, void *cb_data)
 {
-	struct commit *commit = lookup_commit_reference_gently(oid, 1);
+	struct commit *commit = lookup_commit_reference_gently(the_repository,
+							       oid, 1);
 	if (!commit)
 		return 0;
 	commit->object.flags |= UNINTERESTING;
@@ -601,7 +645,8 @@ void assign_shallow_commits_to_refs(stru
 
 	/* Mark potential bottoms so we won't go out of bound */
 	for (i = 0; i < nr_shallow; i++) {
-		struct commit *c = lookup_commit(&oid[shallow[i]]);
+		struct commit *c = lookup_commit(the_repository,
+						 &oid[shallow[i]]);
 		c->object.flags |= BOTTOM;
 	}
 
@@ -612,7 +657,8 @@ void assign_shallow_commits_to_refs(stru
 		int bitmap_size = DIV_ROUND_UP(pi.nr_bits, 32) * sizeof(uint32_t);
 		memset(used, 0, sizeof(*used) * info->shallow->nr);
 		for (i = 0; i < nr_shallow; i++) {
-			const struct commit *c = lookup_commit(&oid[shallow[i]]);
+			const struct commit *c = lookup_commit(the_repository,
+							       &oid[shallow[i]]);
 			uint32_t **map = ref_bitmap_at(&pi.ref_bitmap, c);
 			if (*map)
 				used[shallow[i]] = xmemdupz(*map, bitmap_size);
@@ -643,7 +689,8 @@ static int add_ref(const char *refname,
 {
 	struct commit_array *ca = cb_data;
 	ALLOC_GROW(ca->commits, ca->nr + 1, ca->alloc);
-	ca->commits[ca->nr] = lookup_commit_reference_gently(oid, 1);
+	ca->commits[ca->nr] = lookup_commit_reference_gently(the_repository,
+							     oid, 1);
 	if (ca->commits[ca->nr])
 		ca->nr++;
 	return 0;
@@ -681,7 +728,7 @@ static void post_assign_shallow(struct s
 	for (i = dst = 0; i < info->nr_theirs; i++) {
 		if (i != dst)
 			info->theirs[dst] = info->theirs[i];
-		c = lookup_commit(&oid[info->theirs[i]]);
+		c = lookup_commit(the_repository, &oid[info->theirs[i]]);
 		bitmap = ref_bitmap_at(ref_bitmap, c);
 		if (!*bitmap)
 			continue;
@@ -702,7 +749,7 @@ static void post_assign_shallow(struct s
 	for (i = dst = 0; i < info->nr_ours; i++) {
 		if (i != dst)
 			info->ours[dst] = info->ours[i];
-		c = lookup_commit(&oid[info->ours[i]]);
+		c = lookup_commit(the_repository, &oid[info->ours[i]]);
 		bitmap = ref_bitmap_at(ref_bitmap, c);
 		if (!*bitmap)
 			continue;
@@ -724,7 +771,8 @@ static void post_assign_shallow(struct s
 int delayed_reachability_test(struct shallow_info *si, int c)
 {
 	if (si->need_reachability_test[c]) {
-		struct commit *commit = lookup_commit(&si->shallow->oid[c]);
+		struct commit *commit = lookup_commit(the_repository,
+						      &si->shallow->oid[c]);
 
 		if (!si->commits) {
 			struct commit_array ca;
diff -pruN 1.2.1+git2.18.0-1/git/shell.c 1.2.3+git2.25.1-1/git/shell.c
--- 1.2.1+git2.18.0-1/git/shell.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/shell.c	2020-02-17 04:47:35.000000000 +0000
@@ -16,10 +16,10 @@ static int do_generic_cmd(const char *me
 	setup_path();
 	if (!arg || !(arg = sq_dequote(arg)) || *arg == '-')
 		die("bad argument");
-	if (!starts_with(me, "git-"))
+	if (!skip_prefix(me, "git-", &me))
 		die("bad command");
 
-	my_argv[0] = me + 4;
+	my_argv[0] = me;
 	my_argv[1] = arg;
 	my_argv[2] = NULL;
 
diff -pruN 1.2.1+git2.18.0-1/git/sh-i18n--envsubst.c 1.2.3+git2.25.1-1/git/sh-i18n--envsubst.c
--- 1.2.1+git2.18.0-1/git/sh-i18n--envsubst.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/sh-i18n--envsubst.c	2020-02-17 04:47:35.000000000 +0000
@@ -14,6 +14,7 @@
  */
 
 #include "git-compat-util.h"
+#include "trace2.h"
 
 /* Substitution of environment variables in shell format strings.
    Copyright (C) 2003-2007 Free Software Foundation, Inc.
@@ -67,6 +68,8 @@ cmd_main (int argc, const char *argv[])
   /* Default values for command line options.  */
   /* unsigned short int show_variables = 0; */
 
+  trace2_cmd_name("sh-i18n--envsubst");
+
   switch (argc)
 	{
 	case 1:
@@ -246,7 +249,7 @@ sorted_string_list_member (const string_
 	{
 	  /* Here we know that if s is in the list, it is at an index j
 	     with j1 <= j < j2.  */
-	  size_t j = (j1 + j2) >> 1;
+	  size_t j = j1 + ((j2 - j1) >> 1);
 	  int result = strcmp (slp->item[j], s);
 
 	  if (result > 0)
diff -pruN 1.2.1+git2.18.0-1/git/shortlog.h 1.2.3+git2.25.1-1/git/shortlog.h
--- 1.2.1+git2.18.0-1/git/shortlog.h	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/shortlog.h	2020-02-17 04:47:35.000000000 +0000
@@ -3,6 +3,8 @@
 
 #include "string-list.h"
 
+struct commit;
+
 struct shortlog {
 	struct string_list list;
 	int summary;
diff -pruN 1.2.1+git2.18.0-1/git/show-index.c 1.2.3+git2.25.1-1/git/show-index.c
--- 1.2.1+git2.18.0-1/git/show-index.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/show-index.c	1970-01-01 00:00:00.000000000 +0000
@@ -1,85 +0,0 @@
-#include "cache.h"
-#include "pack.h"
-
-static const char show_index_usage[] =
-"git show-index";
-
-int cmd_main(int argc, const char **argv)
-{
-	int i;
-	unsigned nr;
-	unsigned int version;
-	static unsigned int top_index[256];
-
-	if (argc != 1)
-		usage(show_index_usage);
-	if (fread(top_index, 2 * 4, 1, stdin) != 1)
-		die("unable to read header");
-	if (top_index[0] == htonl(PACK_IDX_SIGNATURE)) {
-		version = ntohl(top_index[1]);
-		if (version < 2 || version > 2)
-			die("unknown index version");
-		if (fread(top_index, 256 * 4, 1, stdin) != 1)
-			die("unable to read index");
-	} else {
-		version = 1;
-		if (fread(&top_index[2], 254 * 4, 1, stdin) != 1)
-			die("unable to read index");
-	}
-	nr = 0;
-	for (i = 0; i < 256; i++) {
-		unsigned n = ntohl(top_index[i]);
-		if (n < nr)
-			die("corrupt index file");
-		nr = n;
-	}
-	if (version == 1) {
-		for (i = 0; i < nr; i++) {
-			unsigned int offset, entry[6];
-
-			if (fread(entry, 4 + 20, 1, stdin) != 1)
-				die("unable to read entry %u/%u", i, nr);
-			offset = ntohl(entry[0]);
-			printf("%u %s\n", offset, sha1_to_hex((void *)(entry+1)));
-		}
-	} else {
-		unsigned off64_nr = 0;
-		struct {
-			unsigned char sha1[20];
-			uint32_t crc;
-			uint32_t off;
-		} *entries;
-		ALLOC_ARRAY(entries, nr);
-		for (i = 0; i < nr; i++)
-			if (fread(entries[i].sha1, 20, 1, stdin) != 1)
-				die("unable to read sha1 %u/%u", i, nr);
-		for (i = 0; i < nr; i++)
-			if (fread(&entries[i].crc, 4, 1, stdin) != 1)
-				die("unable to read crc %u/%u", i, nr);
-		for (i = 0; i < nr; i++)
-			if (fread(&entries[i].off, 4, 1, stdin) != 1)
-				die("unable to read 32b offset %u/%u", i, nr);
-		for (i = 0; i < nr; i++) {
-			uint64_t offset;
-			uint32_t off = ntohl(entries[i].off);
-			if (!(off & 0x80000000)) {
-				offset = off;
-			} else {
-				uint32_t off64[2];
-				if ((off & 0x7fffffff) != off64_nr)
-					die("inconsistent 64b offset index");
-				if (fread(off64, 8, 1, stdin) != 1)
-					die("unable to read 64b offset %u", off64_nr);
-				offset = (((uint64_t)ntohl(off64[0])) << 32) |
-						     ntohl(off64[1]);
-				off64_nr++;
-			}
-			printf("%" PRIuMAX " %s (%08"PRIx32")\n",
-			       (uintmax_t) offset,
-			       sha1_to_hex(entries[i].sha1),
-			       ntohl(entries[i].crc));
-		}
-		free(entries);
-	}
-	return 0;
-}
diff -pruN 1.2.1+git2.18.0-1/git/sideband.c 1.2.3+git2.25.1-1/git/sideband.c
--- 1.2.1+git2.18.0-1/git/sideband.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/sideband.c	2020-02-17 04:47:35.000000000 +0000
@@ -1,106 +1,212 @@
 #include "cache.h"
-#include "pkt-line.h"
+#include "color.h"
+#include "config.h"
 #include "sideband.h"
+#include "help.h"
+
+struct keyword_entry {
+	/*
+	 * We use keyword as config key so it should be a single alphanumeric word.
+	 */
+	const char *keyword;
+	char color[COLOR_MAXLEN];
+};
+
+static struct keyword_entry keywords[] = {
+	{ "hint",	GIT_COLOR_YELLOW },
+	{ "warning",	GIT_COLOR_BOLD_YELLOW },
+	{ "success",	GIT_COLOR_BOLD_GREEN },
+	{ "error",	GIT_COLOR_BOLD_RED },
+};
+
+/* Returns a color setting (GIT_COLOR_NEVER, etc). */
+static int use_sideband_colors(void)
+{
+	static int use_sideband_colors_cached = -1;
+
+	const char *key = "color.remote";
+	struct strbuf sb = STRBUF_INIT;
+	char *value;
+	int i;
+
+	if (use_sideband_colors_cached >= 0)
+		return use_sideband_colors_cached;
+
+	if (!git_config_get_string(key, &value)) {
+		use_sideband_colors_cached = git_config_colorbool(key, value);
+	} else if (!git_config_get_string("color.ui", &value)) {
+		use_sideband_colors_cached = git_config_colorbool("color.ui", value);
+	} else {
+		use_sideband_colors_cached = GIT_COLOR_AUTO;
+	}
+
+	for (i = 0; i < ARRAY_SIZE(keywords); i++) {
+		strbuf_reset(&sb);
+		strbuf_addf(&sb, "%s.%s", key, keywords[i].keyword);
+		if (git_config_get_string(sb.buf, &value))
+			continue;
+		if (color_parse(value, keywords[i].color))
+			continue;
+	}
+	strbuf_release(&sb);
+	return use_sideband_colors_cached;
+}
+
+void list_config_color_sideband_slots(struct string_list *list, const char *prefix)
+{
+	int i;
+
+	for (i = 0; i < ARRAY_SIZE(keywords); i++)
+		list_config_item(list, prefix, keywords[i].keyword);
+}
 
 /*
- * Receive multiplexed output stream over git native protocol.
- * in_stream is the input stream from the remote, which carries data
- * in pkt_line format with band designator.  Demultiplex it into out
- * and err and return error appropriately.  Band #1 carries the
- * primary payload.  Things coming over band #2 is not necessarily
- * error; they are usually informative message on the standard error
- * stream, aka "verbose").  A message over band #3 is a signal that
- * the remote died unexpectedly.  A flush() concludes the stream.
+ * Optionally highlight one keyword in remote output if it appears at the start
+ * of the line. This should be called for a single line only, which is
+ * passed as the first N characters of the SRC array.
+ *
+ * NEEDSWORK: use "size_t n" instead for clarity.
  */
+static void maybe_colorize_sideband(struct strbuf *dest, const char *src, int n)
+{
+	int i;
+
+	if (!want_color_stderr(use_sideband_colors())) {
+		strbuf_add(dest, src, n);
+		return;
+	}
+
+	while (0 < n && isspace(*src)) {
+		strbuf_addch(dest, *src);
+		src++;
+		n--;
+	}
+
+	for (i = 0; i < ARRAY_SIZE(keywords); i++) {
+		struct keyword_entry *p = keywords + i;
+		int len = strlen(p->keyword);
+
+		if (n < len)
+			continue;
+		/*
+		 * Match case insensitively, so we colorize output from existing
+		 * servers regardless of the case that they use for their
+		 * messages. We only highlight the word precisely, so
+		 * "successful" stays uncolored.
+		 */
+		if (!strncasecmp(p->keyword, src, len) &&
+		    (len == n || !isalnum(src[len]))) {
+			strbuf_addstr(dest, p->color);
+			strbuf_add(dest, src, len);
+			strbuf_addstr(dest, GIT_COLOR_RESET);
+			n -= len;
+			src += len;
+			break;
+		}
+	}
+
+	strbuf_add(dest, src, n);
+}
+
 
 #define DISPLAY_PREFIX "remote: "
 
 #define ANSI_SUFFIX "\033[K"
 #define DUMB_SUFFIX "        "
 
-int recv_sideband(const char *me, int in_stream, int out)
+int demultiplex_sideband(const char *me, char *buf, int len,
+			 int die_on_error,
+			 struct strbuf *scratch,
+			 enum sideband_type *sideband_type)
 {
-	const char *suffix;
-	char buf[LARGE_PACKET_MAX + 1];
-	struct strbuf outbuf = STRBUF_INIT;
-	int retval = 0;
-
-	if (isatty(2) && !is_terminal_dumb())
-		suffix = ANSI_SUFFIX;
-	else
-		suffix = DUMB_SUFFIX;
-
-	while (!retval) {
-		const char *b, *brk;
-		int band, len;
-		len = packet_read(in_stream, NULL, NULL, buf, LARGE_PACKET_MAX, 0);
-		if (len == 0)
-			break;
-		if (len < 1) {
-			strbuf_addf(&outbuf,
-				    "%s%s: protocol error: no band designator",
-				    outbuf.len ? "\n" : "", me);
-			retval = SIDEBAND_PROTOCOL_ERROR;
-			break;
-		}
-		band = buf[0] & 0xff;
-		buf[len] = '\0';
-		len--;
-		switch (band) {
-		case 3:
-			strbuf_addf(&outbuf, "%s%s%s", outbuf.len ? "\n" : "",
-				    DISPLAY_PREFIX, buf + 1);
-			retval = SIDEBAND_REMOTE_ERROR;
-			break;
-		case 2:
-			b = buf + 1;
-
-			/*
-			 * Append a suffix to each nonempty line to clear the
-			 * end of the screen line.
-			 *
-			 * The output is accumulated in a buffer and
-			 * each line is printed to stderr using
-			 * write(2) to ensure inter-process atomicity.
-			 */
-			while ((brk = strpbrk(b, "\n\r"))) {
-				int linelen = brk - b;
-
-				if (!outbuf.len)
-					strbuf_addstr(&outbuf, DISPLAY_PREFIX);
-				if (linelen > 0) {
-					strbuf_addf(&outbuf, "%.*s%s%c",
-						    linelen, b, suffix, *brk);
-				} else {
-					strbuf_addch(&outbuf, *brk);
-				}
-				xwrite(2, outbuf.buf, outbuf.len);
-				strbuf_reset(&outbuf);
+	static const char *suffix;
+	const char *b, *brk;
+	int band;
+
+	if (!suffix) {
+		if (isatty(2) && !is_terminal_dumb())
+			suffix = ANSI_SUFFIX;
+		else
+			suffix = DUMB_SUFFIX;
+	}
 
-				b = brk + 1;
+	if (len == 0) {
+		*sideband_type = SIDEBAND_FLUSH;
+		goto cleanup;
+	}
+	if (len < 1) {
+		strbuf_addf(scratch,
+			    "%s%s: protocol error: no band designator",
+			    scratch->len ? "\n" : "", me);
+		*sideband_type = SIDEBAND_PROTOCOL_ERROR;
+		goto cleanup;
+	}
+	band = buf[0] & 0xff;
+	buf[len] = '\0';
+	len--;
+	switch (band) {
+	case 3:
+		if (die_on_error)
+			die("remote error: %s", buf + 1);
+		strbuf_addf(scratch, "%s%s", scratch->len ? "\n" : "",
+			    DISPLAY_PREFIX);
+		maybe_colorize_sideband(scratch, buf + 1, len);
+
+		*sideband_type = SIDEBAND_REMOTE_ERROR;
+		break;
+	case 2:
+		b = buf + 1;
+
+		/*
+		 * Append a suffix to each nonempty line to clear the
+		 * end of the screen line.
+		 *
+		 * The output is accumulated in a buffer and
+		 * each line is printed to stderr using
+		 * write(2) to ensure inter-process atomicity.
+		 */
+		while ((brk = strpbrk(b, "\n\r"))) {
+			int linelen = brk - b;
+
+			if (!scratch->len)
+				strbuf_addstr(scratch, DISPLAY_PREFIX);
+			if (linelen > 0) {
+				maybe_colorize_sideband(scratch, b, linelen);
+				strbuf_addstr(scratch, suffix);
 			}
 
-			if (*b)
-				strbuf_addf(&outbuf, "%s%s", outbuf.len ?
-					    "" : DISPLAY_PREFIX, b);
-			break;
-		case 1:
-			write_or_die(out, buf + 1, len);
-			break;
-		default:
-			strbuf_addf(&outbuf, "%s%s: protocol error: bad band #%d",
-				    outbuf.len ? "\n" : "", me, band);
-			retval = SIDEBAND_PROTOCOL_ERROR;
-			break;
+			strbuf_addch(scratch, *brk);
+			xwrite(2, scratch->buf, scratch->len);
+			strbuf_reset(scratch);
+
+			b = brk + 1;
+		}
+
+		if (*b) {
+			strbuf_addstr(scratch, scratch->len ?
+				    "" : DISPLAY_PREFIX);
+			maybe_colorize_sideband(scratch, b, strlen(b));
 		}
+		return 0;
+	case 1:
+		*sideband_type = SIDEBAND_PRIMARY;
+		break;
+	default:
+		strbuf_addf(scratch, "%s%s: protocol error: bad band #%d",
+			    scratch->len ? "\n" : "", me, band);
+		*sideband_type = SIDEBAND_PROTOCOL_ERROR;
+		break;
 	}
 
-	if (outbuf.len) {
-		strbuf_addch(&outbuf, '\n');
-		xwrite(2, outbuf.buf, outbuf.len);
+cleanup:
+	if (die_on_error && *sideband_type == SIDEBAND_PROTOCOL_ERROR)
+		die("%s", scratch->buf);
+	if (scratch->len) {
+		strbuf_addch(scratch, '\n');
+		xwrite(2, scratch->buf, scratch->len);
 	}
-	strbuf_release(&outbuf);
-	return retval;
+	strbuf_release(scratch);
+	return 1;
 }
 
 /*
diff -pruN 1.2.1+git2.18.0-1/git/sideband.h 1.2.3+git2.25.1-1/git/sideband.h
--- 1.2.1+git2.18.0-1/git/sideband.h	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/sideband.h	2020-02-17 04:47:35.000000000 +0000
@@ -1,10 +1,29 @@
 #ifndef SIDEBAND_H
 #define SIDEBAND_H
 
-#define SIDEBAND_PROTOCOL_ERROR -2
-#define SIDEBAND_REMOTE_ERROR -1
+enum sideband_type {
+	SIDEBAND_PROTOCOL_ERROR = -2,
+	SIDEBAND_REMOTE_ERROR = -1,
+	SIDEBAND_FLUSH = 0,
+	SIDEBAND_PRIMARY = 1
+};
+
+/*
+ * Inspects a multiplexed packet read from the remote. If this packet is a
+ * progress packet and thus should not be processed by the caller, returns 0.
+ * Otherwise, returns 1, releases scratch, and sets sideband_type.
+ *
+ * If this packet is SIDEBAND_PROTOCOL_ERROR, SIDEBAND_REMOTE_ERROR, or a
+ * progress packet, also prints a message to stderr.
+ *
+ * scratch must be a struct strbuf allocated by the caller. It is used to store
+ * progress messages split across multiple packets.
+ */
+int demultiplex_sideband(const char *me, char *buf, int len,
+			 int die_on_error,
+			 struct strbuf *scratch,
+			 enum sideband_type *sideband_type);
 
-int recv_sideband(const char *me, int in_stream, int out);
 void send_sideband(int fd, int band, const char *data, ssize_t sz, int packet_max);
 
 #endif
diff -pruN 1.2.1+git2.18.0-1/git/sigchain.h 1.2.3+git2.25.1-1/git/sigchain.h
--- 1.2.1+git2.18.0-1/git/sigchain.h	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/sigchain.h	2020-02-17 04:47:35.000000000 +0000
@@ -1,12 +1,57 @@
 #ifndef SIGCHAIN_H
 #define SIGCHAIN_H
 
+/**
+ * Code often wants to set a signal handler to clean up temporary files or
+ * other work-in-progress when we die unexpectedly. For multiple pieces of
+ * code to do this without conflicting, each piece of code must remember
+ * the old value of the handler and restore it either when:
+ *
+ *   1. The work-in-progress is finished, and the handler is no longer
+ *      necessary. The handler should revert to the original behavior
+ *      (either another handler, SIG_DFL, or SIG_IGN).
+ *
+ *   2. The signal is received. We should then do our cleanup, then chain
+ *      to the next handler (or die if it is SIG_DFL).
+ *
+ * Sigchain is a tiny library for keeping a stack of handlers. Your handler
+ * and installation code should look something like:
+ *
+ * ------------------------------------------
+ *   void clean_foo_on_signal(int sig)
+ *   {
+ * 	  clean_foo();
+ * 	  sigchain_pop(sig);
+ * 	  raise(sig);
+ *   }
+ *
+ *   void other_func()
+ *   {
+ * 	  sigchain_push_common(clean_foo_on_signal);
+ * 	  mess_up_foo();
+ * 	  clean_foo();
+ *   }
+ * ------------------------------------------
+ *
+ */
+
+/**
+ * Handlers are given the typedef of sigchain_fun. This is the same type
+ * that is given to signal() or sigaction(). It is perfectly reasonable to
+ * push SIG_DFL or SIG_IGN onto the stack.
+ */
 typedef void (*sigchain_fun)(int);
 
+/* You can sigchain_push and sigchain_pop individual signals. */
 int sigchain_push(int sig, sigchain_fun f);
 int sigchain_pop(int sig);
 
+/**
+ * push the handler onto the stack for the common signals:
+ * SIGINT, SIGHUP, SIGTERM, SIGQUIT and SIGPIPE.
+ */
 void sigchain_push_common(sigchain_fun f);
+
 void sigchain_pop_common(void);
 
 #endif /* SIGCHAIN_H */
diff -pruN 1.2.1+git2.18.0-1/git/split-index.c 1.2.3+git2.25.1-1/git/split-index.c
--- 1.2.1+git2.18.0-1/git/split-index.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/split-index.c	2020-02-17 04:47:35.000000000 +0000
@@ -73,16 +73,31 @@ void move_cache_to_base_index(struct ind
 	int i;
 
 	/*
-	 * do not delete old si->base, its index entries may be shared
-	 * with istate->cache[]. Accept a bit of leaking here because
-	 * this code is only used by short-lived update-index.
+	 * If there was a previous base index, then transfer ownership of allocated
+	 * entries to the parent index.
 	 */
+	if (si->base &&
+		si->base->ce_mem_pool) {
+
+		if (!istate->ce_mem_pool)
+			mem_pool_init(&istate->ce_mem_pool, 0);
+
+		mem_pool_combine(istate->ce_mem_pool, istate->split_index->base->ce_mem_pool);
+	}
+
 	si->base = xcalloc(1, sizeof(*si->base));
 	si->base->version = istate->version;
 	/* zero timestamp disables racy test in ce_write_index() */
 	si->base->timestamp = istate->timestamp;
 	ALLOC_GROW(si->base->cache, istate->cache_nr, si->base->cache_alloc);
 	si->base->cache_nr = istate->cache_nr;
+
+	/*
+	 * The mem_pool needs to move with the allocated entries.
+	 */
+	si->base->ce_mem_pool = istate->ce_mem_pool;
+	istate->ce_mem_pool = NULL;
+
 	COPY_ARRAY(si->base->cache, istate->cache, istate->cache_nr);
 	mark_base_index_entries(si->base);
 	for (i = 0; i < si->base->cache_nr; i++)
@@ -96,7 +111,7 @@ static void mark_entry_for_delete(size_t
 		die("position for delete %d exceeds base index size %d",
 		    (int)pos, istate->cache_nr);
 	istate->cache[pos]->ce_flags |= CE_REMOVE;
-	istate->split_index->nr_deletions = 1;
+	istate->split_index->nr_deletions++;
 }
 
 static void replace_entry(size_t pos, void *data)
@@ -123,7 +138,7 @@ static void replace_entry(size_t pos, vo
 	src->ce_flags |= CE_UPDATE_IN_BASE;
 	src->ce_namelen = dst->ce_namelen;
 	copy_cache_entry(dst, src);
-	free(src);
+	discard_cache_entry(src);
 	si->nr_replacements++;
 }
 
@@ -147,7 +162,7 @@ void merge_base_index(struct index_state
 	ewah_each_bit(si->replace_bitmap, replace_entry, istate);
 	ewah_each_bit(si->delete_bitmap, mark_entry_for_delete, istate);
 	if (si->nr_deletions)
-		remove_marked_cache_entries(istate);
+		remove_marked_cache_entries(istate, 0);
 
 	for (i = si->nr_replacements; i < si->saved_cache_nr; i++) {
 		if (!ce_namelen(si->saved_cache[i]))
@@ -173,6 +188,30 @@ void merge_base_index(struct index_state
 	si->saved_cache_nr = 0;
 }
 
+/*
+ * Compare most of the fields in two cache entries, i.e. all except the
+ * hashmap_entry and the name.
+ */
+static int compare_ce_content(struct cache_entry *a, struct cache_entry *b)
+{
+	const unsigned int ondisk_flags = CE_STAGEMASK | CE_VALID |
+					  CE_EXTENDED_FLAGS;
+	unsigned int ce_flags = a->ce_flags;
+	unsigned int base_flags = b->ce_flags;
+	int ret;
+
+	/* only on-disk flags matter */
+	a->ce_flags &= ondisk_flags;
+	b->ce_flags &= ondisk_flags;
+	ret = memcmp(&a->ce_stat_data, &b->ce_stat_data,
+		     offsetof(struct cache_entry, name) -
+		     offsetof(struct cache_entry, ce_stat_data));
+	a->ce_flags = ce_flags;
+	b->ce_flags = base_flags;
+
+	return ret;
+}
+
 void prepare_to_write_split_index(struct index_state *istate)
 {
 	struct split_index *si = init_split_index(istate);
@@ -192,39 +231,110 @@ void prepare_to_write_split_index(struct
 		 */
 		for (i = 0; i < istate->cache_nr; i++) {
 			struct cache_entry *base;
-			/* namelen is checked separately */
-			const unsigned int ondisk_flags =
-				CE_STAGEMASK | CE_VALID | CE_EXTENDED_FLAGS;
-			unsigned int ce_flags, base_flags, ret;
 			ce = istate->cache[i];
-			if (!ce->index)
+			if (!ce->index) {
+				/*
+				 * During simple update index operations this
+				 * is a cache entry that is not present in
+				 * the shared index.  It will be added to the
+				 * split index.
+				 *
+				 * However, it might also represent a file
+				 * that already has a cache entry in the
+				 * shared index, but a new index has just
+				 * been constructed by unpack_trees(), and
+				 * this entry now refers to different content
+				 * than what was recorded in the original
+				 * index, e.g. during 'read-tree -m HEAD^' or
+				 * 'checkout HEAD^'.  In this case the
+				 * original entry in the shared index will be
+				 * marked as deleted, and this entry will be
+				 * added to the split index.
+				 */
 				continue;
+			}
 			if (ce->index > si->base->cache_nr) {
-				ce->index = 0;
-				continue;
+				BUG("ce refers to a shared ce at %d, which is beyond the shared index size %d",
+				    ce->index, si->base->cache_nr);
 			}
 			ce->ce_flags |= CE_MATCHED; /* or "shared" */
 			base = si->base->cache[ce->index - 1];
-			if (ce == base)
+			if (ce == base) {
+				/* The entry is present in the shared index. */
+				if (ce->ce_flags & CE_UPDATE_IN_BASE) {
+					/*
+					 * Already marked for inclusion in
+					 * the split index, either because
+					 * the corresponding file was
+					 * modified and the cached stat data
+					 * was refreshed, or because there
+					 * is already a replacement entry in
+					 * the split index.
+					 * Nothing more to do here.
+					 */
+				} else if (!ce_uptodate(ce) &&
+					   is_racy_timestamp(istate, ce)) {
+					/*
+					 * A racily clean cache entry stored
+					 * only in the shared index: it must
+					 * be added to the split index, so
+					 * the subsequent do_write_index()
+					 * can smudge its stat data.
+					 */
+					ce->ce_flags |= CE_UPDATE_IN_BASE;
+				} else {
+					/*
+					 * The entry is only present in the
+					 * shared index and it was not
+					 * refreshed.
+					 * Just leave it there.
+					 */
+				}
 				continue;
+			}
 			if (ce->ce_namelen != base->ce_namelen ||
 			    strcmp(ce->name, base->name)) {
 				ce->index = 0;
 				continue;
 			}
-			ce_flags = ce->ce_flags;
-			base_flags = base->ce_flags;
-			/* only on-disk flags matter */
-			ce->ce_flags   &= ondisk_flags;
-			base->ce_flags &= ondisk_flags;
-			ret = memcmp(&ce->ce_stat_data, &base->ce_stat_data,
-				     offsetof(struct cache_entry, name) -
-				     offsetof(struct cache_entry, ce_stat_data));
-			ce->ce_flags = ce_flags;
-			base->ce_flags = base_flags;
-			if (ret)
+			/*
+			 * This is the copy of a cache entry that is present
+			 * in the shared index, created by unpack_trees()
+			 * while it constructed a new index.
+			 */
+			if (ce->ce_flags & CE_UPDATE_IN_BASE) {
+				/*
+				 * Already marked for inclusion in the split
+				 * index, either because the corresponding
+				 * file was modified and the cached stat data
+				 * was refreshed, or because the original
+				 * entry already had a replacement entry in
+				 * the split index.
+				 * Nothing to do.
+				 */
+			} else if (!ce_uptodate(ce) &&
+				   is_racy_timestamp(istate, ce)) {
+				/*
+				 * A copy of a racily clean cache entry from
+				 * the shared index.  It must be added to
+				 * the split index, so the subsequent
+				 * do_write_index() can smudge its stat data.
+				 */
 				ce->ce_flags |= CE_UPDATE_IN_BASE;
-			free(base);
+			} else {
+				/*
+				 * Thoroughly compare the cached data to see
+				 * whether it should be marked for inclusion
+				 * in the split index.
+				 *
+				 * This comparison might be unnecessary, as
+				 * code paths modifying the cached data do
+				 * set CE_UPDATE_IN_BASE as well.
+				 */
+				if (compare_ce_content(ce, base))
+					ce->ce_flags |= CE_UPDATE_IN_BASE;
+			}
+			discard_cache_entry(base);
 			si->base->cache[ce->index - 1] = ce;
 		}
 		for (i = 0; i < si->base->cache_nr; i++) {
@@ -301,7 +411,7 @@ void save_or_free_index_entry(struct ind
 	    ce == istate->split_index->base->cache[ce->index - 1])
 		ce->ce_flags |= CE_REMOVE;
 	else
-		free(ce);
+		discard_cache_entry(ce);
 }
 
 void replace_index_entry_in_base(struct index_state *istate,
@@ -314,7 +424,7 @@ void replace_index_entry_in_base(struct
 	    old_entry->index <= istate->split_index->base->cache_nr) {
 		new_entry->index = old_entry->index;
 		if (old_entry != istate->split_index->base->cache[new_entry->index - 1])
-			free(istate->split_index->base->cache[new_entry->index - 1]);
+			discard_cache_entry(istate->split_index->base->cache[new_entry->index - 1]);
 		istate->split_index->base->cache[new_entry->index - 1] = new_entry;
 	}
 }
@@ -330,13 +440,34 @@ void add_split_index(struct index_state
 void remove_split_index(struct index_state *istate)
 {
 	if (istate->split_index) {
+		if (istate->split_index->base) {
+			/*
+			 * When removing the split index, we need to move
+			 * ownership of the mem_pool associated with the
+			 * base index to the main index. There may be cache entries
+			 * allocated from the base's memory pool that are shared with
+			 * the_index.cache[].
+			 */
+			mem_pool_combine(istate->ce_mem_pool,
+					 istate->split_index->base->ce_mem_pool);
+
+			/*
+			 * The split index no longer owns the mem_pool backing
+			 * its cache array. As we are discarding this index,
+			 * mark the index as having no cache entries, so it
+			 * will not attempt to clean up the cache entries or
+			 * validate them.
+			 */
+			istate->split_index->base->cache_nr = 0;
+		}
+
 		/*
-		 * can't discard_split_index(&the_index); because that
-		 * will destroy split_index->base->cache[], which may
-		 * be shared with the_index.cache[]. So yeah we're
-		 * leaking a bit here.
+		 * We can discard the split index because its
+		 * memory pool has been incorporated into the
+		 * memory pool associated with the the_index.
 		 */
-		istate->split_index = NULL;
+		discard_split_index(istate);
+
 		istate->cache_changed |= SOMETHING_CHANGED;
 	}
 }
diff -pruN 1.2.1+git2.18.0-1/git/stable-qsort.c 1.2.3+git2.25.1-1/git/stable-qsort.c
--- 1.2.1+git2.18.0-1/git/stable-qsort.c	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/stable-qsort.c	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,62 @@
+#include "git-compat-util.h"
+
+/*
+ * A merge sort implementation, simplified from the qsort implementation
+ * by Mike Haertel, which is a part of the GNU C Library.
+ */
+
+static void msort_with_tmp(void *b, size_t n, size_t s,
+			   int (*cmp)(const void *, const void *),
+			   char *t)
+{
+	char *tmp;
+	char *b1, *b2;
+	size_t n1, n2;
+
+	if (n <= 1)
+		return;
+
+	n1 = n / 2;
+	n2 = n - n1;
+	b1 = b;
+	b2 = (char *)b + (n1 * s);
+
+	msort_with_tmp(b1, n1, s, cmp, t);
+	msort_with_tmp(b2, n2, s, cmp, t);
+
+	tmp = t;
+
+	while (n1 > 0 && n2 > 0) {
+		if (cmp(b1, b2) <= 0) {
+			memcpy(tmp, b1, s);
+			tmp += s;
+			b1 += s;
+			--n1;
+		} else {
+			memcpy(tmp, b2, s);
+			tmp += s;
+			b2 += s;
+			--n2;
+		}
+	}
+	if (n1 > 0)
+		memcpy(tmp, b1, n1 * s);
+	memcpy(b, t, (n - n2) * s);
+}
+
+void git_stable_qsort(void *b, size_t n, size_t s,
+		      int (*cmp)(const void *, const void *))
+{
+	const size_t size = st_mult(n, s);
+	char buf[1024];
+
+	if (size < sizeof(buf)) {
+		/* The temporary array fits on the small on-stack buffer. */
+		msort_with_tmp(b, n, s, cmp, buf);
+	} else {
+		/* It's somewhat large, so malloc it.  */
+		char *tmp = xmalloc(size);
+		msort_with_tmp(b, n, s, cmp, tmp);
+		free(tmp);
+	}
+}
diff -pruN 1.2.1+git2.18.0-1/git/strbuf.c 1.2.3+git2.25.1-1/git/strbuf.c
--- 1.2.1+git2.18.0-1/git/strbuf.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/strbuf.c	2020-02-17 04:47:35.000000000 +0000
@@ -120,6 +120,15 @@ void strbuf_trim_trailing_dir_sep(struct
 	sb->buf[sb->len] = '\0';
 }
 
+void strbuf_trim_trailing_newline(struct strbuf *sb)
+{
+	if (sb->len > 0 && sb->buf[sb->len - 1] == '\n') {
+		if (--sb->len > 0 && sb->buf[sb->len - 1] == '\r')
+			--sb->len;
+		sb->buf[sb->len] = '\0';
+	}
+}
+
 void strbuf_ltrim(struct strbuf *sb)
 {
 	char *b = sb->buf;
@@ -134,7 +143,7 @@ void strbuf_ltrim(struct strbuf *sb)
 int strbuf_reencode(struct strbuf *sb, const char *from, const char *to)
 {
 	char *out;
-	int len;
+	size_t len;
 
 	if (same_encoding(from, to))
 		return 0;
@@ -209,7 +218,7 @@ void strbuf_list_free(struct strbuf **sb
 
 int strbuf_cmp(const struct strbuf *a, const struct strbuf *b)
 {
-	int len = a->len < b->len ? a->len: b->len;
+	size_t len = a->len < b->len ? a->len: b->len;
 	int cmp = memcmp(a->buf, b->buf, len);
 	if (cmp)
 		return cmp;
@@ -240,6 +249,42 @@ void strbuf_insert(struct strbuf *sb, si
 	strbuf_splice(sb, pos, 0, data, len);
 }
 
+void strbuf_vinsertf(struct strbuf *sb, size_t pos, const char *fmt, va_list ap)
+{
+	int len, len2;
+	char save;
+	va_list cp;
+
+	if (pos > sb->len)
+		die("`pos' is too far after the end of the buffer");
+	va_copy(cp, ap);
+	len = vsnprintf(sb->buf + sb->len, 0, fmt, cp);
+	va_end(cp);
+	if (len < 0)
+		BUG("your vsnprintf is broken (returned %d)", len);
+	if (!len)
+		return; /* nothing to do */
+	if (unsigned_add_overflows(sb->len, len))
+		die("you want to use way too much memory");
+	strbuf_grow(sb, len);
+	memmove(sb->buf + pos + len, sb->buf + pos, sb->len - pos);
+	/* vsnprintf() will append a NUL, overwriting one of our characters */
+	save = sb->buf[pos + len];
+	len2 = vsnprintf(sb->buf + pos, len + 1, fmt, ap);
+	sb->buf[pos + len] = save;
+	if (len2 != len)
+		BUG("your vsnprintf is broken (returns inconsistent lengths)");
+	strbuf_setlen(sb, sb->len + len);
+}
+
+void strbuf_insertf(struct strbuf *sb, size_t pos, const char *fmt, ...)
+{
+	va_list ap;
+	va_start(ap, fmt);
+	strbuf_vinsertf(sb, pos, fmt, ap);
+	va_end(ap);
+}
+
 void strbuf_remove(struct strbuf *sb, size_t pos, size_t len)
 {
 	strbuf_splice(sb, pos, len, "", 0);
@@ -259,6 +304,21 @@ void strbuf_addbuf(struct strbuf *sb, co
 	strbuf_setlen(sb, sb->len + sb2->len);
 }
 
+const char *strbuf_join_argv(struct strbuf *buf,
+			     int argc, const char **argv, char delim)
+{
+	if (!argc)
+		return buf->buf;
+
+	strbuf_addstr(buf, *argv);
+	while (--argc) {
+		strbuf_addch(buf, delim);
+		strbuf_addstr(buf, *(++argv));
+	}
+
+	return buf->buf;
+}
+
 void strbuf_addchars(struct strbuf *sb, int c, size_t n)
 {
 	strbuf_grow(sb, n);
@@ -371,6 +431,27 @@ void strbuf_expand(struct strbuf *sb, co
 	}
 }
 
+size_t strbuf_expand_literal_cb(struct strbuf *sb,
+				const char *placeholder,
+				void *context)
+{
+	int ch;
+
+	switch (placeholder[0]) {
+	case 'n':		/* newline */
+		strbuf_addch(sb, '\n');
+		return 1;
+	case 'x':
+		/* %x00 == NUL, %x0a == LF, etc. */
+		ch = hex2chr(placeholder + 1);
+		if (ch < 0)
+			return 0;
+		strbuf_addch(sb, ch);
+		return 3;
+	}
+	return 0;
+}
+
 size_t strbuf_expand_dict_cb(struct strbuf *sb, const char *placeholder,
 		void *context)
 {
@@ -389,7 +470,7 @@ size_t strbuf_expand_dict_cb(struct strb
 
 void strbuf_addbuf_percentquote(struct strbuf *dst, const struct strbuf *src)
 {
-	int i, len = src->len;
+	size_t i, len = src->len;
 
 	for (i = 0; i < len; i++) {
 		if (src->buf[i] == '%')
@@ -469,7 +550,7 @@ int strbuf_readlink(struct strbuf *sb, c
 		hint = 32;
 
 	while (hint < STRBUF_MAXLINK) {
-		int len;
+		ssize_t len;
 
 		strbuf_grow(sb, hint);
 		len = readlink(path, sb->buf, hint);
@@ -693,8 +774,10 @@ void strbuf_addstr_xml_quoted(struct str
 	}
 }
 
-static int is_rfc3986_reserved(char ch)
+int is_rfc3986_reserved_or_unreserved(char ch)
 {
+	if (is_rfc3986_unreserved(ch))
+		return 1;
 	switch (ch) {
 		case '!': case '*': case '\'': case '(': case ')': case ';':
 		case ':': case '@': case '&': case '=': case '+': case '$':
@@ -704,20 +787,19 @@ static int is_rfc3986_reserved(char ch)
 	return 0;
 }
 
-static int is_rfc3986_unreserved(char ch)
+int is_rfc3986_unreserved(char ch)
 {
 	return isalnum(ch) ||
 		ch == '-' || ch == '_' || ch == '.' || ch == '~';
 }
 
 static void strbuf_add_urlencode(struct strbuf *sb, const char *s, size_t len,
-				 int reserved)
+				 char_predicate allow_unencoded_fn)
 {
 	strbuf_grow(sb, len);
 	while (len--) {
 		char ch = *s++;
-		if (is_rfc3986_unreserved(ch) ||
-		    (!reserved && is_rfc3986_reserved(ch)))
+		if (allow_unencoded_fn(ch))
 			strbuf_addch(sb, ch);
 		else
 			strbuf_addf(sb, "%%%02x", (unsigned char)ch);
@@ -725,30 +807,62 @@ static void strbuf_add_urlencode(struct
 }
 
 void strbuf_addstr_urlencode(struct strbuf *sb, const char *s,
-			     int reserved)
+			     char_predicate allow_unencoded_fn)
 {
-	strbuf_add_urlencode(sb, s, strlen(s), reserved);
+	strbuf_add_urlencode(sb, s, strlen(s), allow_unencoded_fn);
 }
 
-void strbuf_humanise_bytes(struct strbuf *buf, off_t bytes)
+static void strbuf_humanise(struct strbuf *buf, off_t bytes,
+				 int humanise_rate)
 {
 	if (bytes > 1 << 30) {
-		strbuf_addf(buf, "%u.%2.2u GiB",
-			    (int)(bytes >> 30),
-			    (int)(bytes & ((1 << 30) - 1)) / 10737419);
+		strbuf_addf(buf,
+				humanise_rate == 0 ?
+					/* TRANSLATORS: IEC 80000-13:2008 gibibyte */
+					_("%u.%2.2u GiB") :
+					/* TRANSLATORS: IEC 80000-13:2008 gibibyte/second */
+					_("%u.%2.2u GiB/s"),
+			    (unsigned)(bytes >> 30),
+			    (unsigned)(bytes & ((1 << 30) - 1)) / 10737419);
 	} else if (bytes > 1 << 20) {
-		int x = bytes + 5243;  /* for rounding */
-		strbuf_addf(buf, "%u.%2.2u MiB",
+		unsigned x = bytes + 5243;  /* for rounding */
+		strbuf_addf(buf,
+				humanise_rate == 0 ?
+					/* TRANSLATORS: IEC 80000-13:2008 mebibyte */
+					_("%u.%2.2u MiB") :
+					/* TRANSLATORS: IEC 80000-13:2008 mebibyte/second */
+					_("%u.%2.2u MiB/s"),
 			    x >> 20, ((x & ((1 << 20) - 1)) * 100) >> 20);
 	} else if (bytes > 1 << 10) {
-		int x = bytes + 5;  /* for rounding */
-		strbuf_addf(buf, "%u.%2.2u KiB",
+		unsigned x = bytes + 5;  /* for rounding */
+		strbuf_addf(buf,
+				humanise_rate == 0 ?
+					/* TRANSLATORS: IEC 80000-13:2008 kibibyte */
+					_("%u.%2.2u KiB") :
+					/* TRANSLATORS: IEC 80000-13:2008 kibibyte/second */
+					_("%u.%2.2u KiB/s"),
 			    x >> 10, ((x & ((1 << 10) - 1)) * 100) >> 10);
 	} else {
-		strbuf_addf(buf, "%u bytes", (int)bytes);
+		strbuf_addf(buf,
+				humanise_rate == 0 ?
+					/* TRANSLATORS: IEC 80000-13:2008 byte */
+					Q_("%u byte", "%u bytes", (unsigned)bytes) :
+					/* TRANSLATORS: IEC 80000-13:2008 byte/second */
+					Q_("%u byte/s", "%u bytes/s", (unsigned)bytes),
+				(unsigned)bytes);
 	}
 }
 
+void strbuf_humanise_bytes(struct strbuf *buf, off_t bytes)
+{
+	strbuf_humanise(buf, bytes, 0);
+}
+
+void strbuf_humanise_rate(struct strbuf *buf, off_t bytes)
+{
+	strbuf_humanise(buf, bytes, 1);
+}
+
 void strbuf_add_absolute_path(struct strbuf *sb, const char *path)
 {
 	if (!*path)
@@ -921,7 +1035,7 @@ void strbuf_add_unique_abbrev(struct str
 			      int abbrev_len)
 {
 	int r;
-	strbuf_grow(sb, GIT_SHA1_HEXSZ + 1);
+	strbuf_grow(sb, GIT_MAX_HEXSZ + 1);
 	r = find_unique_abbrev_r(sb->buf + sb->len, oid, abbrev_len);
 	strbuf_setlen(sb, sb->len + r);
 }
@@ -960,7 +1074,7 @@ static size_t cleanup(char *line, size_t
  */
 void strbuf_stripspace(struct strbuf *sb, int skip_comments)
 {
-	int empties = 0;
+	size_t empties = 0;
 	size_t i, j, len, newlen;
 	char *eol;
 
@@ -1011,3 +1125,31 @@ int strbuf_normalize_path(struct strbuf
 	strbuf_release(&dst);
 	return 0;
 }
+
+int strbuf_edit_interactively(struct strbuf *buffer, const char *path,
+			      const char *const *env)
+{
+	char *path2 = NULL;
+	int fd, res = 0;
+
+	if (!is_absolute_path(path))
+		path = path2 = xstrdup(git_path("%s", path));
+
+	fd = open(path, O_WRONLY | O_CREAT | O_TRUNC, 0666);
+	if (fd < 0)
+		res = error_errno(_("could not open '%s' for writing"), path);
+	else if (write_in_full(fd, buffer->buf, buffer->len) < 0) {
+		res = error_errno(_("could not write to '%s'"), path);
+		close(fd);
+	} else if (close(fd) < 0)
+		res = error_errno(_("could not close '%s'"), path);
+	else {
+		strbuf_reset(buffer);
+		if (launch_editor(path, buffer, env) < 0)
+			res = error_errno(_("could not edit '%s'"), path);
+		unlink(path);
+	}
+
+	free(path2);
+	return res;
+}
diff -pruN 1.2.1+git2.18.0-1/git/strbuf.h 1.2.3+git2.25.1-1/git/strbuf.h
--- 1.2.1+git2.18.0-1/git/strbuf.h	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/strbuf.h	2020-02-17 04:47:35.000000000 +0000
@@ -87,7 +87,7 @@ struct object_id;
  * Initialize the structure. The second parameter can be zero or a bigger
  * number to allocate memory, in case you want to prevent further reallocs.
  */
-extern void strbuf_init(struct strbuf *, size_t);
+void strbuf_init(struct strbuf *sb, size_t alloc);
 
 /**
  * Release a string buffer and the memory it used. After this call, the
@@ -97,7 +97,7 @@ extern void strbuf_init(struct strbuf *,
  * To clear a strbuf in preparation for further use without the overhead
  * of free()ing and malloc()ing again, use strbuf_reset() instead.
  */
-extern void strbuf_release(struct strbuf *);
+void strbuf_release(struct strbuf *sb);
 
 /**
  * Detach the string from the strbuf and returns it; you now own the
@@ -107,7 +107,7 @@ extern void strbuf_release(struct strbuf
  * The strbuf that previously held the string is reset to `STRBUF_INIT` so
  * it can be reused after calling this function.
  */
-extern char *strbuf_detach(struct strbuf *, size_t *);
+char *strbuf_detach(struct strbuf *sb, size_t *sz);
 
 /**
  * Attach a string to a buffer. You should specify the string to attach,
@@ -117,7 +117,7 @@ extern char *strbuf_detach(struct strbuf
  * malloc()ed, and after attaching, the pointer cannot be relied upon
  * anymore, and neither be free()d directly.
  */
-extern void strbuf_attach(struct strbuf *, void *, size_t, size_t);
+void strbuf_attach(struct strbuf *sb, void *str, size_t len, size_t mem);
 
 /**
  * Swap the contents of two string buffers.
@@ -148,7 +148,7 @@ static inline size_t strbuf_avail(const
  * This is never a needed operation, but can be critical for performance in
  * some cases.
  */
-extern void strbuf_grow(struct strbuf *, size_t);
+void strbuf_grow(struct strbuf *sb, size_t amount);
 
 /**
  * Set the length of the buffer to a given value. This function does *not*
@@ -183,30 +183,33 @@ static inline void strbuf_setlen(struct
  * Strip whitespace from the beginning (`ltrim`), end (`rtrim`), or both side
  * (`trim`) of a string.
  */
-extern void strbuf_trim(struct strbuf *);
-extern void strbuf_rtrim(struct strbuf *);
-extern void strbuf_ltrim(struct strbuf *);
+void strbuf_trim(struct strbuf *sb);
+void strbuf_rtrim(struct strbuf *sb);
+void strbuf_ltrim(struct strbuf *sb);
 
 /* Strip trailing directory separators */
-extern void strbuf_trim_trailing_dir_sep(struct strbuf *);
+void strbuf_trim_trailing_dir_sep(struct strbuf *sb);
+
+/* Strip trailing LF or CR/LF */
+void strbuf_trim_trailing_newline(struct strbuf *sb);
 
 /**
  * Replace the contents of the strbuf with a reencoded form.  Returns -1
  * on error, 0 on success.
  */
-extern int strbuf_reencode(struct strbuf *sb, const char *from, const char *to);
+int strbuf_reencode(struct strbuf *sb, const char *from, const char *to);
 
 /**
  * Lowercase each character in the buffer using `tolower`.
  */
-extern void strbuf_tolower(struct strbuf *sb);
+void strbuf_tolower(struct strbuf *sb);
 
 /**
  * Compare two buffers. Returns an integer less than, equal to, or greater
  * than zero if the first buffer is found, respectively, to be less than,
  * to match, or be greater than the second buffer.
  */
-extern int strbuf_cmp(const struct strbuf *, const struct strbuf *);
+int strbuf_cmp(const struct strbuf *first, const struct strbuf *second);
 
 
 /**
@@ -233,37 +236,47 @@ static inline void strbuf_addch(struct s
 /**
  * Add a character the specified number of times to the buffer.
  */
-extern void strbuf_addchars(struct strbuf *sb, int c, size_t n);
+void strbuf_addchars(struct strbuf *sb, int c, size_t n);
 
 /**
  * Insert data to the given position of the buffer. The remaining contents
  * will be shifted, not overwritten.
  */
-extern void strbuf_insert(struct strbuf *, size_t pos, const void *, size_t);
+void strbuf_insert(struct strbuf *sb, size_t pos, const void *, size_t);
+
+/**
+ * Insert data to the given position of the buffer giving a printf format
+ * string. The contents will be shifted, not overwritten.
+ */
+void strbuf_vinsertf(struct strbuf *sb, size_t pos, const char *fmt,
+		     va_list ap);
+
+void strbuf_insertf(struct strbuf *sb, size_t pos, const char *fmt, ...);
 
 /**
  * Remove given amount of data from a given position of the buffer.
  */
-extern void strbuf_remove(struct strbuf *, size_t pos, size_t len);
+void strbuf_remove(struct strbuf *sb, size_t pos, size_t len);
 
 /**
  * Remove the bytes between `pos..pos+len` and replace it with the given
  * data.
  */
-extern void strbuf_splice(struct strbuf *, size_t pos, size_t len,
-			  const void *, size_t);
+void strbuf_splice(struct strbuf *sb, size_t pos, size_t len,
+		   const void *data, size_t data_len);
 
 /**
  * Add a NUL-terminated string to the buffer. Each line will be prepended
  * by a comment character and a blank.
  */
-extern void strbuf_add_commented_lines(struct strbuf *out, const char *buf, size_t size);
+void strbuf_add_commented_lines(struct strbuf *out,
+				const char *buf, size_t size);
 
 
 /**
  * Add data of given length to the buffer.
  */
-extern void strbuf_add(struct strbuf *, const void *, size_t);
+void strbuf_add(struct strbuf *sb, const void *data, size_t len);
 
 /**
  * Add a NUL-terminated string to the buffer.
@@ -282,7 +295,14 @@ static inline void strbuf_addstr(struct
 /**
  * Copy the contents of another buffer at the end of the current one.
  */
-extern void strbuf_addbuf(struct strbuf *sb, const struct strbuf *sb2);
+void strbuf_addbuf(struct strbuf *sb, const struct strbuf *sb2);
+
+/**
+ * Join the arguments into a buffer. `delim` is put between every
+ * two arguments.
+ */
+const char *strbuf_join_argv(struct strbuf *buf, int argc,
+			     const char **argv, char delim);
 
 /**
  * This function can be used to expand a format string containing
@@ -308,8 +328,21 @@ extern void strbuf_addbuf(struct strbuf
  * parameters to the callback, `strbuf_expand()` passes a context pointer,
  * which can be used by the programmer of the callback as she sees fit.
  */
-typedef size_t (*expand_fn_t) (struct strbuf *sb, const char *placeholder, void *context);
-extern void strbuf_expand(struct strbuf *sb, const char *format, expand_fn_t fn, void *context);
+typedef size_t (*expand_fn_t) (struct strbuf *sb,
+			       const char *placeholder,
+			       void *context);
+void strbuf_expand(struct strbuf *sb,
+		   const char *format,
+		   expand_fn_t fn,
+		   void *context);
+
+/**
+ * Used as callback for `strbuf_expand` to only expand literals
+ * (i.e. %n and %xNN). The context argument is ignored.
+ */
+size_t strbuf_expand_literal_cb(struct strbuf *sb,
+				const char *placeholder,
+				void *context);
 
 /**
  * Used as callback for `strbuf_expand()`, expects an array of
@@ -321,7 +354,9 @@ struct strbuf_expand_dict_entry {
 	const char *placeholder;
 	const char *value;
 };
-extern size_t strbuf_expand_dict_cb(struct strbuf *sb, const char *placeholder, void *context);
+size_t strbuf_expand_dict_cb(struct strbuf *sb,
+			     const char *placeholder,
+			     void *context);
 
 /**
  * Append the contents of one strbuf to another, quoting any
@@ -329,29 +364,35 @@ extern size_t strbuf_expand_dict_cb(stru
  * destination. This is useful for literal data to be fed to either
  * strbuf_expand or to the *printf family of functions.
  */
-extern void strbuf_addbuf_percentquote(struct strbuf *dst, const struct strbuf *src);
+void strbuf_addbuf_percentquote(struct strbuf *dst, const struct strbuf *src);
 
 /**
  * Append the given byte size as a human-readable string (i.e. 12.23 KiB,
  * 3.50 MiB).
  */
-extern void strbuf_humanise_bytes(struct strbuf *buf, off_t bytes);
+void strbuf_humanise_bytes(struct strbuf *buf, off_t bytes);
+
+/**
+ * Append the given byte rate as a human-readable string (i.e. 12.23 KiB/s,
+ * 3.50 MiB/s).
+ */
+void strbuf_humanise_rate(struct strbuf *buf, off_t bytes);
 
 /**
  * Add a formatted string to the buffer.
  */
 __attribute__((format (printf,2,3)))
-extern void strbuf_addf(struct strbuf *sb, const char *fmt, ...);
+void strbuf_addf(struct strbuf *sb, const char *fmt, ...);
 
 /**
  * Add a formatted string prepended by a comment character and a
  * blank to the buffer.
  */
 __attribute__((format (printf, 2, 3)))
-extern void strbuf_commented_addf(struct strbuf *sb, const char *fmt, ...);
+void strbuf_commented_addf(struct strbuf *sb, const char *fmt, ...);
 
 __attribute__((format (printf,2,0)))
-extern void strbuf_vaddf(struct strbuf *sb, const char *fmt, va_list ap);
+void strbuf_vaddf(struct strbuf *sb, const char *fmt, va_list ap);
 
 /**
  * Add the time specified by `tm`, as formatted by `strftime`.
@@ -361,9 +402,9 @@ extern void strbuf_vaddf(struct strbuf *
  * `suppress_tz_name`, when set, expands %Z internally to the empty
  * string rather than passing it to `strftime`.
  */
-extern void strbuf_addftime(struct strbuf *sb, const char *fmt,
-			    const struct tm *tm, int tz_offset,
-			    int suppress_tz_name);
+void strbuf_addftime(struct strbuf *sb, const char *fmt,
+		    const struct tm *tm, int tz_offset,
+		    int suppress_tz_name);
 
 /**
  * Read a given size of data from a FILE* pointer to the buffer.
@@ -373,14 +414,14 @@ extern void strbuf_addftime(struct strbu
  * `strbuf_read()`, `strbuf_read_file()` and `strbuf_getline_*()`
  * family of functions have the same behaviour as well.
  */
-extern size_t strbuf_fread(struct strbuf *, size_t, FILE *);
+size_t strbuf_fread(struct strbuf *sb, size_t size, FILE *file);
 
 /**
  * Read the contents of a given file descriptor. The third argument can be
  * used to give a hint about the file size, to avoid reallocs.  If read fails,
  * any partial read is undone.
  */
-extern ssize_t strbuf_read(struct strbuf *, int fd, size_t hint);
+ssize_t strbuf_read(struct strbuf *sb, int fd, size_t hint);
 
 /**
  * Read the contents of a given file descriptor partially by using only one
@@ -388,7 +429,7 @@ extern ssize_t strbuf_read(struct strbuf
  * file size, to avoid reallocs. Returns the number of new bytes appended to
  * the sb.
  */
-extern ssize_t strbuf_read_once(struct strbuf *, int fd, size_t hint);
+ssize_t strbuf_read_once(struct strbuf *sb, int fd, size_t hint);
 
 /**
  * Read the contents of a file, specified by its path. The third argument
@@ -396,19 +437,19 @@ extern ssize_t strbuf_read_once(struct s
  * Return the number of bytes read or a negative value if some error
  * occurred while opening or reading the file.
  */
-extern ssize_t strbuf_read_file(struct strbuf *sb, const char *path, size_t hint);
+ssize_t strbuf_read_file(struct strbuf *sb, const char *path, size_t hint);
 
 /**
  * Read the target of a symbolic link, specified by its path.  The third
  * argument can be used to give a hint about the size, to avoid reallocs.
  */
-extern int strbuf_readlink(struct strbuf *sb, const char *path, size_t hint);
+int strbuf_readlink(struct strbuf *sb, const char *path, size_t hint);
 
 /**
  * Write the whole content of the strbuf to the stream not stopping at
  * NUL bytes.
  */
-extern ssize_t strbuf_write(struct strbuf *sb, FILE *stream);
+ssize_t strbuf_write(struct strbuf *sb, FILE *stream);
 
 /**
  * Read a line from a FILE *, overwriting the existing contents of
@@ -422,10 +463,10 @@ extern ssize_t strbuf_write(struct strbu
 typedef int (*strbuf_getline_fn)(struct strbuf *, FILE *);
 
 /* Uses LF as the line terminator */
-extern int strbuf_getline_lf(struct strbuf *sb, FILE *fp);
+int strbuf_getline_lf(struct strbuf *sb, FILE *fp);
 
 /* Uses NUL as the line terminator */
-extern int strbuf_getline_nul(struct strbuf *sb, FILE *fp);
+int strbuf_getline_nul(struct strbuf *sb, FILE *fp);
 
 /*
  * Similar to strbuf_getline_lf(), but additionally treats a CR that
@@ -434,14 +475,14 @@ extern int strbuf_getline_nul(struct str
  * that can come from platforms whose native text format is CRLF
  * terminated.
  */
-extern int strbuf_getline(struct strbuf *, FILE *);
+int strbuf_getline(struct strbuf *sb, FILE *file);
 
 
 /**
  * Like `strbuf_getline`, but keeps the trailing terminator (if
  * any) in the buffer.
  */
-extern int strbuf_getwholeline(struct strbuf *, FILE *, int);
+int strbuf_getwholeline(struct strbuf *sb, FILE *file, int term);
 
 /**
  * Like `strbuf_getwholeline`, but operates on a file descriptor.
@@ -449,19 +490,19 @@ extern int strbuf_getwholeline(struct st
  * use it unless you need the correct position in the file
  * descriptor.
  */
-extern int strbuf_getwholeline_fd(struct strbuf *, int, int);
+int strbuf_getwholeline_fd(struct strbuf *sb, int fd, int term);
 
 /**
  * Set the buffer to the path of the current working directory.
  */
-extern int strbuf_getcwd(struct strbuf *sb);
+int strbuf_getcwd(struct strbuf *sb);
 
 /**
  * Add a path to a buffer, converting a relative path to an
  * absolute one in the process.  Symbolic links are not
  * resolved.
  */
-extern void strbuf_add_absolute_path(struct strbuf *sb, const char *path);
+void strbuf_add_absolute_path(struct strbuf *sb, const char *path);
 
 /**
  * Canonize `path` (make it absolute, resolve symlinks, remove extra
@@ -475,7 +516,7 @@ extern void strbuf_add_absolute_path(str
  * Callers that don't mind links should use the more lightweight
  * strbuf_add_absolute_path() instead.
  */
-extern void strbuf_add_real_path(struct strbuf *sb, const char *path);
+void strbuf_add_real_path(struct strbuf *sb, const char *path);
 
 
 /**
@@ -483,13 +524,13 @@ extern void strbuf_add_real_path(struct
  * normalize_path_copy() for details. If an error occurs, the contents of "sb"
  * are left untouched, and -1 is returned.
  */
-extern int strbuf_normalize_path(struct strbuf *sb);
+int strbuf_normalize_path(struct strbuf *sb);
 
 /**
  * Strip whitespace from a buffer. The second parameter controls if
  * comments are considered contents to be removed or not.
  */
-extern void strbuf_stripspace(struct strbuf *buf, int skip_comments);
+void strbuf_stripspace(struct strbuf *buf, int skip_comments);
 
 static inline int strbuf_strip_suffix(struct strbuf *sb, const char *suffix)
 {
@@ -518,8 +559,8 @@ static inline int strbuf_strip_suffix(st
  * For lighter-weight alternatives, see string_list_split() and
  * string_list_split_in_place().
  */
-extern struct strbuf **strbuf_split_buf(const char *, size_t,
-					int terminator, int max);
+struct strbuf **strbuf_split_buf(const char *str, size_t len,
+				 int terminator, int max);
 
 static inline struct strbuf **strbuf_split_str(const char *str,
 					       int terminator, int max)
@@ -528,7 +569,7 @@ static inline struct strbuf **strbuf_spl
 }
 
 static inline struct strbuf **strbuf_split_max(const struct strbuf *sb,
-						int terminator, int max)
+					       int terminator, int max)
 {
 	return strbuf_split_buf(sb->buf, sb->len, terminator, max);
 }
@@ -549,23 +590,23 @@ static inline struct strbuf **strbuf_spl
  *   'element1, element2, ..., elementN'
  * to str.  If only one element, just write "element1" to str.
  */
-extern void strbuf_add_separated_string_list(struct strbuf *str,
-					     const char *sep,
-					     struct string_list *slist);
+void strbuf_add_separated_string_list(struct strbuf *str,
+				      const char *sep,
+				      struct string_list *slist);
 
 /**
  * Free a NULL-terminated list of strbufs (for example, the return
  * values of the strbuf_split*() functions).
  */
-extern void strbuf_list_free(struct strbuf **);
+void strbuf_list_free(struct strbuf **list);
 
 /**
  * Add the abbreviation, as generated by find_unique_abbrev, of `sha1` to
  * the strbuf `sb`.
  */
-extern void strbuf_add_unique_abbrev(struct strbuf *sb,
-				     const struct object_id *oid,
-				     int abbrev_len);
+void strbuf_add_unique_abbrev(struct strbuf *sb,
+			      const struct object_id *oid,
+			      int abbrev_len);
 
 /**
  * Launch the user preferred editor to edit a file and fill the buffer
@@ -574,15 +615,34 @@ extern void strbuf_add_unique_abbrev(str
  * run in. If the buffer is NULL the editor is launched as usual but the
  * file's contents are not read into the buffer upon completion.
  */
-extern int launch_editor(const char *path, struct strbuf *buffer, const char *const *env);
+int launch_editor(const char *path, struct strbuf *buffer,
+		  const char *const *env);
 
-extern void strbuf_add_lines(struct strbuf *sb, const char *prefix, const char *buf, size_t size);
+int launch_sequence_editor(const char *path, struct strbuf *buffer,
+			   const char *const *env);
+
+/*
+ * In contrast to `launch_editor()`, this function writes out the contents
+ * of the specified file first, then clears the `buffer`, then launches
+ * the editor and reads back in the file contents into the `buffer`.
+ * Finally, it deletes the temporary file.
+ *
+ * If `path` is relative, it refers to a file in the `.git` directory.
+ */
+int strbuf_edit_interactively(struct strbuf *buffer, const char *path,
+			      const char *const *env);
+
+void strbuf_add_lines(struct strbuf *sb,
+		      const char *prefix,
+		      const char *buf,
+		      size_t size);
 
 /**
  * Append s to sb, with the characters '<', '>', '&' and '"' converted
  * into XML entities.
  */
-extern void strbuf_addstr_xml_quoted(struct strbuf *sb, const char *s);
+void strbuf_addstr_xml_quoted(struct strbuf *sb,
+			      const char *s);
 
 /**
  * "Complete" the contents of `sb` by ensuring that either it ends with the
@@ -612,8 +672,8 @@ static inline void strbuf_complete_line(
  * If "allowed" is non-zero, restrict the set of allowed expansions. See
  * interpret_branch_name() for details.
  */
-extern void strbuf_branchname(struct strbuf *sb, const char *name,
-			      unsigned allowed);
+void strbuf_branchname(struct strbuf *sb, const char *name,
+		       unsigned allowed);
 
 /*
  * Like strbuf_branchname() above, but confirm that the result is
@@ -621,15 +681,20 @@ extern void strbuf_branchname(struct str
  *
  * The return value is "0" if the result is valid, and "-1" otherwise.
  */
-extern int strbuf_check_branch_ref(struct strbuf *sb, const char *name);
+int strbuf_check_branch_ref(struct strbuf *sb, const char *name);
+
+typedef int (*char_predicate)(char ch);
+
+int is_rfc3986_unreserved(char ch);
+int is_rfc3986_reserved_or_unreserved(char ch);
 
-extern void strbuf_addstr_urlencode(struct strbuf *, const char *,
-				    int reserved);
+void strbuf_addstr_urlencode(struct strbuf *sb, const char *name,
+			     char_predicate allow_unencoded_fn);
 
 __attribute__((format (printf,1,2)))
-extern int printf_ln(const char *fmt, ...);
+int printf_ln(const char *fmt, ...);
 __attribute__((format (printf,2,3)))
-extern int fprintf_ln(FILE *fp, const char *fmt, ...);
+int fprintf_ln(FILE *fp, const char *fmt, ...);
 
 char *xstrdup_tolower(const char *);
 char *xstrdup_toupper(const char *);
diff -pruN 1.2.1+git2.18.0-1/git/streaming.c 1.2.3+git2.25.1-1/git/streaming.c
--- 1.2.1+git2.18.0-1/git/streaming.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/streaming.c	2020-02-17 04:47:35.000000000 +0000
@@ -338,16 +338,16 @@ static struct stream_vtbl loose_vtbl = {
 
 static open_method_decl(loose)
 {
-	st->u.loose.mapped = map_sha1_file(the_repository,
-					   oid->hash, &st->u.loose.mapsize);
+	st->u.loose.mapped = map_loose_object(the_repository,
+					      oid, &st->u.loose.mapsize);
 	if (!st->u.loose.mapped)
 		return -1;
-	if ((unpack_sha1_header(&st->z,
-				st->u.loose.mapped,
-				st->u.loose.mapsize,
-				st->u.loose.hdr,
-				sizeof(st->u.loose.hdr)) < 0) ||
-	    (parse_sha1_header(st->u.loose.hdr, &st->size) < 0)) {
+	if ((unpack_loose_header(&st->z,
+				 st->u.loose.mapped,
+				 st->u.loose.mapsize,
+				 st->u.loose.hdr,
+				 sizeof(st->u.loose.hdr)) < 0) ||
+	    (parse_loose_header(st->u.loose.hdr, &st->size) < 0)) {
 		git_inflate_end(&st->z);
 		munmap(st->u.loose.mapped, st->u.loose.mapsize);
 		return -1;
@@ -408,6 +408,15 @@ static read_method_decl(pack_non_delta)
 			st->z_state = z_done;
 			break;
 		}
+
+		/*
+		 * Unlike the loose object case, we do not have to worry here
+		 * about running out of input bytes and spinning infinitely. If
+		 * we get Z_BUF_ERROR due to too few input bytes, then we'll
+		 * replenish them in the next use_pack() call when we loop. If
+		 * we truly hit the end of the pack (i.e., because it's corrupt
+		 * or truncated), then use_pack() catches that and will die().
+		 */
 		if (status != Z_OK && status != Z_BUF_ERROR) {
 			git_inflate_end(&st->z);
 			st->z_state = z_error;
@@ -490,7 +499,7 @@ static struct stream_vtbl incore_vtbl =
 
 static open_method_decl(incore)
 {
-	st->u.incore.buf = read_object_file_extended(oid, type, &st->size, 0);
+	st->u.incore.buf = read_object_file_extended(the_repository, oid, type, &st->size, 0);
 	st->u.incore.read_ptr = 0;
 	st->vtbl = &incore_vtbl;
 
diff -pruN 1.2.1+git2.18.0-1/git/streaming.h 1.2.3+git2.25.1-1/git/streaming.h
--- 1.2.1+git2.18.0-1/git/streaming.h	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/streaming.h	2020-02-17 04:47:35.000000000 +0000
@@ -8,10 +8,10 @@
 /* opaque */
 struct git_istream;
 
-extern struct git_istream *open_istream(const struct object_id *, enum object_type *, unsigned long *, struct stream_filter *);
-extern int close_istream(struct git_istream *);
-extern ssize_t read_istream(struct git_istream *, void *, size_t);
+struct git_istream *open_istream(const struct object_id *, enum object_type *, unsigned long *, struct stream_filter *);
+int close_istream(struct git_istream *);
+ssize_t read_istream(struct git_istream *, void *, size_t);
 
-extern int stream_blob_to_fd(int fd, const struct object_id *, struct stream_filter *, int can_seek);
+int stream_blob_to_fd(int fd, const struct object_id *, struct stream_filter *, int can_seek);
 
 #endif /* STREAMING_H */
diff -pruN 1.2.1+git2.18.0-1/git/string-list.c 1.2.3+git2.25.1-1/git/string-list.c
--- 1.2.1+git2.18.0-1/git/string-list.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/string-list.c	2020-02-17 04:47:35.000000000 +0000
@@ -155,7 +155,8 @@ static int item_is_not_empty(struct stri
 	return *item->string != '\0';
 }
 
-void string_list_remove_empty_items(struct string_list *list, int free_util) {
+void string_list_remove_empty_items(struct string_list *list, int free_util)
+{
 	filter_string_list(list, free_util, item_is_not_empty, NULL);
 }
 
@@ -195,16 +196,6 @@ void string_list_clear_func(struct strin
 	list->nr = list->alloc = 0;
 }
 
-
-void print_string_list(const struct string_list *p, const char *text)
-{
-	int i;
-	if ( text )
-		printf("%s\n", text);
-	for (i = 0; i < p->nr; i++)
-		printf("%s:%p\n", p->items[i].string, p->items[i].util);
-}
-
 struct string_list_item *string_list_append_nodup(struct string_list *list,
 						  char *string)
 {
@@ -224,18 +215,28 @@ struct string_list_item *string_list_app
 			list->strdup_strings ? xstrdup(string) : (char *)string);
 }
 
+/*
+ * Encapsulate the compare function pointer because ISO C99 forbids
+ * casting from void * to a function pointer and vice versa.
+ */
+struct string_list_sort_ctx
+{
+	compare_strings_fn cmp;
+};
+
 static int cmp_items(const void *a, const void *b, void *ctx)
 {
-	compare_strings_fn cmp = ctx;
+	struct string_list_sort_ctx *sort_ctx = ctx;
 	const struct string_list_item *one = a;
 	const struct string_list_item *two = b;
-	return cmp(one->string, two->string);
+	return sort_ctx->cmp(one->string, two->string);
 }
 
 void string_list_sort(struct string_list *list)
 {
-	QSORT_S(list->items, list->nr, cmp_items,
-		list->cmp ? list->cmp : strcmp);
+	struct string_list_sort_ctx sort_ctx = {list->cmp ? list->cmp : strcmp};
+
+	QSORT_S(list->items, list->nr, cmp_items, &sort_ctx);
 }
 
 struct string_list_item *unsorted_string_list_lookup(struct string_list *list,
diff -pruN 1.2.1+git2.18.0-1/git/string-list.h 1.2.3+git2.25.1-1/git/string-list.h
--- 1.2.1+git2.18.0-1/git/string-list.h	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/string-list.h	2020-02-17 04:47:35.000000000 +0000
@@ -4,7 +4,8 @@
 /**
  * The string_list API offers a data structure and functions to handle
  * sorted and unsorted arrays of strings.  A "sorted" list is one whose
- * entries are sorted by string value in `strcmp()` order.
+ * entries are sorted by string value in the order specified by the `cmp`
+ * member (`strcmp()` by default).
  *
  * The caller:
  *
@@ -114,14 +115,6 @@ void filter_string_list(struct string_li
 			string_list_each_func_t want, void *cb_data);
 
 /**
- * Dump a string_list to stdout, useful mainly for debugging
- * purposes. It can take an optional header argument and it writes out
- * the string-pointer pairs of the string_list, each one in its own
- * line.
- */
-void print_string_list(const struct string_list *p, const char *text);
-
-/**
  * Free a string_list. The `string` pointer of the items will be freed
  * in case the `strdup_strings` member of the string_list is set. The
  * second parameter controls if the `util` pointer of the items should
@@ -182,12 +175,12 @@ struct string_list_item *string_list_ins
  * Remove the given string from the sorted list.  If the string
  * doesn't exist, the list is not altered.
  */
-extern void string_list_remove(struct string_list *list, const char *string,
-			       int free_util);
+void string_list_remove(struct string_list *list, const char *string,
+			int free_util);
 
 /**
  * Check if the given string is part of a sorted list. If it is part of the list,
- * return the coresponding string_list_item, NULL otherwise.
+ * return the corresponding string_list_item, NULL otherwise.
  */
 struct string_list_item *string_list_lookup(struct string_list *list, const char *string);
 
@@ -217,7 +210,8 @@ struct string_list_item *string_list_app
 struct string_list_item *string_list_append_nodup(struct string_list *list, char *string);
 
 /**
- * Sort the list's entries by string value in `strcmp()` order.
+ * Sort the list's entries by string value in order specified by list->cmp
+ * (strcmp() if list->cmp is NULL).
  */
 void string_list_sort(struct string_list *list);
 
diff -pruN 1.2.1+git2.18.0-1/git/submodule.c 1.2.3+git2.25.1-1/git/submodule.c
--- 1.2.1+git2.18.0-1/git/submodule.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/submodule.c	2020-02-17 04:47:35.000000000 +0000
@@ -1,4 +1,3 @@
-#define NO_THE_INDEX_COMPATIBILITY_MACROS
 
 #include "cache.h"
 #include "repository.h"
@@ -22,9 +21,9 @@
 #include "worktree.h"
 #include "parse-options.h"
 #include "object-store.h"
+#include "commit-reach.h"
 
 static int config_update_recurse_submodules = RECURSE_SUBMODULES_OFF;
-static struct string_list changed_submodule_names = STRING_LIST_INIT_DUP;
 static int initialized_fetch_ref_tips;
 static struct oid_array ref_tips_before_fetch;
 static struct oid_array ref_tips_after_fetch;
@@ -51,6 +50,24 @@ int is_gitmodules_unmerged(const struct
 }
 
 /*
+ * Check if the .gitmodules file is safe to write.
+ *
+ * Writing to the .gitmodules file requires that the file exists in the
+ * working tree or, if it doesn't, that a brand new .gitmodules file is going
+ * to be created (i.e. it's neither in the index nor in the current branch).
+ *
+ * It is not safe to write to .gitmodules if it's not in the working tree but
+ * it is in the index or in the current branch, because writing new values
+ * (and staging them) would blindly overwrite ALL the old content.
+ */
+int is_writing_gitmodules_ok(void)
+{
+	struct object_id oid;
+	return file_exists(GITMODULES_FILE) ||
+		(get_oid(GITMODULES_INDEX, &oid) < 0 && get_oid(GITMODULES_HEAD, &oid) < 0);
+}
+
+/*
  * Check if the .gitmodules file has unstaged modifications.  This must be
  * checked before allowing modifications to the .gitmodules file with the
  * intention to stage them later, because when continuing we would stage the
@@ -65,8 +82,7 @@ int is_staging_gitmodules_ok(struct inde
 	if ((pos >= 0) && (pos < istate->cache_nr)) {
 		struct stat st;
 		if (lstat(GITMODULES_FILE, &st) == 0 &&
-		    ie_match_stat(istate, istate->cache[pos], &st,
-				  CE_MATCH_IGNORE_FSMONITOR) & DATA_CHANGED)
+		    ie_match_stat(istate, istate->cache[pos], &st, 0) & DATA_CHANGED)
 			return 0;
 	}
 
@@ -89,11 +105,12 @@ int update_path_in_gitmodules(const char
 {
 	struct strbuf entry = STRBUF_INIT;
 	const struct submodule *submodule;
+	int ret;
 
 	if (!file_exists(GITMODULES_FILE)) /* Do nothing without .gitmodules */
 		return -1;
 
-	if (is_gitmodules_unmerged(&the_index))
+	if (is_gitmodules_unmerged(the_repository->index))
 		die(_("Cannot change unmerged .gitmodules, resolve merge conflicts first"));
 
 	submodule = submodule_from_path(the_repository, &null_oid, oldpath);
@@ -104,14 +121,9 @@ int update_path_in_gitmodules(const char
 	strbuf_addstr(&entry, "submodule.");
 	strbuf_addstr(&entry, submodule->name);
 	strbuf_addstr(&entry, ".path");
-	if (git_config_set_in_file_gently(GITMODULES_FILE, entry.buf, newpath) < 0) {
-		/* Maybe the user already did that, don't error out here */
-		warning(_("Could not update .gitmodules entry %s"), entry.buf);
-		strbuf_release(&entry);
-		return -1;
-	}
+	ret = config_set_in_gitmodules_file_gently(entry.buf, newpath);
 	strbuf_release(&entry);
-	return 0;
+	return ret;
 }
 
 /*
@@ -127,7 +139,7 @@ int remove_path_from_gitmodules(const ch
 	if (!file_exists(GITMODULES_FILE)) /* Do nothing without .gitmodules */
 		return -1;
 
-	if (is_gitmodules_unmerged(&the_index))
+	if (is_gitmodules_unmerged(the_repository->index))
 		die(_("Cannot change unmerged .gitmodules, resolve merge conflicts first"));
 
 	submodule = submodule_from_path(the_repository, &null_oid, path);
@@ -188,7 +200,7 @@ void set_diffopt_flags_from_submodule_co
 
 		if (ignore)
 			handle_ignore_submodules_arg(diffopt, ignore);
-		else if (is_gitmodules_unmerged(&the_index))
+		else if (is_gitmodules_unmerged(the_repository->index))
 			diffopt->flags.ignore_submodules = 1;
 	}
 }
@@ -258,7 +270,7 @@ int is_submodule_active(struct repositor
 		}
 
 		parse_pathspec(&ps, 0, 0, NULL, args.argv);
-		ret = match_pathspec(&ps, path, strlen(path), 0, NULL, 1);
+		ret = match_pathspec(repo->index, &ps, path, strlen(path), 0, NULL, 1);
 
 		argv_array_clear(&args);
 		clear_pathspec(&ps);
@@ -419,7 +431,11 @@ void handle_ignore_submodules_arg(struct
 	else if (!strcmp(arg, "dirty"))
 		diffopt->flags.ignore_dirty_submodules = 1;
 	else if (strcmp(arg, "none"))
-		die("bad --ignore-submodules argument: %s", arg);
+		die(_("bad --ignore-submodules argument: %s"), arg);
+	/*
+	 * Please update _git_status() in git-completion.bash when you
+	 * add new options
+	 */
 }
 
 static int prepare_submodule_summary(struct rev_info *rev, const char *path,
@@ -428,7 +444,7 @@ static int prepare_submodule_summary(str
 {
 	struct commit_list *list;
 
-	init_revisions(rev, NULL);
+	repo_init_revisions(the_repository, rev, NULL);
 	setup_revisions(0, NULL, rev, NULL);
 	rev->left_right = 1;
 	rev->first_parent_only = 1;
@@ -443,7 +459,7 @@ static int prepare_submodule_summary(str
 	return prepare_revision_walk(rev);
 }
 
-static void print_submodule_summary(struct rev_info *rev, struct diff_options *o)
+static void print_submodule_summary(struct repository *r, struct rev_info *rev, struct diff_options *o)
 {
 	static const char format[] = "  %m %s";
 	struct strbuf sb = STRBUF_INIT;
@@ -454,7 +470,8 @@ static void print_submodule_summary(stru
 		ctx.date_mode = rev->date_mode;
 		ctx.output_encoding = get_log_output_encoding();
 		strbuf_setlen(&sb, 0);
-		format_commit_message(commit, format, &sb, &ctx);
+		repo_format_commit_message(r, commit, format, &sb,
+				      &ctx);
 		strbuf_addch(&sb, '\n');
 		if (commit->object.flags & SYMMETRIC_LEFT)
 			diff_emit_submodule_del(o, sb.buf);
@@ -481,14 +498,52 @@ void prepare_submodule_repo_env(struct a
 			 DEFAULT_GIT_DIR_ENVIRONMENT);
 }
 
-/* Helper function to display the submodule header line prior to the full
- * summary output. If it can locate the submodule objects directory it will
- * attempt to lookup both the left and right commits and put them into the
- * left and right pointers.
+static void prepare_submodule_repo_env_in_gitdir(struct argv_array *out)
+{
+	prepare_submodule_repo_env_no_git_dir(out);
+	argv_array_pushf(out, "%s=.", GIT_DIR_ENVIRONMENT);
+}
+
+/*
+ * Initialize a repository struct for a submodule based on the provided 'path'.
+ *
+ * Unlike repo_submodule_init, this tolerates submodules not present
+ * in .gitmodules. This function exists only to preserve historical behavior,
+ *
+ * Returns the repository struct on success,
+ * NULL when the submodule is not present.
  */
-static void show_submodule_header(struct diff_options *o, const char *path,
+static struct repository *open_submodule(const char *path)
+{
+	struct strbuf sb = STRBUF_INIT;
+	struct repository *out = xmalloc(sizeof(*out));
+
+	if (submodule_to_gitdir(&sb, path) || repo_init(out, sb.buf, NULL)) {
+		strbuf_release(&sb);
+		free(out);
+		return NULL;
+	}
+
+	/* Mark it as a submodule */
+	out->submodule_prefix = xstrdup(path);
+
+	strbuf_release(&sb);
+	return out;
+}
+
+/*
+ * Helper function to display the submodule header line prior to the full
+ * summary output.
+ *
+ * If it can locate the submodule git directory it will create a repository
+ * handle for the submodule and lookup both the left and right commits and
+ * put them into the left and right pointers.
+ */
+static void show_submodule_header(struct diff_options *o,
+		const char *path,
 		struct object_id *one, struct object_id *two,
 		unsigned dirty_submodule,
+		struct repository *sub,
 		struct commit **left, struct commit **right,
 		struct commit_list **merge_bases)
 {
@@ -507,7 +562,7 @@ static void show_submodule_header(struct
 	else if (is_null_oid(two))
 		message = "(submodule deleted)";
 
-	if (add_submodule_odb(path)) {
+	if (!sub) {
 		if (!message)
 			message = "(commits not present)";
 		goto output_header;
@@ -517,8 +572,8 @@ static void show_submodule_header(struct
 	 * Attempt to lookup the commit references, and determine if this is
 	 * a fast forward or fast backwards update.
 	 */
-	*left = lookup_commit_reference(one);
-	*right = lookup_commit_reference(two);
+	*left = lookup_commit_reference(sub, one);
+	*right = lookup_commit_reference(sub, two);
 
 	/*
 	 * Warn about missing commits in the submodule project, but only if
@@ -528,7 +583,7 @@ static void show_submodule_header(struct
 	     (!is_null_oid(two) && !*right))
 		message = "(commits not present)";
 
-	*merge_bases = get_merge_bases(*left, *right);
+	*merge_bases = repo_get_merge_bases(sub, *left, *right);
 	if (*merge_bases) {
 		if ((*merge_bases)->item == *left)
 			fast_forward = 1;
@@ -536,7 +591,7 @@ static void show_submodule_header(struct
 			fast_backward = 1;
 	}
 
-	if (!oidcmp(one, two)) {
+	if (oideq(one, two)) {
 		strbuf_release(&sb);
 		return;
 	}
@@ -562,16 +617,18 @@ void show_submodule_summary(struct diff_
 	struct rev_info rev;
 	struct commit *left = NULL, *right = NULL;
 	struct commit_list *merge_bases = NULL;
+	struct repository *sub;
 
+	sub = open_submodule(path);
 	show_submodule_header(o, path, one, two, dirty_submodule,
-			      &left, &right, &merge_bases);
+			      sub, &left, &right, &merge_bases);
 
 	/*
 	 * If we don't have both a left and a right pointer, there is no
 	 * reason to try and display a summary. The header line should contain
 	 * all the information the user needs.
 	 */
-	if (!left || !right)
+	if (!left || !right || !sub)
 		goto out;
 
 	/* Treat revision walker failure the same as missing commits */
@@ -580,13 +637,17 @@ void show_submodule_summary(struct diff_
 		goto out;
 	}
 
-	print_submodule_summary(&rev, o);
+	print_submodule_summary(sub, &rev, o);
 
 out:
 	if (merge_bases)
 		free_commit_list(merge_bases);
 	clear_commit_marks(left, ~0);
 	clear_commit_marks(right, ~0);
+	if (sub) {
+		repo_clear(sub);
+		free(sub);
+	}
 }
 
 void show_submodule_inline_diff(struct diff_options *o, const char *path,
@@ -598,9 +659,11 @@ void show_submodule_inline_diff(struct d
 	struct commit_list *merge_bases = NULL;
 	struct child_process cp = CHILD_PROCESS_INIT;
 	struct strbuf sb = STRBUF_INIT;
+	struct repository *sub;
 
+	sub = open_submodule(path);
 	show_submodule_header(o, path, one, two, dirty_submodule,
-			      &left, &right, &merge_bases);
+			      sub, &left, &right, &merge_bases);
 
 	/* We need a valid left and right commit to display a difference */
 	if (!(left || is_null_oid(one)) ||
@@ -661,6 +724,10 @@ done:
 		clear_commit_marks(left, ~0);
 	if (right)
 		clear_commit_marks(right, ~0);
+	if (sub) {
+		repo_clear(sub);
+		free(sub);
+	}
 }
 
 int should_update_submodules(void)
@@ -694,6 +761,7 @@ static struct oid_array *submodule_commi
 }
 
 struct collect_changed_submodules_cb_data {
+	struct repository *repo;
 	struct string_list *changed;
 	const struct object_id *commit_oid;
 };
@@ -733,19 +801,21 @@ static void collect_changed_submodules_c
 		if (!S_ISGITLINK(p->two->mode))
 			continue;
 
-		submodule = submodule_from_path(the_repository,
+		submodule = submodule_from_path(me->repo,
 						commit_oid, p->two->path);
 		if (submodule)
 			name = submodule->name;
 		else {
 			name = default_name_or_path(p->two->path);
 			/* make sure name does not collide with existing one */
-			submodule = submodule_from_name(the_repository, commit_oid, name);
+			if (name)
+				submodule = submodule_from_name(me->repo,
+								commit_oid, name);
 			if (submodule) {
-				warning("Submodule in commit %s at path: "
+				warning(_("Submodule in commit %s at path: "
 					"'%s' collides with a submodule named "
-					"the same. Skipping it.",
-					oid_to_hex(commit_oid), name);
+					"the same. Skipping it."),
+					oid_to_hex(commit_oid), p->two->path);
 				name = NULL;
 			}
 		}
@@ -764,24 +834,26 @@ static void collect_changed_submodules_c
  * have a corresponding 'struct oid_array' (in the 'util' field) which lists
  * what the submodule pointers were updated to during the change.
  */
-static void collect_changed_submodules(struct string_list *changed,
+static void collect_changed_submodules(struct repository *r,
+				       struct string_list *changed,
 				       struct argv_array *argv)
 {
 	struct rev_info rev;
 	const struct commit *commit;
 
-	init_revisions(&rev, NULL);
+	repo_init_revisions(r, &rev, NULL);
 	setup_revisions(argv->argc, argv->argv, &rev, NULL);
 	if (prepare_revision_walk(&rev))
-		die("revision walk setup failed");
+		die(_("revision walk setup failed"));
 
 	while ((commit = get_revision(&rev))) {
 		struct rev_info diff_rev;
 		struct collect_changed_submodules_cb_data data;
+		data.repo = r;
 		data.changed = changed;
 		data.commit_oid = &commit->object.oid;
 
-		init_revisions(&diff_rev, NULL);
+		repo_init_revisions(r, &diff_rev, NULL);
 		diff_rev.diffopt.output_format |= DIFF_FORMAT_CALLBACK;
 		diff_rev.diffopt.format_callback = collect_changed_submodules_cb;
 		diff_rev.diffopt.format_callback_data = &data;
@@ -813,6 +885,7 @@ static int append_oid_to_argv(const stru
 }
 
 struct has_commit_data {
+	struct repository *repo;
 	int result;
 	const char *path;
 };
@@ -821,7 +894,7 @@ static int check_has_commit(const struct
 {
 	struct has_commit_data *cb = data;
 
-	enum object_type type = oid_object_info(the_repository, oid, NULL);
+	enum object_type type = oid_object_info(cb->repo, oid, NULL);
 
 	switch (type) {
 	case OBJ_COMMIT:
@@ -839,9 +912,11 @@ static int check_has_commit(const struct
 	}
 }
 
-static int submodule_has_commits(const char *path, struct oid_array *commits)
+static int submodule_has_commits(struct repository *r,
+				 const char *path,
+				 struct oid_array *commits)
 {
-	struct has_commit_data has_commit = { 1, path };
+	struct has_commit_data has_commit = { r, 1, path };
 
 	/*
 	 * Perform a cheap, but incorrect check for the existence of 'commits'.
@@ -884,9 +959,11 @@ static int submodule_has_commits(const c
 	return has_commit.result;
 }
 
-static int submodule_needs_pushing(const char *path, struct oid_array *commits)
+static int submodule_needs_pushing(struct repository *r,
+				   const char *path,
+				   struct oid_array *commits)
 {
-	if (!submodule_has_commits(path, commits))
+	if (!submodule_has_commits(r, path, commits))
 		/*
 		 * NOTE: We do consider it safe to return "no" here. The
 		 * correct answer would be "We do not know" instead of
@@ -915,9 +992,9 @@ static int submodule_needs_pushing(const
 		cp.out = -1;
 		cp.dir = path;
 		if (start_command(&cp))
-			die("Could not run 'git rev-list <commits> --not --remotes -n 1' command in submodule %s",
+			die(_("Could not run 'git rev-list <commits> --not --remotes -n 1' command in submodule %s"),
 					path);
-		if (strbuf_read(&buf, cp.out, 41))
+		if (strbuf_read(&buf, cp.out, the_hash_algo->hexsz + 1))
 			needs_pushing = 1;
 		finish_command(&cp);
 		close(cp.out);
@@ -928,8 +1005,10 @@ static int submodule_needs_pushing(const
 	return 0;
 }
 
-int find_unpushed_submodules(struct oid_array *commits,
-		const char *remotes_name, struct string_list *needs_pushing)
+int find_unpushed_submodules(struct repository *r,
+			     struct oid_array *commits,
+			     const char *remotes_name,
+			     struct string_list *needs_pushing)
 {
 	struct string_list submodules = STRING_LIST_INIT_DUP;
 	struct string_list_item *name;
@@ -941,14 +1020,14 @@ int find_unpushed_submodules(struct oid_
 	argv_array_push(&argv, "--not");
 	argv_array_pushf(&argv, "--remotes=%s", remotes_name);
 
-	collect_changed_submodules(&submodules, &argv);
+	collect_changed_submodules(r, &submodules, &argv);
 
 	for_each_string_list_item(name, &submodules) {
 		struct oid_array *commits = name->util;
 		const struct submodule *submodule;
 		const char *path = NULL;
 
-		submodule = submodule_from_name(the_repository, &null_oid, name->string);
+		submodule = submodule_from_name(r, &null_oid, name->string);
 		if (submodule)
 			path = submodule->path;
 		else
@@ -957,7 +1036,7 @@ int find_unpushed_submodules(struct oid_
 		if (!path)
 			continue;
 
-		if (submodule_needs_pushing(path, commits))
+		if (submodule_needs_pushing(r, path, commits))
 			string_list_insert(needs_pushing, path);
 	}
 
@@ -973,9 +1052,6 @@ static int push_submodule(const char *pa
 			  const struct string_list *push_options,
 			  int dry_run)
 {
-	if (add_submodule_odb(path))
-		return 1;
-
 	if (for_each_remote_ref_submodule(path, has_remote, NULL) > 0) {
 		struct child_process cp = CHILD_PROCESS_INIT;
 		argv_array_push(&cp.args, "push");
@@ -1039,10 +1115,11 @@ static void submodule_push_check(const c
 	 * child process.
 	 */
 	if (run_command(&cp))
-		die("process for submodule '%s' failed", path);
+		die(_("process for submodule '%s' failed"), path);
 }
 
-int push_unpushed_submodules(struct oid_array *commits,
+int push_unpushed_submodules(struct repository *r,
+			     struct oid_array *commits,
 			     const struct remote *remote,
 			     const struct refspec *rs,
 			     const struct string_list *push_options,
@@ -1051,7 +1128,8 @@ int push_unpushed_submodules(struct oid_
 	int i, ret = 1;
 	struct string_list needs_pushing = STRING_LIST_INIT_DUP;
 
-	if (!find_unpushed_submodules(commits, remote->name, &needs_pushing))
+	if (!find_unpushed_submodules(r, commits,
+				      remote->name, &needs_pushing))
 		return 1;
 
 	/*
@@ -1077,10 +1155,10 @@ int push_unpushed_submodules(struct oid_
 	/* Actually push the submodules */
 	for (i = 0; i < needs_pushing.nr; i++) {
 		const char *path = needs_pushing.items[i].string;
-		fprintf(stderr, "Pushing submodule '%s'\n", path);
+		fprintf(stderr, _("Pushing submodule '%s'\n"), path);
 		if (!push_submodule(path, remote, rs,
 				    push_options, dry_run)) {
-			fprintf(stderr, "Unable to push submodule '%s'\n", path);
+			fprintf(stderr, _("Unable to push submodule '%s'\n"), path);
 			ret = 0;
 		}
 	}
@@ -1108,14 +1186,14 @@ void check_for_new_submodule_commits(str
 	oid_array_append(&ref_tips_after_fetch, oid);
 }
 
-static void calculate_changed_submodule_paths(void)
+static void calculate_changed_submodule_paths(struct repository *r,
+		struct string_list *changed_submodule_names)
 {
 	struct argv_array argv = ARGV_ARRAY_INIT;
-	struct string_list changed_submodules = STRING_LIST_INIT_DUP;
-	const struct string_list_item *name;
+	struct string_list_item *name;
 
 	/* No need to check if there are no submodules configured */
-	if (!submodule_from_path(the_repository, NULL, NULL))
+	if (!submodule_from_path(r, NULL, NULL))
 		return;
 
 	argv_array_push(&argv, "--"); /* argv[0] program name */
@@ -1129,14 +1207,14 @@ static void calculate_changed_submodule_
 	 * Collect all submodules (whether checked out or not) for which new
 	 * commits have been recorded upstream in "changed_submodule_names".
 	 */
-	collect_changed_submodules(&changed_submodules, &argv);
+	collect_changed_submodules(r, changed_submodule_names, &argv);
 
-	for_each_string_list_item(name, &changed_submodules) {
+	for_each_string_list_item(name, changed_submodule_names) {
 		struct oid_array *commits = name->util;
 		const struct submodule *submodule;
 		const char *path = NULL;
 
-		submodule = submodule_from_name(the_repository, &null_oid, name->string);
+		submodule = submodule_from_name(r, &null_oid, name->string);
 		if (submodule)
 			path = submodule->path;
 		else
@@ -1145,18 +1223,22 @@ static void calculate_changed_submodule_
 		if (!path)
 			continue;
 
-		if (!submodule_has_commits(path, commits))
-			string_list_append(&changed_submodule_names, name->string);
+		if (submodule_has_commits(r, path, commits)) {
+			oid_array_clear(commits);
+			*name->string = '\0';
+		}
 	}
 
-	free_submodules_oids(&changed_submodules);
+	string_list_remove_empty_items(changed_submodule_names, 1);
+
 	argv_array_clear(&argv);
 	oid_array_clear(&ref_tips_before_fetch);
 	oid_array_clear(&ref_tips_after_fetch);
 	initialized_fetch_ref_tips = 0;
 }
 
-int submodule_touches_in_range(struct object_id *excl_oid,
+int submodule_touches_in_range(struct repository *r,
+			       struct object_id *excl_oid,
 			       struct object_id *incl_oid)
 {
 	struct string_list subs = STRING_LIST_INIT_DUP;
@@ -1164,7 +1246,7 @@ int submodule_touches_in_range(struct ob
 	int ret;
 
 	/* No need to check if there are no submodules configured */
-	if (!submodule_from_path(the_repository, NULL, NULL))
+	if (!submodule_from_path(r, NULL, NULL))
 		return 0;
 
 	argv_array_push(&args, "--"); /* args[0] program name */
@@ -1174,7 +1256,7 @@ int submodule_touches_in_range(struct ob
 		argv_array_push(&args, oid_to_hex(excl_oid));
 	}
 
-	collect_changed_submodules(&subs, &args);
+	collect_changed_submodules(r, &subs, &args);
 	ret = subs.nr;
 
 	argv_array_clear(&args);
@@ -1192,8 +1274,16 @@ struct submodule_parallel_fetch {
 	int default_option;
 	int quiet;
 	int result;
+
+	struct string_list changed_submodule_names;
+
+	/* Pending fetches by OIDs */
+	struct fetch_task **oid_fetch_tasks;
+	int oid_fetch_tasks_nr, oid_fetch_tasks_alloc;
 };
-#define SPF_INIT {0, ARGV_ARRAY_INIT, NULL, NULL, 0, 0, 0, 0}
+#define SPF_INIT {0, ARGV_ARRAY_INIT, NULL, NULL, 0, 0, 0, 0, \
+		  STRING_LIST_INIT_DUP, \
+		  NULL, 0, 0}
 
 static int get_fetch_recurse_config(const struct submodule *submodule,
 				    struct submodule_parallel_fetch *spf)
@@ -1220,40 +1310,126 @@ static int get_fetch_recurse_config(cons
 	return spf->default_option;
 }
 
+/*
+ * Fetch in progress (if callback data) or
+ * pending (if in oid_fetch_tasks in struct submodule_parallel_fetch)
+ */
+struct fetch_task {
+	struct repository *repo;
+	const struct submodule *sub;
+	unsigned free_sub : 1; /* Do we need to free the submodule? */
+
+	struct oid_array *commits; /* Ensure these commits are fetched */
+};
+
+/**
+ * When a submodule is not defined in .gitmodules, we cannot access it
+ * via the regular submodule-config. Create a fake submodule, which we can
+ * work on.
+ */
+static const struct submodule *get_non_gitmodules_submodule(const char *path)
+{
+	struct submodule *ret = NULL;
+	const char *name = default_name_or_path(path);
+
+	if (!name)
+		return NULL;
+
+	ret = xmalloc(sizeof(*ret));
+	memset(ret, 0, sizeof(*ret));
+	ret->path = name;
+	ret->name = name;
+
+	return (const struct submodule *) ret;
+}
+
+static struct fetch_task *fetch_task_create(struct repository *r,
+					    const char *path)
+{
+	struct fetch_task *task = xmalloc(sizeof(*task));
+	memset(task, 0, sizeof(*task));
+
+	task->sub = submodule_from_path(r, &null_oid, path);
+	if (!task->sub) {
+		/*
+		 * No entry in .gitmodules? Technically not a submodule,
+		 * but historically we supported repositories that happen to be
+		 * in-place where a gitlink is. Keep supporting them.
+		 */
+		task->sub = get_non_gitmodules_submodule(path);
+		if (!task->sub) {
+			free(task);
+			return NULL;
+		}
+
+		task->free_sub = 1;
+	}
+
+	return task;
+}
+
+static void fetch_task_release(struct fetch_task *p)
+{
+	if (p->free_sub)
+		free((void*)p->sub);
+	p->free_sub = 0;
+	p->sub = NULL;
+
+	if (p->repo)
+		repo_clear(p->repo);
+	FREE_AND_NULL(p->repo);
+}
+
+static struct repository *get_submodule_repo_for(struct repository *r,
+						 const struct submodule *sub)
+{
+	struct repository *ret = xmalloc(sizeof(*ret));
+
+	if (repo_submodule_init(ret, r, sub)) {
+		/*
+		 * No entry in .gitmodules? Technically not a submodule,
+		 * but historically we supported repositories that happen to be
+		 * in-place where a gitlink is. Keep supporting them.
+		 */
+		struct strbuf gitdir = STRBUF_INIT;
+		strbuf_repo_worktree_path(&gitdir, r, "%s/.git", sub->path);
+		if (repo_init(ret, gitdir.buf, NULL)) {
+			strbuf_release(&gitdir);
+			free(ret);
+			return NULL;
+		}
+		strbuf_release(&gitdir);
+	}
+
+	return ret;
+}
+
 static int get_next_submodule(struct child_process *cp,
 			      struct strbuf *err, void *data, void **task_cb)
 {
-	int ret = 0;
 	struct submodule_parallel_fetch *spf = data;
 
 	for (; spf->count < spf->r->index->cache_nr; spf->count++) {
-		struct strbuf submodule_path = STRBUF_INIT;
-		struct strbuf submodule_git_dir = STRBUF_INIT;
-		struct strbuf submodule_prefix = STRBUF_INIT;
 		const struct cache_entry *ce = spf->r->index->cache[spf->count];
-		const char *git_dir, *default_argv;
-		const struct submodule *submodule;
-		struct submodule default_submodule = SUBMODULE_INIT;
+		const char *default_argv;
+		struct fetch_task *task;
 
 		if (!S_ISGITLINK(ce->ce_mode))
 			continue;
 
-		submodule = submodule_from_path(spf->r, &null_oid, ce->name);
-		if (!submodule) {
-			const char *name = default_name_or_path(ce->name);
-			if (name) {
-				default_submodule.path = default_submodule.name = name;
-				submodule = &default_submodule;
-			}
-		}
+		task = fetch_task_create(spf->r, ce->name);
+		if (!task)
+			continue;
 
-		switch (get_fetch_recurse_config(submodule, spf))
+		switch (get_fetch_recurse_config(task->sub, spf))
 		{
 		default:
 		case RECURSE_SUBMODULES_DEFAULT:
 		case RECURSE_SUBMODULES_ON_DEMAND:
-			if (!submodule || !unsorted_string_list_lookup(&changed_submodule_names,
-							 submodule->name))
+			if (!task->sub ||
+			    !string_list_lookup(
+					&spf->changed_submodule_names,
+					task->sub->name))
 				continue;
 			default_argv = "on-demand";
 			break;
@@ -1264,35 +1440,80 @@ static int get_next_submodule(struct chi
 			continue;
 		}
 
-		strbuf_repo_worktree_path(&submodule_path, spf->r, "%s", ce->name);
-		strbuf_addf(&submodule_git_dir, "%s/.git", submodule_path.buf);
-		strbuf_addf(&submodule_prefix, "%s%s/", spf->prefix, ce->name);
-		git_dir = read_gitfile(submodule_git_dir.buf);
-		if (!git_dir)
-			git_dir = submodule_git_dir.buf;
-		if (is_directory(git_dir)) {
+		task->repo = get_submodule_repo_for(spf->r, task->sub);
+		if (task->repo) {
+			struct strbuf submodule_prefix = STRBUF_INIT;
 			child_process_init(cp);
-			cp->dir = strbuf_detach(&submodule_path, NULL);
-			prepare_submodule_repo_env(&cp->env_array);
+			cp->dir = task->repo->gitdir;
+			prepare_submodule_repo_env_in_gitdir(&cp->env_array);
 			cp->git_cmd = 1;
 			if (!spf->quiet)
-				strbuf_addf(err, "Fetching submodule %s%s\n",
+				strbuf_addf(err, _("Fetching submodule %s%s\n"),
 					    spf->prefix, ce->name);
 			argv_array_init(&cp->args);
 			argv_array_pushv(&cp->args, spf->args.argv);
 			argv_array_push(&cp->args, default_argv);
 			argv_array_push(&cp->args, "--submodule-prefix");
+
+			strbuf_addf(&submodule_prefix, "%s%s/",
+						       spf->prefix,
+						       task->sub->path);
 			argv_array_push(&cp->args, submodule_prefix.buf);
-			ret = 1;
-		}
-		strbuf_release(&submodule_path);
-		strbuf_release(&submodule_git_dir);
-		strbuf_release(&submodule_prefix);
-		if (ret) {
+
 			spf->count++;
+			*task_cb = task;
+
+			strbuf_release(&submodule_prefix);
 			return 1;
+		} else {
+
+			fetch_task_release(task);
+			free(task);
+
+			/*
+			 * An empty directory is normal,
+			 * the submodule is not initialized
+			 */
+			if (S_ISGITLINK(ce->ce_mode) &&
+			    !is_empty_dir(ce->name)) {
+				spf->result = 1;
+				strbuf_addf(err,
+					    _("Could not access submodule '%s'\n"),
+					    ce->name);
+			}
 		}
 	}
+
+	if (spf->oid_fetch_tasks_nr) {
+		struct fetch_task *task =
+			spf->oid_fetch_tasks[spf->oid_fetch_tasks_nr - 1];
+		struct strbuf submodule_prefix = STRBUF_INIT;
+		spf->oid_fetch_tasks_nr--;
+
+		strbuf_addf(&submodule_prefix, "%s%s/",
+			    spf->prefix, task->sub->path);
+
+		child_process_init(cp);
+		prepare_submodule_repo_env_in_gitdir(&cp->env_array);
+		cp->git_cmd = 1;
+		cp->dir = task->repo->gitdir;
+
+		argv_array_init(&cp->args);
+		argv_array_pushv(&cp->args, spf->args.argv);
+		argv_array_push(&cp->args, "on-demand");
+		argv_array_push(&cp->args, "--submodule-prefix");
+		argv_array_push(&cp->args, submodule_prefix.buf);
+
+		/* NEEDSWORK: have get_default_remote from submodule--helper */
+		argv_array_push(&cp->args, "origin");
+		oid_array_for_each_unique(task->commits,
+					  append_oid_to_argv, &cp->args);
+
+		*task_cb = task;
+		strbuf_release(&submodule_prefix);
+		return 1;
+	}
+
 	return 0;
 }
 
@@ -1300,20 +1521,73 @@ static int fetch_start_failure(struct st
 			       void *cb, void *task_cb)
 {
 	struct submodule_parallel_fetch *spf = cb;
+	struct fetch_task *task = task_cb;
 
 	spf->result = 1;
 
+	fetch_task_release(task);
 	return 0;
 }
 
+static int commit_missing_in_sub(const struct object_id *oid, void *data)
+{
+	struct repository *subrepo = data;
+
+	enum object_type type = oid_object_info(subrepo, oid, NULL);
+
+	return type != OBJ_COMMIT;
+}
+
 static int fetch_finish(int retvalue, struct strbuf *err,
 			void *cb, void *task_cb)
 {
 	struct submodule_parallel_fetch *spf = cb;
+	struct fetch_task *task = task_cb;
+
+	struct string_list_item *it;
+	struct oid_array *commits;
 
 	if (retvalue)
+		/*
+		 * NEEDSWORK: This indicates that the overall fetch
+		 * failed, even though there may be a subsequent fetch
+		 * by commit hash that might work. It may be a good
+		 * idea to not indicate failure in this case, and only
+		 * indicate failure if the subsequent fetch fails.
+		 */
 		spf->result = 1;
 
+	if (!task || !task->sub)
+		BUG("callback cookie bogus");
+
+	/* Is this the second time we process this submodule? */
+	if (task->commits)
+		goto out;
+
+	it = string_list_lookup(&spf->changed_submodule_names, task->sub->name);
+	if (!it)
+		/* Could be an unchanged submodule, not contained in the list */
+		goto out;
+
+	commits = it->util;
+	oid_array_filter(commits,
+			 commit_missing_in_sub,
+			 task->repo);
+
+	/* Are there commits we want, but do not exist? */
+	if (commits->nr) {
+		task->commits = commits;
+		ALLOC_GROW(spf->oid_fetch_tasks,
+			   spf->oid_fetch_tasks_nr + 1,
+			   spf->oid_fetch_tasks_alloc);
+		spf->oid_fetch_tasks[spf->oid_fetch_tasks_nr] = task;
+		spf->oid_fetch_tasks_nr++;
+		return 0;
+	}
+
+out:
+	fetch_task_release(task);
+
 	return 0;
 }
 
@@ -1336,7 +1610,7 @@ int fetch_populated_submodules(struct re
 		goto out;
 
 	if (repo_read_index(r) < 0)
-		die("index file corrupt");
+		die(_("index file corrupt"));
 
 	argv_array_push(&spf.args, "fetch");
 	for (i = 0; i < options->argc; i++)
@@ -1344,16 +1618,18 @@ int fetch_populated_submodules(struct re
 	argv_array_push(&spf.args, "--recurse-submodules-default");
 	/* default value, "--submodule-prefix" and its value are added later */
 
-	calculate_changed_submodule_paths();
-	run_processes_parallel(max_parallel_jobs,
-			       get_next_submodule,
-			       fetch_start_failure,
-			       fetch_finish,
-			       &spf);
+	calculate_changed_submodule_paths(r, &spf.changed_submodule_names);
+	string_list_sort(&spf.changed_submodule_names);
+	run_processes_parallel_tr2(max_parallel_jobs,
+				   get_next_submodule,
+				   fetch_start_failure,
+				   fetch_finish,
+				   &spf,
+				   "submodule", "parallel/fetch");
 
 	argv_array_clear(&spf.args);
 out:
-	string_list_clear(&changed_submodule_names, 1);
+	free_submodules_oids(&spf.changed_submodule_names);
 	return spf.result;
 }
 
@@ -1389,7 +1665,7 @@ unsigned is_submodule_modified(const cha
 	cp.out = -1;
 	cp.dir = path;
 	if (start_command(&cp))
-		die("Could not run 'git status --porcelain=2' in submodule %s", path);
+		die(_("Could not run 'git status --porcelain=2' in submodule %s"), path);
 
 	fp = xfdopen(cp.out, "r");
 	while (strbuf_getwholeline(&buf, fp, '\n') != EOF) {
@@ -1430,7 +1706,7 @@ unsigned is_submodule_modified(const cha
 	fclose(fp);
 
 	if (finish_command(&cp) && !ignore_cp_exit_code)
-		die("'git status --porcelain=2' failed in submodule %s", path);
+		die(_("'git status --porcelain=2' failed in submodule %s"), path);
 
 	strbuf_release(&buf);
 	return dirty_submodule;
@@ -1532,6 +1808,18 @@ out:
 	return ret;
 }
 
+void submodule_unset_core_worktree(const struct submodule *sub)
+{
+	char *config_path = xstrfmt("%s/modules/%s/config",
+				    get_git_common_dir(), sub->name);
+
+	if (git_config_set_in_file_gently(config_path, "core.worktree", NULL))
+		warning(_("Could not unset core.worktree setting in submodule '%s'"),
+			  sub->path);
+
+	free(config_path);
+}
+
 static const char *get_super_prefix_or_empty(void)
 {
 	const char *s = get_super_prefix();
@@ -1553,7 +1841,7 @@ static int submodule_has_dirty_index(con
 	cp.no_stdout = 1;
 	cp.dir = sub->path;
 	if (start_command(&cp))
-		die("could not recurse into submodule '%s'", sub->path);
+		die(_("could not recurse into submodule '%s'"), sub->path);
 
 	return finish_command(&cp);
 }
@@ -1574,7 +1862,7 @@ static void submodule_reset_index(const
 	argv_array_push(&cp.args, empty_tree_oid_hex());
 
 	if (run_command(&cp))
-		die("could not reset submodule index");
+		die(_("could not reset submodule index"));
 }
 
 /**
@@ -1622,7 +1910,7 @@ int submodule_move_head(const char *path
 	if (!(flags & SUBMODULE_MOVE_HEAD_DRY_RUN)) {
 		if (old_head) {
 			if (!submodule_uses_gitfile(path))
-				absorb_git_dir_into_superproject("", path,
+				absorb_git_dir_into_superproject(path,
 					ABSORB_GITDIR_RECURSE_SUBMODULES);
 		} else {
 			char *gitdir = xstrfmt("%s/modules/%s",
@@ -1668,7 +1956,7 @@ int submodule_move_head(const char *path
 	argv_array_push(&cp.args, new_head ? new_head : empty_tree_oid_hex());
 
 	if (run_command(&cp)) {
-		ret = -1;
+		ret = error(_("Submodule '%s' could not be updated."), path);
 		goto out;
 	}
 
@@ -1697,21 +1985,63 @@ int submodule_move_head(const char *path
 
 			if (is_empty_dir(path))
 				rmdir_or_warn(path);
+
+			submodule_unset_core_worktree(sub);
 		}
 	}
 out:
 	return ret;
 }
 
+int validate_submodule_git_dir(char *git_dir, const char *submodule_name)
+{
+	size_t len = strlen(git_dir), suffix_len = strlen(submodule_name);
+	char *p;
+	int ret = 0;
+
+	if (len <= suffix_len || (p = git_dir + len - suffix_len)[-1] != '/' ||
+	    strcmp(p, submodule_name))
+		BUG("submodule name '%s' not a suffix of git dir '%s'",
+		    submodule_name, git_dir);
+
+	/*
+	 * We prevent the contents of sibling submodules' git directories to
+	 * clash.
+	 *
+	 * Example: having a submodule named `hippo` and another one named
+	 * `hippo/hooks` would result in the git directories
+	 * `.git/modules/hippo/` and `.git/modules/hippo/hooks/`, respectively,
+	 * but the latter directory is already designated to contain the hooks
+	 * of the former.
+	 */
+	for (; *p; p++) {
+		if (is_dir_sep(*p)) {
+			char c = *p;
+
+			*p = '\0';
+			if (is_git_directory(git_dir))
+				ret = -1;
+			*p = c;
+
+			if (ret < 0)
+				return error(_("submodule git dir '%s' is "
+					       "inside git dir '%.*s'"),
+					     git_dir,
+					     (int)(p - git_dir), git_dir);
+		}
+	}
+
+	return 0;
+}
+
 /*
  * Embeds a single submodules git directory into the superprojects git dir,
  * non recursively.
  */
-static void relocate_single_git_dir_into_superproject(const char *prefix,
-						      const char *path)
+static void relocate_single_git_dir_into_superproject(const char *path)
 {
 	char *old_git_dir = NULL, *real_old_git_dir = NULL, *real_new_git_dir = NULL;
-	const char *new_git_dir;
+	char *new_git_dir;
 	const struct submodule *sub;
 
 	if (submodule_uses_worktrees(path))
@@ -1729,10 +2059,14 @@ static void relocate_single_git_dir_into
 	if (!sub)
 		die(_("could not lookup name for submodule '%s'"), path);
 
-	new_git_dir = git_path("modules/%s", sub->name);
+	new_git_dir = git_pathdup("modules/%s", sub->name);
+	if (validate_submodule_git_dir(new_git_dir, sub->name) < 0)
+		die(_("refusing to move '%s' into an existing git dir"),
+		    real_old_git_dir);
 	if (safe_create_leading_directories_const(new_git_dir) < 0)
 		die(_("could not create directory '%s'"), new_git_dir);
 	real_new_git_dir = real_pathdup(new_git_dir, 1);
+	free(new_git_dir);
 
 	fprintf(stderr, _("Migrating git directory of '%s%s' from\n'%s' to\n'%s'\n"),
 		get_super_prefix_or_empty(), path,
@@ -1750,8 +2084,7 @@ static void relocate_single_git_dir_into
  * having its git directory within the working tree to the git dir nested
  * in its superprojects git dir under modules/.
  */
-void absorb_git_dir_into_superproject(const char *prefix,
-				      const char *path,
+void absorb_git_dir_into_superproject(const char *path,
 				      unsigned flags)
 {
 	int err_code;
@@ -1792,7 +2125,7 @@ void absorb_git_dir_into_superproject(co
 		char *real_common_git_dir = real_pathdup(get_git_common_dir(), 1);
 
 		if (!starts_with(real_sub_git_dir, real_common_git_dir))
-			relocate_single_git_dir_into_superproject(prefix, path);
+			relocate_single_git_dir_into_superproject(path);
 
 		free(real_sub_git_dir);
 		free(real_common_git_dir);
@@ -1878,7 +2211,7 @@ const char *get_superproject_working_tre
 		 * We're only interested in the name after the tab.
 		 */
 		super_sub = strchr(sb.buf, '\t') + 1;
-		super_sub_len = sb.buf + sb.len - super_sub - 1;
+		super_sub_len = strlen(super_sub);
 
 		if (super_sub_len > cwd_len ||
 		    strcmp(&cwd[cwd_len - super_sub_len], super_sub))
diff -pruN 1.2.1+git2.18.0-1/git/submodule-config.c 1.2.3+git2.25.1-1/git/submodule-config.c
--- 1.2.1+git2.18.0-1/git/submodule-config.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/submodule-config.c	2020-02-17 04:47:35.000000000 +0000
@@ -1,9 +1,11 @@
 #include "cache.h"
+#include "dir.h"
 #include "repository.h"
 #include "config.h"
 #include "submodule-config.h"
 #include "submodule.h"
 #include "strbuf.h"
+#include "object-store.h"
 #include "parse-options.h"
 
 /*
@@ -36,27 +38,31 @@ enum lookup_type {
 };
 
 static int config_path_cmp(const void *unused_cmp_data,
-			   const void *entry,
-			   const void *entry_or_key,
+			   const struct hashmap_entry *eptr,
+			   const struct hashmap_entry *entry_or_key,
 			   const void *unused_keydata)
 {
-	const struct submodule_entry *a = entry;
-	const struct submodule_entry *b = entry_or_key;
+	const struct submodule_entry *a, *b;
+
+	a = container_of(eptr, const struct submodule_entry, ent);
+	b = container_of(entry_or_key, const struct submodule_entry, ent);
 
 	return strcmp(a->config->path, b->config->path) ||
-	       oidcmp(&a->config->gitmodules_oid, &b->config->gitmodules_oid);
+	       !oideq(&a->config->gitmodules_oid, &b->config->gitmodules_oid);
 }
 
 static int config_name_cmp(const void *unused_cmp_data,
-			   const void *entry,
-			   const void *entry_or_key,
+			   const struct hashmap_entry *eptr,
+			   const struct hashmap_entry *entry_or_key,
 			   const void *unused_keydata)
 {
-	const struct submodule_entry *a = entry;
-	const struct submodule_entry *b = entry_or_key;
+	const struct submodule_entry *a, *b;
+
+	a = container_of(eptr, const struct submodule_entry, ent);
+	b = container_of(entry_or_key, const struct submodule_entry, ent);
 
 	return strcmp(a->config->name, b->config->name) ||
-	       oidcmp(&a->config->gitmodules_oid, &b->config->gitmodules_oid);
+	       !oideq(&a->config->gitmodules_oid, &b->config->gitmodules_oid);
 }
 
 static struct submodule_cache *submodule_cache_alloc(void)
@@ -93,12 +99,12 @@ static void submodule_cache_clear(struct
 	 * allocation of struct submodule entries. Each is allocated by
 	 * their .gitmodules blob sha1 and submodule name.
 	 */
-	hashmap_iter_init(&cache->for_name, &iter);
-	while ((entry = hashmap_iter_next(&iter)))
+	hashmap_for_each_entry(&cache->for_name, &iter, entry,
+				ent /* member name */)
 		free_one_config(entry);
 
-	hashmap_free(&cache->for_path, 1);
-	hashmap_free(&cache->for_name, 1);
+	hashmap_free_entries(&cache->for_path, struct submodule_entry, ent);
+	hashmap_free_entries(&cache->for_name, struct submodule_entry, ent);
 	cache->initialized = 0;
 	cache->gitmodules_read = 0;
 }
@@ -121,9 +127,9 @@ static void cache_put_path(struct submod
 	unsigned int hash = hash_oid_string(&submodule->gitmodules_oid,
 					    submodule->path);
 	struct submodule_entry *e = xmalloc(sizeof(*e));
-	hashmap_entry_init(e, hash);
+	hashmap_entry_init(&e->ent, hash);
 	e->config = submodule;
-	hashmap_put(&cache->for_path, e);
+	hashmap_put(&cache->for_path, &e->ent);
 }
 
 static void cache_remove_path(struct submodule_cache *cache,
@@ -133,9 +139,9 @@ static void cache_remove_path(struct sub
 					    submodule->path);
 	struct submodule_entry e;
 	struct submodule_entry *removed;
-	hashmap_entry_init(&e, hash);
+	hashmap_entry_init(&e.ent, hash);
 	e.config = submodule;
-	removed = hashmap_remove(&cache->for_path, &e, NULL);
+	removed = hashmap_remove_entry(&cache->for_path, &e, ent, NULL);
 	free(removed);
 }
 
@@ -145,9 +151,9 @@ static void cache_add(struct submodule_c
 	unsigned int hash = hash_oid_string(&submodule->gitmodules_oid,
 					    submodule->name);
 	struct submodule_entry *e = xmalloc(sizeof(*e));
-	hashmap_entry_init(e, hash);
+	hashmap_entry_init(&e->ent, hash);
 	e->config = submodule;
-	hashmap_add(&cache->for_name, e);
+	hashmap_add(&cache->for_name, &e->ent);
 }
 
 static const struct submodule *cache_lookup_path(struct submodule_cache *cache,
@@ -161,10 +167,10 @@ static const struct submodule *cache_loo
 	oidcpy(&key_config.gitmodules_oid, gitmodules_oid);
 	key_config.path = path;
 
-	hashmap_entry_init(&key, hash);
+	hashmap_entry_init(&key.ent, hash);
 	key.config = &key_config;
 
-	entry = hashmap_get(&cache->for_path, &key, NULL);
+	entry = hashmap_get_entry(&cache->for_path, &key, ent, NULL);
 	if (entry)
 		return entry->config;
 	return NULL;
@@ -181,10 +187,10 @@ static struct submodule *cache_lookup_na
 	oidcpy(&key_config.gitmodules_oid, gitmodules_oid);
 	key_config.name = name;
 
-	hashmap_entry_init(&key, hash);
+	hashmap_entry_init(&key.ent, hash);
 	key.config = &key_config;
 
-	entry = hashmap_get(&cache->for_name, &key, NULL);
+	entry = hashmap_get_entry(&cache->for_name, &key, ent, NULL);
 	if (entry)
 		return entry->config;
 	return NULL;
@@ -279,7 +285,10 @@ static int parse_fetch_recurse(const cha
 	default:
 		if (!strcmp(arg, "on-demand"))
 			return RECURSE_SUBMODULES_ON_DEMAND;
-
+		/*
+		 * Please update $__git_fetch_recurse_submodules in
+		 * git-completion.bash when you add new options.
+		 */
 		if (die_on_error)
 			die("bad %s argument: %s", opt, arg);
 		else
@@ -360,6 +369,10 @@ static int parse_push_recurse(const char
 			return RECURSE_SUBMODULES_CHECK;
 		else if (!strcmp(arg, "only"))
 			return RECURSE_SUBMODULES_ONLY;
+		/*
+		 * Please update $__git_push_recurse_submodules in
+		 * git-completion.bash when you add new modes.
+		 */
 		else if (die_on_error)
 			die("bad %s argument: %s", opt, arg);
 		else
@@ -383,6 +396,12 @@ static void warn_multiple_config(const s
 			commit_string, name, option);
 }
 
+static void warn_command_line_option(const char *var, const char *value)
+{
+	warning(_("ignoring '%s' which may be interpreted as"
+		  " a command-line option: %s"), var, value);
+}
+
 struct parse_config_parameter {
 	struct submodule_cache *cache;
 	const struct object_id *treeish_name;
@@ -390,6 +409,13 @@ struct parse_config_parameter {
 	int overwrite;
 };
 
+/*
+ * Parse a config item from .gitmodules.
+ *
+ * This does not handle submodule-related configuration from the main
+ * config store (.git/config, etc).  Callers are responsible for
+ * checking for overrides in the main config store when appropriate.
+ */
 static int parse_config(const char *var, const char *value, void *data)
 {
 	struct parse_config_parameter *me = data;
@@ -408,6 +434,8 @@ static int parse_config(const char *var,
 	if (!strcmp(item.buf, "path")) {
 		if (!value)
 			ret = config_error_nonbool(var);
+		else if (looks_like_command_line_option(value))
+			warn_command_line_option(var, value);
 		else if (!me->overwrite && submodule->path)
 			warn_multiple_config(me->treeish_name, submodule->name,
 					"path");
@@ -448,6 +476,8 @@ static int parse_config(const char *var,
 	} else if (!strcmp(item.buf, "url")) {
 		if (!value) {
 			ret = config_error_nonbool(var);
+		} else if (looks_like_command_line_option(value)) {
+			warn_command_line_option(var, value);
 		} else if (!me->overwrite && submodule->url) {
 			warn_multiple_config(me->treeish_name, submodule->name,
 					"url");
@@ -463,8 +493,9 @@ static int parse_config(const char *var,
 			warn_multiple_config(me->treeish_name, submodule->name,
 					     "update");
 		else if (parse_submodule_update_strategy(value,
-			 &submodule->update_strategy) < 0)
-				die(_("invalid value for %s"), var);
+			 &submodule->update_strategy) < 0 ||
+			 submodule->update_strategy.type == SM_UPDATE_COMMAND)
+			die(_("invalid value for %s"), var);
 	} else if (!strcmp(item.buf, "shallow")) {
 		if (!me->overwrite && submodule->recommend_shallow != -1)
 			warn_multiple_config(me->treeish_name, submodule->name,
@@ -531,7 +562,9 @@ static const struct submodule *config_fr
 		struct hashmap_iter iter;
 		struct submodule_entry *entry;
 
-		entry = hashmap_iter_first(&cache->for_name, &iter);
+		entry = hashmap_iter_first_entry(&cache->for_name, &iter,
+						struct submodule_entry,
+						ent /* member name */);
 		if (!entry)
 			return NULL;
 		return entry->config;
@@ -561,7 +594,7 @@ static const struct submodule *config_fr
 	parameter.gitmodules_oid = &oid;
 	parameter.overwrite = 0;
 	git_config_from_mem(parse_config, CONFIG_ORIGIN_SUBMODULE_BLOB, rev.buf,
-			config, config_size, &parameter);
+			config, config_size, &parameter, NULL);
 	strbuf_release(&rev);
 	free(config);
 
@@ -591,6 +624,43 @@ static void submodule_cache_check_init(s
 	submodule_cache_init(repo->submodule_cache);
 }
 
+/*
+ * Note: This function is private for a reason, the '.gitmodules' file should
+ * not be used as a mechanism to retrieve arbitrary configuration stored in
+ * the repository.
+ *
+ * Runs the provided config function on the '.gitmodules' file found in the
+ * working directory.
+ */
+static void config_from_gitmodules(config_fn_t fn, struct repository *repo, void *data)
+{
+	if (repo->worktree) {
+		struct git_config_source config_source = { 0 };
+		const struct config_options opts = { 0 };
+		struct object_id oid;
+		char *file;
+		char *oidstr = NULL;
+
+		file = repo_worktree_path(repo, GITMODULES_FILE);
+		if (file_exists(file)) {
+			config_source.file = file;
+		} else if (repo_get_oid(repo, GITMODULES_INDEX, &oid) >= 0 ||
+			   repo_get_oid(repo, GITMODULES_HEAD, &oid) >= 0) {
+			config_source.blob = oidstr = xstrdup(oid_to_hex(&oid));
+			if (repo != the_repository)
+				add_to_alternates_memory(repo->objects->odb->path);
+		} else {
+			goto out;
+		}
+
+		config_with_options(fn, data, &config_source, &opts);
+
+out:
+		free(oidstr);
+		free(file);
+	}
+}
+
 static int gitmodules_cb(const char *var, const char *value, void *data)
 {
 	struct repository *repo = data;
@@ -608,19 +678,11 @@ void repo_read_gitmodules(struct reposit
 {
 	submodule_cache_check_init(repo);
 
-	if (repo->worktree) {
-		char *gitmodules;
-
-		if (repo_read_index(repo) < 0)
-			return;
-
-		gitmodules = repo_worktree_path(repo, GITMODULES_FILE);
-
-		if (!is_gitmodules_unmerged(repo->index))
-			git_config_from_file(gitmodules_cb, gitmodules, repo);
+	if (repo_read_index(repo) < 0)
+		return;
 
-		free(gitmodules);
-	}
+	if (!is_gitmodules_unmerged(repo->index))
+		config_from_gitmodules(gitmodules_cb, repo, repo);
 
 	repo->submodule_cache->gitmodules_read = 1;
 }
@@ -671,3 +733,82 @@ void submodule_free(struct repository *r
 	if (r->submodule_cache)
 		submodule_cache_clear(r->submodule_cache);
 }
+
+static int config_print_callback(const char *var, const char *value, void *cb_data)
+{
+	char *wanted_key = cb_data;
+
+	if (!strcmp(wanted_key, var))
+		printf("%s\n", value);
+
+	return 0;
+}
+
+int print_config_from_gitmodules(struct repository *repo, const char *key)
+{
+	int ret;
+	char *store_key;
+
+	ret = git_config_parse_key(key, &store_key, NULL);
+	if (ret < 0)
+		return CONFIG_INVALID_KEY;
+
+	config_from_gitmodules(config_print_callback, repo, store_key);
+
+	free(store_key);
+	return 0;
+}
+
+int config_set_in_gitmodules_file_gently(const char *key, const char *value)
+{
+	int ret;
+
+	ret = git_config_set_in_file_gently(GITMODULES_FILE, key, value);
+	if (ret < 0)
+		/* Maybe the user already did that, don't error out here */
+		warning(_("Could not update .gitmodules entry %s"), key);
+
+	return ret;
+}
+
+struct fetch_config {
+	int *max_children;
+	int *recurse_submodules;
+};
+
+static int gitmodules_fetch_config(const char *var, const char *value, void *cb)
+{
+	struct fetch_config *config = cb;
+	if (!strcmp(var, "submodule.fetchjobs")) {
+		*(config->max_children) = parse_submodule_fetchjobs(var, value);
+		return 0;
+	} else if (!strcmp(var, "fetch.recursesubmodules")) {
+		*(config->recurse_submodules) = parse_fetch_recurse_submodules_arg(var, value);
+		return 0;
+	}
+
+	return 0;
+}
+
+void fetch_config_from_gitmodules(int *max_children, int *recurse_submodules)
+{
+	struct fetch_config config = {
+		.max_children = max_children,
+		.recurse_submodules = recurse_submodules
+	};
+	config_from_gitmodules(gitmodules_fetch_config, the_repository, &config);
+}
+
+static int gitmodules_update_clone_config(const char *var, const char *value,
+					  void *cb)
+{
+	int *max_jobs = cb;
+	if (!strcmp(var, "submodule.fetchjobs"))
+		*max_jobs = parse_submodule_fetchjobs(var, value);
+	return 0;
+}
+
+void update_clone_config_from_gitmodules(int *max_jobs)
+{
+	config_from_gitmodules(gitmodules_update_clone_config, the_repository, &max_jobs);
+}
diff -pruN 1.2.1+git2.18.0-1/git/submodule-config.h 1.2.3+git2.25.1-1/git/submodule-config.h
--- 1.2.1+git2.18.0-1/git/submodule-config.h	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/submodule-config.h	2020-02-17 04:47:35.000000000 +0000
@@ -2,13 +2,36 @@
 #define SUBMODULE_CONFIG_CACHE_H
 
 #include "cache.h"
+#include "config.h"
 #include "hashmap.h"
 #include "submodule.h"
 #include "strbuf.h"
 
+/**
+ * The submodule config cache API allows to read submodule
+ * configurations/information from specified revisions. Internally
+ * information is lazily read into a cache that is used to avoid
+ * unnecessary parsing of the same .gitmodules files. Lookups can be done by
+ * submodule path or name.
+ *
+ * Usage
+ * -----
+ *
+ * The caller can look up information about submodules by using the
+ * `submodule_from_path()` or `submodule_from_name()` functions. They return
+ * a `struct submodule` which contains the values. The API automatically
+ * initializes and allocates the needed infrastructure on-demand. If the
+ * caller does only want to lookup values from revisions the initialization
+ * can be skipped.
+ *
+ * If the internal cache might grow too big or when the caller is done with
+ * the API, all internally cached values can be freed with submodule_free().
+ *
+ */
+
 /*
  * Submodule entry containing the information about a certain submodule
- * in a certain revision.
+ * in a certain revision. It is returned by the lookup functions.
  */
 struct submodule {
 	const char *path;
@@ -29,25 +52,41 @@ struct submodule {
 struct submodule_cache;
 struct repository;
 
-extern void submodule_cache_free(struct submodule_cache *cache);
+void submodule_cache_free(struct submodule_cache *cache);
 
-extern int parse_submodule_fetchjobs(const char *var, const char *value);
-extern int parse_fetch_recurse_submodules_arg(const char *opt, const char *arg);
+int parse_submodule_fetchjobs(const char *var, const char *value);
+int parse_fetch_recurse_submodules_arg(const char *opt, const char *arg);
 struct option;
-extern int option_fetch_parse_recurse_submodules(const struct option *opt,
-						 const char *arg, int unset);
-extern int parse_update_recurse_submodules_arg(const char *opt, const char *arg);
-extern int parse_push_recurse_submodules_arg(const char *opt, const char *arg);
-extern void repo_read_gitmodules(struct repository *repo);
-extern void gitmodules_config_oid(const struct object_id *commit_oid);
+int option_fetch_parse_recurse_submodules(const struct option *opt,
+					  const char *arg, int unset);
+int parse_update_recurse_submodules_arg(const char *opt, const char *arg);
+int parse_push_recurse_submodules_arg(const char *opt, const char *arg);
+void repo_read_gitmodules(struct repository *repo);
+void gitmodules_config_oid(const struct object_id *commit_oid);
+
+/**
+ * Same as submodule_from_path but lookup by name.
+ */
 const struct submodule *submodule_from_name(struct repository *r,
 					    const struct object_id *commit_or_tree,
 					    const char *name);
+
+/**
+ * Given a tree-ish in the superproject and a path, return the submodule that
+ * is bound at the path in the named tree.
+ */
 const struct submodule *submodule_from_path(struct repository *r,
 					    const struct object_id *commit_or_tree,
 					    const char *path);
+
+/**
+ * Use these to free the internally cached values.
+ */
 void submodule_free(struct repository *r);
 
+int print_config_from_gitmodules(struct repository *repo, const char *key);
+int config_set_in_gitmodules_file_gently(const char *key, const char *value);
+
 /*
  * Returns 0 if the name is syntactically acceptable as a submodule "name"
  * (e.g., that may be found in the subsection of a .gitmodules file) and -1
@@ -55,4 +94,15 @@ void submodule_free(struct repository *r
  */
 int check_submodule_name(const char *name);
 
+/*
+ * Note: these helper functions exist solely to maintain backward
+ * compatibility with 'fetch' and 'update_clone' storing configuration in
+ * '.gitmodules'.
+ *
+ * New helpers to retrieve arbitrary configuration from the '.gitmodules' file
+ * should NOT be added.
+ */
+void fetch_config_from_gitmodules(int *max_children, int *recurse_submodules);
+void update_clone_config_from_gitmodules(int *max_jobs);
+
 #endif /* SUBMODULE_CONFIG_H */
diff -pruN 1.2.1+git2.18.0-1/git/submodule.h 1.2.3+git2.25.1-1/git/submodule.h
--- 1.2.1+git2.18.0-1/git/submodule.h	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/submodule.h	2020-02-17 04:47:35.000000000 +0000
@@ -1,11 +1,17 @@
 #ifndef SUBMODULE_H
 #define SUBMODULE_H
 
-struct repository;
-struct diff_options;
 struct argv_array;
+struct cache_entry;
+struct diff_options;
+struct index_state;
+struct object_id;
 struct oid_array;
+struct pathspec;
 struct remote;
+struct repository;
+struct string_list;
+struct strbuf;
 
 enum {
 	RECURSE_SUBMODULES_ONLY = -5,
@@ -33,62 +39,63 @@ struct submodule_update_strategy {
 };
 #define SUBMODULE_UPDATE_STRATEGY_INIT {SM_UPDATE_UNSPECIFIED, NULL}
 
-extern int is_gitmodules_unmerged(const struct index_state *istate);
-extern int is_staging_gitmodules_ok(struct index_state *istate);
-extern int update_path_in_gitmodules(const char *oldpath, const char *newpath);
-extern int remove_path_from_gitmodules(const char *path);
-extern void stage_updated_gitmodules(struct index_state *istate);
-extern void set_diffopt_flags_from_submodule_config(struct diff_options *,
-		const char *path);
-extern int git_default_submodule_config(const char *var, const char *value, void *cb);
+int is_gitmodules_unmerged(const struct index_state *istate);
+int is_writing_gitmodules_ok(void);
+int is_staging_gitmodules_ok(struct index_state *istate);
+int update_path_in_gitmodules(const char *oldpath, const char *newpath);
+int remove_path_from_gitmodules(const char *path);
+void stage_updated_gitmodules(struct index_state *istate);
+void set_diffopt_flags_from_submodule_config(struct diff_options *,
+					     const char *path);
+int git_default_submodule_config(const char *var, const char *value, void *cb);
 
 struct option;
 int option_parse_recurse_submodules_worktree_updater(const struct option *opt,
 						     const char *arg, int unset);
-extern int is_submodule_active(struct repository *repo, const char *path);
+int is_submodule_active(struct repository *repo, const char *path);
 /*
  * Determine if a submodule has been populated at a given 'path' by checking if
  * the <path>/.git resolves to a valid git repository.
  * If return_error_code is NULL, die on error.
  * Otherwise the return error code is the same as of resolve_gitdir_gently.
  */
-extern int is_submodule_populated_gently(const char *path, int *return_error_code);
-extern void die_in_unpopulated_submodule(const struct index_state *istate,
-					 const char *prefix);
-extern void die_path_inside_submodule(const struct index_state *istate,
-				      const struct pathspec *ps);
-extern enum submodule_update_type parse_submodule_update_type(const char *value);
-extern int parse_submodule_update_strategy(const char *value,
-		struct submodule_update_strategy *dst);
-extern const char *submodule_strategy_to_string(const struct submodule_update_strategy *s);
-extern void handle_ignore_submodules_arg(struct diff_options *, const char *);
-extern void show_submodule_summary(struct diff_options *o, const char *path,
-		struct object_id *one, struct object_id *two,
-		unsigned dirty_submodule);
-extern void show_submodule_inline_diff(struct diff_options *o, const char *path,
-		struct object_id *one, struct object_id *two,
-		unsigned dirty_submodule);
+int is_submodule_populated_gently(const char *path, int *return_error_code);
+void die_in_unpopulated_submodule(const struct index_state *istate,
+				  const char *prefix);
+void die_path_inside_submodule(const struct index_state *istate,
+			       const struct pathspec *ps);
+enum submodule_update_type parse_submodule_update_type(const char *value);
+int parse_submodule_update_strategy(const char *value,
+				    struct submodule_update_strategy *dst);
+const char *submodule_strategy_to_string(const struct submodule_update_strategy *s);
+void handle_ignore_submodules_arg(struct diff_options *, const char *);
+void show_submodule_summary(struct diff_options *o, const char *path,
+			    struct object_id *one, struct object_id *two,
+			    unsigned dirty_submodule);
+void show_submodule_inline_diff(struct diff_options *o, const char *path,
+				struct object_id *one, struct object_id *two,
+				unsigned dirty_submodule);
 /* Check if we want to update any submodule.*/
-extern int should_update_submodules(void);
+int should_update_submodules(void);
 /*
  * Returns the submodule struct if the given ce entry is a submodule
  * and it should be updated. Returns NULL otherwise.
  */
-extern const struct submodule *submodule_from_ce(const struct cache_entry *ce);
-extern void check_for_new_submodule_commits(struct object_id *oid);
-extern int fetch_populated_submodules(struct repository *r,
-				      const struct argv_array *options,
-				      const char *prefix,
-				      int command_line_option,
-				      int default_option,
-				      int quiet, int max_parallel_jobs);
-extern unsigned is_submodule_modified(const char *path, int ignore_untracked);
-extern int submodule_uses_gitfile(const char *path);
+const struct submodule *submodule_from_ce(const struct cache_entry *ce);
+void check_for_new_submodule_commits(struct object_id *oid);
+int fetch_populated_submodules(struct repository *r,
+			       const struct argv_array *options,
+			       const char *prefix,
+			       int command_line_option,
+			       int default_option,
+			       int quiet, int max_parallel_jobs);
+unsigned is_submodule_modified(const char *path, int ignore_untracked);
+int submodule_uses_gitfile(const char *path);
 
 #define SUBMODULE_REMOVAL_DIE_ON_ERROR (1<<0)
 #define SUBMODULE_REMOVAL_IGNORE_UNTRACKED (1<<1)
 #define SUBMODULE_REMOVAL_IGNORE_IGNORED_UNTRACKED (1<<2)
-extern int bad_to_remove_submodule(const char *path, unsigned flags);
+int bad_to_remove_submodule(const char *path, unsigned flags);
 
 int add_submodule_odb(const char *path);
 
@@ -96,17 +103,20 @@ int add_submodule_odb(const char *path);
  * Checks if there are submodule changes in a..b. If a is the null OID,
  * checks b and all its ancestors instead.
  */
-extern int submodule_touches_in_range(struct object_id *a,
-				      struct object_id *b);
-extern int find_unpushed_submodules(struct oid_array *commits,
-				    const char *remotes_name,
-				    struct string_list *needs_pushing);
+int submodule_touches_in_range(struct repository *r,
+			       struct object_id *a,
+			       struct object_id *b);
+int find_unpushed_submodules(struct repository *r,
+			     struct oid_array *commits,
+			     const char *remotes_name,
+			     struct string_list *needs_pushing);
 struct refspec;
-extern int push_unpushed_submodules(struct oid_array *commits,
-				    const struct remote *remote,
-				    const struct refspec *rs,
-				    const struct string_list *push_options,
-				    int dry_run);
+int push_unpushed_submodules(struct repository *r,
+			     struct oid_array *commits,
+			     const struct remote *remote,
+			     const struct refspec *rs,
+			     const struct string_list *push_options,
+			     int dry_run);
 /*
  * Given a submodule path (as in the index), return the repository
  * path of that submodule in 'buf'. Return -1 on error or when the
@@ -114,30 +124,36 @@ extern int push_unpushed_submodules(stru
  */
 int submodule_to_gitdir(struct strbuf *buf, const char *submodule);
 
+/*
+ * Make sure that no submodule's git dir is nested in a sibling submodule's.
+ */
+int validate_submodule_git_dir(char *git_dir, const char *submodule_name);
+
 #define SUBMODULE_MOVE_HEAD_DRY_RUN (1<<0)
 #define SUBMODULE_MOVE_HEAD_FORCE   (1<<1)
-extern int submodule_move_head(const char *path,
-			       const char *old,
-			       const char *new_head,
-			       unsigned flags);
+int submodule_move_head(const char *path,
+			const char *old,
+			const char *new_head,
+			unsigned flags);
+
+void submodule_unset_core_worktree(const struct submodule *sub);
 
 /*
  * Prepare the "env_array" parameter of a "struct child_process" for executing
  * a submodule by clearing any repo-specific environment variables, but
  * retaining any config in the environment.
  */
-extern void prepare_submodule_repo_env(struct argv_array *out);
+void prepare_submodule_repo_env(struct argv_array *out);
 
 #define ABSORB_GITDIR_RECURSE_SUBMODULES (1<<0)
-extern void absorb_git_dir_into_superproject(const char *prefix,
-					     const char *path,
-					     unsigned flags);
+void absorb_git_dir_into_superproject(const char *path,
+				      unsigned flags);
 
 /*
  * Return the absolute path of the working tree of the superproject, which this
  * project is a submodule of. If this repository is not a submodule of
  * another repository, return NULL.
  */
-extern const char *get_superproject_working_tree(void);
+const char *get_superproject_working_tree(void);
 
 #endif
diff -pruN 1.2.1+git2.18.0-1/git/sub-process.c 1.2.3+git2.25.1-1/git/sub-process.c
--- 1.2.1+git2.18.0-1/git/sub-process.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/sub-process.c	2020-02-17 04:47:35.000000000 +0000
@@ -6,12 +6,14 @@
 #include "pkt-line.h"
 
 int cmd2process_cmp(const void *unused_cmp_data,
-		    const void *entry,
-		    const void *entry_or_key,
+		    const struct hashmap_entry *eptr,
+		    const struct hashmap_entry *entry_or_key,
 		    const void *unused_keydata)
 {
-	const struct subprocess_entry *e1 = entry;
-	const struct subprocess_entry *e2 = entry_or_key;
+	const struct subprocess_entry *e1, *e2;
+
+	e1 = container_of(eptr, const struct subprocess_entry, ent);
+	e2 = container_of(entry_or_key, const struct subprocess_entry, ent);
 
 	return strcmp(e1->cmd, e2->cmd);
 }
@@ -20,9 +22,9 @@ struct subprocess_entry *subprocess_find
 {
 	struct subprocess_entry key;
 
-	hashmap_entry_init(&key, strhash(cmd));
+	hashmap_entry_init(&key.ent, strhash(cmd));
 	key.cmd = cmd;
-	return hashmap_get(hashmap, &key, NULL);
+	return hashmap_get_entry(hashmap, &key, ent, NULL);
 }
 
 int subprocess_read_status(int fd, struct strbuf *status)
@@ -58,7 +60,7 @@ void subprocess_stop(struct hashmap *has
 	kill(entry->process.pid, SIGTERM);
 	finish_command(&entry->process);
 
-	hashmap_remove(hashmap, entry, NULL);
+	hashmap_remove(hashmap, &entry->ent, NULL);
 }
 
 static void subprocess_exit_handler(struct child_process *process)
@@ -88,6 +90,7 @@ int subprocess_start(struct hashmap *has
 	process->out = -1;
 	process->clean_on_exit = 1;
 	process->clean_on_exit_handler = subprocess_exit_handler;
+	process->trace2_child_class = "subprocess";
 
 	err = start_command(process);
 	if (err) {
@@ -95,7 +98,7 @@ int subprocess_start(struct hashmap *has
 		return err;
 	}
 
-	hashmap_entry_init(entry, strhash(cmd));
+	hashmap_entry_init(&entry->ent, strhash(cmd));
 
 	err = startfn(entry);
 	if (err) {
@@ -104,7 +107,7 @@ int subprocess_start(struct hashmap *has
 		return err;
 	}
 
-	hashmap_add(hashmap, entry);
+	hashmap_add(hashmap, &entry->ent);
 	return 0;
 }
 
diff -pruN 1.2.1+git2.18.0-1/git/sub-process.h 1.2.3+git2.25.1-1/git/sub-process.h
--- 1.2.1+git2.18.0-1/git/sub-process.h	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/sub-process.h	2020-02-17 04:47:35.000000000 +0000
@@ -24,7 +24,7 @@
 
 /* Members should not be accessed directly. */
 struct subprocess_entry {
-	struct hashmap_entry ent; /* must be the first member! */
+	struct hashmap_entry ent;
 	const char *cmd;
 	struct child_process process;
 };
@@ -42,10 +42,10 @@ struct subprocess_capability {
 /* subprocess functions */
 
 /* Function to test two subprocess hashmap entries for equality. */
-extern int cmd2process_cmp(const void *unused_cmp_data,
-			   const void *e1,
-			   const void *e2,
-			   const void *unused_keydata);
+int cmd2process_cmp(const void *unused_cmp_data,
+		    const struct hashmap_entry *e,
+		    const struct hashmap_entry *entry_or_key,
+		    const void *unused_keydata);
 
 /*
  * User-supplied function to initialize the sub-process.  This is
diff -pruN 1.2.1+git2.18.0-1/git/symlinks.c 1.2.3+git2.25.1-1/git/symlinks.c
--- 1.2.1+git2.18.0-1/git/symlinks.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/symlinks.c	2020-02-17 04:47:35.000000000 +0000
@@ -221,7 +221,7 @@ int has_symlink_leading_path(const char
  */
 int check_leading_path(const char *name, int len)
 {
-    return threaded_check_leading_path(&default_cache, name, len);
+	return threaded_check_leading_path(&default_cache, name, len);
 }
 
 /*
diff -pruN 1.2.1+git2.18.0-1/git/t/annotate-tests.sh 1.2.3+git2.25.1-1/git/t/annotate-tests.sh
--- 1.2.1+git2.18.0-1/git/t/annotate-tests.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/annotate-tests.sh	2020-02-17 04:47:35.000000000 +0000
@@ -68,6 +68,14 @@ test_expect_success 'blame 1 author' '
 	check_count A 2
 '
 
+test_expect_success 'blame in a bare repo without starting commit' '
+	git clone --bare . bare.git &&
+	(
+		cd bare.git &&
+		check_count A 2
+	)
+'
+
 test_expect_success 'blame by tag objects' '
 	git tag -m "test tag" testTag &&
 	git tag -m "test tag #2" testTag2 testTag &&
@@ -320,11 +328,11 @@ test_expect_success 'blame -L ,Y (Y == n
 
 test_expect_success 'blame -L ,Y (Y == nlines + 1)' '
 	n=$(expr $(wc -l <file) + 2) &&
-	test_must_fail $PROG -L,$n file
+	check_count -L,$n A 1 B 1 B1 1 B2 1 "A U Thor" 1 C 1 D 1 E 1
 '
 
 test_expect_success 'blame -L ,Y (Y > nlines)' '
-	test_must_fail $PROG -L,12345 file
+	check_count -L,12345 A 1 B 1 B1 1 B2 1 "A U Thor" 1 C 1 D 1 E 1
 '
 
 test_expect_success 'blame -L multiple (disjoint)' '
diff -pruN 1.2.1+git2.18.0-1/git/t/chainlint/arithmetic-expansion.expect 1.2.3+git2.25.1-1/git/t/chainlint/arithmetic-expansion.expect
--- 1.2.1+git2.18.0-1/git/t/chainlint/arithmetic-expansion.expect	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/chainlint/arithmetic-expansion.expect	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,9 @@
+(
+	foo &&
+	bar=$((42 + 1)) &&
+	baz
+>) &&
+(
+?!AMP?!	bar=$((42 + 1))
+	baz
+>)
diff -pruN 1.2.1+git2.18.0-1/git/t/chainlint/arithmetic-expansion.test 1.2.3+git2.25.1-1/git/t/chainlint/arithmetic-expansion.test
--- 1.2.1+git2.18.0-1/git/t/chainlint/arithmetic-expansion.test	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/chainlint/arithmetic-expansion.test	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,11 @@
+(
+	foo &&
+# LINT: closing ")" of $((...)) not misinterpreted as subshell-closing ")"
+	bar=$((42 + 1)) &&
+	baz
+) &&
+(
+# LINT: missing "&&" on $((...))
+	bar=$((42 + 1))
+	baz
+)
diff -pruN 1.2.1+git2.18.0-1/git/t/chainlint/bash-array.expect 1.2.3+git2.25.1-1/git/t/chainlint/bash-array.expect
--- 1.2.1+git2.18.0-1/git/t/chainlint/bash-array.expect	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/chainlint/bash-array.expect	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,10 @@
+(
+	foo &&
+	bar=(gumbo stumbo wumbo) &&
+	baz
+>) &&
+(
+	foo &&
+	bar=${#bar[@]} &&
+	baz
+>)
diff -pruN 1.2.1+git2.18.0-1/git/t/chainlint/bash-array.test 1.2.3+git2.25.1-1/git/t/chainlint/bash-array.test
--- 1.2.1+git2.18.0-1/git/t/chainlint/bash-array.test	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/chainlint/bash-array.test	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,12 @@
+(
+	foo &&
+# LINT: ")" in Bash array assignment not misinterpreted as subshell-closing ")"
+	bar=(gumbo stumbo wumbo) &&
+	baz
+) &&
+(
+	foo &&
+# LINT: Bash array length operator not misinterpreted as comment
+	bar=${#bar[@]} &&
+	baz
+)
diff -pruN 1.2.1+git2.18.0-1/git/t/chainlint/blank-line.expect 1.2.3+git2.25.1-1/git/t/chainlint/blank-line.expect
--- 1.2.1+git2.18.0-1/git/t/chainlint/blank-line.expect	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/chainlint/blank-line.expect	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,4 @@
+(
+	nothing &&
+	something
+>)
diff -pruN 1.2.1+git2.18.0-1/git/t/chainlint/blank-line.test 1.2.3+git2.25.1-1/git/t/chainlint/blank-line.test
--- 1.2.1+git2.18.0-1/git/t/chainlint/blank-line.test	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/chainlint/blank-line.test	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,10 @@
+(
+
+	nothing &&
+
+	something
+# LINT: swallow blank lines since final _statement_ before subshell end is
+# LINT: significant to "&&"-check, not final _line_ (which might be blank)
+
+
+)
diff -pruN 1.2.1+git2.18.0-1/git/t/chainlint/block.expect 1.2.3+git2.25.1-1/git/t/chainlint/block.expect
--- 1.2.1+git2.18.0-1/git/t/chainlint/block.expect	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/chainlint/block.expect	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,12 @@
+(
+	foo &&
+	{
+		echo a
+		echo b
+	} &&
+	bar &&
+	{
+		echo c
+?!AMP?!	}
+	baz
+>)
diff -pruN 1.2.1+git2.18.0-1/git/t/chainlint/block.test 1.2.3+git2.25.1-1/git/t/chainlint/block.test
--- 1.2.1+git2.18.0-1/git/t/chainlint/block.test	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/chainlint/block.test	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,15 @@
+(
+# LINT: missing "&&" in block not currently detected (for consistency with
+# LINT: --chain-lint at top level and to provide escape hatch if needed)
+	foo &&
+	{
+		echo a
+		echo b
+	} &&
+	bar &&
+# LINT: missing "&&" at closing "}"
+	{
+		echo c
+	}
+	baz
+)
diff -pruN 1.2.1+git2.18.0-1/git/t/chainlint/broken-chain.expect 1.2.3+git2.25.1-1/git/t/chainlint/broken-chain.expect
--- 1.2.1+git2.18.0-1/git/t/chainlint/broken-chain.expect	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/chainlint/broken-chain.expect	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,6 @@
+(
+	foo &&
+?!AMP?!	bar
+	baz &&
+	wop
+>)
diff -pruN 1.2.1+git2.18.0-1/git/t/chainlint/broken-chain.test 1.2.3+git2.25.1-1/git/t/chainlint/broken-chain.test
--- 1.2.1+git2.18.0-1/git/t/chainlint/broken-chain.test	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/chainlint/broken-chain.test	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,8 @@
+(
+	foo &&
+# LINT: missing "&&" from 'bar'
+	bar
+	baz &&
+# LINT: final statement before closing ")" legitimately lacks "&&"
+	wop
+)
diff -pruN 1.2.1+git2.18.0-1/git/t/chainlint/case.expect 1.2.3+git2.25.1-1/git/t/chainlint/case.expect
--- 1.2.1+git2.18.0-1/git/t/chainlint/case.expect	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/chainlint/case.expect	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,19 @@
+(
+	case "$x" in
+	x) foo ;;
+	*) bar ;;
+	esac &&
+	foobar
+>) &&
+(
+	case "$x" in
+	x) foo ;;
+	*) bar ;;
+?!AMP?!	esac
+	foobar
+>) &&
+(
+	case "$x" in 1) true;; esac &&
+?!AMP?!	case "$y" in 2) false;; esac
+	foobar
+>)
diff -pruN 1.2.1+git2.18.0-1/git/t/chainlint/case.test 1.2.3+git2.25.1-1/git/t/chainlint/case.test
--- 1.2.1+git2.18.0-1/git/t/chainlint/case.test	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/chainlint/case.test	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,23 @@
+(
+# LINT: "...)" arms in 'case' not misinterpreted as subshell-closing ")"
+	case "$x" in
+	x) foo ;;
+	*) bar ;;
+	esac &&
+	foobar
+) &&
+(
+# LINT: missing "&&" on 'esac'
+	case "$x" in
+	x) foo ;;
+	*) bar ;;
+	esac
+	foobar
+) &&
+(
+# LINT: "...)" arm in one-liner 'case' not misinterpreted as closing ")"
+	case "$x" in 1) true;; esac &&
+# LINT: same but missing "&&"
+	case "$y" in 2) false;; esac
+	foobar
+)
diff -pruN 1.2.1+git2.18.0-1/git/t/chainlint/close-nested-and-parent-together.expect 1.2.3+git2.25.1-1/git/t/chainlint/close-nested-and-parent-together.expect
--- 1.2.1+git2.18.0-1/git/t/chainlint/close-nested-and-parent-together.expect	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/chainlint/close-nested-and-parent-together.expect	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,4 @@
+(
+cd foo &&
+	(bar &&
+>>>		baz))
diff -pruN 1.2.1+git2.18.0-1/git/t/chainlint/close-nested-and-parent-together.test 1.2.3+git2.25.1-1/git/t/chainlint/close-nested-and-parent-together.test
--- 1.2.1+git2.18.0-1/git/t/chainlint/close-nested-and-parent-together.test	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/chainlint/close-nested-and-parent-together.test	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,3 @@
+(cd foo &&
+	(bar &&
+		baz))
diff -pruN 1.2.1+git2.18.0-1/git/t/chainlint/close-subshell.expect 1.2.3+git2.25.1-1/git/t/chainlint/close-subshell.expect
--- 1.2.1+git2.18.0-1/git/t/chainlint/close-subshell.expect	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/chainlint/close-subshell.expect	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,25 @@
+(
+	foo
+>) &&
+(
+	bar
+>) >out &&
+(
+	baz
+>) 2>err &&
+(
+	boo
+>) <input &&
+(
+	bip
+>) | wuzzle &&
+(
+	bop
+>) | fazz 	fozz &&
+(
+	bup
+>) |
+fuzzle &&
+(
+	yop
+>)
diff -pruN 1.2.1+git2.18.0-1/git/t/chainlint/close-subshell.test 1.2.3+git2.25.1-1/git/t/chainlint/close-subshell.test
--- 1.2.1+git2.18.0-1/git/t/chainlint/close-subshell.test	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/chainlint/close-subshell.test	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,27 @@
+# LINT: closing ")" with various decorations ("&&", ">", "|", etc.)
+(
+	foo
+) &&
+(
+	bar
+) >out &&
+(
+	baz
+) 2>err &&
+(
+	boo
+) <input &&
+(
+	bip
+) | wuzzle &&
+(
+	bop
+) | fazz \
+	fozz &&
+(
+	bup
+) |
+fuzzle &&
+(
+	yop
+)
diff -pruN 1.2.1+git2.18.0-1/git/t/chainlint/command-substitution.expect 1.2.3+git2.25.1-1/git/t/chainlint/command-substitution.expect
--- 1.2.1+git2.18.0-1/git/t/chainlint/command-substitution.expect	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/chainlint/command-substitution.expect	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,9 @@
+(
+	foo &&
+	bar=$(gobble) &&
+	baz
+>) &&
+(
+?!AMP?!	bar=$(gobble blocks)
+	baz
+>)
diff -pruN 1.2.1+git2.18.0-1/git/t/chainlint/command-substitution.test 1.2.3+git2.25.1-1/git/t/chainlint/command-substitution.test
--- 1.2.1+git2.18.0-1/git/t/chainlint/command-substitution.test	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/chainlint/command-substitution.test	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,11 @@
+(
+	foo &&
+# LINT: closing ")" of $(...) not misinterpreted as subshell-closing ")"
+	bar=$(gobble) &&
+	baz
+) &&
+(
+# LINT: missing "&&" on $(...)
+	bar=$(gobble blocks)
+	baz
+)
diff -pruN 1.2.1+git2.18.0-1/git/t/chainlint/comment.expect 1.2.3+git2.25.1-1/git/t/chainlint/comment.expect
--- 1.2.1+git2.18.0-1/git/t/chainlint/comment.expect	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/chainlint/comment.expect	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,4 @@
+(
+	nothing &&
+	something
+>)
diff -pruN 1.2.1+git2.18.0-1/git/t/chainlint/comment.test 1.2.3+git2.25.1-1/git/t/chainlint/comment.test
--- 1.2.1+git2.18.0-1/git/t/chainlint/comment.test	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/chainlint/comment.test	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,11 @@
+(
+# LINT: swallow comment lines
+	# comment 1
+	nothing &&
+	# comment 2
+	something
+# LINT: swallow comment lines since final _statement_ before subshell end is
+# LINT: significant to "&&"-check, not final _line_ (which might be comment)
+	# comment 3
+	# comment 4
+)
diff -pruN 1.2.1+git2.18.0-1/git/t/chainlint/complex-if-in-cuddled-loop.expect 1.2.3+git2.25.1-1/git/t/chainlint/complex-if-in-cuddled-loop.expect
--- 1.2.1+git2.18.0-1/git/t/chainlint/complex-if-in-cuddled-loop.expect	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/chainlint/complex-if-in-cuddled-loop.expect	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,10 @@
+(
+for i in a b c; do
+   if test "$(echo $(waffle bat))" = "eleventeen" &&
+     test "$x" = "$y"; then
+     :
+   else
+     echo >file
+   fi
+> done) &&
+test ! -f file
diff -pruN 1.2.1+git2.18.0-1/git/t/chainlint/complex-if-in-cuddled-loop.test 1.2.3+git2.25.1-1/git/t/chainlint/complex-if-in-cuddled-loop.test
--- 1.2.1+git2.18.0-1/git/t/chainlint/complex-if-in-cuddled-loop.test	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/chainlint/complex-if-in-cuddled-loop.test	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,11 @@
+# LINT: 'for' loop cuddled with "(" and ")" and nested 'if' with complex
+# LINT: multi-line condition; indented with spaces, not tabs
+(for i in a b c; do
+   if test "$(echo $(waffle bat))" = "eleventeen" &&
+     test "$x" = "$y"; then
+     :
+   else
+     echo >file
+   fi
+ done) &&
+test ! -f file
diff -pruN 1.2.1+git2.18.0-1/git/t/chainlint/cuddled.expect 1.2.3+git2.25.1-1/git/t/chainlint/cuddled.expect
--- 1.2.1+git2.18.0-1/git/t/chainlint/cuddled.expect	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/chainlint/cuddled.expect	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,21 @@
+(
+cd foo &&
+	bar
+>) &&
+
+(
+?!AMP?!cd foo
+	bar
+>) &&
+
+(
+	cd foo &&
+>	bar) &&
+
+(
+cd foo &&
+>	bar) &&
+
+(
+?!AMP?!cd foo
+>	bar)
diff -pruN 1.2.1+git2.18.0-1/git/t/chainlint/cuddled-if-then-else.expect 1.2.3+git2.25.1-1/git/t/chainlint/cuddled-if-then-else.expect
--- 1.2.1+git2.18.0-1/git/t/chainlint/cuddled-if-then-else.expect	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/chainlint/cuddled-if-then-else.expect	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,7 @@
+(
+if test -z ""; then
+    echo empty
+ else
+    echo bizzy
+> fi) &&
+echo foobar
diff -pruN 1.2.1+git2.18.0-1/git/t/chainlint/cuddled-if-then-else.test 1.2.3+git2.25.1-1/git/t/chainlint/cuddled-if-then-else.test
--- 1.2.1+git2.18.0-1/git/t/chainlint/cuddled-if-then-else.test	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/chainlint/cuddled-if-then-else.test	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,7 @@
+# LINT: 'if' cuddled with "(" and ")"; indented with spaces, not tabs
+(if test -z ""; then
+    echo empty
+ else
+    echo bizzy
+ fi) &&
+echo foobar
diff -pruN 1.2.1+git2.18.0-1/git/t/chainlint/cuddled-loop.expect 1.2.3+git2.25.1-1/git/t/chainlint/cuddled-loop.expect
--- 1.2.1+git2.18.0-1/git/t/chainlint/cuddled-loop.expect	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/chainlint/cuddled-loop.expect	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,5 @@
+(
+ while read x
+  do foobar bop || exit 1
+>  done <file ) &&
+outside subshell
diff -pruN 1.2.1+git2.18.0-1/git/t/chainlint/cuddled-loop.test 1.2.3+git2.25.1-1/git/t/chainlint/cuddled-loop.test
--- 1.2.1+git2.18.0-1/git/t/chainlint/cuddled-loop.test	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/chainlint/cuddled-loop.test	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,7 @@
+# LINT: 'while' loop cuddled with "(" and ")", with embedded (allowed)
+# LINT: "|| exit {n}" to exit loop early, and using redirection "<" to feed
+# LINT: loop; indented with spaces, not tabs
+( while read x
+  do foobar bop || exit 1
+  done <file ) &&
+outside subshell
diff -pruN 1.2.1+git2.18.0-1/git/t/chainlint/cuddled.test 1.2.3+git2.25.1-1/git/t/chainlint/cuddled.test
--- 1.2.1+git2.18.0-1/git/t/chainlint/cuddled.test	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/chainlint/cuddled.test	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,23 @@
+# LINT: first subshell statement cuddled with opening "("; for implementation
+# LINT: simplicity, "(..." is split into two lines, "(" and "..."
+(cd foo &&
+	bar
+) &&
+
+# LINT: same with missing "&&"
+(cd foo
+	bar
+) &&
+
+# LINT: closing ")" cuddled with final subshell statement
+(
+	cd foo &&
+	bar) &&
+
+# LINT: "(" and ")" cuddled with first and final subshell statements
+(cd foo &&
+	bar) &&
+
+# LINT: same with missing "&&"
+(cd foo
+	bar)
diff -pruN 1.2.1+git2.18.0-1/git/t/chainlint/exit-loop.expect 1.2.3+git2.25.1-1/git/t/chainlint/exit-loop.expect
--- 1.2.1+git2.18.0-1/git/t/chainlint/exit-loop.expect	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/chainlint/exit-loop.expect	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,24 @@
+(
+	for i in a b c
+	do
+		foo || exit 1
+		bar &&
+		baz
+	done
+>) &&
+(
+	while true
+	do
+		foo || exit 1
+		bar &&
+		baz
+	done
+>) &&
+(
+	i=0 &&
+	while test $i -lt 10
+	do
+		echo $i || exit
+		i=$(($i + 1))
+	done
+>)
diff -pruN 1.2.1+git2.18.0-1/git/t/chainlint/exit-loop.test 1.2.3+git2.25.1-1/git/t/chainlint/exit-loop.test
--- 1.2.1+git2.18.0-1/git/t/chainlint/exit-loop.test	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/chainlint/exit-loop.test	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,27 @@
+(
+	for i in a b c
+	do
+# LINT: "|| exit {n}" valid for-loop escape in subshell; no "&&" needed
+		foo || exit 1
+		bar &&
+		baz
+	done
+) &&
+(
+	while true
+	do
+# LINT: "|| exit {n}" valid while-loop escape in subshell; no "&&" needed
+		foo || exit 1
+		bar &&
+		baz
+	done
+) &&
+(
+	i=0 &&
+	while test $i -lt 10
+	do
+# LINT: "|| exit" (sans exit code) valid escape in subshell; no "&&" needed
+		echo $i || exit
+		i=$(($i + 1))
+	done
+)
diff -pruN 1.2.1+git2.18.0-1/git/t/chainlint/exit-subshell.expect 1.2.3+git2.25.1-1/git/t/chainlint/exit-subshell.expect
--- 1.2.1+git2.18.0-1/git/t/chainlint/exit-subshell.expect	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/chainlint/exit-subshell.expect	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,5 @@
+(
+	foo || exit 1
+	bar &&
+	baz
+>)
diff -pruN 1.2.1+git2.18.0-1/git/t/chainlint/exit-subshell.test 1.2.3+git2.25.1-1/git/t/chainlint/exit-subshell.test
--- 1.2.1+git2.18.0-1/git/t/chainlint/exit-subshell.test	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/chainlint/exit-subshell.test	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,6 @@
+(
+# LINT: "|| exit {n}" valid subshell escape without hurting &&-chain
+	foo || exit 1
+	bar &&
+	baz
+)
diff -pruN 1.2.1+git2.18.0-1/git/t/chainlint/for-loop.expect 1.2.3+git2.25.1-1/git/t/chainlint/for-loop.expect
--- 1.2.1+git2.18.0-1/git/t/chainlint/for-loop.expect	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/chainlint/for-loop.expect	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,11 @@
+(
+	for i in a b c
+	do
+?!AMP?!		echo $i
+		cat
+?!AMP?!	done
+	for i in a b c; do
+		echo $i &&
+		cat $i
+	done
+>)
diff -pruN 1.2.1+git2.18.0-1/git/t/chainlint/for-loop.test 1.2.3+git2.25.1-1/git/t/chainlint/for-loop.test
--- 1.2.1+git2.18.0-1/git/t/chainlint/for-loop.test	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/chainlint/for-loop.test	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,19 @@
+(
+# LINT: 'for', 'do', 'done' do not need "&&"
+	for i in a b c
+	do
+# LINT: missing "&&" on 'echo'
+		echo $i
+# LINT: last statement of while does not need "&&"
+		cat <<-\EOF
+		bar
+		EOF
+# LINT: missing "&&" on 'done'
+	done
+
+# LINT: 'do' on same line as 'for'
+	for i in a b c; do
+		echo $i &&
+		cat $i
+	done
+)
diff -pruN 1.2.1+git2.18.0-1/git/t/chainlint/here-doc-close-subshell.expect 1.2.3+git2.25.1-1/git/t/chainlint/here-doc-close-subshell.expect
--- 1.2.1+git2.18.0-1/git/t/chainlint/here-doc-close-subshell.expect	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/chainlint/here-doc-close-subshell.expect	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,2 @@
+(
+>	cat)
diff -pruN 1.2.1+git2.18.0-1/git/t/chainlint/here-doc-close-subshell.test 1.2.3+git2.25.1-1/git/t/chainlint/here-doc-close-subshell.test
--- 1.2.1+git2.18.0-1/git/t/chainlint/here-doc-close-subshell.test	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/chainlint/here-doc-close-subshell.test	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,5 @@
+(
+# LINT: line contains here-doc and closes nested subshell
+	cat <<-\INPUT)
+	fizz
+	INPUT
diff -pruN 1.2.1+git2.18.0-1/git/t/chainlint/here-doc.expect 1.2.3+git2.25.1-1/git/t/chainlint/here-doc.expect
--- 1.2.1+git2.18.0-1/git/t/chainlint/here-doc.expect	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/chainlint/here-doc.expect	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,9 @@
+boodle wobba        gorgo snoot        wafta snurb &&
+
+cat >foo &&
+
+cat >bar &&
+
+cat >boo &&
+
+horticulture
diff -pruN 1.2.1+git2.18.0-1/git/t/chainlint/here-doc-multi-line-command-subst.expect 1.2.3+git2.25.1-1/git/t/chainlint/here-doc-multi-line-command-subst.expect
--- 1.2.1+git2.18.0-1/git/t/chainlint/here-doc-multi-line-command-subst.expect	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/chainlint/here-doc-multi-line-command-subst.expect	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,5 @@
+(
+	x=$(bobble &&
+?!AMP?!>>		wiffle)
+	echo $x
+>)
diff -pruN 1.2.1+git2.18.0-1/git/t/chainlint/here-doc-multi-line-command-subst.test 1.2.3+git2.25.1-1/git/t/chainlint/here-doc-multi-line-command-subst.test
--- 1.2.1+git2.18.0-1/git/t/chainlint/here-doc-multi-line-command-subst.test	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/chainlint/here-doc-multi-line-command-subst.test	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,9 @@
+(
+# LINT: line contains here-doc and opens multi-line $(...)
+	x=$(bobble <<-\END &&
+		fossil
+		vegetable
+		END
+		wiffle)
+	echo $x
+)
diff -pruN 1.2.1+git2.18.0-1/git/t/chainlint/here-doc-multi-line-string.expect 1.2.3+git2.25.1-1/git/t/chainlint/here-doc-multi-line-string.expect
--- 1.2.1+git2.18.0-1/git/t/chainlint/here-doc-multi-line-string.expect	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/chainlint/here-doc-multi-line-string.expect	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,4 @@
+(
+?!AMP?!	cat && echo "multi-line	string"
+	bap
+>)
diff -pruN 1.2.1+git2.18.0-1/git/t/chainlint/here-doc-multi-line-string.test 1.2.3+git2.25.1-1/git/t/chainlint/here-doc-multi-line-string.test
--- 1.2.1+git2.18.0-1/git/t/chainlint/here-doc-multi-line-string.test	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/chainlint/here-doc-multi-line-string.test	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,8 @@
+(
+# LINT: line contains here-doc and opens multi-line string
+	cat <<-\TXT && echo "multi-line
+	string"
+	fizzle
+	TXT
+	bap
+)
diff -pruN 1.2.1+git2.18.0-1/git/t/chainlint/here-doc.test 1.2.3+git2.25.1-1/git/t/chainlint/here-doc.test
--- 1.2.1+git2.18.0-1/git/t/chainlint/here-doc.test	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/chainlint/here-doc.test	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,37 @@
+# LINT: stitch together incomplete \-ending lines
+# LINT: swallow here-doc to avoid false positives in content
+boodle wobba \
+       gorgo snoot \
+       wafta snurb <<EOF &&
+quoth the raven,
+nevermore...
+EOF
+
+# LINT: swallow here-doc with arbitrary tag
+cat <<-Arbitrary_Tag_42 >foo &&
+snoz
+boz
+woz
+Arbitrary_Tag_42
+
+# LINT: swallow 'quoted' here-doc
+cat <<'FUMP' >bar &&
+snoz
+boz
+woz
+FUMP
+
+# LINT: swallow "quoted" here-doc
+cat <<"zump" >boo &&
+snoz
+boz
+woz
+zump
+
+# LINT: swallow here-doc (EOF is last line of test)
+horticulture <<\EOF
+gomez
+morticia
+wednesday
+pugsly
+EOF
diff -pruN 1.2.1+git2.18.0-1/git/t/chainlint/if-in-loop.expect 1.2.3+git2.25.1-1/git/t/chainlint/if-in-loop.expect
--- 1.2.1+git2.18.0-1/git/t/chainlint/if-in-loop.expect	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/chainlint/if-in-loop.expect	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,12 @@
+(
+	for i in a b c
+	do
+		if false
+		then
+?!AMP?!			echo "err"
+			exit 1
+?!AMP?!		fi
+		foo
+?!AMP?!	done
+	bar
+>)
diff -pruN 1.2.1+git2.18.0-1/git/t/chainlint/if-in-loop.test 1.2.3+git2.25.1-1/git/t/chainlint/if-in-loop.test
--- 1.2.1+git2.18.0-1/git/t/chainlint/if-in-loop.test	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/chainlint/if-in-loop.test	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,15 @@
+(
+	for i in a b c
+	do
+		if false
+		then
+# LINT: missing "&&" on 'echo'
+			echo "err"
+			exit 1
+# LINT: missing "&&" on 'fi'
+		fi
+		foo
+# LINT: missing "&&" on 'done'
+	done
+	bar
+)
diff -pruN 1.2.1+git2.18.0-1/git/t/chainlint/if-then-else.expect 1.2.3+git2.25.1-1/git/t/chainlint/if-then-else.expect
--- 1.2.1+git2.18.0-1/git/t/chainlint/if-then-else.expect	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/chainlint/if-then-else.expect	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,19 @@
+(
+	if test -n ""
+	then
+?!AMP?!		echo very
+		echo empty
+	elif test -z ""
+		echo foo
+	else
+		echo foo &&
+		cat
+?!AMP?!	fi
+	echo poodle
+>) &&
+(
+	if test -n ""; then
+		echo very &&
+?!AMP?!		echo empty
+	if
+>)
diff -pruN 1.2.1+git2.18.0-1/git/t/chainlint/if-then-else.test 1.2.3+git2.25.1-1/git/t/chainlint/if-then-else.test
--- 1.2.1+git2.18.0-1/git/t/chainlint/if-then-else.test	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/chainlint/if-then-else.test	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,28 @@
+(
+# LINT: 'if', 'then', 'elif', 'else', 'fi' do not need "&&"
+	if test -n ""
+	then
+# LINT: missing "&&" on 'echo'
+		echo very
+# LINT: last statement before 'elif' does not need "&&"
+		echo empty
+	elif test -z ""
+# LINT: last statement before 'else' does not need "&&"
+		echo foo
+	else
+		echo foo &&
+# LINT: last statement before 'fi' does not need "&&"
+		cat <<-\EOF
+		bar
+		EOF
+# LINT: missing "&&" on 'fi'
+	fi
+	echo poodle
+) &&
+(
+# LINT: 'then' on same line as 'if'
+	if test -n ""; then
+		echo very &&
+		echo empty
+	if
+)
diff -pruN 1.2.1+git2.18.0-1/git/t/chainlint/incomplete-line.expect 1.2.3+git2.25.1-1/git/t/chainlint/incomplete-line.expect
--- 1.2.1+git2.18.0-1/git/t/chainlint/incomplete-line.expect	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/chainlint/incomplete-line.expect	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,4 @@
+line 1 line 2 line 3 line 4 &&
+(
+	line 5 	line 6 	line 7 	line 8
+>)
diff -pruN 1.2.1+git2.18.0-1/git/t/chainlint/incomplete-line.test 1.2.3+git2.25.1-1/git/t/chainlint/incomplete-line.test
--- 1.2.1+git2.18.0-1/git/t/chainlint/incomplete-line.test	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/chainlint/incomplete-line.test	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,12 @@
+# LINT: stitch together all incomplete \-ending lines
+line 1 \
+line 2 \
+line 3 \
+line 4 &&
+(
+# LINT: stitch together all incomplete \-ending lines (subshell)
+	line 5 \
+	line 6 \
+	line 7 \
+	line 8
+)
diff -pruN 1.2.1+git2.18.0-1/git/t/chainlint/inline-comment.expect 1.2.3+git2.25.1-1/git/t/chainlint/inline-comment.expect
--- 1.2.1+git2.18.0-1/git/t/chainlint/inline-comment.expect	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/chainlint/inline-comment.expect	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,9 @@
+(
+	foobar &&
+?!AMP?!	barfoo
+	flibble "not a # comment"
+>) &&
+
+(
+cd foo &&
+>	flibble "not a # comment")
diff -pruN 1.2.1+git2.18.0-1/git/t/chainlint/inline-comment.test 1.2.3+git2.25.1-1/git/t/chainlint/inline-comment.test
--- 1.2.1+git2.18.0-1/git/t/chainlint/inline-comment.test	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/chainlint/inline-comment.test	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,12 @@
+(
+# LINT: swallow inline comment (leaving command intact)
+	foobar && # comment 1
+# LINT: mispositioned "&&" (correctly) swallowed with comment
+	barfoo # wrong position for &&
+# LINT: "#" in string not misinterpreted as comment
+	flibble "not a # comment"
+) &&
+
+# LINT: "#" in string in cuddled subshell not misinterpreted as comment
+(cd foo &&
+	flibble "not a # comment")
diff -pruN 1.2.1+git2.18.0-1/git/t/chainlint/loop-in-if.expect 1.2.3+git2.25.1-1/git/t/chainlint/loop-in-if.expect
--- 1.2.1+git2.18.0-1/git/t/chainlint/loop-in-if.expect	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/chainlint/loop-in-if.expect	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,12 @@
+(
+	if true
+	then
+		while true
+		do
+?!AMP?!			echo "pop"
+			echo "glup"
+?!AMP?!		done
+		foo
+?!AMP?!	fi
+	bar
+>)
diff -pruN 1.2.1+git2.18.0-1/git/t/chainlint/loop-in-if.test 1.2.3+git2.25.1-1/git/t/chainlint/loop-in-if.test
--- 1.2.1+git2.18.0-1/git/t/chainlint/loop-in-if.test	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/chainlint/loop-in-if.test	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,15 @@
+(
+	if true
+	then
+		while true
+		do
+# LINT: missing "&&" on 'echo'
+			echo "pop"
+			echo "glup"
+# LINT: missing "&&" on 'done'
+		done
+		foo
+# LINT: missing "&&" on 'fi'
+	fi
+	bar
+)
diff -pruN 1.2.1+git2.18.0-1/git/t/chainlint/multi-line-nested-command-substitution.expect 1.2.3+git2.25.1-1/git/t/chainlint/multi-line-nested-command-substitution.expect
--- 1.2.1+git2.18.0-1/git/t/chainlint/multi-line-nested-command-substitution.expect	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/chainlint/multi-line-nested-command-substitution.expect	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,18 @@
+(
+	foo &&
+	x=$(
+		echo bar |
+		cat
+>>	) &&
+	echo ok
+>) |
+sort &&
+(
+	bar &&
+	x=$(echo bar |
+		cat
+>>	) &&
+	y=$(echo baz |
+>>		fip) &&
+	echo fail
+>)
diff -pruN 1.2.1+git2.18.0-1/git/t/chainlint/multi-line-nested-command-substitution.test 1.2.3+git2.25.1-1/git/t/chainlint/multi-line-nested-command-substitution.test
--- 1.2.1+git2.18.0-1/git/t/chainlint/multi-line-nested-command-substitution.test	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/chainlint/multi-line-nested-command-substitution.test	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,18 @@
+(
+	foo &&
+	x=$(
+		echo bar |
+		cat
+	) &&
+	echo ok
+) |
+sort &&
+(
+	bar &&
+	x=$(echo bar |
+		cat
+	) &&
+	y=$(echo baz |
+		fip) &&
+	echo fail
+)
diff -pruN 1.2.1+git2.18.0-1/git/t/chainlint/multi-line-string.expect 1.2.3+git2.25.1-1/git/t/chainlint/multi-line-string.expect
--- 1.2.1+git2.18.0-1/git/t/chainlint/multi-line-string.expect	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/chainlint/multi-line-string.expect	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,15 @@
+(
+	x="line 1		line 2		line 3" &&
+?!AMP?!	y='line 1		line2'
+	foobar
+>) &&
+(
+	echo "there's nothing to see here" &&
+	exit
+>) &&
+(
+	echo "xyz" "abc		def		ghi" &&
+	echo 'xyz' 'abc		def		ghi' &&
+	echo 'xyz' "abc		def		ghi" &&
+	barfoo
+>)
diff -pruN 1.2.1+git2.18.0-1/git/t/chainlint/multi-line-string.test 1.2.3+git2.25.1-1/git/t/chainlint/multi-line-string.test
--- 1.2.1+git2.18.0-1/git/t/chainlint/multi-line-string.test	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/chainlint/multi-line-string.test	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,27 @@
+(
+	x="line 1
+		line 2
+		line 3" &&
+# LINT: missing "&&" on assignment
+	y='line 1
+		line2'
+	foobar
+) &&
+(
+# LINT: apostrophe (in a contraction) within string not misinterpreted as
+# LINT: starting multi-line single-quoted string
+	echo "there's nothing to see here" &&
+	exit
+) &&
+(
+	echo "xyz" "abc
+		def
+		ghi" &&
+	echo 'xyz' 'abc
+		def
+		ghi' &&
+	echo 'xyz' "abc
+		def
+		ghi" &&
+	barfoo
+)
diff -pruN 1.2.1+git2.18.0-1/git/t/chainlint/negated-one-liner.expect 1.2.3+git2.25.1-1/git/t/chainlint/negated-one-liner.expect
--- 1.2.1+git2.18.0-1/git/t/chainlint/negated-one-liner.expect	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/chainlint/negated-one-liner.expect	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,5 @@
+! (foo && bar) &&
+! (foo && bar) >baz &&
+
+?!SEMI?!! (foo; bar) &&
+?!SEMI?!! (foo; bar) >baz
diff -pruN 1.2.1+git2.18.0-1/git/t/chainlint/negated-one-liner.test 1.2.3+git2.25.1-1/git/t/chainlint/negated-one-liner.test
--- 1.2.1+git2.18.0-1/git/t/chainlint/negated-one-liner.test	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/chainlint/negated-one-liner.test	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,7 @@
+# LINT: top-level one-liner subshell
+! (foo && bar) &&
+! (foo && bar) >baz &&
+
+# LINT: top-level one-liner subshell missing internal "&&"
+! (foo; bar) &&
+! (foo; bar) >baz
diff -pruN 1.2.1+git2.18.0-1/git/t/chainlint/nested-cuddled-subshell.expect 1.2.3+git2.25.1-1/git/t/chainlint/nested-cuddled-subshell.expect
--- 1.2.1+git2.18.0-1/git/t/chainlint/nested-cuddled-subshell.expect	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/chainlint/nested-cuddled-subshell.expect	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,19 @@
+(
+	(cd foo &&
+		bar
+>>	) &&
+	(cd foo &&
+		bar
+?!AMP?!>>	)
+	(
+		cd foo &&
+>>		bar) &&
+	(
+		cd foo &&
+?!AMP?!>>		bar)
+	(cd foo &&
+>>		bar) &&
+	(cd foo &&
+?!AMP?!>>		bar)
+	foobar
+>)
diff -pruN 1.2.1+git2.18.0-1/git/t/chainlint/nested-cuddled-subshell.test 1.2.3+git2.25.1-1/git/t/chainlint/nested-cuddled-subshell.test
--- 1.2.1+git2.18.0-1/git/t/chainlint/nested-cuddled-subshell.test	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/chainlint/nested-cuddled-subshell.test	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,31 @@
+(
+# LINT: opening "(" cuddled with first nested subshell statement
+	(cd foo &&
+		bar
+	) &&
+
+# LINT: same but "&&" missing
+	(cd foo &&
+		bar
+	)
+
+# LINT: closing ")" cuddled with final nested subshell statement
+	(
+		cd foo &&
+		bar) &&
+
+# LINT: same but "&&" missing
+	(
+		cd foo &&
+		bar)
+
+# LINT: "(" and ")" cuddled with first and final subshell statements
+	(cd foo &&
+		bar) &&
+
+# LINT: same but "&&" missing
+	(cd foo &&
+		bar)
+
+	foobar
+)
diff -pruN 1.2.1+git2.18.0-1/git/t/chainlint/nested-here-doc.expect 1.2.3+git2.25.1-1/git/t/chainlint/nested-here-doc.expect
--- 1.2.1+git2.18.0-1/git/t/chainlint/nested-here-doc.expect	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/chainlint/nested-here-doc.expect	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,7 @@
+cat >foop &&
+
+(
+	cat &&
+?!AMP?!	cat
+	foobar
+>)
diff -pruN 1.2.1+git2.18.0-1/git/t/chainlint/nested-here-doc.test 1.2.3+git2.25.1-1/git/t/chainlint/nested-here-doc.test
--- 1.2.1+git2.18.0-1/git/t/chainlint/nested-here-doc.test	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/chainlint/nested-here-doc.test	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,33 @@
+# LINT: inner "EOF" not misintrepreted as closing ARBITRARY here-doc
+cat <<ARBITRARY >foop &&
+naddle
+fub <<EOF
+	nozzle
+	noodle
+EOF
+formp
+ARBITRARY
+
+(
+# LINT: inner "EOF" not misintrepreted as closing INPUT_END here-doc
+	cat <<-\INPUT_END &&
+	fish are mice
+	but geese go slow
+	data <<EOF
+		perl is lerp
+		and nothing else
+	EOF
+	toink
+	INPUT_END
+
+# LINT: same but missing "&&"
+	cat <<-\EOT
+	text goes here
+	data <<EOF
+		data goes here
+	EOF
+	more test here
+	EOT
+
+	foobar
+)
diff -pruN 1.2.1+git2.18.0-1/git/t/chainlint/nested-subshell-comment.expect 1.2.3+git2.25.1-1/git/t/chainlint/nested-subshell-comment.expect
--- 1.2.1+git2.18.0-1/git/t/chainlint/nested-subshell-comment.expect	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/chainlint/nested-subshell-comment.expect	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,11 @@
+(
+	foo &&
+	(
+		bar &&
+		# bottles wobble while fiddles gobble
+		# minor numbers of cows (or do they?)
+		baz &&
+		snaff
+?!AMP?!>>	)
+	fuzzy
+>)
diff -pruN 1.2.1+git2.18.0-1/git/t/chainlint/nested-subshell-comment.test 1.2.3+git2.25.1-1/git/t/chainlint/nested-subshell-comment.test
--- 1.2.1+git2.18.0-1/git/t/chainlint/nested-subshell-comment.test	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/chainlint/nested-subshell-comment.test	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,13 @@
+(
+	foo &&
+	(
+		bar &&
+# LINT: ")" in comment in nested subshell not misinterpreted as closing ")"
+		# bottles wobble while fiddles gobble
+		# minor numbers of cows (or do they?)
+		baz &&
+		snaff
+# LINT: missing "&&" on ')'
+	)
+	fuzzy
+)
diff -pruN 1.2.1+git2.18.0-1/git/t/chainlint/nested-subshell.expect 1.2.3+git2.25.1-1/git/t/chainlint/nested-subshell.expect
--- 1.2.1+git2.18.0-1/git/t/chainlint/nested-subshell.expect	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/chainlint/nested-subshell.expect	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,12 @@
+(
+	cd foo &&
+	(
+		echo a &&
+		echo b
+>>	) >file &&
+	cd foo &&
+	(
+		echo a
+		echo b
+>>	) >file
+>)
diff -pruN 1.2.1+git2.18.0-1/git/t/chainlint/nested-subshell.test 1.2.3+git2.25.1-1/git/t/chainlint/nested-subshell.test
--- 1.2.1+git2.18.0-1/git/t/chainlint/nested-subshell.test	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/chainlint/nested-subshell.test	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,14 @@
+(
+	cd foo &&
+	(
+		echo a &&
+		echo b
+	) >file &&
+
+	cd foo &&
+	(
+# LINT: nested multi-line subshell not presently checked for missing "&&"
+		echo a
+		echo b
+	) >file
+)
diff -pruN 1.2.1+git2.18.0-1/git/t/chainlint/one-liner.expect 1.2.3+git2.25.1-1/git/t/chainlint/one-liner.expect
--- 1.2.1+git2.18.0-1/git/t/chainlint/one-liner.expect	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/chainlint/one-liner.expect	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,9 @@
+(foo && bar) &&
+(foo && bar) |
+(foo && bar) >baz &&
+
+?!SEMI?!(foo; bar) &&
+?!SEMI?!(foo; bar) |
+?!SEMI?!(foo; bar) >baz
+
+(foo "bar; baz")
diff -pruN 1.2.1+git2.18.0-1/git/t/chainlint/one-liner.test 1.2.3+git2.25.1-1/git/t/chainlint/one-liner.test
--- 1.2.1+git2.18.0-1/git/t/chainlint/one-liner.test	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/chainlint/one-liner.test	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,12 @@
+# LINT: top-level one-liner subshell
+(foo && bar) &&
+(foo && bar) |
+(foo && bar) >baz &&
+
+# LINT: top-level one-liner subshell missing internal "&&"
+(foo; bar) &&
+(foo; bar) |
+(foo; bar) >baz
+
+# LINT: ";" in string not misinterpreted as broken &&-chain
+(foo "bar; baz")
diff -pruN 1.2.1+git2.18.0-1/git/t/chainlint/p4-filespec.expect 1.2.3+git2.25.1-1/git/t/chainlint/p4-filespec.expect
--- 1.2.1+git2.18.0-1/git/t/chainlint/p4-filespec.expect	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/chainlint/p4-filespec.expect	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,4 @@
+(
+	p4 print -1 //depot/fiddle#42 >file &&
+	foobar
+>)
diff -pruN 1.2.1+git2.18.0-1/git/t/chainlint/p4-filespec.test 1.2.3+git2.25.1-1/git/t/chainlint/p4-filespec.test
--- 1.2.1+git2.18.0-1/git/t/chainlint/p4-filespec.test	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/chainlint/p4-filespec.test	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,5 @@
+(
+# LINT: Perforce revspec in filespec not misinterpreted as in-line comment
+	p4 print -1 //depot/fiddle#42 >file &&
+	foobar
+)
diff -pruN 1.2.1+git2.18.0-1/git/t/chainlint/pipe.expect 1.2.3+git2.25.1-1/git/t/chainlint/pipe.expect
--- 1.2.1+git2.18.0-1/git/t/chainlint/pipe.expect	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/chainlint/pipe.expect	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,8 @@
+(
+	foo |
+	bar |
+	baz &&
+	fish |
+?!AMP?!	cow
+	sunder
+>)
diff -pruN 1.2.1+git2.18.0-1/git/t/chainlint/pipe.test 1.2.3+git2.25.1-1/git/t/chainlint/pipe.test
--- 1.2.1+git2.18.0-1/git/t/chainlint/pipe.test	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/chainlint/pipe.test	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,12 @@
+(
+# LINT: no "&&" needed on line ending with "|"
+	foo |
+	bar |
+	baz &&
+
+# LINT: final line of pipe sequence ('cow') lacking "&&"
+	fish |
+	cow
+
+	sunder
+)
diff -pruN 1.2.1+git2.18.0-1/git/t/chainlint/semicolon.expect 1.2.3+git2.25.1-1/git/t/chainlint/semicolon.expect
--- 1.2.1+git2.18.0-1/git/t/chainlint/semicolon.expect	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/chainlint/semicolon.expect	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,20 @@
+(
+?!AMP?!?!SEMI?!	cat foo ; echo bar
+?!SEMI?!	cat foo ; echo bar
+>) &&
+(
+?!SEMI?!	cat foo ; echo bar &&
+?!SEMI?!	cat foo ; echo bar
+>) &&
+(
+	echo "foo; bar" &&
+?!SEMI?!	cat foo; echo bar
+>) &&
+(
+?!SEMI?!	foo;
+>) &&
+(
+cd foo &&
+	for i in a b c; do
+?!SEMI?!		echo;
+>	done)
diff -pruN 1.2.1+git2.18.0-1/git/t/chainlint/semicolon.test 1.2.3+git2.25.1-1/git/t/chainlint/semicolon.test
--- 1.2.1+git2.18.0-1/git/t/chainlint/semicolon.test	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/chainlint/semicolon.test	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,25 @@
+(
+# LINT: missing internal "&&" and ending "&&"
+	cat foo ; echo bar
+# LINT: final statement before ")" only missing internal "&&"
+	cat foo ; echo bar
+) &&
+(
+# LINT: missing internal "&&"
+	cat foo ; echo bar &&
+	cat foo ; echo bar
+) &&
+(
+# LINT: not fooled by semicolon in string
+	echo "foo; bar" &&
+	cat foo; echo bar
+) &&
+(
+# LINT: unnecessary terminating semicolon
+	foo;
+) &&
+(cd foo &&
+	for i in a b c; do
+# LINT: unnecessary terminating semicolon
+		echo;
+	done)
diff -pruN 1.2.1+git2.18.0-1/git/t/chainlint/subshell-here-doc.expect 1.2.3+git2.25.1-1/git/t/chainlint/subshell-here-doc.expect
--- 1.2.1+git2.18.0-1/git/t/chainlint/subshell-here-doc.expect	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/chainlint/subshell-here-doc.expect	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,11 @@
+(
+	echo wobba 	       gorgo snoot 	       wafta snurb &&
+?!AMP?!	cat >bip
+	echo >bop
+>) &&
+(
+	cat >bup &&
+	cat >bup2 &&
+	cat >bup3 &&
+	meep
+>)
diff -pruN 1.2.1+git2.18.0-1/git/t/chainlint/subshell-here-doc.test 1.2.3+git2.25.1-1/git/t/chainlint/subshell-here-doc.test
--- 1.2.1+git2.18.0-1/git/t/chainlint/subshell-here-doc.test	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/chainlint/subshell-here-doc.test	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,39 @@
+(
+# LINT: stitch together incomplete \-ending lines
+# LINT: swallow here-doc to avoid false positives in content
+	echo wobba \
+	       gorgo snoot \
+	       wafta snurb <<-EOF &&
+	quoth the raven,
+	nevermore...
+	EOF
+
+# LINT: missing "&&" on 'cat'
+	cat <<EOF >bip
+	fish fly high
+	EOF
+
+# LINT: swallow here-doc (EOF is last line of subshell)
+	echo <<-\EOF >bop
+	gomez
+	morticia
+	wednesday
+	pugsly
+	EOF
+) &&
+(
+# LINT: swallow here-doc with arbitrary tag
+	cat <<-\ARBITRARY >bup &&
+	glink
+	FIZZ
+	ARBITRARY
+	cat <<-'ARBITRARY2' >bup2 &&
+	glink
+	FIZZ
+	ARBITRARY2
+	cat <<-"ARBITRARY3" >bup3 &&
+	glink
+	FIZZ
+	ARBITRARY3
+	meep
+)
diff -pruN 1.2.1+git2.18.0-1/git/t/chainlint/subshell-one-liner.expect 1.2.3+git2.25.1-1/git/t/chainlint/subshell-one-liner.expect
--- 1.2.1+git2.18.0-1/git/t/chainlint/subshell-one-liner.expect	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/chainlint/subshell-one-liner.expect	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,14 @@
+(
+	(foo && bar) &&
+	(foo && bar) |
+	(foo && bar) >baz &&
+?!SEMI?!	(foo; bar) &&
+?!SEMI?!	(foo; bar) |
+?!SEMI?!	(foo; bar) >baz &&
+	(foo || exit 1) &&
+	(foo || exit 1) |
+	(foo || exit 1) >baz &&
+?!AMP?!	(foo && bar)
+?!AMP?!?!SEMI?!	(foo && bar; baz)
+	foobar
+>)
diff -pruN 1.2.1+git2.18.0-1/git/t/chainlint/subshell-one-liner.test 1.2.3+git2.25.1-1/git/t/chainlint/subshell-one-liner.test
--- 1.2.1+git2.18.0-1/git/t/chainlint/subshell-one-liner.test	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/chainlint/subshell-one-liner.test	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,24 @@
+(
+# LINT: nested one-liner subshell
+	(foo && bar) &&
+	(foo && bar) |
+	(foo && bar) >baz &&
+
+# LINT: nested one-liner subshell missing internal "&&"
+	(foo; bar) &&
+	(foo; bar) |
+	(foo; bar) >baz &&
+
+# LINT: nested one-liner subshell with "|| exit"
+	(foo || exit 1) &&
+	(foo || exit 1) |
+	(foo || exit 1) >baz &&
+
+# LINT: nested one-liner subshell lacking ending "&&"
+	(foo && bar)
+
+# LINT: nested one-liner subshell missing internal "&&" and lacking ending "&&"
+	(foo && bar; baz)
+
+	foobar
+)
diff -pruN 1.2.1+git2.18.0-1/git/t/chainlint/t7900-subtree.expect 1.2.3+git2.25.1-1/git/t/chainlint/t7900-subtree.expect
--- 1.2.1+git2.18.0-1/git/t/chainlint/t7900-subtree.expect	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/chainlint/t7900-subtree.expect	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,10 @@
+(
+	chks="sub1sub2sub3sub4" &&
+	chks_sub=$(cat | sed 's,^,sub dir/,'
+>>) &&
+	chkms="main-sub1main-sub2main-sub3main-sub4" &&
+	chkms_sub=$(cat | sed 's,^,sub dir/,'
+>>) &&
+	subfiles=$(git ls-files) &&
+	check_equal "$subfiles" "$chkms$chks"
+>)
diff -pruN 1.2.1+git2.18.0-1/git/t/chainlint/t7900-subtree.test 1.2.3+git2.25.1-1/git/t/chainlint/t7900-subtree.test
--- 1.2.1+git2.18.0-1/git/t/chainlint/t7900-subtree.test	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/chainlint/t7900-subtree.test	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,22 @@
+(
+	chks="sub1
+sub2
+sub3
+sub4" &&
+	chks_sub=$(cat <<TXT | sed 's,^,sub dir/,'
+$chks
+TXT
+) &&
+	chkms="main-sub1
+main-sub2
+main-sub3
+main-sub4" &&
+	chkms_sub=$(cat <<TXT | sed 's,^,sub dir/,'
+$chkms
+TXT
+) &&
+
+	subfiles=$(git ls-files) &&
+	check_equal "$subfiles" "$chkms
+$chks"
+)
diff -pruN 1.2.1+git2.18.0-1/git/t/chainlint/while-loop.expect 1.2.3+git2.25.1-1/git/t/chainlint/while-loop.expect
--- 1.2.1+git2.18.0-1/git/t/chainlint/while-loop.expect	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/chainlint/while-loop.expect	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,11 @@
+(
+	while true
+	do
+?!AMP?!		echo foo
+		cat
+?!AMP?!	done
+	while true; do
+		echo foo &&
+		cat bar
+	done
+>)
diff -pruN 1.2.1+git2.18.0-1/git/t/chainlint/while-loop.test 1.2.3+git2.25.1-1/git/t/chainlint/while-loop.test
--- 1.2.1+git2.18.0-1/git/t/chainlint/while-loop.test	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/chainlint/while-loop.test	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,19 @@
+(
+# LINT: 'while, 'do', 'done' do not need "&&"
+	while true
+	do
+# LINT: missing "&&" on 'echo'
+		echo foo
+# LINT: last statement of while does not need "&&"
+		cat <<-\EOF
+		bar
+		EOF
+# LINT: missing "&&" on 'done'
+	done
+
+# LINT: 'do' on same line as 'while'
+	while true; do
+		echo foo &&
+		cat bar
+	done
+)
diff -pruN 1.2.1+git2.18.0-1/git/t/chainlint.sed 1.2.3+git2.25.1-1/git/t/chainlint.sed
--- 1.2.1+git2.18.0-1/git/t/chainlint.sed	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/chainlint.sed	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,369 @@
+#------------------------------------------------------------------------------
+# Detect broken &&-chains in tests.
+#
+# At present, only &&-chains in subshells are examined by this linter;
+# top-level &&-chains are instead checked directly by the test framework. Like
+# the top-level &&-chain linter, the subshell linter (intentionally) does not
+# check &&-chains within {...} blocks.
+#
+# Checking for &&-chain breakage is done line-by-line by pure textual
+# inspection.
+#
+# Incomplete lines (those ending with "\") are stitched together with following
+# lines to simplify processing, particularly of "one-liner" statements.
+# Top-level here-docs are swallowed to avoid false positives within the
+# here-doc body, although the statement to which the here-doc is attached is
+# retained.
+#
+# Heuristics are used to detect end-of-subshell when the closing ")" is cuddled
+# with the final subshell statement on the same line:
+#
+#    (cd foo &&
+#        bar)
+#
+# in order to avoid misinterpreting the ")" in constructs such as "x=$(...)"
+# and "case $x in *)" as ending the subshell.
+#
+# Lines missing a final "&&" are flagged with "?!AMP?!", and lines which chain
+# commands with ";" internally rather than "&&" are flagged "?!SEMI?!". A line
+# may be flagged for both violations.
+#
+# Detection of a missing &&-link in a multi-line subshell is complicated by the
+# fact that the last statement before the closing ")" must not end with "&&".
+# Since processing is line-by-line, it is not known whether a missing "&&" is
+# legitimate or not until the _next_ line is seen. To accommodate this, within
+# multi-line subshells, each line is stored in sed's "hold" area until after
+# the next line is seen and processed. If the next line is a stand-alone ")",
+# then a missing "&&" on the previous line is legitimate; otherwise a missing
+# "&&" is a break in the &&-chain.
+#
+#    (
+#         cd foo &&
+#         bar
+#    )
+#
+# In practical terms, when "bar" is encountered, it is flagged with "?!AMP?!",
+# but when the stand-alone ")" line is seen which closes the subshell, the
+# "?!AMP?!" violation is removed from the "bar" line (retrieved from the "hold"
+# area) since the final statement of a subshell must not end with "&&". The
+# final line of a subshell may still break the &&-chain by using ";" internally
+# to chain commands together rather than "&&", so "?!SEMI?!" is never removed
+# from a line (even though "?!AMP?!" might be).
+#
+# Care is taken to recognize the last _statement_ of a multi-line subshell, not
+# necessarily the last textual _line_ within the subshell, since &&-chaining
+# applies to statements, not to lines. Consequently, blank lines, comment
+# lines, and here-docs are swallowed (but not the command to which the here-doc
+# is attached), leaving the last statement in the "hold" area, not the last
+# line, thus simplifying &&-link checking.
+#
+# The final statement before "done" in for- and while-loops, and before "elif",
+# "else", and "fi" in if-then-else likewise must not end with "&&", thus
+# receives similar treatment.
+#
+# Swallowing here-docs with arbitrary tags requires a bit of finesse. When a
+# line such as "cat <<EOF >out" is seen, the here-doc tag is moved to the front
+# of the line enclosed in angle brackets as a sentinel, giving "<EOF>cat >out".
+# As each subsequent line is read, it is appended to the target line and a
+# (whitespace-loose) back-reference match /^<(.*)>\n\1$/ is attempted to see if
+# the content inside "<...>" matches the entirety of the newly-read line. For
+# instance, if the next line read is "some data", when concatenated with the
+# target line, it becomes "<EOF>cat >out\nsome data", and a match is attempted
+# to see if "EOF" matches "some data". Since it doesn't, the next line is
+# attempted. When a line consisting of only "EOF" (and possible whitespace) is
+# encountered, it is appended to the target line giving "<EOF>cat >out\nEOF",
+# in which case the "EOF" inside "<...>" does match the text following the
+# newline, thus the closing here-doc tag has been found. The closing tag line
+# and the "<...>" prefix on the target line are then discarded, leaving just
+# the target line "cat >out".
+#
+# To facilitate regression testing (and manual debugging), a ">" annotation is
+# applied to the line containing ")" which closes a subshell, ">>" to a line
+# closing a nested subshell, and ">>>" to a line closing both at once. This
+# makes it easy to detect whether the heuristics correctly identify
+# end-of-subshell.
+#------------------------------------------------------------------------------
+
+# incomplete line -- slurp up next line
+:squash
+/\\$/ {
+	N
+	s/\\\n//
+	bsquash
+}
+
+# here-doc -- swallow it to avoid false hits within its body (but keep the
+# command to which it was attached)
+/<<[ 	]*[-\\'"]*[A-Za-z0-9_]/ {
+	s/^\(.*\)<<[ 	]*[-\\'"]*\([A-Za-z0-9_][A-Za-z0-9_]*\)['"]*/<\2>\1<</
+	s/[ 	]*<<//
+	:hered
+	N
+	/^<\([^>]*\)>.*\n[ 	]*\1[ 	]*$/!{
+		s/\n.*$//
+		bhered
+	}
+	s/^<[^>]*>//
+	s/\n.*$//
+}
+
+# one-liner "(...) &&"
+/^[ 	]*!*[ 	]*(..*)[ 	]*&&[ 	]*$/boneline
+
+# same as above but without trailing "&&"
+/^[ 	]*!*[ 	]*(..*)[ 	]*$/boneline
+
+# one-liner "(...) >x" (or "2>x" or "<x" or "|x" or "&"
+/^[ 	]*!*[ 	]*(..*)[ 	]*[0-9]*[<>|&]/boneline
+
+# multi-line "(...\n...)"
+/^[ 	]*(/bsubshell
+
+# innocuous line -- print it and advance to next line
+b
+
+# found one-liner "(...)" -- mark suspect if it uses ";" internally rather than
+# "&&" (but not ";" in a string)
+:oneline
+/;/{
+	/"[^"]*;[^"]*"/!s/^/?!SEMI?!/
+}
+b
+
+:subshell
+# bare "(" line? -- stash for later printing
+/^[ 	]*([	]*$/ {
+	h
+	bnextline
+}
+# "(..." line -- split off and stash "(", then process "..." as its own line
+x
+s/.*/(/
+x
+s/(//
+bslurp
+
+:nextline
+N
+s/.*\n//
+
+:slurp
+# incomplete line "...\"
+/\\$/bicmplte
+# multi-line quoted string "...\n..."?
+/"/bdqstring
+# multi-line quoted string '...\n...'? (but not contraction in string "it's")
+/'/{
+	/"[^'"]*'[^'"]*"/!bsqstring
+}
+:folded
+# here-doc -- swallow it
+/<<[ 	]*[-\\'"]*[A-Za-z0-9_]/bheredoc
+# comment or empty line -- discard since final non-comment, non-empty line
+# before closing ")", "done", "elsif", "else", or "fi" will need to be
+# re-visited to drop "suspect" marking since final line of those constructs
+# legitimately lacks "&&", so "suspect" mark must be removed
+/^[ 	]*#/bnextline
+/^[ 	]*$/bnextline
+# in-line comment -- strip it (but not "#" in a string, Bash ${#...} array
+# length, or Perforce "//depot/path#42" revision in filespec)
+/[ 	]#/{
+	/"[^"]*#[^"]*"/!s/[ 	]#.*$//
+}
+# one-liner "case ... esac"
+/^[ 	]*case[ 	]*..*esac/bchkchn
+# multi-line "case ... esac"
+/^[ 	]*case[ 	]..*[ 	]in/bcase
+# multi-line "for ... done" or "while ... done"
+/^[ 	]*for[ 	]..*[ 	]in/bcontinue
+/^[ 	]*while[ 	]/bcontinue
+/^[ 	]*do[ 	]/bcontinue
+/^[ 	]*do[ 	]*$/bcontinue
+/;[ 	]*do/bcontinue
+/^[ 	]*done[ 	]*&&[ 	]*$/bdone
+/^[ 	]*done[ 	]*$/bdone
+/^[ 	]*done[ 	]*[<>|]/bdone
+/^[ 	]*done[ 	]*)/bdone
+/||[ 	]*exit[ 	]/bcontinue
+/||[ 	]*exit[ 	]*$/bcontinue
+# multi-line "if...elsif...else...fi"
+/^[ 	]*if[ 	]/bcontinue
+/^[ 	]*then[ 	]/bcontinue
+/^[ 	]*then[ 	]*$/bcontinue
+/;[ 	]*then/bcontinue
+/^[ 	]*elif[ 	]/belse
+/^[ 	]*elif[ 	]*$/belse
+/^[ 	]*else[ 	]/belse
+/^[ 	]*else[ 	]*$/belse
+/^[ 	]*fi[ 	]*&&[ 	]*$/bdone
+/^[ 	]*fi[ 	]*$/bdone
+/^[ 	]*fi[ 	]*[<>|]/bdone
+/^[ 	]*fi[ 	]*)/bdone
+# nested one-liner "(...) &&"
+/^[ 	]*(.*)[ 	]*&&[ 	]*$/bchkchn
+# nested one-liner "(...)"
+/^[ 	]*(.*)[ 	]*$/bchkchn
+# nested one-liner "(...) >x" (or "2>x" or "<x" or "|x")
+/^[ 	]*(.*)[ 	]*[0-9]*[<>|]/bchkchn
+# nested multi-line "(...\n...)"
+/^[ 	]*(/bnest
+# multi-line "{...\n...}"
+/^[ 	]*{/bblock
+# closing ")" on own line -- exit subshell
+/^[ 	]*)/bclssolo
+# "$((...))" -- arithmetic expansion; not closing ")"
+/\$(([^)][^)]*))[^)]*$/bchkchn
+# "$(...)" -- command substitution; not closing ")"
+/\$([^)][^)]*)[^)]*$/bchkchn
+# multi-line "$(...\n...)" -- command substitution; treat as nested subshell
+/\$([^)]*$/bnest
+# "=(...)" -- Bash array assignment; not closing ")"
+/=(/bchkchn
+# closing "...) &&"
+/)[ 	]*&&[ 	]*$/bclose
+# closing "...)"
+/)[ 	]*$/bclose
+# closing "...) >x" (or "2>x" or "<x" or "|x")
+/)[ 	]*[<>|]/bclose
+:chkchn
+# mark suspect if line uses ";" internally rather than "&&" (but not ";" in a
+# string and not ";;" in one-liner "case...esac")
+/;/{
+	/;;/!{
+		/"[^"]*;[^"]*"/!s/^/?!SEMI?!/
+	}
+}
+# line ends with pipe "...|" -- valid; not missing "&&"
+/|[ 	]*$/bcontinue
+# missing end-of-line "&&" -- mark suspect
+/&&[ 	]*$/!s/^/?!AMP?!/
+:continue
+# retrieve and print previous line
+x
+n
+bslurp
+
+# found incomplete line "...\" -- slurp up next line
+:icmplte
+N
+s/\\\n//
+bslurp
+
+# check for multi-line double-quoted string "...\n..." -- fold to one line
+:dqstring
+# remove all quote pairs
+s/"\([^"]*\)"/@!\1@!/g
+# done if no dangling quote
+/"/!bdqdone
+# otherwise, slurp next line and try again
+N
+s/\n//
+bdqstring
+:dqdone
+s/@!/"/g
+bfolded
+
+# check for multi-line single-quoted string '...\n...' -- fold to one line
+:sqstring
+# remove all quote pairs
+s/'\([^']*\)'/@!\1@!/g
+# done if no dangling quote
+/'/!bsqdone
+# otherwise, slurp next line and try again
+N
+s/\n//
+bsqstring
+:sqdone
+s/@!/'/g
+bfolded
+
+# found here-doc -- swallow it to avoid false hits within its body (but keep
+# the command to which it was attached)
+:heredoc
+s/^\(.*\)<<[ 	]*[-\\'"]*\([A-Za-z0-9_][A-Za-z0-9_]*\)['"]*/<\2>\1<</
+s/[ 	]*<<//
+:heredsub
+N
+/^<\([^>]*\)>.*\n[ 	]*\1[ 	]*$/!{
+	s/\n.*$//
+	bheredsub
+}
+s/^<[^>]*>//
+s/\n.*$//
+bfolded
+
+# found "case ... in" -- pass through untouched
+:case
+x
+n
+/^[ 	]*esac/bslurp
+bcase
+
+# found "else" or "elif" -- drop "suspect" from final line before "else" since
+# that line legitimately lacks "&&"
+:else
+x
+s/?!AMP?!//
+x
+bcontinue
+
+# found "done" closing for-loop or while-loop, or "fi" closing if-then -- drop
+# "suspect" from final contained line since that line legitimately lacks "&&"
+:done
+x
+s/?!AMP?!//
+x
+# is 'done' or 'fi' cuddled with ")" to close subshell?
+/done.*)/bclose
+/fi.*)/bclose
+bchkchn
+
+# found nested multi-line "(...\n...)" -- pass through untouched
+:nest
+x
+:nstslurp
+n
+# closing ")" on own line -- stop nested slurp
+/^[ 	]*)/bnstclose
+# comment -- not closing ")" if in comment
+/^[ 	]*#/bnstcnt
+# "$((...))" -- arithmetic expansion; not closing ")"
+/\$(([^)][^)]*))[^)]*$/bnstcnt
+# "$(...)" -- command substitution; not closing ")"
+/\$([^)][^)]*)[^)]*$/bnstcnt
+# closing "...)" -- stop nested slurp
+/)/bnstclose
+:nstcnt
+x
+bnstslurp
+:nstclose
+s/^/>>/
+# is it "))" which closes nested and parent subshells?
+/)[ 	]*)/bslurp
+bchkchn
+
+# found multi-line "{...\n...}" block -- pass through untouched
+:block
+x
+n
+# closing "}" -- stop block slurp
+/}/bchkchn
+bblock
+
+# found closing ")" on own line -- drop "suspect" from final line of subshell
+# since that line legitimately lacks "&&" and exit subshell loop
+:clssolo
+x
+s/?!AMP?!//
+p
+x
+s/^/>/
+b
+
+# found closing "...)" -- exit subshell loop
+:close
+x
+p
+x
+s/^/>/
+b
diff -pruN 1.2.1+git2.18.0-1/git/t/check-non-portable-shell.pl 1.2.3+git2.25.1-1/git/t/check-non-portable-shell.pl
--- 1.2.1+git2.18.0-1/git/t/check-non-portable-shell.pl	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/check-non-portable-shell.pl	2020-02-17 04:47:35.000000000 +0000
@@ -7,22 +7,48 @@ use strict;
 use warnings;
 
 my $exit_code=0;
+my %func;
 
 sub err {
 	my $msg = shift;
+	s/^\s+//;
+	s/\s+$//;
+	s/\s+/ /g;
 	print "$ARGV:$.: error: $msg: $_\n";
 	$exit_code = 1;
 }
 
+# glean names of shell functions
+for my $i (@ARGV) {
+	open(my $f, '<', $i) or die "$0: $i: $!\n";
+	while (<$f>) {
+		$func{$1} = 1 if /^\s*(\w+)\s*\(\)\s*{\s*$/;
+	}
+	close $f;
+}
+
+my $line = '';
 while (<>) {
 	chomp;
-	/\bsed\s+-i/ and err 'sed -i is not portable';
-	/\becho\s+-[neE]/ and err 'echo with option is not portable (please use printf)';
+	$line .= $_;
+	# stitch together incomplete lines (those ending with "\")
+	next if $line =~ s/\\$//;
+
+	$_ = $line;
+	/\bcp\s+-a/ and err 'cp -a is not portable';
+	/\bsed\s+-[^efn]\s+/ and err 'sed option not portable (use only -n, -e, -f)';
+	/\becho\s+-[neE]/ and err 'echo with option is not portable (use printf)';
 	/^\s*declare\s+/ and err 'arrays/declare not portable';
-	/^\s*[^#]\s*which\s/ and err 'which is not portable (please use type)';
-	/\btest\s+[^=]*==/ and err '"test a == b" is not portable (please use =)';
-	/\bwc -l.*"\s*=/ and err '`"$(wc -l)"` is not portable (please use test_line_count)';
-	/\bexport\s+[A-Za-z0-9_]*=/ and err '"export FOO=bar" is not portable (please use FOO=bar && export FOO)';
+	/^\s*[^#]\s*which\s/ and err 'which is not portable (use type)';
+	/\btest\s+[^=]*==/ and err '"test a == b" is not portable (use =)';
+	/\bwc -l.*"\s*=/ and err '`"$(wc -l)"` is not portable (use test_line_count)';
+	/\bhead\s+-c\b/ and err 'head -c is not portable (use test_copy_bytes BYTES <file >out)';
+	/(?:\$\(seq|^\s*seq\b)/ and err 'seq is not portable (use test_seq)';
+	/\bgrep\b.*--file\b/ and err 'grep --file FILE is not portable (use grep -f FILE)';
+	/\bexport\s+[A-Za-z0-9_]*=/ and err '"export FOO=bar" is not portable (use FOO=bar && export FOO)';
+	/^\s*([A-Z0-9_]+=(\w+|(["']).*?\3)\s+)+(\w+)/ and exists($func{$4}) and
+		err '"FOO=bar shell_func" assignment extends beyond "shell_func"';
+	$line = '';
 	# this resets our $. for each file
 	close ARGV if eof;
 }
diff -pruN 1.2.1+git2.18.0-1/git/t/.gitattributes 1.2.3+git2.25.1-1/git/t/.gitattributes
--- 1.2.1+git2.18.0-1/git/t/.gitattributes	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/.gitattributes	2020-02-17 04:47:35.000000000 +0000
@@ -1,6 +1,8 @@
 t[0-9][0-9][0-9][0-9]/* -whitespace
+/chainlint/*.expect eol=lf
 /diff-lib/* eol=lf
 /t0110/url-* binary
+/t3206/* eol=lf
 /t3900/*.txt eol=lf
 /t3901/*.txt eol=lf
 /t4034/*/* eol=lf
@@ -14,6 +16,7 @@ t[0-9][0-9][0-9][0-9]/* -whitespace
 /t4135/* eol=lf
 /t4211/* eol=lf
 /t4252/* eol=lf
+/t4256/1/* eol=lf
 /t5100/* eol=lf
 /t5515/* eol=lf
 /t556x_common eol=lf
diff -pruN 1.2.1+git2.18.0-1/git/t/.gitignore 1.2.3+git2.25.1-1/git/t/.gitignore
--- 1.2.1+git2.18.0-1/git/t/.gitignore	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/.gitignore	2020-02-17 04:47:35.000000000 +0000
@@ -1,3 +1,5 @@
 /trash directory*
 /test-results
 /.prove
+/chainlinttmp
+/out/
diff -pruN 1.2.1+git2.18.0-1/git/t/gitweb-lib.sh 1.2.3+git2.25.1-1/git/t/gitweb-lib.sh
--- 1.2.1+git2.18.0-1/git/t/gitweb-lib.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/gitweb-lib.sh	2020-02-17 04:47:35.000000000 +0000
@@ -58,10 +58,11 @@ gitweb_run () {
 	GATEWAY_INTERFACE='CGI/1.1'
 	HTTP_ACCEPT='*/*'
 	REQUEST_METHOD='GET'
-	QUERY_STRING=""$1""
-	PATH_INFO=""$2""
+	QUERY_STRING=$1
+	PATH_INFO=$2
+	REQUEST_URI=/gitweb.cgi$PATH_INFO
 	export GATEWAY_INTERFACE HTTP_ACCEPT REQUEST_METHOD \
-		QUERY_STRING PATH_INFO
+		QUERY_STRING PATH_INFO REQUEST_URI
 
 	GITWEB_CONFIG=$(pwd)/gitweb_config.perl
 	export GITWEB_CONFIG
diff -pruN 1.2.1+git2.18.0-1/git/t/helper/.gitignore 1.2.3+git2.25.1-1/git/t/helper/.gitignore
--- 1.2.1+git2.18.0-1/git/t/helper/.gitignore	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/helper/.gitignore	2020-02-17 04:47:35.000000000 +0000
@@ -1,5 +1,4 @@
-*
-!*.sh
-!*.[ch]
-!*.gitignore
-
+/test-tool
+/test-fake-ssh
+/test-line-buffer
+/test-svn-fe
diff -pruN 1.2.1+git2.18.0-1/git/t/helper/test-date.c 1.2.3+git2.25.1-1/git/t/helper/test-date.c
--- 1.2.1+git2.18.0-1/git/t/helper/test-date.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/helper/test-date.c	2020-02-17 04:47:35.000000000 +0000
@@ -3,25 +3,35 @@
 
 static const char *usage_msg = "\n"
 "  test-tool date relative [time_t]...\n"
+"  test-tool date human [time_t]...\n"
 "  test-tool date show:<format> [time_t]...\n"
 "  test-tool date parse [date]...\n"
 "  test-tool date approxidate [date]...\n"
 "  test-tool date timestamp [date]...\n"
+"  test-tool date getnanos [start-nanos]\n"
 "  test-tool date is64bit\n"
 "  test-tool date time_t-is64bit\n";
 
-static void show_relative_dates(const char **argv, struct timeval *now)
+static void show_relative_dates(const char **argv)
 {
 	struct strbuf buf = STRBUF_INIT;
 
 	for (; *argv; argv++) {
 		time_t t = atoi(*argv);
-		show_date_relative(t, 0, now, &buf);
+		show_date_relative(t, &buf);
 		printf("%s -> %s\n", *argv, buf.buf);
 	}
 	strbuf_release(&buf);
 }
 
+static void show_human_dates(const char **argv)
+{
+	for (; *argv; argv++) {
+		time_t t = atoi(*argv);
+		printf("%s -> %s\n", *argv, show_date(t, 0, DATE_MODE(HUMAN)));
+	}
+}
+
 static void show_dates(const char **argv, const char *format)
 {
 	struct date_mode mode;
@@ -45,7 +55,7 @@ static void show_dates(const char **argv
 	}
 }
 
-static void parse_dates(const char **argv, struct timeval *now)
+static void parse_dates(const char **argv)
 {
 	struct strbuf result = STRBUF_INIT;
 
@@ -64,50 +74,54 @@ static void parse_dates(const char **arg
 	strbuf_release(&result);
 }
 
-static void parse_approxidate(const char **argv, struct timeval *now)
+static void parse_approxidate(const char **argv)
 {
 	for (; *argv; argv++) {
 		timestamp_t t;
-		t = approxidate_relative(*argv, now);
+		t = approxidate_relative(*argv);
 		printf("%s -> %s\n", *argv, show_date(t, 0, DATE_MODE(ISO8601)));
 	}
 }
 
-static void parse_approx_timestamp(const char **argv, struct timeval *now)
+static void parse_approx_timestamp(const char **argv)
 {
 	for (; *argv; argv++) {
 		timestamp_t t;
-		t = approxidate_relative(*argv, now);
+		t = approxidate_relative(*argv);
 		printf("%s -> %"PRItime"\n", *argv, t);
 	}
 }
 
+static void getnanos(const char **argv)
+{
+	double seconds = getnanotime() / 1.0e9;
+
+	if (*argv)
+		seconds -= strtod(*argv, NULL);
+	printf("%lf\n", seconds);
+}
+
 int cmd__date(int argc, const char **argv)
 {
-	struct timeval now;
 	const char *x;
 
-	x = getenv("TEST_DATE_NOW");
-	if (x) {
-		now.tv_sec = atoi(x);
-		now.tv_usec = 0;
-	}
-	else
-		gettimeofday(&now, NULL);
-
 	argv++;
 	if (!*argv)
 		usage(usage_msg);
 	if (!strcmp(*argv, "relative"))
-		show_relative_dates(argv+1, &now);
+		show_relative_dates(argv+1);
+	else if (!strcmp(*argv, "human"))
+		show_human_dates(argv+1);
 	else if (skip_prefix(*argv, "show:", &x))
 		show_dates(argv+1, x);
 	else if (!strcmp(*argv, "parse"))
-		parse_dates(argv+1, &now);
+		parse_dates(argv+1);
 	else if (!strcmp(*argv, "approxidate"))
-		parse_approxidate(argv+1, &now);
+		parse_approxidate(argv+1);
 	else if (!strcmp(*argv, "timestamp"))
-		parse_approx_timestamp(argv+1, &now);
+		parse_approx_timestamp(argv+1);
+	else if (!strcmp(*argv, "getnanos"))
+		getnanos(argv+1);
 	else if (!strcmp(*argv, "is64bit"))
 		return sizeof(timestamp_t) == 8 ? 0 : 1;
 	else if (!strcmp(*argv, "time_t-is64bit"))
diff -pruN 1.2.1+git2.18.0-1/git/t/helper/test-delta.c 1.2.3+git2.25.1-1/git/t/helper/test-delta.c
--- 1.2.1+git2.18.0-1/git/t/helper/test-delta.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/helper/test-delta.c	2020-02-17 04:47:35.000000000 +0000
@@ -34,8 +34,8 @@ int cmd__delta(int argc, const char **ar
 		return 1;
 	}
 	from_size = st.st_size;
-	from_buf = mmap(NULL, from_size, PROT_READ, MAP_PRIVATE, fd, 0);
-	if (from_buf == MAP_FAILED) {
+	from_buf = xmalloc(from_size);
+	if (read_in_full(fd, from_buf, from_size) < 0) {
 		perror(argv[2]);
 		close(fd);
 		return 1;
@@ -48,8 +48,8 @@ int cmd__delta(int argc, const char **ar
 		return 1;
 	}
 	data_size = st.st_size;
-	data_buf = mmap(NULL, data_size, PROT_READ, MAP_PRIVATE, fd, 0);
-	if (data_buf == MAP_FAILED) {
+	data_buf = xmalloc(data_size);
+	if (read_in_full(fd, data_buf, data_size) < 0) {
 		perror(argv[3]);
 		close(fd);
 		return 1;
diff -pruN 1.2.1+git2.18.0-1/git/t/helper/test-dir-iterator.c 1.2.3+git2.25.1-1/git/t/helper/test-dir-iterator.c
--- 1.2.1+git2.18.0-1/git/t/helper/test-dir-iterator.c	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/helper/test-dir-iterator.c	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,65 @@
+#include "test-tool.h"
+#include "git-compat-util.h"
+#include "strbuf.h"
+#include "iterator.h"
+#include "dir-iterator.h"
+
+static const char *error_name(int error_number)
+{
+	switch (error_number) {
+	case ENOENT: return "ENOENT";
+	case ENOTDIR: return "ENOTDIR";
+	default: return "ESOMETHINGELSE";
+	}
+}
+
+/*
+ * usage:
+ * tool-test dir-iterator [--follow-symlinks] [--pedantic] directory_path
+ */
+int cmd__dir_iterator(int argc, const char **argv)
+{
+	struct dir_iterator *diter;
+	unsigned int flags = 0;
+	int iter_status;
+
+	for (++argv, --argc; *argv && starts_with(*argv, "--"); ++argv, --argc) {
+		if (strcmp(*argv, "--follow-symlinks") == 0)
+			flags |= DIR_ITERATOR_FOLLOW_SYMLINKS;
+		else if (strcmp(*argv, "--pedantic") == 0)
+			flags |= DIR_ITERATOR_PEDANTIC;
+		else
+			die("invalid option '%s'", *argv);
+	}
+
+	if (!*argv || argc != 1)
+		die("dir-iterator needs exactly one non-option argument");
+
+	diter = dir_iterator_begin(*argv, flags);
+
+	if (!diter) {
+		printf("dir_iterator_begin failure: %s\n", error_name(errno));
+		exit(EXIT_FAILURE);
+	}
+
+	while ((iter_status = dir_iterator_advance(diter)) == ITER_OK) {
+		if (S_ISDIR(diter->st.st_mode))
+			printf("[d] ");
+		else if (S_ISREG(diter->st.st_mode))
+			printf("[f] ");
+		else if (S_ISLNK(diter->st.st_mode))
+			printf("[s] ");
+		else
+			printf("[?] ");
+
+		printf("(%s) [%s] %s\n", diter->relative_path, diter->basename,
+		       diter->path.buf);
+	}
+
+	if (iter_status != ITER_DONE) {
+		printf("dir_iterator_advance failure\n");
+		return 1;
+	}
+
+	return 0;
+}
diff -pruN 1.2.1+git2.18.0-1/git/t/helper/test-drop-caches.c 1.2.3+git2.25.1-1/git/t/helper/test-drop-caches.c
--- 1.2.1+git2.18.0-1/git/t/helper/test-drop-caches.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/helper/test-drop-caches.c	2020-02-17 04:47:35.000000000 +0000
@@ -8,18 +8,21 @@ static int cmd_sync(void)
 {
 	char Buffer[MAX_PATH];
 	DWORD dwRet;
-	char szVolumeAccessPath[] = "\\\\.\\X:";
+	char szVolumeAccessPath[] = "\\\\.\\XXXX:";
 	HANDLE hVolWrite;
-	int success = 0;
+	int success = 0, dos_drive_prefix;
 
 	dwRet = GetCurrentDirectory(MAX_PATH, Buffer);
 	if ((0 == dwRet) || (dwRet > MAX_PATH))
 		return error("Error getting current directory");
 
-	if ((Buffer[0] < 'A') || (Buffer[0] > 'Z'))
-		return error("Invalid drive letter '%c'", Buffer[0]);
+	dos_drive_prefix = has_dos_drive_prefix(Buffer);
+	if (!dos_drive_prefix)
+		return error("'%s': invalid drive letter", Buffer);
+
+	memcpy(szVolumeAccessPath, Buffer, dos_drive_prefix);
+	szVolumeAccessPath[dos_drive_prefix] = '\0';
 
-	szVolumeAccessPath[4] = Buffer[0];
 	hVolWrite = CreateFile(szVolumeAccessPath, GENERIC_READ | GENERIC_WRITE,
 		FILE_SHARE_READ | FILE_SHARE_WRITE, NULL, OPEN_EXISTING, 0, NULL);
 	if (INVALID_HANDLE_VALUE == hVolWrite)
diff -pruN 1.2.1+git2.18.0-1/git/t/helper/test-dump-cache-tree.c 1.2.3+git2.25.1-1/git/t/helper/test-dump-cache-tree.c
--- 1.2.1+git2.18.0-1/git/t/helper/test-dump-cache-tree.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/helper/test-dump-cache-tree.c	2020-02-17 04:47:35.000000000 +0000
@@ -33,7 +33,7 @@ static int dump_cache_tree(struct cache_
 	}
 	else {
 		dump_one(it, pfx, "");
-		if (oidcmp(&it->oid, &ref->oid) ||
+		if (!oideq(&it->oid, &ref->oid) ||
 		    ref->entry_count != it->entry_count ||
 		    ref->subtree_nr != it->subtree_nr) {
 			/* claims to be valid but is lying */
diff -pruN 1.2.1+git2.18.0-1/git/t/helper/test-dump-fsmonitor.c 1.2.3+git2.25.1-1/git/t/helper/test-dump-fsmonitor.c
--- 1.2.1+git2.18.0-1/git/t/helper/test-dump-fsmonitor.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/helper/test-dump-fsmonitor.c	2020-02-17 04:47:35.000000000 +0000
@@ -1,12 +1,13 @@
+#include "test-tool.h"
 #include "cache.h"
 
-int cmd_main(int ac, const char **av)
+int cmd__dump_fsmonitor(int ac, const char **av)
 {
-	struct index_state *istate = &the_index;
+	struct index_state *istate = the_repository->index;
 	int i;
 
 	setup_git_directory();
-	if (do_read_index(istate, get_index_file(), 0) < 0)
+	if (do_read_index(istate, the_repository->index_file, 0) < 0)
 		die("unable to read index file");
 	if (!istate->fsmonitor_last_update) {
 		printf("no fsmonitor\n");
diff -pruN 1.2.1+git2.18.0-1/git/t/helper/test-dump-untracked-cache.c 1.2.3+git2.25.1-1/git/t/helper/test-dump-untracked-cache.c
--- 1.2.1+git2.18.0-1/git/t/helper/test-dump-untracked-cache.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/helper/test-dump-untracked-cache.c	2020-02-17 04:47:35.000000000 +0000
@@ -1,3 +1,5 @@
+#define USE_THE_INDEX_COMPATIBILITY_MACROS
+#include "test-tool.h"
 #include "cache.h"
 #include "dir.h"
 
@@ -38,7 +40,7 @@ static void dump(struct untracked_cache_
 	strbuf_setlen(base, len);
 }
 
-int cmd_main(int ac, const char **av)
+int cmd__dump_untracked_cache(int ac, const char **av)
 {
 	struct untracked_cache *uc;
 	struct strbuf base = STRBUF_INIT;
diff -pruN 1.2.1+git2.18.0-1/git/t/helper/test-example-decorate.c 1.2.3+git2.25.1-1/git/t/helper/test-example-decorate.c
--- 1.2.1+git2.18.0-1/git/t/helper/test-example-decorate.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/helper/test-example-decorate.c	2020-02-17 04:47:35.000000000 +0000
@@ -26,8 +26,8 @@ int cmd__example_decorate(int argc, cons
 	 * Add 2 objects, one with a non-NULL decoration and one with a NULL
 	 * decoration.
 	 */
-	one = lookup_unknown_object(one_oid.hash);
-	two = lookup_unknown_object(two_oid.hash);
+	one = lookup_unknown_object(&one_oid);
+	two = lookup_unknown_object(&two_oid);
 	ret = add_decoration(&n, one, &decoration_a);
 	if (ret)
 		BUG("when adding a brand-new object, NULL should be returned");
@@ -56,7 +56,7 @@ int cmd__example_decorate(int argc, cons
 	ret = lookup_decoration(&n, two);
 	if (ret != &decoration_b)
 		BUG("lookup should return added declaration");
-	three = lookup_unknown_object(three_oid.hash);
+	three = lookup_unknown_object(&three_oid);
 	ret = lookup_decoration(&n, three);
 	if (ret)
 		BUG("lookup for unknown object should return NULL");
diff -pruN 1.2.1+git2.18.0-1/git/t/helper/test-genzeros.c 1.2.3+git2.25.1-1/git/t/helper/test-genzeros.c
--- 1.2.1+git2.18.0-1/git/t/helper/test-genzeros.c	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/helper/test-genzeros.c	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,21 @@
+#include "test-tool.h"
+#include "git-compat-util.h"
+
+int cmd__genzeros(int argc, const char **argv)
+{
+	long count;
+
+	if (argc > 2) {
+		fprintf(stderr, "usage: %s [<count>]\n", argv[0]);
+		return 1;
+	}
+
+	count = argc > 1 ? strtol(argv[1], NULL, 0) : -1L;
+
+	while (count < 0 || count--) {
+		if (putchar(0) == EOF)
+			return -1;
+	}
+
+	return 0;
+}
diff -pruN 1.2.1+git2.18.0-1/git/t/helper/test-hash.c 1.2.3+git2.25.1-1/git/t/helper/test-hash.c
--- 1.2.1+git2.18.0-1/git/t/helper/test-hash.c	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/helper/test-hash.c	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,58 @@
+#include "test-tool.h"
+#include "cache.h"
+
+int cmd_hash_impl(int ac, const char **av, int algo)
+{
+	git_hash_ctx ctx;
+	unsigned char hash[GIT_MAX_HEXSZ];
+	unsigned bufsz = 8192;
+	int binary = 0;
+	char *buffer;
+	const struct git_hash_algo *algop = &hash_algos[algo];
+
+	if (ac == 2) {
+		if (!strcmp(av[1], "-b"))
+			binary = 1;
+		else
+			bufsz = strtoul(av[1], NULL, 10) * 1024 * 1024;
+	}
+
+	if (!bufsz)
+		bufsz = 8192;
+
+	while ((buffer = malloc(bufsz)) == NULL) {
+		fprintf(stderr, "bufsz %u is too big, halving...\n", bufsz);
+		bufsz /= 2;
+		if (bufsz < 1024)
+			die("OOPS");
+	}
+
+	algop->init_fn(&ctx);
+
+	while (1) {
+		ssize_t sz, this_sz;
+		char *cp = buffer;
+		unsigned room = bufsz;
+		this_sz = 0;
+		while (room) {
+			sz = xread(0, cp, room);
+			if (sz == 0)
+				break;
+			if (sz < 0)
+				die_errno("test-hash");
+			this_sz += sz;
+			cp += sz;
+			room -= sz;
+		}
+		if (this_sz == 0)
+			break;
+		algop->update_fn(&ctx, buffer, this_sz);
+	}
+	algop->final_fn(hash, &ctx);
+
+	if (binary)
+		fwrite(hash, 1, algop->rawsz, stdout);
+	else
+		puts(hash_to_hex_algop(hash, algop));
+	exit(0);
+}
diff -pruN 1.2.1+git2.18.0-1/git/t/helper/test-hashmap.c 1.2.3+git2.25.1-1/git/t/helper/test-hashmap.c
--- 1.2.1+git2.18.0-1/git/t/helper/test-hashmap.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/helper/test-hashmap.c	2020-02-17 04:47:35.000000000 +0000
@@ -5,6 +5,7 @@
 
 struct test_entry
 {
+	int padding; /* hashmap entry no longer needs to be the first member */
 	struct hashmap_entry ent;
 	/* key and value as two \0-terminated strings */
 	char key[FLEX_ARRAY];
@@ -16,15 +17,17 @@ static const char *get_value(const struc
 }
 
 static int test_entry_cmp(const void *cmp_data,
-			  const void *entry,
-			  const void *entry_or_key,
+			  const struct hashmap_entry *eptr,
+			  const struct hashmap_entry *entry_or_key,
 			  const void *keydata)
 {
 	const int ignore_case = cmp_data ? *((int *)cmp_data) : 0;
-	const struct test_entry *e1 = entry;
-	const struct test_entry *e2 = entry_or_key;
+	const struct test_entry *e1, *e2;
 	const char *key = keydata;
 
+	e1 = container_of(eptr, const struct test_entry, ent);
+	e2 = container_of(entry_or_key, const struct test_entry, ent);
+
 	if (ignore_case)
 		return strcasecmp(e1->key, key ? key : e2->key);
 	else
@@ -37,7 +40,7 @@ static struct test_entry *alloc_test_ent
 	size_t klen = strlen(key);
 	size_t vlen = strlen(value);
 	struct test_entry *entry = xmalloc(st_add4(sizeof(*entry), klen, vlen, 2));
-	hashmap_entry_init(entry, hash);
+	hashmap_entry_init(&entry->ent, hash);
 	memcpy(entry->key, key, klen + 1);
 	memcpy(entry->key + klen + 1, value, vlen + 1);
 	return entry;
@@ -103,11 +106,11 @@ static void perf_hashmap(unsigned int me
 
 			/* add entries */
 			for (i = 0; i < TEST_SIZE; i++) {
-				hashmap_entry_init(entries[i], hashes[i]);
-				hashmap_add(&map, entries[i]);
+				hashmap_entry_init(&entries[i]->ent, hashes[i]);
+				hashmap_add(&map, &entries[i]->ent);
 			}
 
-			hashmap_free(&map, 0);
+			hashmap_free(&map);
 		}
 	} else {
 		/* test map lookups */
@@ -116,8 +119,8 @@ static void perf_hashmap(unsigned int me
 		/* fill the map (sparsely if specified) */
 		j = (method & TEST_SPARSE) ? TEST_SIZE / 10 : TEST_SIZE;
 		for (i = 0; i < j; i++) {
-			hashmap_entry_init(entries[i], hashes[i]);
-			hashmap_add(&map, entries[i]);
+			hashmap_entry_init(&entries[i]->ent, hashes[i]);
+			hashmap_add(&map, &entries[i]->ent);
 		}
 
 		for (j = 0; j < rounds; j++) {
@@ -127,7 +130,7 @@ static void perf_hashmap(unsigned int me
 			}
 		}
 
-		hashmap_free(&map, 0);
+		hashmap_free(&map);
 	}
 }
 
@@ -173,20 +176,13 @@ int cmd__hashmap(int argc, const char **
 			p2 = strtok(NULL, DELIM);
 		}
 
-		if (!strcmp("hash", cmd) && p1) {
-
-			/* print results of different hash functions */
-			printf("%u %u %u %u\n",
-			       strhash(p1), memhash(p1, strlen(p1)),
-			       strihash(p1), memihash(p1, strlen(p1)));
-
-		} else if (!strcmp("add", cmd) && p1 && p2) {
+		if (!strcmp("add", cmd) && p1 && p2) {
 
 			/* create entry with key = p1, value = p2 */
 			entry = alloc_test_entry(hash, p1, p2);
 
 			/* add to hashmap */
-			hashmap_add(&map, entry);
+			hashmap_add(&map, &entry->ent);
 
 		} else if (!strcmp("put", cmd) && p1 && p2) {
 
@@ -194,43 +190,44 @@ int cmd__hashmap(int argc, const char **
 			entry = alloc_test_entry(hash, p1, p2);
 
 			/* add / replace entry */
-			entry = hashmap_put(&map, entry);
+			entry = hashmap_put_entry(&map, entry, ent);
 
 			/* print and free replaced entry, if any */
 			puts(entry ? get_value(entry) : "NULL");
 			free(entry);
 
 		} else if (!strcmp("get", cmd) && p1) {
-
 			/* lookup entry in hashmap */
-			entry = hashmap_get_from_hash(&map, hash, p1);
+			entry = hashmap_get_entry_from_hash(&map, hash, p1,
+							struct test_entry, ent);
 
 			/* print result */
 			if (!entry)
 				puts("NULL");
-			while (entry) {
+			hashmap_for_each_entry_from(&map, entry, ent)
 				puts(get_value(entry));
-				entry = hashmap_get_next(&map, entry);
-			}
 
 		} else if (!strcmp("remove", cmd) && p1) {
 
 			/* setup static key */
 			struct hashmap_entry key;
+			struct hashmap_entry *rm;
 			hashmap_entry_init(&key, hash);
 
 			/* remove entry from hashmap */
-			entry = hashmap_remove(&map, &key, p1);
+			rm = hashmap_remove(&map, &key, p1);
+			entry = rm ? container_of(rm, struct test_entry, ent)
+					: NULL;
 
 			/* print result and free entry*/
 			puts(entry ? get_value(entry) : "NULL");
 			free(entry);
 
 		} else if (!strcmp("iterate", cmd)) {
-
 			struct hashmap_iter iter;
-			hashmap_iter_init(&map, &iter);
-			while ((entry = hashmap_iter_next(&iter)))
+
+			hashmap_for_each_entry(&map, &iter, entry,
+						ent /* member name */)
 				printf("%s %s\n", entry->key, get_value(entry));
 
 		} else if (!strcmp("size", cmd)) {
@@ -265,6 +262,6 @@ int cmd__hashmap(int argc, const char **
 	}
 
 	strbuf_release(&line);
-	hashmap_free(&map, 1);
+	hashmap_free_entries(&map, struct test_entry, ent);
 	return 0;
 }
diff -pruN 1.2.1+git2.18.0-1/git/t/helper/test-hash-speed.c 1.2.3+git2.25.1-1/git/t/helper/test-hash-speed.c
--- 1.2.1+git2.18.0-1/git/t/helper/test-hash-speed.c	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/helper/test-hash-speed.c	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,61 @@
+#include "test-tool.h"
+#include "cache.h"
+
+#define NUM_SECONDS 3
+
+static inline void compute_hash(const struct git_hash_algo *algo, git_hash_ctx *ctx, uint8_t *final, const void *p, size_t len)
+{
+	algo->init_fn(ctx);
+	algo->update_fn(ctx, p, len);
+	algo->final_fn(final, ctx);
+}
+
+int cmd__hash_speed(int ac, const char **av)
+{
+	git_hash_ctx ctx;
+	unsigned char hash[GIT_MAX_RAWSZ];
+	clock_t initial, start, end;
+	unsigned bufsizes[] = { 64, 256, 1024, 8192, 16384 };
+	int i;
+	void *p;
+	const struct git_hash_algo *algo = NULL;
+
+	if (ac == 2) {
+		for (i = 1; i < GIT_HASH_NALGOS; i++) {
+			if (!strcmp(av[1], hash_algos[i].name)) {
+				algo = &hash_algos[i];
+				break;
+			}
+		}
+	}
+	if (!algo)
+		die("usage: test-tool hash-speed algo_name");
+
+	/* Use this as an offset to make overflow less likely. */
+	initial = clock();
+
+	printf("algo: %s\n", algo->name);
+
+	for (i = 0; i < ARRAY_SIZE(bufsizes); i++) {
+		unsigned long j, kb;
+		double kb_per_sec;
+		p = xcalloc(1, bufsizes[i]);
+		start = end = clock() - initial;
+		for (j = 0; ((end - start) / CLOCKS_PER_SEC) < NUM_SECONDS; j++) {
+			compute_hash(algo, &ctx, hash, p, bufsizes[i]);
+
+			/*
+			 * Only check elapsed time every 128 iterations to avoid
+			 * dominating the runtime with system calls.
+			 */
+			if (!(j & 127))
+				end = clock() - initial;
+		}
+		kb = j * bufsizes[i];
+		kb_per_sec = kb / (1024 * ((double)end - start) / CLOCKS_PER_SEC);
+		printf("size %u: %lu iters; %lu KiB; %0.2f KiB/s\n", bufsizes[i], j, kb, kb_per_sec);
+		free(p);
+	}
+
+	exit(0);
+}
diff -pruN 1.2.1+git2.18.0-1/git/t/helper/test-json-writer.c 1.2.3+git2.25.1-1/git/t/helper/test-json-writer.c
--- 1.2.1+git2.18.0-1/git/t/helper/test-json-writer.c	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/helper/test-json-writer.c	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,565 @@
+#include "test-tool.h"
+#include "cache.h"
+#include "json-writer.h"
+
+static const char *expect_obj1 = "{\"a\":\"abc\",\"b\":42,\"c\":true}";
+static const char *expect_obj2 = "{\"a\":-1,\"b\":2147483647,\"c\":0}";
+static const char *expect_obj3 = "{\"a\":0,\"b\":4294967295,\"c\":9223372036854775807}";
+static const char *expect_obj4 = "{\"t\":true,\"f\":false,\"n\":null}";
+static const char *expect_obj5 = "{\"abc\\tdef\":\"abc\\\\def\"}";
+static const char *expect_obj6 = "{\"a\":3.14}";
+
+static const char *pretty_obj1 = ("{\n"
+				  "  \"a\": \"abc\",\n"
+				  "  \"b\": 42,\n"
+				  "  \"c\": true\n"
+				  "}");
+static const char *pretty_obj2 = ("{\n"
+				  "  \"a\": -1,\n"
+				  "  \"b\": 2147483647,\n"
+				  "  \"c\": 0\n"
+				  "}");
+static const char *pretty_obj3 = ("{\n"
+				  "  \"a\": 0,\n"
+				  "  \"b\": 4294967295,\n"
+				  "  \"c\": 9223372036854775807\n"
+				  "}");
+static const char *pretty_obj4 = ("{\n"
+				  "  \"t\": true,\n"
+				  "  \"f\": false,\n"
+				  "  \"n\": null\n"
+				  "}");
+
+static struct json_writer obj1 = JSON_WRITER_INIT;
+static struct json_writer obj2 = JSON_WRITER_INIT;
+static struct json_writer obj3 = JSON_WRITER_INIT;
+static struct json_writer obj4 = JSON_WRITER_INIT;
+static struct json_writer obj5 = JSON_WRITER_INIT;
+static struct json_writer obj6 = JSON_WRITER_INIT;
+
+static void make_obj1(int pretty)
+{
+	jw_object_begin(&obj1, pretty);
+	{
+		jw_object_string(&obj1, "a", "abc");
+		jw_object_intmax(&obj1, "b", 42);
+		jw_object_true(&obj1, "c");
+	}
+	jw_end(&obj1);
+}
+
+static void make_obj2(int pretty)
+{
+	jw_object_begin(&obj2, pretty);
+	{
+		jw_object_intmax(&obj2, "a", -1);
+		jw_object_intmax(&obj2, "b", 0x7fffffff);
+		jw_object_intmax(&obj2, "c", 0);
+	}
+	jw_end(&obj2);
+}
+
+static void make_obj3(int pretty)
+{
+	jw_object_begin(&obj3, pretty);
+	{
+		jw_object_intmax(&obj3, "a", 0);
+		jw_object_intmax(&obj3, "b", 0xffffffff);
+		jw_object_intmax(&obj3, "c", 0x7fffffffffffffffULL);
+	}
+	jw_end(&obj3);
+}
+
+static void make_obj4(int pretty)
+{
+	jw_object_begin(&obj4, pretty);
+	{
+		jw_object_true(&obj4, "t");
+		jw_object_false(&obj4, "f");
+		jw_object_null(&obj4, "n");
+	}
+	jw_end(&obj4);
+}
+
+static void make_obj5(int pretty)
+{
+	jw_object_begin(&obj5, pretty);
+	{
+		jw_object_string(&obj5, "abc" "\x09" "def", "abc" "\\" "def");
+	}
+	jw_end(&obj5);
+}
+
+static void make_obj6(int pretty)
+{
+	jw_object_begin(&obj6, pretty);
+	{
+		jw_object_double(&obj6, "a", 2, 3.14159);
+	}
+	jw_end(&obj6);
+}
+
+static const char *expect_arr1 = "[\"abc\",42,true]";
+static const char *expect_arr2 = "[-1,2147483647,0]";
+static const char *expect_arr3 = "[0,4294967295,9223372036854775807]";
+static const char *expect_arr4 = "[true,false,null]";
+
+static const char *pretty_arr1 = ("[\n"
+				  "  \"abc\",\n"
+				  "  42,\n"
+				  "  true\n"
+				  "]");
+static const char *pretty_arr2 = ("[\n"
+				  "  -1,\n"
+				  "  2147483647,\n"
+				  "  0\n"
+				  "]");
+static const char *pretty_arr3 = ("[\n"
+				  "  0,\n"
+				  "  4294967295,\n"
+				  "  9223372036854775807\n"
+				  "]");
+static const char *pretty_arr4 = ("[\n"
+				  "  true,\n"
+				  "  false,\n"
+				  "  null\n"
+				  "]");
+
+static struct json_writer arr1 = JSON_WRITER_INIT;
+static struct json_writer arr2 = JSON_WRITER_INIT;
+static struct json_writer arr3 = JSON_WRITER_INIT;
+static struct json_writer arr4 = JSON_WRITER_INIT;
+
+static void make_arr1(int pretty)
+{
+	jw_array_begin(&arr1, pretty);
+	{
+		jw_array_string(&arr1, "abc");
+		jw_array_intmax(&arr1, 42);
+		jw_array_true(&arr1);
+	}
+	jw_end(&arr1);
+}
+
+static void make_arr2(int pretty)
+{
+	jw_array_begin(&arr2, pretty);
+	{
+		jw_array_intmax(&arr2, -1);
+		jw_array_intmax(&arr2, 0x7fffffff);
+		jw_array_intmax(&arr2, 0);
+	}
+	jw_end(&arr2);
+}
+
+static void make_arr3(int pretty)
+{
+	jw_array_begin(&arr3, pretty);
+	{
+		jw_array_intmax(&arr3, 0);
+		jw_array_intmax(&arr3, 0xffffffff);
+		jw_array_intmax(&arr3, 0x7fffffffffffffffULL);
+	}
+	jw_end(&arr3);
+}
+
+static void make_arr4(int pretty)
+{
+	jw_array_begin(&arr4, pretty);
+	{
+		jw_array_true(&arr4);
+		jw_array_false(&arr4);
+		jw_array_null(&arr4);
+	}
+	jw_end(&arr4);
+}
+
+static char *expect_nest1 =
+	"{\"obj1\":{\"a\":\"abc\",\"b\":42,\"c\":true},\"arr1\":[\"abc\",42,true]}";
+
+static struct json_writer nest1 = JSON_WRITER_INIT;
+
+static void make_nest1(int pretty)
+{
+	jw_object_begin(&nest1, pretty);
+	{
+		jw_object_sub_jw(&nest1, "obj1", &obj1);
+		jw_object_sub_jw(&nest1, "arr1", &arr1);
+	}
+	jw_end(&nest1);
+}
+
+static char *expect_inline1 =
+	"{\"obj1\":{\"a\":\"abc\",\"b\":42,\"c\":true},\"arr1\":[\"abc\",42,true]}";
+
+static char *pretty_inline1 =
+	("{\n"
+	 "  \"obj1\": {\n"
+	 "    \"a\": \"abc\",\n"
+	 "    \"b\": 42,\n"
+	 "    \"c\": true\n"
+	 "  },\n"
+	 "  \"arr1\": [\n"
+	 "    \"abc\",\n"
+	 "    42,\n"
+	 "    true\n"
+	 "  ]\n"
+	 "}");
+
+static struct json_writer inline1 = JSON_WRITER_INIT;
+
+static void make_inline1(int pretty)
+{
+	jw_object_begin(&inline1, pretty);
+	{
+		jw_object_inline_begin_object(&inline1, "obj1");
+		{
+			jw_object_string(&inline1, "a", "abc");
+			jw_object_intmax(&inline1, "b", 42);
+			jw_object_true(&inline1, "c");
+		}
+		jw_end(&inline1);
+		jw_object_inline_begin_array(&inline1, "arr1");
+		{
+			jw_array_string(&inline1, "abc");
+			jw_array_intmax(&inline1, 42);
+			jw_array_true(&inline1);
+		}
+		jw_end(&inline1);
+	}
+	jw_end(&inline1);
+}
+
+static char *expect_inline2 =
+	"[[1,2],[3,4],{\"a\":\"abc\"}]";
+
+static char *pretty_inline2 =
+	("[\n"
+	 "  [\n"
+	 "    1,\n"
+	 "    2\n"
+	 "  ],\n"
+	 "  [\n"
+	 "    3,\n"
+	 "    4\n"
+	 "  ],\n"
+	 "  {\n"
+	 "    \"a\": \"abc\"\n"
+	 "  }\n"
+	 "]");
+
+static struct json_writer inline2 = JSON_WRITER_INIT;
+
+static void make_inline2(int pretty)
+{
+	jw_array_begin(&inline2, pretty);
+	{
+		jw_array_inline_begin_array(&inline2);
+		{
+			jw_array_intmax(&inline2, 1);
+			jw_array_intmax(&inline2, 2);
+		}
+		jw_end(&inline2);
+		jw_array_inline_begin_array(&inline2);
+		{
+			jw_array_intmax(&inline2, 3);
+			jw_array_intmax(&inline2, 4);
+		}
+		jw_end(&inline2);
+		jw_array_inline_begin_object(&inline2);
+		{
+			jw_object_string(&inline2, "a", "abc");
+		}
+		jw_end(&inline2);
+	}
+	jw_end(&inline2);
+}
+
+/*
+ * When super is compact, we expect subs to be compacted (even if originally
+ * pretty).
+ */
+static const char *expect_mixed1 =
+	("{\"obj1\":{\"a\":\"abc\",\"b\":42,\"c\":true},"
+	 "\"arr1\":[\"abc\",42,true]}");
+
+/*
+ * When super is pretty, a compact sub (obj1) is kept compact and a pretty
+ * sub (arr1) is re-indented.
+ */
+static const char *pretty_mixed1 =
+	("{\n"
+	 "  \"obj1\": {\"a\":\"abc\",\"b\":42,\"c\":true},\n"
+	 "  \"arr1\": [\n"
+	 "    \"abc\",\n"
+	 "    42,\n"
+	 "    true\n"
+	 "  ]\n"
+	 "}");
+
+static struct json_writer mixed1 = JSON_WRITER_INIT;
+
+static void make_mixed1(int pretty)
+{
+	jw_init(&obj1);
+	jw_init(&arr1);
+
+	make_obj1(0); /* obj1 is compact */
+	make_arr1(1); /* arr1 is pretty */
+
+	jw_object_begin(&mixed1, pretty);
+	{
+		jw_object_sub_jw(&mixed1, "obj1", &obj1);
+		jw_object_sub_jw(&mixed1, "arr1", &arr1);
+	}
+	jw_end(&mixed1);
+}
+
+static void cmp(const char *test, const struct json_writer *jw, const char *exp)
+{
+	if (!strcmp(jw->json.buf, exp))
+		return;
+
+	printf("error[%s]: observed '%s' expected '%s'\n",
+	       test, jw->json.buf, exp);
+	exit(1);
+}
+
+#define t(v) do { make_##v(0); cmp(#v, &v, expect_##v); } while (0)
+#define p(v) do { make_##v(1); cmp(#v, &v, pretty_##v); } while (0)
+
+/*
+ * Run some basic regression tests with some known patterns.
+ * These tests also demonstrate how to use the jw_ API.
+ */
+static int unit_tests(void)
+{
+	/* comptact (canonical) forms */
+	t(obj1);
+	t(obj2);
+	t(obj3);
+	t(obj4);
+	t(obj5);
+	t(obj6);
+
+	t(arr1);
+	t(arr2);
+	t(arr3);
+	t(arr4);
+
+	t(nest1);
+
+	t(inline1);
+	t(inline2);
+
+	jw_init(&obj1);
+	jw_init(&obj2);
+	jw_init(&obj3);
+	jw_init(&obj4);
+
+	jw_init(&arr1);
+	jw_init(&arr2);
+	jw_init(&arr3);
+	jw_init(&arr4);
+
+	jw_init(&inline1);
+	jw_init(&inline2);
+
+	/* pretty forms */
+	p(obj1);
+	p(obj2);
+	p(obj3);
+	p(obj4);
+
+	p(arr1);
+	p(arr2);
+	p(arr3);
+	p(arr4);
+
+	p(inline1);
+	p(inline2);
+
+	/* mixed forms */
+	t(mixed1);
+	jw_init(&mixed1);
+	p(mixed1);
+
+	return 0;
+}
+
+static void get_s(int line_nr, char **s_in)
+{
+	*s_in = strtok(NULL, " ");
+	if (!*s_in)
+		die("line[%d]: expected: <s>", line_nr);
+}
+
+static void get_i(int line_nr, intmax_t *s_in)
+{
+	char *s;
+	char *endptr;
+
+	get_s(line_nr, &s);
+
+	*s_in = strtol(s, &endptr, 10);
+	if (*endptr || errno == ERANGE)
+		die("line[%d]: invalid integer value", line_nr);
+}
+
+static void get_d(int line_nr, double *s_in)
+{
+	char *s;
+	char *endptr;
+
+	get_s(line_nr, &s);
+
+	*s_in = strtod(s, &endptr);
+	if (*endptr || errno == ERANGE)
+		die("line[%d]: invalid float value", line_nr);
+}
+
+static int pretty;
+
+#define MAX_LINE_LENGTH (64 * 1024)
+
+static char *get_trimmed_line(char *buf, int buf_size)
+{
+	int len;
+
+	if (!fgets(buf, buf_size, stdin))
+		return NULL;
+
+	len = strlen(buf);
+	while (len > 0) {
+		char c = buf[len - 1];
+		if (c == '\n' || c == '\r' || c == ' ' || c == '\t')
+			buf[--len] = 0;
+		else
+			break;
+	}
+
+	while (*buf == ' ' || *buf == '\t')
+		buf++;
+
+	return buf;
+}
+
+static int scripted(void)
+{
+	struct json_writer jw = JSON_WRITER_INIT;
+	char buf[MAX_LINE_LENGTH];
+	char *line;
+	int line_nr = 0;
+
+	line = get_trimmed_line(buf, MAX_LINE_LENGTH);
+	if (!line)
+		return 0;
+
+	if (!strcmp(line, "object"))
+		jw_object_begin(&jw, pretty);
+	else if (!strcmp(line, "array"))
+		jw_array_begin(&jw, pretty);
+	else
+		die("expected first line to be 'object' or 'array'");
+
+	while ((line = get_trimmed_line(buf, MAX_LINE_LENGTH)) != NULL) {
+		char *verb;
+		char *key;
+		char *s_value;
+		intmax_t i_value;
+		double d_value;
+
+		line_nr++;
+
+		verb = strtok(line, " ");
+
+		if (!strcmp(verb, "end")) {
+			jw_end(&jw);
+		}
+		else if (!strcmp(verb, "object-string")) {
+			get_s(line_nr, &key);
+			get_s(line_nr, &s_value);
+			jw_object_string(&jw, key, s_value);
+		}
+		else if (!strcmp(verb, "object-int")) {
+			get_s(line_nr, &key);
+			get_i(line_nr, &i_value);
+			jw_object_intmax(&jw, key, i_value);
+		}
+		else if (!strcmp(verb, "object-double")) {
+			get_s(line_nr, &key);
+			get_i(line_nr, &i_value);
+			get_d(line_nr, &d_value);
+			jw_object_double(&jw, key, i_value, d_value);
+		}
+		else if (!strcmp(verb, "object-true")) {
+			get_s(line_nr, &key);
+			jw_object_true(&jw, key);
+		}
+		else if (!strcmp(verb, "object-false")) {
+			get_s(line_nr, &key);
+			jw_object_false(&jw, key);
+		}
+		else if (!strcmp(verb, "object-null")) {
+			get_s(line_nr, &key);
+			jw_object_null(&jw, key);
+		}
+		else if (!strcmp(verb, "object-object")) {
+			get_s(line_nr, &key);
+			jw_object_inline_begin_object(&jw, key);
+		}
+		else if (!strcmp(verb, "object-array")) {
+			get_s(line_nr, &key);
+			jw_object_inline_begin_array(&jw, key);
+		}
+		else if (!strcmp(verb, "array-string")) {
+			get_s(line_nr, &s_value);
+			jw_array_string(&jw, s_value);
+		}
+		else if (!strcmp(verb, "array-int")) {
+			get_i(line_nr, &i_value);
+			jw_array_intmax(&jw, i_value);
+		}
+		else if (!strcmp(verb, "array-double")) {
+			get_i(line_nr, &i_value);
+			get_d(line_nr, &d_value);
+			jw_array_double(&jw, i_value, d_value);
+		}
+		else if (!strcmp(verb, "array-true"))
+			jw_array_true(&jw);
+		else if (!strcmp(verb, "array-false"))
+			jw_array_false(&jw);
+		else if (!strcmp(verb, "array-null"))
+			jw_array_null(&jw);
+		else if (!strcmp(verb, "array-object"))
+			jw_array_inline_begin_object(&jw);
+		else if (!strcmp(verb, "array-array"))
+			jw_array_inline_begin_array(&jw);
+		else
+			die("unrecognized token: '%s'", verb);
+	}
+
+	if (!jw_is_terminated(&jw))
+		die("json not terminated: '%s'", jw.json.buf);
+
+	printf("%s\n", jw.json.buf);
+
+	strbuf_release(&jw.json);
+	return 0;
+}
+
+int cmd__json_writer(int argc, const char **argv)
+{
+	argc--; /* skip over "json-writer" arg */
+	argv++;
+
+	if (argc > 0 && argv[0][0] == '-') {
+		if (!strcmp(argv[0], "-u") || !strcmp(argv[0], "--unit"))
+			return unit_tests();
+
+		if (!strcmp(argv[0], "-p") || !strcmp(argv[0], "--pretty"))
+			pretty = 1;
+	}
+
+	return scripted();
+}
diff -pruN 1.2.1+git2.18.0-1/git/t/helper/test-lazy-init-name-hash.c 1.2.3+git2.25.1-1/git/t/helper/test-lazy-init-name-hash.c
--- 1.2.1+git2.18.0-1/git/t/helper/test-lazy-init-name-hash.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/helper/test-lazy-init-name-hash.c	2020-02-17 04:47:35.000000000 +0000
@@ -41,17 +41,13 @@ static void dump_run(void)
 			die("non-threaded code path used");
 	}
 
-	dir = hashmap_iter_first(&the_index.dir_hash, &iter_dir);
-	while (dir) {
+	hashmap_for_each_entry(&the_index.dir_hash, &iter_dir, dir,
+				ent /* member name */)
 		printf("dir %08x %7d %s\n", dir->ent.hash, dir->nr, dir->name);
-		dir = hashmap_iter_next(&iter_dir);
-	}
 
-	ce = hashmap_iter_first(&the_index.name_hash, &iter_cache);
-	while (ce) {
+	hashmap_for_each_entry(&the_index.name_hash, &iter_cache, ce,
+				ent /* member name */)
 		printf("name %08x %s\n", ce->ent.hash, ce->name);
-		ce = hashmap_iter_next(&iter_cache);
-	}
 
 	discard_cache();
 }
diff -pruN 1.2.1+git2.18.0-1/git/t/helper/test-match-trees.c 1.2.3+git2.25.1-1/git/t/helper/test-match-trees.c
--- 1.2.1+git2.18.0-1/git/t/helper/test-match-trees.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/helper/test-match-trees.c	2020-02-17 04:47:35.000000000 +0000
@@ -20,7 +20,7 @@ int cmd__match_trees(int ac, const char
 	if (!two)
 		die("not a tree-ish %s", av[2]);
 
-	shift_tree(&one->object.oid, &two->object.oid, &shifted, -1);
+	shift_tree(the_repository, &one->object.oid, &two->object.oid, &shifted, -1);
 	printf("shifted: %s\n", oid_to_hex(&shifted));
 
 	exit(0);
diff -pruN 1.2.1+git2.18.0-1/git/t/helper/test-oidmap.c 1.2.3+git2.25.1-1/git/t/helper/test-oidmap.c
--- 1.2.1+git2.18.0-1/git/t/helper/test-oidmap.c	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/helper/test-oidmap.c	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,112 @@
+#include "test-tool.h"
+#include "cache.h"
+#include "oidmap.h"
+#include "strbuf.h"
+
+/* key is an oid and value is a name (could be a refname for example) */
+struct test_entry {
+	struct oidmap_entry entry;
+	char name[FLEX_ARRAY];
+};
+
+#define DELIM " \t\r\n"
+
+/*
+ * Read stdin line by line and print result of commands to stdout:
+ *
+ * hash oidkey -> sha1hash(oidkey)
+ * put oidkey namevalue -> NULL / old namevalue
+ * get oidkey -> NULL / namevalue
+ * remove oidkey -> NULL / old namevalue
+ * iterate -> oidkey1 namevalue1\noidkey2 namevalue2\n...
+ *
+ */
+int cmd__oidmap(int argc, const char **argv)
+{
+	struct strbuf line = STRBUF_INIT;
+	struct oidmap map = OIDMAP_INIT;
+
+	setup_git_directory();
+
+	/* init oidmap */
+	oidmap_init(&map, 0);
+
+	/* process commands from stdin */
+	while (strbuf_getline(&line, stdin) != EOF) {
+		char *cmd, *p1 = NULL, *p2 = NULL;
+		struct test_entry *entry;
+		struct object_id oid;
+
+		/* break line into command and up to two parameters */
+		cmd = strtok(line.buf, DELIM);
+		/* ignore empty lines */
+		if (!cmd || *cmd == '#')
+			continue;
+
+		p1 = strtok(NULL, DELIM);
+		if (p1)
+			p2 = strtok(NULL, DELIM);
+
+		if (!strcmp("put", cmd) && p1 && p2) {
+
+			if (get_oid(p1, &oid)) {
+				printf("Unknown oid: %s\n", p1);
+				continue;
+			}
+
+			/* create entry with oid_key = p1, name_value = p2 */
+			FLEX_ALLOC_STR(entry, name, p2);
+			oidcpy(&entry->entry.oid, &oid);
+
+			/* add / replace entry */
+			entry = oidmap_put(&map, entry);
+
+			/* print and free replaced entry, if any */
+			puts(entry ? entry->name : "NULL");
+			free(entry);
+
+		} else if (!strcmp("get", cmd) && p1) {
+
+			if (get_oid(p1, &oid)) {
+				printf("Unknown oid: %s\n", p1);
+				continue;
+			}
+
+			/* lookup entry in oidmap */
+			entry = oidmap_get(&map, &oid);
+
+			/* print result */
+			puts(entry ? entry->name : "NULL");
+
+		} else if (!strcmp("remove", cmd) && p1) {
+
+			if (get_oid(p1, &oid)) {
+				printf("Unknown oid: %s\n", p1);
+				continue;
+			}
+
+			/* remove entry from oidmap */
+			entry = oidmap_remove(&map, &oid);
+
+			/* print result and free entry*/
+			puts(entry ? entry->name : "NULL");
+			free(entry);
+
+		} else if (!strcmp("iterate", cmd)) {
+
+			struct oidmap_iter iter;
+			oidmap_iter_init(&map, &iter);
+			while ((entry = oidmap_iter_next(&iter)))
+				printf("%s %s\n", oid_to_hex(&entry->entry.oid), entry->name);
+
+		} else {
+
+			printf("Unknown command %s\n", cmd);
+
+		}
+	}
+
+	strbuf_release(&line);
+	oidmap_free(&map, 1);
+	return 0;
+}
diff -pruN 1.2.1+git2.18.0-1/git/t/helper/test-parse-options.c 1.2.3+git2.25.1-1/git/t/helper/test-parse-options.c
--- 1.2.1+git2.18.0-1/git/t/helper/test-parse-options.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/helper/test-parse-options.c	2020-02-17 04:47:35.000000000 +0000
@@ -1,6 +1,8 @@
+#include "test-tool.h"
 #include "cache.h"
 #include "parse-options.h"
 #include "string-list.h"
+#include "trace2.h"
 
 static int boolean = 0;
 static int integer = 0;
@@ -35,6 +37,7 @@ static int length_callback(const struct
 
 static int number_callback(const struct option *opt, const char *arg, int unset)
 {
+	BUG_ON_OPT_NEG(unset);
 	*(int *)opt->value = strtol(arg, NULL, 10);
 	return 0;
 }
@@ -94,11 +97,11 @@ static void show(struct string_list *exp
 	strbuf_release(&buf);
 }
 
-int cmd_main(int argc, const char **argv)
+int cmd__parse_options(int argc, const char **argv)
 {
 	const char *prefix = "prefix/";
 	const char *usage[] = {
-		"test-parse-options <options>",
+		"test-tool parse-options <options>",
 		"",
 		"A helper function for the parse-options API.",
 		NULL
@@ -118,7 +121,6 @@ int cmd_main(int argc, const char **argv
 		OPT_INTEGER('j', NULL, &integer, "get a integer, too"),
 		OPT_MAGNITUDE('m', "magnitude", &magnitude, "get a magnitude"),
 		OPT_SET_INT(0, "set23", &integer, "set integer to 23", 23),
-		OPT_DATE('t', NULL, &timestamp, "get timestamp of <time>"),
 		OPT_CALLBACK('L', "length", &integer, "str",
 			"get length of <str>", length_callback),
 		OPT_FILENAME('F', "file", &file, "set file to <file>"),
@@ -130,7 +132,7 @@ int cmd_main(int argc, const char **argv
 		OPT_NOOP_NOARG(0, "obsolete"),
 		OPT_STRING_LIST(0, "list", &list, "str", "add str to list"),
 		OPT_GROUP("Magic arguments"),
-		OPT_ARGUMENT("quux", "means --quux"),
+		OPT_ARGUMENT("quux", NULL, "means --quux"),
 		OPT_NUMBER_CALLBACK(&integer, "set integer to NUM",
 			number_callback),
 		{ OPTION_COUNTUP, '+', NULL, &boolean, NULL, "same as -b",
@@ -147,11 +149,16 @@ int cmd_main(int argc, const char **argv
 		OPT_CALLBACK(0, "expect", &expect, "string",
 			     "expected output in the variable dump",
 			     collect_expect),
+		OPT_GROUP("Alias"),
+		OPT_STRING('A', "alias-source", &string, "string", "get a string"),
+		OPT_ALIAS('Z', "alias-target", "alias-source"),
 		OPT_END(),
 	};
 	int i;
 	int ret = 0;
 
+	trace2_cmd_name("_parse_");
+
 	argc = parse_options(argc, (const char **)argv, prefix, options, usage, 0);
 
 	if (length_cb.called) {
diff -pruN 1.2.1+git2.18.0-1/git/t/helper/test-path-utils.c 1.2.3+git2.25.1-1/git/t/helper/test-path-utils.c
--- 1.2.1+git2.18.0-1/git/t/helper/test-path-utils.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/helper/test-path-utils.c	2020-02-17 04:47:35.000000000 +0000
@@ -177,6 +177,107 @@ static int is_dotgitmodules(const char *
 	return is_hfs_dotgitmodules(path) || is_ntfs_dotgitmodules(path);
 }
 
+static int cmp_by_st_size(const void *a, const void *b)
+{
+	intptr_t x = (intptr_t)((struct string_list_item *)a)->util;
+	intptr_t y = (intptr_t)((struct string_list_item *)b)->util;
+
+	return x > y ? -1 : (x < y ? +1 : 0);
+}
+
+/*
+ * A very simple, reproducible pseudo-random generator. Copied from
+ * `test-genrandom.c`.
+ */
+static uint64_t my_random_value = 1234;
+
+static uint64_t my_random(void)
+{
+	my_random_value = my_random_value * 1103515245 + 12345;
+	return my_random_value;
+}
+
+/*
+ * A fast approximation of the square root, without requiring math.h.
+ *
+ * It uses Newton's method to approximate the solution of 0 = x^2 - value.
+ */
+static double my_sqrt(double value)
+{
+	const double epsilon = 1e-6;
+	double x = value;
+
+	if (value == 0)
+		return 0;
+
+	for (;;) {
+		double delta = (value / x - x) / 2;
+		if (delta < epsilon && delta > -epsilon)
+			return x + delta;
+		x += delta;
+	}
+}
+
+static int protect_ntfs_hfs_benchmark(int argc, const char **argv)
+{
+	size_t i, j, nr, min_len = 3, max_len = 20;
+	char **names;
+	int repetitions = 15, file_mode = 0100644;
+	uint64_t begin, end;
+	double m[3][2], v[3][2];
+	uint64_t cumul;
+	double cumul2;
+
+	if (argc > 1 && !strcmp(argv[1], "--with-symlink-mode")) {
+		file_mode = 0120000;
+		argc--;
+		argv++;
+	}
+
+	nr = argc > 1 ? strtoul(argv[1], NULL, 0) : 1000000;
+	ALLOC_ARRAY(names, nr);
+
+	if (argc > 2) {
+		min_len = strtoul(argv[2], NULL, 0);
+		if (argc > 3)
+			max_len = strtoul(argv[3], NULL, 0);
+		if (min_len > max_len)
+			die("min_len > max_len");
+	}
+
+	for (i = 0; i < nr; i++) {
+		size_t len = min_len + (my_random() % (max_len + 1 - min_len));
+
+		names[i] = xmallocz(len);
+		while (len > 0)
+			names[i][--len] = (char)(' ' + (my_random() % ('\x7f' - ' ')));
+	}
+
+	for (protect_ntfs = 0; protect_ntfs < 2; protect_ntfs++)
+		for (protect_hfs = 0; protect_hfs < 2; protect_hfs++) {
+			cumul = 0;
+			cumul2 = 0;
+			for (i = 0; i < repetitions; i++) {
+				begin = getnanotime();
+				for (j = 0; j < nr; j++)
+					verify_path(names[j], file_mode);
+				end = getnanotime();
+				printf("protect_ntfs = %d, protect_hfs = %d: %lfms\n", protect_ntfs, protect_hfs, (end-begin) / (double)1e6);
+				cumul += end - begin;
+				cumul2 += (end - begin) * (end - begin);
+			}
+			m[protect_ntfs][protect_hfs] = cumul / (double)repetitions;
+			v[protect_ntfs][protect_hfs] = my_sqrt(cumul2 / (double)repetitions - m[protect_ntfs][protect_hfs] * m[protect_ntfs][protect_hfs]);
+			printf("mean: %lfms, stddev: %lfms\n", m[protect_ntfs][protect_hfs] / (double)1e6, v[protect_ntfs][protect_hfs] / (double)1e6);
+		}
+
+	for (protect_ntfs = 0; protect_ntfs < 2; protect_ntfs++)
+		for (protect_hfs = 0; protect_hfs < 2; protect_hfs++)
+			printf("ntfs=%d/hfs=%d: %lf%% slower\n", protect_ntfs, protect_hfs, (m[protect_ntfs][protect_hfs] - m[0][0]) * 100 / m[0][0]);
+
+	return 0;
+}
+
 int cmd__path_utils(int argc, const char **argv)
 {
 	if (argc == 3 && !strcmp(argv[1], "normalize_path_copy")) {
@@ -291,6 +392,82 @@ int cmd__path_utils(int argc, const char
 		return !!res;
 	}
 
+	if (argc > 2 && !strcmp(argv[1], "file-size")) {
+		int res = 0, i;
+		struct stat st;
+
+		for (i = 2; i < argc; i++)
+			if (stat(argv[i], &st))
+				res = error_errno("Cannot stat '%s'", argv[i]);
+			else
+				printf("%"PRIuMAX"\n", (uintmax_t)st.st_size);
+		return !!res;
+	}
+
+	if (argc == 4 && !strcmp(argv[1], "skip-n-bytes")) {
+		int fd = open(argv[2], O_RDONLY), offset = atoi(argv[3]);
+		char buffer[65536];
+
+		if (fd < 0)
+			die_errno("could not open '%s'", argv[2]);
+		if (lseek(fd, offset, SEEK_SET) < 0)
+			die_errno("could not skip %d bytes", offset);
+		for (;;) {
+			ssize_t count = read(fd, buffer, sizeof(buffer));
+			if (count < 0)
+				die_errno("could not read '%s'", argv[2]);
+			if (!count)
+				break;
+			if (write(1, buffer, count) < 0)
+				die_errno("could not write to stdout");
+		}
+		close(fd);
+		return 0;
+	}
+
+	if (argc > 5 && !strcmp(argv[1], "slice-tests")) {
+		int res = 0;
+		long offset, stride, i;
+		struct string_list list = STRING_LIST_INIT_NODUP;
+		struct stat st;
+
+		offset = strtol(argv[2], NULL, 10);
+		stride = strtol(argv[3], NULL, 10);
+		if (stride < 1)
+			stride = 1;
+		for (i = 4; i < argc; i++)
+			if (stat(argv[i], &st))
+				res = error_errno("Cannot stat '%s'", argv[i]);
+			else
+				string_list_append(&list, argv[i])->util =
+					(void *)(intptr_t)st.st_size;
+		QSORT(list.items, list.nr, cmp_by_st_size);
+		for (i = offset; i < list.nr; i+= stride)
+			printf("%s\n", list.items[i].string);
+
+		return !!res;
+	}
+
+	if (argc > 1 && !strcmp(argv[1], "protect_ntfs_hfs"))
+		return !!protect_ntfs_hfs_benchmark(argc - 1, argv + 1);
+
+	if (argc > 1 && !strcmp(argv[1], "is_valid_path")) {
+		int res = 0, expect = 1, i;
+
+		for (i = 2; i < argc; i++)
+			if (!strcmp("--not", argv[i]))
+				expect = 0;
+			else if (expect != is_valid_path(argv[i]))
+				res = error("'%s' is%s a valid path",
+					    argv[i], expect ? " not" : "");
+			else
+				fprintf(stderr,
+					"'%s' is%s a valid path\n",
+					argv[i], expect ? "" : " not");
+
+		return !!res;
+	}
+
 	fprintf(stderr, "%s: unknown function name: %s\n", argv[0],
 		argv[1] ? argv[1] : "(there was none)");
 	return 1;
diff -pruN 1.2.1+git2.18.0-1/git/t/helper/test-pkt-line.c 1.2.3+git2.25.1-1/git/t/helper/test-pkt-line.c
--- 1.2.1+git2.18.0-1/git/t/helper/test-pkt-line.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/helper/test-pkt-line.c	2020-02-17 04:47:35.000000000 +0000
@@ -1,3 +1,5 @@
+#include "cache.h"
+#include "test-tool.h"
 #include "pkt-line.h"
 
 static void pack_line(const char *line)
@@ -48,7 +50,37 @@ static void unpack(void)
 	}
 }
 
-int cmd_main(int argc, const char **argv)
+static void unpack_sideband(void)
+{
+	struct packet_reader reader;
+	packet_reader_init(&reader, 0, NULL, 0,
+			   PACKET_READ_GENTLE_ON_EOF |
+			   PACKET_READ_CHOMP_NEWLINE);
+
+	while (packet_reader_read(&reader) != PACKET_READ_EOF) {
+		int band;
+		int fd;
+
+		switch (reader.status) {
+		case PACKET_READ_EOF:
+			break;
+		case PACKET_READ_NORMAL:
+			band = reader.line[0] & 0xff;
+			if (band < 1 || band > 2)
+				die("unexpected side band %d", band);
+			fd = band;
+
+			write_or_die(fd, reader.line + 1, reader.pktlen - 1);
+			break;
+		case PACKET_READ_FLUSH:
+			return;
+		case PACKET_READ_DELIM:
+			break;
+		}
+	}
+}
+
+int cmd__pkt_line(int argc, const char **argv)
 {
 	if (argc < 2)
 		die("too few arguments");
@@ -57,6 +89,8 @@ int cmd_main(int argc, const char **argv
 		pack(argc - 2, argv + 2);
 	else if (!strcmp(argv[1], "unpack"))
 		unpack();
+	else if (!strcmp(argv[1], "unpack-sideband"))
+		unpack_sideband();
 	else
 		die("invalid argument '%s'", argv[1]);
 
diff -pruN 1.2.1+git2.18.0-1/git/t/helper/test-prio-queue.c 1.2.3+git2.25.1-1/git/t/helper/test-prio-queue.c
--- 1.2.1+git2.18.0-1/git/t/helper/test-prio-queue.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/helper/test-prio-queue.c	2020-02-17 04:47:35.000000000 +0000
@@ -22,15 +22,25 @@ int cmd__prio_queue(int argc, const char
 	struct prio_queue pq = { intcmp };
 
 	while (*++argv) {
-		if (!strcmp(*argv, "get"))
-			show(prio_queue_get(&pq));
-		else if (!strcmp(*argv, "dump")) {
-			int *v;
-			while ((v = prio_queue_get(&pq)))
-			       show(v);
-		}
-		else {
-			int *v = malloc(sizeof(*v));
+		if (!strcmp(*argv, "get")) {
+			void *peek = prio_queue_peek(&pq);
+			void *get = prio_queue_get(&pq);
+			if (peek != get)
+				BUG("peek and get results do not match");
+			show(get);
+		} else if (!strcmp(*argv, "dump")) {
+			void *peek;
+			void *get;
+			while ((peek = prio_queue_peek(&pq))) {
+				get = prio_queue_get(&pq);
+				if (peek != get)
+					BUG("peek and get results do not match");
+				show(get);
+			}
+		} else if (!strcmp(*argv, "stack")) {
+			pq.compare = NULL;
+		} else {
+			int *v = xmalloc(sizeof(*v));
 			*v = atoi(*argv);
 			prio_queue_put(&pq, v);
 		}
diff -pruN 1.2.1+git2.18.0-1/git/t/helper/test-progress.c 1.2.3+git2.25.1-1/git/t/helper/test-progress.c
--- 1.2.1+git2.18.0-1/git/t/helper/test-progress.c	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/helper/test-progress.c	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,81 @@
+/*
+ * A test helper to exercise the progress display.
+ *
+ * Reads instructions from standard input, one instruction per line:
+ *
+ *   "progress <items>" - Call display_progress() with the given item count
+ *                        as parameter.
+ *   "throughput <bytes> <millis> - Call display_throughput() with the given
+ *                                  byte count as parameter.  The 'millis'
+ *                                  specify the time elapsed since the
+ *                                  start_progress() call.
+ *   "update" - Set the 'progress_update' flag.
+ *
+ * See 't0500-progress-display.sh' for examples.
+ */
+#include "test-tool.h"
+#include "gettext.h"
+#include "parse-options.h"
+#include "progress.h"
+#include "strbuf.h"
+
+/*
+ * These are defined in 'progress.c', but are not exposed in 'progress.h',
+ * because they are exclusively for testing.
+ */
+extern int progress_testing;
+extern uint64_t progress_test_ns;
+void progress_test_force_update(void);
+
+int cmd__progress(int argc, const char **argv)
+{
+	int total = 0;
+	const char *title;
+	struct strbuf line = STRBUF_INIT;
+	struct progress *progress;
+
+	const char *usage[] = {
+		"test-tool progress [--total=<n>] <progress-title>",
+		NULL
+	};
+	struct option options[] = {
+		OPT_INTEGER(0, "total", &total, "total number of items"),
+		OPT_END(),
+	};
+
+	argc = parse_options(argc, argv, NULL, options, usage, 0);
+	if (argc != 1)
+		die("need a title for the progress output");
+	title = argv[0];
+
+	progress_testing = 1;
+	progress = start_progress(title, total);
+	while (strbuf_getline(&line, stdin) != EOF) {
+		char *end;
+
+		if (skip_prefix(line.buf, "progress ", (const char **) &end)) {
+			uint64_t item_count = strtoull(end, &end, 10);
+			if (*end != '\0')
+				die("invalid input: '%s'\n", line.buf);
+			display_progress(progress, item_count);
+		} else if (skip_prefix(line.buf, "throughput ",
+				       (const char **) &end)) {
+			uint64_t byte_count, test_ms;
+
+			byte_count = strtoull(end, &end, 10);
+			if (*end != ' ')
+				die("invalid input: '%s'\n", line.buf);
+			test_ms = strtoull(end + 1, &end, 10);
+			if (*end != '\0')
+				die("invalid input: '%s'\n", line.buf);
+			progress_test_ns = test_ms * 1000 * 1000;
+			display_throughput(progress, byte_count);
+		} else if (!strcmp(line.buf, "update"))
+			progress_test_force_update();
+		else
+			die("invalid input: '%s'\n", line.buf);
+	}
+	stop_progress(&progress);
+
+	return 0;
+}
diff -pruN 1.2.1+git2.18.0-1/git/t/helper/test-reach.c 1.2.3+git2.25.1-1/git/t/helper/test-reach.c
--- 1.2.1+git2.18.0-1/git/t/helper/test-reach.c	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/helper/test-reach.c	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,168 @@
+#include "test-tool.h"
+#include "cache.h"
+#include "commit.h"
+#include "commit-reach.h"
+#include "config.h"
+#include "parse-options.h"
+#include "ref-filter.h"
+#include "string-list.h"
+#include "tag.h"
+
+static void print_sorted_commit_ids(struct commit_list *list)
+{
+	int i;
+	struct string_list s = STRING_LIST_INIT_DUP;
+
+	while (list) {
+		string_list_append(&s, oid_to_hex(&list->item->object.oid));
+		list = list->next;
+	}
+
+	string_list_sort(&s);
+
+	for (i = 0; i < s.nr; i++)
+		printf("%s\n", s.items[i].string);
+
+	string_list_clear(&s, 0);
+}
+
+int cmd__reach(int ac, const char **av)
+{
+	struct object_id oid_A, oid_B;
+	struct commit *A, *B;
+	struct commit_list *X, *Y;
+	struct object_array X_obj = OBJECT_ARRAY_INIT;
+	struct commit **X_array, **Y_array;
+	int X_nr, X_alloc, Y_nr, Y_alloc;
+	struct strbuf buf = STRBUF_INIT;
+	struct repository *r = the_repository;
+
+	setup_git_directory();
+
+	if (ac < 2)
+		exit(1);
+
+	A = B = NULL;
+	X = Y = NULL;
+	X_nr = Y_nr = 0;
+	X_alloc = Y_alloc = 16;
+	ALLOC_ARRAY(X_array, X_alloc);
+	ALLOC_ARRAY(Y_array, Y_alloc);
+
+	while (strbuf_getline(&buf, stdin) != EOF) {
+		struct object_id oid;
+		struct object *orig;
+		struct object *peeled;
+		struct commit *c;
+		if (buf.len < 3)
+			continue;
+
+		if (get_oid_committish(buf.buf + 2, &oid))
+			die("failed to resolve %s", buf.buf + 2);
+
+		orig = parse_object(r, &oid);
+		peeled = deref_tag_noverify(orig);
+
+		if (!peeled)
+			die("failed to load commit for input %s resulting in oid %s\n",
+			    buf.buf, oid_to_hex(&oid));
+
+		c = object_as_type(r, peeled, OBJ_COMMIT, 0);
+
+		if (!c)
+			die("failed to load commit for input %s resulting in oid %s\n",
+			    buf.buf, oid_to_hex(&oid));
+
+		switch (buf.buf[0]) {
+			case 'A':
+				oidcpy(&oid_A, &oid);
+				A = c;
+				break;
+
+			case 'B':
+				oidcpy(&oid_B, &oid);
+				B = c;
+				break;
+
+			case 'X':
+				commit_list_insert(c, &X);
+				ALLOC_GROW(X_array, X_nr + 1, X_alloc);
+				X_array[X_nr++] = c;
+				add_object_array(orig, NULL, &X_obj);
+				break;
+
+			case 'Y':
+				commit_list_insert(c, &Y);
+				ALLOC_GROW(Y_array, Y_nr + 1, Y_alloc);
+				Y_array[Y_nr++] = c;
+				break;
+
+			default:
+				die("unexpected start of line: %c", buf.buf[0]);
+		}
+	}
+	strbuf_release(&buf);
+
+	if (!strcmp(av[1], "ref_newer"))
+		printf("%s(A,B):%d\n", av[1], ref_newer(&oid_A, &oid_B));
+	else if (!strcmp(av[1], "in_merge_bases"))
+		printf("%s(A,B):%d\n", av[1], in_merge_bases(A, B));
+	else if (!strcmp(av[1], "is_descendant_of"))
+		printf("%s(A,X):%d\n", av[1], is_descendant_of(A, X));
+	else if (!strcmp(av[1], "get_merge_bases_many")) {
+		struct commit_list *list = get_merge_bases_many(A, X_nr, X_array);
+		printf("%s(A,X):\n", av[1]);
+		print_sorted_commit_ids(list);
+	} else if (!strcmp(av[1], "reduce_heads")) {
+		struct commit_list *list = reduce_heads(X);
+		printf("%s(X):\n", av[1]);
+		print_sorted_commit_ids(list);
+	} else if (!strcmp(av[1], "can_all_from_reach")) {
+		printf("%s(X,Y):%d\n", av[1], can_all_from_reach(X, Y, 1));
+	} else if (!strcmp(av[1], "can_all_from_reach_with_flag")) {
+		struct commit_list *iter = Y;
+
+		while (iter) {
+			iter->item->object.flags |= 2;
+			iter = iter->next;
+		}
+
+		printf("%s(X,_,_,0,0):%d\n", av[1], can_all_from_reach_with_flag(&X_obj, 2, 4, 0, 0));
+	} else if (!strcmp(av[1], "commit_contains")) {
+		struct ref_filter filter;
+		struct contains_cache cache;
+		init_contains_cache(&cache);
+
+		if (ac > 2 && !strcmp(av[2], "--tag"))
+			filter.with_commit_tag_algo = 1;
+		else
+			filter.with_commit_tag_algo = 0;
+
+		printf("%s(_,A,X,_):%d\n", av[1], commit_contains(&filter, A, X, &cache));
+	} else if (!strcmp(av[1], "get_reachable_subset")) {
+		const int reachable_flag = 1;
+		int i, count = 0;
+		struct commit_list *current;
+		struct commit_list *list = get_reachable_subset(X_array, X_nr,
+								Y_array, Y_nr,
+								reachable_flag);
+		printf("get_reachable_subset(X,Y)\n");
+		for (current = list; current; current = current->next) {
+			if (!(list->item->object.flags & reachable_flag))
+				die(_("commit %s is not marked reachable"),
+				    oid_to_hex(&list->item->object.oid));
+			count++;
+		}
+		for (i = 0; i < Y_nr; i++) {
+			if (Y_array[i]->object.flags & reachable_flag)
+				count--;
+		}
+
+		if (count < 0)
+			die(_("too many commits marked reachable"));
+
+		print_sorted_commit_ids(list);
+	}
+
+	exit(0);
+}
diff -pruN 1.2.1+git2.18.0-1/git/t/helper/test-read-cache.c 1.2.3+git2.25.1-1/git/t/helper/test-read-cache.c
--- 1.2.1+git2.18.0-1/git/t/helper/test-read-cache.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/helper/test-read-cache.c	2020-02-17 04:47:35.000000000 +0000
@@ -1,14 +1,35 @@
 #include "test-tool.h"
 #include "cache.h"
+#include "config.h"
 
 int cmd__read_cache(int argc, const char **argv)
 {
 	int i, cnt = 1;
+	const char *name = NULL;
+
+	if (argc > 1 && skip_prefix(argv[1], "--print-and-refresh=", &name)) {
+		argc--;
+		argv++;
+	}
+
 	if (argc == 2)
 		cnt = strtol(argv[1], NULL, 0);
 	setup_git_directory();
+	git_config(git_default_config, NULL);
 	for (i = 0; i < cnt; i++) {
 		read_cache();
+		if (name) {
+			int pos;
+
+			refresh_index(&the_index, REFRESH_QUIET,
+				      NULL, NULL, NULL);
+			pos = index_name_pos(&the_index, name, strlen(name));
+			if (pos < 0)
+				die("%s not in index", name);
+			printf("%s is%s up to date\n", name,
+			       ce_uptodate(the_index.cache[pos]) ? "" : " not");
+			write_file(name, "%d\n", i);
+		}
 		discard_cache();
 	}
 	return 0;
diff -pruN 1.2.1+git2.18.0-1/git/t/helper/test-read-graph.c 1.2.3+git2.25.1-1/git/t/helper/test-read-graph.c
--- 1.2.1+git2.18.0-1/git/t/helper/test-read-graph.c	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/helper/test-read-graph.c	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,53 @@
+#include "test-tool.h"
+#include "cache.h"
+#include "commit-graph.h"
+#include "repository.h"
+#include "object-store.h"
+
+int cmd__read_graph(int argc, const char **argv)
+{
+	struct commit_graph *graph = NULL;
+	char *graph_name;
+	int open_ok;
+	int fd;
+	struct stat st;
+	const char *object_dir;
+
+	setup_git_directory();
+	object_dir = get_object_directory();
+
+	graph_name = get_commit_graph_filename(object_dir);
+
+	open_ok = open_commit_graph(graph_name, &fd, &st);
+	if (!open_ok)
+		die_errno(_("Could not open commit-graph '%s'"), graph_name);
+
+	graph = load_commit_graph_one_fd_st(fd, &st);
+	if (!graph)
+		return 1;
+
+	FREE_AND_NULL(graph_name);
+
+	printf("header: %08x %d %d %d %d\n",
+		ntohl(*(uint32_t*)graph->data),
+		*(unsigned char*)(graph->data + 4),
+		*(unsigned char*)(graph->data + 5),
+		*(unsigned char*)(graph->data + 6),
+		*(unsigned char*)(graph->data + 7));
+	printf("num_commits: %u\n", graph->num_commits);
+	printf("chunks:");
+
+	if (graph->chunk_oid_fanout)
+		printf(" oid_fanout");
+	if (graph->chunk_oid_lookup)
+		printf(" oid_lookup");
+	if (graph->chunk_commit_data)
+		printf(" commit_metadata");
+	if (graph->chunk_extra_edges)
+		printf(" extra_edges");
+	printf("\n");
+
+	UNLEAK(graph);
+
+	return 0;
+}
diff -pruN 1.2.1+git2.18.0-1/git/t/helper/test-read-midx.c 1.2.3+git2.25.1-1/git/t/helper/test-read-midx.c
--- 1.2.1+git2.18.0-1/git/t/helper/test-read-midx.c	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/helper/test-read-midx.c	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,51 @@
+#include "test-tool.h"
+#include "cache.h"
+#include "midx.h"
+#include "repository.h"
+#include "object-store.h"
+
+static int read_midx_file(const char *object_dir)
+{
+	uint32_t i;
+	struct multi_pack_index *m = load_multi_pack_index(object_dir, 1);
+
+	if (!m)
+		return 1;
+
+	printf("header: %08x %d %d %d\n",
+	       m->signature,
+	       m->version,
+	       m->num_chunks,
+	       m->num_packs);
+
+	printf("chunks:");
+
+	if (m->chunk_pack_names)
+		printf(" pack-names");
+	if (m->chunk_oid_fanout)
+		printf(" oid-fanout");
+	if (m->chunk_oid_lookup)
+		printf(" oid-lookup");
+	if (m->chunk_object_offsets)
+		printf(" object-offsets");
+	if (m->chunk_large_offsets)
+		printf(" large-offsets");
+
+	printf("\nnum_objects: %d\n", m->num_objects);
+
+	printf("packs:\n");
+	for (i = 0; i < m->num_packs; i++)
+		printf("%s\n", m->pack_names[i]);
+
+	printf("object-dir: %s\n", m->object_dir);
+
+	return 0;
+}
+
+int cmd__read_midx(int argc, const char **argv)
+{
+	if (argc != 2)
+		usage("read-midx <object-dir>");
+
+	return read_midx_file(argv[1]);
+}
diff -pruN 1.2.1+git2.18.0-1/git/t/helper/test-ref-store.c 1.2.3+git2.25.1-1/git/t/helper/test-ref-store.c
--- 1.2.1+git2.18.0-1/git/t/helper/test-ref-store.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/helper/test-ref-store.c	2020-02-17 04:47:35.000000000 +0000
@@ -233,7 +233,7 @@ static int cmd_update_ref(struct ref_sto
 {
 	const char *msg = notnull(*argv++, "msg");
 	const char *refname = notnull(*argv++, "refname");
-	const char *new_sha1_buf = notnull(*argv++, "old-sha1");
+	const char *new_sha1_buf = notnull(*argv++, "new-sha1");
 	const char *old_sha1_buf = notnull(*argv++, "old-sha1");
 	unsigned int flags = arg_flags(*argv++, "flags");
 	struct object_id old_oid;
diff -pruN 1.2.1+git2.18.0-1/git/t/helper/test-repository.c 1.2.3+git2.25.1-1/git/t/helper/test-repository.c
--- 1.2.1+git2.18.0-1/git/t/helper/test-repository.c	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/helper/test-repository.c	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,98 @@
+#include "test-tool.h"
+#include "cache.h"
+#include "commit-graph.h"
+#include "commit.h"
+#include "config.h"
+#include "object-store.h"
+#include "object.h"
+#include "repository.h"
+#include "tree.h"
+
+static void test_parse_commit_in_graph(const char *gitdir, const char *worktree,
+				       const struct object_id *commit_oid)
+{
+	struct repository r;
+	struct commit *c;
+	struct commit_list *parent;
+
+	setup_git_env(gitdir);
+
+	memset(the_repository, 0, sizeof(*the_repository));
+
+	/* TODO: Needed for temporary hack in hashcmp, see 183a638b7da. */
+	repo_set_hash_algo(the_repository, GIT_HASH_SHA1);
+
+	if (repo_init(&r, gitdir, worktree))
+		die("Couldn't init repo");
+
+	c = lookup_commit(&r, commit_oid);
+
+	if (!parse_commit_in_graph(&r, c))
+		die("Couldn't parse commit");
+
+	printf("%"PRItime, c->date);
+	for (parent = c->parents; parent; parent = parent->next)
+		printf(" %s", oid_to_hex(&parent->item->object.oid));
+	printf("\n");
+
+	repo_clear(&r);
+}
+
+static void test_get_commit_tree_in_graph(const char *gitdir,
+					  const char *worktree,
+					  const struct object_id *commit_oid)
+{
+	struct repository r;
+	struct commit *c;
+	struct tree *tree;
+
+	setup_git_env(gitdir);
+
+	memset(the_repository, 0, sizeof(*the_repository));
+
+	/* TODO: Needed for temporary hack in hashcmp, see 183a638b7da. */
+	repo_set_hash_algo(the_repository, GIT_HASH_SHA1);
+
+	if (repo_init(&r, gitdir, worktree))
+		die("Couldn't init repo");
+
+	c = lookup_commit(&r, commit_oid);
+
+	/*
+	 * get_commit_tree_in_graph does not automatically parse the commit, so
+	 * parse it first.
+	 */
+	if (!parse_commit_in_graph(&r, c))
+		die("Couldn't parse commit");
+	tree = get_commit_tree_in_graph(&r, c);
+	if (!tree)
+		die("Couldn't get commit tree");
+
+	printf("%s\n", oid_to_hex(&tree->object.oid));
+
+	repo_clear(&r);
+}
+
+int cmd__repository(int argc, const char **argv)
+{
+	if (argc < 2)
+		die("must have at least 2 arguments");
+	if (!strcmp(argv[1], "parse_commit_in_graph")) {
+		struct object_id oid;
+		if (argc < 5)
+			die("not enough arguments");
+		if (parse_oid_hex(argv[4], &oid, &argv[4]))
+			die("cannot parse oid '%s'", argv[4]);
+		test_parse_commit_in_graph(argv[2], argv[3], &oid);
+	} else if (!strcmp(argv[1], "get_commit_tree_in_graph")) {
+		struct object_id oid;
+		if (argc < 5)
+			die("not enough arguments");
+		if (parse_oid_hex(argv[4], &oid, &argv[4]))
+			die("cannot parse oid '%s'", argv[4]);
+		test_get_commit_tree_in_graph(argv[2], argv[3], &oid);
+	} else {
+		die("unrecognized '%s'", argv[1]);
+	}
+	return 0;
+}
diff -pruN 1.2.1+git2.18.0-1/git/t/helper/test-revision-walking.c 1.2.3+git2.25.1-1/git/t/helper/test-revision-walking.c
--- 1.2.1+git2.18.0-1/git/t/helper/test-revision-walking.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/helper/test-revision-walking.c	2020-02-17 04:47:35.000000000 +0000
@@ -32,7 +32,7 @@ static int run_revision_walk(void)
 	int argc = ARRAY_SIZE(argv) - 1;
 	int got_revision = 0;
 
-	init_revisions(&rev, NULL);
+	repo_init_revisions(the_repository, &rev, NULL);
 	setup_revisions(argc, argv, &rev, NULL);
 	if (prepare_revision_walk(&rev))
 		die("revision walk setup failed");
diff -pruN 1.2.1+git2.18.0-1/git/t/helper/test-run-command.c 1.2.3+git2.25.1-1/git/t/helper/test-run-command.c
--- 1.2.1+git2.18.0-1/git/t/helper/test-run-command.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/helper/test-run-command.c	2020-02-17 04:47:35.000000000 +0000
@@ -10,11 +10,16 @@
 
 #include "test-tool.h"
 #include "git-compat-util.h"
+#include "cache.h"
 #include "run-command.h"
 #include "argv-array.h"
 #include "strbuf.h"
-#include <string.h>
-#include <errno.h>
+#include "parse-options.h"
+#include "string-list.h"
+#include "thread-utils.h"
+#include "wildmatch.h"
+#include "gettext.h"
+#include "parse-options.h"
 
 static int number_callbacks;
 static int parallel_next(struct child_process *cp,
@@ -50,11 +55,337 @@ static int task_finished(int result,
 	return 1;
 }
 
+struct testsuite {
+	struct string_list tests, failed;
+	int next;
+	int quiet, immediate, verbose, verbose_log, trace, write_junit_xml;
+};
+#define TESTSUITE_INIT \
+	{ STRING_LIST_INIT_DUP, STRING_LIST_INIT_DUP, -1, 0, 0, 0, 0, 0, 0 }
+
+static int next_test(struct child_process *cp, struct strbuf *err, void *cb,
+		     void **task_cb)
+{
+	struct testsuite *suite = cb;
+	const char *test;
+	if (suite->next >= suite->tests.nr)
+		return 0;
+
+	test = suite->tests.items[suite->next++].string;
+	argv_array_pushl(&cp->args, "sh", test, NULL);
+	if (suite->quiet)
+		argv_array_push(&cp->args, "--quiet");
+	if (suite->immediate)
+		argv_array_push(&cp->args, "-i");
+	if (suite->verbose)
+		argv_array_push(&cp->args, "-v");
+	if (suite->verbose_log)
+		argv_array_push(&cp->args, "-V");
+	if (suite->trace)
+		argv_array_push(&cp->args, "-x");
+	if (suite->write_junit_xml)
+		argv_array_push(&cp->args, "--write-junit-xml");
+
+	strbuf_addf(err, "Output of '%s':\n", test);
+	*task_cb = (void *)test;
+
+	return 1;
+}
+
+static int test_finished(int result, struct strbuf *err, void *cb,
+			 void *task_cb)
+{
+	struct testsuite *suite = cb;
+	const char *name = (const char *)task_cb;
+
+	if (result)
+		string_list_append(&suite->failed, name);
+
+	strbuf_addf(err, "%s: '%s'\n", result ? "FAIL" : "SUCCESS", name);
+
+	return 0;
+}
+
+static int test_failed(struct strbuf *out, void *cb, void *task_cb)
+{
+	struct testsuite *suite = cb;
+	const char *name = (const char *)task_cb;
+
+	string_list_append(&suite->failed, name);
+	strbuf_addf(out, "FAILED TO START: '%s'\n", name);
+
+	return 0;
+}
+
+static const char * const testsuite_usage[] = {
+	"test-run-command testsuite [<options>] [<pattern>...]",
+	NULL
+};
+
+static int testsuite(int argc, const char **argv)
+{
+	struct testsuite suite = TESTSUITE_INIT;
+	int max_jobs = 1, i, ret;
+	DIR *dir;
+	struct dirent *d;
+	struct option options[] = {
+		OPT_BOOL('i', "immediate", &suite.immediate,
+			 "stop at first failed test case(s)"),
+		OPT_INTEGER('j', "jobs", &max_jobs, "run <N> jobs in parallel"),
+		OPT_BOOL('q', "quiet", &suite.quiet, "be terse"),
+		OPT_BOOL('v', "verbose", &suite.verbose, "be verbose"),
+		OPT_BOOL('V', "verbose-log", &suite.verbose_log,
+			 "be verbose, redirected to a file"),
+		OPT_BOOL('x', "trace", &suite.trace, "trace shell commands"),
+		OPT_BOOL(0, "write-junit-xml", &suite.write_junit_xml,
+			 "write JUnit-style XML files"),
+		OPT_END()
+	};
+
+	memset(&suite, 0, sizeof(suite));
+	suite.tests.strdup_strings = suite.failed.strdup_strings = 1;
+
+	argc = parse_options(argc, argv, NULL, options,
+			testsuite_usage, PARSE_OPT_STOP_AT_NON_OPTION);
+
+	if (max_jobs <= 0)
+		max_jobs = online_cpus();
+
+	dir = opendir(".");
+	if (!dir)
+		die("Could not open the current directory");
+	while ((d = readdir(dir))) {
+		const char *p = d->d_name;
+
+		if (*p != 't' || !isdigit(p[1]) || !isdigit(p[2]) ||
+		    !isdigit(p[3]) || !isdigit(p[4]) || p[5] != '-' ||
+		    !ends_with(p, ".sh"))
+			continue;
+
+		/* No pattern: match all */
+		if (!argc) {
+			string_list_append(&suite.tests, p);
+			continue;
+		}
+
+		for (i = 0; i < argc; i++)
+			if (!wildmatch(argv[i], p, 0)) {
+				string_list_append(&suite.tests, p);
+				break;
+			}
+	}
+	closedir(dir);
+
+	if (!suite.tests.nr)
+		die("No tests match!");
+	if (max_jobs > suite.tests.nr)
+		max_jobs = suite.tests.nr;
+
+	fprintf(stderr, "Running %d tests (%d at a time)\n",
+		suite.tests.nr, max_jobs);
+
+	ret = run_processes_parallel(max_jobs, next_test, test_failed,
+				     test_finished, &suite);
+
+	if (suite.failed.nr > 0) {
+		ret = 1;
+		fprintf(stderr, "%d tests failed:\n\n", suite.failed.nr);
+		for (i = 0; i < suite.failed.nr; i++)
+			fprintf(stderr, "\t%s\n", suite.failed.items[i].string);
+	}
+
+	string_list_clear(&suite.tests, 0);
+	string_list_clear(&suite.failed, 0);
+
+	return !!ret;
+}
+
+static uint64_t my_random_next = 1234;
+
+static uint64_t my_random(void)
+{
+	uint64_t res = my_random_next;
+	my_random_next = my_random_next * 1103515245 + 12345;
+	return res;
+}
+
+static int quote_stress_test(int argc, const char **argv)
+{
+	/*
+	 * We are running a quote-stress test.
+	 * spawn a subprocess that runs quote-stress with a
+	 * special option that echoes back the arguments that
+	 * were passed in.
+	 */
+	char special[] = ".?*\\^_\"'`{}()[]<>@~&+:;$%"; // \t\r\n\a";
+	int i, j, k, trials = 100, skip = 0, msys2 = 0;
+	struct strbuf out = STRBUF_INIT;
+	struct argv_array args = ARGV_ARRAY_INIT;
+	struct option options[] = {
+		OPT_INTEGER('n', "trials", &trials, "Number of trials"),
+		OPT_INTEGER('s', "skip", &skip, "Skip <n> trials"),
+		OPT_BOOL('m', "msys2", &msys2, "Test quoting for MSYS2's sh"),
+		OPT_END()
+	};
+	const char * const usage[] = {
+		"test-tool run-command quote-stress-test <options>",
+		NULL
+	};
+
+	argc = parse_options(argc, argv, NULL, options, usage, 0);
+
+	setenv("MSYS_NO_PATHCONV", "1", 0);
+
+	for (i = 0; i < trials; i++) {
+		struct child_process cp = CHILD_PROCESS_INIT;
+		size_t arg_count, arg_offset;
+		int ret = 0;
+
+		argv_array_clear(&args);
+		if (msys2)
+			argv_array_pushl(&args, "sh", "-c",
+					 "printf %s\\\\0 \"$@\"", "skip", NULL);
+		else
+			argv_array_pushl(&args, "test-tool", "run-command",
+					 "quote-echo", NULL);
+		arg_offset = args.argc;
+
+		if (argc > 0) {
+			trials = 1;
+			arg_count = argc;
+			for (j = 0; j < arg_count; j++)
+				argv_array_push(&args, argv[j]);
+		} else {
+			arg_count = 1 + (my_random() % 5);
+			for (j = 0; j < arg_count; j++) {
+				char buf[20];
+				size_t min_len = 1;
+				size_t arg_len = min_len +
+					(my_random() % (ARRAY_SIZE(buf) - min_len));
+
+				for (k = 0; k < arg_len; k++)
+					buf[k] = special[my_random() %
+						ARRAY_SIZE(special)];
+				buf[arg_len] = '\0';
+
+				argv_array_push(&args, buf);
+			}
+		}
+
+		if (i < skip)
+			continue;
+
+		cp.argv = args.argv;
+		strbuf_reset(&out);
+		if (pipe_command(&cp, NULL, 0, &out, 0, NULL, 0) < 0)
+			return error("Failed to spawn child process");
+
+		for (j = 0, k = 0; j < arg_count; j++) {
+			const char *arg = args.argv[j + arg_offset];
+
+			if (strcmp(arg, out.buf + k))
+				ret = error("incorrectly quoted arg: '%s', "
+					    "echoed back as '%s'",
+					     arg, out.buf + k);
+			k += strlen(out.buf + k) + 1;
+		}
+
+		if (k != out.len)
+			ret = error("got %d bytes, but consumed only %d",
+				     (int)out.len, (int)k);
+
+		if (ret) {
+			fprintf(stderr, "Trial #%d failed. Arguments:\n", i);
+			for (j = 0; j < arg_count; j++)
+				fprintf(stderr, "arg #%d: '%s'\n",
+					(int)j, args.argv[j + arg_offset]);
+
+			strbuf_release(&out);
+			argv_array_clear(&args);
+
+			return ret;
+		}
+
+		if (i && (i % 100) == 0)
+			fprintf(stderr, "Trials completed: %d\n", (int)i);
+	}
+
+	strbuf_release(&out);
+	argv_array_clear(&args);
+
+	return 0;
+}
+
+static int quote_echo(int argc, const char **argv)
+{
+	while (argc > 1) {
+		fwrite(argv[1], strlen(argv[1]), 1, stdout);
+		fputc('\0', stdout);
+		argv++;
+		argc--;
+	}
+
+	return 0;
+}
+
+static int inherit_handle(const char *argv0)
+{
+	struct child_process cp = CHILD_PROCESS_INIT;
+	char path[PATH_MAX];
+	int tmp;
+
+	/* First, open an inheritable handle */
+	xsnprintf(path, sizeof(path), "out-XXXXXX");
+	tmp = xmkstemp(path);
+
+	argv_array_pushl(&cp.args,
+			 "test-tool", argv0, "inherited-handle-child", NULL);
+	cp.in = -1;
+	cp.no_stdout = cp.no_stderr = 1;
+	if (start_command(&cp) < 0)
+		die("Could not start child process");
+
+	/* Then close it, and try to delete it. */
+	close(tmp);
+	if (unlink(path))
+		die("Could not delete '%s'", path);
+
+	if (close(cp.in) < 0 || finish_command(&cp) < 0)
+		die("Child did not finish");
+
+	return 0;
+}
+
+static int inherit_handle_child(void)
+{
+	struct strbuf buf = STRBUF_INIT;
+
+	if (strbuf_read(&buf, 0, 0) < 0)
+		die("Could not read stdin");
+	printf("Received %s\n", buf.buf);
+	strbuf_release(&buf);
+
+	return 0;
+}
+
 int cmd__run_command(int argc, const char **argv)
 {
 	struct child_process proc = CHILD_PROCESS_INIT;
 	int jobs;
 
+	if (argc > 1 && !strcmp(argv[1], "testsuite"))
+		exit(testsuite(argc - 1, argv + 1));
+	if (!strcmp(argv[1], "inherited-handle"))
+		exit(inherit_handle(argv[0]));
+	if (!strcmp(argv[1], "inherited-handle-child"))
+		exit(inherit_handle_child());
+
+	if (argc >= 2 && !strcmp(argv[1], "quote-stress-test"))
+		return !!quote_stress_test(argc - 1, argv + 1);
+
+	if (argc >= 2 && !strcmp(argv[1], "quote-echo"))
+		return !!quote_echo(argc - 1, argv + 1);
+
 	if (argc < 3)
 		return 1;
 	while (!strcmp(argv[1], "env")) {
diff -pruN 1.2.1+git2.18.0-1/git/t/helper/test-serve-v2.c 1.2.3+git2.25.1-1/git/t/helper/test-serve-v2.c
--- 1.2.1+git2.18.0-1/git/t/helper/test-serve-v2.c	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/helper/test-serve-v2.c	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,31 @@
+#include "test-tool.h"
+#include "cache.h"
+#include "parse-options.h"
+#include "serve.h"
+
+static char const * const serve_usage[] = {
+	N_("test-tool serve-v2 [<options>]"),
+	NULL
+};
+
+int cmd__serve_v2(int argc, const char **argv)
+{
+	struct serve_options opts = SERVE_OPTIONS_INIT;
+
+	struct option options[] = {
+		OPT_BOOL(0, "stateless-rpc", &opts.stateless_rpc,
+			 N_("quit after a single request/response exchange")),
+		OPT_BOOL(0, "advertise-capabilities", &opts.advertise_capabilities,
+			 N_("exit immediately after advertising capabilities")),
+		OPT_END()
+	};
+	const char *prefix = setup_git_directory();
+
+	/* ignore all unknown cmdline switches for now */
+	argc = parse_options(argc, argv, prefix, options, serve_usage,
+			     PARSE_OPT_KEEP_DASHDASH |
+			     PARSE_OPT_KEEP_UNKNOWN);
+	serve(&opts);
+
+	return 0;
+}
diff -pruN 1.2.1+git2.18.0-1/git/t/helper/test-sha1.c 1.2.3+git2.25.1-1/git/t/helper/test-sha1.c
--- 1.2.1+git2.18.0-1/git/t/helper/test-sha1.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/helper/test-sha1.c	2020-02-17 04:47:35.000000000 +0000
@@ -3,55 +3,5 @@
 
 int cmd__sha1(int ac, const char **av)
 {
-	git_SHA_CTX ctx;
-	unsigned char sha1[20];
-	unsigned bufsz = 8192;
-	int binary = 0;
-	char *buffer;
-
-	if (ac == 2) {
-		if (!strcmp(av[1], "-b"))
-			binary = 1;
-		else
-			bufsz = strtoul(av[1], NULL, 10) * 1024 * 1024;
-	}
-
-	if (!bufsz)
-		bufsz = 8192;
-
-	while ((buffer = malloc(bufsz)) == NULL) {
-		fprintf(stderr, "bufsz %u is too big, halving...\n", bufsz);
-		bufsz /= 2;
-		if (bufsz < 1024)
-			die("OOPS");
-	}
-
-	git_SHA1_Init(&ctx);
-
-	while (1) {
-		ssize_t sz, this_sz;
-		char *cp = buffer;
-		unsigned room = bufsz;
-		this_sz = 0;
-		while (room) {
-			sz = xread(0, cp, room);
-			if (sz == 0)
-				break;
-			if (sz < 0)
-				die_errno("test-sha1");
-			this_sz += sz;
-			cp += sz;
-			room -= sz;
-		}
-		if (this_sz == 0)
-			break;
-		git_SHA1_Update(&ctx, buffer, this_sz);
-	}
-	git_SHA1_Final(sha1, &ctx);
-
-	if (binary)
-		fwrite(sha1, 1, 20, stdout);
-	else
-		puts(sha1_to_hex(sha1));
-	exit(0);
+	return cmd_hash_impl(ac, av, GIT_HASH_SHA1);
 }
diff -pruN 1.2.1+git2.18.0-1/git/t/helper/test-sha256.c 1.2.3+git2.25.1-1/git/t/helper/test-sha256.c
--- 1.2.1+git2.18.0-1/git/t/helper/test-sha256.c	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/helper/test-sha256.c	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,7 @@
+#include "test-tool.h"
+#include "cache.h"
+
+int cmd__sha256(int ac, const char **av)
+{
+	return cmd_hash_impl(ac, av, GIT_HASH_SHA256);
+}
diff -pruN 1.2.1+git2.18.0-1/git/t/helper/test-sigchain.c 1.2.3+git2.25.1-1/git/t/helper/test-sigchain.c
--- 1.2.1+git2.18.0-1/git/t/helper/test-sigchain.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/helper/test-sigchain.c	2020-02-17 04:47:35.000000000 +0000
@@ -14,7 +14,8 @@ X(two)
 X(three)
 #undef X
 
-int cmd__sigchain(int argc, const char **argv) {
+int cmd__sigchain(int argc, const char **argv)
+{
 	sigchain_push(SIGTERM, one);
 	sigchain_push(SIGTERM, two);
 	sigchain_push(SIGTERM, three);
diff -pruN 1.2.1+git2.18.0-1/git/t/helper/test-submodule-nested-repo-config.c 1.2.3+git2.25.1-1/git/t/helper/test-submodule-nested-repo-config.c
--- 1.2.1+git2.18.0-1/git/t/helper/test-submodule-nested-repo-config.c	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/helper/test-submodule-nested-repo-config.c	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,32 @@
+#include "test-tool.h"
+#include "submodule-config.h"
+
+static void die_usage(int argc, const char **argv, const char *msg)
+{
+	fprintf(stderr, "%s\n", msg);
+	fprintf(stderr, "Usage: %s <submodulepath> <config name>\n", argv[0]);
+	exit(1);
+}
+
+int cmd__submodule_nested_repo_config(int argc, const char **argv)
+{
+	struct repository subrepo;
+	const struct submodule *sub;
+
+	if (argc < 3)
+		die_usage(argc, argv, "Wrong number of arguments.");
+
+	setup_git_directory();
+
+	sub = submodule_from_path(the_repository, &null_oid, argv[1]);
+	if (repo_submodule_init(&subrepo, the_repository, sub)) {
+		die_usage(argc, argv, "Submodule not found.");
+	}
+
+	/* Read the config of _child_ submodules. */
+	print_config_from_gitmodules(&subrepo, argv[2]);
+
+	submodule_free(the_repository);
+
+	return 0;
+}
diff -pruN 1.2.1+git2.18.0-1/git/t/helper/test-tool.c 1.2.3+git2.25.1-1/git/t/helper/test-tool.c
--- 1.2.1+git2.18.0-1/git/t/helper/test-tool.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/helper/test-tool.c	2020-02-17 04:47:35.000000000 +0000
@@ -1,5 +1,12 @@
 #include "git-compat-util.h"
 #include "test-tool.h"
+#include "trace2.h"
+#include "parse-options.h"
+
+static const char * const test_tool_usage[] = {
+	"test-tool [-C <directory>] <command [<arguments>...]]",
+	NULL
+};
 
 struct test_cmd {
 	const char *name;
@@ -12,52 +19,100 @@ static struct test_cmd cmds[] = {
 	{ "ctype", cmd__ctype },
 	{ "date", cmd__date },
 	{ "delta", cmd__delta },
+	{ "dir-iterator", cmd__dir_iterator },
 	{ "drop-caches", cmd__drop_caches },
 	{ "dump-cache-tree", cmd__dump_cache_tree },
+	{ "dump-fsmonitor", cmd__dump_fsmonitor },
 	{ "dump-split-index", cmd__dump_split_index },
+	{ "dump-untracked-cache", cmd__dump_untracked_cache },
 	{ "example-decorate", cmd__example_decorate },
 	{ "genrandom", cmd__genrandom },
+	{ "genzeros", cmd__genzeros },
 	{ "hashmap", cmd__hashmap },
+	{ "hash-speed", cmd__hash_speed },
 	{ "index-version", cmd__index_version },
+	{ "json-writer", cmd__json_writer },
 	{ "lazy-init-name-hash", cmd__lazy_init_name_hash },
 	{ "match-trees", cmd__match_trees },
 	{ "mergesort", cmd__mergesort },
 	{ "mktemp", cmd__mktemp },
+	{ "oidmap", cmd__oidmap },
 	{ "online-cpus", cmd__online_cpus },
+	{ "parse-options", cmd__parse_options },
 	{ "path-utils", cmd__path_utils },
+	{ "pkt-line", cmd__pkt_line },
 	{ "prio-queue", cmd__prio_queue },
+	{ "progress", cmd__progress },
+	{ "reach", cmd__reach },
 	{ "read-cache", cmd__read_cache },
+	{ "read-graph", cmd__read_graph },
+	{ "read-midx", cmd__read_midx },
 	{ "ref-store", cmd__ref_store },
 	{ "regex", cmd__regex },
+	{ "repository", cmd__repository },
 	{ "revision-walking", cmd__revision_walking },
 	{ "run-command", cmd__run_command },
 	{ "scrap-cache-tree", cmd__scrap_cache_tree },
-	{ "sha1-array", cmd__sha1_array },
+	{ "serve-v2", cmd__serve_v2 },
 	{ "sha1", cmd__sha1 },
+	{ "sha1-array", cmd__sha1_array },
+	{ "sha256", cmd__sha256 },
 	{ "sigchain", cmd__sigchain },
 	{ "strcmp-offset", cmd__strcmp_offset },
 	{ "string-list", cmd__string_list },
 	{ "submodule-config", cmd__submodule_config },
+	{ "submodule-nested-repo-config", cmd__submodule_nested_repo_config },
 	{ "subprocess", cmd__subprocess },
+	{ "trace2", cmd__trace2 },
 	{ "urlmatch-normalization", cmd__urlmatch_normalization },
+	{ "xml-encode", cmd__xml_encode },
 	{ "wildmatch", cmd__wildmatch },
+#ifdef GIT_WINDOWS_NATIVE
+	{ "windows-named-pipe", cmd__windows_named_pipe },
+#endif
 	{ "write-cache", cmd__write_cache },
 };
 
+static NORETURN void die_usage(void)
+{
+	size_t i;
+
+	fprintf(stderr, "usage: test-tool <toolname> [args]\n");
+	for (i = 0; i < ARRAY_SIZE(cmds); i++)
+		fprintf(stderr, "  %s\n", cmds[i].name);
+	exit(128);
+}
+
 int cmd_main(int argc, const char **argv)
 {
 	int i;
+	const char *working_directory = NULL;
+	struct option options[] = {
+		OPT_STRING('C', NULL, &working_directory, "directory",
+			   "change the working directory"),
+		OPT_END()
+	};
 
 	BUG_exit_code = 99;
+	argc = parse_options(argc, argv, NULL, options, test_tool_usage,
+			     PARSE_OPT_STOP_AT_NON_OPTION |
+			     PARSE_OPT_KEEP_ARGV0);
+
 	if (argc < 2)
-		die("I need a test name!");
+		die_usage();
+
+	if (working_directory && chdir(working_directory) < 0)
+		die("Could not cd to '%s'", working_directory);
 
 	for (i = 0; i < ARRAY_SIZE(cmds); i++) {
 		if (!strcmp(cmds[i].name, argv[1])) {
 			argv++;
 			argc--;
+			trace2_cmd_name(cmds[i].name);
+			trace2_cmd_list_config();
 			return cmds[i].fn(argc, argv);
 		}
 	}
-	die("There is no test named '%s'", argv[1]);
+	error("there is no tool named '%s'", argv[1]);
+	die_usage();
 }
diff -pruN 1.2.1+git2.18.0-1/git/t/helper/test-tool.h 1.2.3+git2.25.1-1/git/t/helper/test-tool.h
--- 1.2.1+git2.18.0-1/git/t/helper/test-tool.h	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/helper/test-tool.h	2020-02-17 04:47:35.000000000 +0000
@@ -1,40 +1,67 @@
-#ifndef __TEST_TOOL_H__
-#define __TEST_TOOL_H__
+#ifndef TEST_TOOL_H
+#define TEST_TOOL_H
+
+#define USE_THE_INDEX_COMPATIBILITY_MACROS
+#include "git-compat-util.h"
 
 int cmd__chmtime(int argc, const char **argv);
 int cmd__config(int argc, const char **argv);
 int cmd__ctype(int argc, const char **argv);
 int cmd__date(int argc, const char **argv);
 int cmd__delta(int argc, const char **argv);
+int cmd__dir_iterator(int argc, const char **argv);
 int cmd__drop_caches(int argc, const char **argv);
 int cmd__dump_cache_tree(int argc, const char **argv);
+int cmd__dump_fsmonitor(int argc, const char **argv);
 int cmd__dump_split_index(int argc, const char **argv);
+int cmd__dump_untracked_cache(int argc, const char **argv);
 int cmd__example_decorate(int argc, const char **argv);
 int cmd__genrandom(int argc, const char **argv);
+int cmd__genzeros(int argc, const char **argv);
 int cmd__hashmap(int argc, const char **argv);
+int cmd__hash_speed(int argc, const char **argv);
 int cmd__index_version(int argc, const char **argv);
+int cmd__json_writer(int argc, const char **argv);
 int cmd__lazy_init_name_hash(int argc, const char **argv);
 int cmd__match_trees(int argc, const char **argv);
 int cmd__mergesort(int argc, const char **argv);
 int cmd__mktemp(int argc, const char **argv);
+int cmd__oidmap(int argc, const char **argv);
 int cmd__online_cpus(int argc, const char **argv);
+int cmd__parse_options(int argc, const char **argv);
 int cmd__path_utils(int argc, const char **argv);
+int cmd__pkt_line(int argc, const char **argv);
 int cmd__prio_queue(int argc, const char **argv);
+int cmd__progress(int argc, const char **argv);
+int cmd__reach(int argc, const char **argv);
 int cmd__read_cache(int argc, const char **argv);
+int cmd__read_graph(int argc, const char **argv);
+int cmd__read_midx(int argc, const char **argv);
 int cmd__ref_store(int argc, const char **argv);
 int cmd__regex(int argc, const char **argv);
+int cmd__repository(int argc, const char **argv);
 int cmd__revision_walking(int argc, const char **argv);
 int cmd__run_command(int argc, const char **argv);
 int cmd__scrap_cache_tree(int argc, const char **argv);
-int cmd__sha1_array(int argc, const char **argv);
+int cmd__serve_v2(int argc, const char **argv);
 int cmd__sha1(int argc, const char **argv);
+int cmd__sha1_array(int argc, const char **argv);
+int cmd__sha256(int argc, const char **argv);
 int cmd__sigchain(int argc, const char **argv);
 int cmd__strcmp_offset(int argc, const char **argv);
 int cmd__string_list(int argc, const char **argv);
 int cmd__submodule_config(int argc, const char **argv);
+int cmd__submodule_nested_repo_config(int argc, const char **argv);
 int cmd__subprocess(int argc, const char **argv);
+int cmd__trace2(int argc, const char **argv);
 int cmd__urlmatch_normalization(int argc, const char **argv);
+int cmd__xml_encode(int argc, const char **argv);
 int cmd__wildmatch(int argc, const char **argv);
+#ifdef GIT_WINDOWS_NATIVE
+int cmd__windows_named_pipe(int argc, const char **argv);
+#endif
 int cmd__write_cache(int argc, const char **argv);
 
+int cmd_hash_impl(int ac, const char **av, int algo);
+
 #endif
diff -pruN 1.2.1+git2.18.0-1/git/t/helper/test-trace2.c 1.2.3+git2.25.1-1/git/t/helper/test-trace2.c
--- 1.2.1+git2.18.0-1/git/t/helper/test-trace2.c	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/helper/test-trace2.c	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,273 @@
+#include "test-tool.h"
+#include "cache.h"
+#include "argv-array.h"
+#include "run-command.h"
+#include "exec-cmd.h"
+#include "config.h"
+
+typedef int(fn_unit_test)(int argc, const char **argv);
+
+struct unit_test {
+	fn_unit_test *ut_fn;
+	const char *ut_name;
+	const char *ut_usage;
+};
+
+#define MyOk 0
+#define MyError 1
+
+static int get_i(int *p_value, const char *data)
+{
+	char *endptr;
+
+	if (!data || !*data)
+		return MyError;
+
+	*p_value = strtol(data, &endptr, 10);
+	if (*endptr || errno == ERANGE)
+		return MyError;
+
+	return MyOk;
+}
+
+/*
+ * Cause process to exit with the requested value via "return".
+ *
+ * Rely on test-tool.c:cmd_main() to call trace2_cmd_exit()
+ * with our result.
+ *
+ * Test harness can confirm:
+ * [] the process-exit value.
+ * [] the "code" field in the "exit" trace2 event.
+ * [] the "code" field in the "atexit" trace2 event.
+ * [] the "name" field in the "cmd_name" trace2 event.
+ * [] "def_param" events for all of the "interesting" pre-defined
+ * config settings.
+ */
+static int ut_001return(int argc, const char **argv)
+{
+	int rc;
+
+	if (get_i(&rc, argv[0]))
+		die("expect <exit_code>");
+
+	return rc;
+}
+
+/*
+ * Cause the process to exit with the requested value via "exit()".
+ *
+ * Test harness can confirm:
+ * [] the "code" field in the "exit" trace2 event.
+ * [] the "code" field in the "atexit" trace2 event.
+ * [] the "name" field in the "cmd_name" trace2 event.
+ * [] "def_param" events for all of the "interesting" pre-defined
+ * config settings.
+ */
+static int ut_002exit(int argc, const char **argv)
+{
+	int rc;
+
+	if (get_i(&rc, argv[0]))
+		die("expect <exit_code>");
+
+	exit(rc);
+}
+
+/*
+ * Send an "error" event with each value in argv.  Normally, git only issues
+ * a single "error" event immediately before issuing an "exit" event (such
+ * as in die() or BUG()), but multiple "error" events are allowed.
+ *
+ * Test harness can confirm:
+ * [] a trace2 "error" event for each value in argv.
+ * [] the "name" field in the "cmd_name" trace2 event.
+ * [] (optional) the file:line in the "exit" event refers to this function.
+ */
+static int ut_003error(int argc, const char **argv)
+{
+	int k;
+
+	if (!argv[0] || !*argv[0])
+		die("expect <error_message>");
+
+	for (k = 0; k < argc; k++)
+		error("%s", argv[k]);
+
+	return 0;
+}
+
+/*
+ * Run a child process and wait for it to finish and exit with its return code.
+ * test-tool trace2 004child [<child-command-line>]
+ *
+ * For example:
+ * test-tool trace2 004child git version
+ * test-tool trace2 004child test-tool trace2 001return 0
+ * test-tool trace2 004child test-tool trace2 004child test-tool trace2 004child
+ * test-tool trace2 004child git -c alias.xyz=version xyz
+ *
+ * Test harness can confirm:
+ * [] the "name" field in the "cmd_name" trace2 event.
+ * [] that the outer process has a single component SID (or depth "d0" in
+ *    the PERF stream).
+ * [] that "child_start" and "child_exit" events are generated for the child.
+ * [] if the child process is an instrumented executable:
+ *    [] that "version", "start", ..., "exit", and "atexit" events are
+ *       generated by the child process.
+ *    [] that the child process events have a multiple component SID (or
+ *       depth "dN+1" in the PERF stream).
+ * [] that the child exit code is propagated to the parent process "exit"
+ *    and "atexit" events..
+ * [] (optional) that the "t_abs" field in the child process "atexit" event
+ *    is less than the "t_rel" field in the "child_exit" event of the parent
+ *    process.
+ * [] if the child process is like the alias example above,
+ *    [] (optional) the child process attempts to run "git-xyx" as a dashed
+ *       command.
+ *    [] the child process emits an "alias" event with "xyz" => "version"
+ *    [] the child process runs "git version" as a child process.
+ *    [] the child process has a 3 component SID (or depth "d2" in the PERF
+ *       stream).
+ */
+static int ut_004child(int argc, const char **argv)
+{
+	int result;
+
+	/*
+	 * Allow empty <child_command_line> so we can do arbitrarily deep
+	 * command nesting and let the last one be null.
+	 */
+	if (!argc)
+		return 0;
+
+	result = run_command_v_opt(argv, 0);
+	exit(result);
+}
+
+/*
+ * Exec a git command.  This may either create a child process (Windows)
+ * or replace the existing process.
+ * test-tool trace2 005exec <git_command_args>
+ *
+ * For example:
+ * test-tool trace2 005exec version
+ *
+ * Test harness can confirm (on Windows):
+ * [] the "name" field in the "cmd_name" trace2 event.
+ * [] that the outer process has a single component SID (or depth "d0" in
+ *    the PERF stream).
+ * [] that "exec" and "exec_result" events are generated for the child
+ *    process (since the Windows compatibility layer fakes an exec() with
+ *    a CreateProcess(), WaitForSingleObject(), and exit()).
+ * [] that the child process has multiple component SID (or depth "dN+1"
+ *    in the PERF stream).
+ *
+ * Test harness can confirm (on platforms with a real exec() function):
+ * [] TODO talk about process replacement and how it affects SID.
+ */
+static int ut_005exec(int argc, const char **argv)
+{
+	int result;
+
+	if (!argc)
+		return 0;
+
+	result = execv_git_cmd(argv);
+	return result;
+}
+
+static int ut_006data(int argc, const char **argv)
+{
+	const char *usage_error =
+		"expect <cat0> <k0> <v0> [<cat1> <k1> <v1> [...]]";
+
+	if (argc % 3 != 0)
+		die("%s", usage_error);
+
+	while (argc) {
+		if (!argv[0] || !*argv[0] || !argv[1] || !*argv[1] ||
+		    !argv[2] || !*argv[2])
+			die("%s", usage_error);
+
+		trace2_data_string(argv[0], the_repository, argv[1], argv[2]);
+		argv += 3;
+		argc -= 3;
+	}
+
+	return 0;
+}
+
+/*
+ * Usage:
+ *     test-tool trace2 <ut_name_1> <ut_usage_1>
+ *     test-tool trace2 <ut_name_2> <ut_usage_2>
+ *     ...
+ */
+#define USAGE_PREFIX "test-tool trace2"
+
+/* clang-format off */
+static struct unit_test ut_table[] = {
+	{ ut_001return,   "001return", "<exit_code>" },
+	{ ut_002exit,     "002exit",   "<exit_code>" },
+	{ ut_003error,    "003error",  "<error_message>+" },
+	{ ut_004child,    "004child",  "[<child_command_line>]" },
+	{ ut_005exec,     "005exec",   "<git_command_args>" },
+	{ ut_006data,     "006data",   "[<category> <key> <value>]+" },
+};
+/* clang-format on */
+
+/* clang-format off */
+#define for_each_ut(k, ut_k)			\
+	for (k = 0, ut_k = &ut_table[k];	\
+	     k < ARRAY_SIZE(ut_table);		\
+	     k++, ut_k = &ut_table[k])
+/* clang-format on */
+
+static int print_usage(void)
+{
+	int k;
+	struct unit_test *ut_k;
+
+	fprintf(stderr, "usage:\n");
+	for_each_ut (k, ut_k)
+		fprintf(stderr, "\t%s %s %s\n", USAGE_PREFIX, ut_k->ut_name,
+			ut_k->ut_usage);
+
+	return 129;
+}
+
+/*
+ * Issue various trace2 events for testing.
+ *
+ * We assume that these trace2 routines has already been called:
+ *    [] trace2_initialize()      [common-main.c:main()]
+ *    [] trace2_cmd_start()       [common-main.c:main()]
+ *    [] trace2_cmd_name()        [test-tool.c:cmd_main()]
+ *    [] tracd2_cmd_list_config() [test-tool.c:cmd_main()]
+ * So that:
+ *    [] the various trace2 streams are open.
+ *    [] the process SID has been created.
+ *    [] the "version" event has been generated.
+ *    [] the "start" event has been generated.
+ *    [] the "cmd_name" event has been generated.
+ *    [] this writes various "def_param" events for interesting config values.
+ *
+ * We further assume that if we return (rather than exit()), trace2_cmd_exit()
+ * will be called by test-tool.c:cmd_main().
+ */
+int cmd__trace2(int argc, const char **argv)
+{
+	int k;
+	struct unit_test *ut_k;
+
+	argc--; /* skip over "trace2" arg */
+	argv++;
+
+	if (argc)
+		for_each_ut (k, ut_k)
+			if (!strcmp(argv[0], ut_k->ut_name))
+				return ut_k->ut_fn(argc - 1, argv + 1);
+
+	return print_usage();
+}
diff -pruN 1.2.1+git2.18.0-1/git/t/helper/test-windows-named-pipe.c 1.2.3+git2.25.1-1/git/t/helper/test-windows-named-pipe.c
--- 1.2.1+git2.18.0-1/git/t/helper/test-windows-named-pipe.c	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/helper/test-windows-named-pipe.c	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,72 @@
+#include "test-tool.h"
+#include "git-compat-util.h"
+#include "strbuf.h"
+
+#ifdef GIT_WINDOWS_NATIVE
+static const char *usage_string = "<pipe-filename>";
+
+#define TEST_BUFSIZE (4096)
+
+int cmd__windows_named_pipe(int argc, const char **argv)
+{
+	const char *filename;
+	struct strbuf pathname = STRBUF_INIT;
+	int err;
+	HANDLE h;
+	BOOL connected;
+	char buf[TEST_BUFSIZE + 1];
+
+	if (argc < 2)
+		goto print_usage;
+	filename = argv[1];
+	if (strchr(filename, '/') || strchr(filename, '\\'))
+		goto print_usage;
+	strbuf_addf(&pathname, "//./pipe/%s", filename);
+
+	/*
+	 * Create a single instance of the server side of the named pipe.
+	 * This will allow exactly one client instance to connect to it.
+	 */
+	h = CreateNamedPipeA(
+		pathname.buf,
+		PIPE_ACCESS_INBOUND | FILE_FLAG_FIRST_PIPE_INSTANCE,
+		PIPE_TYPE_MESSAGE | PIPE_READMODE_MESSAGE | PIPE_WAIT,
+		PIPE_UNLIMITED_INSTANCES,
+		TEST_BUFSIZE, TEST_BUFSIZE, 0, NULL);
+	if (h == INVALID_HANDLE_VALUE) {
+		err = err_win_to_posix(GetLastError());
+		fprintf(stderr, "CreateNamedPipe failed: %s\n",
+			strerror(err));
+		return err;
+	}
+
+	connected = ConnectNamedPipe(h, NULL)
+		? TRUE
+		: (GetLastError() == ERROR_PIPE_CONNECTED);
+	if (!connected) {
+		err = err_win_to_posix(GetLastError());
+		fprintf(stderr, "ConnectNamedPipe failed: %s\n",
+			strerror(err));
+		CloseHandle(h);
+		return err;
+	}
+
+	while (1) {
+		DWORD nbr;
+		BOOL success = ReadFile(h, buf, TEST_BUFSIZE, &nbr, NULL);
+		if (!success || nbr == 0)
+			break;
+		buf[nbr] = 0;
+
+		write(1, buf, nbr);
+	}
+
+	DisconnectNamedPipe(h);
+	CloseHandle(h);
+	return 0;
+
+print_usage:
+	fprintf(stderr, "usage: %s %s\n", argv[0], usage_string);
+	return 1;
+}
+#endif
diff -pruN 1.2.1+git2.18.0-1/git/t/helper/test-xml-encode.c 1.2.3+git2.25.1-1/git/t/helper/test-xml-encode.c
--- 1.2.1+git2.18.0-1/git/t/helper/test-xml-encode.c	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/helper/test-xml-encode.c	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,80 @@
+#include "test-tool.h"
+
+static const char *utf8_replace_character = "&#xfffd;";
+
+/*
+ * Encodes (possibly incorrect) UTF-8 on <stdin> to <stdout>, to be embedded
+ * in an XML file.
+ */
+int cmd__xml_encode(int argc, const char **argv)
+{
+	unsigned char buf[1024], tmp[4], *tmp2 = NULL;
+	ssize_t cur = 0, len = 1, remaining = 0;
+	unsigned char ch;
+
+	for (;;) {
+		if (++cur == len) {
+			len = xread(0, buf, sizeof(buf));
+			if (!len)
+				return 0;
+			if (len < 0)
+				die_errno("Could not read <stdin>");
+			cur = 0;
+		}
+		ch = buf[cur];
+
+		if (tmp2) {
+			if ((ch & 0xc0) != 0x80) {
+				fputs(utf8_replace_character, stdout);
+				tmp2 = NULL;
+				cur--;
+				continue;
+			}
+			*tmp2 = ch;
+			tmp2++;
+			if (--remaining == 0) {
+				fwrite(tmp, tmp2 - tmp, 1, stdout);
+				tmp2 = NULL;
+			}
+			continue;
+		}
+
+		if (!(ch & 0x80)) {
+			/* 0xxxxxxx */
+			if (ch == '&')
+				fputs("&amp;", stdout);
+			else if (ch == '\'')
+				fputs("&apos;", stdout);
+			else if (ch == '"')
+				fputs("&quot;", stdout);
+			else if (ch == '<')
+				fputs("&lt;", stdout);
+			else if (ch == '>')
+				fputs("&gt;", stdout);
+			else if (ch >= 0x20)
+				fputc(ch, stdout);
+			else if (ch == 0x09 || ch == 0x0a || ch == 0x0d)
+				fprintf(stdout, "&#x%02x;", ch);
+			else
+				fputs(utf8_replace_character, stdout);
+		} else if ((ch & 0xe0) == 0xc0) {
+			/* 110XXXXx 10xxxxxx */
+			tmp[0] = ch;
+			remaining = 1;
+			tmp2 = tmp + 1;
+		} else if ((ch & 0xf0) == 0xe0) {
+			/* 1110XXXX 10Xxxxxx 10xxxxxx */
+			tmp[0] = ch;
+			remaining = 2;
+			tmp2 = tmp + 1;
+		} else if ((ch & 0xf8) == 0xf0) {
+			/* 11110XXX 10XXxxxx 10xxxxxx 10xxxxxx */
+			tmp[0] = ch;
+			remaining = 3;
+			tmp2 = tmp + 1;
+		} else
+			fputs(utf8_replace_character, stdout);
+	}
+
+	return 0;
+}
diff -pruN 1.2.1+git2.18.0-1/git/t/interop/i5500-git-daemon.sh 1.2.3+git2.25.1-1/git/t/interop/i5500-git-daemon.sh
--- 1.2.1+git2.18.0-1/git/t/interop/i5500-git-daemon.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/interop/i5500-git-daemon.sh	2020-02-17 04:47:35.000000000 +0000
@@ -37,5 +37,4 @@ test_expect_success "fetch with $VERSION
 	test_cmp expect actual
 '
 
-stop_git_daemon
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/lib-bash.sh 1.2.3+git2.25.1-1/git/t/lib-bash.sh
--- 1.2.1+git2.18.0-1/git/t/lib-bash.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/lib-bash.sh	2020-02-17 04:47:35.000000000 +0000
@@ -2,10 +2,12 @@
 # to run under Bash; primarily intended for tests of the completion
 # script.
 
-if test -n "$BASH" && test -z "$POSIXLY_CORRECT"; then
+if test -n "$BASH" && test -z "$POSIXLY_CORRECT"
+then
 	# we are in full-on bash mode
 	true
-elif type bash >/dev/null 2>&1; then
+elif type bash >/dev/null 2>&1
+then
 	# execute in full-on bash mode
 	unset POSIXLY_CORRECT
 	exec bash "$0" "$@"
diff -pruN 1.2.1+git2.18.0-1/git/t/lib-gettext.sh 1.2.3+git2.25.1-1/git/t/lib-gettext.sh
--- 1.2.1+git2.18.0-1/git/t/lib-gettext.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/lib-gettext.sh	2020-02-17 04:47:35.000000000 +0000
@@ -10,9 +10,14 @@ GIT_TEXTDOMAINDIR="$GIT_BUILD_DIR/po/bui
 GIT_PO_PATH="$GIT_BUILD_DIR/po"
 export GIT_TEXTDOMAINDIR GIT_PO_PATH
 
-. "$GIT_BUILD_DIR"/git-sh-i18n
+if test -n "$GIT_TEST_INSTALLED"
+then
+	. "$(git --exec-path)"/git-sh-i18n
+else
+	. "$GIT_BUILD_DIR"/git-sh-i18n
+fi
 
-if test_have_prereq GETTEXT && ! test_have_prereq GETTEXT_POISON
+if test_have_prereq GETTEXT && test_have_prereq C_LOCALE_OUTPUT
 then
 	# is_IS.UTF-8 on Solaris and FreeBSD, is_IS.utf8 on Debian
 	is_IS_locale=$(locale -a 2>/dev/null |
diff -pruN 1.2.1+git2.18.0-1/git/t/lib-git-daemon.sh 1.2.3+git2.25.1-1/git/t/lib-git-daemon.sh
--- 1.2.1+git2.18.0-1/git/t/lib-git-daemon.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/lib-git-daemon.sh	2020-02-17 04:47:35.000000000 +0000
@@ -13,11 +13,9 @@
 #
 #	test_expect_success ...
 #
-#	stop_git_daemon
 #	test_done
 
-test_tristate GIT_TEST_GIT_DAEMON
-if test "$GIT_TEST_GIT_DAEMON" = false
+if ! test_bool_env GIT_TEST_GIT_DAEMON true
 then
 	skip_all="git-daemon testing disabled (unset GIT_TEST_GIT_DAEMON to enable)"
 	test_done
@@ -25,16 +23,18 @@ fi
 
 if test_have_prereq !PIPE
 then
-	test_skip_or_die $GIT_TEST_GIT_DAEMON "file system does not support FIFOs"
+	test_skip_or_die GIT_TEST_GIT_DAEMON "file system does not support FIFOs"
 fi
 
-LIB_GIT_DAEMON_PORT=${LIB_GIT_DAEMON_PORT-${this_test#t}}
+test_set_port LIB_GIT_DAEMON_PORT
 
 GIT_DAEMON_PID=
+GIT_DAEMON_PIDFILE="$PWD"/daemon.pid
 GIT_DAEMON_DOCUMENT_ROOT_PATH="$PWD"/repo
 GIT_DAEMON_HOST_PORT=127.0.0.1:$LIB_GIT_DAEMON_PORT
 GIT_DAEMON_URL=git://$GIT_DAEMON_HOST_PORT
 
+registered_stop_git_daemon_atexit_handler=
 start_git_daemon() {
 	if test -n "$GIT_DAEMON_PID"
 	then
@@ -43,38 +43,36 @@ start_git_daemon() {
 
 	mkdir -p "$GIT_DAEMON_DOCUMENT_ROOT_PATH"
 
-	trap 'code=$?; stop_git_daemon; (exit $code); die' EXIT
+	# One of the test scripts stops and then re-starts 'git daemon'.
+	# Don't register and then run the same atexit handlers several times.
+	if test -z "$registered_stop_git_daemon_atexit_handler"
+	then
+		test_atexit 'stop_git_daemon'
+		registered_stop_git_daemon_atexit_handler=AlreadyDone
+	fi
 
 	say >&3 "Starting git daemon ..."
 	mkfifo git_daemon_output
 	${LIB_GIT_DAEMON_COMMAND:-git daemon} \
 		--listen=127.0.0.1 --port="$LIB_GIT_DAEMON_PORT" \
-		--reuseaddr --verbose \
+		--reuseaddr --verbose --pid-file="$GIT_DAEMON_PIDFILE" \
 		--base-path="$GIT_DAEMON_DOCUMENT_ROOT_PATH" \
 		"$@" "$GIT_DAEMON_DOCUMENT_ROOT_PATH" \
 		>&3 2>git_daemon_output &
 	GIT_DAEMON_PID=$!
-	>daemon.log
 	{
 		read -r line <&7
-		printf "%s\n" "$line"
-		printf >&4 "%s\n" "$line"
-		(
-			while read -r line <&7
-			do
-				printf "%s\n" "$line"
-				printf >&4 "%s\n" "$line"
-			done
-		) &
-	} 7<git_daemon_output >>"$TRASH_DIRECTORY/daemon.log" &&
+		printf "%s\n" "$line" >&4
+		cat <&7 >&4 &
+	} 7<git_daemon_output &&
 
 	# Check expected output
 	if test x"$(expr "$line" : "\[[0-9]*\] \(.*\)")" != x"Ready to rumble"
 	then
 		kill "$GIT_DAEMON_PID"
 		wait "$GIT_DAEMON_PID"
-		trap 'die' EXIT
-		test_skip_or_die $GIT_TEST_GIT_DAEMON \
+		unset GIT_DAEMON_PID
+		test_skip_or_die GIT_TEST_GIT_DAEMON \
 			"git daemon failed to start"
 	fi
 }
@@ -85,19 +83,18 @@ stop_git_daemon() {
 		return
 	fi
 
-	trap 'die' EXIT
-
 	# kill git-daemon child of git
 	say >&3 "Stopping git daemon ..."
 	kill "$GIT_DAEMON_PID"
 	wait "$GIT_DAEMON_PID" >&3 2>&4
 	ret=$?
-	if test_match_signal 15 $?
+	if ! test_match_signal 15 $ret
 	then
 		error "git daemon exited with status: $ret"
 	fi
+	kill "$(cat "$GIT_DAEMON_PIDFILE")" 2>/dev/null
 	GIT_DAEMON_PID=
-	rm -f git_daemon_output
+	rm -f git_daemon_output "$GIT_DAEMON_PIDFILE"
 }
 
 # A stripped-down version of a netcat client, that connects to a "host:port"
diff -pruN 1.2.1+git2.18.0-1/git/t/lib-git-p4.sh 1.2.3+git2.25.1-1/git/t/lib-git-p4.sh
--- 1.2.1+git2.18.0-1/git/t/lib-git-p4.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/lib-git-p4.sh	2020-02-17 04:47:35.000000000 +0000
@@ -44,23 +44,7 @@ native_path () {
 	echo "$path"
 }
 
-# On Solaris the 'date +%s' function is not supported and therefore we
-# need this replacement.
-# Attention: This function is not safe again against time offset updates
-# at runtime (e.g. via NTP). The 'clock_gettime(CLOCK_MONOTONIC)'
-# function could fix that but it is not in Python until 3.3.
-time_in_seconds () {
-	(cd / && "$PYTHON_PATH" -c 'import time; print(int(time.time()))')
-}
-
-# Try to pick a unique port: guess a large number, then hope
-# no more than one of each test is running.
-#
-# This does not handle the case where somebody else is running the
-# same tests and has chosen the same ports.
-testid=${this_test#t}
-git_p4_test_start=9800
-P4DPORT=$((10669 + ($testid - $git_p4_test_start)))
+test_set_port P4DPORT
 
 P4PORT=localhost:$P4DPORT
 P4CLIENT=client
@@ -74,14 +58,9 @@ cli="$TRASH_DIRECTORY/cli"
 git="$TRASH_DIRECTORY/git"
 pidfile="$TRASH_DIRECTORY/p4d.pid"
 
-# Sometimes "prove" seems to hang on exit because p4d is still running
-cleanup () {
-	if test -f "$pidfile"
-	then
-		kill -9 $(cat "$pidfile") 2>/dev/null && exit 255
-	fi
+stop_p4d_and_watchdog () {
+	kill -9 $p4d_pid $watchdog_pid
 }
-trap cleanup EXIT
 
 # git p4 submit generates a temp file, which will
 # not get cleaned up if the submission fails.  Don't
@@ -89,7 +68,16 @@ trap cleanup EXIT
 TMPDIR="$TRASH_DIRECTORY"
 export TMPDIR
 
+registered_stop_p4d_atexit_handler=
 start_p4d () {
+	# One of the test scripts stops and then re-starts p4d.
+	# Don't register and then run the same atexit handlers several times.
+	if test -z "$registered_stop_p4d_atexit_handler"
+	then
+		test_atexit 'stop_p4d_and_watchdog'
+		registered_stop_p4d_atexit_handler=AlreadyDone
+	fi
+
 	mkdir -p "$db" "$cli" "$git" &&
 	rm -f "$pidfile" &&
 	(
@@ -99,6 +87,7 @@ start_p4d () {
 			echo $! >"$pidfile"
 		}
 	) &&
+	p4d_pid=$(cat "$pidfile")
 
 	# This gives p4d a long time to start up, as it can be
 	# quite slow depending on the machine.  Set this environment
@@ -106,18 +95,18 @@ start_p4d () {
 	# an automated test setup.  If the p4d process dies, that
 	# will be caught with the "kill -0" check below.
 	i=${P4D_START_PATIENCE:-300}
-	pid=$(cat "$pidfile")
 
-	timeout=$(($(time_in_seconds) + $P4D_TIMEOUT))
+	nr_tries_left=$P4D_TIMEOUT
 	while true
 	do
-		if test $(time_in_seconds) -gt $timeout
+		if test $nr_tries_left -eq 0
 		then
-			kill -9 $pid
+			kill -9 $p4d_pid
 			exit 1
 		fi
 		sleep 1
-	done &
+		nr_tries_left=$(($nr_tries_left - 1))
+	done 2>/dev/null 4>&2 &
 	watchdog_pid=$!
 
 	ready=
@@ -130,7 +119,7 @@ start_p4d () {
 			break
 		fi
 		# fail if p4d died
-		kill -0 $pid 2>/dev/null || break
+		kill -0 $p4d_pid 2>/dev/null || break
 		echo waiting for p4d to start
 		sleep 1
 		i=$(( $i - 1 ))
@@ -170,29 +159,18 @@ p4_add_job () {
 }
 
 retry_until_success () {
-	timeout=$(($(time_in_seconds) + $RETRY_TIMEOUT))
-	until "$@" 2>/dev/null || test $(time_in_seconds) -gt $timeout
-	do
-		sleep 1
-	done
-}
-
-retry_until_fail () {
-	timeout=$(($(time_in_seconds) + $RETRY_TIMEOUT))
-	until ! "$@" 2>/dev/null || test $(time_in_seconds) -gt $timeout
+	nr_tries_left=$RETRY_TIMEOUT
+	until "$@" 2>/dev/null || test $nr_tries_left -eq 0
 	do
 		sleep 1
+		nr_tries_left=$(($nr_tries_left - 1))
 	done
 }
 
-kill_p4d () {
-	pid=$(cat "$pidfile")
-	retry_until_fail kill $pid
-	retry_until_fail kill -9 $pid
-	# complain if it would not die
-	test_must_fail kill $pid >/dev/null 2>&1 &&
-	rm -rf "$db" "$cli" "$pidfile" &&
-	retry_until_fail kill -9 $watchdog_pid
+stop_and_cleanup_p4d () {
+	kill -9 $p4d_pid $watchdog_pid
+	wait $p4d_pid
+	rm -rf "$db" "$cli" "$pidfile"
 }
 
 cleanup_git () {
diff -pruN 1.2.1+git2.18.0-1/git/t/lib-git-svn.sh 1.2.3+git2.25.1-1/git/t/lib-git-svn.sh
--- 1.2.1+git2.18.0-1/git/t/lib-git-svn.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/lib-git-svn.sh	2020-02-17 04:47:35.000000000 +0000
@@ -13,6 +13,7 @@ fi
 GIT_DIR=$PWD/.git
 GIT_SVN_DIR=$GIT_DIR/svn/refs/remotes/git-svn
 SVN_TREE=$GIT_SVN_DIR/svn-tree
+test_set_port SVNSERVE_PORT
 
 svn >/dev/null 2>&1
 if test $? -ne 1
@@ -68,19 +69,12 @@ svn_cmd () {
 maybe_start_httpd () {
 	loc=${1-svn}
 
-	test_tristate GIT_SVN_TEST_HTTPD
-	case $GIT_SVN_TEST_HTTPD in
-	true)
+	if test_bool_env GIT_TEST_SVN_HTTPD false
+	then
 		. "$TEST_DIRECTORY"/lib-httpd.sh
 		LIB_HTTPD_SVN="$loc"
 		start_httpd
-		;;
-	*)
-		stop_httpd () {
-			: noop
-		}
-		;;
-	esac
+	fi
 }
 
 convert_to_rev_db () {
@@ -110,8 +104,7 @@ EOF
 }
 
 require_svnserve () {
-	test_tristate GIT_TEST_SVNSERVE
-	if ! test "$GIT_TEST_SVNSERVE" = true
+	if ! test_bool_env GIT_TEST_SVNSERVE false
 	then
 		skip_all='skipping svnserve test. (set $GIT_TEST_SVNSERVE to enable)'
 		test_done
@@ -119,7 +112,6 @@ require_svnserve () {
 }
 
 start_svnserve () {
-	SVNSERVE_PORT=${SVNSERVE_PORT-${this_test#t}}
 	svnserve --listen-port $SVNSERVE_PORT \
 		 --root "$rawsvnrepo" \
 		 --listen-once \
Binary files 1.2.1+git2.18.0-1/git/t/lib-gpg/gpgsm_cert.p12 and 1.2.3+git2.25.1-1/git/t/lib-gpg/gpgsm_cert.p12 differ
diff -pruN 1.2.1+git2.18.0-1/git/t/lib-gpg/gpgsm-gen-key.in 1.2.3+git2.25.1-1/git/t/lib-gpg/gpgsm-gen-key.in
--- 1.2.1+git2.18.0-1/git/t/lib-gpg/gpgsm-gen-key.in	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/lib-gpg/gpgsm-gen-key.in	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,8 @@
+Key-Type: RSA
+Key-Length: 2048
+Key-Usage: sign
+Serial: random
+Name-DN: CN=C O Mitter, O=Example, SN=C O, GN=Mitter
+Name-Email: committer@example.com
+Not-Before: 1970-01-01 00:00:00
+Not-After: 3000-01-01 00:00:00
diff -pruN 1.2.1+git2.18.0-1/git/t/lib-gpg/keyring.gpg 1.2.3+git2.25.1-1/git/t/lib-gpg/keyring.gpg
--- 1.2.1+git2.18.0-1/git/t/lib-gpg/keyring.gpg	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/lib-gpg/keyring.gpg	2020-02-17 04:47:35.000000000 +0000
@@ -30,7 +30,6 @@ Cezx4Q2khACcCs+/LtE8Lb9hC+2cvr3uH5p82AI=
 =aEiU
 -----END PGP PRIVATE KEY BLOCK-----
 -----BEGIN PGP PRIVATE KEY BLOCK-----
-Version: GnuPG v1
 
 lQOYBFFMlkcBCADJi/xnAF8yI34PHilSCbM7VtOFO17oFMkpu4cgN2QpPuM5MVjy
 cvrzKSguZFvPCDLzeAFJW1uPxL4SHaHSkisCrFhijH7OJWcOPNPSFCwu+inAoAsv
@@ -83,11 +82,43 @@ fn1sY/IG5atoKK+ypmV/TlBlMZqFQzuPIJQT8VLb
 ZKLy5nTTSy16ztqEeS7eifHLPZg1UFFyEEIQ1XW0CNDAeuWKh90ERjyl4Cg7PnWS
 Z9Ei+zj6JD5Pcdi3BJhQo9WOLOVEJ0NHmewTYqk9QVXH/0v1Hdl4LMJtgcbdbDWk
 4UTkXbg9pn3umCgkNJ3Vs8fWnIWO9Izdr2/wrFY2JvUT7Yvl+wsNIWatvOEzGy7n
-BOW78WUxzhu0YJTLKy+iKCjg5HS5dx6OC+e4aEEgfhNPCMkbvDsJjtQ=
-=hieJ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+=Iv7W
 -----END PGP PRIVATE KEY BLOCK-----
 -----BEGIN PGP PUBLIC KEY BLOCK-----
-Version: GnuPG v1
 
 mQGiBEZnyykRBACzCPjIpTYNL7Y2tQqlEGTTDlvZcWNLjF5f7ZzuyOqNOidLUgFD
 36qch1LZLSZkShdR3Gae+bsolyjxrlFuFP0eXRPMtqK20aLw7WZvPFpEV1ThMne+
@@ -137,6 +168,25 @@ bGPyBuWraCivsqZlf05QZTGahUM7jyCUE/FS25sb
 8uZ000stes7ahHku3onxyz2YNVBRchBCENV1tAjQwHrliofdBEY8peAoOz51kmfR
 Ivs4+iQ+T3HYtwSYUKPVjizlRCdDR5nsE2KpPUFVx/9L9R3ZeCzCbYHG3Ww1pOFE
 5F24PaZ97pgoJDSd1bPH1pyFjvSM3a9v8KxWNib1E+2L5fsLDSFmrbzhMxsu5wTl
-u/FlMc4btGCUyysvoigo4OR0uXcejgvnuGhBIH4TTwjJG7w7CY7U
-=iYv/
+u/FlMc4btGCUyysvoigo4OR0uXcejgvnuGhBIH4TTwjJG7w7CY7UuQENBFveu9wB
+CACo7Hk9LE0I8jd/Xzp9H88VqfPURDFFCoC4oG9NTCrrjSN3HnQWbM94aRTilXIo
+ua5XcPLn98ktzpIbdg3xz0g+DaxsyxhM0k6UNdEvDdqtA1GMMi1OgtFPB5zGZv5/
+pQhgW1KMb567qIQLygI6Rzt65ifA+A3vYZVoP38HQMUENEr3tJDfFcJNqdRrjjlk
+CldUlPXPpAYqLu3XsEJm4pT0Wpypj+WUlOHpoaUzjJSRVxfpJmEjg0JNXDL1ljm9
+7bZZdpZV9Brpe0o3/oWqvxXEckZO08OTB8GY6+Wlogp8tP9Pm8r3xekgSH88hKpc
+llEUNoB2VKkoht0DzGYmK9OHABEBAAGJAmwEGAEIACAWIQTUviIxGtMTHl7aKaRh
+CS6FtyJxiQUCW9673AIbAgFACRBhCS6FtyJxicB0IAQZAQgAHRYhBPg2Slngf/6f
+TWMAWmWg7qAuMMrXBQJb3rvcAAoJEGWg7qAuMMrXA/YH/1ooLR5e5RcpfEWhP7qk
+ThRHpWcjNNL9YeeX3fyBkRvPBLTdC6+BWqgaj5DGY1PyzfVDAWk3fu+PLx5R2sHm
+apY1ybvfQjvSHe2OMO1sxdwt2MkLBmfdhBsbYbDytPq4R1dDG2iDbqSNaDvYAExY
+JUsate6PNxSWrRkY2lwmWrvI6+e/wctTBrY5PiKtTZMxpK1++/C3UUBiyg8NkGu5
+bHR2PHd5VDwB/Jm2/exC5iHPbTxtmjOwEyS+5wZhbkx6OoZhHCMN9hIvSitc8TNG
+cpRGJIwYxwJZJVpim/TImsjAubh1uyMoY5fjW4GyBK9iU2plv/bS+lKyCMYgxHam
+hzXwmgf/Q/ld9VKXKIXPWs8AeABfHYkMLeZ34laZ1Xhf1vPnktQctlukK8CzbYTU
+Wm2BZ7kn/VEhwGOmrQ1nvnoCHTCyL+HHtIt8pKHM0rtKDKFAjMXZfZEK7DR2Qqll
+/zogwy0m9Obvz/94XvdNMurUgdeTGyDwOouQcP+vd5x4LqsUtQEmwQfy4iLt7wl3
+RRLPUTLyCfqpD98UAPeqCJkIikd1Ojhr+fd3jjSoo1CDTah0auvlMSMifjggIvi9
+kE4nQISS0QqehGQ/ertNnLYWKvCgPI9fq8fQXG3mnFVR3qXhtSbIMbF1/AUye2bk
+uVVZ3WTo2oPFEVv/ZyTH9NcP4XpeuA==
+=KRyT
 -----END PGP PUBLIC KEY BLOCK-----
diff -pruN 1.2.1+git2.18.0-1/git/t/lib-gpg.sh 1.2.3+git2.25.1-1/git/t/lib-gpg.sh
--- 1.2.1+git2.18.0-1/git/t/lib-gpg.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/lib-gpg.sh	2020-02-17 04:47:35.000000000 +0000
@@ -38,7 +38,35 @@ then
 			"$TEST_DIRECTORY"/lib-gpg/ownertrust &&
 		gpg --homedir "${GNUPGHOME}" </dev/null >/dev/null 2>&1 \
 			--sign -u committer@example.com &&
-		test_set_prereq GPG
+		test_set_prereq GPG &&
+		# Available key info:
+		# * see t/lib-gpg/gpgsm-gen-key.in
+		# To generate new certificate:
+		#  * no passphrase
+		#	gpgsm --homedir /tmp/gpghome/ \
+		#		-o /tmp/gpgsm.crt.user \
+		#		--generate-key \
+		#		--batch t/lib-gpg/gpgsm-gen-key.in
+		# To import certificate:
+		#	gpgsm --homedir /tmp/gpghome/ \
+		#		--import /tmp/gpgsm.crt.user
+		# To export into a .p12 we can later import:
+		#	gpgsm --homedir /tmp/gpghome/ \
+		#		-o t/lib-gpg/gpgsm_cert.p12 \
+		#		--export-secret-key-p12 "committer@example.com"
+		echo | gpgsm --homedir "${GNUPGHOME}" 2>/dev/null \
+			--passphrase-fd 0 --pinentry-mode loopback \
+			--import "$TEST_DIRECTORY"/lib-gpg/gpgsm_cert.p12 &&
+
+		gpgsm --homedir "${GNUPGHOME}" 2>/dev/null -K |
+		grep fingerprint: |
+		cut -d" " -f4 |
+		tr -d '\n' >"${GNUPGHOME}/trustlist.txt" &&
+
+		echo " S relax" >>"${GNUPGHOME}/trustlist.txt" &&
+		echo hello | gpgsm --homedir "${GNUPGHOME}" >/dev/null \
+			-u committer@example.com -o /dev/null --sign - 2>&1 &&
+		test_set_prereq GPGSM
 		;;
 	esac
 fi
diff -pruN 1.2.1+git2.18.0-1/git/t/lib-httpd/apache.conf 1.2.3+git2.25.1-1/git/t/lib-httpd/apache.conf
--- 1.2.1+git2.18.0-1/git/t/lib-httpd/apache.conf	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/lib-httpd/apache.conf	2020-02-17 04:47:35.000000000 +0000
@@ -76,8 +76,10 @@ PassEnv GIT_VALGRIND
 PassEnv GIT_VALGRIND_OPTIONS
 PassEnv GNUPGHOME
 PassEnv ASAN_OPTIONS
+PassEnv LSAN_OPTIONS
 PassEnv GIT_TRACE
 PassEnv GIT_CONFIG_NOSYSTEM
+PassEnv GIT_TEST_SIDEBAND_ALL
 
 SetEnvIf Git-Protocol ".*" GIT_PROTOCOL=$0
 
@@ -111,18 +113,31 @@ Alias /auth/dumb/ www/auth/dumb/
 	SetEnv GIT_EXEC_PATH ${GIT_EXEC_PATH}
 	SetEnv GIT_HTTP_EXPORT_ALL
 </LocationMatch>
+<LocationMatch /one_time_sed/>
+	SetEnv GIT_EXEC_PATH ${GIT_EXEC_PATH}
+	SetEnv GIT_HTTP_EXPORT_ALL
+</LocationMatch>
+ScriptAliasMatch /error_git_upload_pack/(.*)/git-upload-pack error.sh/
 ScriptAliasMatch /smart_*[^/]*/(.*) ${GIT_EXEC_PATH}/git-http-backend/$1
 ScriptAlias /broken_smart/ broken-smart-http.sh/
+ScriptAlias /error_smart/ error-smart-http.sh/
 ScriptAlias /error/ error.sh/
+ScriptAliasMatch /one_time_sed/(.*) apply-one-time-sed.sh/$1
 <Directory ${GIT_EXEC_PATH}>
 	Options FollowSymlinks
 </Directory>
 <Files broken-smart-http.sh>
 	Options ExecCGI
 </Files>
+<Files error-smart-http.sh>
+	Options ExecCGI
+</Files>
 <Files error.sh>
   Options ExecCGI
 </Files>
+<Files apply-one-time-sed.sh>
+	Options ExecCGI
+</Files>
 <Files ${GIT_EXEC_PATH}/git-http-backend>
 	Options ExecCGI
 </Files>
diff -pruN 1.2.1+git2.18.0-1/git/t/lib-httpd/apply-one-time-sed.sh 1.2.3+git2.25.1-1/git/t/lib-httpd/apply-one-time-sed.sh
--- 1.2.1+git2.18.0-1/git/t/lib-httpd/apply-one-time-sed.sh	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/lib-httpd/apply-one-time-sed.sh	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,24 @@
+#!/bin/sh
+
+# If "one-time-sed" exists in $HTTPD_ROOT_PATH, run sed on the HTTP response,
+# using the contents of "one-time-sed" as the sed command to be run. If the
+# response was modified as a result, delete "one-time-sed" so that subsequent
+# HTTP responses are no longer modified.
+#
+# This can be used to simulate the effects of the repository changing in
+# between HTTP request-response pairs.
+if test -f one-time-sed
+then
+	"$GIT_EXEC_PATH/git-http-backend" >out
+	sed "$(cat one-time-sed)" out >out_modified
+
+	if cmp -s out out_modified
+	then
+		cat out
+	else
+		cat out_modified
+		rm one-time-sed
+	fi
+else
+	"$GIT_EXEC_PATH/git-http-backend"
+fi
diff -pruN 1.2.1+git2.18.0-1/git/t/lib-httpd/error-smart-http.sh 1.2.3+git2.25.1-1/git/t/lib-httpd/error-smart-http.sh
--- 1.2.1+git2.18.0-1/git/t/lib-httpd/error-smart-http.sh	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/lib-httpd/error-smart-http.sh	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,3 @@
+echo "Content-Type: application/x-git-upload-pack-advertisement"
+echo
+printf "%s" "0019ERR server-side error"
diff -pruN 1.2.1+git2.18.0-1/git/t/lib-httpd.sh 1.2.3+git2.25.1-1/git/t/lib-httpd.sh
--- 1.2.1+git2.18.0-1/git/t/lib-httpd.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/lib-httpd.sh	2020-02-17 04:47:35.000000000 +0000
@@ -14,7 +14,6 @@
 #
 #	test_expect_success ...
 #
-#	stop_httpd
 #	test_done
 #
 # Can be configured using the following variables.
@@ -42,15 +41,14 @@ then
 	test_done
 fi
 
-test_tristate GIT_TEST_HTTPD
-if test "$GIT_TEST_HTTPD" = false
+if ! test_bool_env GIT_TEST_HTTPD true
 then
 	skip_all="Network testing disabled (unset GIT_TEST_HTTPD to enable)"
 	test_done
 fi
 
 if ! test_have_prereq NOT_ROOT; then
-	test_skip_or_die $GIT_TEST_HTTPD \
+	test_skip_or_die GIT_TEST_HTTPD \
 		"Cannot run httpd tests as root"
 fi
 
@@ -82,7 +80,7 @@ case $(uname) in
 esac
 
 LIB_HTTPD_PATH=${LIB_HTTPD_PATH-"$DEFAULT_HTTPD_PATH"}
-LIB_HTTPD_PORT=${LIB_HTTPD_PORT-${this_test#t}}
+test_set_port LIB_HTTPD_PORT
 
 TEST_PATH="$TEST_DIRECTORY"/lib-httpd
 HTTPD_ROOT_PATH="$PWD"/httpd
@@ -91,11 +89,12 @@ HTTPD_DOCUMENT_ROOT_PATH=$HTTPD_ROOT_PAT
 # hack to suppress apache PassEnv warnings
 GIT_VALGRIND=$GIT_VALGRIND; export GIT_VALGRIND
 GIT_VALGRIND_OPTIONS=$GIT_VALGRIND_OPTIONS; export GIT_VALGRIND_OPTIONS
+GIT_TEST_SIDEBAND_ALL=$GIT_TEST_SIDEBAND_ALL; export GIT_TEST_SIDEBAND_ALL
 GIT_TRACE=$GIT_TRACE; export GIT_TRACE
 
 if ! test -x "$LIB_HTTPD_PATH"
 then
-	test_skip_or_die $GIT_TEST_HTTPD "no web server found at '$LIB_HTTPD_PATH'"
+	test_skip_or_die GIT_TEST_HTTPD "no web server found at '$LIB_HTTPD_PATH'"
 fi
 
 HTTPD_VERSION=$($LIB_HTTPD_PATH -v | \
@@ -107,19 +106,19 @@ then
 	then
 		if ! test $HTTPD_VERSION -ge 2
 		then
-			test_skip_or_die $GIT_TEST_HTTPD \
+			test_skip_or_die GIT_TEST_HTTPD \
 				"at least Apache version 2 is required"
 		fi
 		if ! test -d "$DEFAULT_HTTPD_MODULE_PATH"
 		then
-			test_skip_or_die $GIT_TEST_HTTPD \
+			test_skip_or_die GIT_TEST_HTTPD \
 				"Apache module directory not found"
 		fi
 
 		LIB_HTTPD_MODULE_PATH="$DEFAULT_HTTPD_MODULE_PATH"
 	fi
 else
-	test_skip_or_die $GIT_TEST_HTTPD \
+	test_skip_or_die GIT_TEST_HTTPD \
 		"Could not identify web server at '$LIB_HTTPD_PATH'"
 fi
 
@@ -131,7 +130,9 @@ prepare_httpd() {
 	mkdir -p "$HTTPD_DOCUMENT_ROOT_PATH"
 	cp "$TEST_PATH"/passwd "$HTTPD_ROOT_PATH"
 	install_script broken-smart-http.sh
+	install_script error-smart-http.sh
 	install_script error.sh
+	install_script apply-one-time-sed.sh
 
 	ln -s "$LIB_HTTPD_MODULE_PATH" "$HTTPD_ROOT_PATH/modules"
 
@@ -173,7 +174,7 @@ prepare_httpd() {
 start_httpd() {
 	prepare_httpd >&3 2>&4
 
-	trap 'code=$?; stop_httpd; (exit $code); die' EXIT
+	test_atexit stop_httpd
 
 	"$LIB_HTTPD_PATH" -d "$HTTPD_ROOT_PATH" \
 		-f "$TEST_PATH/apache.conf" $HTTPD_PARA \
@@ -181,15 +182,12 @@ start_httpd() {
 		>&3 2>&4
 	if test $? -ne 0
 	then
-		trap 'die' EXIT
 		cat "$HTTPD_ROOT_PATH"/error.log >&4 2>/dev/null
-		test_skip_or_die $GIT_TEST_HTTPD "web server setup failed"
+		test_skip_or_die GIT_TEST_HTTPD "web server setup failed"
 	fi
 }
 
 stop_httpd() {
-	trap 'die' EXIT
-
 	"$LIB_HTTPD_PATH" -d "$HTTPD_ROOT_PATH" \
 		-f "$TEST_PATH/apache.conf" $HTTPD_PARA -k stop
 }
@@ -287,3 +285,24 @@ expect_askpass() {
 	test_cmp "$TRASH_DIRECTORY/askpass-expect" \
 		 "$TRASH_DIRECTORY/askpass-query"
 }
+
+strip_access_log() {
+	sed -e "
+		s/^.* \"//
+		s/\"//
+		s/ [1-9][0-9]*\$//
+		s/^GET /GET  /
+	" "$HTTPD_ROOT_PATH"/access.log
+}
+
+# Requires one argument: the name of a file containing the expected stripped
+# access log entries.
+check_access_log() {
+	sort "$1" >"$1".sorted &&
+	strip_access_log >access.log.stripped &&
+	sort access.log.stripped >access.log.sorted &&
+	if ! test_cmp "$1".sorted access.log.sorted
+	then
+		test_cmp "$1" access.log.stripped
+	fi
+}
diff -pruN 1.2.1+git2.18.0-1/git/t/lib-patch-mode.sh 1.2.3+git2.25.1-1/git/t/lib-patch-mode.sh
--- 1.2.1+git2.18.0-1/git/t/lib-patch-mode.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/lib-patch-mode.sh	2020-02-17 04:47:35.000000000 +0000
@@ -2,28 +2,40 @@
 
 . ./test-lib.sh
 
+# set_state <path> <worktree-content> <index-content>
+#
+# Prepare the content for path in worktree and the index as specified.
 set_state () {
 	echo "$3" > "$1" &&
 	git add "$1" &&
 	echo "$2" > "$1"
 }
 
+# save_state <path>
+#
+# Save index/worktree content of <path> in the files _worktree_<path>
+# and _index_<path>
 save_state () {
 	noslash="$(echo "$1" | tr / _)" &&
 	cat "$1" > _worktree_"$noslash" &&
 	git show :"$1" > _index_"$noslash"
 }
 
+# set_and_save_state <path> <worktree-content> <index-content>
 set_and_save_state () {
 	set_state "$@" &&
 	save_state "$1"
 }
 
+# verify_state <path> <expected-worktree-content> <expected-index-content>
 verify_state () {
 	test "$(cat "$1")" = "$2" &&
 	test "$(git show :"$1")" = "$3"
 }
 
+# verify_saved_state <path>
+#
+# Call verify_state with expected contents from the last save_state
 verify_saved_state () {
 	noslash="$(echo "$1" | tr / _)" &&
 	verify_state "$1" "$(cat _worktree_"$noslash")" "$(cat _index_"$noslash")"
diff -pruN 1.2.1+git2.18.0-1/git/t/lib-rebase.sh 1.2.3+git2.25.1-1/git/t/lib-rebase.sh
--- 1.2.1+git2.18.0-1/git/t/lib-rebase.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/lib-rebase.sh	2020-02-17 04:47:35.000000000 +0000
@@ -14,8 +14,8 @@
 #       specified line.
 #
 #   "<cmd> <lineno>" -- add a line with the specified command
-#       ("squash", "fixup", "edit", "reword" or "drop") and the SHA1 taken
-#       from the specified line.
+#       ("pick", "squash", "fixup", "edit", "reword" or "drop") and the
+#       SHA1 taken from the specified line.
 #
 #   "exec_cmd_with_args" -- add an "exec cmd with args" line.
 #
@@ -44,12 +44,12 @@ set_fake_editor () {
 	rm -f "$1"
 	echo 'rebase -i script before editing:'
 	cat "$1".tmp
-	action=pick
+	action=\&
 	for line in $FAKE_LINES; do
 		case $line in
-		squash|fixup|edit|reword|drop)
+		pick|p|squash|s|fixup|f|edit|e|reword|r|drop|d|label|l|reset|r|merge|m)
 			action="$line";;
-		exec*)
+		exec_*|x_*|break|b)
 			echo "$line" | sed 's/_/ /g' >> "$1";;
 		"#")
 			echo '# comment' >> "$1";;
@@ -58,11 +58,12 @@ set_fake_editor () {
 		bad)
 			action="badcmd";;
 		fakesha)
+			test \& != "$action" || action=pick
 			echo "$action XXXXXXX False commit" >> "$1"
 			action=pick;;
 		*)
-			sed -n "${line}s/^pick/$action/p" < "$1".tmp >> "$1"
-			action=pick;;
+			sed -n "${line}s/^[a-z][a-z]*/$action/p" < "$1".tmp >> "$1"
+			action=\&;;
 		esac
 	done
 	echo 'rebase -i script after editing:'
@@ -118,3 +119,31 @@ make_empty () {
 	git commit --allow-empty -m "$1" &&
 	git tag "$1"
 }
+
+# Call this (inside test_expect_success) at the end of a test file to
+# check that no tests have changed editor related environment
+# variables or config settings
+test_editor_unchanged () {
+	# We're only interested in exported variables hence 'sh -c'
+	sh -c 'cat >actual <<-EOF
+	EDITOR=$EDITOR
+	FAKE_COMMIT_AMEND=$FAKE_COMMIT_AMEND
+	FAKE_COMMIT_MESSAGE=$FAKE_COMMIT_MESSAGE
+	FAKE_LINES=$FAKE_LINES
+	GIT_EDITOR=$GIT_EDITOR
+	GIT_SEQUENCE_EDITOR=$GIT_SEQUENCE_EDITOR
+	core.editor=$(git config core.editor)
+	sequence.editor=$(git config sequence.editor)
+	EOF'
+	cat >expect <<-\EOF
+	EDITOR=:
+	FAKE_COMMIT_AMEND=
+	FAKE_COMMIT_MESSAGE=
+	FAKE_LINES=
+	GIT_EDITOR=
+	GIT_SEQUENCE_EDITOR=
+	core.editor=
+	sequence.editor=
+	EOF
+	test_cmp expect actual
+}
diff -pruN 1.2.1+git2.18.0-1/git/t/lib-submodule-update.sh 1.2.3+git2.25.1-1/git/t/lib-submodule-update.sh
--- 1.2.1+git2.18.0-1/git/t/lib-submodule-update.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/lib-submodule-update.sh	2020-02-17 04:47:35.000000000 +0000
@@ -139,7 +139,7 @@ create_lib_submodule_repo () {
 		git revert HEAD &&
 
 		git checkout -b invalid_sub1 add_sub1 &&
-		git update-index --cacheinfo 160000 0123456789012345678901234567890123456789 sub1 &&
+		git update-index --cacheinfo 160000 $(test_oid numeric) sub1 &&
 		git commit -m "Invalid sub1 commit" &&
 		git checkout -b valid_sub1 &&
 		git revert HEAD &&
@@ -196,6 +196,7 @@ test_git_directory_exists() {
 # the submodule repo if it doesn't exist and configures the most problematic
 # settings for diff.ignoreSubmodules.
 prolog () {
+	test_oid_init &&
 	(test -d submodule_update_repo || create_lib_submodule_repo) &&
 	test_config_global diff.ignoreSubmodules all &&
 	test_config diff.ignoreSubmodules all
@@ -235,7 +236,7 @@ reset_work_tree_to_interested () {
 	then
 		mkdir -p submodule_update/.git/modules/sub1/modules &&
 		cp -r submodule_update_repo/.git/modules/sub1/modules/sub2 submodule_update/.git/modules/sub1/modules/sub2
-		GIT_WORK_TREE=. git -C submodule_update/.git/modules/sub1/modules/sub2 config --unset core.worktree
+		# core.worktree is unset for sub2 as it is not checked out
 	fi &&
 	# indicate we are interested in the submodule:
 	git -C submodule_update config submodule.sub1.url "bogus" &&
@@ -709,7 +710,8 @@ test_submodule_recursing_with_args_commo
 			git branch -t remove_sub1 origin/remove_sub1 &&
 			$command remove_sub1 &&
 			test_superproject_content origin/remove_sub1 &&
-			! test -e sub1
+			! test -e sub1 &&
+			test_must_fail git config -f .git/modules/sub1/config core.worktree
 		)
 	'
 	# ... absorbing a .git directory along the way.
@@ -755,7 +757,7 @@ test_submodule_recursing_with_args_commo
 			: >sub1/untrackedfile &&
 			test_must_fail $command replace_sub1_with_file &&
 			test_superproject_content origin/add_sub1 &&
-			test_submodule_content sub1 origin/add_sub1
+			test_submodule_content sub1 origin/add_sub1 &&
 			test -f sub1/untracked_file
 		)
 	'
@@ -781,7 +783,8 @@ test_submodule_recursing_with_args_commo
 		(
 			cd submodule_update &&
 			git branch -t invalid_sub1 origin/invalid_sub1 &&
-			test_must_fail $command invalid_sub1 &&
+			test_must_fail $command invalid_sub1 2>err &&
+			test_i18ngrep sub1 err &&
 			test_superproject_content origin/add_sub1 &&
 			test_submodule_content sub1 origin/add_sub1
 		)
@@ -842,7 +845,7 @@ test_submodule_switch_recursing_with_arg
 			cd submodule_update &&
 			git branch -t add_sub1 origin/add_sub1 &&
 			: >sub1 &&
-			echo sub1 >.git/info/exclude
+			echo sub1 >.git/info/exclude &&
 			$command add_sub1 &&
 			test_superproject_content origin/add_sub1 &&
 			test_submodule_content sub1 origin/add_sub1
@@ -969,7 +972,6 @@ test_submodule_forced_switch_recursing_w
 			rm -rf .git/modules/sub1 &&
 			$command replace_sub1_with_directory &&
 			test_superproject_content origin/replace_sub1_with_directory &&
-			test_submodule_content sub1 origin/modify_sub1
 			test_git_directory_exists sub1
 		)
 	'
diff -pruN 1.2.1+git2.18.0-1/git/t/Makefile 1.2.3+git2.25.1-1/git/t/Makefile
--- 1.2.1+git2.18.0-1/git/t/Makefile	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/Makefile	2020-02-17 04:47:35.000000000 +0000
@@ -18,8 +18,10 @@ TEST_LINT ?= test-lint
 
 ifdef TEST_OUTPUT_DIRECTORY
 TEST_RESULTS_DIRECTORY = $(TEST_OUTPUT_DIRECTORY)/test-results
+CHAINLINTTMP = $(TEST_OUTPUT_DIRECTORY)/chainlinttmp
 else
 TEST_RESULTS_DIRECTORY = test-results
+CHAINLINTTMP = chainlinttmp
 endif
 
 # Shell quote;
@@ -27,14 +29,17 @@ SHELL_PATH_SQ = $(subst ','\'',$(SHELL_P
 TEST_SHELL_PATH_SQ = $(subst ','\'',$(TEST_SHELL_PATH))
 PERL_PATH_SQ = $(subst ','\'',$(PERL_PATH))
 TEST_RESULTS_DIRECTORY_SQ = $(subst ','\'',$(TEST_RESULTS_DIRECTORY))
+CHAINLINTTMP_SQ = $(subst ','\'',$(CHAINLINTTMP))
 
 T = $(sort $(wildcard t[0-9][0-9][0-9][0-9]-*.sh))
 TGITWEB = $(sort $(wildcard t95[0-9][0-9]-*.sh))
 THELPERS = $(sort $(filter-out $(T),$(wildcard *.sh)))
+CHAINLINTTESTS = $(sort $(patsubst chainlint/%.test,%,$(wildcard chainlint/*.test)))
+CHAINLINT = sed -f chainlint.sed
 
 all: $(DEFAULT_TEST_TARGET)
 
-test: pre-clean $(TEST_LINT)
+test: pre-clean check-chainlint $(TEST_LINT)
 	$(MAKE) aggregate-results-and-cleanup
 
 failed:
@@ -43,7 +48,7 @@ failed:
 		sed -n 's/\.counts$$/.sh/p') && \
 	test -z "$$failed" || $(MAKE) $$failed
 
-prove: pre-clean $(TEST_LINT)
+prove: pre-clean check-chainlint $(TEST_LINT)
 	@echo "*** prove ***"; $(PROVE) --exec '$(TEST_SHELL_PATH_SQ)' $(GIT_PROVE_OPTS) $(T) :: $(GIT_TEST_OPTS)
 	$(MAKE) clean-except-prove-cache
 
@@ -53,13 +58,25 @@ $(T):
 pre-clean:
 	$(RM) -r '$(TEST_RESULTS_DIRECTORY_SQ)'
 
-clean-except-prove-cache:
+clean-except-prove-cache: clean-chainlint
 	$(RM) -r 'trash directory'.* '$(TEST_RESULTS_DIRECTORY_SQ)'
 	$(RM) -r valgrind/bin
 
 clean: clean-except-prove-cache
 	$(RM) .prove
 
+clean-chainlint:
+	$(RM) -r '$(CHAINLINTTMP_SQ)'
+
+check-chainlint:
+	@mkdir -p '$(CHAINLINTTMP_SQ)' && \
+	err=0 && \
+	for i in $(CHAINLINTTESTS); do \
+		$(CHAINLINT) <chainlint/$$i.test | \
+		sed -e '/^# LINT: /d' >'$(CHAINLINTTMP_SQ)'/$$i.actual && \
+		diff -u chainlint/$$i.expect '$(CHAINLINTTMP_SQ)'/$$i.actual || err=1; \
+	done && exit $$err
+
 test-lint: test-lint-duplicates test-lint-executable test-lint-shell-syntax \
 	test-lint-filenames
 
@@ -102,4 +119,4 @@ valgrind:
 perf:
 	$(MAKE) -C perf/ all
 
-.PHONY: pre-clean $(T) aggregate-results clean valgrind perf
+.PHONY: pre-clean $(T) aggregate-results clean valgrind perf check-chainlint clean-chainlint
diff -pruN 1.2.1+git2.18.0-1/git/t/oid-info/hash-info 1.2.3+git2.25.1-1/git/t/oid-info/hash-info
--- 1.2.1+git2.18.0-1/git/t/oid-info/hash-info	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/oid-info/hash-info	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,17 @@
+rawsz sha1:20
+rawsz sha256:32
+
+hexsz sha1:40
+hexsz sha256:64
+
+zero sha1:0000000000000000000000000000000000000000
+zero sha256:0000000000000000000000000000000000000000000000000000000000000000
+
+algo sha1:sha1
+algo sha256:sha256
+
+empty_blob sha1:e69de29bb2d1d6434b8b29ae775ad8c2e48c5391
+empty_blob sha256:473a0f4c3be8a93681a267e3b1e9a7dcda1185436fe141f7749120a303721813
+
+empty_tree sha1:4b825dc642cb6eb9a060e54bf8d69288fbee4904
+empty_tree sha256:6ef19b41225c5369f1c104d45d8d85efa9b057b53b14b4b9b939dd74decc5321
diff -pruN 1.2.1+git2.18.0-1/git/t/oid-info/oid 1.2.3+git2.25.1-1/git/t/oid-info/oid
--- 1.2.1+git2.18.0-1/git/t/oid-info/oid	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/oid-info/oid	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,29 @@
+# These are some common invalid and partial object IDs used in tests.
+001	sha1:0000000000000000000000000000000000000001
+001	sha256:0000000000000000000000000000000000000000000000000000000000000001
+002	sha1:0000000000000000000000000000000000000002
+002	sha256:0000000000000000000000000000000000000000000000000000000000000002
+003	sha1:0000000000000000000000000000000000000003
+003	sha256:0000000000000000000000000000000000000000000000000000000000000003
+004	sha1:0000000000000000000000000000000000000004
+004	sha256:0000000000000000000000000000000000000000000000000000000000000004
+005	sha1:0000000000000000000000000000000000000005
+005	sha256:0000000000000000000000000000000000000000000000000000000000000005
+006	sha1:0000000000000000000000000000000000000006
+006	sha256:0000000000000000000000000000000000000000000000000000000000000006
+007	sha1:0000000000000000000000000000000000000007
+007	sha256:0000000000000000000000000000000000000000000000000000000000000007
+# All zeros or Fs missing one or two hex segments.
+zero_1		sha1:000000000000000000000000000000000000000
+zero_1		sha256:000000000000000000000000000000000000000000000000000000000000000
+zero_2		sha1:00000000000000000000000000000000000000
+zero_2		sha256:00000000000000000000000000000000000000000000000000000000000000
+ff_1		sha1:fffffffffffffffffffffffffffffffffffffff
+ff_1		sha256:fffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffff
+ff_2		sha1:ffffffffffffffffffffffffffffffffffffff
+ff_2		sha256:ffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffff
+# More various invalid OIDs.
+numeric		sha1:0123456789012345678901234567890123456789
+numeric		sha256:0123456789012345678901234567890123456789012345678901234567890123
+deadbeef	sha1:deadbeefdeadbeefdeadbeefdeadbeefdeadbeef
+deadbeef	sha256:deadbeefdeadbeefdeadbeefdeadbeefdeadbeefdeadbeefdeadbeefdeadbeef
diff -pruN 1.2.1+git2.18.0-1/git/t/oid-info/README 1.2.3+git2.25.1-1/git/t/oid-info/README
--- 1.2.1+git2.18.0-1/git/t/oid-info/README	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/oid-info/README	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,19 @@
+This directory contains various per-hash values that are used in the testsuite.
+
+Each file contains lines containing a key-value pair; blank lines and lines
+starting with `#` are ignored.  The key and value are separated by whitespace
+(specifically, those whitespace in the default `$IFS`).  The key consists only
+of shell identifier characters, and the value consists of a hash algorithm,
+colon, and value.  The hash algorithm also consists only of shell identifier
+characters; it should match the value in sha1-file.c.
+
+For example, the following lines map the key "rawsz" to "20" if SHA-1 is in use
+and to "32" if SHA-256 is in use:
+
+----
+rawsz sha1:20
+rawsz sha256:32
+----
+
+The keys and values used here are loaded by `test_oid_init` (see the README file
+in the "t" directory) and are used by calling `test_oid`.
diff -pruN 1.2.1+git2.18.0-1/git/t/perf/aggregate.perl 1.2.3+git2.25.1-1/git/t/perf/aggregate.perl
--- 1.2.1+git2.18.0-1/git/t/perf/aggregate.perl	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/perf/aggregate.perl	2020-02-17 04:47:35.000000000 +0000
@@ -3,9 +3,8 @@
 use lib '../../perl/build/lib';
 use strict;
 use warnings;
-use JSON;
 use Getopt::Long;
-use Git;
+use Cwd qw(realpath);
 
 sub get_times {
 	my $name = shift;
@@ -13,27 +12,42 @@ sub get_times {
 	my $line = <$fh>;
 	return undef if not defined $line;
 	close $fh or die "cannot close $name: $!";
-	$line =~ /^(?:(\d+):)?(\d+):(\d+(?:\.\d+)?) (\d+(?:\.\d+)?) (\d+(?:\.\d+)?)$/
-		or die "bad input line: $line";
-	my $rt = ((defined $1 ? $1 : 0.0)*60+$2)*60+$3;
-	return ($rt, $4, $5);
+	# times
+	if ($line =~ /^(?:(\d+):)?(\d+):(\d+(?:\.\d+)?) (\d+(?:\.\d+)?) (\d+(?:\.\d+)?)$/) {
+		my $rt = ((defined $1 ? $1 : 0.0)*60+$2)*60+$3;
+		return ($rt, $4, $5);
+	# size
+	} elsif ($line =~ /^\d+$/) {
+		return $&;
+	} else {
+		die "bad input line: $line";
+	}
+}
+
+sub relative_change {
+	my ($r, $firstr) = @_;
+	if ($firstr > 0) {
+		return sprintf "%+.1f%%", 100.0*($r-$firstr)/$firstr;
+	} elsif ($r == 0) {
+		return "=";
+	} else {
+		return "+inf";
+	}
 }
 
 sub format_times {
 	my ($r, $u, $s, $firstr) = @_;
+	# no value means we did not finish the test
 	if (!defined $r) {
 		return "<missing>";
 	}
-	my $out = sprintf "%.2f(%.2f+%.2f)", $r, $u, $s;
-	if (defined $firstr) {
-		if ($firstr > 0) {
-			$out .= sprintf " %+.1f%%", 100.0*($r-$firstr)/$firstr;
-		} elsif ($r == 0) {
-			$out .= " =";
-		} else {
-			$out .= " +inf";
-		}
+	# a single value means we have a size, not times
+	if (!defined $u) {
+		return format_size($r, $firstr);
 	}
+	# otherwise, we have real/user/system times
+	my $out = sprintf "%.2f(%.2f+%.2f)", $r, $u, $s;
+	$out .= ' ' . relative_change($r, $firstr) if defined $firstr;
 	return $out;
 }
 
@@ -51,6 +65,30 @@ EOT
 	exit(1);
 }
 
+sub human_size {
+	my $n = shift;
+	my @units = ('', qw(K M G));
+	while ($n > 900 && @units > 1) {
+		$n /= 1000;
+		shift @units;
+	}
+	return $n unless length $units[0];
+	return sprintf '%.1f%s', $n, $units[0];
+}
+
+sub format_size {
+	my ($size, $first) = @_;
+	# match the width of a time: 0.00(0.00+0.00)
+	my $out = sprintf '%15s', human_size($size);
+	$out .= ' ' . relative_change($size, $first) if defined $first;
+	return $out;
+}
+
+sub sane_backticks {
+	open(my $fh, '-|', @_);
+	return <$fh>;
+}
+
 my (@dirs, %dirnames, %dirabbrevs, %prefixes, @tests,
     $codespeed, $sortby, $subsection, $reponame);
 
@@ -65,18 +103,22 @@ usage() unless $rc;
 while (scalar @ARGV) {
 	my $arg = $ARGV[0];
 	my $dir;
+	my $prefix = '';
 	last if -f $arg or $arg eq "--";
 	if (! -d $arg) {
-		my $rev = Git::command_oneline(qw(rev-parse --verify), $arg);
+		my $rev = sane_backticks(qw(git rev-parse --verify), $arg);
+		chomp $rev;
 		$dir = "build/".$rev;
+	} elsif ($arg eq '.') {
+		$dir = '.';
 	} else {
-		$arg =~ s{/*$}{};
-		$dir = $arg;
-		$dirabbrevs{$dir} = $dir;
+		$dir = realpath($arg);
+		$dirnames{$dir} = $dir;
+		$prefix .= 'bindir';
 	}
 	push @dirs, $dir;
-	$dirnames{$dir} = $arg;
-	my $prefix = $dir;
+	$dirnames{$dir} ||= $arg;
+	$prefix .= $dir;
 	$prefix =~ tr/^a-zA-Z0-9/_/c;
 	$prefixes{$dir} = $prefix . '.';
 	shift @ARGV;
@@ -181,7 +223,8 @@ sub print_default_results {
 		my $firstr;
 		for my $i (0..$#dirs) {
 			my $d = $dirs[$i];
-			$times{$prefixes{$d}.$t} = [get_times("$resultsdir/$prefixes{$d}$t.times")];
+			my $base = "$resultsdir/$prefixes{$d}$t";
+			$times{$prefixes{$d}.$t} = [get_times("$base.result")];
 			my ($r,$u,$s) = @{$times{$prefixes{$d}.$t}};
 			my $w = length format_times($r,$u,$s,$firstr);
 			$colwidth[$i] = $w if $w > $colwidth[$i];
@@ -223,7 +266,7 @@ sub print_sorted_results {
 		my ($prevr, $prevu, $prevs, $prevrev);
 		for my $i (0..$#dirs) {
 			my $d = $dirs[$i];
-			my ($r, $u, $s) = get_times("$resultsdir/$prefixes{$d}$t.times");
+			my ($r, $u, $s) = get_times("$resultsdir/$prefixes{$d}$t.result");
 			if ($i > 0 and defined $r and defined $prevr and $prevr > 0) {
 				my $percent = 100.0 * ($r - $prevr) / $prevr;
 				push @evolutions, { "percent"  => $percent,
@@ -271,9 +314,6 @@ sub print_codespeed_results {
 		$environment = $reponame;
 	} elsif (exists $ENV{GIT_PERF_REPO_NAME} and $ENV{GIT_PERF_REPO_NAME} ne "") {
 		$environment = $ENV{GIT_PERF_REPO_NAME};
-	} elsif (exists $ENV{GIT_TEST_INSTALLED} and $ENV{GIT_TEST_INSTALLED} ne "") {
-		$environment = $ENV{GIT_TEST_INSTALLED};
-		$environment =~ s|/bin-wrappers$||;
 	} else {
 		$environment = `uname -r`;
 		chomp $environment;
@@ -286,7 +326,7 @@ sub print_codespeed_results {
 			my $commitid = $prefixes{$d};
 			$commitid =~ s/^build_//;
 			$commitid =~ s/\.$//;
-			my ($result_value, $u, $s) = get_times("$resultsdir/$prefixes{$d}$t.times");
+			my ($result_value, $u, $s) = get_times("$resultsdir/$prefixes{$d}$t.result");
 
 			my %vals = (
 				"commitid" => $commitid,
@@ -301,7 +341,8 @@ sub print_codespeed_results {
 		}
 	}
 
-	print to_json(\@data, {utf8 => 1, pretty => 1, canonical => 1}), "\n";
+	require JSON;
+	print JSON::to_json(\@data, {utf8 => 1, pretty => 1, canonical => 1}), "\n";
 }
 
 binmode STDOUT, ":utf8" or die "PANIC on binmode: $!";
diff -pruN 1.2.1+git2.18.0-1/git/t/perf/bisect_regression 1.2.3+git2.25.1-1/git/t/perf/bisect_regression
--- 1.2.1+git2.18.0-1/git/t/perf/bisect_regression	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/perf/bisect_regression	2020-02-17 04:47:35.000000000 +0000
@@ -51,7 +51,7 @@ oldtime=$(echo "$oldtime" | sed -e 's/^\
 newtime=$(echo "$newtime" | sed -e 's/^\([0-9]\+\.[0-9]\+\).*$/\1/')
 
 test $(echo "$newtime" "$oldtime" | awk '{ print ($1 > $2) }') = 1 ||
-	die "New time '$newtime' shoud be greater than old time '$oldtime'"
+	die "New time '$newtime' should be greater than old time '$oldtime'"
 
 tmpdir=$(mktemp -d -t bisect_regression_XXXXXX) || die "Failed to create temp directory"
 echo "$oldtime" >"$tmpdir/oldtime" || die "Failed to write to '$tmpdir/oldtime'"
diff -pruN 1.2.1+git2.18.0-1/git/t/perf/p0001-rev-list.sh 1.2.3+git2.25.1-1/git/t/perf/p0001-rev-list.sh
--- 1.2.1+git2.18.0-1/git/t/perf/p0001-rev-list.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/perf/p0001-rev-list.sh	2020-02-17 04:47:35.000000000 +0000
@@ -14,6 +14,24 @@ test_perf 'rev-list --all --objects' '
 	git rev-list --all --objects >/dev/null
 '
 
+test_perf 'rev-list --parents' '
+	git rev-list --parents HEAD >/dev/null
+'
+
+test_expect_success 'create dummy file' '
+	echo unlikely-to-already-be-there >dummy &&
+	git add dummy &&
+	git commit -m dummy
+'
+
+test_perf 'rev-list -- dummy' '
+	git rev-list HEAD -- dummy
+'
+
+test_perf 'rev-list --parents -- dummy' '
+	git rev-list --parents HEAD -- dummy
+'
+
 test_expect_success 'create new unreferenced commit' '
 	commit=$(git commit-tree HEAD^{tree} -p HEAD) &&
 	test_export commit
diff -pruN 1.2.1+git2.18.0-1/git/t/perf/p1450-fsck.sh 1.2.3+git2.25.1-1/git/t/perf/p1450-fsck.sh
--- 1.2.1+git2.18.0-1/git/t/perf/p1450-fsck.sh	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/perf/p1450-fsck.sh	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,13 @@
+#!/bin/sh
+
+test_description='Test fsck performance'
+
+. ./perf-lib.sh
+
+test_perf_large_repo
+
+test_perf 'fsck' '
+	git fsck
+'
+
+test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/perf/p1451-fsck-skip-list.sh 1.2.3+git2.25.1-1/git/t/perf/p1451-fsck-skip-list.sh
--- 1.2.1+git2.18.0-1/git/t/perf/p1451-fsck-skip-list.sh	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/perf/p1451-fsck-skip-list.sh	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,40 @@
+#!/bin/sh
+
+test_description='Test fsck skipList performance'
+
+. ./perf-lib.sh
+
+test_perf_fresh_repo
+
+n=1000000
+
+test_expect_success "setup $n bad commits" '
+	for i in $(test_seq 1 $n)
+	do
+		echo "commit refs/heads/master" &&
+		echo "committer C <c@example.com> 1234567890 +0000" &&
+		echo "data <<EOF" &&
+		echo "$i.Q." &&
+		echo "EOF"
+	done | q_to_nul | git fast-import
+'
+
+skip=0
+while test $skip -le $n
+do
+	test_expect_success "create skipList for $skip bad commits" '
+		git log --format=%H --max-count=$skip |
+		sort >skiplist
+	'
+
+	test_perf "fsck with $skip skipped bad commits" '
+		git -c fsck.skipList=skiplist fsck
+	'
+
+	case $skip in
+	0) skip=1 ;;
+	*) skip=${skip}0 ;;
+	esac
+done
+
+test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/perf/p3400-rebase.sh 1.2.3+git2.25.1-1/git/t/perf/p3400-rebase.sh
--- 1.2.1+git2.18.0-1/git/t/perf/p3400-rebase.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/perf/p3400-rebase.sh	2020-02-17 04:47:35.000000000 +0000
@@ -6,9 +6,9 @@ test_description='Tests rebase performan
 test_perf_default_repo
 
 test_expect_success 'setup rebasing on top of a lot of changes' '
-	git checkout -f -b base &&
-	git checkout -b to-rebase &&
-	git checkout -b upstream &&
+	git checkout -f -B base &&
+	git checkout -B to-rebase &&
+	git checkout -B upstream &&
 	for i in $(seq 100)
 	do
 		# simulate huge diffs
@@ -35,8 +35,8 @@ test_perf 'rebase on top of a lot of unr
 
 test_expect_success 'setup rebasing many changes without split-index' '
 	git config core.splitIndex false &&
-	git checkout -b upstream2 to-rebase &&
-	git checkout -b to-rebase2 upstream
+	git checkout -B upstream2 to-rebase &&
+	git checkout -B to-rebase2 upstream
 '
 
 test_perf 'rebase a lot of unrelated changes without split-index' '
diff -pruN 1.2.1+git2.18.0-1/git/t/perf/p5302-pack-index.sh 1.2.3+git2.25.1-1/git/t/perf/p5302-pack-index.sh
--- 1.2.1+git2.18.0-1/git/t/perf/p5302-pack-index.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/perf/p5302-pack-index.sh	2020-02-17 04:47:35.000000000 +0000
@@ -13,35 +13,40 @@ test_expect_success 'repack' '
 	export PACK
 '
 
-test_expect_success 'create target repositories' '
-	for repo in t1 t2 t3 t4 t5 t6
-	do
-		git init --bare $repo
-	done
-'
-
 test_perf 'index-pack 0 threads' '
-	GIT_DIR=t1 git index-pack --threads=1 --stdin < $PACK
+	rm -rf repo.git &&
+	git init --bare repo.git &&
+	GIT_DIR=repo.git git index-pack --threads=1 --stdin < $PACK
 '
 
 test_perf 'index-pack 1 thread ' '
-	GIT_DIR=t2 GIT_FORCE_THREADS=1 git index-pack --threads=1 --stdin < $PACK
+	rm -rf repo.git &&
+	git init --bare repo.git &&
+	GIT_DIR=repo.git GIT_FORCE_THREADS=1 git index-pack --threads=1 --stdin < $PACK
 '
 
 test_perf 'index-pack 2 threads' '
-	GIT_DIR=t3 git index-pack --threads=2 --stdin < $PACK
+	rm -rf repo.git &&
+	git init --bare repo.git &&
+	GIT_DIR=repo.git git index-pack --threads=2 --stdin < $PACK
 '
 
 test_perf 'index-pack 4 threads' '
-	GIT_DIR=t4 git index-pack --threads=4 --stdin < $PACK
+	rm -rf repo.git &&
+	git init --bare repo.git &&
+	GIT_DIR=repo.git git index-pack --threads=4 --stdin < $PACK
 '
 
 test_perf 'index-pack 8 threads' '
-	GIT_DIR=t5 git index-pack --threads=8 --stdin < $PACK
+	rm -rf repo.git &&
+	git init --bare repo.git &&
+	GIT_DIR=repo.git git index-pack --threads=8 --stdin < $PACK
 '
 
 test_perf 'index-pack default number of threads' '
-	GIT_DIR=t6 git index-pack --stdin < $PACK
+	rm -rf repo.git &&
+	git init --bare repo.git &&
+	GIT_DIR=repo.git git index-pack --stdin < $PACK
 '
 
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/perf/p5303-many-packs.sh 1.2.3+git2.25.1-1/git/t/perf/p5303-many-packs.sh
--- 1.2.1+git2.18.0-1/git/t/perf/p5303-many-packs.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/perf/p5303-many-packs.sh	2020-02-17 04:47:35.000000000 +0000
@@ -77,6 +77,7 @@ do
 	# actual pack generation, without smudging the on-disk setup
 	# between trials.
 	test_perf "repack ($nr_packs)" '
+		GIT_TEST_FULL_IN_PACK_ARRAY=1 \
 		git pack-objects --keep-true-parents \
 		  --honor-pack-keep --non-empty --all \
 		  --reflog --indexed-objects --delta-base-offset \
@@ -84,4 +85,22 @@ do
 	'
 done
 
+# Measure pack loading with 10,000 packs.
+test_expect_success 'generate lots of packs' '
+	for i in $(test_seq 10000); do
+		echo "blob"
+		echo "data <<EOF"
+		echo "blob $i"
+		echo "EOF"
+		echo "checkpoint"
+	done |
+	git -c fastimport.unpackLimit=0 fast-import
+'
+
+# The purpose of this test is to evaluate load time for a large number
+# of packs while doing as little other work as possible.
+test_perf "load 10,000 packs" '
+	git rev-parse --verify "HEAD^{commit}"
+'
+
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/perf/p5304-prune.sh 1.2.3+git2.25.1-1/git/t/perf/p5304-prune.sh
--- 1.2.1+git2.18.0-1/git/t/perf/p5304-prune.sh	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/perf/p5304-prune.sh	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,35 @@
+#!/bin/sh
+
+test_description='performance tests of prune'
+. ./perf-lib.sh
+
+test_perf_default_repo
+
+test_expect_success 'remove reachable loose objects' '
+	git repack -ad
+'
+
+test_expect_success 'remove unreachable loose objects' '
+	git prune
+'
+
+test_expect_success 'confirm there are no loose objects' '
+	git count-objects | grep ^0
+'
+
+test_perf 'prune with no objects' '
+	git prune
+'
+
+test_expect_success 'repack with bitmaps' '
+	git repack -adb
+'
+
+# We have to create the object in each trial run, since otherwise
+# runs after the first see no object and just skip the traversal entirely!
+test_perf 'prune with bitmaps' '
+	echo "probably not present in repo" | git hash-object -w --stdin &&
+	git prune
+'
+
+test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/perf/p5310-pack-bitmaps.sh 1.2.3+git2.25.1-1/git/t/perf/p5310-pack-bitmaps.sh
--- 1.2.1+git2.18.0-1/git/t/perf/p5310-pack-bitmaps.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/perf/p5310-pack-bitmaps.sh	2020-02-17 04:47:35.000000000 +0000
@@ -12,8 +12,7 @@ test_perf_large_repo
 # We intentionally use the deprecated pack.writebitmaps
 # config so that we can test against older versions of git.
 test_expect_success 'setup bitmap config' '
-	git config pack.writebitmaps true &&
-	git config pack.writebitmaphashcache true
+	git config pack.writebitmaps true
 '
 
 test_perf 'repack to disk' '
diff -pruN 1.2.1+git2.18.0-1/git/t/perf/p5311-pack-bitmaps-fetch.sh 1.2.3+git2.25.1-1/git/t/perf/p5311-pack-bitmaps-fetch.sh
--- 1.2.1+git2.18.0-1/git/t/perf/p5311-pack-bitmaps-fetch.sh	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/perf/p5311-pack-bitmaps-fetch.sh	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,44 @@
+#!/bin/sh
+
+test_description='performance of fetches from bitmapped packs'
+. ./perf-lib.sh
+
+test_perf_default_repo
+
+test_expect_success 'create bitmapped server repo' '
+	git config pack.writebitmaps true &&
+	git repack -ad
+'
+
+# simulate a fetch from a repository that last fetched N days ago, for
+# various values of N. We do so by following the first-parent chain,
+# and assume the first entry in the chain that is N days older than the current
+# HEAD is where the HEAD would have been then.
+for days in 1 2 4 8 16 32 64 128; do
+	title=$(printf '%10s' "($days days)")
+	test_expect_success "setup revs from $days days ago" '
+		now=$(git log -1 --format=%ct HEAD) &&
+		then=$(($now - ($days * 86400))) &&
+		tip=$(git rev-list -1 --first-parent --until=$then HEAD) &&
+		{
+			echo HEAD &&
+			echo ^$tip
+		} >revs
+	'
+
+	test_perf "server $title" '
+		git pack-objects --stdout --revs \
+				 --thin --delta-base-offset \
+				 <revs >tmp.pack
+	'
+
+	test_size "size   $title" '
+		wc -c <tmp.pack
+	'
+
+	test_perf "client $title" '
+		git index-pack --stdin --fix-thin <tmp.pack
+	'
+done
+
+test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/perf/p5600-partial-clone.sh 1.2.3+git2.25.1-1/git/t/perf/p5600-partial-clone.sh
--- 1.2.1+git2.18.0-1/git/t/perf/p5600-partial-clone.sh	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/perf/p5600-partial-clone.sh	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,26 @@
+#!/bin/sh
+
+test_description='performance of partial clones'
+. ./perf-lib.sh
+
+test_perf_default_repo
+
+test_expect_success 'enable server-side config' '
+	git config uploadpack.allowFilter true &&
+	git config uploadpack.allowAnySHA1InWant true
+'
+
+test_perf 'clone without blobs' '
+	rm -rf bare.git &&
+	git clone --no-local --bare --filter=blob:none . bare.git
+'
+
+test_perf 'checkout of result' '
+	rm -rf worktree &&
+	mkdir -p worktree/.git &&
+	tar -C bare.git -cf - . | tar -C worktree/.git -xf - &&
+	git -C worktree config core.bare false &&
+	git -C worktree checkout -f
+'
+
+test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/perf/p5601-clone-reference.sh 1.2.3+git2.25.1-1/git/t/perf/p5601-clone-reference.sh
--- 1.2.1+git2.18.0-1/git/t/perf/p5601-clone-reference.sh	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/perf/p5601-clone-reference.sh	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,27 @@
+#!/bin/sh
+
+test_description='speed of clone --reference'
+. ./perf-lib.sh
+
+test_perf_default_repo
+
+test_expect_success 'create shareable repository' '
+	git clone --bare . shared.git
+'
+
+test_expect_success 'advance base repository' '
+	# Do not use test_commit here; its test_tick will
+	# use some ancient hard-coded date. The resulting clock
+	# skew will cause pack-objects to traverse in a very
+	# sub-optimal order, skewing the results.
+	echo content >new-file-that-does-not-exist &&
+	git add new-file-that-does-not-exist &&
+	git commit -m "new commit"
+'
+
+test_perf 'clone --reference' '
+	rm -rf dst.git &&
+	git clone --no-local --bare --reference shared.git . dst.git
+'
+
+test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/perf/perf-lib.sh 1.2.3+git2.25.1-1/git/t/perf/perf-lib.sh
--- 1.2.1+git2.18.0-1/git/t/perf/perf-lib.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/perf/perf-lib.sh	2020-02-17 04:47:35.000000000 +0000
@@ -17,37 +17,27 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see http://www.gnu.org/licenses/ .
 
-# do the --tee work early; it otherwise confuses our careful
-# GIT_BUILD_DIR mangling
-case "$GIT_TEST_TEE_STARTED, $* " in
-done,*)
-	# do not redirect again
-	;;
-*' --tee '*|*' --va'*)
-	mkdir -p test-results
-	BASE=test-results/$(basename "$0" .sh)
-	(GIT_TEST_TEE_STARTED=done ${SHELL-sh} "$0" "$@" 2>&1;
-	 echo $? > $BASE.exit) | tee $BASE.out
-	test "$(cat $BASE.exit)" = 0
-	exit
-	;;
-esac
-
+# These variables must be set before the inclusion of test-lib.sh below,
+# because it will change our working directory.
 TEST_DIRECTORY=$(pwd)/..
 TEST_OUTPUT_DIRECTORY=$(pwd)
-if test -z "$GIT_TEST_INSTALLED"; then
-	perf_results_prefix=
-else
-	perf_results_prefix=$(printf "%s" "${GIT_TEST_INSTALLED%/bin-wrappers}" | tr -c "[a-zA-Z0-9]" "[_*]")"."
-	# make the tested dir absolute
-	GIT_TEST_INSTALLED=$(cd "$GIT_TEST_INSTALLED" && pwd)
-fi
 
 TEST_NO_CREATE_REPO=t
 TEST_NO_MALLOC_CHECK=t
 
 . ../test-lib.sh
 
+if test -n "$GIT_TEST_INSTALLED" -a -z "$PERF_SET_GIT_TEST_INSTALLED"
+then
+	error "Do not use GIT_TEST_INSTALLED with the perf tests.
+
+Instead use:
+
+    ./run <path-to-git> -- <tests>
+
+See t/perf/README for details."
+fi
+
 # Variables from test-lib that are normally internal to the tests; we
 # need to export them for test_perf subshells
 export TEST_DIRECTORY TRASH_DIRECTORY GIT_BUILD_DIR GIT_TEST_CMP
@@ -82,7 +72,7 @@ test_perf_do_repo_symlink_config_ () {
 
 test_perf_create_repo_from () {
 	test "$#" = 2 ||
-	error "bug in the test script: not 2 parameters to test-create-repo"
+	BUG "not 2 parameters to test-create-repo"
 	repo="$1"
 	source="$2"
 	source_git="$("$MODERN_GIT" -C "$source" rev-parse --git-dir)"
@@ -179,47 +169,69 @@ exit $ret' >&3 2>&4
 	return "$eval_ret"
 }
 
-
-test_perf () {
+test_wrapper_ () {
+	test_wrapper_func_=$1; shift
 	test_start_
 	test "$#" = 3 && { test_prereq=$1; shift; } || test_prereq=
 	test "$#" = 2 ||
-	error "bug in the test script: not 2 or 3 parameters to test-expect-success"
+	BUG "not 2 or 3 parameters to test-expect-success"
 	export test_prereq
 	if ! test_skip "$@"
 	then
 		base=$(basename "$0" .sh)
 		echo "$test_count" >>"$perf_results_dir"/$base.subtests
 		echo "$1" >"$perf_results_dir"/$base.$test_count.descr
-		if test -z "$verbose"; then
-			printf "%s" "perf $test_count - $1:"
-		else
-			echo "perf $test_count - $1:"
-		fi
-		for i in $(test_seq 1 $GIT_PERF_REPEAT_COUNT); do
-			say >&3 "running: $2"
-			if test_run_perf_ "$2"
-			then
-				if test -z "$verbose"; then
-					printf " %s" "$i"
-				else
-					echo "* timing run $i/$GIT_PERF_REPEAT_COUNT:"
-				fi
+		base="$perf_results_dir"/"$PERF_RESULTS_PREFIX$(basename "$0" .sh)"."$test_count"
+		"$test_wrapper_func_" "$@"
+	fi
+
+	test_finish_
+}
+
+test_perf_ () {
+	if test -z "$verbose"; then
+		printf "%s" "perf $test_count - $1:"
+	else
+		echo "perf $test_count - $1:"
+	fi
+	for i in $(test_seq 1 $GIT_PERF_REPEAT_COUNT); do
+		say >&3 "running: $2"
+		if test_run_perf_ "$2"
+		then
+			if test -z "$verbose"; then
+				printf " %s" "$i"
 			else
-				test -z "$verbose" && echo
-				test_failure_ "$@"
-				break
+				echo "* timing run $i/$GIT_PERF_REPEAT_COUNT:"
 			fi
-		done
-		if test -z "$verbose"; then
-			echo " ok"
 		else
-			test_ok_ "$1"
+			test -z "$verbose" && echo
+			test_failure_ "$@"
+			break
 		fi
-		base="$perf_results_dir"/"$perf_results_prefix$(basename "$0" .sh)"."$test_count"
-		"$TEST_DIRECTORY"/perf/min_time.perl test_time.* >"$base".times
+	done
+	if test -z "$verbose"; then
+		echo " ok"
+	else
+		test_ok_ "$1"
 	fi
-	test_finish_
+	"$TEST_DIRECTORY"/perf/min_time.perl test_time.* >"$base".result
+}
+
+test_perf () {
+	test_wrapper_ test_perf_ "$@"
+}
+
+test_size_ () {
+	say >&3 "running: $2"
+	if test_eval_ "$2" 3>"$base".result; then
+		test_ok_ "$1"
+	else
+		test_failure_ "$@"
+	fi
+}
+
+test_size () {
+	test_wrapper_ test_size_ "$@"
 }
 
 # We extend test_done to print timings at the end (./run disables this
diff -pruN 1.2.1+git2.18.0-1/git/t/perf/README 1.2.3+git2.25.1-1/git/t/perf/README
--- 1.2.1+git2.18.0-1/git/t/perf/README	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/perf/README	2020-02-17 04:47:35.000000000 +0000
@@ -45,7 +45,7 @@ call the aggregation script to summarize
 
     $ ./p0001-rev-list.sh
     [...]
-    $ GIT_BUILD_DIR=/path/to/other/git ./p0001-rev-list.sh
+    $ ./run /path/to/other/git -- ./p0001-rev-list.sh
     [...]
     $ ./aggregate.perl . /path/to/other/git ./p0001-rev-list.sh
 
@@ -168,3 +168,28 @@ that
   While we have tried to make sure that it can cope with embedded
   whitespace and other special characters, it will not work with
   multi-line data.
+
+Rather than tracking the performance by run-time as `test_perf` does, you
+may also track output size by using `test_size`. The stdout of the
+function should be a single numeric value, which will be captured and
+shown in the aggregated output. For example:
+
+	test_perf 'time foo' '
+		./foo >foo.out
+	'
+
+	test_size 'output size'
+		wc -c <foo.out
+	'
+
+might produce output like:
+
+	Test                origin           HEAD
+	-------------------------------------------------------------
+	1234.1 time foo     0.37(0.79+0.02)  0.26(0.51+0.02) -29.7%
+	1234.2 output size             4.3M             3.6M -14.7%
+
+The item being measured (and its units) is up to the test; the context
+and the test title should make it clear to the user whether bigger or
+smaller numbers are better. Unlike test_perf, the test code will only be
+run once, since output sizes tend to be more deterministic than timings.
diff -pruN 1.2.1+git2.18.0-1/git/t/perf/run 1.2.3+git2.25.1-1/git/t/perf/run
--- 1.2.1+git2.18.0-1/git/t/perf/run	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/perf/run	2020-02-17 04:47:35.000000000 +0000
@@ -70,6 +70,24 @@ build_git_rev () {
 	) || die "failed to build revision '$mydir'"
 }
 
+set_git_test_installed () {
+	mydir=$1
+
+	mydir_abs=$(cd $mydir && pwd)
+	mydir_abs_wrappers="$mydir_abs_wrappers/bin-wrappers"
+	if test -d "$mydir_abs_wrappers"
+	then
+		GIT_TEST_INSTALLED=$mydir_abs_wrappers
+	else
+		# Older versions of git lacked bin-wrappers;
+		# fallback to the files in the root.
+		GIT_TEST_INSTALLED=$mydir_abs
+	fi
+	export GIT_TEST_INSTALLED
+	PERF_SET_GIT_TEST_INSTALLED=true
+	export PERF_SET_GIT_TEST_INSTALLED
+}
+
 run_dirs_helper () {
 	mydir=${1%/}
 	shift
@@ -79,7 +97,16 @@ run_dirs_helper () {
 	if test $# -gt 0 -a "$1" = --; then
 		shift
 	fi
-	if [ ! -d "$mydir" ]; then
+
+	PERF_RESULTS_PREFIX=
+	if test "$mydir" = "."
+	then
+		unset GIT_TEST_INSTALLED
+	elif test -d "$mydir"
+	then
+		PERF_RESULTS_PREFIX=bindir$(cd $mydir && printf "%s" "$(pwd)" | tr -c "[a-zA-Z0-9]" "_").
+		set_git_test_installed "$mydir"
+	else
 		rev=$(git rev-parse --verify "$mydir" 2>/dev/null) ||
 		die "'$mydir' is neither a directory nor a valid revision"
 		if [ ! -d build/$rev ]; then
@@ -87,16 +114,12 @@ run_dirs_helper () {
 		fi
 		build_git_rev $rev "$mydir"
 		mydir=build/$rev
+
+		PERF_RESULTS_PREFIX=build_$rev.
+		set_git_test_installed "$mydir"
 	fi
-	if test "$mydir" = .; then
-		unset GIT_TEST_INSTALLED
-	else
-		GIT_TEST_INSTALLED="$mydir/bin-wrappers"
-		# Older versions of git lacked bin-wrappers; fallback to the
-		# files in the root.
-		test -d "$GIT_TEST_INSTALLED" || GIT_TEST_INSTALLED=$mydir
-		export GIT_TEST_INSTALLED
-	fi
+	export PERF_RESULTS_PREFIX
+
 	run_one_dir "$@"
 }
 
diff -pruN 1.2.1+git2.18.0-1/git/t/README 1.2.3+git2.25.1-1/git/t/README
--- 1.2.1+git2.18.0-1/git/t/README	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/README	2020-02-17 04:47:35.000000000 +0000
@@ -154,6 +154,7 @@ appropriately before running "make".
 	As the names depend on the tests' file names, it is safe to
 	run the tests with this option in parallel.
 
+-V::
 --verbose-log::
 	Write verbose output to the same logfile as `--tee`, but do
 	_not_ write it to stdout. Unlike `--tee --verbose`, this option
@@ -169,6 +170,15 @@ appropriately before running "make".
 	implied by other options like --valgrind and
 	GIT_TEST_INSTALLED.
 
+--no-bin-wrappers::
+	By default, the test suite uses the wrappers in
+	`../bin-wrappers/` to execute `git` and friends. With this option,
+	`../git` and friends are run directly. This is not recommended
+	in general, as the wrappers contain safeguards to ensure that no
+	files from an installed Git are used, but can speed up test runs
+	especially on platforms where running shell scripts is expensive
+	(most notably, Windows).
+
 --root=<directory>::
 	Create "trash" directories used to store all temporary data during
 	testing under <directory>, instead of the t/ directory.
@@ -185,6 +195,29 @@ appropriately before running "make".
 	this feature by setting the GIT_TEST_CHAIN_LINT environment
 	variable to "1" or "0", respectively.
 
+--stress::
+	Run the test script repeatedly in multiple parallel jobs until
+	one of them fails.  Useful for reproducing rare failures in
+	flaky tests.  The number of parallel jobs is, in order of
+	precedence: the value of the GIT_TEST_STRESS_LOAD
+	environment variable, or twice the number of available
+	processors (as shown by the 'getconf' utility),	or 8.
+	Implies `--verbose -x --immediate` to get the most information
+	about the failure.  Note that the verbose output of each test
+	job is saved to 't/test-results/$TEST_NAME.stress-<nr>.out',
+	and only the output of the failed test job is shown on the
+	terminal.  The names of the trash directories get a
+	'.stress-<nr>' suffix, and the trash directory of the failed
+	test job is renamed to end with a '.stress-failed' suffix.
+
+--stress-jobs=<N>::
+	Override the number of parallel jobs. Implies `--stress`.
+
+--stress-limit=<N>::
+	When combined with --stress run the test script repeatedly
+	this many times in each of the parallel jobs or until one of
+	them fails, whichever comes first. Implies `--stress`.
+
 You can also set the GIT_TEST_INSTALLED environment variable to
 the bindir of an existing git installation to test that installation.
 You still need to have built this git sandbox, from which various
@@ -301,9 +334,27 @@ that cannot be easily covered by a few s
 could be enabled by running the test suite with correct GIT_TEST_
 environment set.
 
+GIT_TEST_FAIL_PREREQS=<boolean> fails all prerequisites. This is
+useful for discovering issues with the tests where say a later test
+implicitly depends on an optional earlier test.
+
+There's a "FAIL_PREREQS" prerequisite that can be used to test for
+whether this mode is active, and e.g. skip some tests that are hard to
+refactor to deal with it. The "SYMLINKS" prerequisite is currently
+excluded as so much relies on it, but this might change in the future.
+
+GIT_TEST_GETTEXT_POISON=<boolean> turns all strings marked for
+translation into gibberish if true. Used for spotting those tests that
+need to be marked with a C_LOCALE_OUTPUT prerequisite when adding more
+strings for translation. See "Testing marked strings" in po/README for
+details.
+
 GIT_TEST_SPLIT_INDEX=<boolean> forces split-index mode on the whole
 test suite. Accept any boolean values that are accepted by git-config.
 
+GIT_TEST_PROTOCOL_VERSION=<n>, when set, overrides the
+'protocol.version' setting to n if it is less than n.
+
 GIT_TEST_FULL_IN_PACK_ARRAY=<boolean> exercises the uncommon
 pack-objects code path where there are more than 1024 packs even if
 the actual number of packs in repository is below this limit. Accept
@@ -315,6 +366,59 @@ packs on demand. This normally only happ
 over 2GB. This variable forces the code path on any object larger than
 <n> bytes.
 
+GIT_TEST_OE_DELTA_SIZE=<n> exercises the uncommon pack-objects code
+path where deltas larger than this limit require extra memory
+allocation for bookkeeping.
+
+GIT_TEST_VALIDATE_INDEX_CACHE_ENTRIES=<boolean> checks that cache-tree
+records are valid when the index is written out or after a merge. This
+is mostly to catch missing invalidation. Default is true.
+
+GIT_TEST_COMMIT_GRAPH=<boolean>, when true, forces the commit-graph to
+be written after every 'git commit' command, and overrides the
+'core.commitGraph' setting to true.
+
+GIT_TEST_FSMONITOR=$PWD/t7519/fsmonitor-all exercises the fsmonitor
+code path for utilizing a file system monitor to speed up detecting
+new or changed files.
+
+GIT_TEST_INDEX_VERSION=<n> exercises the index read/write code path
+for the index version specified.  Can be set to any valid version
+(currently 2, 3, or 4).
+
+GIT_TEST_PACK_SPARSE=<boolean> if enabled will default the pack-objects
+builtin to use the sparse object walk. This can still be overridden by
+the --no-sparse command-line argument.
+
+GIT_TEST_PRELOAD_INDEX=<boolean> exercises the preload-index code path
+by overriding the minimum number of cache entries required per thread.
+
+GIT_TEST_STASH_USE_BUILTIN=<boolean>, when false, disables the
+built-in version of git-stash. See 'stash.useBuiltin' in
+git-config(1).
+
+GIT_TEST_ADD_I_USE_BUILTIN=<boolean>, when true, enables the
+built-in version of git add -i. See 'add.interactive.useBuiltin' in
+git-config(1).
+
+GIT_TEST_INDEX_THREADS=<n> enables exercising the multi-threaded loading
+of the index for the whole test suite by bypassing the default number of
+cache entries and thread minimums. Setting this to 1 will make the
+index loading single threaded.
+
+GIT_TEST_MULTI_PACK_INDEX=<boolean>, when true, forces the multi-pack-
+index to be written after every 'git repack' command, and overrides the
+'core.multiPackIndex' setting to true.
+
+GIT_TEST_SIDEBAND_ALL=<boolean>, when true, overrides the
+'uploadpack.allowSidebandAll' setting to true, and when false, forces
+fetch-pack to not request sideband-all (even if the server advertises
+sideband-all).
+
+GIT_TEST_DISALLOW_ABBREVIATED_OPTIONS=<boolean>, when true (which is
+the default when running tests), errors out when an abbreviated option
+is used.
+
 Naming Tests
 ------------
 
@@ -382,20 +486,21 @@ This test harness library does the follo
  - Creates an empty test directory with an empty .git/objects database
    and chdir(2) into it.  This directory is 't/trash
    directory.$test_name_without_dotsh', with t/ subject to change by
-   the --root option documented above.
+   the --root option documented above, and a '.stress-<N>' suffix
+   appended by the --stress option.
 
  - Defines standard test helper functions for your scripts to
    use.  These functions are designed to make all scripts behave
    consistently when command line arguments --verbose (or -v),
    --debug (or -d), and --immediate (or -i) is given.
 
-Do's, don'ts & things to keep in mind
--------------------------------------
+Do's & don'ts
+-------------
 
 Here are a few examples of things you probably should and shouldn't do
 when writing tests.
 
-Do:
+Here are the "do's:"
 
  - Put all code inside test_expect_success and other assertions.
 
@@ -440,16 +545,21 @@ Do:
    Windows, where the shell (MSYS bash) mangles absolute path names.
    For details, see the commit message of 4114156ae9.
 
-Don't:
+ - Remember that inside the <script> part, the standard output and
+   standard error streams are discarded, and the test harness only
+   reports "ok" or "not ok" to the end user running the tests. Under
+   --verbose, they are shown to help debug the tests.
+
+And here are the "don'ts:"
 
- - exit() within a <script> part.
+ - Don't exit() within a <script> part.
 
    The harness will catch this as a programming error of the test.
    Use test_done instead if you need to stop the tests early (see
    "Skipping tests" below).
 
- - use '! git cmd' when you want to make sure the git command exits
-   with failure in a controlled way by calling "die()".  Instead,
+ - Don't use '! git cmd' when you want to make sure the git command
+   exits with failure in a controlled way by calling "die()".  Instead,
    use 'test_must_fail git cmd'.  This will signal a failure if git
    dies in an unexpected way (e.g. segfault).
 
@@ -457,8 +567,35 @@ Don't:
    platform commands; just use '! cmd'.  We are not in the business
    of verifying that the world given to us sanely works.
 
- - use perl without spelling it as "$PERL_PATH". This is to help our
-   friends on Windows where the platform Perl often adds CR before
+ - Don't feed the output of a git command to a pipe, as in:
+
+     git -C repo ls-files |
+     xargs -n 1 basename |
+     grep foo
+
+   which will discard git's exit code and may mask a crash. In the
+   above example, all exit codes are ignored except grep's.
+
+   Instead, write the output of that command to a temporary
+   file with ">" or assign it to a variable with "x=$(git ...)" rather
+   than pipe it.
+
+ - Don't use command substitution in a way that discards git's exit
+   code. When assigning to a variable, the exit code is not discarded,
+   e.g.:
+
+     x=$(git cat-file -p $sha) &&
+     ...
+
+   is OK because a crash in "git cat-file" will cause the "&&" chain
+   to fail, but:
+
+     test "refs/heads/foo" = "$(git symbolic-ref HEAD)"
+
+   is not OK and a crash in git could go undetected.
+
+ - Don't use perl without spelling it as "$PERL_PATH". This is to help
+   our friends on Windows where the platform Perl often adds CR before
    the end of line, and they bundle Git with a version of Perl that
    does not do so, whose path is specified with $PERL_PATH. Note that we
    provide a "perl" function which uses $PERL_PATH under the hood, so
@@ -466,17 +603,17 @@ Don't:
    (but you do, for example, on a shebang line or in a sub script
    created via "write_script").
 
- - use sh without spelling it as "$SHELL_PATH", when the script can
-   be misinterpreted by broken platform shell (e.g. Solaris).
+ - Don't use sh without spelling it as "$SHELL_PATH", when the script
+   can be misinterpreted by broken platform shell (e.g. Solaris).
 
- - chdir around in tests.  It is not sufficient to chdir to
+ - Don't chdir around in tests.  It is not sufficient to chdir to
    somewhere and then chdir back to the original location later in
    the test, as any intermediate step can fail and abort the test,
    causing the next test to start in an unexpected directory.  Do so
    inside a subshell if necessary.
 
- - save and verify the standard error of compound commands, i.e. group
-   commands, subshells, and shell functions (except test helper
+ - Don't save and verify the standard error of compound commands, i.e.
+   group commands, subshells, and shell functions (except test helper
    functions like 'test_must_fail') like this:
 
      ( cd dir && git cmd ) 2>error &&
@@ -491,7 +628,7 @@ Don't:
      ( cd dir && git cmd 2>../error ) &&
      test_cmp expect error
 
- - Break the TAP output
+ - Don't break the TAP output
 
    The raw output from your test may be interpreted by a TAP harness. TAP
    harnesses will ignore everything they don't know about, but don't step
@@ -511,13 +648,6 @@ Don't:
    but the best indication is to just run the tests with prove(1),
    it'll complain if anything is amiss.
 
-Keep in mind:
-
- - Inside the <script> part, the standard output and standard error
-   streams are discarded, and the test harness only reports "ok" or
-   "not ok" to the end user running the tests. Under --verbose, they
-   are shown to help debugging the tests.
-
 
 Skipping tests
 --------------
@@ -754,6 +884,26 @@ library for your script to use.
 		...
 	'
 
+ - test_atexit <script>
+
+   Prepend <script> to a list of commands to run unconditionally to
+   clean up before the test script exits, e.g. to stop a daemon:
+
+	test_expect_success 'test git daemon' '
+		git daemon &
+		daemon_pid=$! &&
+		test_atexit 'kill $daemon_pid' &&
+		hello world
+	'
+
+   The commands will be executed before the trash directory is removed,
+   i.e. the atexit commands will still be able to access any pidfiles or
+   socket files.
+
+   Note that these commands will be run even when a test script run
+   with '--immediate' fails.  Be careful with your atexit commands to
+   minimize any changes to the failed state.
+
  - test_write_lines <lines>
 
    Write <lines> on standard output, one line per argument.
@@ -802,6 +952,46 @@ library for your script to use.
    the symbolic link in the file system and a part that does; then only
    the latter part need be protected by a SYMLINKS prerequisite (see below).
 
+ - test_oid_init
+
+   This function loads facts and useful object IDs related to the hash
+   algorithm(s) in use from the files in t/oid-info.
+
+ - test_oid_cache
+
+   This function reads per-hash algorithm information from standard
+   input (usually a heredoc) in the format described in
+   t/oid-info/README.  This is useful for test-specific values, such as
+   object IDs, which must vary based on the hash algorithm.
+
+   Certain fixed values, such as hash sizes and common placeholder
+   object IDs, can be loaded with test_oid_init (described above).
+
+ - test_oid <key>
+
+   This function looks up a value for the hash algorithm in use, based
+   on the key given.  The value must have been loaded using
+   test_oid_init or test_oid_cache.  Providing an unknown key is an
+   error.
+
+ - yes [<string>]
+
+   This is often seen in modern UNIX but some platforms lack it, so
+   the test harness overrides the platform implementation with a
+   more limited one.  Use this only when feeding a handful lines of
+   output to the downstream---unlike the real version, it generates
+   only up to 99 lines.
+
+ - test_bool_env <env-variable-name> <default-value>
+
+   Given the name of an environment variable with a bool value,
+   normalize its value to a 0 (true) or 1 (false or empty string)
+   return code.  Return with code corresponding to the given default
+   value if the variable is unset.
+   Abort the test script if either the value of the variable or the
+   default are not valid bool values.
+
+
 Prerequisites
 -------------
 
diff -pruN 1.2.1+git2.18.0-1/git/t/t0000-basic.sh 1.2.3+git2.25.1-1/git/t/t0000-basic.sh
--- 1.2.1+git2.18.0-1/git/t/t0000-basic.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t0000-basic.sh	2020-02-17 04:47:35.000000000 +0000
@@ -20,28 +20,27 @@ modification *should* take notice and up
 
 . ./test-lib.sh
 
-try_local_x () {
-	local x="local" &&
-	echo "$x"
+try_local_xy () {
+	local x="local" y="alsolocal" &&
+	echo "$x $y"
 }
 
-# This test is an experiment to check whether any Git users are using
-# Shells that don't support the "local" keyword. "local" is not
+# Check whether the shell supports the "local" keyword. "local" is not
 # POSIX-standard, but it is very widely supported by POSIX-compliant
-# shells, and if it doesn't cause problems for people, we would like
-# to be able to use it in Git code.
+# shells, and we rely on it within Git's test framework.
 #
-# For now, this is the only test that requires "local". If your shell
-# fails this test, you can ignore the failure, but please report the
-# problem to the Git mailing list <git@vger.kernel.org>, as it might
-# convince us to continue avoiding the use of "local".
+# If your shell fails this test, the results of other tests may be
+# unreliable. You may wish to report the problem to the Git mailing
+# list <git@vger.kernel.org>, as it could cause us to reconsider
+# relying on "local".
 test_expect_success 'verify that the running shell supports "local"' '
 	x="notlocal" &&
-	echo "local" >expected1 &&
-	try_local_x >actual1 &&
+	y="alsonotlocal" &&
+	echo "local alsolocal" >expected1 &&
+	try_local_xy >actual1 &&
 	test_cmp expected1 actual1 &&
-	echo "notlocal" >expected2 &&
-	echo "$x" >actual2 &&
+	echo "notlocal alsonotlocal" >expected2 &&
+	echo "$x $y" >actual2 &&
 	test_cmp expected2 actual2
 '
 
@@ -87,6 +86,10 @@ _run_sub_test_lib_test_common () {
 		passing metrics
 		'
 
+		# Tell the framework that we are self-testing to make sure
+		# it yields a stable result.
+		GIT_TEST_FRAMEWORK_SELFTEST=t &&
+
 		# Point to the t/test-lib.sh, which isn't in ../ as usual
 		. "\$TEST_DIRECTORY"/test-lib.sh
 		EOF
@@ -116,7 +119,7 @@ check_sub_test_lib_test () {
 	name="$1" # stdin is the expected output from the test
 	(
 		cd "$name" &&
-		! test -s err &&
+		test_must_be_empty err &&
 		sed -e 's/^> //' -e 's/Z$//' >expect &&
 		test_cmp expect out
 	)
@@ -124,7 +127,7 @@ check_sub_test_lib_test () {
 
 check_sub_test_lib_test_err () {
 	name="$1" # stdin is the expected output from the test
-	# expected error output is in descriptior 3
+	# expected error output is in descriptor 3
 	(
 		cd "$name" &&
 		sed -e 's/^> //' -e 's/Z$//' >expect.out &&
@@ -270,25 +273,25 @@ test_expect_success 'pretend we have a m
 	EOF
 "
 
-test_expect_success 'test --verbose' '
+test_expect_success C_LOCALE_OUTPUT 'test --verbose' '
 	test_must_fail run_sub_test_lib_test \
-		test-verbose "test verbose" --verbose <<-\EOF &&
+		t1234-verbose "test verbose" --verbose <<-\EOF &&
 	test_expect_success "passing test" true
 	test_expect_success "test with output" "echo foo"
 	test_expect_success "failing test" false
 	test_done
 	EOF
-	mv test-verbose/out test-verbose/out+ &&
-	grep -v "^Initialized empty" test-verbose/out+ >test-verbose/out &&
-	check_sub_test_lib_test test-verbose <<-\EOF
-	> expecting success: true
+	mv t1234-verbose/out t1234-verbose/out+ &&
+	grep -v "^Initialized empty" t1234-verbose/out+ >t1234-verbose/out &&
+	check_sub_test_lib_test t1234-verbose <<-\EOF
+	> expecting success of 1234.1 '\''passing test'\'': true
 	> ok 1 - passing test
 	> Z
-	> expecting success: echo foo
+	> expecting success of 1234.2 '\''test with output'\'': echo foo
 	> foo
 	> ok 2 - test with output
 	> Z
-	> expecting success: false
+	> expecting success of 1234.3 '\''failing test'\'': false
 	> not ok 3 - failing test
 	> #	false
 	> Z
@@ -299,17 +302,17 @@ test_expect_success 'test --verbose' '
 
 test_expect_success 'test --verbose-only' '
 	test_must_fail run_sub_test_lib_test \
-		test-verbose-only-2 "test verbose-only=2" \
+		t2345-verbose-only-2 "test verbose-only=2" \
 		--verbose-only=2 <<-\EOF &&
 	test_expect_success "passing test" true
 	test_expect_success "test with output" "echo foo"
 	test_expect_success "failing test" false
 	test_done
 	EOF
-	check_sub_test_lib_test test-verbose-only-2 <<-\EOF
+	check_sub_test_lib_test t2345-verbose-only-2 <<-\EOF
 	> ok 1 - passing test
 	> Z
-	> expecting success: echo foo
+	> expecting success of 2345.2 '\''test with output'\'': echo foo
 	> foo
 	> ok 2 - test with output
 	> Z
@@ -389,6 +392,44 @@ test_expect_success 'GIT_SKIP_TESTS sh p
 	)
 "
 
+test_expect_success 'GIT_SKIP_TESTS entire suite' "
+	(
+		GIT_SKIP_TESTS='git' && export GIT_SKIP_TESTS &&
+		run_sub_test_lib_test git-skip-tests-entire-suite \
+			'GIT_SKIP_TESTS entire suite' <<-\\EOF &&
+		for i in 1 2 3
+		do
+			test_expect_success \"passing test #\$i\" 'true'
+		done
+		test_done
+		EOF
+		check_sub_test_lib_test git-skip-tests-entire-suite <<-\\EOF
+		> 1..0 # SKIP skip all tests in git
+		EOF
+	)
+"
+
+test_expect_success 'GIT_SKIP_TESTS does not skip unmatched suite' "
+	(
+		GIT_SKIP_TESTS='notgit' && export GIT_SKIP_TESTS &&
+		run_sub_test_lib_test git-skip-tests-unmatched-suite \
+			'GIT_SKIP_TESTS does not skip unmatched suite' <<-\\EOF &&
+		for i in 1 2 3
+		do
+			test_expect_success \"passing test #\$i\" 'true'
+		done
+		test_done
+		EOF
+		check_sub_test_lib_test git-skip-tests-unmatched-suite <<-\\EOF
+		> ok 1 - passing test #1
+		> ok 2 - passing test #2
+		> ok 3 - passing test #3
+		> # passed all 3 test(s)
+		> 1..3
+		EOF
+	)
+"
+
 test_expect_success '--run basic' "
 	run_sub_test_lib_test run-basic \
 		'--run basic' --run='1 3 5' <<-\\EOF &&
@@ -722,7 +763,7 @@ donthaveit=yes
 test_expect_success DONTHAVEIT 'unmet prerequisite causes test to be skipped' '
 	donthaveit=no
 '
-if test $haveit$donthaveit != yesyes
+if test -z "$GIT_TEST_FAIL_PREREQS_INTERNAL" -a $haveit$donthaveit != yesyes
 then
 	say "bug in test framework: prerequisite tags do not work reliably"
 	exit 1
@@ -743,7 +784,7 @@ donthaveiteither=yes
 test_expect_success DONTHAVEIT,HAVEIT 'unmet prerequisites causes test to be skipped' '
 	donthaveiteither=no
 '
-if test $haveit$donthaveit$donthaveiteither != yesyesyes
+if test -z "$GIT_TEST_FAIL_PREREQS_INTERNAL" -a $haveit$donthaveit$donthaveiteither != yesyesyes
 then
 	say "bug in test framework: multiple prerequisite tags do not work reliably"
 	exit 1
@@ -759,7 +800,7 @@ test_expect_success !LAZY_TRUE 'missing
 	donthavetrue=no
 '
 
-if test "$havetrue$donthavetrue" != yesyes
+if test -z "$GIT_TEST_FAIL_PREREQS_INTERNAL" -a "$havetrue$donthavetrue" != yesyes
 then
 	say 'bug in test framework: lazy prerequisites do not work'
 	exit 1
@@ -775,7 +816,7 @@ test_expect_success LAZY_FALSE 'missing
 	havefalse=no
 '
 
-if test "$nothavefalse$havefalse" != yesyes
+if test -z "$GIT_TEST_FAIL_PREREQS_INTERNAL" -a "$nothavefalse$havefalse" != yesyes
 then
 	say 'bug in test framework: negative lazy prerequisites do not work'
 	exit 1
@@ -786,7 +827,7 @@ test_expect_success 'tests clean up afte
 	test_when_finished clean=yes
 '
 
-if test $clean != yes
+if test -z "$GIT_TEST_FAIL_PREREQS_INTERNAL" -a $clean != yes
 then
 	say "bug in test framework: basic cleanup command does not work reliably"
 	exit 1
@@ -821,9 +862,139 @@ test_expect_success 'tests clean up even
 	EOF
 "
 
+test_expect_success 'test_atexit is run' "
+	test_must_fail run_sub_test_lib_test \
+		atexit-cleanup 'Run atexit commands' -i <<-\\EOF &&
+	test_expect_success 'tests clean up even after a failure' '
+		> ../../clean-atexit &&
+		test_atexit rm ../../clean-atexit &&
+		> ../../also-clean-atexit &&
+		test_atexit rm ../../also-clean-atexit &&
+		> ../../dont-clean-atexit &&
+		(exit 1)
+	'
+	test_done
+	EOF
+	test_path_is_file dont-clean-atexit &&
+	test_path_is_missing clean-atexit &&
+	test_path_is_missing also-clean-atexit
+"
+
+test_expect_success 'test_oid setup' '
+	test_oid_init
+'
+
+test_expect_success 'test_oid provides sane info by default' '
+	test_oid zero >actual &&
+	grep "^00*\$" actual &&
+	rawsz="$(test_oid rawsz)" &&
+	hexsz="$(test_oid hexsz)" &&
+	test "$hexsz" -eq $(wc -c <actual) &&
+	test $(( $rawsz * 2)) -eq "$hexsz"
+'
+
+test_expect_success 'test_oid can look up data for SHA-1' '
+	test_when_finished "test_detect_hash" &&
+	test_set_hash sha1 &&
+	test_oid zero >actual &&
+	grep "^00*\$" actual &&
+	rawsz="$(test_oid rawsz)" &&
+	hexsz="$(test_oid hexsz)" &&
+	test $(wc -c <actual) -eq 40 &&
+	test "$rawsz" -eq 20 &&
+	test "$hexsz" -eq 40
+'
+
+test_expect_success 'test_oid can look up data for SHA-256' '
+	test_when_finished "test_detect_hash" &&
+	test_set_hash sha256 &&
+	test_oid zero >actual &&
+	grep "^00*\$" actual &&
+	rawsz="$(test_oid rawsz)" &&
+	hexsz="$(test_oid hexsz)" &&
+	test $(wc -c <actual) -eq 64 &&
+	test "$rawsz" -eq 32 &&
+	test "$hexsz" -eq 64
+'
+
+test_expect_success 'test_bool_env' '
+	(
+		sane_unset envvar &&
+
+		test_bool_env envvar true &&
+		! test_bool_env envvar false &&
+
+		envvar= &&
+		export envvar &&
+		! test_bool_env envvar true &&
+		! test_bool_env envvar false &&
+
+		envvar=true &&
+		test_bool_env envvar true &&
+		test_bool_env envvar false &&
+
+		envvar=false &&
+		! test_bool_env envvar true &&
+		! test_bool_env envvar false &&
+
+		envvar=invalid &&
+		# When encountering an invalid bool value, test_bool_env
+		# prints its error message to the original stderr of the
+		# test script, hence the redirection of fd 7, and aborts
+		# with "exit 1", hence the subshell.
+		! ( test_bool_env envvar true ) 7>err &&
+		grep "error: test_bool_env requires bool values" err &&
+
+		envvar=true &&
+		! ( test_bool_env envvar invalid ) 7>err &&
+		grep "error: test_bool_env requires bool values" err
+	)
+'
+
 ################################################################
 # Basics of the basics
 
+test_oid_cache <<\EOF
+path0f sha1:f87290f8eb2cbbea7857214459a0739927eab154
+path0f sha256:638106af7c38be056f3212cbd7ac65bc1bac74f420ca5a436ff006a9d025d17d
+
+path0s sha1:15a98433ae33114b085f3eb3bb03b832b3180a01
+path0s sha256:3a24cc53cf68edddac490bbf94a418a52932130541361f685df685e41dd6c363
+
+path2f sha1:3feff949ed00a62d9f7af97c15cd8a30595e7ac7
+path2f sha256:2a7f36571c6fdbaf0e3f62751a0b25a3f4c54d2d1137b3f4af9cb794bb498e5f
+
+path2s sha1:d8ce161addc5173867a3c3c730924388daedbc38
+path2s sha256:18fd611b787c2e938ddcc248fabe4d66a150f9364763e9ec133dd01d5bb7c65a
+
+path2d sha1:58a09c23e2ca152193f2786e06986b7b6712bdbe
+path2d sha256:00e4b32b96e7e3d65d79112dcbea53238a22715f896933a62b811377e2650c17
+
+path3f sha1:0aa34cae68d0878578ad119c86ca2b5ed5b28376
+path3f sha256:09f58616b951bd571b8cb9dc76d372fbb09ab99db2393f5ab3189d26c45099ad
+
+path3s sha1:8599103969b43aff7e430efea79ca4636466794f
+path3s sha256:fce1aed087c053306f3f74c32c1a838c662bbc4551a7ac2420f5d6eb061374d0
+
+path3d sha1:21ae8269cacbe57ae09138dcc3a2887f904d02b3
+path3d sha256:9b60497be959cb830bf3f0dc82bcc9ad9e925a24e480837ade46b2295e47efe1
+
+subp3f sha1:00fb5908cb97c2564a9783c0c64087333b3b464f
+subp3f sha256:a1a9e16998c988453f18313d10375ee1d0ddefe757e710dcae0d66aa1e0c58b3
+
+subp3s sha1:6649a1ebe9e9f1c553b66f5a6e74136a07ccc57c
+subp3s sha256:81759d9f5e93c6546ecfcadb560c1ff057314b09f93fe8ec06e2d8610d34ef10
+
+subp3d sha1:3c5e5399f3a333eddecce7a9b9465b63f65f51e2
+subp3d sha256:76b4ef482d4fa1c754390344cf3851c7f883b27cf9bc999c6547928c46aeafb7
+
+root sha1:087704a96baf1c2d1c869a8b084481e121c88b5b
+root sha256:9481b52abab1b2ffeedbf9de63ce422b929f179c1b98ff7bee5f8f1bc0710751
+
+simpletree sha1:7bb943559a305bdd6bdee2cef6e5df2413c3d30a
+simpletree sha256:1710c07a6c86f9a3c7376364df04c47ee39e5a5e221fcdd84b743bc9bb7e2bc5
+EOF
+
 # updating a new file without --add should fail.
 test_expect_success 'git update-index without --add should fail adding' '
 	test_must_fail git update-index should-be-empty
@@ -839,8 +1010,8 @@ test_expect_success 'writing tree out wi
 '
 
 # we know the shape and contents of the tree and know the object ID for it.
-test_expect_success SHA1 'validate object ID of a known tree' '
-	test "$tree" = 7bb943559a305bdd6bdee2cef6e5df2413c3d30a
+test_expect_success 'validate object ID of a known tree' '
+	test "$tree" = "$(test_oid simpletree)"
     '
 
 # Removing paths.
@@ -882,16 +1053,16 @@ test_expect_success 'showing stage with
 	git ls-files --stage >current
 '
 
-test_expect_success SHA1 'validate git ls-files output for a known tree' '
-	cat >expected <<-\EOF &&
-	100644 f87290f8eb2cbbea7857214459a0739927eab154 0	path0
-	120000 15a98433ae33114b085f3eb3bb03b832b3180a01 0	path0sym
-	100644 3feff949ed00a62d9f7af97c15cd8a30595e7ac7 0	path2/file2
-	120000 d8ce161addc5173867a3c3c730924388daedbc38 0	path2/file2sym
-	100644 0aa34cae68d0878578ad119c86ca2b5ed5b28376 0	path3/file3
-	120000 8599103969b43aff7e430efea79ca4636466794f 0	path3/file3sym
-	100644 00fb5908cb97c2564a9783c0c64087333b3b464f 0	path3/subp3/file3
-	120000 6649a1ebe9e9f1c553b66f5a6e74136a07ccc57c 0	path3/subp3/file3sym
+test_expect_success 'validate git ls-files output for a known tree' '
+	cat >expected <<-EOF &&
+	100644 $(test_oid path0f) 0	path0
+	120000 $(test_oid path0s) 0	path0sym
+	100644 $(test_oid path2f) 0	path2/file2
+	120000 $(test_oid path2s) 0	path2/file2sym
+	100644 $(test_oid path3f) 0	path3/file3
+	120000 $(test_oid path3s) 0	path3/file3sym
+	100644 $(test_oid subp3f) 0	path3/subp3/file3
+	120000 $(test_oid subp3s) 0	path3/subp3/file3sym
 	EOF
 	test_cmp expected current
 '
@@ -900,20 +1071,20 @@ test_expect_success 'writing tree out wi
 	tree=$(git write-tree)
 '
 
-test_expect_success SHA1 'validate object ID for a known tree' '
-	test "$tree" = 087704a96baf1c2d1c869a8b084481e121c88b5b
+test_expect_success 'validate object ID for a known tree' '
+	test "$tree" = "$(test_oid root)"
 '
 
 test_expect_success 'showing tree with git ls-tree' '
     git ls-tree $tree >current
 '
 
-test_expect_success SHA1 'git ls-tree output for a known tree' '
-	cat >expected <<-\EOF &&
-	100644 blob f87290f8eb2cbbea7857214459a0739927eab154	path0
-	120000 blob 15a98433ae33114b085f3eb3bb03b832b3180a01	path0sym
-	040000 tree 58a09c23e2ca152193f2786e06986b7b6712bdbe	path2
-	040000 tree 21ae8269cacbe57ae09138dcc3a2887f904d02b3	path3
+test_expect_success 'git ls-tree output for a known tree' '
+	cat >expected <<-EOF &&
+	100644 blob $(test_oid path0f)	path0
+	120000 blob $(test_oid path0s)	path0sym
+	040000 tree $(test_oid path2d)	path2
+	040000 tree $(test_oid path3d)	path3
 	EOF
 	test_cmp expected current
 '
@@ -924,16 +1095,16 @@ test_expect_success 'showing tree with g
 	git ls-tree -r $tree >current
 '
 
-test_expect_success SHA1 'git ls-tree -r output for a known tree' '
-	cat >expected <<-\EOF &&
-	100644 blob f87290f8eb2cbbea7857214459a0739927eab154	path0
-	120000 blob 15a98433ae33114b085f3eb3bb03b832b3180a01	path0sym
-	100644 blob 3feff949ed00a62d9f7af97c15cd8a30595e7ac7	path2/file2
-	120000 blob d8ce161addc5173867a3c3c730924388daedbc38	path2/file2sym
-	100644 blob 0aa34cae68d0878578ad119c86ca2b5ed5b28376	path3/file3
-	120000 blob 8599103969b43aff7e430efea79ca4636466794f	path3/file3sym
-	100644 blob 00fb5908cb97c2564a9783c0c64087333b3b464f	path3/subp3/file3
-	120000 blob 6649a1ebe9e9f1c553b66f5a6e74136a07ccc57c	path3/subp3/file3sym
+test_expect_success 'git ls-tree -r output for a known tree' '
+	cat >expected <<-EOF &&
+	100644 blob $(test_oid path0f)	path0
+	120000 blob $(test_oid path0s)	path0sym
+	100644 blob $(test_oid path2f)	path2/file2
+	120000 blob $(test_oid path2s)	path2/file2sym
+	100644 blob $(test_oid path3f)	path3/file3
+	120000 blob $(test_oid path3s)	path3/file3sym
+	100644 blob $(test_oid subp3f)	path3/subp3/file3
+	120000 blob $(test_oid subp3s)	path3/subp3/file3sym
 	EOF
 	test_cmp expected current
 '
@@ -943,19 +1114,19 @@ test_expect_success 'showing tree with g
 	git ls-tree -r -t $tree >current
 '
 
-test_expect_success SHA1 'git ls-tree -r output for a known tree' '
-	cat >expected <<-\EOF &&
-	100644 blob f87290f8eb2cbbea7857214459a0739927eab154	path0
-	120000 blob 15a98433ae33114b085f3eb3bb03b832b3180a01	path0sym
-	040000 tree 58a09c23e2ca152193f2786e06986b7b6712bdbe	path2
-	100644 blob 3feff949ed00a62d9f7af97c15cd8a30595e7ac7	path2/file2
-	120000 blob d8ce161addc5173867a3c3c730924388daedbc38	path2/file2sym
-	040000 tree 21ae8269cacbe57ae09138dcc3a2887f904d02b3	path3
-	100644 blob 0aa34cae68d0878578ad119c86ca2b5ed5b28376	path3/file3
-	120000 blob 8599103969b43aff7e430efea79ca4636466794f	path3/file3sym
-	040000 tree 3c5e5399f3a333eddecce7a9b9465b63f65f51e2	path3/subp3
-	100644 blob 00fb5908cb97c2564a9783c0c64087333b3b464f	path3/subp3/file3
-	120000 blob 6649a1ebe9e9f1c553b66f5a6e74136a07ccc57c	path3/subp3/file3sym
+test_expect_success 'git ls-tree -r output for a known tree' '
+	cat >expected <<-EOF &&
+	100644 blob $(test_oid path0f)	path0
+	120000 blob $(test_oid path0s)	path0sym
+	040000 tree $(test_oid path2d)	path2
+	100644 blob $(test_oid path2f)	path2/file2
+	120000 blob $(test_oid path2s)	path2/file2sym
+	040000 tree $(test_oid path3d)	path3
+	100644 blob $(test_oid path3f)	path3/file3
+	120000 blob $(test_oid path3s)	path3/file3sym
+	040000 tree $(test_oid subp3d)	path3/subp3
+	100644 blob $(test_oid subp3f)	path3/subp3/file3
+	120000 blob $(test_oid subp3s)	path3/subp3/file3sym
 	EOF
 	test_cmp expected current
 '
@@ -964,26 +1135,27 @@ test_expect_success 'writing partial tre
 	ptree=$(git write-tree --prefix=path3)
 '
 
-test_expect_success SHA1 'validate object ID for a known tree' '
-	test "$ptree" = 21ae8269cacbe57ae09138dcc3a2887f904d02b3
+test_expect_success 'validate object ID for a known tree' '
+	test "$ptree" = $(test_oid path3d)
 '
 
 test_expect_success 'writing partial tree out with git write-tree --prefix' '
 	ptree=$(git write-tree --prefix=path3/subp3)
 '
 
-test_expect_success SHA1 'validate object ID for a known tree' '
-	test "$ptree" = 3c5e5399f3a333eddecce7a9b9465b63f65f51e2
+test_expect_success 'validate object ID for a known tree' '
+	test "$ptree" = $(test_oid subp3d)
 '
 
 test_expect_success 'put invalid objects into the index' '
 	rm -f .git/index &&
-	cat >badobjects <<-\EOF &&
-	100644 blob 1000000000000000000000000000000000000000	dir/file1
-	100644 blob 2000000000000000000000000000000000000000	dir/file2
-	100644 blob 3000000000000000000000000000000000000000	dir/file3
-	100644 blob 4000000000000000000000000000000000000000	dir/file4
-	100644 blob 5000000000000000000000000000000000000000	dir/file5
+	suffix=$(echo $ZERO_OID | sed -e "s/^.//") &&
+	cat >badobjects <<-EOF &&
+	100644 blob $(test_oid 001)	dir/file1
+	100644 blob $(test_oid 002)	dir/file2
+	100644 blob $(test_oid 003)	dir/file3
+	100644 blob $(test_oid 004)	dir/file4
+	100644 blob $(test_oid 005)	dir/file5
 	EOF
 	git update-index --index-info <badobjects
 '
@@ -1006,19 +1178,19 @@ test_expect_success 'git read-tree follo
 	test "$newtree" = "$tree"
 '
 
-test_expect_success SHA1 'validate git diff-files output for a know cache/work tree state' '
-	cat >expected <<\EOF &&
-:100644 100644 f87290f8eb2cbbea7857214459a0739927eab154 0000000000000000000000000000000000000000 M	path0
-:120000 120000 15a98433ae33114b085f3eb3bb03b832b3180a01 0000000000000000000000000000000000000000 M	path0sym
-:100644 100644 3feff949ed00a62d9f7af97c15cd8a30595e7ac7 0000000000000000000000000000000000000000 M	path2/file2
-:120000 120000 d8ce161addc5173867a3c3c730924388daedbc38 0000000000000000000000000000000000000000 M	path2/file2sym
-:100644 100644 0aa34cae68d0878578ad119c86ca2b5ed5b28376 0000000000000000000000000000000000000000 M	path3/file3
-:120000 120000 8599103969b43aff7e430efea79ca4636466794f 0000000000000000000000000000000000000000 M	path3/file3sym
-:100644 100644 00fb5908cb97c2564a9783c0c64087333b3b464f 0000000000000000000000000000000000000000 M	path3/subp3/file3
-:120000 120000 6649a1ebe9e9f1c553b66f5a6e74136a07ccc57c 0000000000000000000000000000000000000000 M	path3/subp3/file3sym
+test_expect_success 'validate git diff-files output for a know cache/work tree state' '
+	cat >expected <<EOF &&
+:100644 100644 $(test_oid path0f) $ZERO_OID M	path0
+:120000 120000 $(test_oid path0s) $ZERO_OID M	path0sym
+:100644 100644 $(test_oid path2f) $ZERO_OID M	path2/file2
+:120000 120000 $(test_oid path2s) $ZERO_OID M	path2/file2sym
+:100644 100644 $(test_oid path3f) $ZERO_OID M	path3/file3
+:120000 120000 $(test_oid path3s) $ZERO_OID M	path3/file3sym
+:100644 100644 $(test_oid subp3f) $ZERO_OID M	path3/subp3/file3
+:120000 120000 $(test_oid subp3s) $ZERO_OID M	path3/subp3/file3sym
 EOF
 	git diff-files >current &&
-	test_cmp current expected
+	test_cmp expected current
 '
 
 test_expect_success 'git update-index --refresh should succeed' '
@@ -1031,23 +1203,23 @@ test_expect_success 'no diff after check
 '
 
 ################################################################
-P=087704a96baf1c2d1c869a8b084481e121c88b5b
+P=$(test_oid root)
 
-test_expect_success SHA1 'git commit-tree records the correct tree in a commit' '
+test_expect_success 'git commit-tree records the correct tree in a commit' '
 	commit0=$(echo NO | git commit-tree $P) &&
 	tree=$(git show --pretty=raw $commit0 |
 		 sed -n -e "s/^tree //p" -e "/^author /q") &&
 	test "z$tree" = "z$P"
 '
 
-test_expect_success SHA1 'git commit-tree records the correct parent in a commit' '
+test_expect_success 'git commit-tree records the correct parent in a commit' '
 	commit1=$(echo NO | git commit-tree $P -p $commit0) &&
 	parent=$(git show --pretty=raw $commit1 |
 		sed -n -e "s/^parent //p" -e "/^author /q") &&
 	test "z$commit0" = "z$parent"
 '
 
-test_expect_success SHA1 'git commit-tree omits duplicated parent in a commit' '
+test_expect_success 'git commit-tree omits duplicated parent in a commit' '
 	commit2=$(echo NO | git commit-tree $P -p $commit0 -p $commit0) &&
 	     parent=$(git show --pretty=raw $commit2 |
 		sed -n -e "s/^parent //p" -e "/^author /q" |
@@ -1081,7 +1253,7 @@ test_expect_success 'very long name in t
 	(
 		git ls-files -s path4 |
 		sed -e "s/	.*/	/" |
-		tr -d "\012"
+		tr -d "\012" &&
 		echo "$a"
 	) | git update-index --index-info &&
 	len=$(git ls-files "a*" | wc -c) &&
diff -pruN 1.2.1+git2.18.0-1/git/t/t0001-init.sh 1.2.3+git2.25.1-1/git/t/t0001-init.sh
--- 1.2.1+git2.18.0-1/git/t/t0001-init.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t0001-init.sh	2020-02-17 04:47:35.000000000 +0000
@@ -93,6 +93,7 @@ test_expect_success 'No extra GIT_* on a
 		sed -n \
 			-e "/^GIT_PREFIX=/d" \
 			-e "/^GIT_TEXTDOMAINDIR=/d" \
+			-e "/^GIT_TRACE2_PARENT/d" \
 			-e "/^GIT_/s/=.*//p" |
 		sort
 	EOF
@@ -167,15 +168,14 @@ test_expect_success 'reinit' '
 	) &&
 	test_i18ngrep "Initialized empty" again/out1 &&
 	test_i18ngrep "Reinitialized existing" again/out2 &&
-	>again/empty &&
-	test_i18ncmp again/empty again/err1 &&
-	test_i18ncmp again/empty again/err2
+	test_must_be_empty again/err1 &&
+	test_must_be_empty again/err2
 '
 
 test_expect_success 'init with --template' '
 	mkdir template-source &&
 	echo content >template-source/file &&
-	git init --template=../template-source template-custom &&
+	git init --template=template-source template-custom &&
 	test_cmp template-source/file template-custom/.git/file
 '
 
@@ -287,6 +287,7 @@ test_expect_success 'init notices EEXIST
 '
 
 test_expect_success POSIXPERM,SANITY 'init notices EPERM' '
+	test_when_finished "chmod +w newdir" &&
 	rm -fr newdir &&
 	mkdir newdir &&
 	chmod -w newdir &&
@@ -310,8 +311,8 @@ test_expect_success 'init prefers comman
 test_expect_success 'init with separate gitdir' '
 	rm -rf newdir &&
 	git init --separate-git-dir realgitdir newdir &&
-	echo "gitdir: $(pwd)/realgitdir" >expected &&
-	test_cmp expected newdir/.git &&
+	newdir_git="$(cat newdir/.git)" &&
+	test_cmp_fspath "$(pwd)/realgitdir" "${newdir_git#gitdir: }" &&
 	test_path_is_dir realgitdir/refs
 '
 
@@ -319,14 +320,14 @@ test_lazy_prereq GETCWD_IGNORES_PERMS '
 	base=GETCWD_TEST_BASE_DIR &&
 	mkdir -p $base/dir &&
 	chmod 100 $base ||
-	error "bug in test script: cannot prepare $base"
+	BUG "cannot prepare $base"
 
 	(cd $base/dir && /bin/pwd -P)
 	status=$?
 
 	chmod 700 $base &&
 	rm -rf $base ||
-	error "bug in test script: cannot clean $base"
+	BUG "cannot clean $base"
 	return $status
 '
 
@@ -360,12 +361,9 @@ test_expect_success 're-init on .git fil
 '
 
 test_expect_success 're-init to update git link' '
-	(
-	cd newdir &&
-	git init --separate-git-dir ../surrealgitdir
-	) &&
-	echo "gitdir: $(pwd)/surrealgitdir" >expected &&
-	test_cmp expected newdir/.git &&
+	git -C newdir init --separate-git-dir ../surrealgitdir &&
+	newdir_git="$(cat newdir/.git)" &&
+	test_cmp_fspath "$(pwd)/surrealgitdir" "${newdir_git#gitdir: }" &&
 	test_path_is_dir surrealgitdir/refs &&
 	test_path_is_missing realgitdir/refs
 '
@@ -373,12 +371,9 @@ test_expect_success 're-init to update g
 test_expect_success 're-init to move gitdir' '
 	rm -rf newdir realgitdir surrealgitdir &&
 	git init newdir &&
-	(
-	cd newdir &&
-	git init --separate-git-dir ../realgitdir
-	) &&
-	echo "gitdir: $(pwd)/realgitdir" >expected &&
-	test_cmp expected newdir/.git &&
+	git -C newdir init --separate-git-dir ../realgitdir &&
+	newdir_git="$(cat newdir/.git)" &&
+	test_cmp_fspath "$(pwd)/realgitdir" "${newdir_git#gitdir: }" &&
 	test_path_is_dir realgitdir/refs
 '
 
@@ -407,7 +402,7 @@ is_hidden () {
 test_expect_success MINGW '.git hidden' '
 	rm -rf newdir &&
 	(
-		unset GIT_DIR GIT_WORK_TREE
+		sane_unset GIT_DIR GIT_WORK_TREE &&
 		mkdir newdir &&
 		cd newdir &&
 		git init &&
@@ -419,7 +414,7 @@ test_expect_success MINGW '.git hidden'
 test_expect_success MINGW 'bare git dir not hidden' '
 	rm -rf newdir &&
 	(
-		unset GIT_DIR GIT_WORK_TREE GIT_CONFIG
+		sane_unset GIT_DIR GIT_WORK_TREE GIT_CONFIG &&
 		mkdir newdir &&
 		cd newdir &&
 		git --bare init
@@ -453,6 +448,17 @@ test_expect_success 're-init from a link
 	)
 '
 
+test_expect_success MINGW 'core.hidedotfiles = false' '
+	git config --global core.hidedotfiles false &&
+	rm -rf newdir &&
+	mkdir newdir &&
+	(
+		sane_unset GIT_DIR GIT_WORK_TREE GIT_CONFIG &&
+		git -C newdir init
+	) &&
+	! is_hidden newdir/.git
+'
+
 test_expect_success MINGW 'redirect std handles' '
 	GIT_REDIRECT_STDOUT=output.txt git rev-parse --git-dir &&
 	test .git = "$(cat output.txt)" &&
@@ -461,8 +467,8 @@ test_expect_success MINGW 'redirect std
 		GIT_REDIRECT_STDOUT=output.txt \
 		GIT_REDIRECT_STDERR="2>&1" \
 		git rev-parse --git-dir --verify refs/invalid &&
-	printf ".git\nfatal: Needed a single revision\n" >expect &&
-	test_cmp expect output.txt
+	grep "^\\.git\$" output.txt &&
+	grep "Needed a single revision" output.txt
 '
 
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t0002-gitfile.sh 1.2.3+git2.25.1-1/git/t/t0002-gitfile.sh
--- 1.2.1+git2.18.0-1/git/t/t0002-gitfile.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t0002-gitfile.sh	2020-02-17 04:47:35.000000000 +0000
@@ -92,11 +92,12 @@ test_expect_success 'enter_repo non-stri
 		mv .git .realgit &&
 		echo "gitdir: .realgit" >.git
 	) &&
+	head=$(git -C enter_repo rev-parse HEAD) &&
 	git ls-remote enter_repo >actual &&
-	cat >expected <<-\EOF &&
-	946e985ab20de757ca5b872b16d64e92ff3803a9	HEAD
-	946e985ab20de757ca5b872b16d64e92ff3803a9	refs/heads/master
-	946e985ab20de757ca5b872b16d64e92ff3803a9	refs/tags/foo
+	cat >expected <<-EOF &&
+	$head	HEAD
+	$head	refs/heads/master
+	$head	refs/tags/foo
 	EOF
 	test_cmp expected actual
 '
@@ -106,21 +107,23 @@ test_expect_success 'enter_repo linked c
 		cd enter_repo &&
 		git worktree add  ../foo refs/tags/foo
 	) &&
+	head=$(git -C enter_repo rev-parse HEAD) &&
 	git ls-remote foo >actual &&
-	cat >expected <<-\EOF &&
-	946e985ab20de757ca5b872b16d64e92ff3803a9	HEAD
-	946e985ab20de757ca5b872b16d64e92ff3803a9	refs/heads/master
-	946e985ab20de757ca5b872b16d64e92ff3803a9	refs/tags/foo
+	cat >expected <<-EOF &&
+	$head	HEAD
+	$head	refs/heads/master
+	$head	refs/tags/foo
 	EOF
 	test_cmp expected actual
 '
 
 test_expect_success 'enter_repo strict mode' '
+	head=$(git -C enter_repo rev-parse HEAD) &&
 	git ls-remote --upload-pack="git upload-pack --strict" foo/.git >actual &&
-	cat >expected <<-\EOF &&
-	946e985ab20de757ca5b872b16d64e92ff3803a9	HEAD
-	946e985ab20de757ca5b872b16d64e92ff3803a9	refs/heads/master
-	946e985ab20de757ca5b872b16d64e92ff3803a9	refs/tags/foo
+	cat >expected <<-EOF &&
+	$head	HEAD
+	$head	refs/heads/master
+	$head	refs/tags/foo
 	EOF
 	test_cmp expected actual
 '
diff -pruN 1.2.1+git2.18.0-1/git/t/t0003-attributes.sh 1.2.3+git2.25.1-1/git/t/t0003-attributes.sh
--- 1.2.1+git2.18.0-1/git/t/t0003-attributes.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t0003-attributes.sh	2020-02-17 04:47:35.000000000 +0000
@@ -34,15 +34,15 @@ test_expect_success 'open-quoted pathnam
 test_expect_success 'setup' '
 	mkdir -p a/b/d a/c b &&
 	(
-		echo "[attr]notest !test"
-		echo "\" d \"	test=d"
-		echo " e	test=e"
-		echo " e\"	test=e"
-		echo "f	test=f"
-		echo "a/i test=a/i"
-		echo "onoff test -test"
-		echo "offon -test test"
-		echo "no notest"
+		echo "[attr]notest !test" &&
+		echo "\" d \"	test=d" &&
+		echo " e	test=e" &&
+		echo " e\"	test=e" &&
+		echo "f	test=f" &&
+		echo "a/i test=a/i" &&
+		echo "onoff test -test" &&
+		echo "offon -test test" &&
+		echo "no notest" &&
 		echo "A/e/F test=A/e/F"
 	) >.gitattributes &&
 	(
@@ -51,7 +51,7 @@ test_expect_success 'setup' '
 	) >a/.gitattributes &&
 	(
 		echo "h test=a/b/h" &&
-		echo "d/* test=a/b/d/*"
+		echo "d/* test=a/b/d/*" &&
 		echo "d/yes notest"
 	) >a/b/.gitattributes &&
 	(
@@ -208,9 +208,8 @@ test_expect_success 'attribute test: --a
 '
 
 test_expect_success 'attribute test: --cached option' '
-	: >empty &&
 	git check-attr --cached --stdin --all <stdin-all | sort >actual &&
-	test_cmp empty actual &&
+	test_must_be_empty actual &&
 	git add .gitattributes a/.gitattributes a/b/.gitattributes &&
 	git check-attr --cached --stdin --all <stdin-all | sort >actual &&
 	test_cmp specified-all actual
@@ -287,7 +286,7 @@ test_expect_success 'bare repository: ch
 	(
 		cd bare.git &&
 		(
-			echo "f	test=f"
+			echo "f	test=f" &&
 			echo "a/i test=a/i"
 		) >.gitattributes &&
 		attr_check f unspecified &&
@@ -312,7 +311,7 @@ test_expect_success 'bare repository: te
 	(
 		cd bare.git &&
 		(
-			echo "f	test=f"
+			echo "f	test=f" &&
 			echo "a/i test=a/i"
 		) >info/attributes &&
 		attr_check f f &&
@@ -323,4 +322,24 @@ test_expect_success 'bare repository: te
 	)
 '
 
+test_expect_success 'binary macro expanded by -a' '
+	echo "file binary" >.gitattributes &&
+	cat >expect <<-\EOF &&
+	file: binary: set
+	file: diff: unset
+	file: merge: unset
+	file: text: unset
+	EOF
+	git check-attr -a file >actual &&
+	test_cmp expect actual
+'
+
+
+test_expect_success 'query binary macro directly' '
+	echo "file binary" >.gitattributes &&
+	echo file: binary: set >expect &&
+	git check-attr binary file >actual &&
+	test_cmp expect actual
+'
+
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t0006-date.sh 1.2.3+git2.25.1-1/git/t/t0006-date.sh
--- 1.2.1+git2.18.0-1/git/t/t0006-date.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t0006-date.sh	2020-02-17 04:47:35.000000000 +0000
@@ -4,10 +4,10 @@ test_description='test date parsing and
 . ./test-lib.sh
 
 # arbitrary reference time: 2009-08-30 19:20:00
-TEST_DATE_NOW=1251660000; export TEST_DATE_NOW
+GIT_TEST_DATE_NOW=1251660000; export GIT_TEST_DATE_NOW
 
 check_relative() {
-	t=$(($TEST_DATE_NOW - $1))
+	t=$(($GIT_TEST_DATE_NOW - $1))
 	echo "$t -> $2" >expect
 	test_expect_${3:-success} "relative date ($2)" "
 	test-tool date relative $t >actual &&
@@ -113,6 +113,8 @@ check_approxidate '3:00' '2009-08-30 03:
 check_approxidate '15:00' '2009-08-30 15:00:00'
 check_approxidate 'noon today' '2009-08-30 12:00:00'
 check_approxidate 'noon yesterday' '2009-08-29 12:00:00'
+check_approxidate 'January 5th noon pm' '2009-01-05 12:00:00'
+check_approxidate '10am noon' '2009-08-29 12:00:00'
 
 check_approxidate 'last tuesday' '2009-08-25 19:20:00'
 check_approxidate 'July 5th' '2009-07-05 19:20:00'
@@ -126,4 +128,22 @@ check_approxidate '6AM, June 7, 2009' '2
 check_approxidate '2008-12-01' '2008-12-01 19:20:00'
 check_approxidate '2009-12-01' '2009-12-01 19:20:00'
 
+check_date_format_human() {
+	t=$(($GIT_TEST_DATE_NOW - $1))
+	echo "$t -> $2" >expect
+	test_expect_success "human date $t" '
+		test-tool date human $t >actual &&
+		test_i18ncmp expect actual
+'
+}
+
+check_date_format_human 18000 "5 hours ago" # 5 hours ago
+check_date_format_human 432000 "Tue Aug 25 19:20" # 5 days ago
+check_date_format_human 1728000 "Mon Aug 10 19:20" # 3 weeks ago
+check_date_format_human 13000000 "Thu Apr 2 08:13" # 5 months ago
+check_date_format_human 31449600 "Aug 31 2008" # 12 months ago
+check_date_format_human 37500000 "Jun 22 2008" # 1 year, 2 months ago
+check_date_format_human 55188000 "Dec 1 2007" # 1 year, 9 months ago
+check_date_format_human 630000000 "Sep 13 1989" # 20 years ago
+
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t0007-git-var.sh 1.2.3+git2.25.1-1/git/t/t0007-git-var.sh
--- 1.2.1+git2.18.0-1/git/t/t0007-git-var.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t0007-git-var.sh	2020-02-17 04:47:35.000000000 +0000
@@ -17,7 +17,7 @@ test_expect_success 'get GIT_COMMITTER_I
 	test_cmp expect actual
 '
 
-test_expect_success !AUTOIDENT 'requested identites are strict' '
+test_expect_success !FAIL_PREREQS,!AUTOIDENT 'requested identites are strict' '
 	(
 		sane_unset GIT_COMMITTER_NAME &&
 		sane_unset GIT_COMMITTER_EMAIL &&
diff -pruN 1.2.1+git2.18.0-1/git/t/t0008-ignores.sh 1.2.3+git2.25.1-1/git/t/t0008-ignores.sh
--- 1.2.1+git2.18.0-1/git/t/t0008-ignores.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t0008-ignores.sh	2020-02-17 04:47:35.000000000 +0000
@@ -807,10 +807,9 @@ test_expect_success 'trailing whitespace
 	cat >expect <<EOF &&
 whitespace/untracked
 EOF
-	: >err.expect &&
 	git ls-files -o -X ignore whitespace >actual 2>err &&
 	test_cmp expect actual &&
-	test_cmp err.expect err
+	test_must_be_empty err
 '
 
 test_expect_success !MINGW 'quoting allows trailing whitespace' '
@@ -820,10 +819,9 @@ test_expect_success !MINGW 'quoting allo
 	>whitespace/untracked &&
 	echo "whitespace/trailing\\ \\ " >ignore &&
 	echo whitespace/untracked >expect &&
-	: >err.expect &&
 	git ls-files -o -X ignore whitespace >actual 2>err &&
 	test_cmp expect actual &&
-	test_cmp err.expect err
+	test_must_be_empty err
 '
 
 test_expect_success !MINGW,!CYGWIN 'correct handling of backslashes' '
@@ -845,10 +843,9 @@ test_expect_success !MINGW,!CYGWIN 'corr
 	whitespace/trailing 6 \\a\\Z
 	EOF
 	echo whitespace/untracked >expect &&
-	>err.expect &&
 	git ls-files -o -X ignore whitespace >actual 2>err &&
 	test_cmp expect actual &&
-	test_cmp err.expect err
+	test_must_be_empty err
 '
 
 test_expect_success 'info/exclude trumps core.excludesfile' '
diff -pruN 1.2.1+git2.18.0-1/git/t/t0009-prio-queue.sh 1.2.3+git2.25.1-1/git/t/t0009-prio-queue.sh
--- 1.2.1+git2.18.0-1/git/t/t0009-prio-queue.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t0009-prio-queue.sh	2020-02-17 04:47:35.000000000 +0000
@@ -47,4 +47,18 @@ test_expect_success 'notice empty queue'
 	test_cmp expect actual
 '
 
+cat >expect <<'EOF'
+3
+2
+6
+4
+5
+1
+8
+EOF
+test_expect_success 'stack order' '
+	test-tool prio-queue stack 8 1 5 4 6 2 3 dump >actual &&
+	test_cmp expect actual
+'
+
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t0011-hashmap.sh 1.2.3+git2.25.1-1/git/t/t0011-hashmap.sh
--- 1.2.1+git2.18.0-1/git/t/t0011-hashmap.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t0011-hashmap.sh	2020-02-17 04:47:35.000000000 +0000
@@ -9,15 +9,6 @@ test_hashmap() {
 	test_cmp expect actual
 }
 
-test_expect_success 'hash functions' '
-
-test_hashmap "hash key1" "2215982743 2215982743 116372151 116372151" &&
-test_hashmap "hash key2" "2215982740 2215982740 116372148 116372148" &&
-test_hashmap "hash fooBarFrotz" "1383912807 1383912807 3189766727 3189766727" &&
-test_hashmap "hash foobarfrotz" "2862305959 2862305959 3189766727 3189766727"
-
-'
-
 test_expect_success 'put' '
 
 test_hashmap "put key1 value1
@@ -179,31 +170,45 @@ NULL
 '
 
 test_expect_success 'iterate' '
+	test-tool hashmap >actual.raw <<-\EOF &&
+	put key1 value1
+	put key2 value2
+	put fooBarFrotz value3
+	iterate
+	EOF
+
+	cat >expect <<-\EOF &&
+	NULL
+	NULL
+	NULL
+	fooBarFrotz value3
+	key1 value1
+	key2 value2
+	EOF
 
-test_hashmap "put key1 value1
-put key2 value2
-put fooBarFrotz value3
-iterate" "NULL
-NULL
-NULL
-key2 value2
-key1 value1
-fooBarFrotz value3"
-
+	sort <actual.raw >actual &&
+	test_cmp expect actual
 '
 
 test_expect_success 'iterate (case insensitive)' '
+	test-tool hashmap ignorecase >actual.raw <<-\EOF &&
+	put key1 value1
+	put key2 value2
+	put fooBarFrotz value3
+	iterate
+	EOF
+
+	cat >expect <<-\EOF &&
+	NULL
+	NULL
+	NULL
+	fooBarFrotz value3
+	key1 value1
+	key2 value2
+	EOF
 
-test_hashmap "put key1 value1
-put key2 value2
-put fooBarFrotz value3
-iterate" "NULL
-NULL
-NULL
-fooBarFrotz value3
-key2 value2
-key1 value1" ignorecase
-
+	sort <actual.raw >actual &&
+	test_cmp expect actual
 '
 
 test_expect_success 'grow / shrink' '
diff -pruN 1.2.1+git2.18.0-1/git/t/t0012-help.sh 1.2.3+git2.25.1-1/git/t/t0012-help.sh
--- 1.2.1+git2.18.0-1/git/t/t0012-help.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t0012-help.sh	2020-02-17 04:47:35.000000000 +0000
@@ -29,9 +29,9 @@ test_expect_success "setup" '
 # to verify
 test_expect_success 'basic help commands' '
 	git help >/dev/null &&
-	git help -a >/dev/null &&
+	git help -a --no-verbose >/dev/null &&
 	git help -g >/dev/null &&
-	git help -av >/dev/null
+	git help -a >/dev/null
 '
 
 test_expect_success "works for commands and guides by default" '
diff -pruN 1.2.1+git2.18.0-1/git/t/t0014-alias.sh 1.2.3+git2.25.1-1/git/t/t0014-alias.sh
--- 1.2.1+git2.18.0-1/git/t/t0014-alias.sh	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t0014-alias.sh	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,47 @@
+#!/bin/sh
+
+test_description='git command aliasing'
+
+. ./test-lib.sh
+
+test_expect_success 'nested aliases - internal execution' '
+	git config alias.nested-internal-1 nested-internal-2 &&
+	git config alias.nested-internal-2 status &&
+	git nested-internal-1 >output &&
+	test_i18ngrep "^On branch " output
+'
+
+test_expect_success 'nested aliases - mixed execution' '
+	git config alias.nested-external-1 nested-external-2 &&
+	git config alias.nested-external-2 "!git nested-external-3" &&
+	git config alias.nested-external-3 status &&
+	git nested-external-1 >output &&
+	test_i18ngrep "^On branch " output
+'
+
+test_expect_success 'looping aliases - internal execution' '
+	git config alias.loop-internal-1 loop-internal-2 &&
+	git config alias.loop-internal-2 loop-internal-3 &&
+	git config alias.loop-internal-3 loop-internal-2 &&
+	test_must_fail git loop-internal-1 2>output &&
+	test_i18ngrep "^fatal: alias loop detected: expansion of" output
+'
+
+# This test is disabled until external loops are fixed, because would block
+# the test suite for a full minute.
+#
+#test_expect_failure 'looping aliases - mixed execution' '
+#	git config alias.loop-mixed-1 loop-mixed-2 &&
+#	git config alias.loop-mixed-2 "!git loop-mixed-1" &&
+#	test_must_fail git loop-mixed-1 2>output &&
+#	test_i18ngrep "^fatal: alias loop detected: expansion of" output
+#'
+
+test_expect_success 'run-command formats empty args properly' '
+    test_must_fail env GIT_TRACE=1 git frotz a "" b " " c 2>actual.raw &&
+    sed -ne "/run_command:/s/.*trace: run_command: //p" actual.raw >actual &&
+    echo "git-frotz a '\'''\'' b '\'' '\'' c" >expect &&
+    test_cmp expect actual
+'
+
+test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t0015-hash.sh 1.2.3+git2.25.1-1/git/t/t0015-hash.sh
--- 1.2.1+git2.18.0-1/git/t/t0015-hash.sh	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t0015-hash.sh	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,55 @@
+#!/bin/sh
+
+test_description='test basic hash implementation'
+. ./test-lib.sh
+
+
+test_expect_success 'test basic SHA-1 hash values' '
+	test-tool sha1 </dev/null >actual &&
+	grep da39a3ee5e6b4b0d3255bfef95601890afd80709 actual &&
+	printf "a" | test-tool sha1 >actual &&
+	grep 86f7e437faa5a7fce15d1ddcb9eaeaea377667b8 actual &&
+	printf "abc" | test-tool sha1 >actual &&
+	grep a9993e364706816aba3e25717850c26c9cd0d89d actual &&
+	printf "message digest" | test-tool sha1 >actual &&
+	grep c12252ceda8be8994d5fa0290a47231c1d16aae3 actual &&
+	printf "abcdefghijklmnopqrstuvwxyz" | test-tool sha1 >actual &&
+	grep 32d10c7b8cf96570ca04ce37f2a19d84240d3a89 actual &&
+	perl -e "$| = 1; print q{aaaaaaaaaa} for 1..100000;" | \
+		test-tool sha1 >actual &&
+	grep 34aa973cd4c4daa4f61eeb2bdbad27316534016f actual &&
+	printf "blob 0\0" | test-tool sha1 >actual &&
+	grep e69de29bb2d1d6434b8b29ae775ad8c2e48c5391 actual &&
+	printf "blob 3\0abc" | test-tool sha1 >actual &&
+	grep f2ba8f84ab5c1bce84a7b441cb1959cfc7093b7f actual &&
+	printf "tree 0\0" | test-tool sha1 >actual &&
+	grep 4b825dc642cb6eb9a060e54bf8d69288fbee4904 actual
+'
+
+test_expect_success 'test basic SHA-256 hash values' '
+	test-tool sha256 </dev/null >actual &&
+	grep e3b0c44298fc1c149afbf4c8996fb92427ae41e4649b934ca495991b7852b855 actual &&
+	printf "a" | test-tool sha256 >actual &&
+	grep ca978112ca1bbdcafac231b39a23dc4da786eff8147c4e72b9807785afee48bb actual &&
+	printf "abc" | test-tool sha256 >actual &&
+	grep ba7816bf8f01cfea414140de5dae2223b00361a396177a9cb410ff61f20015ad actual &&
+	printf "message digest" | test-tool sha256 >actual &&
+	grep f7846f55cf23e14eebeab5b4e1550cad5b509e3348fbc4efa3a1413d393cb650 actual &&
+	printf "abcdefghijklmnopqrstuvwxyz" | test-tool sha256 >actual &&
+	grep 71c480df93d6ae2f1efad1447c66c9525e316218cf51fc8d9ed832f2daf18b73 actual &&
+	# Try to exercise the chunking code by turning autoflush on.
+	perl -e "$| = 1; print q{aaaaaaaaaa} for 1..100000;" | \
+		test-tool sha256 >actual &&
+	grep cdc76e5c9914fb9281a1c7e284d73e67f1809a48a497200e046d39ccc7112cd0 actual &&
+	perl -e "$| = 1; print q{abcdefghijklmnopqrstuvwxyz} for 1..100000;" | \
+		test-tool sha256 >actual &&
+	grep e406ba321ca712ad35a698bf0af8d61fc4dc40eca6bdcea4697962724ccbde35 actual &&
+	printf "blob 0\0" | test-tool sha256 >actual &&
+	grep 473a0f4c3be8a93681a267e3b1e9a7dcda1185436fe141f7749120a303721813 actual &&
+	printf "blob 3\0abc" | test-tool sha256 >actual &&
+	grep c1cf6e465077930e88dc5136641d402f72a229ddd996f627d60e9639eaba35a6 actual &&
+	printf "tree 0\0" | test-tool sha256 >actual &&
+	grep 6ef19b41225c5369f1c104d45d8d85efa9b057b53b14b4b9b939dd74decc5321 actual
+'
+
+test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t0016-oidmap.sh 1.2.3+git2.25.1-1/git/t/t0016-oidmap.sh
--- 1.2.1+git2.18.0-1/git/t/t0016-oidmap.sh	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t0016-oidmap.sh	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,110 @@
+#!/bin/sh
+
+test_description='test oidmap'
+. ./test-lib.sh
+
+# This purposefully is very similar to t0011-hashmap.sh
+
+test_oidmap () {
+	echo "$1" | test-tool oidmap $3 >actual &&
+	echo "$2" >expect &&
+	test_cmp expect actual
+}
+
+
+test_expect_success 'setup' '
+
+	test_commit one &&
+	test_commit two &&
+	test_commit three &&
+	test_commit four
+
+'
+
+test_expect_success 'put' '
+
+test_oidmap "put one 1
+put two 2
+put invalidOid 4
+put three 3" "NULL
+NULL
+Unknown oid: invalidOid
+NULL"
+
+'
+
+test_expect_success 'replace' '
+
+test_oidmap "put one 1
+put two 2
+put three 3
+put invalidOid 4
+put two deux
+put one un" "NULL
+NULL
+NULL
+Unknown oid: invalidOid
+2
+1"
+
+'
+
+test_expect_success 'get' '
+
+test_oidmap "put one 1
+put two 2
+put three 3
+get two
+get four
+get invalidOid
+get one" "NULL
+NULL
+NULL
+2
+NULL
+Unknown oid: invalidOid
+1"
+
+'
+
+test_expect_success 'remove' '
+
+test_oidmap "put one 1
+put two 2
+put three 3
+remove one
+remove two
+remove invalidOid
+remove four" "NULL
+NULL
+NULL
+1
+2
+Unknown oid: invalidOid
+NULL"
+
+'
+
+test_expect_success 'iterate' '
+	test-tool oidmap >actual.raw <<-\EOF &&
+	put one 1
+	put two 2
+	put three 3
+	iterate
+	EOF
+
+	# sort "expect" too so we do not rely on the order of particular oids
+	sort >expect <<-EOF &&
+	NULL
+	NULL
+	NULL
+	$(git rev-parse one) 1
+	$(git rev-parse two) 2
+	$(git rev-parse three) 3
+	EOF
+
+	sort <actual.raw >actual &&
+	test_cmp expect actual
+'
+
+test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t0017-env-helper.sh 1.2.3+git2.25.1-1/git/t/t0017-env-helper.sh
--- 1.2.1+git2.18.0-1/git/t/t0017-env-helper.sh	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t0017-env-helper.sh	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,99 @@
+#!/bin/sh
+
+test_description='test env--helper'
+
+. ./test-lib.sh
+
+
+test_expect_success 'env--helper usage' '
+	test_must_fail git env--helper &&
+	test_must_fail git env--helper --type=bool &&
+	test_must_fail git env--helper --type=ulong &&
+	test_must_fail git env--helper --type=bool &&
+	test_must_fail git env--helper --type=bool --default &&
+	test_must_fail git env--helper --type=bool --default= &&
+	test_must_fail git env--helper --defaultxyz
+'
+
+test_expect_success 'env--helper bad default values' '
+	test_must_fail git env--helper --type=bool --default=1xyz MISSING &&
+	test_must_fail git env--helper --type=ulong --default=1xyz MISSING
+'
+
+test_expect_success 'env--helper --type=bool' '
+	# Test various --default bool values
+	echo true >expected &&
+	git env--helper --type=bool --default=1 MISSING >actual &&
+	test_cmp expected actual &&
+	git env--helper --type=bool --default=yes MISSING >actual &&
+	test_cmp expected actual &&
+	git env--helper --type=bool --default=true MISSING >actual &&
+	test_cmp expected actual &&
+	echo false >expected &&
+	test_must_fail git env--helper --type=bool --default=0 MISSING >actual &&
+	test_cmp expected actual &&
+	test_must_fail git env--helper --type=bool --default=no MISSING >actual &&
+	test_cmp expected actual &&
+	test_must_fail git env--helper --type=bool --default=false MISSING >actual &&
+	test_cmp expected actual &&
+
+	# No output with --exit-code
+	git env--helper --type=bool --default=true --exit-code MISSING >actual.out 2>actual.err &&
+	test_must_be_empty actual.out &&
+	test_must_be_empty actual.err &&
+	test_must_fail git env--helper --type=bool --default=false --exit-code MISSING >actual.out 2>actual.err &&
+	test_must_be_empty actual.out &&
+	test_must_be_empty actual.err &&
+
+	# Existing variable
+	EXISTS=true git env--helper --type=bool --default=false --exit-code EXISTS >actual.out 2>actual.err &&
+	test_must_be_empty actual.out &&
+	test_must_be_empty actual.err &&
+	test_must_fail \
+		env EXISTS=false \
+		git env--helper --type=bool --default=true --exit-code EXISTS >actual.out 2>actual.err &&
+	test_must_be_empty actual.out &&
+	test_must_be_empty actual.err
+'
+
+test_expect_success 'env--helper --type=ulong' '
+	echo 1234567890 >expected &&
+	git env--helper --type=ulong --default=1234567890 MISSING >actual.out 2>actual.err &&
+	test_cmp expected actual.out &&
+	test_must_be_empty actual.err &&
+
+	echo 0 >expected &&
+	test_must_fail git env--helper --type=ulong --default=0 MISSING >actual &&
+	test_cmp expected actual &&
+
+	git env--helper --type=ulong --default=1234567890 --exit-code MISSING >actual.out 2>actual.err &&
+	test_must_be_empty actual.out &&
+	test_must_be_empty actual.err &&
+
+	EXISTS=1234567890 git env--helper --type=ulong --default=0 EXISTS --exit-code >actual.out 2>actual.err &&
+	test_must_be_empty actual.out &&
+	test_must_be_empty actual.err &&
+
+	echo 1234567890 >expected &&
+	EXISTS=1234567890 git env--helper --type=ulong --default=0 EXISTS >actual.out 2>actual.err &&
+	test_cmp expected actual.out &&
+	test_must_be_empty actual.err
+'
+
+test_expect_success 'env--helper reads config thanks to trace2' '
+	mkdir home &&
+	git config -f home/.gitconfig include.path cycle &&
+	git config -f home/cycle include.path .gitconfig &&
+
+	test_must_fail \
+		env HOME="$(pwd)/home" GIT_TEST_GETTEXT_POISON=false \
+		git config -l 2>err &&
+	grep "exceeded maximum include depth" err &&
+
+	test_must_fail \
+		env HOME="$(pwd)/home" GIT_TEST_GETTEXT_POISON=true \
+		git -C cycle env--helper --type=bool --default=0 --exit-code GIT_TEST_GETTEXT_POISON 2>err &&
+	grep "# GETTEXT POISON #" err
+'
+
+test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t0019/parse_json.perl 1.2.3+git2.25.1-1/git/t/t0019/parse_json.perl
--- 1.2.1+git2.18.0-1/git/t/t0019/parse_json.perl	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t0019/parse_json.perl	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,55 @@
+#!/usr/bin/perl
+use strict;
+use warnings;
+use JSON;
+
+sub dump_array {
+    my ($label_in, $ary_ref) = @_;
+    my @ary = @$ary_ref;
+
+    for ( my $i = 0; $i <= $#{ $ary_ref }; $i++ )
+    {
+	my $label = "$label_in\[$i\]";
+	dump_item($label, $ary[$i]);
+    }
+}
+
+sub dump_hash {
+    my ($label_in, $obj_ref) = @_;
+    my %obj = %$obj_ref;
+
+    foreach my $k (sort keys %obj) {
+	my $label = (length($label_in) > 0) ? "$label_in.$k" : "$k";
+	my $value = $obj{$k};
+
+	dump_item($label, $value);
+    }
+}
+
+sub dump_item {
+    my ($label_in, $value) = @_;
+    if (ref($value) eq 'ARRAY') {
+	print "$label_in array\n";
+	dump_array($label_in, $value);
+    } elsif (ref($value) eq 'HASH') {
+	print "$label_in hash\n";
+	dump_hash($label_in, $value);
+    } elsif (ref $value) {
+	my $bool = $value ? 1 : 0;
+	print "$label_in $bool\n";
+    } elsif (defined $value) {
+	print "$label_in $value\n";
+    } else {
+	print "$label_in null\n";
+    }
+}
+
+my $row = 0;
+while (<>) {
+    my $data = decode_json( $_ );
+    my $label = "row[$row]";
+
+    dump_hash($label, $data);
+    $row++;
+}
+
diff -pruN 1.2.1+git2.18.0-1/git/t/t0019-json-writer.sh 1.2.3+git2.25.1-1/git/t/t0019-json-writer.sh
--- 1.2.1+git2.18.0-1/git/t/t0019-json-writer.sh	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t0019-json-writer.sh	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,331 @@
+#!/bin/sh
+
+test_description='test json-writer JSON generation'
+. ./test-lib.sh
+
+test_expect_success 'unit test of json-writer routines' '
+	test-tool json-writer -u
+'
+
+test_expect_success 'trivial object' '
+	cat >expect <<-\EOF &&
+	{}
+	EOF
+	cat >input <<-\EOF &&
+	object
+	end
+	EOF
+	test-tool json-writer <input >actual &&
+	test_cmp expect actual
+'
+
+test_expect_success 'trivial array' '
+	cat >expect <<-\EOF &&
+	[]
+	EOF
+	cat >input <<-\EOF &&
+	array
+	end
+	EOF
+	test-tool json-writer <input >actual &&
+	test_cmp expect actual
+'
+
+test_expect_success 'simple object' '
+	cat >expect <<-\EOF &&
+	{"a":"abc","b":42,"c":3.14,"d":true,"e":false,"f":null}
+	EOF
+	cat >input <<-\EOF &&
+	object
+		object-string a abc
+		object-int b 42
+		object-double c 2 3.140
+		object-true d
+		object-false e
+		object-null f
+	end
+	EOF
+	test-tool json-writer <input >actual &&
+	test_cmp expect actual
+'
+
+test_expect_success 'simple array' '
+	cat >expect <<-\EOF &&
+	["abc",42,3.14,true,false,null]
+	EOF
+	cat >input <<-\EOF &&
+	array
+		array-string abc
+		array-int 42
+		array-double 2 3.140
+		array-true
+		array-false
+		array-null
+	end
+	EOF
+	test-tool json-writer <input >actual &&
+	test_cmp expect actual
+'
+
+test_expect_success 'escape quoting string' '
+	cat >expect <<-\EOF &&
+	{"a":"abc\\def"}
+	EOF
+	cat >input <<-\EOF &&
+	object
+		object-string a abc\def
+	end
+	EOF
+	test-tool json-writer <input >actual &&
+	test_cmp expect actual
+'
+
+test_expect_success 'escape quoting string 2' '
+	cat >expect <<-\EOF &&
+	{"a":"abc\"def"}
+	EOF
+	cat >input <<-\EOF &&
+	object
+		object-string a abc"def
+	end
+	EOF
+	test-tool json-writer <input >actual &&
+	test_cmp expect actual
+'
+
+test_expect_success 'nested inline object' '
+	cat >expect <<-\EOF &&
+	{"a":"abc","b":42,"sub1":{"c":3.14,"d":true,"sub2":{"e":false,"f":null}}}
+	EOF
+	cat >input <<-\EOF &&
+	object
+		object-string a abc
+		object-int b 42
+		object-object sub1
+			object-double c 2 3.140
+			object-true d
+			object-object sub2
+				object-false e
+				object-null f
+			end
+		end
+	end
+	EOF
+	test-tool json-writer <input >actual &&
+	test_cmp expect actual
+'
+
+test_expect_success 'nested inline array' '
+	cat >expect <<-\EOF &&
+	["abc",42,[3.14,true,[false,null]]]
+	EOF
+	cat >input <<-\EOF &&
+	array
+		array-string abc
+		array-int 42
+		array-array
+			array-double 2 3.140
+			array-true
+			array-array
+				array-false
+				array-null
+			end
+		end
+	end
+	EOF
+	test-tool json-writer <input >actual &&
+	test_cmp expect actual
+'
+
+test_expect_success 'nested inline object and array' '
+	cat >expect <<-\EOF &&
+	{"a":"abc","b":42,"sub1":{"c":3.14,"d":true,"sub2":[false,null]}}
+	EOF
+	cat >input <<-\EOF &&
+	object
+		object-string a abc
+		object-int b 42
+		object-object sub1
+			object-double c 2 3.140
+			object-true d
+			object-array sub2
+				array-false
+				array-null
+			end
+		end
+	end
+	EOF
+	test-tool json-writer <input >actual &&
+	test_cmp expect actual
+'
+
+test_expect_success 'nested inline object and array 2' '
+	cat >expect <<-\EOF &&
+	{"a":"abc","b":42,"sub1":{"c":3.14,"d":true,"sub2":[false,{"g":0,"h":1},null]}}
+	EOF
+	cat >input <<-\EOF &&
+	object
+		object-string a abc
+		object-int b 42
+		object-object sub1
+			object-double c 2 3.140
+			object-true d
+			object-array sub2
+				array-false
+				array-object
+					object-int g 0
+					object-int h 1
+				end
+				array-null
+			end
+		end
+	end
+	EOF
+	test-tool json-writer <input >actual &&
+	test_cmp expect actual
+'
+
+test_expect_success 'pretty nested inline object and array 2' '
+	sed -e "s/^|//" >expect <<-\EOF &&
+	|{
+	|  "a": "abc",
+	|  "b": 42,
+	|  "sub1": {
+	|    "c": 3.14,
+	|    "d": true,
+	|    "sub2": [
+	|      false,
+	|      {
+	|        "g": 0,
+	|        "h": 1
+	|      },
+	|      null
+	|    ]
+	|  }
+	|}
+	EOF
+	cat >input <<-\EOF &&
+	object
+		object-string a abc
+		object-int b 42
+		object-object sub1
+			object-double c 2 3.140
+			object-true d
+			object-array sub2
+				array-false
+				array-object
+					object-int g 0
+					object-int h 1
+				end
+				array-null
+			end
+		end
+	end
+	EOF
+	test-tool json-writer -p <input >actual &&
+	test_cmp expect actual
+'
+
+test_expect_success 'inline object with no members' '
+	cat >expect <<-\EOF &&
+	{"a":"abc","empty":{},"b":42}
+	EOF
+	cat >input <<-\EOF &&
+	object
+		object-string a abc
+		object-object empty
+		end
+		object-int b 42
+	end
+	EOF
+	test-tool json-writer <input >actual &&
+	test_cmp expect actual
+'
+
+test_expect_success 'inline array with no members' '
+	cat >expect <<-\EOF &&
+	{"a":"abc","empty":[],"b":42}
+	EOF
+	cat >input <<-\EOF &&
+	object
+		object-string a abc
+		object-array empty
+		end
+		object-int b 42
+	end
+	EOF
+	test-tool json-writer <input >actual &&
+	test_cmp expect actual
+'
+
+test_expect_success 'larger empty example' '
+	cat >expect <<-\EOF &&
+	{"a":"abc","empty":[{},{},{},[],{}],"b":42}
+	EOF
+	cat >input <<-\EOF &&
+	object
+		object-string a abc
+		object-array empty
+			array-object
+			end
+			array-object
+			end
+			array-object
+			end
+			array-array
+			end
+			array-object
+			end
+		end
+		object-int b 42
+	end
+	EOF
+	test-tool json-writer <input >actual &&
+	test_cmp expect actual
+'
+
+test_lazy_prereq PERLJSON '
+	perl -MJSON -e "exit 0"
+'
+
+# As a sanity check, ask Perl to parse our generated JSON and recursively
+# dump the resulting data in sorted order.  Confirm that that matches our
+# expectations.
+test_expect_success PERLJSON 'parse JSON using Perl' '
+	cat >expect <<-\EOF &&
+	row[0].a abc
+	row[0].b 42
+	row[0].sub1 hash
+	row[0].sub1.c 3.14
+	row[0].sub1.d 1
+	row[0].sub1.sub2 array
+	row[0].sub1.sub2[0] 0
+	row[0].sub1.sub2[1] hash
+	row[0].sub1.sub2[1].g 0
+	row[0].sub1.sub2[1].h 1
+	row[0].sub1.sub2[2] null
+	EOF
+	cat >input <<-\EOF &&
+	object
+		object-string a abc
+		object-int b 42
+		object-object sub1
+			object-double c 2 3.140
+			object-true d
+			object-array sub2
+				array-false
+				array-object
+					object-int g 0
+					object-int h 1
+				end
+				array-null
+			end
+		end
+	end
+	EOF
+	test-tool json-writer <input >output.json &&
+	perl "$TEST_DIRECTORY"/t0019/parse_json.perl <output.json >actual &&
+	test_cmp expect actual
+'
+
+test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t0020-crlf.sh 1.2.3+git2.25.1-1/git/t/t0020-crlf.sh
--- 1.2.1+git2.18.0-1/git/t/t0020-crlf.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t0020-crlf.sh	2020-02-17 04:47:35.000000000 +0000
@@ -98,6 +98,16 @@ test_expect_success 'safecrlf: git diff
 '
 
 
+test_expect_success 'safecrlf: no warning with safecrlf=false' '
+	git config core.autocrlf input &&
+	git config core.safecrlf false &&
+
+	for w in I am all CRLF; do echo $w; done | append_cr >allcrlf &&
+	git add allcrlf 2>err &&
+	test_must_be_empty err
+'
+
+
 test_expect_success 'switch off autocrlf, safecrlf, reset HEAD' '
 	git config core.autocrlf false &&
 	git config core.safecrlf false &&
@@ -150,7 +160,7 @@ test_expect_success 'checkout with autoc
 	git config core.autocrlf input &&
 	git read-tree --reset -u HEAD &&
 	test_must_fail has_cr one &&
-	test_must_fail has_cr two &&
+	test_must_fail has_cr dir/two &&
 	git update-index -- one dir/two &&
 	test "$one" = $(git hash-object --stdin <one) &&
 	test "$two" = $(git hash-object --stdin <dir/two) &&
diff -pruN 1.2.1+git2.18.0-1/git/t/t0021-conversion.sh 1.2.3+git2.25.1-1/git/t/t0021-conversion.sh
--- 1.2.1+git2.18.0-1/git/t/t0021-conversion.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t0021-conversion.sh	2020-02-17 04:47:35.000000000 +0000
@@ -24,7 +24,7 @@ generate_random_characters () {
 }
 
 file_size () {
-	perl -e 'print -s $ARGV[0]' "$1"
+	test-tool path-utils file-size "$1"
 }
 
 filter_git () {
@@ -35,7 +35,7 @@ filter_git () {
 # Compare two files and ensure that `clean` and `smudge` respectively are
 # called at least once if specified in the `expect` file. The actual
 # invocation count is not relevant because their number can vary.
-# c.f. http://public-inbox.org/git/xmqqshv18i8i.fsf@gitster.mtv.corp.google.com/
+# c.f. http://lore.kernel.org/git/xmqqshv18i8i.fsf@gitster.mtv.corp.google.com/
 test_cmp_count () {
 	expect=$1
 	actual=$2
@@ -50,7 +50,7 @@ test_cmp_count () {
 
 # Compare two files but exclude all `clean` invocations because Git can
 # call `clean` zero or more times.
-# c.f. http://public-inbox.org/git/xmqqshv18i8i.fsf@gitster.mtv.corp.google.com/
+# c.f. http://lore.kernel.org/git/xmqqshv18i8i.fsf@gitster.mtv.corp.google.com/
 test_cmp_exclude_clean () {
 	expect=$1
 	actual=$2
@@ -166,10 +166,10 @@ test_expect_success expanded_in_repo '
 	rm -f expanded-keywords expanded-keywords-crlf &&
 
 	git checkout -- expanded-keywords &&
-	test_cmp expanded-keywords expected-output &&
+	test_cmp expected-output expanded-keywords &&
 
 	git checkout -- expanded-keywords-crlf &&
-	test_cmp expanded-keywords-crlf expected-output-crlf
+	test_cmp expected-output-crlf expanded-keywords-crlf
 '
 
 # The use of %f in a filter definition is expanded to the path to
@@ -390,6 +390,9 @@ test_expect_success PERL 'required proce
 		EOF
 		test_cmp_exclude_clean expected.log debug.log &&
 
+		# Make sure that the file appears dirty, so checkout below has to
+		# run the configured filter.
+		touch test.r &&
 		filter_git checkout --quiet --no-progress empty-branch &&
 		cat >expected.log <<-EOF &&
 			START
@@ -583,7 +586,7 @@ test_expect_success PERL 'process filter
 		git checkout --quiet --no-progress . 2>git-stderr.log &&
 
 		grep "smudge write error at" git-stderr.log &&
-		grep "error: external filter" git-stderr.log &&
+		test_i18ngrep "error: external filter" git-stderr.log &&
 
 		cat >expected.log <<-EOF &&
 			START
@@ -785,7 +788,7 @@ test_expect_success PERL 'missing file i
 		cd repo &&
 		git init &&
 		echo "*.a filter=bug" >.gitattributes &&
-		cp "$TEST_ROOT/test.o" missing-delay.a
+		cp "$TEST_ROOT/test.o" missing-delay.a &&
 		git add . &&
 		git commit -m "test commit"
 	) &&
@@ -807,7 +810,7 @@ test_expect_success PERL 'invalid file i
 		git init &&
 		echo "*.a filter=bug" >.gitattributes &&
 		cp "$TEST_ROOT/test.o" invalid-delay.a &&
-		cp "$TEST_ROOT/test.o" unfiltered
+		cp "$TEST_ROOT/test.o" unfiltered &&
 		git add . &&
 		git commit -m "test commit"
 	) &&
diff -pruN 1.2.1+git2.18.0-1/git/t/t0025-crlf-renormalize.sh 1.2.3+git2.25.1-1/git/t/t0025-crlf-renormalize.sh
--- 1.2.1+git2.18.0-1/git/t/t0025-crlf-renormalize.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t0025-crlf-renormalize.sh	2020-02-17 04:47:35.000000000 +0000
@@ -27,4 +27,13 @@ test_expect_success 'renormalize CRLF in
 	test_cmp expect actual
 '
 
+test_expect_success 'ignore-errors not mistaken for renormalize' '
+	git reset --hard &&
+	echo "*.txt text=auto" >.gitattributes &&
+	git ls-files --eol >expect &&
+	git add --ignore-errors "*.txt" &&
+	git ls-files --eol >actual &&
+	test_cmp expect actual
+'
+
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t0027-auto-crlf.sh 1.2.3+git2.25.1-1/git/t/t0027-auto-crlf.sh
--- 1.2.1+git2.18.0-1/git/t/t0027-auto-crlf.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t0027-auto-crlf.sh	2020-02-17 04:47:35.000000000 +0000
@@ -15,8 +15,10 @@ compare_ws_file () {
 	pfx=$1
 	exp=$2.expect
 	act=$pfx.actual.$3
-	tr '\015\000abcdef0123456789' QN00000000000000000 <"$2" >"$exp" &&
-	tr '\015\000abcdef0123456789' QN00000000000000000 <"$3" >"$act" &&
+	tr '\015\000abcdef0123456789' QN00000000000000000 <"$2" |
+		sed -e "s/0000*/$ZERO_OID/" >"$exp" &&
+	tr '\015\000abcdef0123456789' QN00000000000000000 <"$3" |
+		sed -e "s/0000*/$ZERO_OID/" >"$act" &&
 	test_cmp "$exp" "$act" &&
 	rm "$exp" "$act"
 }
@@ -213,7 +215,7 @@ stats_ascii () {
 }
 
 
-# contruct the attr/ returned by git ls-files --eol
+# construct the attr/ returned by git ls-files --eol
 # Take none (=empty), one or two args
 # convert.c: eol=XX overrides text=auto
 attr_ascii () {
@@ -293,9 +295,9 @@ checkout_files () {
 	do
 		rm crlf_false_attr__$f.txt &&
 		if test -z "$ceol"; then
-			git checkout crlf_false_attr__$f.txt
+			git checkout -- crlf_false_attr__$f.txt
 		else
-			git -c core.eol=$ceol checkout crlf_false_attr__$f.txt
+			git -c core.eol=$ceol checkout -- crlf_false_attr__$f.txt
 		fi
 	done
 
diff -pruN 1.2.1+git2.18.0-1/git/t/t0028-working-tree-encoding.sh 1.2.3+git2.25.1-1/git/t/t0028-working-tree-encoding.sh
--- 1.2.1+git2.18.0-1/git/t/t0028-working-tree-encoding.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t0028-working-tree-encoding.sh	2020-02-17 04:47:35.000000000 +0000
@@ -6,14 +6,41 @@ test_description='working-tree-encoding
 
 GIT_TRACE_WORKING_TREE_ENCODING=1 && export GIT_TRACE_WORKING_TREE_ENCODING
 
+test_lazy_prereq NO_UTF16_BOM '
+	test $(printf abc | iconv -f UTF-8 -t UTF-16 | wc -c) = 6
+'
+
+test_lazy_prereq NO_UTF32_BOM '
+	test $(printf abc | iconv -f UTF-8 -t UTF-32 | wc -c) = 12
+'
+
+write_utf16 () {
+	if test_have_prereq NO_UTF16_BOM
+	then
+		printf '\376\377'
+	fi &&
+	iconv -f UTF-8 -t UTF-16
+}
+
+write_utf32 () {
+	if test_have_prereq NO_UTF32_BOM
+	then
+		printf '\0\0\376\377'
+	fi &&
+	iconv -f UTF-8 -t UTF-32
+}
+
 test_expect_success 'setup test files' '
 	git config core.eol lf &&
 
 	text="hallo there!\ncan you read me?" &&
 	echo "*.utf16 text working-tree-encoding=utf-16" >.gitattributes &&
+	echo "*.utf16lebom text working-tree-encoding=UTF-16LE-BOM" >>.gitattributes &&
 	printf "$text" >test.utf8.raw &&
-	printf "$text" | iconv -f UTF-8 -t UTF-16 >test.utf16.raw &&
-	printf "$text" | iconv -f UTF-8 -t UTF-32 >test.utf32.raw &&
+	printf "$text" | write_utf16 >test.utf16.raw &&
+	printf "$text" | write_utf32 >test.utf32.raw &&
+	printf "\377\376"                         >test.utf16lebom.raw &&
+	printf "$text" | iconv -f UTF-8 -t UTF-16LE >>test.utf16lebom.raw &&
 
 	# Line ending tests
 	printf "one\ntwo\nthree\n" >lf.utf8.raw &&
@@ -22,17 +49,18 @@ test_expect_success 'setup test files' '
 	# BOM tests
 	printf "\0a\0b\0c"                         >nobom.utf16be.raw &&
 	printf "a\0b\0c\0"                         >nobom.utf16le.raw &&
-	printf "\376\777\0a\0b\0c"                 >bebom.utf16be.raw &&
-	printf "\777\376a\0b\0c\0"                 >lebom.utf16le.raw &&
+	printf "\376\377\0a\0b\0c"                 >bebom.utf16be.raw &&
+	printf "\377\376a\0b\0c\0"                 >lebom.utf16le.raw &&
 	printf "\0\0\0a\0\0\0b\0\0\0c"             >nobom.utf32be.raw &&
 	printf "a\0\0\0b\0\0\0c\0\0\0"             >nobom.utf32le.raw &&
-	printf "\0\0\376\777\0\0\0a\0\0\0b\0\0\0c" >bebom.utf32be.raw &&
-	printf "\777\376\0\0a\0\0\0b\0\0\0c\0\0\0" >lebom.utf32le.raw &&
+	printf "\0\0\376\377\0\0\0a\0\0\0b\0\0\0c" >bebom.utf32be.raw &&
+	printf "\377\376\0\0a\0\0\0b\0\0\0c\0\0\0" >lebom.utf32le.raw &&
 
 	# Add only UTF-16 file, we will add the UTF-32 file later
 	cp test.utf16.raw test.utf16 &&
 	cp test.utf32.raw test.utf32 &&
-	git add .gitattributes test.utf16 &&
+	cp test.utf16lebom.raw test.utf16lebom &&
+	git add .gitattributes test.utf16 test.utf16lebom &&
 	git commit -m initial
 '
 
@@ -51,6 +79,12 @@ test_expect_success 're-encode to UTF-16
 	test_cmp_bin test.utf16.raw test.utf16
 '
 
+test_expect_success 're-encode to UTF-16-LE-BOM on checkout' '
+	rm test.utf16lebom &&
+	git checkout test.utf16lebom &&
+	test_cmp_bin test.utf16lebom.raw test.utf16lebom
+'
+
 test_expect_success 'check $GIT_DIR/info/attributes support' '
 	test_when_finished "rm -f test.utf32.git" &&
 	test_when_finished "git reset --hard HEAD" &&
@@ -114,8 +148,8 @@ do
 		test_when_finished "rm -f crlf.utf${i}.raw lf.utf${i}.raw" &&
 		test_when_finished "git reset --hard HEAD^" &&
 
-		cat lf.utf8.raw | iconv -f UTF-8 -t UTF-${i} >lf.utf${i}.raw &&
-		cat crlf.utf8.raw | iconv -f UTF-8 -t UTF-${i} >crlf.utf${i}.raw &&
+		cat lf.utf8.raw | write_utf${i} >lf.utf${i}.raw &&
+		cat crlf.utf8.raw | write_utf${i} >crlf.utf${i}.raw &&
 		cp crlf.utf${i}.raw eol.utf${i} &&
 
 		cat >expectIndexLF <<-EOF &&
@@ -203,13 +237,17 @@ test_expect_success 'error if encoding g
 	test_i18ngrep "error: BOM is required" err.out
 '
 
-test_expect_success 'check roundtrip encoding' '
+test_lazy_prereq ICONV_SHIFT_JIS '
+	iconv -f UTF-8 -t SHIFT-JIS </dev/null
+'
+
+test_expect_success ICONV_SHIFT_JIS 'check roundtrip encoding' '
 	test_when_finished "rm -f roundtrip.shift roundtrip.utf16" &&
 	test_when_finished "git reset --hard HEAD" &&
 
 	text="hallo there!\nroundtrip test here!" &&
 	printf "$text" | iconv -f UTF-8 -t SHIFT-JIS >roundtrip.shift &&
-	printf "$text" | iconv -f UTF-8 -t UTF-16 >roundtrip.utf16 &&
+	printf "$text" | write_utf16 >roundtrip.utf16 &&
 	echo "*.shift text working-tree-encoding=SHIFT-JIS" >>.gitattributes &&
 
 	# SHIFT-JIS encoded files are round-trip checked by default...
@@ -242,4 +280,43 @@ test_expect_success 'check roundtrip enc
 	git reset
 '
 
+# $1: checkout encoding
+# $2: test string
+# $3: binary test string in checkout encoding
+test_commit_utf8_checkout_other () {
+	encoding="$1"
+	orig_string="$2"
+	expect_bytes="$3"
+
+	test_expect_success "Commit UTF-8, checkout $encoding" '
+		test_when_finished "git checkout HEAD -- .gitattributes" &&
+
+		test_ext="commit_utf8_checkout_$encoding" &&
+		test_file="test.$test_ext" &&
+
+		# Commit as UTF-8
+		echo "*.$test_ext text working-tree-encoding=UTF-8" >.gitattributes &&
+		printf "$orig_string" >$test_file &&
+		git add $test_file &&
+		git commit -m "Test data" &&
+
+		# Checkout in tested encoding
+		rm $test_file &&
+		echo "*.$test_ext text working-tree-encoding=$encoding" >.gitattributes &&
+		git checkout HEAD -- $test_file &&
+
+		# Test
+		printf $expect_bytes >$test_file.raw &&
+		test_cmp_bin $test_file.raw $test_file
+	'
+}
+
+test_commit_utf8_checkout_other "UTF-8"        "Test Тест" "\124\145\163\164\040\320\242\320\265\321\201\321\202"
+test_commit_utf8_checkout_other "UTF-16LE"     "Test Тест" "\124\000\145\000\163\000\164\000\040\000\042\004\065\004\101\004\102\004"
+test_commit_utf8_checkout_other "UTF-16BE"     "Test Тест" "\000\124\000\145\000\163\000\164\000\040\004\042\004\065\004\101\004\102"
+test_commit_utf8_checkout_other "UTF-16LE-BOM" "Test Тест" "\377\376\124\000\145\000\163\000\164\000\040\000\042\004\065\004\101\004\102\004"
+test_commit_utf8_checkout_other "UTF-16BE-BOM" "Test Тест" "\376\377\000\124\000\145\000\163\000\164\000\040\004\042\004\065\004\101\004\102"
+test_commit_utf8_checkout_other "UTF-32LE"     "Test Тест" "\124\000\000\000\145\000\000\000\163\000\000\000\164\000\000\000\040\000\000\000\042\004\000\000\065\004\000\000\101\004\000\000\102\004\000\000"
+test_commit_utf8_checkout_other "UTF-32BE"     "Test Тест" "\000\000\000\124\000\000\000\145\000\000\000\163\000\000\000\164\000\000\000\040\000\000\004\042\000\000\004\065\000\000\004\101\000\000\004\102"
+
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t0029-core-unsetenvvars.sh 1.2.3+git2.25.1-1/git/t/t0029-core-unsetenvvars.sh
--- 1.2.1+git2.18.0-1/git/t/t0029-core-unsetenvvars.sh	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t0029-core-unsetenvvars.sh	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,30 @@
+#!/bin/sh
+
+test_description='test the Windows-only core.unsetenvvars setting'
+
+. ./test-lib.sh
+
+if ! test_have_prereq MINGW
+then
+	skip_all='skipping Windows-specific tests'
+	test_done
+fi
+
+test_expect_success 'setup' '
+	mkdir -p "$TRASH_DIRECTORY/.git/hooks" &&
+	write_script "$TRASH_DIRECTORY/.git/hooks/pre-commit" <<-\EOF
+	echo $HOBBES >&2
+	EOF
+'
+
+test_expect_success 'core.unsetenvvars works' '
+	HOBBES=Calvin &&
+	export HOBBES &&
+	git commit --allow-empty -m with 2>err &&
+	grep Calvin err &&
+	git -c core.unsetenvvars=FINDUS,HOBBES,CALVIN \
+		commit --allow-empty -m without 2>err &&
+	! grep Calvin err
+'
+
+test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t0030-stripspace.sh 1.2.3+git2.25.1-1/git/t/t0030-stripspace.sh
--- 1.2.1+git2.18.0-1/git/t/t0030-stripspace.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t0030-stripspace.sh	2020-02-17 04:47:35.000000000 +0000
@@ -110,31 +110,30 @@ test_expect_success \
 
 test_expect_success \
     'only consecutive blank lines should be completely removed' '
-    > expect &&
 
     printf "\n" | git stripspace >actual &&
-    test_cmp expect actual &&
+    test_must_be_empty actual &&
 
     printf "\n\n\n" | git stripspace >actual &&
-    test_cmp expect actual &&
+    test_must_be_empty actual &&
 
     printf "$sss\n$sss\n$sss\n" | git stripspace >actual &&
-    test_cmp expect actual &&
+    test_must_be_empty actual &&
 
     printf "$sss$sss\n$sss\n\n" | git stripspace >actual &&
-    test_cmp expect actual &&
+    test_must_be_empty actual &&
 
     printf "\n$sss\n$sss$sss\n" | git stripspace >actual &&
-    test_cmp expect actual &&
+    test_must_be_empty actual &&
 
     printf "$sss$sss$sss$sss\n\n\n" | git stripspace >actual &&
-    test_cmp expect actual &&
+    test_must_be_empty actual &&
 
     printf "\n$sss$sss$sss$sss\n\n" | git stripspace >actual &&
-    test_cmp expect actual &&
+    test_must_be_empty actual &&
 
     printf "\n\n$sss$sss$sss$sss\n" | git stripspace >actual &&
-    test_cmp expect actual
+    test_must_be_empty actual
 '
 
 test_expect_success \
@@ -321,22 +320,20 @@ test_expect_success \
 
 test_expect_success \
     'spaces with newline at end should be replaced with empty string' '
-    printf "" >expect &&
-
     echo | git stripspace >actual &&
-    test_cmp expect actual &&
+    test_must_be_empty actual &&
 
     echo "$sss" | git stripspace >actual &&
-    test_cmp expect actual &&
+    test_must_be_empty actual &&
 
     echo "$sss$sss" | git stripspace >actual &&
-    test_cmp expect actual &&
+    test_must_be_empty actual &&
 
     echo "$sss$sss$sss" | git stripspace >actual &&
-    test_cmp expect actual &&
+    test_must_be_empty actual &&
 
     echo "$sss$sss$sss$sss" | git stripspace >actual &&
-    test_cmp expect actual
+    test_must_be_empty actual
 '
 
 test_expect_success \
@@ -350,19 +347,17 @@ test_expect_success \
 
 test_expect_success \
     'spaces without newline at end should be replaced with empty string' '
-    printf "" >expect &&
-
     printf "" | git stripspace >actual &&
-    test_cmp expect actual &&
+    test_must_be_empty actual &&
 
     printf "$sss$sss" | git stripspace >actual &&
-    test_cmp expect actual &&
+    test_must_be_empty actual &&
 
     printf "$sss$sss$sss" | git stripspace >actual &&
-    test_cmp expect actual &&
+    test_must_be_empty actual &&
 
     printf "$sss$sss$sss$sss" | git stripspace >actual &&
-    test_cmp expect actual
+    test_must_be_empty actual
 '
 
 test_expect_success \
@@ -435,9 +430,15 @@ test_expect_success '-c with changed com
 test_expect_success '-c with comment char defined in .git/config' '
 	test_config core.commentchar = &&
 	printf "= foo\n" >expect &&
-	printf "foo" | (
-		mkdir sub && cd sub && git stripspace -c
-	) >actual &&
+	rm -fr sub &&
+	mkdir sub &&
+	printf "foo" | git -C sub stripspace -c >actual &&
+	test_cmp expect actual
+'
+
+test_expect_success '-c outside git repository' '
+	printf "# foo\n" >expect &&
+	printf "foo" | nongit git stripspace -c >actual &&
 	test_cmp expect actual
 '
 
diff -pruN 1.2.1+git2.18.0-1/git/t/t0040-parse-options.sh 1.2.3+git2.25.1-1/git/t/t0040-parse-options.sh
--- 1.2.1+git2.18.0-1/git/t/t0040-parse-options.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t0040-parse-options.sh	2020-02-17 04:47:35.000000000 +0000
@@ -8,7 +8,7 @@ test_description='our own option parser'
 . ./test-lib.sh
 
 cat >expect <<\EOF
-usage: test-parse-options <options>
+usage: test-tool parse-options <options>
 
     A helper function for the parse-options API.
 
@@ -23,7 +23,6 @@ usage: test-parse-options <options>
     -j <n>                get a integer, too
     -m, --magnitude <n>   get a magnitude
     --set23               set integer to 23
-    -t <time>             get timestamp of <time>
     -L, --length <str>    get length of <str>
     -F, --file <file>     set file to <file>
 
@@ -49,10 +48,16 @@ Standard options
     -q, --quiet           be quiet
     --expect <string>     expected output in the variable dump
 
+Alias
+    -A, --alias-source <string>
+                          get a string
+    -Z, --alias-target <string>
+                          get a string
+
 EOF
 
 test_expect_success 'test help' '
-	test_must_fail test-parse-options -h >output 2>output.err &&
+	test_must_fail test-tool parse-options -h >output 2>output.err &&
 	test_must_be_empty output.err &&
 	test_i18ncmp expect output
 '
@@ -64,7 +69,7 @@ check () {
 	shift &&
 	expect="$1" &&
 	shift &&
-	test-parse-options --expect="$what $expect" "$@"
+	test-tool parse-options --expect="$what $expect" "$@"
 }
 
 check_unknown_i18n() {
@@ -75,7 +80,7 @@ check_unknown_i18n() {
 		echo error: unknown switch \`${1#-}\' >expect ;;
 	esac &&
 	cat expect.err >>expect &&
-	test_must_fail test-parse-options $* >output 2>output.err &&
+	test_must_fail test-tool parse-options $* >output 2>output.err &&
 	test_must_be_empty output &&
 	test_i18ncmp expect output.err
 }
@@ -133,7 +138,7 @@ file: prefix/my.file
 EOF
 
 test_expect_success 'short options' '
-	test-parse-options -s123 -b -i 1729 -m 16k -b -vv -n -F my.file \
+	test-tool parse-options -s123 -b -i 1729 -m 16k -b -vv -n -F my.file \
 	>output 2>output.err &&
 	test_cmp expect output &&
 	test_must_be_empty output.err
@@ -153,7 +158,7 @@ file: prefix/fi.le
 EOF
 
 test_expect_success 'long options' '
-	test-parse-options --boolean --integer 1729 --magnitude 16k \
+	test-tool parse-options --boolean --integer 1729 --magnitude 16k \
 		--boolean --string2=321 --verbose --verbose --no-dry-run \
 		--abbrev=10 --file fi.le --obsolete \
 		>output 2>output.err &&
@@ -162,9 +167,9 @@ test_expect_success 'long options' '
 '
 
 test_expect_success 'missing required value' '
-	test_expect_code 129 test-parse-options -s &&
-	test_expect_code 129 test-parse-options --string &&
-	test_expect_code 129 test-parse-options --file
+	test_expect_code 129 test-tool parse-options -s &&
+	test_expect_code 129 test-tool parse-options --string &&
+	test_expect_code 129 test-tool parse-options --file
 '
 
 cat >expect <<\EOF
@@ -184,7 +189,7 @@ arg 02: --boolean
 EOF
 
 test_expect_success 'intermingled arguments' '
-	test-parse-options a1 --string 123 b1 --boolean -j 13 -- --boolean \
+	test-tool parse-options a1 --string 123 b1 --boolean -j 13 -- --boolean \
 		>output 2>output.err &&
 	test_must_be_empty output.err &&
 	test_cmp expect output
@@ -204,66 +209,60 @@ file: (not set)
 EOF
 
 test_expect_success 'unambiguously abbreviated option' '
-	test-parse-options --int 2 --boolean --no-bo >output 2>output.err &&
+	GIT_TEST_DISALLOW_ABBREVIATED_OPTIONS=false \
+	test-tool parse-options --int 2 --boolean --no-bo >output 2>output.err &&
 	test_must_be_empty output.err &&
 	test_cmp expect output
 '
 
 test_expect_success 'unambiguously abbreviated option with "="' '
-	test-parse-options --expect="integer: 2" --int=2
+	GIT_TEST_DISALLOW_ABBREVIATED_OPTIONS=false \
+	test-tool parse-options --expect="integer: 2" --int=2
 '
 
 test_expect_success 'ambiguously abbreviated option' '
-	test_expect_code 129 test-parse-options --strin 123
+	test_expect_code 129 env GIT_TEST_DISALLOW_ABBREVIATED_OPTIONS=false \
+	test-tool parse-options --strin 123
 '
 
 test_expect_success 'non ambiguous option (after two options it abbreviates)' '
-	test-parse-options --expect="string: 123" --st 123
+	GIT_TEST_DISALLOW_ABBREVIATED_OPTIONS=false \
+	test-tool parse-options --expect="string: 123" --st 123
+'
+
+test_expect_success 'Alias options do not contribute to abbreviation' '
+	test-tool parse-options --alias-source 123 >output &&
+	grep "^string: 123" output &&
+	test-tool parse-options --alias-target 123 >output &&
+	grep "^string: 123" output &&
+	test_must_fail test-tool parse-options --alias &&
+	GIT_TEST_DISALLOW_ABBREVIATED_OPTIONS=false \
+	test-tool parse-options --alias 123 >output &&
+	grep "^string: 123" output
 '
 
 cat >typo.err <<\EOF
-error: did you mean `--boolean` (with two dashes ?)
+error: did you mean `--boolean` (with two dashes)?
 EOF
 
 test_expect_success 'detect possible typos' '
-	test_must_fail test-parse-options -boolean >output 2>output.err &&
+	test_must_fail test-tool parse-options -boolean >output 2>output.err &&
 	test_must_be_empty output &&
-	test_cmp typo.err output.err
+	test_i18ncmp typo.err output.err
 '
 
 cat >typo.err <<\EOF
-error: did you mean `--ambiguous` (with two dashes ?)
+error: did you mean `--ambiguous` (with two dashes)?
 EOF
 
 test_expect_success 'detect possible typos' '
-	test_must_fail test-parse-options -ambiguous >output 2>output.err &&
+	test_must_fail test-tool parse-options -ambiguous >output 2>output.err &&
 	test_must_be_empty output &&
-	test_cmp typo.err output.err
+	test_i18ncmp typo.err output.err
 '
 
 test_expect_success 'keep some options as arguments' '
-	test-parse-options --expect="arg 00: --quux" --quux
-'
-
-cat >expect <<\EOF
-boolean: 0
-integer: 0
-magnitude: 0
-timestamp: 1
-string: (not set)
-abbrev: 7
-verbose: -1
-quiet: 1
-dry run: no
-file: (not set)
-arg 00: foo
-EOF
-
-test_expect_success 'OPT_DATE() works' '
-	test-parse-options -t "1970-01-01 00:00:01 +0000" \
-		foo -q >output 2>output.err &&
-	test_must_be_empty output.err &&
-	test_cmp expect output
+	test-tool parse-options --expect="arg 00: --quux" --quux
 '
 
 cat >expect <<\EOF
@@ -281,16 +280,14 @@ file: (not set)
 EOF
 
 test_expect_success 'OPT_CALLBACK() and OPT_BIT() work' '
-	test-parse-options --length=four -b -4 >output 2>output.err &&
+	test-tool parse-options --length=four -b -4 >output 2>output.err &&
 	test_must_be_empty output.err &&
 	test_cmp expect output
 '
 
->expect
-
 test_expect_success 'OPT_CALLBACK() and callback errors work' '
-	test_must_fail test-parse-options --no-length >output 2>output.err &&
-	test_i18ncmp expect output &&
+	test_must_fail test-tool parse-options --no-length >output 2>output.err &&
+	test_must_be_empty output &&
 	test_must_be_empty output.err
 '
 
@@ -308,31 +305,31 @@ file: (not set)
 EOF
 
 test_expect_success 'OPT_BIT() and OPT_SET_INT() work' '
-	test-parse-options --set23 -bbbbb --no-or4 >output 2>output.err &&
+	test-tool parse-options --set23 -bbbbb --no-or4 >output 2>output.err &&
 	test_must_be_empty output.err &&
 	test_cmp expect output
 '
 
 test_expect_success 'OPT_NEGBIT() and OPT_SET_INT() work' '
-	test-parse-options --set23 -bbbbb --neg-or4 >output 2>output.err &&
+	test-tool parse-options --set23 -bbbbb --neg-or4 >output 2>output.err &&
 	test_must_be_empty output.err &&
 	test_cmp expect output
 '
 
 test_expect_success 'OPT_BIT() works' '
-	test-parse-options --expect="boolean: 6" -bb --or4
+	test-tool parse-options --expect="boolean: 6" -bb --or4
 '
 
 test_expect_success 'OPT_NEGBIT() works' '
-	test-parse-options --expect="boolean: 6" -bb --no-neg-or4
+	test-tool parse-options --expect="boolean: 6" -bb --no-neg-or4
 '
 
 test_expect_success 'OPT_COUNTUP() with PARSE_OPT_NODASH works' '
-	test-parse-options --expect="boolean: 6" + + + + + +
+	test-tool parse-options --expect="boolean: 6" + + + + + +
 '
 
 test_expect_success 'OPT_NUMBER_CALLBACK() works' '
-	test-parse-options --expect="integer: 12345" -12345
+	test-tool parse-options --expect="integer: 12345" -12345
 '
 
 cat >expect <<\EOF
@@ -349,7 +346,8 @@ file: (not set)
 EOF
 
 test_expect_success 'negation of OPT_NONEG flags is not ambiguous' '
-	test-parse-options --no-ambig >output 2>output.err &&
+	GIT_TEST_DISALLOW_ABBREVIATED_OPTIONS=false \
+	test-tool parse-options --no-ambig >output 2>output.err &&
 	test_must_be_empty output.err &&
 	test_cmp expect output
 '
@@ -360,38 +358,52 @@ list: bar
 list: baz
 EOF
 test_expect_success '--list keeps list of strings' '
-	test-parse-options --list foo --list=bar --list=baz >output &&
+	test-tool parse-options --list foo --list=bar --list=baz >output &&
 	test_cmp expect output
 '
 
 test_expect_success '--no-list resets list' '
-	test-parse-options --list=other --list=irrelevant --list=options \
+	test-tool parse-options --list=other --list=irrelevant --list=options \
 		--no-list --list=foo --list=bar --list=baz >output &&
 	test_cmp expect output
 '
 
 test_expect_success 'multiple quiet levels' '
-	test-parse-options --expect="quiet: 3" -q -q -q
+	test-tool parse-options --expect="quiet: 3" -q -q -q
 '
 
 test_expect_success 'multiple verbose levels' '
-	test-parse-options --expect="verbose: 3" -v -v -v
+	test-tool parse-options --expect="verbose: 3" -v -v -v
 '
 
 test_expect_success '--no-quiet sets --quiet to 0' '
-	test-parse-options --expect="quiet: 0" --no-quiet
+	test-tool parse-options --expect="quiet: 0" --no-quiet
 '
 
 test_expect_success '--no-quiet resets multiple -q to 0' '
-	test-parse-options --expect="quiet: 0" -q -q -q --no-quiet
+	test-tool parse-options --expect="quiet: 0" -q -q -q --no-quiet
 '
 
 test_expect_success '--no-verbose sets verbose to 0' '
-	test-parse-options --expect="verbose: 0" --no-verbose
+	test-tool parse-options --expect="verbose: 0" --no-verbose
 '
 
 test_expect_success '--no-verbose resets multiple verbose to 0' '
-	test-parse-options --expect="verbose: 0" -v -v -v --no-verbose
+	test-tool parse-options --expect="verbose: 0" -v -v -v --no-verbose
+'
+
+test_expect_success 'GIT_TEST_DISALLOW_ABBREVIATED_OPTIONS works' '
+	GIT_TEST_DISALLOW_ABBREVIATED_OPTIONS=false \
+		test-tool parse-options --ye &&
+	test_must_fail env GIT_TEST_DISALLOW_ABBREVIATED_OPTIONS=true \
+		test-tool parse-options --ye
+'
+
+test_expect_success '--end-of-options treats remainder as args' '
+	test-tool parse-options \
+	    --expect="verbose: -1" \
+	    --expect="arg 00: --verbose" \
+	    --end-of-options --verbose
 '
 
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t0050-filesystem.sh 1.2.3+git2.25.1-1/git/t/t0050-filesystem.sh
--- 1.2.1+git2.18.0-1/git/t/t0050-filesystem.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t0050-filesystem.sh	2020-02-17 04:47:35.000000000 +0000
@@ -131,4 +131,24 @@ $test_unicode 'merge (silent unicode nor
 	git merge topic
 '
 
+test_expect_success CASE_INSENSITIVE_FS 'checkout with no pathspec and a case insensitive fs' '
+	git init repo &&
+	(
+		cd repo &&
+
+		>Gitweb &&
+		git add Gitweb &&
+		git commit -m "add Gitweb" &&
+
+		git checkout --orphan todo &&
+		git reset --hard &&
+		mkdir -p gitweb/subdir &&
+		>gitweb/subdir/file &&
+		git add gitweb &&
+		git commit -m "add gitweb/subdir/file" &&
+
+		git checkout master
+	)
+'
+
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t0051-windows-named-pipe.sh 1.2.3+git2.25.1-1/git/t/t0051-windows-named-pipe.sh
--- 1.2.1+git2.18.0-1/git/t/t0051-windows-named-pipe.sh	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t0051-windows-named-pipe.sh	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,17 @@
+#!/bin/sh
+
+test_description='Windows named pipes'
+
+. ./test-lib.sh
+
+test_expect_success MINGW 'o_append write to named pipe' '
+	GIT_TRACE="$(pwd)/expect" git status >/dev/null 2>&1 &&
+	{ test-tool windows-named-pipe t0051 >actual 2>&1 & } &&
+	pid=$! &&
+	sleep 1 &&
+	GIT_TRACE=//./pipe/t0051 git status >/dev/null 2>warning &&
+	wait $pid &&
+	test_cmp expect actual
+'
+
+test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t0060-path-utils.sh 1.2.3+git2.25.1-1/git/t/t0060-path-utils.sh
--- 1.2.1+git2.18.0-1/git/t/t0060-path-utils.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t0060-path-utils.sh	2020-02-17 04:47:35.000000000 +0000
@@ -165,6 +165,15 @@ test_expect_success 'absolute path rejec
 	test_must_fail test-tool path-utils absolute_path ""
 '
 
+test_expect_success MINGW '<drive-letter>:\\abc is an absolute path' '
+	for letter in : \" C Z 1 ä
+	do
+		path=$letter:\\abc &&
+		absolute="$(test-tool path-utils absolute_path "$path")" &&
+		test "$path" = "$absolute" || return 1
+	done
+'
+
 test_expect_success 'real path rejects the empty string' '
 	test_must_fail test-tool path-utils real_path ""
 '
@@ -285,9 +294,13 @@ test_git_path GIT_OBJECT_DIRECTORY=foo o
 test_git_path GIT_OBJECT_DIRECTORY=foo objects2 .git/objects2
 test_expect_success 'setup common repository' 'git --git-dir=bar init'
 test_git_path GIT_COMMON_DIR=bar index                    .git/index
+test_git_path GIT_COMMON_DIR=bar index.lock               .git/index.lock
 test_git_path GIT_COMMON_DIR=bar HEAD                     .git/HEAD
 test_git_path GIT_COMMON_DIR=bar logs/HEAD                .git/logs/HEAD
+test_git_path GIT_COMMON_DIR=bar logs/HEAD.lock           .git/logs/HEAD.lock
 test_git_path GIT_COMMON_DIR=bar logs/refs/bisect/foo     .git/logs/refs/bisect/foo
+test_git_path GIT_COMMON_DIR=bar logs/refs                bar/logs/refs
+test_git_path GIT_COMMON_DIR=bar logs/refs/               bar/logs/refs/
 test_git_path GIT_COMMON_DIR=bar logs/refs/bisec/foo      bar/logs/refs/bisec/foo
 test_git_path GIT_COMMON_DIR=bar logs/refs/bisec          bar/logs/refs/bisec
 test_git_path GIT_COMMON_DIR=bar logs/refs/bisectfoo      bar/logs/refs/bisectfoo
@@ -306,6 +319,8 @@ test_git_path GIT_COMMON_DIR=bar hooks/m
 test_git_path GIT_COMMON_DIR=bar config                   bar/config
 test_git_path GIT_COMMON_DIR=bar packed-refs              bar/packed-refs
 test_git_path GIT_COMMON_DIR=bar shallow                  bar/shallow
+test_git_path GIT_COMMON_DIR=bar common                   bar/common
+test_git_path GIT_COMMON_DIR=bar common/file              bar/common/file
 
 # In the tests below, $(pwd) must be used because it is a native path on
 # Windows and avoids MSYS's path mangling (which simplifies "foo/../bar" and
@@ -330,6 +345,9 @@ test_submodule_relative_url "(null)" "..
 test_submodule_relative_url "(null)" "./foo/bar" "../submodule" "foo/submodule"
 test_submodule_relative_url "(null)" "./foo" "../submodule" "submodule"
 test_submodule_relative_url "(null)" "//somewhere else/repo" "../subrepo" "//somewhere else/subrepo"
+test_submodule_relative_url "(null)" "//somewhere else/repo" "../../subrepo" "//subrepo"
+test_submodule_relative_url "(null)" "//somewhere else/repo" "../../../subrepo" "/subrepo"
+test_submodule_relative_url "(null)" "//somewhere else/repo" "../../../../subrepo" "subrepo"
 test_submodule_relative_url "(null)" "$(pwd)/subsuper_update_r" "../subsubsuper_update_r" "$(pwd)/subsubsuper_update_r"
 test_submodule_relative_url "(null)" "$(pwd)/super_update_r2" "../subsuper_update_r" "$(pwd)/subsuper_update_r"
 test_submodule_relative_url "(null)" "$(pwd)/." "../." "$(pwd)/."
@@ -344,10 +362,20 @@ test_submodule_relative_url "(null)" "fi
 test_submodule_relative_url "(null)" "foo/bar" "../submodule" "foo/submodule"
 test_submodule_relative_url "(null)" "foo" "../submodule" "submodule"
 test_submodule_relative_url "(null)" "helper:://hostname/repo" "../subrepo" "helper:://hostname/subrepo"
+test_submodule_relative_url "(null)" "helper:://hostname/repo" "../../subrepo" "helper:://subrepo"
+test_submodule_relative_url "(null)" "helper:://hostname/repo" "../../../subrepo" "helper::/subrepo"
+test_submodule_relative_url "(null)" "helper:://hostname/repo" "../../../../subrepo" "helper::subrepo"
+test_submodule_relative_url "(null)" "helper:://hostname/repo" "../../../../../subrepo" "helper:subrepo"
+test_submodule_relative_url "(null)" "helper:://hostname/repo" "../../../../../../subrepo" ".:subrepo"
 test_submodule_relative_url "(null)" "ssh://hostname/repo" "../subrepo" "ssh://hostname/subrepo"
+test_submodule_relative_url "(null)" "ssh://hostname/repo" "../../subrepo" "ssh://subrepo"
+test_submodule_relative_url "(null)" "ssh://hostname/repo" "../../../subrepo" "ssh:/subrepo"
+test_submodule_relative_url "(null)" "ssh://hostname/repo" "../../../../subrepo" "ssh:subrepo"
+test_submodule_relative_url "(null)" "ssh://hostname/repo" "../../../../../subrepo" ".:subrepo"
 test_submodule_relative_url "(null)" "ssh://hostname:22/repo" "../subrepo" "ssh://hostname:22/subrepo"
 test_submodule_relative_url "(null)" "user@host:path/to/repo" "../subrepo" "user@host:path/to/subrepo"
 test_submodule_relative_url "(null)" "user@host:repo" "../subrepo" "user@host:subrepo"
+test_submodule_relative_url "(null)" "user@host:repo" "../../subrepo" ".:subrepo"
 
 test_expect_success 'match .gitmodules' '
 	test-tool path-utils is_dotgitmodules \
@@ -408,6 +436,9 @@ test_expect_success 'match .gitmodules'
 		~1000000 \
 		~9999999 \
 		\
+		.gitmodules:\$DATA \
+		"gitmod~4 . :\$DATA" \
+		\
 		--not \
 		".gitmodules x"  \
 		".gitmodules .x" \
@@ -432,7 +463,34 @@ test_expect_success 'match .gitmodules'
 		\
 		GI7EB~1 \
 		GI7EB~01 \
-		GI7EB~1X
+		GI7EB~1X \
+		\
+		.gitmodules,:\$DATA
+'
+
+test_expect_success MINGW 'is_valid_path() on Windows' '
+	test-tool path-utils is_valid_path \
+		win32 \
+		"win32 x" \
+		../hello.txt \
+		C:\\git \
+		comm \
+		conout.c \
+		lptN \
+		\
+		--not \
+		"win32 "  \
+		"win32 /x "  \
+		"win32."  \
+		"win32 . ." \
+		.../hello.txt \
+		colon:test \
+		"AUX.c" \
+		"abc/conOut\$  .xyz/test" \
+		lpt8 \
+		"lpt*" \
+		Nul \
+		"PRN./abc"
 '
 
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t0061-run-command.sh 1.2.3+git2.25.1-1/git/t/t0061-run-command.sh
--- 1.2.1+git2.18.0-1/git/t/t0061-run-command.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t0061-run-command.sh	2020-02-17 04:47:35.000000000 +0000
@@ -11,10 +11,19 @@ cat >hello-script <<-EOF
 	#!$SHELL_PATH
 	cat hello-script
 EOF
->empty
 
-test_expect_success 'start_command reports ENOENT' '
-	test-tool run-command start-command-ENOENT ./does-not-exist
+test_expect_success MINGW 'subprocess inherits only std handles' '
+	test-tool run-command inherited-handle
+'
+
+test_expect_success 'start_command reports ENOENT (slash)' '
+	test-tool run-command start-command-ENOENT ./does-not-exist 2>err &&
+	test_i18ngrep "\./does-not-exist" err
+'
+
+test_expect_success 'start_command reports ENOENT (no slash)' '
+	test-tool run-command start-command-ENOENT does-not-exist 2>err &&
+	test_i18ngrep "does-not-exist" err
 '
 
 test_expect_success 'run_command can run a command' '
@@ -23,7 +32,23 @@ test_expect_success 'run_command can run
 	test-tool run-command run-command ./hello.sh >actual 2>err &&
 
 	test_cmp hello-script actual &&
-	test_cmp empty err
+	test_must_be_empty err
+'
+
+
+test_lazy_prereq RUNS_COMMANDS_FROM_PWD '
+	write_script runs-commands-from-pwd <<-\EOF &&
+	true
+	EOF
+	runs-commands-from-pwd >/dev/null 2>&1
+'
+
+test_expect_success !RUNS_COMMANDS_FROM_PWD 'run_command is restricted to PATH' '
+	write_script should-not-run <<-\EOF &&
+	echo yikes
+	EOF
+	test_must_fail test-tool run-command run-command should-not-run 2>err &&
+	test_i18ngrep "should-not-run" err
 '
 
 test_expect_success !MINGW 'run_command can run a script without a #! line' '
@@ -34,7 +59,7 @@ test_expect_success !MINGW 'run_command
 	test-tool run-command run-command ./hello >actual 2>err &&
 
 	test_cmp hello-script actual &&
-	test_cmp empty err
+	test_must_be_empty err
 '
 
 test_expect_success 'run_command does not try to execute a directory' '
@@ -47,7 +72,7 @@ test_expect_success 'run_command does no
 	PATH=$PWD/bin1:$PWD/bin2:$PATH \
 		test-tool run-command run-command greet >actual 2>err &&
 	test_cmp bin2/greet actual &&
-	test_cmp empty err
+	test_must_be_empty err
 '
 
 test_expect_success POSIXPERM 'run_command passes over non-executable file' '
@@ -64,7 +89,7 @@ test_expect_success POSIXPERM 'run_comma
 	PATH=$PWD/bin1:$PWD/bin2:$PATH \
 		test-tool run-command run-command greet >actual 2>err &&
 	test_cmp bin2/greet actual &&
-	test_cmp empty err
+	test_must_be_empty err
 '
 
 test_expect_success POSIXPERM 'run_command reports EACCES' '
@@ -145,7 +170,8 @@ test_trace () {
 	expect="$1"
 	shift
 	GIT_TRACE=1 test-tool run-command "$@" run-command true 2>&1 >/dev/null | \
-		sed -e 's/.* run_command: //' -e '/trace: .*/d' >actual &&
+		sed -e 's/.* run_command: //' -e '/trace: .*/d' \
+			-e '/RUNTIME_PREFIX requested/d' >actual &&
 	echo "$expect true" >expect &&
 	test_cmp expect actual
 }
@@ -178,4 +204,33 @@ test_expect_success 'GIT_TRACE with envi
 	)
 '
 
+test_expect_success MINGW 'verify curlies are quoted properly' '
+	: force the rev-parse through the MSYS2 Bash &&
+	git -c alias.r="!git rev-parse" r -- a{b}c >actual &&
+	cat >expect <<-\EOF &&
+	--
+	a{b}c
+	EOF
+	test_cmp expect actual
+'
+
+test_expect_success MINGW 'can spawn .bat with argv[0] containing spaces' '
+	bat="$TRASH_DIRECTORY/bat with spaces in name.bat" &&
+
+	# Every .bat invocation will log its arguments to file "out"
+	rm -f out &&
+	echo "echo %* >>out" >"$bat" &&
+
+	# Ask git to invoke .bat; clone will fail due to fake SSH helper
+	test_must_fail env GIT_SSH="$bat" git clone myhost:src ssh-clone &&
+
+	# Spawning .bat can fail if there are two quoted cmd.exe arguments.
+	# .bat itself is first (due to spaces in name), so just one more is
+	# needed to verify. GIT_SSH will invoke .bat multiple times:
+	# 1) -G myhost
+	# 2) myhost "git-upload-pack src"
+	# First invocation will always succeed. Test the second one.
+	grep "git-upload-pack" out
+'
+
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t0064-sha1-array.sh 1.2.3+git2.25.1-1/git/t/t0064-sha1-array.sh
--- 1.2.1+git2.18.0-1/git/t/t0064-sha1-array.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t0064-sha1-array.sh	2020-02-17 04:47:35.000000000 +0000
@@ -3,30 +3,30 @@
 test_description='basic tests for the SHA1 array implementation'
 . ./test-lib.sh
 
-echo20 () {
+echoid () {
 	prefix="${1:+$1 }"
 	shift
 	while test $# -gt 0
 	do
-		echo "$prefix$1$1$1$1$1$1$1$1$1$1$1$1$1$1$1$1$1$1$1$1"
+		echo "$prefix$ZERO_OID" | sed -e "s/00/$1/g"
 		shift
 	done
 }
 
 test_expect_success 'ordered enumeration' '
-	echo20 "" 44 55 88 aa >expect &&
+	echoid "" 44 55 88 aa >expect &&
 	{
-		echo20 append 88 44 aa 55 &&
+		echoid append 88 44 aa 55 &&
 		echo for_each_unique
 	} | test-tool sha1-array >actual &&
 	test_cmp expect actual
 '
 
 test_expect_success 'ordered enumeration with duplicate suppression' '
-	echo20 "" 44 55 88 aa >expect &&
+	echoid "" 44 55 88 aa >expect &&
 	{
-		echo20 append 88 44 aa 55 &&
-		echo20 append 88 44 aa 55 &&
+		echoid append 88 44 aa 55 &&
+		echoid append 88 44 aa 55 &&
 		echo for_each_unique
 	} | test-tool sha1-array >actual &&
 	test_cmp expect actual
@@ -34,8 +34,8 @@ test_expect_success 'ordered enumeration
 
 test_expect_success 'lookup' '
 	{
-		echo20 append 88 44 aa 55 &&
-		echo20 lookup 55
+		echoid append 88 44 aa 55 &&
+		echoid lookup 55
 	} | test-tool sha1-array >actual &&
 	n=$(cat actual) &&
 	test "$n" -eq 1
@@ -43,8 +43,8 @@ test_expect_success 'lookup' '
 
 test_expect_success 'lookup non-existing entry' '
 	{
-		echo20 append 88 44 aa 55 &&
-		echo20 lookup 33
+		echoid append 88 44 aa 55 &&
+		echoid lookup 33
 	} | test-tool sha1-array >actual &&
 	n=$(cat actual) &&
 	test "$n" -lt 0
@@ -52,9 +52,9 @@ test_expect_success 'lookup non-existing
 
 test_expect_success 'lookup with duplicates' '
 	{
-		echo20 append 88 44 aa 55 &&
-		echo20 append 88 44 aa 55 &&
-		echo20 lookup 55
+		echoid append 88 44 aa 55 &&
+		echoid append 88 44 aa 55 &&
+		echoid lookup 55
 	} | test-tool sha1-array >actual &&
 	n=$(cat actual) &&
 	test "$n" -ge 2 &&
@@ -63,19 +63,24 @@ test_expect_success 'lookup with duplica
 
 test_expect_success 'lookup non-existing entry with duplicates' '
 	{
-		echo20 append 88 44 aa 55 &&
-		echo20 append 88 44 aa 55 &&
-		echo20 lookup 66
+		echoid append 88 44 aa 55 &&
+		echoid append 88 44 aa 55 &&
+		echoid lookup 66
 	} | test-tool sha1-array >actual &&
 	n=$(cat actual) &&
 	test "$n" -lt 0
 '
 
 test_expect_success 'lookup with almost duplicate values' '
-	{
-		echo "append 5555555555555555555555555555555555555555" &&
-		echo "append 555555555555555555555555555555555555555f" &&
-		echo20 lookup 55
+	# n-1 5s
+	root=$(echoid "" 55) &&
+	root=${root%5} &&
+	{
+		id1="${root}5" &&
+		id2="${root}f" &&
+		echo "append $id1" &&
+		echo "append $id2" &&
+		echoid lookup 55
 	} | test-tool sha1-array >actual &&
 	n=$(cat actual) &&
 	test "$n" -eq 0
@@ -83,8 +88,8 @@ test_expect_success 'lookup with almost
 
 test_expect_success 'lookup with single duplicate value' '
 	{
-		echo20 append 55 55 &&
-		echo20 lookup 55
+		echoid append 55 55 &&
+		echoid lookup 55
 	} | test-tool sha1-array >actual &&
 	n=$(cat actual) &&
 	test "$n" -ge 0 &&
diff -pruN 1.2.1+git2.18.0-1/git/t/t0066-dir-iterator.sh 1.2.3+git2.25.1-1/git/t/t0066-dir-iterator.sh
--- 1.2.1+git2.18.0-1/git/t/t0066-dir-iterator.sh	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t0066-dir-iterator.sh	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,148 @@
+#!/bin/sh
+
+test_description='Test the dir-iterator functionality'
+
+. ./test-lib.sh
+
+test_expect_success 'setup' '
+	mkdir -p dir &&
+	mkdir -p dir/a/b/c/ &&
+	>dir/b &&
+	>dir/c &&
+	mkdir -p dir/d/e/d/ &&
+	>dir/a/b/c/d &&
+	>dir/a/e &&
+	>dir/d/e/d/a &&
+
+	mkdir -p dir2/a/b/c/ &&
+	>dir2/a/b/c/d
+'
+
+test_expect_success 'dir-iterator should iterate through all files' '
+	cat >expected-iteration-sorted-output <<-EOF &&
+	[d] (a) [a] ./dir/a
+	[d] (a/b) [b] ./dir/a/b
+	[d] (a/b/c) [c] ./dir/a/b/c
+	[d] (d) [d] ./dir/d
+	[d] (d/e) [e] ./dir/d/e
+	[d] (d/e/d) [d] ./dir/d/e/d
+	[f] (a/b/c/d) [d] ./dir/a/b/c/d
+	[f] (a/e) [e] ./dir/a/e
+	[f] (b) [b] ./dir/b
+	[f] (c) [c] ./dir/c
+	[f] (d/e/d/a) [a] ./dir/d/e/d/a
+	EOF
+
+	test-tool dir-iterator ./dir >out &&
+	sort out >./actual-iteration-sorted-output &&
+
+	test_cmp expected-iteration-sorted-output actual-iteration-sorted-output
+'
+
+test_expect_success 'dir-iterator should list files in the correct order' '
+	cat >expected-pre-order-output <<-EOF &&
+	[d] (a) [a] ./dir2/a
+	[d] (a/b) [b] ./dir2/a/b
+	[d] (a/b/c) [c] ./dir2/a/b/c
+	[f] (a/b/c/d) [d] ./dir2/a/b/c/d
+	EOF
+
+	test-tool dir-iterator ./dir2 >actual-pre-order-output &&
+
+	test_cmp expected-pre-order-output actual-pre-order-output
+'
+
+test_expect_success 'begin should fail upon inexistent paths' '
+	test_must_fail test-tool dir-iterator ./inexistent-path \
+		>actual-inexistent-path-output &&
+	echo "dir_iterator_begin failure: ENOENT" >expected-inexistent-path-output &&
+	test_cmp expected-inexistent-path-output actual-inexistent-path-output
+'
+
+test_expect_success 'begin should fail upon non directory paths' '
+	test_must_fail test-tool dir-iterator ./dir/b >actual-non-dir-output &&
+	echo "dir_iterator_begin failure: ENOTDIR" >expected-non-dir-output &&
+	test_cmp expected-non-dir-output actual-non-dir-output
+'
+
+test_expect_success POSIXPERM,SANITY 'advance should not fail on errors by default' '
+	cat >expected-no-permissions-output <<-EOF &&
+	[d] (a) [a] ./dir3/a
+	EOF
+
+	mkdir -p dir3/a &&
+	>dir3/a/b &&
+	chmod 0 dir3/a &&
+
+	test-tool dir-iterator ./dir3 >actual-no-permissions-output &&
+	test_cmp expected-no-permissions-output actual-no-permissions-output &&
+	chmod 755 dir3/a &&
+	rm -rf dir3
+'
+
+test_expect_success POSIXPERM,SANITY 'advance should fail on errors, w/ pedantic flag' '
+	cat >expected-no-permissions-pedantic-output <<-EOF &&
+	[d] (a) [a] ./dir3/a
+	dir_iterator_advance failure
+	EOF
+
+	mkdir -p dir3/a &&
+	>dir3/a/b &&
+	chmod 0 dir3/a &&
+
+	test_must_fail test-tool dir-iterator --pedantic ./dir3 \
+		>actual-no-permissions-pedantic-output &&
+	test_cmp expected-no-permissions-pedantic-output \
+		actual-no-permissions-pedantic-output &&
+	chmod 755 dir3/a &&
+	rm -rf dir3
+'
+
+test_expect_success SYMLINKS 'setup dirs with symlinks' '
+	mkdir -p dir4/a &&
+	mkdir -p dir4/b/c &&
+	>dir4/a/d &&
+	ln -s d dir4/a/e &&
+	ln -s ../b dir4/a/f &&
+
+	mkdir -p dir5/a/b &&
+	mkdir -p dir5/a/c &&
+	ln -s ../c dir5/a/b/d &&
+	ln -s ../ dir5/a/b/e &&
+	ln -s ../../ dir5/a/b/f
+'
+
+test_expect_success SYMLINKS 'dir-iterator should not follow symlinks by default' '
+	cat >expected-no-follow-sorted-output <<-EOF &&
+	[d] (a) [a] ./dir4/a
+	[d] (b) [b] ./dir4/b
+	[d] (b/c) [c] ./dir4/b/c
+	[f] (a/d) [d] ./dir4/a/d
+	[s] (a/e) [e] ./dir4/a/e
+	[s] (a/f) [f] ./dir4/a/f
+	EOF
+
+	test-tool dir-iterator ./dir4 >out &&
+	sort out >actual-no-follow-sorted-output &&
+
+	test_cmp expected-no-follow-sorted-output actual-no-follow-sorted-output
+'
+
+test_expect_success SYMLINKS 'dir-iterator should follow symlinks w/ follow flag' '
+	cat >expected-follow-sorted-output <<-EOF &&
+	[d] (a) [a] ./dir4/a
+	[d] (a/f) [f] ./dir4/a/f
+	[d] (a/f/c) [c] ./dir4/a/f/c
+	[d] (b) [b] ./dir4/b
+	[d] (b/c) [c] ./dir4/b/c
+	[f] (a/d) [d] ./dir4/a/d
+	[f] (a/e) [e] ./dir4/a/e
+	EOF
+
+	test-tool dir-iterator --follow-symlinks ./dir4 >out &&
+	sort out >actual-follow-sorted-output &&
+
+	test_cmp expected-follow-sorted-output actual-follow-sorted-output
+'
+
+test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t0070-fundamental.sh 1.2.3+git2.25.1-1/git/t/t0070-fundamental.sh
--- 1.2.1+git2.18.0-1/git/t/t0070-fundamental.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t0070-fundamental.sh	2020-02-17 04:47:35.000000000 +0000
@@ -19,8 +19,8 @@ test_expect_success 'mktemp to nonexiste
 
 test_expect_success POSIXPERM,SANITY 'mktemp to unwritable directory prints filename' '
 	mkdir cannotwrite &&
-	chmod -w cannotwrite &&
 	test_when_finished "chmod +w cannotwrite" &&
+	chmod -w cannotwrite &&
 	test_must_fail test-tool mktemp cannotwrite/testXXXXXX 2>err &&
 	grep "cannotwrite/test" err
 '
diff -pruN 1.2.1+git2.18.0-1/git/t/t0090-cache-tree.sh 1.2.3+git2.25.1-1/git/t/t0090-cache-tree.sh
--- 1.2.1+git2.18.0-1/git/t/t0090-cache-tree.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t0090-cache-tree.sh	2020-02-17 04:47:35.000000000 +0000
@@ -21,9 +21,10 @@ generate_expected_cache_tree_rec () {
 	parent="$2" &&
 	# ls-files might have foo/bar, foo/bar/baz, and foo/bar/quux
 	# We want to count only foo because it's the only direct child
-	subtrees=$(git ls-files|grep /|cut -d / -f 1|uniq) &&
+	git ls-files >files &&
+	subtrees=$(grep / files|cut -d / -f 1|uniq) &&
 	subtree_count=$(echo "$subtrees"|awk -v c=0 '$1 != "" {++c} END {print c}') &&
-	entries=$(git ls-files|wc -l) &&
+	entries=$(wc -l <files) &&
 	printf "SHA $dir (%d entries, %d subtrees)\n" "$entries" "$subtree_count" &&
 	for subtree in $subtrees
 	do
@@ -156,11 +157,29 @@ test_expect_success PERL 'commit --inter
 		return 44;
 	}
 	EOT
-	(echo p; echo 1; echo; echo s; echo n; echo y; echo q) |
+	test_write_lines p 1 "" s n y q |
 	git commit --interactive -m foo &&
 	test_cache_tree
 '
 
+test_expect_success PERL 'commit -p with shrinking cache-tree' '
+	mkdir -p deep/very-long-subdir &&
+	echo content >deep/very-long-subdir/file &&
+	git add deep &&
+	git commit -m add &&
+	git rm -r deep &&
+
+	before=$(wc -c <.git/index) &&
+	git commit -m delete -p &&
+	after=$(wc -c <.git/index) &&
+
+	# double check that the index shrank
+	test $before -gt $after &&
+
+	# and that our index was not corrupted
+	git fsck
+'
+
 test_expect_success 'commit in child dir has cache-tree' '
 	mkdir dir &&
 	>dir/child.t &&
@@ -239,17 +258,20 @@ test_expect_success 'no phantom error wh
 	>newdir/one &&
 	git add newdir/one &&
 	git checkout 2>errors &&
-	! test -s errors
+	test_must_be_empty errors
 '
 
 test_expect_success 'switching trees does not invalidate shared index' '
-	git update-index --split-index &&
-	>split &&
-	git add split &&
-	test-tool dump-split-index .git/index | grep -v ^own >before &&
-	git commit -m "as-is" &&
-	test-tool dump-split-index .git/index | grep -v ^own >after &&
-	test_cmp before after
+	(
+		sane_unset GIT_TEST_SPLIT_INDEX &&
+		git update-index --split-index &&
+		>split &&
+		git add split &&
+		test-tool dump-split-index .git/index | grep -v ^own >before &&
+		git commit -m "as-is" &&
+		test-tool dump-split-index .git/index | grep -v ^own >after &&
+		test_cmp before after
+	)
 '
 
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t0203-gettext-setlocale-sanity.sh 1.2.3+git2.25.1-1/git/t/t0203-gettext-setlocale-sanity.sh
--- 1.2.1+git2.18.0-1/git/t/t0203-gettext-setlocale-sanity.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t0203-gettext-setlocale-sanity.sh	2020-02-17 04:47:35.000000000 +0000
@@ -11,7 +11,7 @@ test_expect_success 'git show a ISO-8859
 	. "$TEST_DIRECTORY"/t3901/8859-1.txt &&
 	test_commit "iso-c-commit" iso-under-c &&
 	git show >out 2>err &&
-	! test -s err &&
+	test_must_be_empty err &&
 	grep -q "iso-c-commit" out
 '
 
@@ -19,7 +19,7 @@ test_expect_success GETTEXT_LOCALE 'git
 	. "$TEST_DIRECTORY"/t3901/8859-1.txt &&
 	test_commit "iso-utf8-commit" iso-under-utf8 &&
 	LANGUAGE=is LC_ALL="$is_IS_locale" git show >out 2>err &&
-	! test -s err &&
+	test_must_be_empty err &&
 	grep -q "iso-utf8-commit" out
 '
 
diff -pruN 1.2.1+git2.18.0-1/git/t/t0205-gettext-poison.sh 1.2.3+git2.25.1-1/git/t/t0205-gettext-poison.sh
--- 1.2.1+git2.18.0-1/git/t/t0205-gettext-poison.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t0205-gettext-poison.sh	2020-02-17 04:47:35.000000000 +0000
@@ -5,13 +5,15 @@
 
 test_description='Gettext Shell poison'
 
+GIT_TEST_GETTEXT_POISON=true
+export GIT_TEST_GETTEXT_POISON
 . ./lib-gettext.sh
 
-test_expect_success GETTEXT_POISON 'sanity: $GIT_INTERNAL_GETTEXT_SH_SCHEME" is poison' '
+test_expect_success 'sanity: $GIT_INTERNAL_GETTEXT_SH_SCHEME" is poison' '
     test "$GIT_INTERNAL_GETTEXT_SH_SCHEME" = "poison"
 '
 
-test_expect_success GETTEXT_POISON 'gettext: our gettext() fallback has poison semantics' '
+test_expect_success 'gettext: our gettext() fallback has poison semantics' '
     printf "# GETTEXT POISON #" >expect &&
     gettext "test" >actual &&
     test_cmp expect actual &&
@@ -20,7 +22,7 @@ test_expect_success GETTEXT_POISON 'gett
     test_cmp expect actual
 '
 
-test_expect_success GETTEXT_POISON 'eval_gettext: our eval_gettext() fallback has poison semantics' '
+test_expect_success 'eval_gettext: our eval_gettext() fallback has poison semantics' '
     printf "# GETTEXT POISON #" >expect &&
     eval_gettext "test" >actual &&
     test_cmp expect actual &&
@@ -29,4 +31,9 @@ test_expect_success GETTEXT_POISON 'eval
     test_cmp expect actual
 '
 
+test_expect_success "gettext: invalid GIT_TEST_GETTEXT_POISON value doesn't infinitely loop" "
+	test_must_fail env GIT_TEST_GETTEXT_POISON=xyz git version 2>error &&
+	grep \"fatal: bad numeric config value 'xyz' for 'GIT_TEST_GETTEXT_POISON': invalid unit\" error
+"
+
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t0210/scrub_normal.perl 1.2.3+git2.25.1-1/git/t/t0210/scrub_normal.perl
--- 1.2.1+git2.18.0-1/git/t/t0210/scrub_normal.perl	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t0210/scrub_normal.perl	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,48 @@
+#!/usr/bin/perl
+#
+# Scrub the variable fields from the normal trace2 output to
+# make testing easier.
+
+use strict;
+use warnings;
+
+my $float = '[0-9]*\.[0-9]+([eE][-+]?[0-9]+)?';
+
+# This code assumes that the trace2 data was written with bare
+# turned on (which omits the "<clock> <file>:<line>" prefix.
+
+while (<>) {
+    # Various messages include an elapsed time in the middle
+    # of the message.  Replace the time with a placeholder to
+    # simplify our HEREDOC in the test script.
+    s/elapsed:$float/elapsed:_TIME_/g;
+
+    my $line = $_;
+
+    # we expect:
+    #    start <argv0> [<argv1> [<argv2> [...]]]
+    #
+    # where argv0 might be a relative or absolute path, with
+    # or without quotes, and platform dependent.  Replace argv0
+    # with a token for HEREDOC matching in the test script.
+
+    if ($line =~ m/^start/) {
+	$line =~ /^start\s+(.*)/;
+	my $argv = $1;
+	$argv =~ m/(\'[^\']*\'|[^ ]+)\s+(.*)/;
+	my $argv_0 = $1;
+	my $argv_rest = $2;
+
+	print "start _EXE_ $argv_rest\n";
+    }
+    elsif ($line =~ m/^cmd_path/) {
+	# Likewise, the 'cmd_path' message breaks out argv[0].
+	#
+	# This line is only emitted when RUNTIME_PREFIX is defined,
+	# so just omit it for testing purposes.
+	# print "cmd_path _EXE_\n";
+    }
+    else {
+	print "$line";
+    }
+}
diff -pruN 1.2.1+git2.18.0-1/git/t/t0210-trace2-normal.sh 1.2.3+git2.25.1-1/git/t/t0210-trace2-normal.sh
--- 1.2.1+git2.18.0-1/git/t/t0210-trace2-normal.sh	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t0210-trace2-normal.sh	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,189 @@
+#!/bin/sh
+
+test_description='test trace2 facility (normal target)'
+. ./test-lib.sh
+
+# Turn off any inherited trace2 settings for this test.
+sane_unset GIT_TRACE2 GIT_TRACE2_PERF GIT_TRACE2_EVENT
+sane_unset GIT_TRACE2_BRIEF
+sane_unset GIT_TRACE2_CONFIG_PARAMS
+
+# Add t/helper directory to PATH so that we can use a relative
+# path to run nested instances of test-tool.exe (see 004child).
+# This helps with HEREDOC comparisons later.
+TTDIR="$GIT_BUILD_DIR/t/helper/" && export TTDIR
+PATH="$TTDIR:$PATH" && export PATH
+
+# Warning: use of 'test_cmp' may run test-tool.exe and/or git.exe
+# Warning: to do the actual diff/comparison, so the HEREDOCs here
+# Warning: only cover our actual calls to test-tool and/or git.
+# Warning: So you may see extra lines in artifact files when
+# Warning: interactively debugging.
+
+V=$(git version | sed -e 's/^git version //') && export V
+
+# There are multiple trace2 targets: normal, perf, and event.
+# Trace2 events will/can be written to each active target (subject
+# to whatever filtering that target decides to do).
+# This script tests the normal target in isolation.
+#
+# Defer setting GIT_TRACE2 until the actual command line we want to test
+# because hidden git and test-tool commands run by the test harness
+# can contaminate our output.
+
+# Enable "brief" feature which turns off "<clock> <file>:<line> " prefix.
+GIT_TRACE2_BRIEF=1 && export GIT_TRACE2_BRIEF
+
+# Basic tests of the trace2 normal stream.  Since this stream is used
+# primarily with printf-style debugging/tracing, we do limited testing
+# here.
+#
+# We do confirm the following API features:
+# [] the 'version <v>' event
+# [] the 'start <argv>' event
+# [] the 'cmd_name <name>' event
+# [] the 'exit <time> code:<code>' event
+# [] the 'atexit <time> code:<code>' event
+#
+# Fields of the form _FIELD_ are tokens that have been replaced (such
+# as the elapsed time).
+
+# Verb 001return
+#
+# Implicit return from cmd_<verb> function propagates <code>.
+
+test_expect_success 'normal stream, return code 0' '
+	test_when_finished "rm trace.normal actual expect" &&
+	GIT_TRACE2="$(pwd)/trace.normal" test-tool trace2 001return 0 &&
+	perl "$TEST_DIRECTORY/t0210/scrub_normal.perl" <trace.normal >actual &&
+	cat >expect <<-EOF &&
+		version $V
+		start _EXE_ trace2 001return 0
+		cmd_name trace2 (trace2)
+		exit elapsed:_TIME_ code:0
+		atexit elapsed:_TIME_ code:0
+	EOF
+	test_cmp expect actual
+'
+
+test_expect_success 'normal stream, return code 1' '
+	test_when_finished "rm trace.normal actual expect" &&
+	test_must_fail env GIT_TRACE2="$(pwd)/trace.normal" test-tool trace2 001return 1 &&
+	perl "$TEST_DIRECTORY/t0210/scrub_normal.perl" <trace.normal >actual &&
+	cat >expect <<-EOF &&
+		version $V
+		start _EXE_ trace2 001return 1
+		cmd_name trace2 (trace2)
+		exit elapsed:_TIME_ code:1
+		atexit elapsed:_TIME_ code:1
+	EOF
+	test_cmp expect actual
+'
+
+test_expect_success 'automatic filename' '
+	test_when_finished "rm -r traces actual expect" &&
+	mkdir traces &&
+	GIT_TRACE2="$(pwd)/traces" test-tool trace2 001return 0 &&
+	perl "$TEST_DIRECTORY/t0210/scrub_normal.perl" <"$(ls traces/*)" >actual &&
+	cat >expect <<-EOF &&
+		version $V
+		start _EXE_ trace2 001return 0
+		cmd_name trace2 (trace2)
+		exit elapsed:_TIME_ code:0
+		atexit elapsed:_TIME_ code:0
+	EOF
+	test_cmp expect actual
+'
+
+# Verb 002exit
+#
+# Explicit exit(code) from within cmd_<verb> propagates <code>.
+
+test_expect_success 'normal stream, exit code 0' '
+	test_when_finished "rm trace.normal actual expect" &&
+	GIT_TRACE2="$(pwd)/trace.normal" test-tool trace2 002exit 0 &&
+	perl "$TEST_DIRECTORY/t0210/scrub_normal.perl" <trace.normal >actual &&
+	cat >expect <<-EOF &&
+		version $V
+		start _EXE_ trace2 002exit 0
+		cmd_name trace2 (trace2)
+		exit elapsed:_TIME_ code:0
+		atexit elapsed:_TIME_ code:0
+	EOF
+	test_cmp expect actual
+'
+
+test_expect_success 'normal stream, exit code 1' '
+	test_when_finished "rm trace.normal actual expect" &&
+	test_must_fail env GIT_TRACE2="$(pwd)/trace.normal" test-tool trace2 002exit 1 &&
+	perl "$TEST_DIRECTORY/t0210/scrub_normal.perl" <trace.normal >actual &&
+	cat >expect <<-EOF &&
+		version $V
+		start _EXE_ trace2 002exit 1
+		cmd_name trace2 (trace2)
+		exit elapsed:_TIME_ code:1
+		atexit elapsed:_TIME_ code:1
+	EOF
+	test_cmp expect actual
+'
+
+# Verb 003error
+#
+# To the above, add multiple 'error <msg>' events
+
+test_expect_success 'normal stream, error event' '
+	test_when_finished "rm trace.normal actual expect" &&
+	GIT_TRACE2="$(pwd)/trace.normal" test-tool trace2 003error "hello world" "this is a test" &&
+	perl "$TEST_DIRECTORY/t0210/scrub_normal.perl" <trace.normal >actual &&
+	cat >expect <<-EOF &&
+		version $V
+		start _EXE_ trace2 003error '\''hello world'\'' '\''this is a test'\''
+		cmd_name trace2 (trace2)
+		error hello world
+		error this is a test
+		exit elapsed:_TIME_ code:0
+		atexit elapsed:_TIME_ code:0
+	EOF
+	test_cmp expect actual
+'
+
+sane_unset GIT_TRACE2_BRIEF
+
+# Now test without environment variables and get all Trace2 settings
+# from the global config.
+
+test_expect_success 'using global config, normal stream, return code 0' '
+	test_when_finished "rm trace.normal actual expect" &&
+	test_config_global trace2.normalBrief 1 &&
+	test_config_global trace2.normalTarget "$(pwd)/trace.normal" &&
+	test-tool trace2 001return 0 &&
+	perl "$TEST_DIRECTORY/t0210/scrub_normal.perl" <trace.normal >actual &&
+	cat >expect <<-EOF &&
+		version $V
+		start _EXE_ trace2 001return 0
+		cmd_name trace2 (trace2)
+		exit elapsed:_TIME_ code:0
+		atexit elapsed:_TIME_ code:0
+	EOF
+	test_cmp expect actual
+'
+
+test_expect_success 'using global config with include' '
+	test_when_finished "rm trace.normal actual expect real.gitconfig" &&
+	test_config_global trace2.normalBrief 1 &&
+	test_config_global trace2.normalTarget "$(pwd)/trace.normal" &&
+	mv "$(pwd)/.gitconfig" "$(pwd)/real.gitconfig" &&
+	test_config_global include.path "$(pwd)/real.gitconfig" &&
+	test-tool trace2 001return 0 &&
+	perl "$TEST_DIRECTORY/t0210/scrub_normal.perl" <trace.normal >actual &&
+	cat >expect <<-EOF &&
+		version $V
+		start _EXE_ trace2 001return 0
+		cmd_name trace2 (trace2)
+		exit elapsed:_TIME_ code:0
+		atexit elapsed:_TIME_ code:0
+	EOF
+	test_cmp expect actual
+'
+
+test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t0211/scrub_perf.perl 1.2.3+git2.25.1-1/git/t/t0211/scrub_perf.perl
--- 1.2.1+git2.18.0-1/git/t/t0211/scrub_perf.perl	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t0211/scrub_perf.perl	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,76 @@
+#!/usr/bin/perl
+#
+# Scrub the variable fields from the perf trace2 output to
+# make testing easier.
+
+use strict;
+use warnings;
+
+my $qpath = '\'[^\']*\'|[^ ]*';
+
+my $col_depth=0;
+my $col_thread=1;
+my $col_event=2;
+my $col_repo=3;
+my $col_t_abs=4;
+my $col_t_rel=5;
+my $col_category=6;
+my $col_rest=7;
+
+# This code assumes that the trace2 data was written with bare
+# turned on (which omits the "<clock> <file>:<line> | <parents>"
+# prefix.
+
+while (<>) {
+    my @tokens = split /\|/;
+
+    foreach my $col (@tokens) { $col =~ s/^\s+|\s+$//g; }
+
+    if ($tokens[$col_event] =~ m/^start/) {
+	# The 'start' message lists the contents of argv in $col_rest.
+	# On some platforms (Windows), argv[0] is *sometimes* a canonical
+	# absolute path to the EXE rather than the value passed in the
+	# shell script.  Replace it with a placeholder to simplify our
+	# HEREDOC in the test script.
+	my $argv0;
+	my $argvRest;
+	$tokens[$col_rest] =~ s/^($qpath)\W*(.*)/_EXE_ $2/;
+    }
+    elsif ($tokens[$col_event] =~ m/cmd_path/) {
+	# Likewise, the 'cmd_path' message breaks out argv[0].
+	#
+	# This line is only emitted when RUNTIME_PREFIX is defined,
+	# so just omit it for testing purposes.
+	# $tokens[$col_rest] = "_EXE_";
+	goto SKIP_LINE;
+    }
+    elsif ($tokens[$col_event] =~ m/child_exit/) {
+	$tokens[$col_rest] =~ s/ pid:\d* / pid:_PID_ /;
+    }
+    elsif ($tokens[$col_event] =~ m/data/) {
+	if ($tokens[$col_category] =~ m/process/) {
+	    # 'data' and 'data_json' events containing 'process'
+	    # category data are assumed to be platform-specific
+	    # and highly variable.  Just omit them.
+	    goto SKIP_LINE;
+	}
+    }
+
+    # t_abs and t_rel are either blank or a float.  Replace the float
+    # with a constant for matching the HEREDOC in the test script.
+    if ($tokens[$col_t_abs] =~ m/\d/) {
+	$tokens[$col_t_abs] = "_T_ABS_";
+    }
+    if ($tokens[$col_t_rel] =~ m/\d/) {
+	$tokens[$col_t_rel] = "_T_REL_";
+    }
+
+    my $out;
+
+    $out = join('|', @tokens);
+    print "$out\n";
+
+  SKIP_LINE:
+}
+
+
diff -pruN 1.2.1+git2.18.0-1/git/t/t0211-trace2-perf.sh 1.2.3+git2.25.1-1/git/t/t0211-trace2-perf.sh
--- 1.2.1+git2.18.0-1/git/t/t0211-trace2-perf.sh	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t0211-trace2-perf.sh	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,174 @@
+#!/bin/sh
+
+test_description='test trace2 facility (perf target)'
+. ./test-lib.sh
+
+# Turn off any inherited trace2 settings for this test.
+sane_unset GIT_TRACE2 GIT_TRACE2_PERF GIT_TRACE2_EVENT
+sane_unset GIT_TRACE2_PERF_BRIEF
+sane_unset GIT_TRACE2_CONFIG_PARAMS
+
+# Add t/helper directory to PATH so that we can use a relative
+# path to run nested instances of test-tool.exe (see 004child).
+# This helps with HEREDOC comparisons later.
+TTDIR="$GIT_BUILD_DIR/t/helper/" && export TTDIR
+PATH="$TTDIR:$PATH" && export PATH
+
+# Warning: use of 'test_cmp' may run test-tool.exe and/or git.exe
+# Warning: to do the actual diff/comparison, so the HEREDOCs here
+# Warning: only cover our actual calls to test-tool and/or git.
+# Warning: So you may see extra lines in artifact files when
+# Warning: interactively debugging.
+
+V=$(git version | sed -e 's/^git version //') && export V
+
+# There are multiple trace2 targets: normal, perf, and event.
+# Trace2 events will/can be written to each active target (subject
+# to whatever filtering that target decides to do).
+# Test each target independently.
+#
+# Defer setting GIT_TRACE2_PERF until the actual command we want to
+# test because hidden git and test-tool commands in the test
+# harness can contaminate our output.
+
+# Enable "brief" feature which turns off the prefix:
+#     "<clock> <file>:<line> | <nr_parents> | "
+GIT_TRACE2_PERF_BRIEF=1 && export GIT_TRACE2_PERF_BRIEF
+
+# Repeat some of the t0210 tests using the perf target stream instead of
+# the normal stream.
+#
+# Tokens here of the form _FIELD_ have been replaced in the observed output.
+
+# Verb 001return
+#
+# Implicit return from cmd_<verb> function propagates <code>.
+
+test_expect_success 'perf stream, return code 0' '
+	test_when_finished "rm trace.perf actual expect" &&
+	GIT_TRACE2_PERF="$(pwd)/trace.perf" test-tool trace2 001return 0 &&
+	perl "$TEST_DIRECTORY/t0211/scrub_perf.perl" <trace.perf >actual &&
+	cat >expect <<-EOF &&
+		d0|main|version|||||$V
+		d0|main|start||_T_ABS_|||_EXE_ trace2 001return 0
+		d0|main|cmd_name|||||trace2 (trace2)
+		d0|main|exit||_T_ABS_|||code:0
+		d0|main|atexit||_T_ABS_|||code:0
+	EOF
+	test_cmp expect actual
+'
+
+test_expect_success 'perf stream, return code 1' '
+	test_when_finished "rm trace.perf actual expect" &&
+	test_must_fail env GIT_TRACE2_PERF="$(pwd)/trace.perf" test-tool trace2 001return 1 &&
+	perl "$TEST_DIRECTORY/t0211/scrub_perf.perl" <trace.perf >actual &&
+	cat >expect <<-EOF &&
+		d0|main|version|||||$V
+		d0|main|start||_T_ABS_|||_EXE_ trace2 001return 1
+		d0|main|cmd_name|||||trace2 (trace2)
+		d0|main|exit||_T_ABS_|||code:1
+		d0|main|atexit||_T_ABS_|||code:1
+	EOF
+	test_cmp expect actual
+'
+
+# Verb 003error
+#
+# To the above, add multiple 'error <msg>' events
+
+test_expect_success 'perf stream, error event' '
+	test_when_finished "rm trace.perf actual expect" &&
+	GIT_TRACE2_PERF="$(pwd)/trace.perf" test-tool trace2 003error "hello world" "this is a test" &&
+	perl "$TEST_DIRECTORY/t0211/scrub_perf.perl" <trace.perf >actual &&
+	cat >expect <<-EOF &&
+		d0|main|version|||||$V
+		d0|main|start||_T_ABS_|||_EXE_ trace2 003error '\''hello world'\'' '\''this is a test'\''
+		d0|main|cmd_name|||||trace2 (trace2)
+		d0|main|error|||||hello world
+		d0|main|error|||||this is a test
+		d0|main|exit||_T_ABS_|||code:0
+		d0|main|atexit||_T_ABS_|||code:0
+	EOF
+	test_cmp expect actual
+'
+
+# Verb 004child
+#
+# Test nested spawning of child processes.
+#
+# Conceptually, this looks like:
+#    P1: TT trace2 004child
+#    P2: |--- TT trace2 004child
+#    P3:      |--- TT trace2 001return 0
+#
+# Which should generate events:
+#    P1: version
+#    P1: start
+#    P1: cmd_name
+#    P1: child_start
+#        P2: version
+#        P2: start
+#        P2: cmd_name
+#        P2: child_start
+#            P3: version
+#            P3: start
+#            P3: cmd_name
+#            P3: exit
+#            P3: atexit
+#        P2: child_exit
+#        P2: exit
+#        P2: atexit
+#    P1: child_exit
+#    P1: exit
+#    P1: atexit
+
+test_expect_success 'perf stream, child processes' '
+	test_when_finished "rm trace.perf actual expect" &&
+	GIT_TRACE2_PERF="$(pwd)/trace.perf" test-tool trace2 004child test-tool trace2 004child test-tool trace2 001return 0 &&
+	perl "$TEST_DIRECTORY/t0211/scrub_perf.perl" <trace.perf >actual &&
+	cat >expect <<-EOF &&
+		d0|main|version|||||$V
+		d0|main|start||_T_ABS_|||_EXE_ trace2 004child test-tool trace2 004child test-tool trace2 001return 0
+		d0|main|cmd_name|||||trace2 (trace2)
+		d0|main|child_start||_T_ABS_|||[ch0] class:? argv:[test-tool trace2 004child test-tool trace2 001return 0]
+		d1|main|version|||||$V
+		d1|main|start||_T_ABS_|||_EXE_ trace2 004child test-tool trace2 001return 0
+		d1|main|cmd_name|||||trace2 (trace2/trace2)
+		d1|main|child_start||_T_ABS_|||[ch0] class:? argv:[test-tool trace2 001return 0]
+		d2|main|version|||||$V
+		d2|main|start||_T_ABS_|||_EXE_ trace2 001return 0
+		d2|main|cmd_name|||||trace2 (trace2/trace2/trace2)
+		d2|main|exit||_T_ABS_|||code:0
+		d2|main|atexit||_T_ABS_|||code:0
+		d1|main|child_exit||_T_ABS_|_T_REL_||[ch0] pid:_PID_ code:0
+		d1|main|exit||_T_ABS_|||code:0
+		d1|main|atexit||_T_ABS_|||code:0
+		d0|main|child_exit||_T_ABS_|_T_REL_||[ch0] pid:_PID_ code:0
+		d0|main|exit||_T_ABS_|||code:0
+		d0|main|atexit||_T_ABS_|||code:0
+	EOF
+	test_cmp expect actual
+'
+
+sane_unset GIT_TRACE2_PERF_BRIEF
+
+# Now test without environment variables and get all Trace2 settings
+# from the global config.
+
+test_expect_success 'using global config, perf stream, return code 0' '
+	test_when_finished "rm trace.perf actual expect" &&
+	test_config_global trace2.perfBrief 1 &&
+	test_config_global trace2.perfTarget "$(pwd)/trace.perf" &&
+	test-tool trace2 001return 0 &&
+	perl "$TEST_DIRECTORY/t0211/scrub_perf.perl" <trace.perf >actual &&
+	cat >expect <<-EOF &&
+		d0|main|version|||||$V
+		d0|main|start||_T_ABS_|||_EXE_ trace2 001return 0
+		d0|main|cmd_name|||||trace2 (trace2)
+		d0|main|exit||_T_ABS_|||code:0
+		d0|main|atexit||_T_ABS_|||code:0
+	EOF
+	test_cmp expect actual
+'
+
+test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t0212/parse_events.perl 1.2.3+git2.25.1-1/git/t/t0212/parse_events.perl
--- 1.2.1+git2.18.0-1/git/t/t0212/parse_events.perl	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t0212/parse_events.perl	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,251 @@
+#!/usr/bin/perl
+#
+# Parse event stream and convert individual events into a summary
+# record for the process.
+#
+# Git.exe generates one or more "event" records for each API method,
+# such as "start <argv>" and "exit <code>", during the life of the git
+# process.  Additionally, the input may contain interleaved events
+# from multiple concurrent git processes and/or multiple threads from
+# within a git process.
+#
+# Accumulate events for each process (based on its unique SID) in a
+# dictionary and emit process summary records.
+#
+# Convert some of the variable fields (such as elapsed time) into
+# placeholders (or omit them) to make HEREDOC comparisons easier in
+# the test scripts.
+#
+# We may also omit fields not (currently) useful for testing purposes.
+
+use strict;
+use warnings;
+use JSON::PP;
+use Data::Dumper;
+use Getopt::Long;
+
+# The version of the trace2 event target format that we understand.
+# This is reported in the 'version' event in the 'evt' field.
+# It comes from the GIT_TRACE2_EVENT_VERSION macro in trace2/tr2_tgt_event.c
+my $evt_version = '1';
+
+my $show_children = 1;
+my $show_exec     = 1;
+my $show_threads  = 1;
+
+# A hack to generate test HEREDOC data for pasting into the test script.
+# Usage:
+#    cd "t/trash directory.t0212-trace2-event"
+#    $TT trace ... >trace.event
+#    VV=$(../../git.exe version | sed -e 's/^git version //')
+#    perl ../t0212/parse_events.perl --HEREDOC --VERSION=$VV <trace.event >heredoc
+# Then paste heredoc into your new test.
+
+my $gen_heredoc = 0;
+my $gen_version = '';
+
+GetOptions("children!" => \$show_children,
+	   "exec!"     => \$show_exec,
+	   "threads!"  => \$show_threads,
+	   "HEREDOC!"  => \$gen_heredoc,
+	   "VERSION=s" => \$gen_version    )
+    or die("Error in command line arguments\n");
+
+
+# SIDs contains timestamps and PIDs of the process and its parents.
+# This makes it difficult to match up in a HEREDOC in the test script.
+# Build a map from actual SIDs to predictable constant values and yet
+# keep the parent/child relationships.  For example:
+# {..., "sid":"1539706952458276-8652", ...}
+# {..., "sid":"1539706952458276-8652/1539706952649493-15452", ...}
+# becomes:
+# {..., "sid":"_SID1_", ...}
+# {..., "sid":"_SID1_/_SID2_", ...}
+my $sid_map;
+my $sid_count = 0;
+
+my $processes;
+
+while (<>) {
+    my $line = decode_json( $_ );
+
+    my $sid = "";
+    my $sid_sep = "";
+
+    my $raw_sid = $line->{'sid'};
+    my @raw_sid_parts = split /\//, $raw_sid;
+    foreach my $raw_sid_k (@raw_sid_parts) {
+	if (!exists $sid_map->{$raw_sid_k}) {
+	    $sid_map->{$raw_sid_k} = '_SID' . $sid_count . '_';
+	    $sid_count++;
+	}
+	$sid = $sid . $sid_sep . $sid_map->{$raw_sid_k};
+	$sid_sep = '/';
+    }
+    
+    my $event = $line->{'event'};
+
+    if ($event eq 'version') {
+	$processes->{$sid}->{'version'} = $line->{'exe'};
+	if ($gen_heredoc == 1 && $gen_version eq $line->{'exe'}) {
+	    # If we are generating data FOR the test script, replace
+	    # the reported git.exe version with a reference to an
+	    # environment variable.  When our output is pasted into
+	    # the test script, it will then be expanded in future
+	    # test runs to the THEN current version of git.exe.
+	    # We assume that the test script uses env var $V.
+	    $processes->{$sid}->{'version'} = "\$V";
+	}
+    }
+
+    elsif ($event eq 'start') {
+	$processes->{$sid}->{'argv'} = $line->{'argv'};
+	$processes->{$sid}->{'argv'}[0] = "_EXE_";
+    }
+
+    elsif ($event eq 'exit') {
+	$processes->{$sid}->{'exit_code'} = $line->{'code'};
+    }
+
+    elsif ($event eq 'atexit') {
+	$processes->{$sid}->{'exit_code'} = $line->{'code'};
+    }
+
+    elsif ($event eq 'error') {
+	# For HEREDOC purposes, use the error message format string if
+	# available, rather than the formatted message (which probably
+	# has an absolute pathname).
+	if (exists $line->{'fmt'}) {
+	    push( @{$processes->{$sid}->{'errors'}}, $line->{'fmt'} );
+	}
+	elsif (exists $line->{'msg'}) {
+	    push( @{$processes->{$sid}->{'errors'}}, $line->{'msg'} );
+	}
+    }
+
+    elsif ($event eq 'cmd_path') {
+	## $processes->{$sid}->{'path'} = $line->{'path'};
+	#
+	# Like in the 'start' event, we need to replace the value of
+	# argv[0] with a token for HEREDOC purposes.  However, the
+	# event is only emitted when RUNTIME_PREFIX is defined, so
+	# just omit it for testing purposes.
+	# $processes->{$sid}->{'path'} = "_EXE_";
+    }
+    
+    elsif ($event eq 'cmd_name') {
+	$processes->{$sid}->{'name'} = $line->{'name'};
+	$processes->{$sid}->{'hierarchy'} = $line->{'hierarchy'};
+    }
+
+    elsif ($event eq 'alias') {
+	$processes->{$sid}->{'alias'}->{'key'} = $line->{'alias'};
+	$processes->{$sid}->{'alias'}->{'argv'} = $line->{'argv'};
+    }
+
+    elsif ($event eq 'def_param') {
+	my $kv;
+	$kv->{'param'} = $line->{'param'};
+	$kv->{'value'} = $line->{'value'};
+	push( @{$processes->{$sid}->{'params'}}, $kv );
+    }
+
+    elsif ($event eq 'child_start') {
+	if ($show_children == 1) {
+	    $processes->{$sid}->{'child'}->{$line->{'child_id'}}->{'child_class'} = $line->{'child_class'};
+	    $processes->{$sid}->{'child'}->{$line->{'child_id'}}->{'child_argv'} = $line->{'argv'};
+	    $processes->{$sid}->{'child'}->{$line->{'child_id'}}->{'child_argv'}[0] = "_EXE_";
+	    $processes->{$sid}->{'child'}->{$line->{'child_id'}}->{'use_shell'} = $line->{'use_shell'} ? 1 : 0;
+	}
+    }
+
+    elsif ($event eq 'child_exit') {
+	if ($show_children == 1) {
+	    $processes->{$sid}->{'child'}->{$line->{'child_id'}}->{'child_code'} = $line->{'code'};
+	}
+    }
+
+    # TODO decide what information we want to test from thread events.
+
+    elsif ($event eq 'thread_start') {
+	if ($show_threads == 1) {
+	}
+    }
+
+    elsif ($event eq 'thread_exit') {
+	if ($show_threads == 1) {
+	}
+    }
+
+    # TODO decide what information we want to test from exec events.
+
+    elsif ($event eq 'exec') {
+	if ($show_exec == 1) {
+	}
+    }
+
+    elsif ($event eq 'exec_result') {
+	if ($show_exec == 1) {
+	}
+    }
+
+    elsif ($event eq 'def_param') {
+	# Accumulate parameter key/value pairs by key rather than in an array
+	# so that we get overwrite (last one wins) effects.
+	$processes->{$sid}->{'params'}->{$line->{'param'}} = $line->{'value'};
+    }
+
+    elsif ($event eq 'def_repo') {
+	# $processes->{$sid}->{'repos'}->{$line->{'repo'}} = $line->{'worktree'};
+	$processes->{$sid}->{'repos'}->{$line->{'repo'}} = "_WORKTREE_";
+    }
+
+    # A series of potentially nested and threaded region and data events
+    # is fundamentally incompatibile with the type of summary record we
+    # are building in this script.  Since they are intended for
+    # perf-trace-like analysis rather than a result summary, we ignore
+    # most of them here.
+
+    # elsif ($event eq 'region_enter') {
+    # }
+    # elsif ($event eq 'region_leave') {
+    # }
+
+    elsif ($event eq 'data') {
+	my $cat = $line->{'category'};
+	if ($cat eq 'test_category') {
+	    
+	    my $key = $line->{'key'};
+	    my $value = $line->{'value'};
+	    $processes->{$sid}->{'data'}->{$cat}->{$key} = $value;
+	}
+    }
+
+    # This trace2 target does not emit 'printf' events.
+    #
+    # elsif ($event eq 'printf') {
+    # }
+}
+
+# Dump the resulting hash into something that we can compare against
+# in the test script.  These options make Dumper output look a little
+# bit like JSON.  Also convert variable references of the form "$VAR*"
+# so that the matching HEREDOC doesn't need to escape it.
+
+$Data::Dumper::Sortkeys = 1;
+$Data::Dumper::Indent = 1;
+$Data::Dumper::Purity = 1;
+$Data::Dumper::Pair = ':';
+
+my $out = Dumper($processes);
+$out =~ s/'/"/g;
+$out =~ s/\$VAR/VAR/g;
+
+# Finally, if we're running this script to generate (manually confirmed)
+# data to add to the test script, guard the indentation.
+
+if ($gen_heredoc == 1) {
+    $out =~ s/^/\t\|/gms;
+}
+
+print $out;
diff -pruN 1.2.1+git2.18.0-1/git/t/t0212-trace2-event.sh 1.2.3+git2.25.1-1/git/t/t0212-trace2-event.sh
--- 1.2.1+git2.18.0-1/git/t/t0212-trace2-event.sh	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t0212-trace2-event.sh	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,287 @@
+#!/bin/sh
+
+test_description='test trace2 facility'
+. ./test-lib.sh
+
+# Turn off any inherited trace2 settings for this test.
+sane_unset GIT_TRACE2 GIT_TRACE2_PERF GIT_TRACE2_EVENT
+sane_unset GIT_TRACE2_BARE
+sane_unset GIT_TRACE2_CONFIG_PARAMS
+
+perl -MJSON::PP -e 0 >/dev/null 2>&1 && test_set_prereq JSON_PP
+
+# Add t/helper directory to PATH so that we can use a relative
+# path to run nested instances of test-tool.exe (see 004child).
+# This helps with HEREDOC comparisons later.
+TTDIR="$GIT_BUILD_DIR/t/helper/" && export TTDIR
+PATH="$TTDIR:$PATH" && export PATH
+
+# Warning: use of 'test_cmp' may run test-tool.exe and/or git.exe
+# Warning: to do the actual diff/comparison, so the HEREDOCs here
+# Warning: only cover our actual calls to test-tool and/or git.
+# Warning: So you may see extra lines in artifact files when
+# Warning: interactively debugging.
+
+V=$(git version | sed -e 's/^git version //') && export V
+
+# There are multiple trace2 targets: normal, perf, and event.
+# Trace2 events will/can be written to each active target (subject
+# to whatever filtering that target decides to do).
+# Test each target independently.
+#
+# Defer setting GIT_TRACE2_PERF until the actual command we want to
+# test because hidden git and test-tool commands in the test
+# harness can contaminate our output.
+
+# We don't bother repeating the 001return and 002exit tests, since they
+# have coverage in the normal and perf targets.
+
+# Verb 003error
+#
+# To the above, add multiple 'error <msg>' events
+
+test_expect_success JSON_PP 'event stream, error event' '
+	test_when_finished "rm trace.event actual expect" &&
+	GIT_TRACE2_EVENT="$(pwd)/trace.event" test-tool trace2 003error "hello world" "this is a test" &&
+	perl "$TEST_DIRECTORY/t0212/parse_events.perl" <trace.event >actual &&
+	sed -e "s/^|//" >expect <<-EOF &&
+	|VAR1 = {
+	|  "_SID0_":{
+	|    "argv":[
+	|      "_EXE_",
+	|      "trace2",
+	|      "003error",
+	|      "hello world",
+	|      "this is a test"
+	|    ],
+	|    "errors":[
+	|      "%s",
+	|      "%s"
+	|    ],
+	|    "exit_code":0,
+	|    "hierarchy":"trace2",
+	|    "name":"trace2",
+	|    "version":"$V"
+	|  }
+	|};
+	EOF
+	test_cmp expect actual
+'
+
+# Verb 004child
+#
+# Test nested spawning of child processes.
+#
+# Conceptually, this looks like:
+#    P1: TT trace2 004child
+#    P2: |--- TT trace2 004child
+#    P3:      |--- TT trace2 001return 0
+
+test_expect_success JSON_PP 'event stream, return code 0' '
+	test_when_finished "rm trace.event actual expect" &&
+	GIT_TRACE2_EVENT="$(pwd)/trace.event" test-tool trace2 004child test-tool trace2 004child test-tool trace2 001return 0 &&
+	perl "$TEST_DIRECTORY/t0212/parse_events.perl" <trace.event >actual &&
+	sed -e "s/^|//" >expect <<-EOF &&
+	|VAR1 = {
+	|  "_SID0_":{
+	|    "argv":[
+	|      "_EXE_",
+	|      "trace2",
+	|      "004child",
+	|      "test-tool",
+	|      "trace2",
+	|      "004child",
+	|      "test-tool",
+	|      "trace2",
+	|      "001return",
+	|      "0"
+	|    ],
+	|    "child":{
+	|      "0":{
+	|        "child_argv":[
+	|          "_EXE_",
+	|          "trace2",
+	|          "004child",
+	|          "test-tool",
+	|          "trace2",
+	|          "001return",
+	|          "0"
+	|        ],
+	|        "child_class":"?",
+	|        "child_code":0,
+	|        "use_shell":0
+	|      }
+	|    },
+	|    "exit_code":0,
+	|    "hierarchy":"trace2",
+	|    "name":"trace2",
+	|    "version":"$V"
+	|  },
+	|  "_SID0_/_SID1_":{
+	|    "argv":[
+	|      "_EXE_",
+	|      "trace2",
+	|      "004child",
+	|      "test-tool",
+	|      "trace2",
+	|      "001return",
+	|      "0"
+	|    ],
+	|    "child":{
+	|      "0":{
+	|        "child_argv":[
+	|          "_EXE_",
+	|          "trace2",
+	|          "001return",
+	|          "0"
+	|        ],
+	|        "child_class":"?",
+	|        "child_code":0,
+	|        "use_shell":0
+	|      }
+	|    },
+	|    "exit_code":0,
+	|    "hierarchy":"trace2/trace2",
+	|    "name":"trace2",
+	|    "version":"$V"
+	|  },
+	|  "_SID0_/_SID1_/_SID2_":{
+	|    "argv":[
+	|      "_EXE_",
+	|      "trace2",
+	|      "001return",
+	|      "0"
+	|    ],
+	|    "exit_code":0,
+	|    "hierarchy":"trace2/trace2/trace2",
+	|    "name":"trace2",
+	|    "version":"$V"
+	|  }
+	|};
+	EOF
+	test_cmp expect actual
+'
+
+# Test listing of all "interesting" config settings.
+
+test_expect_success JSON_PP 'event stream, list config' '
+	test_when_finished "rm trace.event actual expect" &&
+	git config --local t0212.abc 1 &&
+	git config --local t0212.def "hello world" &&
+	GIT_TRACE2_EVENT="$(pwd)/trace.event" GIT_TRACE2_CONFIG_PARAMS="t0212.*" test-tool trace2 001return 0 &&
+	perl "$TEST_DIRECTORY/t0212/parse_events.perl" <trace.event >actual &&
+	sed -e "s/^|//" >expect <<-EOF &&
+	|VAR1 = {
+	|  "_SID0_":{
+	|    "argv":[
+	|      "_EXE_",
+	|      "trace2",
+	|      "001return",
+	|      "0"
+	|    ],
+	|    "exit_code":0,
+	|    "hierarchy":"trace2",
+	|    "name":"trace2",
+	|    "params":[
+	|      {
+	|        "param":"t0212.abc",
+	|        "value":"1"
+	|      },
+	|      {
+	|        "param":"t0212.def",
+	|        "value":"hello world"
+	|      }
+	|    ],
+	|    "version":"$V"
+	|  }
+	|};
+	EOF
+	test_cmp expect actual
+'
+
+test_expect_success JSON_PP 'basic trace2_data' '
+	test_when_finished "rm trace.event actual expect" &&
+	GIT_TRACE2_EVENT="$(pwd)/trace.event" test-tool trace2 006data test_category k1 v1 test_category k2 v2 &&
+	perl "$TEST_DIRECTORY/t0212/parse_events.perl" <trace.event >actual &&
+	sed -e "s/^|//" >expect <<-EOF &&
+	|VAR1 = {
+	|  "_SID0_":{
+	|    "argv":[
+	|      "_EXE_",
+	|      "trace2",
+	|      "006data",
+	|      "test_category",
+	|      "k1",
+	|      "v1",
+	|      "test_category",
+	|      "k2",
+	|      "v2"
+	|    ],
+	|    "data":{
+	|      "test_category":{
+	|        "k1":"v1",
+	|        "k2":"v2"
+	|      }
+	|    },
+	|    "exit_code":0,
+	|    "hierarchy":"trace2",
+	|    "name":"trace2",
+	|    "version":"$V"
+	|  }
+	|};
+	EOF
+	test_cmp expect actual
+'
+
+# Now test without environment variables and get all Trace2 settings
+# from the global config.
+
+test_expect_success JSON_PP 'using global config, event stream, error event' '
+	test_when_finished "rm trace.event actual expect" &&
+	test_config_global trace2.eventTarget "$(pwd)/trace.event" &&
+	test-tool trace2 003error "hello world" "this is a test" &&
+	perl "$TEST_DIRECTORY/t0212/parse_events.perl" <trace.event >actual &&
+	sed -e "s/^|//" >expect <<-EOF &&
+	|VAR1 = {
+	|  "_SID0_":{
+	|    "argv":[
+	|      "_EXE_",
+	|      "trace2",
+	|      "003error",
+	|      "hello world",
+	|      "this is a test"
+	|    ],
+	|    "errors":[
+	|      "%s",
+	|      "%s"
+	|    ],
+	|    "exit_code":0,
+	|    "hierarchy":"trace2",
+	|    "name":"trace2",
+	|    "version":"$V"
+	|  }
+	|};
+	EOF
+	test_cmp expect actual
+'
+
+test_expect_success 'discard traces when there are too many files' '
+	mkdir trace_target_dir &&
+	test_when_finished "rm -r trace_target_dir" &&
+	(
+		GIT_TRACE2_MAX_FILES=5 &&
+		export GIT_TRACE2_MAX_FILES &&
+		cd trace_target_dir &&
+		test_seq $GIT_TRACE2_MAX_FILES >../expected_filenames.txt &&
+		xargs touch <../expected_filenames.txt &&
+		cd .. &&
+		GIT_TRACE2_EVENT="$(pwd)/trace_target_dir" test-tool trace2 001return 0
+	) &&
+	echo git-trace2-discard >>expected_filenames.txt &&
+	ls trace_target_dir >ls_output.txt &&
+	test_cmp expected_filenames.txt ls_output.txt &&
+	head -n1 trace_target_dir/git-trace2-discard | grep \"event\":\"version\" &&
+	head -n2 trace_target_dir/git-trace2-discard | tail -n1 | grep \"event\":\"too_many_files\"
+'
+
+test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t0300-credentials.sh 1.2.3+git2.25.1-1/git/t/t0300-credentials.sh
--- 1.2.1+git2.18.0-1/git/t/t0300-credentials.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t0300-credentials.sh	2020-02-17 04:47:35.000000000 +0000
@@ -294,8 +294,7 @@ test_expect_success 'helpers can abort t
 		-c credential.helper="!f() { echo quit=1; }; f" \
 		-c credential.helper="verbatim foo bar" \
 		credential fill >stdout &&
-	>expect &&
-	test_cmp expect stdout
+	test_must_be_empty stdout
 '
 
 test_expect_success 'empty helper spec resets helper list' '
diff -pruN 1.2.1+git2.18.0-1/git/t/t0301-credential-cache.sh 1.2.3+git2.25.1-1/git/t/t0301-credential-cache.sh
--- 1.2.1+git2.18.0-1/git/t/t0301-credential-cache.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t0301-credential-cache.sh	2020-02-17 04:47:35.000000000 +0000
@@ -10,7 +10,7 @@ test -z "$NO_UNIX_SOCKETS" || {
 }
 
 # don't leave a stale daemon running
-trap 'code=$?; git credential-cache exit; (exit $code); die' EXIT
+test_atexit 'git credential-cache exit'
 
 # test that the daemon works with no special setup
 helper_test cache
@@ -108,9 +108,4 @@ test_expect_success SYMLINKS 'use user s
 
 helper_test_timeout cache --timeout=1
 
-# we can't rely on our "trap" above working after test_done,
-# as test_done will delete the trash directory containing
-# our socket, leaving us with no way to access the daemon.
-git credential-cache exit
-
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t0410-partial-clone.sh 1.2.3+git2.25.1-1/git/t/t0410-partial-clone.sh
--- 1.2.1+git2.18.0-1/git/t/t0410-partial-clone.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t0410-partial-clone.sh	2020-02-17 04:47:35.000000000 +0000
@@ -23,7 +23,15 @@ promise_and_delete () {
 	delete_object repo "$HASH"
 }
 
+test_expect_success 'extensions.partialclone without filter' '
+	test_create_repo server &&
+	git clone --filter="blob:none" "file://$(pwd)/server" client &&
+	git -C client config --unset remote.origin.partialclonefilter &&
+	git -C client fetch origin
+'
+
 test_expect_success 'missing reflog object, but promised by a commit, passes fsck' '
+	rm -rf repo &&
 	test_create_repo repo &&
 	test_commit -C repo my_commit &&
 
@@ -158,8 +166,109 @@ test_expect_success 'fetching of missing
 	# associated packfile contains the object
 	ls repo/.git/objects/pack/pack-*.promisor >promisorlist &&
 	test_line_count = 1 promisorlist &&
-	IDX=$(cat promisorlist | sed "s/promisor$/idx/") &&
-	git verify-pack --verbose "$IDX" | grep "$HASH"
+	IDX=$(sed "s/promisor$/idx/" promisorlist) &&
+	git verify-pack --verbose "$IDX" >out &&
+	grep "$HASH" out
+'
+
+test_expect_success 'fetching of missing objects works with ref-in-want enabled' '
+	# ref-in-want requires protocol version 2
+	git -C server config protocol.version 2 &&
+	git -C server config uploadpack.allowrefinwant 1 &&
+	git -C repo config protocol.version 2 &&
+
+	rm -rf repo/.git/objects/* &&
+	rm -f trace &&
+	GIT_TRACE_PACKET="$(pwd)/trace" git -C repo cat-file -p "$HASH" &&
+	grep "git< fetch=.*ref-in-want" trace
+'
+
+test_expect_success 'fetching of missing objects from another promisor remote' '
+	git clone "file://$(pwd)/server" server2 &&
+	test_commit -C server2 bar &&
+	git -C server2 repack -a -d --write-bitmap-index &&
+	HASH2=$(git -C server2 rev-parse bar) &&
+
+	git -C repo remote add server2 "file://$(pwd)/server2" &&
+	git -C repo config remote.server2.promisor true &&
+	git -C repo cat-file -p "$HASH2" &&
+
+	git -C repo fetch server2 &&
+	rm -rf repo/.git/objects/* &&
+	git -C repo cat-file -p "$HASH2" &&
+
+	# Ensure that the .promisor file is written, and check that its
+	# associated packfile contains the object
+	ls repo/.git/objects/pack/pack-*.promisor >promisorlist &&
+	test_line_count = 1 promisorlist &&
+	IDX=$(sed "s/promisor$/idx/" promisorlist) &&
+	git verify-pack --verbose "$IDX" >out &&
+	grep "$HASH2" out
+'
+
+test_expect_success 'fetching of missing objects configures a promisor remote' '
+	git clone "file://$(pwd)/server" server3 &&
+	test_commit -C server3 baz &&
+	git -C server3 repack -a -d --write-bitmap-index &&
+	HASH3=$(git -C server3 rev-parse baz) &&
+	git -C server3 config uploadpack.allowfilter 1 &&
+
+	rm repo/.git/objects/pack/pack-*.promisor &&
+
+	git -C repo remote add server3 "file://$(pwd)/server3" &&
+	git -C repo fetch --filter="blob:none" server3 $HASH3 &&
+
+	test_cmp_config -C repo true remote.server3.promisor &&
+
+	# Ensure that the .promisor file is written, and check that its
+	# associated packfile contains the object
+	ls repo/.git/objects/pack/pack-*.promisor >promisorlist &&
+	test_line_count = 1 promisorlist &&
+	IDX=$(sed "s/promisor$/idx/" promisorlist) &&
+	git verify-pack --verbose "$IDX" >out &&
+	grep "$HASH3" out
+'
+
+test_expect_success 'fetching of missing blobs works' '
+	rm -rf server server2 repo &&
+	rm -rf server server3 repo &&
+	test_create_repo server &&
+	test_commit -C server foo &&
+	git -C server repack -a -d --write-bitmap-index &&
+
+	git clone "file://$(pwd)/server" repo &&
+	git hash-object repo/foo.t >blobhash &&
+	rm -rf repo/.git/objects/* &&
+
+	git -C server config uploadpack.allowanysha1inwant 1 &&
+	git -C server config uploadpack.allowfilter 1 &&
+	git -C repo config core.repositoryformatversion 1 &&
+	git -C repo config extensions.partialclone "origin" &&
+
+	git -C repo cat-file -p $(cat blobhash)
+'
+
+test_expect_success 'fetching of missing trees does not fetch blobs' '
+	rm -rf server repo &&
+	test_create_repo server &&
+	test_commit -C server foo &&
+	git -C server repack -a -d --write-bitmap-index &&
+
+	git clone "file://$(pwd)/server" repo &&
+	git -C repo rev-parse foo^{tree} >treehash &&
+	git hash-object repo/foo.t >blobhash &&
+	rm -rf repo/.git/objects/* &&
+
+	git -C server config uploadpack.allowanysha1inwant 1 &&
+	git -C server config uploadpack.allowfilter 1 &&
+	git -C repo config core.repositoryformatversion 1 &&
+	git -C repo config extensions.partialclone "origin" &&
+	git -C repo cat-file -p $(cat treehash) &&
+
+	# Ensure that the tree, but not the blob, is fetched
+	git -C repo rev-list --objects --missing=print $(cat treehash) >objects &&
+	grep "^$(cat treehash)" objects &&
+	grep "^[?]$(cat blobhash)" objects
 '
 
 test_expect_success 'rev-list stops traversal at missing and promised commit' '
@@ -173,11 +282,56 @@ test_expect_success 'rev-list stops trav
 
 	git -C repo config core.repositoryformatversion 1 &&
 	git -C repo config extensions.partialclone "arbitrary string" &&
-	git -C repo rev-list --exclude-promisor-objects --objects bar >out &&
+	GIT_TEST_COMMIT_GRAPH=0 git -C repo -c core.commitGraph=false rev-list --exclude-promisor-objects --objects bar >out &&
 	grep $(git -C repo rev-parse bar) out &&
 	! grep $FOO out
 '
 
+test_expect_success 'missing tree objects with --missing=allow-promisor and --exclude-promisor-objects' '
+	rm -rf repo &&
+	test_create_repo repo &&
+	test_commit -C repo foo &&
+	test_commit -C repo bar &&
+	test_commit -C repo baz &&
+
+	promise_and_delete $(git -C repo rev-parse bar^{tree}) &&
+	promise_and_delete $(git -C repo rev-parse foo^{tree}) &&
+
+	git -C repo config core.repositoryformatversion 1 &&
+	git -C repo config extensions.partialclone "arbitrary string" &&
+
+	git -C repo rev-list --missing=allow-promisor --objects HEAD >objs 2>rev_list_err &&
+	test_must_be_empty rev_list_err &&
+	# 3 commits, 3 blobs, and 1 tree
+	test_line_count = 7 objs &&
+
+	# Do the same for --exclude-promisor-objects, but with all trees gone.
+	promise_and_delete $(git -C repo rev-parse baz^{tree}) &&
+	git -C repo rev-list --exclude-promisor-objects --objects HEAD >objs 2>rev_list_err &&
+	test_must_be_empty rev_list_err &&
+	# 3 commits, no blobs or trees
+	test_line_count = 3 objs
+'
+
+test_expect_success 'missing non-root tree object and rev-list' '
+	rm -rf repo &&
+	test_create_repo repo &&
+	mkdir repo/dir &&
+	echo foo >repo/dir/foo &&
+	git -C repo add dir/foo &&
+	git -C repo commit -m "commit dir/foo" &&
+
+	promise_and_delete $(git -C repo rev-parse HEAD:dir) &&
+
+	git -C repo config core.repositoryformatversion 1 &&
+	git -C repo config extensions.partialclone "arbitrary string" &&
+
+	git -C repo rev-list --missing=allow-any --objects HEAD >objs 2>rev_list_err &&
+	test_must_be_empty rev_list_err &&
+	# 1 commit and 1 tree
+	test_line_count = 2 objs
+'
+
 test_expect_success 'rev-list stops traversal at missing and promised tree' '
 	rm -rf repo &&
 	test_create_repo repo &&
@@ -243,7 +397,7 @@ test_expect_success 'rev-list stops trav
 	grep $(git -C repo rev-parse bar) out  # sanity check that some walking was done
 '
 
-test_expect_success 'rev-list accepts missing and promised objects on command line' '
+test_expect_success 'rev-list dies for missing objects on cmd line' '
 	rm -rf repo &&
 	test_create_repo repo &&
 	test_commit -C repo foo &&
@@ -260,31 +414,119 @@ test_expect_success 'rev-list accepts mi
 
 	git -C repo config core.repositoryformatversion 1 &&
 	git -C repo config extensions.partialclone "arbitrary string" &&
-	git -C repo rev-list --exclude-promisor-objects --objects "$COMMIT" "$TREE" "$BLOB"
+
+	for OBJ in "$COMMIT" "$TREE" "$BLOB"; do
+		test_must_fail git -C repo rev-list --objects \
+			--exclude-promisor-objects "$OBJ" &&
+		test_must_fail git -C repo rev-list --objects-edge-aggressive \
+			--exclude-promisor-objects "$OBJ" &&
+
+		# Do not die or crash when --ignore-missing is passed.
+		git -C repo rev-list --ignore-missing --objects \
+			--exclude-promisor-objects "$OBJ" &&
+		git -C repo rev-list --ignore-missing --objects-edge-aggressive \
+			--exclude-promisor-objects "$OBJ"
+	done
 '
 
-test_expect_success 'gc does not repack promisor objects' '
+test_expect_success 'single promisor remote can be re-initialized gracefully' '
+	# ensure one promisor is in the promisors list
 	rm -rf repo &&
 	test_create_repo repo &&
-	test_commit -C repo my_commit &&
+	test_create_repo other &&
+	git -C repo remote add foo "file://$(pwd)/other" &&
+	git -C repo config remote.foo.promisor true &&
+	git -C repo config extensions.partialclone foo &&
 
-	TREE_HASH=$(git -C repo rev-parse HEAD^{tree}) &&
-	HASH=$(printf "$TREE_HASH\n" | pack_as_from_promisor) &&
+	# reinitialize the promisors list
+	git -C repo fetch --filter=blob:none foo
+'
+
+test_expect_success 'gc repacks promisor objects separately from non-promisor objects' '
+	rm -rf repo &&
+	test_create_repo repo &&
+	test_commit -C repo one &&
+	test_commit -C repo two &&
+
+	TREE_ONE=$(git -C repo rev-parse one^{tree}) &&
+	printf "$TREE_ONE\n" | pack_as_from_promisor &&
+	TREE_TWO=$(git -C repo rev-parse two^{tree}) &&
+	printf "$TREE_TWO\n" | pack_as_from_promisor &&
 
 	git -C repo config core.repositoryformatversion 1 &&
 	git -C repo config extensions.partialclone "arbitrary string" &&
 	git -C repo gc &&
 
-	# Ensure that the promisor packfile still exists, and remove it
-	test -e repo/.git/objects/pack/pack-$HASH.pack &&
-	rm repo/.git/objects/pack/pack-$HASH.* &&
+	# Ensure that exactly one promisor packfile exists, and that it
+	# contains the trees but not the commits
+	ls repo/.git/objects/pack/pack-*.promisor >promisorlist &&
+	test_line_count = 1 promisorlist &&
+	PROMISOR_PACKFILE=$(sed "s/.promisor/.pack/" <promisorlist) &&
+	git verify-pack $PROMISOR_PACKFILE -v >out &&
+	grep "$TREE_ONE" out &&
+	grep "$TREE_TWO" out &&
+	! grep "$(git -C repo rev-parse one)" out &&
+	! grep "$(git -C repo rev-parse two)" out &&
 
-	# Ensure that the single other pack contains the commit, but not the tree
+	# Remove the promisor packfile and associated files
+	rm $(sed "s/.promisor//" <promisorlist).* &&
+
+	# Ensure that the single other pack contains the commits, but not the
+	# trees
 	ls repo/.git/objects/pack/pack-*.pack >packlist &&
 	test_line_count = 1 packlist &&
 	git verify-pack repo/.git/objects/pack/pack-*.pack -v >out &&
-	grep "$(git -C repo rev-parse HEAD)" out &&
-	! grep "$TREE_HASH" out
+	grep "$(git -C repo rev-parse one)" out &&
+	grep "$(git -C repo rev-parse two)" out &&
+	! grep "$TREE_ONE" out &&
+	! grep "$TREE_TWO" out
+'
+
+test_expect_success 'gc does not repack promisor objects if there are none' '
+	rm -rf repo &&
+	test_create_repo repo &&
+	test_commit -C repo one &&
+
+	git -C repo config core.repositoryformatversion 1 &&
+	git -C repo config extensions.partialclone "arbitrary string" &&
+	git -C repo gc &&
+
+	# Ensure that only one pack exists
+	ls repo/.git/objects/pack/pack-*.pack >packlist &&
+	test_line_count = 1 packlist
+'
+
+repack_and_check () {
+	rm -rf repo2 &&
+	cp -r repo repo2 &&
+	git -C repo2 repack $1 -d &&
+	git -C repo2 fsck &&
+
+	git -C repo2 cat-file -e $2 &&
+	git -C repo2 cat-file -e $3
+}
+
+test_expect_success 'repack -d does not irreversibly delete promisor objects' '
+	rm -rf repo &&
+	test_create_repo repo &&
+	git -C repo config core.repositoryformatversion 1 &&
+	git -C repo config extensions.partialclone "arbitrary string" &&
+
+	git -C repo commit --allow-empty -m one &&
+	git -C repo commit --allow-empty -m two &&
+	git -C repo commit --allow-empty -m three &&
+	git -C repo commit --allow-empty -m four &&
+	ONE=$(git -C repo rev-parse HEAD^^^) &&
+	TWO=$(git -C repo rev-parse HEAD^^) &&
+	THREE=$(git -C repo rev-parse HEAD^) &&
+
+	printf "$TWO\n" | pack_as_from_promisor &&
+	printf "$THREE\n" | pack_as_from_promisor &&
+	delete_object repo "$ONE" &&
+
+	repack_and_check -a "$TWO" "$THREE" &&
+	repack_and_check -A "$TWO" "$THREE" &&
+	repack_and_check -l "$TWO" "$THREE"
 '
 
 test_expect_success 'gc stops traversal when a missing but promised object is reached' '
@@ -311,7 +553,20 @@ test_expect_success 'gc stops traversal
 	! grep "$TREE_HASH" out
 '
 
-LIB_HTTPD_PORT=12345  # default port, 410, cannot be used as non-root
+test_expect_success 'do not fetch when checking existence of tree we construct ourselves' '
+	rm -rf repo &&
+	test_create_repo repo &&
+	test_commit -C repo base &&
+	test_commit -C repo side1 &&
+	git -C repo checkout base &&
+	test_commit -C repo side2 &&
+
+	git -C repo config core.repositoryformatversion 1 &&
+	git -C repo config extensions.partialclone "arbitrary string" &&
+
+	git -C repo cherry-pick side1
+'
+
 . "$TEST_DIRECTORY"/lib-httpd.sh
 start_httpd
 
@@ -334,10 +589,12 @@ test_expect_success 'fetching of missing
 	# associated packfile contains the object
 	ls repo/.git/objects/pack/pack-*.promisor >promisorlist &&
 	test_line_count = 1 promisorlist &&
-	IDX=$(cat promisorlist | sed "s/promisor$/idx/") &&
-	git verify-pack --verbose "$IDX" | grep "$HASH"
+	IDX=$(sed "s/promisor$/idx/" promisorlist) &&
+	git verify-pack --verbose "$IDX" >out &&
+	grep "$HASH" out
 '
 
-stop_httpd
+# DO NOT add non-httpd-specific tests here, because the last part of this
+# test script is only executed when httpd is available and enabled.
 
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t0500-progress-display.sh 1.2.3+git2.25.1-1/git/t/t0500-progress-display.sh
--- 1.2.1+git2.18.0-1/git/t/t0500-progress-display.sh	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t0500-progress-display.sh	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,286 @@
+#!/bin/sh
+
+test_description='progress display'
+
+. ./test-lib.sh
+
+show_cr () {
+	tr '\015' Q | sed -e "s/Q/<CR>\\$LF/g"
+}
+
+test_expect_success 'simple progress display' '
+	cat >expect <<-\EOF &&
+	Working hard: 1<CR>
+	Working hard: 2<CR>
+	Working hard: 5<CR>
+	Working hard: 5, done.
+	EOF
+
+	cat >in <<-\EOF &&
+	update
+	progress 1
+	update
+	progress 2
+	progress 3
+	progress 4
+	update
+	progress 5
+	EOF
+	test-tool progress "Working hard" <in 2>stderr &&
+
+	show_cr <stderr >out &&
+	test_i18ncmp expect out
+'
+
+test_expect_success 'progress display with total' '
+	cat >expect <<-\EOF &&
+	Working hard:  33% (1/3)<CR>
+	Working hard:  66% (2/3)<CR>
+	Working hard: 100% (3/3)<CR>
+	Working hard: 100% (3/3), done.
+	EOF
+
+	cat >in <<-\EOF &&
+	progress 1
+	progress 2
+	progress 3
+	EOF
+	test-tool progress --total=3 "Working hard" <in 2>stderr &&
+
+	show_cr <stderr >out &&
+	test_i18ncmp expect out
+'
+
+test_expect_success 'progress display breaks long lines #1' '
+	sed -e "s/Z$//" >expect <<\EOF &&
+Working hard.......2.........3.........4.........5.........6:   0% (100/100000)<CR>
+Working hard.......2.........3.........4.........5.........6:   1% (1000/100000)<CR>
+Working hard.......2.........3.........4.........5.........6:                   Z
+   10% (10000/100000)<CR>
+  100% (100000/100000)<CR>
+  100% (100000/100000), done.
+EOF
+
+	cat >in <<-\EOF &&
+	progress 100
+	progress 1000
+	progress 10000
+	progress 100000
+	EOF
+	test-tool progress --total=100000 \
+		"Working hard.......2.........3.........4.........5.........6" \
+		<in 2>stderr &&
+
+	show_cr <stderr >out &&
+	test_i18ncmp expect out
+'
+
+test_expect_success 'progress display breaks long lines #2' '
+	# Note: we do not need that many spaces after the title to cover up
+	# the last line before breaking the progress line.
+	sed -e "s/Z$//" >expect <<\EOF &&
+Working hard.......2.........3.........4.........5.........6:   0% (1/100000)<CR>
+Working hard.......2.........3.........4.........5.........6:   0% (2/100000)<CR>
+Working hard.......2.........3.........4.........5.........6:                   Z
+   10% (10000/100000)<CR>
+  100% (100000/100000)<CR>
+  100% (100000/100000), done.
+EOF
+
+	cat >in <<-\EOF &&
+	update
+	progress 1
+	update
+	progress 2
+	progress 10000
+	progress 100000
+	EOF
+	test-tool progress --total=100000 \
+		"Working hard.......2.........3.........4.........5.........6" \
+		<in 2>stderr &&
+
+	show_cr <stderr >out &&
+	test_i18ncmp expect out
+'
+
+test_expect_success 'progress display breaks long lines #3 - even the first is too long' '
+	# Note: we do not actually need any spaces at the end of the title
+	# line, because there is no previous progress line to cover up.
+	sed -e "s/Z$//" >expect <<\EOF &&
+Working hard.......2.........3.........4.........5.........6:                   Z
+   25% (25000/100000)<CR>
+   50% (50000/100000)<CR>
+   75% (75000/100000)<CR>
+  100% (100000/100000)<CR>
+  100% (100000/100000), done.
+EOF
+
+	cat >in <<-\EOF &&
+	progress 25000
+	progress 50000
+	progress 75000
+	progress 100000
+	EOF
+	test-tool progress --total=100000 \
+		"Working hard.......2.........3.........4.........5.........6" \
+		<in 2>stderr &&
+
+	show_cr <stderr >out &&
+	test_i18ncmp expect out
+'
+
+test_expect_success 'progress display breaks long lines #4 - title line matches terminal width' '
+	cat >expect <<\EOF &&
+Working hard.......2.........3.........4.........5.........6.........7.........:
+   25% (25000/100000)<CR>
+   50% (50000/100000)<CR>
+   75% (75000/100000)<CR>
+  100% (100000/100000)<CR>
+  100% (100000/100000), done.
+EOF
+
+	cat >in <<-\EOF &&
+	progress 25000
+	progress 50000
+	progress 75000
+	progress 100000
+	EOF
+	test-tool progress --total=100000 \
+		"Working hard.......2.........3.........4.........5.........6.........7........." \
+		<in 2>stderr &&
+
+	show_cr <stderr >out &&
+	test_i18ncmp expect out
+'
+
+# Progress counter goes backwards, this should not happen in practice.
+test_expect_success 'progress shortens - crazy caller' '
+	cat >expect <<-\EOF &&
+	Working hard:  10% (100/1000)<CR>
+	Working hard:  20% (200/1000)<CR>
+	Working hard:   0% (1/1000)  <CR>
+	Working hard: 100% (1000/1000)<CR>
+	Working hard: 100% (1000/1000), done.
+	EOF
+
+	cat >in <<-\EOF &&
+	progress 100
+	progress 200
+	progress 1
+	progress 1000
+	EOF
+	test-tool progress --total=1000 "Working hard" <in 2>stderr &&
+
+	show_cr <stderr >out &&
+	test_i18ncmp expect out
+'
+
+test_expect_success 'progress display with throughput' '
+	cat >expect <<-\EOF &&
+	Working hard: 10<CR>
+	Working hard: 20, 200.00 KiB | 100.00 KiB/s<CR>
+	Working hard: 30, 300.00 KiB | 100.00 KiB/s<CR>
+	Working hard: 40, 400.00 KiB | 100.00 KiB/s<CR>
+	Working hard: 40, 400.00 KiB | 100.00 KiB/s, done.
+	EOF
+
+	cat >in <<-\EOF &&
+	throughput 102400 1000
+	update
+	progress 10
+	throughput 204800 2000
+	update
+	progress 20
+	throughput 307200 3000
+	update
+	progress 30
+	throughput 409600 4000
+	update
+	progress 40
+	EOF
+	test-tool progress "Working hard" <in 2>stderr &&
+
+	show_cr <stderr >out &&
+	test_i18ncmp expect out
+'
+
+test_expect_success 'progress display with throughput and total' '
+	cat >expect <<-\EOF &&
+	Working hard:  25% (10/40)<CR>
+	Working hard:  50% (20/40), 200.00 KiB | 100.00 KiB/s<CR>
+	Working hard:  75% (30/40), 300.00 KiB | 100.00 KiB/s<CR>
+	Working hard: 100% (40/40), 400.00 KiB | 100.00 KiB/s<CR>
+	Working hard: 100% (40/40), 400.00 KiB | 100.00 KiB/s, done.
+	EOF
+
+	cat >in <<-\EOF &&
+	throughput 102400 1000
+	progress 10
+	throughput 204800 2000
+	progress 20
+	throughput 307200 3000
+	progress 30
+	throughput 409600 4000
+	progress 40
+	EOF
+	test-tool progress --total=40 "Working hard" <in 2>stderr &&
+
+	show_cr <stderr >out &&
+	test_i18ncmp expect out
+'
+
+test_expect_success 'cover up after throughput shortens' '
+	cat >expect <<-\EOF &&
+	Working hard: 1<CR>
+	Working hard: 2, 800.00 KiB | 400.00 KiB/s<CR>
+	Working hard: 3, 1.17 MiB | 400.00 KiB/s  <CR>
+	Working hard: 4, 1.56 MiB | 400.00 KiB/s<CR>
+	Working hard: 4, 1.56 MiB | 400.00 KiB/s, done.
+	EOF
+
+	cat >in <<-\EOF &&
+	throughput 409600 1000
+	update
+	progress 1
+	throughput 819200 2000
+	update
+	progress 2
+	throughput 1228800 3000
+	update
+	progress 3
+	throughput 1638400 4000
+	update
+	progress 4
+	EOF
+	test-tool progress "Working hard" <in 2>stderr &&
+
+	show_cr <stderr >out &&
+	test_i18ncmp expect out
+'
+
+test_expect_success 'cover up after throughput shortens a lot' '
+	cat >expect <<-\EOF &&
+	Working hard: 1<CR>
+	Working hard: 2, 1000.00 KiB | 1000.00 KiB/s<CR>
+	Working hard: 3, 3.00 MiB | 1.50 MiB/s      <CR>
+	Working hard: 3, 3.00 MiB | 1024.00 KiB/s, done.
+	EOF
+
+	cat >in <<-\EOF &&
+	throughput 1 1000
+	update
+	progress 1
+	throughput 1024000 2000
+	update
+	progress 2
+	throughput 3145728 3000
+	update
+	progress 3
+	EOF
+	test-tool progress "Working hard" <in 2>stderr &&
+
+	show_cr <stderr >out &&
+	test_i18ncmp expect out
+'
+
+test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t1004-read-tree-m-u-wf.sh 1.2.3+git2.25.1-1/git/t/t1004-read-tree-m-u-wf.sh
--- 1.2.1+git2.18.0-1/git/t/t1004-read-tree-m-u-wf.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t1004-read-tree-m-u-wf.sh	2020-02-17 04:47:35.000000000 +0000
@@ -179,6 +179,8 @@ test_expect_success 'funny symlink in wo
 
 test_expect_success SANITY 'funny symlink in work tree, un-unlink-able' '
 
+	test_when_finished "chmod u+w a 2>/dev/null; rm -fr a b" &&
+
 	rm -fr a b &&
 	git reset --hard &&
 
@@ -188,10 +190,6 @@ test_expect_success SANITY 'funny symlin
 
 '
 
-# clean-up from the above test
-chmod a+w a 2>/dev/null
-rm -fr a b
-
 test_expect_success 'D/F setup' '
 
 	git reset --hard &&
@@ -212,10 +210,10 @@ test_expect_success 'D/F' '
 	read_tree_u_must_succeed -m -u branch-point side-b side-a &&
 	git ls-files -u >actual &&
 	(
-		a=$(git rev-parse branch-point:subdir/file2)
-		b=$(git rev-parse side-a:subdir/file2/another)
-		echo "100644 $a 1	subdir/file2"
-		echo "100644 $a 2	subdir/file2"
+		a=$(git rev-parse branch-point:subdir/file2) &&
+		b=$(git rev-parse side-a:subdir/file2/another) &&
+		echo "100644 $a 1	subdir/file2" &&
+		echo "100644 $a 2	subdir/file2" &&
 		echo "100644 $b 3	subdir/file2/another"
 	) >expect &&
 	test_cmp expect actual
diff -pruN 1.2.1+git2.18.0-1/git/t/t1005-read-tree-reset.sh 1.2.3+git2.25.1-1/git/t/t1005-read-tree-reset.sh
--- 1.2.1+git2.18.0-1/git/t/t1005-read-tree-reset.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t1005-read-tree-reset.sh	2020-02-17 04:47:35.000000000 +0000
@@ -33,7 +33,7 @@ test_expect_success 'reset should remove
 	git ls-files -s >expect &&
 	sha1=$(git rev-parse :new) &&
 	(
-		echo "100644 $sha1 1	old"
+		echo "100644 $sha1 1	old" &&
 		echo "100644 $sha1 3	old"
 	) | git update-index --index-info &&
 	>old &&
@@ -48,7 +48,7 @@ test_expect_success 'two-way reset shoul
 	git ls-files -s >expect &&
 	sha1=$(git rev-parse :new) &&
 	(
-		echo "100644 $sha1 1	old"
+		echo "100644 $sha1 1	old" &&
 		echo "100644 $sha1 3	old"
 	) | git update-index --index-info &&
 	>old &&
@@ -63,7 +63,7 @@ test_expect_success 'Porcelain reset sho
 	git ls-files -s >expect &&
 	sha1=$(git rev-parse :new) &&
 	(
-		echo "100644 $sha1 1	old"
+		echo "100644 $sha1 1	old" &&
 		echo "100644 $sha1 3	old"
 	) | git update-index --index-info &&
 	>old &&
@@ -78,7 +78,7 @@ test_expect_success 'Porcelain checkout
 	git ls-files -s >expect &&
 	sha1=$(git rev-parse :new) &&
 	(
-		echo "100644 $sha1 1	old"
+		echo "100644 $sha1 1	old" &&
 		echo "100644 $sha1 3	old"
 	) | git update-index --index-info &&
 	>old &&
@@ -93,7 +93,7 @@ test_expect_success 'Porcelain checkout
 	git ls-files -s >expect &&
 	sha1=$(git rev-parse :new) &&
 	(
-		echo "100644 $sha1 1	old"
+		echo "100644 $sha1 1	old" &&
 		echo "100644 $sha1 3	old"
 	) | git update-index --index-info &&
 	>old &&
diff -pruN 1.2.1+git2.18.0-1/git/t/t1006-cat-file.sh 1.2.3+git2.25.1-1/git/t/t1006-cat-file.sh
--- 1.2.1+git2.18.0-1/git/t/t1006-cat-file.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t1006-cat-file.sh	2020-02-17 04:47:35.000000000 +0000
@@ -140,15 +140,17 @@ test_expect_success '--batch-check witho
 	test_cmp expect actual
 '
 
+test_oid_init
+
 tree_sha1=$(git write-tree)
-tree_size=33
+tree_size=$(($(test_oid rawsz) + 13))
 tree_pretty_content="100644 blob $hello_sha1	hello"
 
 run_tests 'tree' $tree_sha1 $tree_size "" "$tree_pretty_content"
 
 commit_message="Initial commit"
 commit_sha1=$(echo_without_newline "$commit_message" | git commit-tree $tree_sha1)
-commit_size=177
+commit_size=$(($(test_oid hexsz) + 137))
 commit_content="tree $tree_sha1
 author $GIT_AUTHOR_NAME <$GIT_AUTHOR_EMAIL> 0000000000 +0000
 committer $GIT_COMMITTER_NAME <$GIT_COMMITTER_EMAIL> 0000000000 +0000
@@ -218,8 +220,8 @@ test_expect_success "--batch-check for a
     test "0000000000000000000000000000000000000042 missing
 0000000000000000000000000000000000000084 missing" = \
     "$( ( echo 0000000000000000000000000000000000000042;
-         echo_without_newline 0000000000000000000000000000000000000084; ) \
-       | git cat-file --batch-check)"
+	 echo_without_newline 0000000000000000000000000000000000000084; ) |
+       git cat-file --batch-check)"
 '
 
 test_expect_success "--batch for an existent and a non-existent hash" '
@@ -227,8 +229,8 @@ test_expect_success "--batch for an exis
 $tag_content
 0000000000000000000000000000000000000000 missing" = \
     "$( ( echo $tag_sha1;
-         echo_without_newline 0000000000000000000000000000000000000000; ) \
-       | git cat-file --batch)"
+	 echo_without_newline 0000000000000000000000000000000000000000; ) |
+       git cat-file --batch)"
 '
 
 test_expect_success "--batch-check for an empty line" '
@@ -550,8 +552,8 @@ test_expect_success 'git cat-file --batc
 test_expect_success 'cat-file --batch-all-objects shows all objects' '
 	# make new repos so we know the full set of objects; we will
 	# also make sure that there are some packed and some loose
-	# objects, some referenced and some not, and that there are
-	# some available only via alternates.
+	# objects, some referenced and some not, some duplicates, and that
+	# there are some available only via alternates.
 	git init all-one &&
 	(
 		cd all-one &&
@@ -567,10 +569,23 @@ test_expect_success 'cat-file --batch-al
 		cd all-two &&
 		echo local-unref | git hash-object -w --stdin
 	) >>expect.unsorted &&
+	git -C all-two rev-parse HEAD:file |
+		git -C all-two pack-objects .git/objects/pack/pack &&
 	sort <expect.unsorted >expect &&
 	git -C all-two cat-file --batch-all-objects \
 				--batch-check="%(objectname)" >actual &&
 	test_cmp expect actual
 '
 
+# The only user-visible difference is that the objects are no longer sorted,
+# and the resulting sort order is undefined. So we can only check that it
+# produces the same objects as the ordered case, but that at least exercises
+# the code.
+test_expect_success 'cat-file --unordered works' '
+	git -C all-two cat-file --batch-all-objects --unordered \
+				--batch-check="%(objectname)" >actual.unsorted &&
+	sort <actual.unsorted >actual &&
+	test_cmp expect actual
+'
+
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t1007-hash-object.sh 1.2.3+git2.25.1-1/git/t/t1007-hash-object.sh
--- 1.2.1+git2.18.0-1/git/t/t1007-hash-object.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t1007-hash-object.sh	2020-02-17 04:47:35.000000000 +0000
@@ -9,22 +9,19 @@ echo_without_newline() {
 }
 
 test_blob_does_not_exist() {
-	test_expect_success SHA1 'blob does not exist in database' "
+	test_expect_success 'blob does not exist in database' "
 		test_must_fail git cat-file blob $1
 	"
 }
 
 test_blob_exists() {
-	test_expect_success SHA1 'blob exists in database' "
+	test_expect_success 'blob exists in database' "
 		git cat-file blob $1
 	"
 }
 
 hello_content="Hello World"
-hello_sha1=5e1c309dae7f45e0f39b1bf3ac3cd9db12e7d689
-
 example_content="This is an example"
-example_sha1=ddd3f836d3e3fbb7ae289aa9ae83536f76956399
 
 setup_repo() {
 	echo_without_newline "$hello_content" > hello
@@ -44,7 +41,16 @@ pop_repo() {
 	rm -rf $test_repo
 }
 
-setup_repo
+test_expect_success 'setup' '
+	setup_repo &&
+	test_oid_cache <<-EOF
+	hello sha1:5e1c309dae7f45e0f39b1bf3ac3cd9db12e7d689
+	hello sha256:1e3b6c04d2eeb2b3e45c8a330445404c0b7cc7b257e2b097167d26f5230090c4
+
+	example sha1:ddd3f836d3e3fbb7ae289aa9ae83536f76956399
+	example sha256:b44fe1fe65589848253737db859bd490453510719d7424daab03daf0767b85ae
+	EOF
+'
 
 # Argument checking
 
@@ -73,23 +79,23 @@ test_expect_success "Can't use --path wi
 
 push_repo
 
-test_expect_success SHA1 'hash a file' '
-	test $hello_sha1 = $(git hash-object hello)
+test_expect_success 'hash a file' '
+	test "$(test_oid hello)" = $(git hash-object hello)
 '
 
-test_blob_does_not_exist $hello_sha1
+test_blob_does_not_exist "$(test_oid hello)"
 
-test_expect_success SHA1 'hash from stdin' '
-	test $example_sha1 = $(git hash-object --stdin < example)
+test_expect_success 'hash from stdin' '
+	test "$(test_oid example)" = $(git hash-object --stdin < example)
 '
 
-test_blob_does_not_exist $example_sha1
+test_blob_does_not_exist "$(test_oid example)"
 
-test_expect_success SHA1 'hash a file and write to database' '
-	test $hello_sha1 = $(git hash-object -w hello)
+test_expect_success 'hash a file and write to database' '
+	test "$(test_oid hello)" = $(git hash-object -w hello)
 '
 
-test_blob_exists $hello_sha1
+test_blob_exists "$(test_oid hello)"
 
 test_expect_success 'git hash-object --stdin file1 <file0 first operates on file0, then file1' '
 	echo foo > file1 &&
@@ -161,11 +167,11 @@ pop_repo
 for args in "-w --stdin" "--stdin -w"; do
 	push_repo
 
-	test_expect_success SHA1 "hash from stdin and write to database ($args)" '
-		test $example_sha1 = $(git hash-object $args < example)
+	test_expect_success "hash from stdin and write to database ($args)" '
+		test "$(test_oid example)" = $(git hash-object $args < example)
 	'
 
-	test_blob_exists $example_sha1
+	test_blob_exists "$(test_oid example)"
 
 	pop_repo
 done
@@ -173,22 +179,22 @@ done
 filenames="hello
 example"
 
-sha1s="$hello_sha1
-$example_sha1"
+oids="$(test_oid hello)
+$(test_oid example)"
 
-test_expect_success SHA1 "hash two files with names on stdin" '
-	test "$sha1s" = "$(echo_without_newline "$filenames" | git hash-object --stdin-paths)"
+test_expect_success "hash two files with names on stdin" '
+	test "$oids" = "$(echo_without_newline "$filenames" | git hash-object --stdin-paths)"
 '
 
 for args in "-w --stdin-paths" "--stdin-paths -w"; do
 	push_repo
 
-	test_expect_success SHA1 "hash two files with names on stdin and write to database ($args)" '
-		test "$sha1s" = "$(echo_without_newline "$filenames" | git hash-object $args)"
+	test_expect_success "hash two files with names on stdin and write to database ($args)" '
+		test "$oids" = "$(echo_without_newline "$filenames" | git hash-object $args)"
 	'
 
-	test_blob_exists $hello_sha1
-	test_blob_exists $example_sha1
+	test_blob_exists "$(test_oid hello)"
+	test_blob_exists "$(test_oid example)"
 
 	pop_repo
 done
@@ -199,10 +205,6 @@ test_expect_success 'too-short tree' '
 	test_i18ngrep "too-short tree object" err
 '
 
-hex2oct() {
-    perl -ne 'printf "\\%03o", hex for /../g'
-}
-
 test_expect_success 'malformed mode in tree' '
 	hex_sha1=$(echo foo | git hash-object --stdin -w) &&
 	bin_sha1=$(echo $hex_sha1 | hex2oct) &&
diff -pruN 1.2.1+git2.18.0-1/git/t/t1008-read-tree-overlay.sh 1.2.3+git2.25.1-1/git/t/t1008-read-tree-overlay.sh
--- 1.2.1+git2.18.0-1/git/t/t1008-read-tree-overlay.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t1008-read-tree-overlay.sh	2020-02-17 04:47:35.000000000 +0000
@@ -23,7 +23,7 @@ test_expect_success setup '
 
 test_expect_success 'multi-read' '
 	read_tree_must_succeed initial master side &&
-	(echo a; echo b/c) >expect &&
+	test_write_lines a b/c >expect &&
 	git ls-files >actual &&
 	test_cmp expect actual
 '
diff -pruN 1.2.1+git2.18.0-1/git/t/t1011-read-tree-sparse-checkout.sh 1.2.3+git2.25.1-1/git/t/t1011-read-tree-sparse-checkout.sh
--- 1.2.1+git2.18.0-1/git/t/t1011-read-tree-sparse-checkout.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t1011-read-tree-sparse-checkout.sh	2020-02-17 04:47:35.000000000 +0000
@@ -215,7 +215,6 @@ test_expect_success 'read-tree adds to w
 '
 
 test_expect_success 'index removal and worktree narrowing at the same time' '
-	>empty &&
 	echo init.t >.git/info/sparse-checkout &&
 	echo sub/added >>.git/info/sparse-checkout &&
 	git checkout -f top &&
@@ -223,16 +222,15 @@ test_expect_success 'index removal and w
 	git checkout removed &&
 	git ls-files sub/added >result &&
 	test ! -f sub/added &&
-	test_cmp empty result
+	test_must_be_empty result
 '
 
 test_expect_success 'read-tree --reset removes outside worktree' '
-	>empty &&
 	echo init.t >.git/info/sparse-checkout &&
 	git checkout -f top &&
 	git reset --hard removed &&
 	git ls-files sub/added >result &&
-	test_cmp empty result
+	test_must_be_empty result
 '
 
 test_expect_success 'print errors when failed to update worktree' '
diff -pruN 1.2.1+git2.18.0-1/git/t/t1014-read-tree-confusing.sh 1.2.3+git2.25.1-1/git/t/t1014-read-tree-confusing.sh
--- 1.2.1+git2.18.0-1/git/t/t1014-read-tree-confusing.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t1014-read-tree-confusing.sh	2020-02-17 04:47:35.000000000 +0000
@@ -49,6 +49,7 @@ git~1
 .git.SPACE .git.{space}
 .\\\\.GIT\\\\foobar backslashes
 .git\\\\foobar backslashes2
+.git...:alternate-stream
 EOF
 
 test_expect_success 'utf-8 paths allowed with core.protectHFS off' '
diff -pruN 1.2.1+git2.18.0-1/git/t/t1015-read-index-unmerged.sh 1.2.3+git2.25.1-1/git/t/t1015-read-index-unmerged.sh
--- 1.2.1+git2.18.0-1/git/t/t1015-read-index-unmerged.sh	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t1015-read-index-unmerged.sh	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,123 @@
+#!/bin/sh
+
+test_description='Test various callers of read_index_unmerged'
+. ./test-lib.sh
+
+test_expect_success 'setup modify/delete + directory/file conflict' '
+	test_create_repo df_plus_modify_delete &&
+	(
+		cd df_plus_modify_delete &&
+
+		test_write_lines a b c d e f g h >letters &&
+		git add letters &&
+		git commit -m initial &&
+
+		git checkout -b modify &&
+		# Throw in letters.txt for sorting order fun
+		# ("letters.txt" sorts between "letters" and "letters/file")
+		echo i >>letters &&
+		echo "version 2" >letters.txt &&
+		git add letters letters.txt &&
+		git commit -m modified &&
+
+		git checkout -b delete HEAD^ &&
+		git rm letters &&
+		mkdir letters &&
+		>letters/file &&
+		echo "version 1" >letters.txt &&
+		git add letters letters.txt &&
+		git commit -m deleted
+	)
+'
+
+test_expect_success 'read-tree --reset cleans unmerged entries' '
+	test_when_finished "git -C df_plus_modify_delete clean -f" &&
+	test_when_finished "git -C df_plus_modify_delete reset --hard" &&
+	(
+		cd df_plus_modify_delete &&
+
+		git checkout delete^0 &&
+		test_must_fail git merge modify &&
+
+		git read-tree --reset HEAD &&
+		git ls-files -u >conflicts &&
+		test_must_be_empty conflicts
+	)
+'
+
+test_expect_success 'One reset --hard cleans unmerged entries' '
+	test_when_finished "git -C df_plus_modify_delete clean -f" &&
+	test_when_finished "git -C df_plus_modify_delete reset --hard" &&
+	(
+		cd df_plus_modify_delete &&
+
+		git checkout delete^0 &&
+		test_must_fail git merge modify &&
+
+		git reset --hard &&
+		test_path_is_missing .git/MERGE_HEAD &&
+		git ls-files -u >conflicts &&
+		test_must_be_empty conflicts
+	)
+'
+
+test_expect_success 'setup directory/file conflict + simple edit/edit' '
+	test_create_repo df_plus_edit_edit &&
+	(
+		cd df_plus_edit_edit &&
+
+		test_seq 1 10 >numbers &&
+		git add numbers &&
+		git commit -m initial &&
+
+		git checkout -b d-edit &&
+		mkdir foo &&
+		echo content >foo/bar &&
+		git add foo &&
+		echo 11 >>numbers &&
+		git add numbers &&
+		git commit -m "directory and edit" &&
+
+		git checkout -b f-edit d-edit^1 &&
+		echo content >foo &&
+		git add foo &&
+		echo eleven >>numbers &&
+		git add numbers &&
+		git commit -m "file and edit"
+	)
+'
+
+test_expect_success 'git merge --abort succeeds despite D/F conflict' '
+	test_when_finished "git -C df_plus_edit_edit clean -f" &&
+	test_when_finished "git -C df_plus_edit_edit reset --hard" &&
+	(
+		cd df_plus_edit_edit &&
+
+		git checkout f-edit^0 &&
+		test_must_fail git merge d-edit^0 &&
+
+		git merge --abort &&
+		test_path_is_missing .git/MERGE_HEAD &&
+		git ls-files -u >conflicts &&
+		test_must_be_empty conflicts
+	)
+'
+
+test_expect_success 'git am --skip succeeds despite D/F conflict' '
+	test_when_finished "git -C df_plus_edit_edit clean -f" &&
+	test_when_finished "git -C df_plus_edit_edit reset --hard" &&
+	(
+		cd df_plus_edit_edit &&
+
+		git checkout f-edit^0 &&
+		git format-patch -1 d-edit &&
+		test_must_fail git am -3 0001*.patch &&
+
+		git am --skip &&
+		test_path_is_missing .git/rebase-apply &&
+		git ls-files -u >conflicts &&
+		test_must_be_empty conflicts
+	)
+'
+
+test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t1020-subdirectory.sh 1.2.3+git2.25.1-1/git/t/t1020-subdirectory.sh
--- 1.2.1+git2.18.0-1/git/t/t1020-subdirectory.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t1020-subdirectory.sh	2020-02-17 04:47:35.000000000 +0000
@@ -148,7 +148,7 @@ test_expect_success 'GIT_PREFIX for buil
 	(
 		cd dir &&
 		echo "change" >two &&
-		GIT_EXTERNAL_DIFF=./diff git diff >../actual
+		GIT_EXTERNAL_DIFF=./diff git diff >../actual &&
 		git checkout -- two
 	) &&
 	test_cmp expect actual
diff -pruN 1.2.1+git2.18.0-1/git/t/t1050-large.sh 1.2.3+git2.25.1-1/git/t/t1050-large.sh
--- 1.2.1+git2.18.0-1/git/t/t1050-large.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t1050-large.sh	2020-02-17 04:47:35.000000000 +0000
@@ -8,7 +8,7 @@ test_description='adding and checking ou
 # This should be moved to test-lib.sh together with the
 # copy in t0021 after both topics have graduated to 'master'.
 file_size () {
-	perl -e 'print -s $ARGV[0]' "$1"
+	test-tool path-utils file-size "$1"
 }
 
 test_expect_success setup '
@@ -108,7 +108,7 @@ test_expect_success 'packsize limit' '
 		test-tool genrandom "c" $(( 128 * 1024 )) >mid3 &&
 		git add mid1 mid2 mid3 &&
 
-		count=0
+		count=0 &&
 		for pi in .git/objects/pack/pack-*.idx
 		do
 			test -f "$pi" && count=$(( $count + 1 ))
@@ -116,8 +116,8 @@ test_expect_success 'packsize limit' '
 		test $count = 2 &&
 
 		(
-			git hash-object --stdin <mid1
-			git hash-object --stdin <mid2
+			git hash-object --stdin <mid1 &&
+			git hash-object --stdin <mid2 &&
 			git hash-object --stdin <mid3
 		) |
 		sort >expect &&
@@ -194,15 +194,15 @@ test_expect_success 'pack-objects with l
 	test_cmp huge actual
 '
 
-test_expect_success 'tar achiving' '
+test_expect_success 'tar archiving' '
 	git archive --format=tar HEAD >/dev/null
 '
 
-test_expect_success 'zip achiving, store only' '
+test_expect_success 'zip archiving, store only' '
 	git archive --format=zip -0 HEAD >/dev/null
 '
 
-test_expect_success 'zip achiving, deflate' '
+test_expect_success 'zip archiving, deflate' '
 	git archive --format=zip HEAD >/dev/null
 '
 
diff -pruN 1.2.1+git2.18.0-1/git/t/t1060-object-corruption.sh 1.2.3+git2.25.1-1/git/t/t1060-object-corruption.sh
--- 1.2.1+git2.18.0-1/git/t/t1060-object-corruption.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t1060-object-corruption.sh	2020-02-17 04:47:35.000000000 +0000
@@ -117,12 +117,24 @@ test_expect_failure 'clone --local detec
 '
 
 test_expect_success 'fetch into corrupted repo with index-pack' '
+	cp -R bit-error bit-error-cp &&
+	test_when_finished "rm -rf bit-error-cp" &&
 	(
-		cd bit-error &&
+		cd bit-error-cp &&
 		test_must_fail git -c transfer.unpackLimit=1 \
 			fetch ../no-bit-error 2>stderr &&
 		test_i18ngrep ! -i collision stderr
 	)
 '
 
+test_expect_success 'internal tree objects are not "missing"' '
+	git init missing-empty &&
+	(
+		cd missing-empty &&
+		empty_tree=$(git hash-object -t tree /dev/null) &&
+		commit=$(echo foo | git commit-tree $empty_tree) &&
+		git rev-list --objects $commit
+	)
+'
+
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t1090-sparse-checkout-scope.sh 1.2.3+git2.25.1-1/git/t/t1090-sparse-checkout-scope.sh
--- 1.2.1+git2.18.0-1/git/t/t1090-sparse-checkout-scope.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t1090-sparse-checkout-scope.sh	2020-02-17 04:47:35.000000000 +0000
@@ -49,4 +49,37 @@ test_expect_success 'return to full chec
 	test "$(cat b)" = "modified"
 '
 
+test_expect_success 'in partial clone, sparse checkout only fetches needed blobs' '
+	test_create_repo server &&
+	git clone "file://$(pwd)/server" client &&
+
+	test_config -C server uploadpack.allowfilter 1 &&
+	test_config -C server uploadpack.allowanysha1inwant 1 &&
+	echo a >server/a &&
+	echo bb >server/b &&
+	mkdir server/c &&
+	echo ccc >server/c/c &&
+	git -C server add a b c/c &&
+	git -C server commit -m message &&
+
+	test_config -C client core.sparsecheckout 1 &&
+	test_config -C client extensions.partialclone origin &&
+	echo "!/*" >client/.git/info/sparse-checkout &&
+	echo "/a" >>client/.git/info/sparse-checkout &&
+	git -C client fetch --filter=blob:none origin &&
+	git -C client checkout FETCH_HEAD &&
+
+	git -C client rev-list HEAD \
+		--quiet --objects --missing=print >unsorted_actual &&
+	(
+		printf "?" &&
+		git hash-object server/b &&
+		printf "?" &&
+		git hash-object server/c/c
+	) >unsorted_expect &&
+	sort unsorted_actual >actual &&
+	sort unsorted_expect >expect &&
+	test_cmp expect actual
+'
+
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t1091-sparse-checkout-builtin.sh 1.2.3+git2.25.1-1/git/t/t1091-sparse-checkout-builtin.sh
--- 1.2.1+git2.18.0-1/git/t/t1091-sparse-checkout-builtin.sh	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t1091-sparse-checkout-builtin.sh	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,371 @@
+#!/bin/sh
+
+test_description='sparse checkout builtin tests'
+
+. ./test-lib.sh
+
+list_files() {
+	# Do not replace this with 'ls "$1"', as "ls" with BSD-lineage
+	# enables "-A" by default for root and ends up including ".git" and
+	# such in its output. (Note, though, that running the test suite as
+	# root is generally not recommended.)
+	(cd "$1" && printf '%s\n' *)
+}
+
+test_expect_success 'setup' '
+	git init repo &&
+	(
+		cd repo &&
+		echo "initial" >a &&
+		mkdir folder1 folder2 deep &&
+		mkdir deep/deeper1 deep/deeper2 &&
+		mkdir deep/deeper1/deepest &&
+		cp a folder1 &&
+		cp a folder2 &&
+		cp a deep &&
+		cp a deep/deeper1 &&
+		cp a deep/deeper2 &&
+		cp a deep/deeper1/deepest &&
+		git add . &&
+		git commit -m "initial commit"
+	)
+'
+
+test_expect_success 'git sparse-checkout list (empty)' '
+	git -C repo sparse-checkout list >list 2>err &&
+	test_must_be_empty list &&
+	test_i18ngrep "this worktree is not sparse (sparse-checkout file may not exist)" err
+'
+
+test_expect_success 'git sparse-checkout list (populated)' '
+	test_when_finished rm -f repo/.git/info/sparse-checkout &&
+	cat >repo/.git/info/sparse-checkout <<-EOF &&
+		/folder1/*
+		/deep/
+		**/a
+		!*bin*
+	EOF
+	cp repo/.git/info/sparse-checkout expect &&
+	git -C repo sparse-checkout list >list &&
+	test_cmp expect list
+'
+
+test_expect_success 'git sparse-checkout init' '
+	git -C repo sparse-checkout init &&
+	cat >expect <<-EOF &&
+		/*
+		!/*/
+	EOF
+	test_cmp expect repo/.git/info/sparse-checkout &&
+	test_cmp_config -C repo true core.sparsecheckout &&
+	list_files repo >dir  &&
+	echo a >expect &&
+	test_cmp expect dir
+'
+
+test_expect_success 'git sparse-checkout list after init' '
+	git -C repo sparse-checkout list >actual &&
+	cat >expect <<-EOF &&
+		/*
+		!/*/
+	EOF
+	test_cmp expect actual
+'
+
+test_expect_success 'init with existing sparse-checkout' '
+	echo "*folder*" >> repo/.git/info/sparse-checkout &&
+	git -C repo sparse-checkout init &&
+	cat >expect <<-EOF &&
+		/*
+		!/*/
+		*folder*
+	EOF
+	test_cmp expect repo/.git/info/sparse-checkout &&
+	list_files repo >dir  &&
+	cat >expect <<-EOF &&
+		a
+		folder1
+		folder2
+	EOF
+	test_cmp expect dir
+'
+
+test_expect_success 'clone --sparse' '
+	git clone --sparse repo clone &&
+	git -C clone sparse-checkout list >actual &&
+	cat >expect <<-EOF &&
+		/*
+		!/*/
+	EOF
+	test_cmp expect actual &&
+	list_files clone >dir &&
+	echo a >expect &&
+	test_cmp expect dir
+'
+
+test_expect_success 'set enables config' '
+	git init empty-config &&
+	(
+		cd empty-config &&
+		test_commit test file &&
+		test_path_is_missing .git/config.worktree &&
+		test_must_fail git sparse-checkout set nothing &&
+		test_path_is_file .git/config.worktree &&
+		test_must_fail git config core.sparseCheckout &&
+		git sparse-checkout set "/*" &&
+		test_cmp_config true core.sparseCheckout
+	)
+'
+
+test_expect_success 'set sparse-checkout using builtin' '
+	git -C repo sparse-checkout set "/*" "!/*/" "*folder*" &&
+	cat >expect <<-EOF &&
+		/*
+		!/*/
+		*folder*
+	EOF
+	git -C repo sparse-checkout list >actual &&
+	test_cmp expect actual &&
+	test_cmp expect repo/.git/info/sparse-checkout &&
+	list_files repo >dir  &&
+	cat >expect <<-EOF &&
+		a
+		folder1
+		folder2
+	EOF
+	test_cmp expect dir
+'
+
+test_expect_success 'set sparse-checkout using --stdin' '
+	cat >expect <<-EOF &&
+		/*
+		!/*/
+		/folder1/
+		/folder2/
+	EOF
+	git -C repo sparse-checkout set --stdin <expect &&
+	git -C repo sparse-checkout list >actual &&
+	test_cmp expect actual &&
+	test_cmp expect repo/.git/info/sparse-checkout &&
+	list_files repo >dir  &&
+	cat >expect <<-EOF &&
+		a
+		folder1
+		folder2
+	EOF
+	test_cmp expect dir
+'
+
+test_expect_success 'cone mode: match patterns' '
+	git -C repo config --worktree core.sparseCheckoutCone true &&
+	rm -rf repo/a repo/folder1 repo/folder2 &&
+	git -C repo read-tree -mu HEAD 2>err &&
+	test_i18ngrep ! "disabling cone patterns" err &&
+	git -C repo reset --hard &&
+	list_files repo >dir  &&
+	cat >expect <<-EOF &&
+		a
+		folder1
+		folder2
+	EOF
+	test_cmp expect dir
+'
+
+test_expect_success 'cone mode: warn on bad pattern' '
+	test_when_finished mv sparse-checkout repo/.git/info/ &&
+	cp repo/.git/info/sparse-checkout . &&
+	echo "!/deep/deeper/*" >>repo/.git/info/sparse-checkout &&
+	git -C repo read-tree -mu HEAD 2>err &&
+	test_i18ngrep "unrecognized negative pattern" err
+'
+
+test_expect_success 'sparse-checkout disable' '
+	test_when_finished rm -rf repo/.git/info/sparse-checkout &&
+	git -C repo sparse-checkout disable &&
+	test_path_is_file repo/.git/info/sparse-checkout &&
+	git -C repo config --list >config &&
+	test_must_fail git config core.sparseCheckout &&
+	list_files repo >dir &&
+	cat >expect <<-EOF &&
+		a
+		deep
+		folder1
+		folder2
+	EOF
+	test_cmp expect dir
+'
+
+test_expect_success 'cone mode: init and set' '
+	git -C repo sparse-checkout init --cone &&
+	git -C repo config --list >config &&
+	test_i18ngrep "core.sparsecheckoutcone=true" config &&
+	list_files repo >dir  &&
+	echo a >expect &&
+	test_cmp expect dir &&
+	git -C repo sparse-checkout set deep/deeper1/deepest/ 2>err &&
+	test_must_be_empty err &&
+	list_files repo >dir  &&
+	cat >expect <<-EOF &&
+		a
+		deep
+	EOF
+	test_cmp expect dir &&
+	list_files repo/deep >dir  &&
+	cat >expect <<-EOF &&
+		a
+		deeper1
+	EOF
+	test_cmp expect dir &&
+	list_files repo/deep/deeper1 >dir  &&
+	cat >expect <<-EOF &&
+		a
+		deepest
+	EOF
+	test_cmp expect dir &&
+	cat >expect <<-EOF &&
+		/*
+		!/*/
+		/deep/
+		!/deep/*/
+		/deep/deeper1/
+		!/deep/deeper1/*/
+		/deep/deeper1/deepest/
+	EOF
+	test_cmp expect repo/.git/info/sparse-checkout &&
+	git -C repo sparse-checkout set --stdin 2>err <<-EOF &&
+		folder1
+		folder2
+	EOF
+	test_must_be_empty err &&
+	cat >expect <<-EOF &&
+		a
+		folder1
+		folder2
+	EOF
+	list_files repo >dir &&
+	test_cmp expect dir
+'
+
+test_expect_success 'cone mode: list' '
+	cat >expect <<-EOF &&
+		folder1
+		folder2
+	EOF
+	git -C repo sparse-checkout set --stdin <expect &&
+	git -C repo sparse-checkout list >actual 2>err &&
+	test_must_be_empty err &&
+	test_cmp expect actual
+'
+
+test_expect_success 'cone mode: set with nested folders' '
+	git -C repo sparse-checkout set deep deep/deeper1/deepest 2>err &&
+	test_line_count = 0 err &&
+	cat >expect <<-EOF &&
+		/*
+		!/*/
+		/deep/
+	EOF
+	test_cmp repo/.git/info/sparse-checkout expect
+'
+
+test_expect_success 'revert to old sparse-checkout on bad update' '
+	test_when_finished git -C repo reset --hard &&
+	echo update >repo/deep/deeper2/a &&
+	cp repo/.git/info/sparse-checkout expect &&
+	test_must_fail git -C repo sparse-checkout set deep/deeper1 2>err &&
+	test_i18ngrep "cannot set sparse-checkout patterns" err &&
+	test_cmp repo/.git/info/sparse-checkout expect &&
+	list_files repo/deep >dir &&
+	cat >expect <<-EOF &&
+		a
+		deeper1
+		deeper2
+	EOF
+	test_cmp dir expect
+'
+
+test_expect_success 'revert to old sparse-checkout on empty update' '
+	git init empty-test &&
+	(
+		echo >file &&
+		git add file &&
+		git commit -m "test" &&
+		test_must_fail git sparse-checkout set nothing 2>err &&
+		test_i18ngrep "Sparse checkout leaves no entry on working directory" err &&
+		test_i18ngrep ! ".git/index.lock" err &&
+		git sparse-checkout set file
+	)
+'
+
+test_expect_success 'fail when lock is taken' '
+	test_when_finished rm -rf repo/.git/info/sparse-checkout.lock &&
+	touch repo/.git/info/sparse-checkout.lock &&
+	test_must_fail git -C repo sparse-checkout set deep 2>err &&
+	test_i18ngrep "File exists" err
+'
+
+test_expect_success '.gitignore should not warn about cone mode' '
+	git -C repo config --worktree core.sparseCheckoutCone true &&
+	echo "**/bin/*" >repo/.gitignore &&
+	git -C repo reset --hard 2>err &&
+	test_i18ngrep ! "disabling cone patterns" err
+'
+
+test_expect_success 'sparse-checkout (init|set|disable) fails with dirty status' '
+	git clone repo dirty &&
+	echo dirty >dirty/folder1/a &&
+	test_must_fail git -C dirty sparse-checkout init &&
+	test_must_fail git -C dirty sparse-checkout set /folder2/* /deep/deeper1/* &&
+	test_must_fail git -C dirty sparse-checkout disable &&
+	git -C dirty reset --hard &&
+	git -C dirty sparse-checkout init &&
+	git -C dirty sparse-checkout set /folder2/* /deep/deeper1/* &&
+	git -C dirty sparse-checkout disable
+'
+
+test_expect_success 'cone mode: set with core.ignoreCase=true' '
+	git -C repo sparse-checkout init --cone &&
+	git -C repo -c core.ignoreCase=true sparse-checkout set folder1 &&
+	cat >expect <<-EOF &&
+		/*
+		!/*/
+		/folder1/
+	EOF
+	test_cmp expect repo/.git/info/sparse-checkout &&
+	list_files repo >dir &&
+	cat >expect <<-EOF &&
+		a
+		folder1
+	EOF
+	test_cmp expect dir
+'
+
+test_expect_success 'interaction with submodules' '
+	git clone repo super &&
+	(
+		cd super &&
+		mkdir modules &&
+		git submodule add ../repo modules/child &&
+		git add . &&
+		git commit -m "add submodule" &&
+		git sparse-checkout init --cone &&
+		git sparse-checkout set folder1
+	) &&
+	list_files super >dir &&
+	cat >expect <<-\EOF &&
+		a
+		folder1
+		modules
+	EOF
+	test_cmp expect dir &&
+	list_files super/modules/child >dir &&
+	cat >expect <<-\EOF &&
+		a
+		deep
+		folder1
+		folder2
+	EOF
+	test_cmp expect dir
+'
+
+test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t1300-config.sh 1.2.3+git2.25.1-1/git/t/t1300-config.sh
--- 1.2.1+git2.18.0-1/git/t/t1300-config.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t1300-config.sh	2020-02-17 04:47:35.000000000 +0000
@@ -76,15 +76,11 @@ EOF
 test_expect_success 'non-match result' 'test_cmp expect .git/config'
 
 test_expect_success 'find mixed-case key by canonical name' '
-	echo Second >expect &&
-	git config cores.whatever >actual &&
-	test_cmp expect actual
+	test_cmp_config Second cores.whatever
 '
 
 test_expect_success 'find mixed-case key by non-canonical name' '
-	echo Second >expect &&
-	git config CoReS.WhAtEvEr >actual &&
-	test_cmp expect actual
+	test_cmp_config Second CoReS.WhAtEvEr
 '
 
 test_expect_success 'subsections are not canonicalized by git-config' '
@@ -94,12 +90,8 @@ test_expect_success 'subsections are not
 	[section "SubSection"]
 	key = two
 	EOF
-	echo one >expect &&
-	git config section.subsection.key >actual &&
-	test_cmp expect actual &&
-	echo two >expect &&
-	git config section.SubSection.key >actual &&
-	test_cmp expect actual
+	test_cmp_config one section.subsection.key &&
+	test_cmp_config two section.SubSection.key
 '
 
 cat > .git/config <<\EOF
@@ -212,9 +204,7 @@ test_expect_success 'really really mean
 '
 
 test_expect_success 'get value' '
-	echo alpha >expect &&
-	git config beta.haha >actual &&
-	test_cmp expect actual
+	test_cmp_config alpha beta.haha
 '
 
 cat > expect << EOF
@@ -251,15 +241,11 @@ test_expect_success 'non-match' '
 '
 
 test_expect_success 'non-match value' '
-	echo wow >expect &&
-	git config --get nextsection.nonewline !for >actual &&
-	test_cmp expect actual
+	test_cmp_config wow --get nextsection.nonewline !for
 '
 
 test_expect_success 'multi-valued get returns final one' '
-	echo "wow2 for me" >expect &&
-	git config --get nextsection.nonewline >actual &&
-	test_cmp expect actual
+	test_cmp_config "wow2 for me" --get nextsection.nonewline
 '
 
 test_expect_success 'multi-valued get-all returns all' '
@@ -346,12 +332,9 @@ test_expect_success 'working --list' '
 	git config --list > output &&
 	test_cmp expect output
 '
-cat > expect << EOF
-EOF
-
 test_expect_success '--list without repo produces empty output' '
 	git --git-dir=nonexistent config --list >output &&
-	test_cmp expect output
+	test_must_be_empty output
 '
 
 cat > expect << EOF
@@ -523,21 +506,11 @@ test_expect_success 'editing stdin is an
 
 test_expect_success 'refer config from subdirectory' '
 	mkdir x &&
-	(
-		cd x &&
-		echo strasse >expect &&
-		git config --get --file ../other-config ein.bahn >actual &&
-		test_cmp expect actual
-	)
-
+	test_cmp_config -C x strasse --get --file ../other-config ein.bahn
 '
 
 test_expect_success 'refer config from subdirectory via --file' '
-	(
-		cd x &&
-		git config --file=../other-config --get ein.bahn >actual &&
-		test_cmp expect actual
-	)
+	test_cmp_config -C x strasse --file=../other-config --get ein.bahn
 '
 
 cat > expect << EOF
@@ -691,16 +664,13 @@ test_expect_success numbers '
 
 test_expect_success '--int is at least 64 bits' '
 	git config giga.watts 121g &&
-	echo 129922760704 >expect &&
-	git config --int --get giga.watts >actual &&
-	test_cmp expect actual
+	echo  >expect &&
+	test_cmp_config 129922760704 --int --get giga.watts
 '
 
 test_expect_success 'invalid unit' '
 	git config aninvalid.unit "1auto" &&
-	echo 1auto >expect &&
-	git config aninvalid.unit >actual &&
-	test_cmp expect actual &&
+	test_cmp_config 1auto aninvalid.unit &&
 	test_must_fail git config --int --get aninvalid.unit 2>actual &&
 	test_i18ngrep "bad numeric config value .1auto. for .aninvalid.unit. in file .git/config: invalid unit" actual
 '
@@ -888,7 +858,7 @@ EOF
 
 test_expect_success !MINGW 'get --path copes with unset $HOME' '
 	(
-		unset HOME;
+		sane_unset HOME &&
 		test_must_fail git config --get --path path.home \
 			>result 2>msg &&
 		git config --get --path path.normal >>result &&
@@ -922,6 +892,7 @@ test_expect_success 'get --expiry-date'
 	1510348087
 	0
 	EOF
+	: "work around heredoc parsing bug fixed in dash 0.5.7 (in ec2c84d)" &&
 	{
 		echo "$rel_out $(git config --expiry-date date.valid1)"
 		git config --expiry-date date.valid2 &&
@@ -1004,7 +975,7 @@ EOF
 
 test_expect_success 'value continued on next line' '
 	git config --list > result &&
-	test_cmp result expect
+	test_cmp expect result
 '
 
 cat > .git/config <<\EOF
@@ -1042,9 +1013,7 @@ test_expect_success '--null --get-regexp
 
 test_expect_success 'inner whitespace kept verbatim' '
 	git config section.val "foo 	  bar" &&
-	echo "foo 	  bar" >expect &&
-	git config section.val >actual &&
-	test_cmp expect actual
+	test_cmp_config "foo 	  bar" section.val
 '
 
 test_expect_success SYMLINKS 'symlinked configuration' '
@@ -1218,6 +1187,93 @@ test_expect_success 'last one wins: thre
 	test_cmp expect actual
 '
 
+test_expect_success 'old-fashioned settings are case insensitive' '
+	test_when_finished "rm -f testConfig testConfig_expect testConfig_actual" &&
+
+	cat >testConfig_actual <<-EOF &&
+		[V.A]
+		r = value1
+	EOF
+	q_to_tab >testConfig_expect <<-EOF &&
+		[V.A]
+		Qr = value2
+	EOF
+	git config -f testConfig_actual "v.a.r" value2 &&
+	test_cmp testConfig_expect testConfig_actual &&
+
+	cat >testConfig_actual <<-EOF &&
+		[V.A]
+		r = value1
+	EOF
+	q_to_tab >testConfig_expect <<-EOF &&
+		[V.A]
+		QR = value2
+	EOF
+	git config -f testConfig_actual "V.a.R" value2 &&
+	test_cmp testConfig_expect testConfig_actual &&
+
+	cat >testConfig_actual <<-EOF &&
+		[V.A]
+		r = value1
+	EOF
+	q_to_tab >testConfig_expect <<-EOF &&
+		[V.A]
+		r = value1
+		Qr = value2
+	EOF
+	git config -f testConfig_actual "V.A.r" value2 &&
+	test_cmp testConfig_expect testConfig_actual &&
+
+	cat >testConfig_actual <<-EOF &&
+		[V.A]
+		r = value1
+	EOF
+	q_to_tab >testConfig_expect <<-EOF &&
+		[V.A]
+		r = value1
+		Qr = value2
+	EOF
+	git config -f testConfig_actual "v.A.r" value2 &&
+	test_cmp testConfig_expect testConfig_actual
+'
+
+test_expect_success 'setting different case sensitive subsections ' '
+	test_when_finished "rm -f testConfig testConfig_expect testConfig_actual" &&
+
+	cat >testConfig_actual <<-EOF &&
+		[V "A"]
+		R = v1
+		[K "E"]
+		Y = v1
+		[a "b"]
+		c = v1
+		[d "e"]
+		f = v1
+	EOF
+	q_to_tab >testConfig_expect <<-EOF &&
+		[V "A"]
+		Qr = v2
+		[K "E"]
+		Qy = v2
+		[a "b"]
+		Qc = v2
+		[d "e"]
+		f = v1
+		[d "E"]
+		Qf = v2
+	EOF
+	# exact match
+	git config -f testConfig_actual a.b.c v2 &&
+	# match section and subsection, key is cased differently.
+	git config -f testConfig_actual K.E.y v2 &&
+	# section and key are matched case insensitive, but subsection needs
+	# to match; When writing out new values only the key is adjusted
+	git config -f testConfig_actual v.A.r v2 &&
+	# subsection is not matched:
+	git config -f testConfig_actual d.E.f v2 &&
+	test_cmp testConfig_expect testConfig_actual
+'
+
 for VAR in a .a a. a.0b a."b c". a."b c".0d
 do
 	test_expect_success "git -c $VAR=VAL rejects invalid '$VAR'" '
@@ -1238,26 +1294,25 @@ test_expect_success 'git -c is not confu
 	GIT_CONFIG_PARAMETERS="" git -c x.one=1 config --list
 '
 
-sq="'"
 test_expect_success 'detect bogus GIT_CONFIG_PARAMETERS' '
 	cat >expect <<-\EOF &&
 	env.one one
 	env.two two
 	EOF
-	GIT_CONFIG_PARAMETERS="${sq}env.one=one${sq} ${sq}env.two=two${sq}" \
+	GIT_CONFIG_PARAMETERS="${SQ}env.one=one${SQ} ${SQ}env.two=two${SQ}" \
 		git config --get-regexp "env.*" >actual &&
 	test_cmp expect actual &&
 
 	cat >expect <<-EOF &&
-	env.one one${sq}
+	env.one one${SQ}
 	env.two two
 	EOF
-	GIT_CONFIG_PARAMETERS="${sq}env.one=one${sq}\\$sq$sq$sq ${sq}env.two=two${sq}" \
+	GIT_CONFIG_PARAMETERS="${SQ}env.one=one${SQ}\\$SQ$SQ$SQ ${SQ}env.two=two${SQ}" \
 		git config --get-regexp "env.*" >actual &&
 	test_cmp expect actual &&
 
 	test_must_fail env \
-		GIT_CONFIG_PARAMETERS="${sq}env.one=one${sq}\\$sq ${sq}env.two=two${sq}" \
+		GIT_CONFIG_PARAMETERS="${SQ}env.one=one${SQ}\\$SQ ${SQ}env.two=two${SQ}" \
 		git config --get-regexp "env.*"
 '
 
@@ -1686,8 +1741,9 @@ test_expect_success '--show-origin stdin
 	cat >expect <<-EOF &&
 		file:$INCLUDE_DIR/stdin.include	include
 	EOF
-	echo "[include]path=\"$INCLUDE_DIR\"/stdin.include" \
-		| git config --show-origin --includes --file - user.stdin >output &&
+	echo "[include]path=\"$INCLUDE_DIR\"/stdin.include" |
+	git config --show-origin --includes --file - user.stdin >output &&
+
 	test_cmp expect output
 '
 
@@ -1724,21 +1780,15 @@ big = 1M
 EOF
 
 test_expect_success 'identical modern --type specifiers are allowed' '
-	git config --type=int --type=int core.big >actual &&
-	echo 1048576 >expect &&
-	test_cmp expect actual
+	test_cmp_config 1048576 --type=int --type=int core.big
 '
 
 test_expect_success 'identical legacy --type specifiers are allowed' '
-	git config --int --int core.big >actual &&
-	echo 1048576 >expect &&
-	test_cmp expect actual
+	test_cmp_config 1048576 --int --int core.big
 '
 
 test_expect_success 'identical mixed --type specifiers are allowed' '
-	git config --int --type=int core.big >actual &&
-	echo 1048576 >expect &&
-	test_cmp expect actual
+	test_cmp_config 1048576 --int --type=int core.big
 '
 
 test_expect_success 'non-identical modern --type specifiers are not allowed' '
@@ -1757,21 +1807,15 @@ test_expect_success 'non-identical mixed
 '
 
 test_expect_success '--type allows valid type specifiers' '
-	echo "true" >expect &&
-	git config --type=bool core.foo >actual &&
-	test_cmp expect actual
+	test_cmp_config true  --type=bool core.foo
 '
 
 test_expect_success '--no-type unsets type specifiers' '
-	echo "10" >expect &&
-	git config --type=bool --no-type core.number >actual &&
-	test_cmp expect actual
+	test_cmp_config 10 --type=bool --no-type core.number
 '
 
 test_expect_success 'unset type specifiers may be reset to conflicting ones' '
-	echo 1048576 >expect &&
-	git config --type=bool --no-type --type=int core.big >actual &&
-	test_cmp expect actual
+	test_cmp_config 1048576 --type=bool --no-type --type=int core.big
 '
 
 test_expect_success '--type rejects unknown specifiers' '
@@ -1797,7 +1841,7 @@ test_expect_success '--replace-all does
 	Qkey = b
 	EOF
 	git config --replace-all abc.key b &&
-	test_cmp .git/config expect
+	test_cmp expect .git/config
 '
 
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t1301-shared-repo.sh 1.2.3+git2.25.1-1/git/t/t1301-shared-repo.sh
--- 1.2.1+git2.18.0-1/git/t/t1301-shared-repo.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t1301-shared-repo.sh	2020-02-17 04:47:35.000000000 +0000
@@ -136,7 +136,7 @@ test_expect_success POSIXPERM 'forced mo
 	(
 		cd new &&
 		umask 002 &&
-		git init --shared=0660 --template=../templates &&
+		git init --shared=0660 --template=templates &&
 		>frotz &&
 		git add frotz &&
 		git commit -a -m initial &&
@@ -192,7 +192,7 @@ test_expect_success POSIXPERM 're-init r
 	umask 0022 &&
 	git init --bare --shared=0666 child.git &&
 	test_path_is_missing child.git/foo &&
-	git init --bare --template=../templates child.git &&
+	git init --bare --template=templates child.git &&
 	echo "-rw-rw-rw-" >expect &&
 	test_modebits child.git/foo >actual &&
 	test_cmp expect actual
@@ -203,7 +203,7 @@ test_expect_success POSIXPERM 'template
 	umask 0022 &&
 	git config core.sharedrepository 0666 &&
 	cp .git/config templates/config &&
-	git init --bare --template=../templates child.git &&
+	git init --bare --template=templates child.git &&
 	echo "-rw-rw-rw-" >expect &&
 	test_modebits child.git/HEAD >actual &&
 	test_cmp expect actual
diff -pruN 1.2.1+git2.18.0-1/git/t/t1303-wacky-config.sh 1.2.3+git2.25.1-1/git/t/t1303-wacky-config.sh
--- 1.2.1+git2.18.0-1/git/t/t1303-wacky-config.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t1303-wacky-config.sh	2020-02-17 04:47:35.000000000 +0000
@@ -14,7 +14,7 @@ setup() {
 check() {
 	echo "$2" >expected
 	git config --get "$1" >actual 2>&1
-	test_cmp actual expected
+	test_cmp expected actual
 }
 
 # 'check section.key regex value' verifies that the entry for
@@ -22,7 +22,7 @@ check() {
 check_regex() {
 	echo "$3" >expected
 	git config --get "$1" "$2" >actual 2>&1
-	test_cmp actual expected
+	test_cmp expected actual
 }
 
 test_expect_success 'modify same key' '
diff -pruN 1.2.1+git2.18.0-1/git/t/t1305-config-include.sh 1.2.3+git2.25.1-1/git/t/t1305-config-include.sh
--- 1.2.1+git2.18.0-1/git/t/t1305-config-include.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t1305-config-include.sh	2020-02-17 04:47:35.000000000 +0000
@@ -63,7 +63,7 @@ test_expect_success 'listing includes op
 	test.one=1
 	EOF
 	git config --list >actual.full &&
-	grep -v ^core actual.full >actual &&
+	grep -v -e ^core -e ^extensions actual.full >actual &&
 	test_cmp expect actual
 '
 
@@ -229,6 +229,19 @@ test_expect_success 'conditional include
 	)
 '
 
+test_expect_success 'conditional include with /**/' '
+	REPO=foo/bar/repo &&
+	git init $REPO &&
+	cat >>$REPO/.git/config <<-\EOF &&
+	[includeIf "gitdir:**/foo/**/bar/**"]
+	path=bar7
+	EOF
+	echo "[test]seven=7" >$REPO/.git/bar7 &&
+	echo 7 >expect &&
+	git -C $REPO config test.seven >actual &&
+	test_cmp expect actual
+'
+
 test_expect_success SYMLINKS 'conditional include, set up symlinked $HOME' '
 	mkdir real-home &&
 	ln -s real-home home &&
@@ -296,20 +309,52 @@ test_expect_success SYMLINKS 'conditiona
 	)
 '
 
+test_expect_success 'conditional include, onbranch' '
+	echo "[includeIf \"onbranch:foo-branch\"]path=bar9" >>.git/config &&
+	echo "[test]nine=9" >.git/bar9 &&
+	git checkout -b master &&
+	test_must_fail git config test.nine &&
+	git checkout -b foo-branch &&
+	echo 9 >expect &&
+	git config test.nine >actual &&
+	test_cmp expect actual
+'
+
+test_expect_success 'conditional include, onbranch, wildcard' '
+	echo "[includeIf \"onbranch:?oo-*/**\"]path=bar10" >>.git/config &&
+	echo "[test]ten=10" >.git/bar10 &&
+	git checkout -b not-foo-branch/a &&
+	test_must_fail git config test.ten &&
+
+	echo 10 >expect &&
+	git checkout -b foo-branch/a/b/c &&
+	git config test.ten >actual &&
+	test_cmp expect actual &&
+
+	git checkout -b moo-bar/a &&
+	git config test.ten >actual &&
+	test_cmp expect actual
+'
+
+test_expect_success 'conditional include, onbranch, implicit /** for /' '
+	echo "[includeIf \"onbranch:foo-dir/\"]path=bar11" >>.git/config &&
+	echo "[test]eleven=11" >.git/bar11 &&
+	git checkout -b not-foo-dir/a &&
+	test_must_fail git config test.eleven &&
+
+	echo 11 >expect &&
+	git checkout -b foo-dir/a/b/c &&
+	git config test.eleven >actual &&
+	test_cmp expect actual
+'
+
 test_expect_success 'include cycles are detected' '
-	cat >.gitconfig <<-\EOF &&
-	[test]value = gitconfig
-	[include]path = cycle
-	EOF
-	cat >cycle <<-\EOF &&
-	[test]value = cycle
-	[include]path = .gitconfig
-	EOF
-	cat >expect <<-\EOF &&
-	gitconfig
-	cycle
-	EOF
-	test_must_fail git config --get-all test.value 2>stderr &&
+	git init --bare cycle &&
+	git -C cycle config include.path cycle &&
+	git config -f cycle/cycle include.path config &&
+	test_must_fail \
+		env GIT_TEST_GETTEXT_POISON=false \
+		git -C cycle config --get-all test.value 2>stderr &&
 	grep "exceeded maximum include depth" stderr
 '
 
diff -pruN 1.2.1+git2.18.0-1/git/t/t1306-xdg-files.sh 1.2.3+git2.25.1-1/git/t/t1306-xdg-files.sh
--- 1.2.1+git2.18.0-1/git/t/t1306-xdg-files.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t1306-xdg-files.sh	2020-02-17 04:47:35.000000000 +0000
@@ -114,11 +114,10 @@ test_expect_success 'Exclusion in a non-
 '
 
 test_expect_success 'Checking XDG ignore file when HOME is unset' '
-	>expected &&
 	(sane_unset HOME &&
 	 git config --unset core.excludesfile &&
 	 git ls-files --exclude-standard --ignored >actual) &&
-	test_cmp expected actual
+	test_must_be_empty actual
 '
 
 test_expect_success 'Checking attributes in the XDG attributes file' '
@@ -132,10 +131,9 @@ test_expect_success 'Checking attributes
 '
 
 test_expect_success 'Checking XDG attributes when HOME is unset' '
-	>expected &&
 	(sane_unset HOME &&
 	 git check-attr -a f >actual) &&
-	test_cmp expected actual
+	test_must_be_empty actual
 '
 
 test_expect_success '$XDG_CONFIG_HOME overrides $HOME/.config/git/attributes' '
diff -pruN 1.2.1+git2.18.0-1/git/t/t1308-config-set.sh 1.2.3+git2.25.1-1/git/t/t1308-config-set.sh
--- 1.2.1+git2.18.0-1/git/t/t1308-config-set.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t1308-config-set.sh	2020-02-17 04:47:35.000000000 +0000
@@ -166,14 +166,14 @@ test_expect_success 'find value with hig
 '
 
 test_expect_success 'find value_list for a key from a configset' '
-	cat >except <<-\EOF &&
+	cat >expect <<-\EOF &&
+	lama
+	ball
 	sam
 	bat
 	hask
-	lama
-	ball
 	EOF
-	test-tool config configset_get_value case.baz config2 .git/config >actual &&
+	test-tool config configset_get_value_multi case.baz config2 .git/config >actual &&
 	test_cmp expect actual
 '
 
@@ -233,7 +233,7 @@ test_expect_success 'check line errors f
 
 test_expect_success 'error on modifying repo config without repo' '
 	nongit test_must_fail git config a.b c 2>err &&
-	grep "not in a git directory" err
+	test_i18ngrep "not in a git directory" err
 '
 
 cmdline_config="'foo.bar=from-cmdline'"
diff -pruN 1.2.1+git2.18.0-1/git/t/t1309-early-config.sh 1.2.3+git2.25.1-1/git/t/t1309-early-config.sh
--- 1.2.1+git2.18.0-1/git/t/t1309-early-config.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t1309-early-config.sh	2020-02-17 04:47:35.000000000 +0000
@@ -29,7 +29,7 @@ test_expect_success 'ceiling' '
 		cd sub &&
 		test-tool config read_early_config early.config
 	) >output &&
-	test -z "$(cat output)"
+	test_must_be_empty output
 '
 
 test_expect_success 'ceiling #2' '
@@ -89,4 +89,14 @@ test_expect_failure 'ignore .git/ with i
 	test_with_config "["
 '
 
+test_expect_success 'early config and onbranch' '
+	echo "[broken" >broken &&
+	test_with_config "[includeif \"onbranch:master\"]path=../broken"
+'
+
+test_expect_success 'onbranch config outside of git repo' '
+	test_config_global includeIf.onbranch:master.path non-existent &&
+	nongit git help
+'
+
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t1400-update-ref.sh 1.2.3+git2.25.1-1/git/t/t1400-update-ref.sh
--- 1.2.1+git2.18.0-1/git/t/t1400-update-ref.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t1400-update-ref.sh	2020-02-17 04:47:35.000000000 +0000
@@ -344,14 +344,16 @@ test_expect_success "verifying $m's log
 	test_cmp expect .git/logs/$m
 '
 
-git update-ref $m $D
-cat >.git/logs/$m <<EOF
-0000000000000000000000000000000000000000 $C $GIT_COMMITTER_NAME <$GIT_COMMITTER_EMAIL> 1117150320 -0500
-$C $A $GIT_COMMITTER_NAME <$GIT_COMMITTER_EMAIL> 1117150350 -0500
-$A $B $GIT_COMMITTER_NAME <$GIT_COMMITTER_EMAIL> 1117150380 -0500
-$F $Z $GIT_COMMITTER_NAME <$GIT_COMMITTER_EMAIL> 1117150680 -0500
-$Z $E $GIT_COMMITTER_NAME <$GIT_COMMITTER_EMAIL> 1117150980 -0500
-EOF
+test_expect_success 'set up for querying the reflog' '
+	git update-ref $m $D &&
+	cat >.git/logs/$m <<-EOF
+	$Z $C $GIT_COMMITTER_NAME <$GIT_COMMITTER_EMAIL> 1117150320 -0500
+	$C $A $GIT_COMMITTER_NAME <$GIT_COMMITTER_EMAIL> 1117150350 -0500
+	$A $B $GIT_COMMITTER_NAME <$GIT_COMMITTER_EMAIL> 1117150380 -0500
+	$F $Z $GIT_COMMITTER_NAME <$GIT_COMMITTER_EMAIL> 1117150680 -0500
+	$Z $E $GIT_COMMITTER_NAME <$GIT_COMMITTER_EMAIL> 1117150980 -0500
+	EOF
+'
 
 ed="Thu, 26 May 2005 18:32:00 -0500"
 gd="Thu, 26 May 2005 18:33:00 -0500"
@@ -366,7 +368,7 @@ test_expect_success 'Query master@{2005-
 	test_when_finished "rm -f o e" &&
 	git rev-parse --verify master@{2005-05-25} >o 2>e &&
 	test $C = $(cat o) &&
-	echo test "warning: Log for '\''master'\'' only goes back to $ed." = "$(cat e)"
+	test "warning: Log for '\''master'\'' only goes back to $ed." = "$(cat e)"
 '
 test_expect_success 'Query "master@{May 26 2005 23:31:59}" (1 second before history)' '
 	test_when_finished "rm -f o e" &&
@@ -378,37 +380,37 @@ test_expect_success 'Query "master@{May
 	test_when_finished "rm -f o e" &&
 	git rev-parse --verify "master@{May 26 2005 23:32:00}" >o 2>e &&
 	test $C = $(cat o) &&
-	test "" = "$(cat e)"
+	test_must_be_empty e
 '
 test_expect_success 'Query "master@{May 26 2005 23:32:30}" (first non-creation change)' '
 	test_when_finished "rm -f o e" &&
 	git rev-parse --verify "master@{May 26 2005 23:32:30}" >o 2>e &&
 	test $A = $(cat o) &&
-	test "" = "$(cat e)"
+	test_must_be_empty e
 '
 test_expect_success 'Query "master@{2005-05-26 23:33:01}" (middle of history with gap)' '
 	test_when_finished "rm -f o e" &&
 	git rev-parse --verify "master@{2005-05-26 23:33:01}" >o 2>e &&
 	test $B = $(cat o) &&
-	test "warning: Log for ref $m has gap after $gd." = "$(cat e)"
+	test_i18ngrep -F "warning: log for ref $m has gap after $gd" e
 '
 test_expect_success 'Query "master@{2005-05-26 23:38:00}" (middle of history)' '
 	test_when_finished "rm -f o e" &&
 	git rev-parse --verify "master@{2005-05-26 23:38:00}" >o 2>e &&
 	test $Z = $(cat o) &&
-	test "" = "$(cat e)"
+	test_must_be_empty e
 '
 test_expect_success 'Query "master@{2005-05-26 23:43:00}" (exact end of history)' '
 	test_when_finished "rm -f o e" &&
 	git rev-parse --verify "master@{2005-05-26 23:43:00}" >o 2>e &&
 	test $E = $(cat o) &&
-	test "" = "$(cat e)"
+	test_must_be_empty e
 '
 test_expect_success 'Query "master@{2005-05-28}" (past end of history)' '
 	test_when_finished "rm -f o e" &&
 	git rev-parse --verify "master@{2005-05-28}" >o 2>e &&
 	test $D = $(cat o) &&
-	test "warning: Log for ref $m unexpectedly ended on $ld." = "$(cat e)"
+	test_i18ngrep -F "warning: log for ref $m unexpectedly ended on $ld" e
 '
 
 rm -f .git/$m .git/logs/$m expect
@@ -462,7 +464,7 @@ test_expect_success 'git cat-file blob m
 test_expect_success 'given old value for missing pseudoref, do not create' '
 	test_must_fail git update-ref PSEUDOREF $A $B 2>err &&
 	test_path_is_missing .git/PSEUDOREF &&
-	grep "could not read ref" err
+	test_i18ngrep "could not read ref" err
 '
 
 test_expect_success 'create pseudoref' '
@@ -483,7 +485,7 @@ test_expect_success 'overwrite pseudoref
 test_expect_success 'do not overwrite pseudoref with wrong old value' '
 	test_must_fail git update-ref PSEUDOREF $D $E 2>err &&
 	test $C = $(cat .git/PSEUDOREF) &&
-	grep "unexpected object ID" err
+	test_i18ngrep "unexpected object ID" err
 '
 
 test_expect_success 'delete pseudoref' '
@@ -495,7 +497,7 @@ test_expect_success 'do not delete pseud
 	git update-ref PSEUDOREF $A &&
 	test_must_fail git update-ref -d PSEUDOREF $B 2>err &&
 	test $A = $(cat .git/PSEUDOREF) &&
-	grep "unexpected object ID" err
+	test_i18ngrep "unexpected object ID" err
 '
 
 test_expect_success 'delete pseudoref with correct old value' '
@@ -512,7 +514,7 @@ test_expect_success 'do not overwrite ps
 	test_when_finished git update-ref -d PSEUDOREF &&
 	test_must_fail git update-ref PSEUDOREF $B $Z 2>err &&
 	test $A = $(cat .git/PSEUDOREF) &&
-	grep "already exists" err
+	test_i18ngrep "already exists" err
 '
 
 # Test --stdin
@@ -650,7 +652,7 @@ test_expect_success 'stdin fails with du
 	create $a $m
 	EOF
 	test_must_fail git update-ref --stdin <stdin 2>err &&
-	grep "fatal: multiple updates for ref '"'"'$a'"'"' not allowed." err
+	test_i18ngrep "fatal: multiple updates for ref '"'"'$a'"'"' not allowed" err
 '
 
 test_expect_success 'stdin create ref works' '
@@ -807,6 +809,37 @@ test_expect_success 'stdin delete symref
 	test_cmp expect actual
 '
 
+test_expect_success 'stdin update symref works flag --no-deref' '
+	git symbolic-ref TESTSYMREFONE $b &&
+	git symbolic-ref TESTSYMREFTWO $b &&
+	cat >stdin <<-EOF &&
+	update TESTSYMREFONE $a $b
+	update TESTSYMREFTWO $a $b
+	EOF
+	git update-ref --no-deref --stdin <stdin &&
+	git rev-parse TESTSYMREFONE TESTSYMREFTWO >expect &&
+	git rev-parse $a $a >actual &&
+	test_cmp expect actual &&
+	git rev-parse $m~1 >expect &&
+	git rev-parse $b >actual &&
+	test_cmp expect actual
+'
+
+test_expect_success 'stdin delete symref works flag --no-deref' '
+	git symbolic-ref TESTSYMREFONE $b &&
+	git symbolic-ref TESTSYMREFTWO $b &&
+	cat >stdin <<-EOF &&
+	delete TESTSYMREFONE $b
+	delete TESTSYMREFTWO $b
+	EOF
+	git update-ref --no-deref --stdin <stdin &&
+	test_must_fail git rev-parse --verify -q TESTSYMREFONE &&
+	test_must_fail git rev-parse --verify -q TESTSYMREFTWO &&
+	git rev-parse $m~1 >expect &&
+	git rev-parse $b >actual &&
+	test_cmp expect actual
+'
+
 test_expect_success 'stdin delete ref works with right old value' '
 	echo "delete $b $m~1" >stdin &&
 	git update-ref --stdin <stdin &&
@@ -1052,7 +1085,7 @@ test_expect_success 'stdin -z fails opti
 test_expect_success 'stdin -z fails with duplicate refs' '
 	printf $F "create $a" "$m" "create $b" "$m" "create $a" "$m" >stdin &&
 	test_must_fail git update-ref -z --stdin <stdin 2>err &&
-	grep "fatal: multiple updates for ref '"'"'$a'"'"' not allowed." err
+	test_i18ngrep "fatal: multiple updates for ref '"'"'$a'"'"' not allowed" err
 '
 
 test_expect_success 'stdin -z create ref works' '
@@ -1283,7 +1316,7 @@ test_expect_success 'fails with duplicat
 	update HEAD $B
 	EOF
 	test_must_fail git update-ref --stdin <stdin 2>err &&
-	grep "fatal: multiple updates for '\''HEAD'\'' (including one via its referent .refs/heads/target1.) are not allowed" err &&
+	test_i18ngrep "fatal: multiple updates for '\''HEAD'\'' (including one via its referent .refs/heads/target1.) are not allowed" err &&
 	echo "refs/heads/target1" >expect &&
 	git symbolic-ref HEAD >actual &&
 	test_cmp expect actual &&
@@ -1300,7 +1333,7 @@ test_expect_success 'fails with duplicat
 	update refs/heads/symref2 $B
 	EOF
 	test_must_fail git update-ref --stdin <stdin 2>err &&
-	grep "fatal: multiple updates for '\''refs/heads/target2'\'' (including one via symref .refs/heads/symref2.) are not allowed" err &&
+	test_i18ngrep "fatal: multiple updates for '\''refs/heads/target2'\'' (including one via symref .refs/heads/symref2.) are not allowed" err &&
 	echo "refs/heads/target2" >expect &&
 	git symbolic-ref refs/heads/symref2 >actual &&
 	test_cmp expect actual &&
diff -pruN 1.2.1+git2.18.0-1/git/t/t1403-show-ref.sh 1.2.3+git2.25.1-1/git/t/t1403-show-ref.sh
--- 1.2.1+git2.18.0-1/git/t/t1403-show-ref.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t1403-show-ref.sh	2020-02-17 04:47:35.000000000 +0000
@@ -26,26 +26,22 @@ test_expect_success 'show-ref' '
 	git show-ref refs/tags/A >actual &&
 	test_cmp expect actual &&
 
-	>expect &&
-
 	test_must_fail git show-ref D >actual &&
-	test_cmp expect actual
+	test_must_be_empty actual
 '
 
 test_expect_success 'show-ref -q' '
-	>expect &&
-
 	git show-ref -q A >actual &&
-	test_cmp expect actual &&
+	test_must_be_empty actual &&
 
 	git show-ref -q tags/A >actual &&
-	test_cmp expect actual &&
+	test_must_be_empty actual &&
 
 	git show-ref -q refs/tags/A >actual &&
-	test_cmp expect actual &&
+	test_must_be_empty actual &&
 
 	test_must_fail git show-ref -q D >actual &&
-	test_cmp expect actual
+	test_must_be_empty actual
 '
 
 test_expect_success 'show-ref --verify' '
@@ -54,32 +50,28 @@ test_expect_success 'show-ref --verify'
 	git show-ref --verify refs/tags/A >actual &&
 	test_cmp expect actual &&
 
-	>expect &&
-
 	test_must_fail git show-ref --verify A >actual &&
-	test_cmp expect actual &&
+	test_must_be_empty actual &&
 
 	test_must_fail git show-ref --verify tags/A >actual &&
-	test_cmp expect actual &&
+	test_must_be_empty actual &&
 
 	test_must_fail git show-ref --verify D >actual &&
-	test_cmp expect actual
+	test_must_be_empty actual
 '
 
 test_expect_success 'show-ref --verify -q' '
-	>expect &&
-
 	git show-ref --verify -q refs/tags/A >actual &&
-	test_cmp expect actual &&
+	test_must_be_empty actual &&
 
 	test_must_fail git show-ref --verify -q A >actual &&
-	test_cmp expect actual &&
+	test_must_be_empty actual &&
 
 	test_must_fail git show-ref --verify -q tags/A >actual &&
-	test_cmp expect actual &&
+	test_must_be_empty actual &&
 
 	test_must_fail git show-ref --verify -q D >actual &&
-	test_cmp expect actual
+	test_must_be_empty actual
 '
 
 test_expect_success 'show-ref -d' '
@@ -113,19 +105,17 @@ test_expect_success 'show-ref -d' '
 	git show-ref -d --verify refs/heads/master >actual &&
 	test_cmp expect actual &&
 
-	>expect &&
-
 	test_must_fail git show-ref -d --verify master >actual &&
-	test_cmp expect actual &&
+	test_must_be_empty actual &&
 
 	test_must_fail git show-ref -d --verify heads/master >actual &&
-	test_cmp expect actual &&
+	test_must_be_empty actual &&
 
 	test_must_fail git show-ref --verify -d A C >actual &&
-	test_cmp expect actual &&
+	test_must_be_empty actual &&
 
 	test_must_fail git show-ref --verify -d tags/A tags/C >actual &&
-	test_cmp expect actual
+	test_must_be_empty actual
 
 '
 
@@ -178,10 +168,8 @@ test_expect_success 'show-ref --verify H
 	git show-ref --verify HEAD >actual &&
 	test_cmp expect actual &&
 
-	>expect &&
-
 	git show-ref --verify -q HEAD >actual &&
-	test_cmp expect actual
+	test_must_be_empty actual
 '
 
 test_expect_success 'show-ref --verify with dangling ref' '
diff -pruN 1.2.1+git2.18.0-1/git/t/t1404-update-ref-errors.sh 1.2.3+git2.25.1-1/git/t/t1404-update-ref-errors.sh
--- 1.2.1+git2.18.0-1/git/t/t1404-update-ref-errors.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t1404-update-ref-errors.sh	2020-02-17 04:47:35.000000000 +0000
@@ -27,13 +27,11 @@ test_update_rejected () {
 	fi &&
 	printf "create $prefix/%s $C\n" $create >input &&
 	test_must_fail git update-ref --stdin <input 2>output.err &&
-	grep -F "$error" output.err &&
+	test_i18ngrep -F "$error" output.err &&
 	git for-each-ref $prefix >actual &&
 	test_cmp unchanged actual
 }
 
-Q="'"
-
 # Test adding and deleting D/F-conflicting references in a single
 # transaction.
 df_test() {
@@ -93,7 +91,7 @@ df_test() {
 		delname="$delref"
 	fi &&
 	cat >expected-err <<-EOF &&
-	fatal: cannot lock ref $Q$addname$Q: $Q$delref$Q exists; cannot create $Q$addref$Q
+	fatal: cannot lock ref $SQ$addname$SQ: $SQ$delref$SQ exists; cannot create $SQ$addref$SQ
 	EOF
 	$pack &&
 	if $add_del
@@ -103,7 +101,7 @@ df_test() {
 		printf "%s\n" "delete $delname" "create $addname $D"
 	fi >commands &&
 	test_must_fail git update-ref --stdin <commands 2>output.err &&
-	test_cmp expected-err output.err &&
+	test_i18ncmp expected-err output.err &&
 	printf "%s\n" "$C $delref" >expected-refs &&
 	git for-each-ref --format="%(objectname) %(refname)" $prefix/r >actual-refs &&
 	test_cmp expected-refs actual-refs
@@ -123,7 +121,7 @@ test_expect_success 'existing loose ref
 
 	prefix=refs/1l &&
 	test_update_rejected "a c e" false "b c/x d" \
-		"$Q$prefix/c$Q exists; cannot create $Q$prefix/c/x$Q"
+		"$SQ$prefix/c$SQ exists; cannot create $SQ$prefix/c/x$SQ"
 
 '
 
@@ -131,7 +129,7 @@ test_expect_success 'existing packed ref
 
 	prefix=refs/1p &&
 	test_update_rejected "a c e" true "b c/x d" \
-		"$Q$prefix/c$Q exists; cannot create $Q$prefix/c/x$Q"
+		"$SQ$prefix/c$SQ exists; cannot create $SQ$prefix/c/x$SQ"
 
 '
 
@@ -139,7 +137,7 @@ test_expect_success 'existing loose ref
 
 	prefix=refs/2l &&
 	test_update_rejected "a c e" false "b c/x/y d" \
-		"$Q$prefix/c$Q exists; cannot create $Q$prefix/c/x/y$Q"
+		"$SQ$prefix/c$SQ exists; cannot create $SQ$prefix/c/x/y$SQ"
 
 '
 
@@ -147,7 +145,7 @@ test_expect_success 'existing packed ref
 
 	prefix=refs/2p &&
 	test_update_rejected "a c e" true "b c/x/y d" \
-		"$Q$prefix/c$Q exists; cannot create $Q$prefix/c/x/y$Q"
+		"$SQ$prefix/c$SQ exists; cannot create $SQ$prefix/c/x/y$SQ"
 
 '
 
@@ -155,7 +153,7 @@ test_expect_success 'new ref is a simple
 
 	prefix=refs/3l &&
 	test_update_rejected "a c/x e" false "b c d" \
-		"$Q$prefix/c/x$Q exists; cannot create $Q$prefix/c$Q"
+		"$SQ$prefix/c/x$SQ exists; cannot create $SQ$prefix/c$SQ"
 
 '
 
@@ -163,7 +161,7 @@ test_expect_success 'new ref is a simple
 
 	prefix=refs/3p &&
 	test_update_rejected "a c/x e" true "b c d" \
-		"$Q$prefix/c/x$Q exists; cannot create $Q$prefix/c$Q"
+		"$SQ$prefix/c/x$SQ exists; cannot create $SQ$prefix/c$SQ"
 
 '
 
@@ -171,7 +169,7 @@ test_expect_success 'new ref is a deeper
 
 	prefix=refs/4l &&
 	test_update_rejected "a c/x/y e" false "b c d" \
-		"$Q$prefix/c/x/y$Q exists; cannot create $Q$prefix/c$Q"
+		"$SQ$prefix/c/x/y$SQ exists; cannot create $SQ$prefix/c$SQ"
 
 '
 
@@ -179,7 +177,7 @@ test_expect_success 'new ref is a deeper
 
 	prefix=refs/4p &&
 	test_update_rejected "a c/x/y e" true "b c d" \
-		"$Q$prefix/c/x/y$Q exists; cannot create $Q$prefix/c$Q"
+		"$SQ$prefix/c/x/y$SQ exists; cannot create $SQ$prefix/c$SQ"
 
 '
 
@@ -187,7 +185,7 @@ test_expect_success 'one new ref is a si
 
 	prefix=refs/5 &&
 	test_update_rejected "a e" false "b c c/x d" \
-		"cannot process $Q$prefix/c$Q and $Q$prefix/c/x$Q at the same time"
+		"cannot process $SQ$prefix/c$SQ and $SQ$prefix/c/x$SQ at the same time"
 
 '
 
@@ -334,7 +332,7 @@ test_expect_success 'D/F conflict preven
 test_expect_success 'missing old value blocks update' '
 	prefix=refs/missing-update &&
 	cat >expected <<-EOF &&
-	fatal: cannot lock ref $Q$prefix/foo$Q: unable to resolve reference $Q$prefix/foo$Q
+	fatal: cannot lock ref $SQ$prefix/foo$SQ: unable to resolve reference $SQ$prefix/foo$SQ
 	EOF
 	printf "%s\n" "update $prefix/foo $E $D" |
 	test_must_fail git update-ref --stdin 2>output.err &&
@@ -345,7 +343,7 @@ test_expect_success 'incorrect old value
 	prefix=refs/incorrect-update &&
 	git update-ref $prefix/foo $C &&
 	cat >expected <<-EOF &&
-	fatal: cannot lock ref $Q$prefix/foo$Q: is at $C but expected $D
+	fatal: cannot lock ref $SQ$prefix/foo$SQ: is at $C but expected $D
 	EOF
 	printf "%s\n" "update $prefix/foo $E $D" |
 	test_must_fail git update-ref --stdin 2>output.err &&
@@ -356,7 +354,7 @@ test_expect_success 'existing old value
 	prefix=refs/existing-create &&
 	git update-ref $prefix/foo $C &&
 	cat >expected <<-EOF &&
-	fatal: cannot lock ref $Q$prefix/foo$Q: reference already exists
+	fatal: cannot lock ref $SQ$prefix/foo$SQ: reference already exists
 	EOF
 	printf "%s\n" "create $prefix/foo $E" |
 	test_must_fail git update-ref --stdin 2>output.err &&
@@ -367,7 +365,7 @@ test_expect_success 'incorrect old value
 	prefix=refs/incorrect-delete &&
 	git update-ref $prefix/foo $C &&
 	cat >expected <<-EOF &&
-	fatal: cannot lock ref $Q$prefix/foo$Q: is at $C but expected $D
+	fatal: cannot lock ref $SQ$prefix/foo$SQ: is at $C but expected $D
 	EOF
 	printf "%s\n" "delete $prefix/foo $D" |
 	test_must_fail git update-ref --stdin 2>output.err &&
@@ -378,7 +376,7 @@ test_expect_success 'missing old value b
 	prefix=refs/missing-indirect-update &&
 	git symbolic-ref $prefix/symref $prefix/foo &&
 	cat >expected <<-EOF &&
-	fatal: cannot lock ref $Q$prefix/symref$Q: unable to resolve reference $Q$prefix/foo$Q
+	fatal: cannot lock ref $SQ$prefix/symref$SQ: unable to resolve reference $SQ$prefix/foo$SQ
 	EOF
 	printf "%s\n" "update $prefix/symref $E $D" |
 	test_must_fail git update-ref --stdin 2>output.err &&
@@ -390,7 +388,7 @@ test_expect_success 'incorrect old value
 	git symbolic-ref $prefix/symref $prefix/foo &&
 	git update-ref $prefix/foo $C &&
 	cat >expected <<-EOF &&
-	fatal: cannot lock ref $Q$prefix/symref$Q: is at $C but expected $D
+	fatal: cannot lock ref $SQ$prefix/symref$SQ: is at $C but expected $D
 	EOF
 	printf "%s\n" "update $prefix/symref $E $D" |
 	test_must_fail git update-ref --stdin 2>output.err &&
@@ -402,7 +400,7 @@ test_expect_success 'existing old value
 	git symbolic-ref $prefix/symref $prefix/foo &&
 	git update-ref $prefix/foo $C &&
 	cat >expected <<-EOF &&
-	fatal: cannot lock ref $Q$prefix/symref$Q: reference already exists
+	fatal: cannot lock ref $SQ$prefix/symref$SQ: reference already exists
 	EOF
 	printf "%s\n" "create $prefix/symref $E" |
 	test_must_fail git update-ref --stdin 2>output.err &&
@@ -414,7 +412,7 @@ test_expect_success 'incorrect old value
 	git symbolic-ref $prefix/symref $prefix/foo &&
 	git update-ref $prefix/foo $C &&
 	cat >expected <<-EOF &&
-	fatal: cannot lock ref $Q$prefix/symref$Q: is at $C but expected $D
+	fatal: cannot lock ref $SQ$prefix/symref$SQ: is at $C but expected $D
 	EOF
 	printf "%s\n" "delete $prefix/symref $D" |
 	test_must_fail git update-ref --stdin 2>output.err &&
@@ -425,7 +423,7 @@ test_expect_success 'missing old value b
 	prefix=refs/missing-noderef-update &&
 	git symbolic-ref $prefix/symref $prefix/foo &&
 	cat >expected <<-EOF &&
-	fatal: cannot lock ref $Q$prefix/symref$Q: reference is missing but expected $D
+	fatal: cannot lock ref $SQ$prefix/symref$SQ: reference is missing but expected $D
 	EOF
 	printf "%s\n" "option no-deref" "update $prefix/symref $E $D" |
 	test_must_fail git update-ref --stdin 2>output.err &&
@@ -437,7 +435,7 @@ test_expect_success 'incorrect old value
 	git symbolic-ref $prefix/symref $prefix/foo &&
 	git update-ref $prefix/foo $C &&
 	cat >expected <<-EOF &&
-	fatal: cannot lock ref $Q$prefix/symref$Q: is at $C but expected $D
+	fatal: cannot lock ref $SQ$prefix/symref$SQ: is at $C but expected $D
 	EOF
 	printf "%s\n" "option no-deref" "update $prefix/symref $E $D" |
 	test_must_fail git update-ref --stdin 2>output.err &&
@@ -449,7 +447,7 @@ test_expect_success 'existing old value
 	git symbolic-ref $prefix/symref $prefix/foo &&
 	git update-ref $prefix/foo $C &&
 	cat >expected <<-EOF &&
-	fatal: cannot lock ref $Q$prefix/symref$Q: reference already exists
+	fatal: cannot lock ref $SQ$prefix/symref$SQ: reference already exists
 	EOF
 	printf "%s\n" "option no-deref" "create $prefix/symref $E" |
 	test_must_fail git update-ref --stdin 2>output.err &&
@@ -461,7 +459,7 @@ test_expect_success 'incorrect old value
 	git symbolic-ref $prefix/symref $prefix/foo &&
 	git update-ref $prefix/foo $C &&
 	cat >expected <<-EOF &&
-	fatal: cannot lock ref $Q$prefix/symref$Q: is at $C but expected $D
+	fatal: cannot lock ref $SQ$prefix/symref$SQ: is at $C but expected $D
 	EOF
 	printf "%s\n" "option no-deref" "delete $prefix/symref $D" |
 	test_must_fail git update-ref --stdin 2>output.err &&
@@ -474,13 +472,13 @@ test_expect_success 'non-empty directory
 	: >.git/$prefix/foo/bar/baz.lock &&
 	test_when_finished "rm -f .git/$prefix/foo/bar/baz.lock" &&
 	cat >expected <<-EOF &&
-	fatal: cannot lock ref $Q$prefix/foo$Q: there is a non-empty directory $Q.git/$prefix/foo$Q blocking reference $Q$prefix/foo$Q
+	fatal: cannot lock ref $SQ$prefix/foo$SQ: there is a non-empty directory $SQ.git/$prefix/foo$SQ blocking reference $SQ$prefix/foo$SQ
 	EOF
 	printf "%s\n" "update $prefix/foo $C" |
 	test_must_fail git update-ref --stdin 2>output.err &&
 	test_cmp expected output.err &&
 	cat >expected <<-EOF &&
-	fatal: cannot lock ref $Q$prefix/foo$Q: unable to resolve reference $Q$prefix/foo$Q
+	fatal: cannot lock ref $SQ$prefix/foo$SQ: unable to resolve reference $SQ$prefix/foo$SQ
 	EOF
 	printf "%s\n" "update $prefix/foo $D $C" |
 	test_must_fail git update-ref --stdin 2>output.err &&
@@ -493,13 +491,13 @@ test_expect_success 'broken reference bl
 	echo "gobbledigook" >.git/$prefix/foo &&
 	test_when_finished "rm -f .git/$prefix/foo" &&
 	cat >expected <<-EOF &&
-	fatal: cannot lock ref $Q$prefix/foo$Q: unable to resolve reference $Q$prefix/foo$Q: reference broken
+	fatal: cannot lock ref $SQ$prefix/foo$SQ: unable to resolve reference $SQ$prefix/foo$SQ: reference broken
 	EOF
 	printf "%s\n" "update $prefix/foo $C" |
 	test_must_fail git update-ref --stdin 2>output.err &&
 	test_cmp expected output.err &&
 	cat >expected <<-EOF &&
-	fatal: cannot lock ref $Q$prefix/foo$Q: unable to resolve reference $Q$prefix/foo$Q: reference broken
+	fatal: cannot lock ref $SQ$prefix/foo$SQ: unable to resolve reference $SQ$prefix/foo$SQ: reference broken
 	EOF
 	printf "%s\n" "update $prefix/foo $D $C" |
 	test_must_fail git update-ref --stdin 2>output.err &&
@@ -513,13 +511,13 @@ test_expect_success 'non-empty directory
 	: >.git/$prefix/foo/bar/baz.lock &&
 	test_when_finished "rm -f .git/$prefix/foo/bar/baz.lock" &&
 	cat >expected <<-EOF &&
-	fatal: cannot lock ref $Q$prefix/symref$Q: there is a non-empty directory $Q.git/$prefix/foo$Q blocking reference $Q$prefix/foo$Q
+	fatal: cannot lock ref $SQ$prefix/symref$SQ: there is a non-empty directory $SQ.git/$prefix/foo$SQ blocking reference $SQ$prefix/foo$SQ
 	EOF
 	printf "%s\n" "update $prefix/symref $C" |
 	test_must_fail git update-ref --stdin 2>output.err &&
 	test_cmp expected output.err &&
 	cat >expected <<-EOF &&
-	fatal: cannot lock ref $Q$prefix/symref$Q: unable to resolve reference $Q$prefix/foo$Q
+	fatal: cannot lock ref $SQ$prefix/symref$SQ: unable to resolve reference $SQ$prefix/foo$SQ
 	EOF
 	printf "%s\n" "update $prefix/symref $D $C" |
 	test_must_fail git update-ref --stdin 2>output.err &&
@@ -532,13 +530,13 @@ test_expect_success 'broken reference bl
 	echo "gobbledigook" >.git/$prefix/foo &&
 	test_when_finished "rm -f .git/$prefix/foo" &&
 	cat >expected <<-EOF &&
-	fatal: cannot lock ref $Q$prefix/symref$Q: unable to resolve reference $Q$prefix/foo$Q: reference broken
+	fatal: cannot lock ref $SQ$prefix/symref$SQ: unable to resolve reference $SQ$prefix/foo$SQ: reference broken
 	EOF
 	printf "%s\n" "update $prefix/symref $C" |
 	test_must_fail git update-ref --stdin 2>output.err &&
 	test_cmp expected output.err &&
 	cat >expected <<-EOF &&
-	fatal: cannot lock ref $Q$prefix/symref$Q: unable to resolve reference $Q$prefix/foo$Q: reference broken
+	fatal: cannot lock ref $SQ$prefix/symref$SQ: unable to resolve reference $SQ$prefix/foo$SQ: reference broken
 	EOF
 	printf "%s\n" "update $prefix/symref $D $C" |
 	test_must_fail git update-ref --stdin 2>output.err &&
@@ -559,9 +557,9 @@ test_expect_success 'no bogus intermedia
 	{
 		# Note: the following command is intentionally run in the
 		# background. We increase the timeout so that `update-ref`
-		# attempts to acquire the `packed-refs` lock for longer than
-		# it takes for us to do the check then delete it:
-		git -c core.packedrefstimeout=3000 update-ref -d $prefix/foo &
+		# attempts to acquire the `packed-refs` lock for much longer
+		# than it takes for us to do the check then delete it:
+		git -c core.packedrefstimeout=30000 update-ref -d $prefix/foo &
 	} &&
 	pid2=$! &&
 	# Give update-ref plenty of time to get to the point where it tries
@@ -614,7 +612,23 @@ test_expect_success 'delete fails cleanl
 	test_when_finished "rm -f .git/packed-refs.lock" &&
 	test_must_fail git update-ref -d $prefix/foo >out 2>err &&
 	git for-each-ref $prefix >actual &&
-	test_i18ngrep "Unable to create $Q.*packed-refs.lock$Q: File exists" err &&
+	test_i18ngrep "Unable to create $SQ.*packed-refs.lock$SQ: " err &&
+	test_cmp unchanged actual
+'
+
+test_expect_success 'delete fails cleanly if packed-refs.new write fails' '
+	# Setup and expectations are similar to the test above.
+	prefix=refs/failed-packed-refs &&
+	git update-ref $prefix/foo $C &&
+	git pack-refs --all &&
+	git update-ref $prefix/foo $D &&
+	git for-each-ref $prefix >unchanged &&
+	# This should not happen in practice, but it is an easy way to get a
+	# reliable error (we open with create_tempfile(), which uses O_EXCL).
+	: >.git/packed-refs.new &&
+	test_when_finished "rm -f .git/packed-refs.new" &&
+	test_must_fail git update-ref -d $prefix/foo &&
+	git for-each-ref $prefix >actual &&
 	test_cmp unchanged actual
 '
 
diff -pruN 1.2.1+git2.18.0-1/git/t/t1405-main-ref-store.sh 1.2.3+git2.25.1-1/git/t/t1405-main-ref-store.sh
--- 1.2.1+git2.18.0-1/git/t/t1405-main-ref-store.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t1405-main-ref-store.sh	2020-02-17 04:47:35.000000000 +0000
@@ -54,7 +54,7 @@ test_expect_success 'for_each_ref(refs/h
 '
 
 test_expect_success 'for_each_ref() is sorted' '
-	$RUN for-each-ref refs/heads/ | cut -c 42- >actual &&
+	$RUN for-each-ref refs/heads/ | cut -d" " -f 2- >actual &&
 	sort actual > expected &&
 	test_cmp expected actual
 '
@@ -71,7 +71,7 @@ test_expect_success 'verify_ref(new-mast
 '
 
 test_expect_success 'for_each_reflog()' '
-	$RUN for-each-reflog | sort -k2 | cut -c 42- >actual &&
+	$RUN for-each-reflog | sort -k2 | cut -d" " -f 2- >actual &&
 	cat >expected <<-\EOF &&
 	HEAD 0x1
 	refs/heads/master 0x0
diff -pruN 1.2.1+git2.18.0-1/git/t/t1406-submodule-ref-store.sh 1.2.3+git2.25.1-1/git/t/t1406-submodule-ref-store.sh
--- 1.2.1+git2.18.0-1/git/t/t1406-submodule-ref-store.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t1406-submodule-ref-store.sh	2020-02-17 04:47:35.000000000 +0000
@@ -39,7 +39,7 @@ test_expect_success 'rename_refs() not a
 '
 
 test_expect_success 'for_each_ref(refs/heads/)' '
-	$RUN for-each-ref refs/heads/ | cut -c 42- >actual &&
+	$RUN for-each-ref refs/heads/ | cut -d" " -f 2- >actual &&
 	cat >expected <<-\EOF &&
 	master 0x0
 	new-master 0x0
@@ -48,7 +48,7 @@ test_expect_success 'for_each_ref(refs/h
 '
 
 test_expect_success 'for_each_ref() is sorted' '
-	$RUN for-each-ref refs/heads/ | cut -c 42- >actual &&
+	$RUN for-each-ref refs/heads/ | cut -d" " -f 2- >actual &&
 	sort actual > expected &&
 	test_cmp expected actual
 '
@@ -65,7 +65,7 @@ test_expect_success 'verify_ref(new-mast
 '
 
 test_expect_success 'for_each_reflog()' '
-	$RUN for-each-reflog | sort | cut -c 42- >actual &&
+	$RUN for-each-reflog | sort | cut -d" " -f 2- >actual &&
 	cat >expected <<-\EOF &&
 	HEAD 0x1
 	refs/heads/master 0x0
diff -pruN 1.2.1+git2.18.0-1/git/t/t1407-worktree-ref-store.sh 1.2.3+git2.25.1-1/git/t/t1407-worktree-ref-store.sh
--- 1.2.1+git2.18.0-1/git/t/t1407-worktree-ref-store.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t1407-worktree-ref-store.sh	2020-02-17 04:47:35.000000000 +0000
@@ -58,7 +58,7 @@ test_expect_success 'for_each_reflog()'
 	mkdir -p     .git/worktrees/wt/logs/refs/bisect &&
 	echo $ZERO_OID > .git/worktrees/wt/logs/refs/bisect/wt-random &&
 
-	$RWT for-each-reflog | cut -c 42- | sort >actual &&
+	$RWT for-each-reflog | cut -d" " -f 2- | sort >actual &&
 	cat >expected <<-\EOF &&
 	HEAD 0x1
 	PSEUDO-WT 0x0
@@ -68,7 +68,7 @@ test_expect_success 'for_each_reflog()'
 	EOF
 	test_cmp expected actual &&
 
-	$RMAIN for-each-reflog | cut -c 42- | sort >actual &&
+	$RMAIN for-each-reflog | cut -d" " -f 2- | sort >actual &&
 	cat >expected <<-\EOF &&
 	HEAD 0x1
 	PSEUDO-MAIN 0x0
diff -pruN 1.2.1+git2.18.0-1/git/t/t1410-reflog.sh 1.2.3+git2.25.1-1/git/t/t1410-reflog.sh
--- 1.2.1+git2.18.0-1/git/t/t1410-reflog.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t1410-reflog.sh	2020-02-17 04:47:35.000000000 +0000
@@ -20,24 +20,23 @@ check_have () {
 }
 
 check_fsck () {
-	output=$(git fsck --full)
+	git fsck --full >fsck.output
 	case "$1" in
 	'')
-		test -z "$output" ;;
+		test_must_be_empty fsck.output ;;
 	*)
-		echo "$output" | grep "$1" ;;
+		test_i18ngrep "$1" fsck.output ;;
 	esac
 }
 
 corrupt () {
-	aa=${1%??????????????????????????????????????} zz=${1#??}
-	mv .git/objects/$aa/$zz .git/$aa$zz
+	mv .git/objects/$(test_oid_to_path $1) .git/$1
 }
 
 recover () {
-	aa=${1%??????????????????????????????????????} zz=${1#??}
+	aa=$(echo $1 | cut -c 1-2)
 	mkdir -p .git/objects/$aa
-	mv .git/$aa$zz .git/objects/$aa/$zz
+	mv .git/$1 .git/objects/$(test_oid_to_path $1)
 }
 
 check_dont_have () {
@@ -55,6 +54,7 @@ check_dont_have () {
 }
 
 test_expect_success setup '
+	test_oid_init &&
 	mkdir -p A/B &&
 	echo rat >C &&
 	echo ox >A/D &&
@@ -195,7 +195,7 @@ test_expect_success 'delete' '
 
 	git reflog delete master@{1} &&
 	git reflog show master > output &&
-	test $(($master_entry_count - 1)) = $(wc -l < output) &&
+	test_line_count = $(($master_entry_count - 1)) output &&
 	test $HEAD_entry_count = $(git reflog | wc -l) &&
 	! grep ox < output &&
 
@@ -209,7 +209,7 @@ test_expect_success 'delete' '
 
 	git reflog delete master@{07.04.2005.15:15:00.-0700} &&
 	git reflog show master > output &&
-	test $(($master_entry_count - 1)) = $(wc -l < output) &&
+	test_line_count = $(($master_entry_count - 1)) output &&
 	! grep dragon < output
 
 '
@@ -232,25 +232,34 @@ test_expect_success '--expire=never' '
 '
 
 test_expect_success 'gc.reflogexpire=never' '
+	test_config gc.reflogexpire never &&
+	test_config gc.reflogexpireunreachable never &&
+
+	git reflog expire --verbose --all >output &&
+	test_line_count = 9 output &&
 
-	git config gc.reflogexpire never &&
-	git config gc.reflogexpireunreachable never &&
-	git reflog expire --verbose --all &&
 	git reflog refs/heads/master >output &&
 	test_line_count = 4 output
 '
 
 test_expect_success 'gc.reflogexpire=false' '
+	test_config gc.reflogexpire false &&
+	test_config gc.reflogexpireunreachable false &&
 
-	git config gc.reflogexpire false &&
-	git config gc.reflogexpireunreachable false &&
 	git reflog expire --verbose --all &&
 	git reflog refs/heads/master >output &&
-	test_line_count = 4 output &&
+	test_line_count = 4 output
 
-	git config --unset gc.reflogexpire &&
-	git config --unset gc.reflogexpireunreachable
+'
 
+test_expect_success 'git reflog expire unknown reference' '
+	test_config gc.reflogexpire never &&
+	test_config gc.reflogexpireunreachable never &&
+
+	test_must_fail git reflog expire master@{123} 2>stderr &&
+	test_i18ngrep "points nowhere" stderr &&
+	test_must_fail git reflog expire does-not-exist 2>stderr &&
+	test_i18ngrep "points nowhere" stderr
 '
 
 test_expect_success 'checkout should not delete log for packed ref' '
@@ -290,9 +299,8 @@ test_expect_success 'stale dirs do not c
 	# same as before, but we only create a reflog for "one" if
 	# it already exists, which it does not
 	git -c core.logallrefupdates=false branch one master &&
-	: >expect &&
 	git log -g --format="%gd %gs" one >actual &&
-	test_cmp expect actual
+	test_must_be_empty actual
 '
 
 # Triggering the bug detected by this test requires a newline to fall
@@ -305,12 +313,12 @@ test_expect_success 'stale dirs do not c
 # Each line is 114 characters, so we need 75 to still have a few before the
 # last 8K. The 89-character padding on the final entry lines up our
 # newline exactly.
-test_expect_success 'parsing reverse reflogs at BUFSIZ boundaries' '
+test_expect_success SHA1 'parsing reverse reflogs at BUFSIZ boundaries' '
 	git checkout -b reflogskip &&
-	z38=00000000000000000000000000000000000000 &&
+	zf=$(test_oid zero_2) &&
 	ident="abc <xyz> 0000000001 +0000" &&
 	for i in $(test_seq 1 75); do
-		printf "$z38%02d $z38%02d %s\t" $i $(($i+1)) "$ident" &&
+		printf "$zf%02d $zf%02d %s\t" $i $(($i+1)) "$ident" &&
 		if test $i = 75; then
 			for j in $(test_seq 1 89); do
 				printf X
@@ -321,7 +329,7 @@ test_expect_success 'parsing reverse ref
 		printf "\n"
 	done >.git/logs/refs/heads/reflogskip &&
 	git rev-parse reflogskip@{73} >actual &&
-	echo ${z38}03 >expect &&
+	echo ${zf}03 >expect &&
 	test_cmp expect actual
 '
 
@@ -339,8 +347,8 @@ test_expect_failure 'reflog with non-com
 '
 
 test_expect_success 'reflog expire operates on symref not referrent' '
-	git branch -l the_symref &&
-	git branch -l referrent &&
+	git branch --create-reflog the_symref &&
+	git branch --create-reflog referrent &&
 	git update-ref referrent HEAD &&
 	git symbolic-ref refs/heads/the_symref refs/heads/referrent &&
 	test_when_finished "rm -f .git/refs/heads/referrent.lock" &&
@@ -369,4 +377,19 @@ test_expect_success 'continue walking pa
 	)
 '
 
+test_expect_success 'expire with multiple worktrees' '
+	git init main-wt &&
+	(
+		cd main-wt &&
+		test_tick &&
+		test_commit foo &&
+		git  worktree add link-wt &&
+		test_tick &&
+		test_commit -C link-wt foobar &&
+		test_tick &&
+		git reflog expire --verbose --all --expire=$test_tick &&
+		test_must_be_empty .git/worktrees/link-wt/logs/HEAD
+	)
+'
+
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t1411-reflog-show.sh 1.2.3+git2.25.1-1/git/t/t1411-reflog-show.sh
--- 1.2.1+git2.18.0-1/git/t/t1411-reflog-show.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t1411-reflog-show.sh	2020-02-17 04:47:35.000000000 +0000
@@ -136,13 +136,12 @@ test_expect_success '--date magic does n
 	test_cmp expect actual
 '
 
-: >expect
 test_expect_success 'empty reflog file' '
 	git branch empty &&
 	git reflog expire --expire=all refs/heads/empty &&
 
 	git log -g empty >actual &&
-	test_cmp expect actual
+	test_must_be_empty actual
 '
 
 # This guards against the alternative of showing the diffs vs. the
@@ -159,9 +158,9 @@ test_expect_success 'git log -g -p shows
 	git log -1 -p HEAD^ >log.one &&
 	git log -1 -p HEAD >log.two &&
 	(
-		cat log.one; echo
-		cat log.two; echo
-		cat log.one; echo
+		cat log.one && echo &&
+		cat log.two && echo &&
+		cat log.one && echo &&
 		cat log.two
 	) >expect &&
 	test_cmp expect actual
diff -pruN 1.2.1+git2.18.0-1/git/t/t1414-reflog-walk.sh 1.2.3+git2.25.1-1/git/t/t1414-reflog-walk.sh
--- 1.2.1+git2.18.0-1/git/t/t1414-reflog-walk.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t1414-reflog-walk.sh	2020-02-17 04:47:35.000000000 +0000
@@ -18,10 +18,9 @@ do_walk () {
 	git log -g --format="%gd %gs" "$@"
 }
 
-sq="'"
 test_expect_success 'set up expected reflog' '
 	cat >expect.all <<-EOF
-	HEAD@{0} commit (merge): Merge branch ${sq}master${sq} into side
+	HEAD@{0} commit (merge): Merge branch ${SQ}master${SQ} into side
 	HEAD@{1} commit: three
 	HEAD@{2} checkout: moving from master to side
 	HEAD@{3} commit: two
diff -pruN 1.2.1+git2.18.0-1/git/t/t1415-worktree-refs.sh 1.2.3+git2.25.1-1/git/t/t1415-worktree-refs.sh
--- 1.2.1+git2.18.0-1/git/t/t1415-worktree-refs.sh	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t1415-worktree-refs.sh	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,114 @@
+#!/bin/sh
+
+test_description='per-worktree refs'
+
+. ./test-lib.sh
+
+test_expect_success 'setup' '
+	test_commit initial &&
+	test_commit wt1 &&
+	test_commit wt2 &&
+	git worktree add wt1 wt1 &&
+	git worktree add wt2 wt2 &&
+	git checkout initial &&
+	git update-ref refs/worktree/foo HEAD &&
+	git -C wt1 update-ref refs/worktree/foo HEAD &&
+	git -C wt2 update-ref refs/worktree/foo HEAD
+'
+
+test_expect_success 'refs/worktree must not be packed' '
+	git pack-refs --all &&
+	test_path_is_missing .git/refs/tags/wt1 &&
+	test_path_is_file .git/refs/worktree/foo &&
+	test_path_is_file .git/worktrees/wt1/refs/worktree/foo &&
+	test_path_is_file .git/worktrees/wt2/refs/worktree/foo
+'
+
+test_expect_success 'refs/worktree are per-worktree' '
+	test_cmp_rev worktree/foo initial &&
+	( cd wt1 && test_cmp_rev worktree/foo wt1 ) &&
+	( cd wt2 && test_cmp_rev worktree/foo wt2 )
+'
+
+test_expect_success 'resolve main-worktree/HEAD' '
+	test_cmp_rev main-worktree/HEAD initial &&
+	( cd wt1 && test_cmp_rev main-worktree/HEAD initial ) &&
+	( cd wt2 && test_cmp_rev main-worktree/HEAD initial )
+'
+
+test_expect_success 'ambiguous main-worktree/HEAD' '
+	mkdir -p .git/refs/heads/main-worktree &&
+	test_when_finished rm -f .git/refs/heads/main-worktree/HEAD &&
+	cp .git/HEAD .git/refs/heads/main-worktree/HEAD &&
+	git rev-parse main-worktree/HEAD 2>warn &&
+	grep "main-worktree/HEAD.*ambiguous" warn
+'
+
+test_expect_success 'resolve worktrees/xx/HEAD' '
+	test_cmp_rev worktrees/wt1/HEAD wt1 &&
+	( cd wt1 && test_cmp_rev worktrees/wt1/HEAD wt1 ) &&
+	( cd wt2 && test_cmp_rev worktrees/wt1/HEAD wt1 )
+'
+
+test_expect_success 'ambiguous worktrees/xx/HEAD' '
+	mkdir -p .git/refs/heads/worktrees/wt1 &&
+	test_when_finished rm -f .git/refs/heads/worktrees/wt1/HEAD &&
+	cp .git/HEAD .git/refs/heads/worktrees/wt1/HEAD &&
+	git rev-parse worktrees/wt1/HEAD 2>warn &&
+	grep "worktrees/wt1/HEAD.*ambiguous" warn
+'
+
+test_expect_success 'reflog of main-worktree/HEAD' '
+	git reflog HEAD | sed "s/HEAD/main-worktree\/HEAD/" >expected &&
+	git reflog main-worktree/HEAD >actual &&
+	test_cmp expected actual &&
+	git -C wt1 reflog main-worktree/HEAD >actual.wt1 &&
+	test_cmp expected actual.wt1
+'
+
+test_expect_success 'reflog of worktrees/xx/HEAD' '
+	git -C wt2 reflog HEAD | sed "s/HEAD/worktrees\/wt2\/HEAD/" >expected &&
+	git reflog worktrees/wt2/HEAD >actual &&
+	test_cmp expected actual &&
+	git -C wt1 reflog worktrees/wt2/HEAD >actual.wt1 &&
+	test_cmp expected actual.wt1 &&
+	git -C wt2 reflog worktrees/wt2/HEAD >actual.wt2 &&
+	test_cmp expected actual.wt2
+'
+
+test_expect_success 'for-each-ref from main repo' '
+	mkdir fer1 &&
+	git -C fer1 init repo &&
+	test_commit -C fer1/repo initial &&
+	git -C fer1/repo worktree add ../second &&
+	git -C fer1/repo update-ref refs/bisect/main HEAD &&
+	git -C fer1/repo update-ref refs/rewritten/main HEAD &&
+	git -C fer1/repo update-ref refs/worktree/main HEAD &&
+	git -C fer1/repo for-each-ref --format="%(refname)" | grep main >actual &&
+	cat >expected <<-\EOF &&
+	refs/bisect/main
+	refs/rewritten/main
+	refs/worktree/main
+	EOF
+	test_cmp expected actual
+'
+
+test_expect_success 'for-each-ref from linked repo' '
+	mkdir fer2 &&
+	git -C fer2 init repo &&
+	test_commit -C fer2/repo initial &&
+	git -C fer2/repo worktree add ../second &&
+	git -C fer2/second update-ref refs/bisect/second HEAD &&
+	git -C fer2/second update-ref refs/rewritten/second HEAD &&
+	git -C fer2/second update-ref refs/worktree/second HEAD &&
+	git -C fer2/second for-each-ref --format="%(refname)" | grep second >actual &&
+	cat >expected <<-\EOF &&
+	refs/bisect/second
+	refs/heads/second
+	refs/rewritten/second
+	refs/worktree/second
+	EOF
+	test_cmp expected actual
+'
+
+test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t1450-fsck.sh 1.2.3+git2.25.1-1/git/t/t1450-fsck.sh
--- 1.2.1+git2.18.0-1/git/t/t1450-fsck.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t1450-fsck.sh	2020-02-17 04:47:35.000000000 +0000
@@ -9,6 +9,7 @@ test_description='git fsck random collec
 . ./test-lib.sh
 
 test_expect_success setup '
+	test_oid_init &&
 	git config gc.auto 0 &&
 	git config i18n.commitencoding ISO-8859-1 &&
 	test_commit A fileA one &&
@@ -16,8 +17,7 @@ test_expect_success setup '
 	git checkout HEAD^0 &&
 	test_commit B fileB two &&
 	git tag -d A B &&
-	git reflog expire --expire=now --all &&
-	>empty
+	git reflog expire --expire=now --all
 '
 
 test_expect_success 'loose objects borrowed from alternate are not missing' '
@@ -29,12 +29,12 @@ test_expect_success 'loose objects borro
 		test_commit C fileC one &&
 		git fsck --no-dangling >../actual 2>&1
 	) &&
-	test_cmp empty actual
+	test_must_be_empty actual
 '
 
 test_expect_success 'HEAD is part of refs, valid objects appear valid' '
 	git fsck >actual 2>&1 &&
-	test_cmp empty actual
+	test_must_be_empty actual
 '
 
 # Corruption tests follow.  Make sure to remove all traces of the
@@ -55,8 +55,8 @@ test_expect_success 'setup: helpers for
 
 test_expect_success 'object with bad sha1' '
 	sha=$(echo blob | git hash-object -w --stdin) &&
-	old=$(echo $sha | sed "s+^..+&/+") &&
-	new=$(dirname $old)/ffffffffffffffffffffffffffffffffffffff &&
+	old=$(test_oid_to_path "$sha") &&
+	new=$(dirname $old)/$(test_oid ff_2) &&
 	sha="$(dirname $new)$(basename $new)" &&
 	mv .git/objects/$old .git/objects/$new &&
 	test_when_finished "remove_object $sha" &&
@@ -70,26 +70,23 @@ test_expect_success 'object with bad sha
 	test_when_finished "git update-ref -d refs/heads/bogus" &&
 
 	test_must_fail git fsck 2>out &&
-	cat out &&
-	grep "$sha.*corrupt" out
+	test_i18ngrep "$sha.*corrupt" out
 '
 
 test_expect_success 'branch pointing to non-commit' '
 	git rev-parse HEAD^{tree} >.git/refs/heads/invalid &&
 	test_when_finished "git update-ref -d refs/heads/invalid" &&
 	test_must_fail git fsck 2>out &&
-	cat out &&
-	grep "not a commit" out
+	test_i18ngrep "not a commit" out
 '
 
 test_expect_success 'HEAD link pointing at a funny object' '
 	test_when_finished "mv .git/SAVED_HEAD .git/HEAD" &&
 	mv .git/HEAD .git/SAVED_HEAD &&
-	echo 0000000000000000000000000000000000000000 >.git/HEAD &&
+	echo $ZERO_OID >.git/HEAD &&
 	# avoid corrupt/broken HEAD from interfering with repo discovery
 	test_must_fail env GIT_DIR=.git git fsck 2>out &&
-	cat out &&
-	grep "detached HEAD points" out
+	test_i18ngrep "detached HEAD points" out
 '
 
 test_expect_success 'HEAD link pointing at a funny place' '
@@ -98,8 +95,42 @@ test_expect_success 'HEAD link pointing
 	echo "ref: refs/funny/place" >.git/HEAD &&
 	# avoid corrupt/broken HEAD from interfering with repo discovery
 	test_must_fail env GIT_DIR=.git git fsck 2>out &&
-	cat out &&
-	grep "HEAD points to something strange" out
+	test_i18ngrep "HEAD points to something strange" out
+'
+
+test_expect_success 'HEAD link pointing at a funny object (from different wt)' '
+	test_when_finished "mv .git/SAVED_HEAD .git/HEAD" &&
+	test_when_finished "rm -rf .git/worktrees wt" &&
+	git worktree add wt &&
+	mv .git/HEAD .git/SAVED_HEAD &&
+	echo $ZERO_OID >.git/HEAD &&
+	# avoid corrupt/broken HEAD from interfering with repo discovery
+	test_must_fail git -C wt fsck 2>out &&
+	test_i18ngrep "main-worktree/HEAD: detached HEAD points" out
+'
+
+test_expect_success 'other worktree HEAD link pointing at a funny object' '
+	test_when_finished "rm -rf .git/worktrees other" &&
+	git worktree add other &&
+	echo $ZERO_OID >.git/worktrees/other/HEAD &&
+	test_must_fail git fsck 2>out &&
+	test_i18ngrep "worktrees/other/HEAD: detached HEAD points" out
+'
+
+test_expect_success 'other worktree HEAD link pointing at missing object' '
+	test_when_finished "rm -rf .git/worktrees other" &&
+	git worktree add other &&
+	echo "Contents missing from repo" | git hash-object --stdin >.git/worktrees/other/HEAD &&
+	test_must_fail git fsck 2>out &&
+	test_i18ngrep "worktrees/other/HEAD: invalid sha1 pointer" out
+'
+
+test_expect_success 'other worktree HEAD link pointing at a funny place' '
+	test_when_finished "rm -rf .git/worktrees other" &&
+	git worktree add other &&
+	echo "ref: refs/funny/place" >.git/worktrees/other/HEAD &&
+	test_must_fail git fsck 2>out &&
+	test_i18ngrep "worktrees/other/HEAD points to something strange" out
 '
 
 test_expect_success 'email without @ is okay' '
@@ -122,8 +153,7 @@ test_expect_success 'email with embedded
 	git update-ref refs/heads/bogus "$new" &&
 	test_when_finished "git update-ref -d refs/heads/bogus" &&
 	test_must_fail git fsck 2>out &&
-	cat out &&
-	grep "error in commit $new" out
+	test_i18ngrep "error in commit $new" out
 '
 
 test_expect_success 'missing < email delimiter is reported nicely' '
@@ -134,8 +164,7 @@ test_expect_success 'missing < email del
 	git update-ref refs/heads/bogus "$new" &&
 	test_when_finished "git update-ref -d refs/heads/bogus" &&
 	test_must_fail git fsck 2>out &&
-	cat out &&
-	grep "error in commit $new.* - bad name" out
+	test_i18ngrep "error in commit $new.* - bad name" out
 '
 
 test_expect_success 'missing email is reported nicely' '
@@ -146,8 +175,7 @@ test_expect_success 'missing email is re
 	git update-ref refs/heads/bogus "$new" &&
 	test_when_finished "git update-ref -d refs/heads/bogus" &&
 	test_must_fail git fsck 2>out &&
-	cat out &&
-	grep "error in commit $new.* - missing email" out
+	test_i18ngrep "error in commit $new.* - missing email" out
 '
 
 test_expect_success '> in name is reported' '
@@ -158,8 +186,7 @@ test_expect_success '> in name is report
 	git update-ref refs/heads/bogus "$new" &&
 	test_when_finished "git update-ref -d refs/heads/bogus" &&
 	test_must_fail git fsck 2>out &&
-	cat out &&
-	grep "error in commit $new" out
+	test_i18ngrep "error in commit $new" out
 '
 
 # date is 2^64 + 1
@@ -172,8 +199,7 @@ test_expect_success 'integer overflow in
 	git update-ref refs/heads/bogus "$new" &&
 	test_when_finished "git update-ref -d refs/heads/bogus" &&
 	test_must_fail git fsck 2>out &&
-	cat out &&
-	grep "error in commit $new.*integer overflow" out
+	test_i18ngrep "error in commit $new.*integer overflow" out
 '
 
 test_expect_success 'commit with NUL in header' '
@@ -184,8 +210,7 @@ test_expect_success 'commit with NUL in
 	git update-ref refs/heads/bogus "$new" &&
 	test_when_finished "git update-ref -d refs/heads/bogus" &&
 	test_must_fail git fsck 2>out &&
-	cat out &&
-	grep "error in commit $new.*unterminated header: NUL at offset" out
+	test_i18ngrep "error in commit $new.*unterminated header: NUL at offset" out
 '
 
 test_expect_success 'tree object with duplicate entries' '
@@ -206,14 +231,20 @@ test_expect_success 'tree object with du
 		git hash-object -w -t tree --stdin
 	) &&
 	test_must_fail git fsck 2>out &&
-	grep "error in tree .*contains duplicate file entries" out
+	test_i18ngrep "error in tree .*contains duplicate file entries" out
 '
 
 test_expect_success 'unparseable tree object' '
+	test_oid_cache <<-\EOF &&
+	junk sha1:twenty-bytes-of-junk
+	junk sha256:twenty-bytes-of-junk-twelve-more
+	EOF
+
 	test_when_finished "git update-ref -d refs/heads/wrong" &&
 	test_when_finished "remove_object \$tree_sha1" &&
 	test_when_finished "remove_object \$commit_sha1" &&
-	tree_sha1=$(printf "100644 \0twenty-bytes-of-junk" | git hash-object -t tree --stdin -w --literally) &&
+	junk=$(test_oid junk) &&
+	tree_sha1=$(printf "100644 \0$junk" | git hash-object -t tree --stdin -w --literally) &&
 	commit_sha1=$(git commit-tree $tree_sha1) &&
 	git update-ref refs/heads/wrong $commit_sha1 &&
 	test_must_fail git fsck 2>out &&
@@ -222,10 +253,6 @@ test_expect_success 'unparseable tree ob
 	test_i18ngrep ! "fatal: empty filename in tree entry" out
 '
 
-hex2oct() {
-	perl -ne 'printf "\\%03o", hex for /../g'
-}
-
 test_expect_success 'tree entry with type mismatch' '
 	test_when_finished "remove_object \$blob" &&
 	test_when_finished "remove_object \$tree" &&
@@ -245,8 +272,9 @@ test_expect_success 'tree entry with typ
 '
 
 test_expect_success 'tag pointing to nonexistent' '
-	cat >invalid-tag <<-\EOF &&
-	object ffffffffffffffffffffffffffffffffffffffff
+	badoid=$(test_oid deadbeef) &&
+	cat >invalid-tag <<-EOF &&
+	object $badoid
 	type commit
 	tag invalid
 	tagger T A Gger <tagger@example.com> 1234567890 -0000
@@ -259,8 +287,7 @@ test_expect_success 'tag pointing to non
 	echo $tag >.git/refs/tags/invalid &&
 	test_when_finished "git update-ref -d refs/tags/invalid" &&
 	test_must_fail git fsck --tags >out &&
-	cat out &&
-	grep "broken link" out
+	test_i18ngrep "broken link" out
 '
 
 test_expect_success 'tag pointing to something else than its type' '
@@ -302,7 +329,7 @@ test_expect_success 'tag with incorrect
 	warning in tag $tag: badTagName: invalid '\''tag'\'' name: wrong name format
 	warning in tag $tag: missingTaggerEntry: invalid format - expected '\''tagger'\'' line
 	EOF
-	test_cmp expect out
+	test_i18ncmp expect out
 '
 
 test_expect_success 'tag with bad tagger' '
@@ -321,7 +348,7 @@ test_expect_success 'tag with bad tagger
 	echo $tag >.git/refs/tags/wrong &&
 	test_when_finished "git update-ref -d refs/tags/wrong" &&
 	test_must_fail git fsck --tags 2>out &&
-	grep "error in tag .*: invalid author/committer" out
+	test_i18ngrep "error in tag .*: invalid author/committer" out
 '
 
 test_expect_success 'tag with NUL in header' '
@@ -340,24 +367,23 @@ test_expect_success 'tag with NUL in hea
 	echo $tag >.git/refs/tags/wrong &&
 	test_when_finished "git update-ref -d refs/tags/wrong" &&
 	test_must_fail git fsck --tags 2>out &&
-	cat out &&
-	grep "error in tag $tag.*unterminated header: NUL at offset" out
+	test_i18ngrep "error in tag $tag.*unterminated header: NUL at offset" out
 '
 
 test_expect_success 'cleaned up' '
 	git fsck >actual 2>&1 &&
-	test_cmp empty actual
+	test_must_be_empty actual
 '
 
 test_expect_success 'rev-list --verify-objects' '
 	git rev-list --verify-objects --all >/dev/null 2>out &&
-	test_cmp empty out
+	test_must_be_empty out
 '
 
 test_expect_success 'rev-list --verify-objects with bad sha1' '
 	sha=$(echo blob | git hash-object -w --stdin) &&
-	old=$(echo $sha | sed "s+^..+&/+") &&
-	new=$(dirname $old)/ffffffffffffffffffffffffffffffffffffff &&
+	old=$(test_oid_to_path $sha) &&
+	new=$(dirname $old)/$(test_oid ff_2) &&
 	sha="$(dirname $new)$(basename $new)" &&
 	mv .git/objects/$old .git/objects/$new &&
 	test_when_finished "remove_object $sha" &&
@@ -371,8 +397,7 @@ test_expect_success 'rev-list --verify-o
 	test_when_finished "git update-ref -d refs/heads/bogus" &&
 
 	test_might_fail git rev-list --verify-objects refs/heads/bogus >/dev/null 2>out &&
-	cat out &&
-	grep -q "error: sha1 mismatch 63ffffffffffffffffffffffffffffffffffffff" out
+	test_i18ngrep -q "error: hash mismatch $(dirname $new)$(test_oid ff_2)" out
 '
 
 test_expect_success 'force fsck to ignore double author' '
@@ -387,28 +412,25 @@ test_expect_success 'force fsck to ignor
 '
 
 _bz='\0'
-_bz5="$_bz$_bz$_bz$_bz$_bz"
-_bz20="$_bz5$_bz5$_bz5$_bz5"
+_bzoid=$(printf $ZERO_OID | sed -e 's/00/\\0/g')
 
 test_expect_success 'fsck notices blob entry pointing to null sha1' '
 	(git init null-blob &&
 	 cd null-blob &&
-	 sha=$(printf "100644 file$_bz$_bz20" |
+	 sha=$(printf "100644 file$_bz$_bzoid" |
 	       git hash-object -w --stdin -t tree) &&
 	  git fsck 2>out &&
-	  cat out &&
-	  grep "warning.*null sha1" out
+	  test_i18ngrep "warning.*null sha1" out
 	)
 '
 
 test_expect_success 'fsck notices submodule entry pointing to null sha1' '
 	(git init null-commit &&
 	 cd null-commit &&
-	 sha=$(printf "160000 submodule$_bz$_bz20" |
+	 sha=$(printf "160000 submodule$_bz$_bzoid" |
 	       git hash-object -w --stdin -t tree) &&
 	  git fsck 2>out &&
-	  cat out &&
-	  grep "warning.*null sha1" out
+	  test_i18ngrep "warning.*null sha1" out
 	)
 '
 
@@ -419,6 +441,7 @@ while read name path pretty; do
 		(
 			git init $name-$type &&
 			cd $name-$type &&
+			git config core.protectNTFS false &&
 			echo content >file &&
 			git add file &&
 			git commit -m base &&
@@ -428,8 +451,7 @@ while read name path pretty; do
 			printf "$mode $type %s\t%s" "$value" "$path" >bad &&
 			bad_tree=$(git mktree <bad) &&
 			git fsck 2>out &&
-			cat out &&
-			grep "warning.*tree $bad_tree" out
+			test_i18ngrep "warning.*tree $bad_tree" out
 		)'
 	done <<-\EOF
 	100644 blob
@@ -475,9 +497,9 @@ test_expect_success 'NUL in commit' '
 		git branch bad $(cat name) &&
 
 		test_must_fail git -c fsck.nulInCommit=error fsck 2>warn.1 &&
-		grep nulInCommit warn.1 &&
+		test_i18ngrep nulInCommit warn.1 &&
 		git fsck 2>warn.2 &&
-		grep nulInCommit warn.2
+		test_i18ngrep nulInCommit warn.2
 	)
 '
 
@@ -556,7 +578,7 @@ test_expect_success 'fsck --connectivity
 		# its type. That lets us see that --connectivity-only is
 		# not actually looking at the contents, but leaves it
 		# free to examine the type if it chooses.
-		empty=.git/objects/e6/9de29bb2d1d6434b8b29ae775ad8c2e48c5391 &&
+		empty=.git/objects/$(test_oid_to_path $EMPTY_BLOB) &&
 		blob=$(echo unrelated | git hash-object -w --stdin) &&
 		mv -f $(sha1_file $blob) $empty &&
 
@@ -595,18 +617,20 @@ test_expect_success 'fsck --name-objects
 		remove_object $(git rev-parse julius:caesar.t) &&
 		test_must_fail git fsck --name-objects >out &&
 		tree=$(git rev-parse --verify julius:) &&
-		egrep "$tree \((refs/heads/master|HEAD)@\{[0-9]*\}:" out
+		test_i18ngrep "$tree (refs/tags/julius:" out
 	)
 '
 
 test_expect_success 'alternate objects are correctly blamed' '
 	test_when_finished "rm -rf alt.git .git/objects/info/alternates" &&
+	name=$(test_oid numeric) &&
+	path=$(test_oid_to_path "$name") &&
 	git init --bare alt.git &&
 	echo "../../alt.git/objects" >.git/objects/info/alternates &&
-	mkdir alt.git/objects/12 &&
-	>alt.git/objects/12/34567890123456789012345678901234567890 &&
+	mkdir alt.git/objects/$(dirname $path) &&
+	>alt.git/objects/$(dirname $path)/$(basename $path) &&
 	test_must_fail git fsck >out 2>&1 &&
-	grep alt.git out
+	test_i18ngrep alt.git out
 '
 
 test_expect_success 'fsck errors in packed objects' '
@@ -625,8 +649,8 @@ test_expect_success 'fsck errors in pack
 	remove_object $one &&
 	remove_object $two &&
 	test_must_fail git fsck 2>out &&
-	grep "error in commit $one.* - bad name" out &&
-	grep "error in commit $two.* - bad name" out &&
+	test_i18ngrep "error in commit $one.* - bad name" out &&
+	test_i18ngrep "error in commit $two.* - bad name" out &&
 	! grep corrupt out
 '
 
@@ -674,20 +698,39 @@ test_expect_success 'fsck detects traili
 	test_i18ngrep "garbage.*$commit" out
 '
 
-test_expect_success 'fsck detects trailing loose garbage (blob)' '
+test_expect_success 'fsck detects trailing loose garbage (large blob)' '
 	blob=$(echo trailing | git hash-object -w --stdin) &&
 	file=$(sha1_file $blob) &&
 	test_when_finished "remove_object $blob" &&
 	chmod +w "$file" &&
 	echo garbage >>"$file" &&
-	test_must_fail git fsck 2>out &&
+	test_must_fail git -c core.bigfilethreshold=5 fsck 2>out &&
 	test_i18ngrep "garbage.*$blob" out
 '
 
+test_expect_success 'fsck detects truncated loose object' '
+	# make it big enough that we know we will truncate in the data
+	# portion, not the header
+	test-tool genrandom truncate 4096 >file &&
+	blob=$(git hash-object -w file) &&
+	file=$(sha1_file $blob) &&
+	test_when_finished "remove_object $blob" &&
+	test_copy_bytes 1024 <"$file" >tmp &&
+	rm "$file" &&
+	mv -f tmp "$file" &&
+
+	# check both regular and streaming code paths
+	test_must_fail git fsck 2>out &&
+	test_i18ngrep corrupt.*$blob out &&
+
+	test_must_fail git -c core.bigfilethreshold=128 fsck 2>out &&
+	test_i18ngrep corrupt.*$blob out
+'
+
 # for each of type, we have one version which is referenced by another object
 # (and so while unreachable, not dangling), and another variant which really is
 # dangling.
-test_expect_success 'fsck notices dangling objects' '
+test_expect_success 'create dangling-object repository' '
 	git init dangling &&
 	(
 		cd dangling &&
@@ -698,16 +741,31 @@ test_expect_success 'fsck notices dangli
 		commit=$(git commit-tree $tree) &&
 		dcommit=$(git commit-tree -p $commit $tree) &&
 
-		cat >expect <<-EOF &&
+		cat >expect <<-EOF
 		dangling blob $dblob
 		dangling commit $dcommit
 		dangling tree $dtree
 		EOF
+	)
+'
 
+test_expect_success 'fsck notices dangling objects' '
+	(
+		cd dangling &&
 		git fsck >actual &&
 		# the output order is non-deterministic, as it comes from a hash
 		sort <actual >actual.sorted &&
-		test_cmp expect actual.sorted
+		test_i18ncmp expect actual.sorted
+	)
+'
+
+test_expect_success 'fsck --connectivity-only notices dangling objects' '
+	(
+		cd dangling &&
+		git fsck --connectivity-only >actual &&
+		# the output order is non-deterministic, as it comes from a hash
+		sort <actual >actual.sorted &&
+		test_i18ncmp expect actual.sorted
 	)
 '
 
@@ -755,7 +813,7 @@ test_expect_success 'detect corrupt inde
 	test_when_finished "mv .git/index.backup .git/index" &&
 	corrupt_index_checksum &&
 	test_must_fail git fsck --cache 2>errors &&
-	grep "bad index file" errors
+	test_i18ngrep "bad index file" errors
 '
 
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t1500-rev-parse.sh 1.2.3+git2.25.1-1/git/t/t1500-rev-parse.sh
--- 1.2.1+git2.18.0-1/git/t/t1500-rev-parse.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t1500-rev-parse.sh	2020-02-17 04:47:35.000000000 +0000
@@ -59,6 +59,7 @@ test_rev_parse () {
 ROOT=$(pwd)
 
 test_expect_success 'setup' '
+	test_oid_init &&
 	mkdir -p sub/dir work &&
 	cp -R .git repo.git
 '
@@ -131,6 +132,30 @@ test_expect_success 'rev-parse --is-shal
 	test_cmp expect actual
 '
 
+test_expect_success 'rev-parse --show-object-format in repo' '
+	echo "$(test_oid algo)" >expect &&
+	git rev-parse --show-object-format >actual &&
+	test_cmp expect actual &&
+	git rev-parse --show-object-format=storage >actual &&
+	test_cmp expect actual &&
+	git rev-parse --show-object-format=input >actual &&
+	test_cmp expect actual &&
+	git rev-parse --show-object-format=output >actual &&
+	test_cmp expect actual &&
+	test_must_fail git rev-parse --show-object-format=squeamish-ossifrage 2>err &&
+	grep "unknown mode for --show-object-format: squeamish-ossifrage" err
+'
+
+test_expect_success '--show-toplevel from subdir of working tree' '
+	pwd >expect &&
+	git -C sub/dir rev-parse --show-toplevel >actual &&
+	test_cmp expect actual
+'
+
+test_expect_success '--show-toplevel from inside .git' '
+	test_must_fail git -C .git rev-parse --show-toplevel
+'
+
 test_expect_success 'showing the superproject correctly' '
 	git rev-parse --show-superproject-working-tree >out &&
 	test_must_be_empty out &&
@@ -142,6 +167,22 @@ test_expect_success 'showing the superpr
 	git -C super submodule add ../sub dir/sub &&
 	echo $(pwd)/super >expect  &&
 	git -C super/dir/sub rev-parse --show-superproject-working-tree >out &&
+	test_cmp expect out &&
+
+	test_commit -C super submodule_add &&
+	git -C super checkout -b branch1 &&
+	git -C super/dir/sub checkout -b branch1 &&
+	test_commit -C super/dir/sub branch1_commit &&
+	git -C super add dir/sub &&
+	test_commit -C super branch1_commit &&
+	git -C super checkout -b branch2 master &&
+	git -C super/dir/sub checkout -b branch2 master &&
+	test_commit -C super/dir/sub branch2_commit &&
+	git -C super add dir/sub &&
+	test_commit -C super branch2_commit &&
+	test_must_fail git -C super merge branch1 &&
+
+	git -C super/dir/sub rev-parse --show-superproject-working-tree >out &&
 	test_cmp expect out
 '
 
diff -pruN 1.2.1+git2.18.0-1/git/t/t1501-work-tree.sh 1.2.3+git2.25.1-1/git/t/t1501-work-tree.sh
--- 1.2.1+git2.18.0-1/git/t/t1501-work-tree.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t1501-work-tree.sh	2020-02-17 04:47:35.000000000 +0000
@@ -41,7 +41,7 @@ test_expect_success 'setup: helper for t
 			# rev-parse --show-prefix should output
 			# a single newline when at the top of the work tree,
 			# but we test for that separately.
-			test -z "$4" && ! test -s actual.prefix ||
+			test -z "$4" && test_must_be_empty actual.prefix ||
 			test_cmp expected.prefix actual.prefix
 		fi
 	}
diff -pruN 1.2.1+git2.18.0-1/git/t/t1506-rev-parse-diagnosis.sh 1.2.3+git2.25.1-1/git/t/t1506-rev-parse-diagnosis.sh
--- 1.2.1+git2.18.0-1/git/t/t1506-rev-parse-diagnosis.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t1506-rev-parse-diagnosis.sh	2020-02-17 04:47:35.000000000 +0000
@@ -8,10 +8,9 @@ exec </dev/null
 
 test_did_you_mean ()
 {
-	sq="'" &&
 	cat >expected <<-EOF &&
-	fatal: Path '$2$3' $4, but not ${5:-$sq$3$sq}.
-	Did you mean '$1:$2$3'${2:+ aka $sq$1:./$3$sq}?
+	fatal: Path '$2$3' $4, but not ${5:-$SQ$3$SQ}.
+	Did you mean '$1:$2$3'${2:+ aka $SQ$1:./$3$SQ}?
 	EOF
 	test_cmp expected error
 }
@@ -139,10 +138,10 @@ test_expect_success 'incorrect file in :
 
 test_expect_success 'invalid @{n} reference' '
 	test_must_fail git rev-parse master@{99999} >output 2>error &&
-	test -z "$(cat output)" &&
+	test_must_be_empty output &&
 	grep "fatal: Log for [^ ]* only has [0-9][0-9]* entries." error  &&
 	test_must_fail git rev-parse --verify master@{99999} >output 2>error &&
-	test -z "$(cat output)" &&
+	test_must_be_empty output &&
 	grep "fatal: Log for [^ ]* only has [0-9][0-9]* entries." error
 '
 
@@ -156,13 +155,13 @@ test_expect_success 'relative path not f
 
 test_expect_success 'relative path outside worktree' '
 	test_must_fail git rev-parse HEAD:../file.txt >output 2>error &&
-	test -z "$(cat output)" &&
+	test_must_be_empty output &&
 	test_i18ngrep "outside repository" error
 '
 
 test_expect_success 'relative path when cwd is outside worktree' '
 	test_must_fail git --git-dir=.git --work-tree=subdir rev-parse HEAD:./file.txt >output 2>error &&
-	test -z "$(cat output)" &&
+	test_must_be_empty output &&
 	grep "relative path syntax can.t be used outside working tree." error
 '
 
@@ -215,4 +214,12 @@ test_expect_success 'arg before dashdash
 	test_cmp expect actual
 '
 
+test_expect_success 'reject Nth parent if N is too high' '
+	test_must_fail git rev-parse HEAD^100000000000000000000000000000000
+'
+
+test_expect_success 'reject Nth ancestor if N is too high' '
+	test_must_fail git rev-parse HEAD~100000000000000000000000000000000
+'
+
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t1507-rev-parse-upstream.sh 1.2.3+git2.25.1-1/git/t/t1507-rev-parse-upstream.sh
--- 1.2.1+git2.18.0-1/git/t/t1507-rev-parse-upstream.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t1507-rev-parse-upstream.sh	2020-02-17 04:47:35.000000000 +0000
@@ -28,8 +28,6 @@ test_expect_success 'setup' '
 	)
 '
 
-sq="'"
-
 full_name () {
 	(cd clone &&
 	 git rev-parse --symbolic-full-name "$@")
@@ -123,13 +121,13 @@ test_expect_success 'checkout -b new my-
 
 test_expect_success 'merge my-side@{u} records the correct name' '
 (
-	cd clone || exit
-	git checkout master || exit
-	git branch -D new ;# can fail but is ok
+	cd clone &&
+	git checkout master &&
+	test_might_fail git branch -D new &&
 	git branch -t new my-side@{u} &&
 	git merge -s ours new@{u} &&
 	git show -s --pretty=tformat:%s >actual &&
-	echo "Merge remote-tracking branch ${sq}origin/side${sq}" >expect &&
+	echo "Merge remote-tracking branch ${SQ}origin/side${SQ}" >expect &&
 	test_cmp expect actual
 )
 '
@@ -138,8 +136,7 @@ test_expect_success 'branch -d other@{u}
 	git checkout -t -b other master &&
 	git branch -d @{u} &&
 	git for-each-ref refs/heads/master >actual &&
-	>expect &&
-	test_cmp expect actual
+	test_must_be_empty actual
 '
 
 test_expect_success 'checkout other@{u}' '
@@ -157,7 +154,7 @@ test_expect_success 'branch@{u} works wh
 
 test_expect_success 'branch@{u} error message when no upstream' '
 	cat >expect <<-EOF &&
-	fatal: no upstream configured for branch ${sq}non-tracking${sq}
+	fatal: no upstream configured for branch ${SQ}non-tracking${SQ}
 	EOF
 	error_message non-tracking@{u} &&
 	test_i18ncmp expect error
@@ -165,7 +162,7 @@ test_expect_success 'branch@{u} error me
 
 test_expect_success '@{u} error message when no upstream' '
 	cat >expect <<-EOF &&
-	fatal: no upstream configured for branch ${sq}master${sq}
+	fatal: no upstream configured for branch ${SQ}master${SQ}
 	EOF
 	test_must_fail git rev-parse --verify @{u} 2>actual &&
 	test_i18ncmp expect actual
@@ -173,7 +170,7 @@ test_expect_success '@{u} error message
 
 test_expect_success 'branch@{u} error message with misspelt branch' '
 	cat >expect <<-EOF &&
-	fatal: no such branch: ${sq}no-such-branch${sq}
+	fatal: no such branch: ${SQ}no-such-branch${SQ}
 	EOF
 	error_message no-such-branch@{u} &&
 	test_i18ncmp expect error
@@ -190,7 +187,7 @@ test_expect_success '@{u} error message
 
 test_expect_success 'branch@{u} error message if upstream branch not fetched' '
 	cat >expect <<-EOF &&
-	fatal: upstream branch ${sq}refs/heads/side${sq} not stored as a remote-tracking branch
+	fatal: upstream branch ${SQ}refs/heads/side${SQ} not stored as a remote-tracking branch
 	EOF
 	error_message bad-upstream@{u} &&
 	test_i18ncmp expect error
diff -pruN 1.2.1+git2.18.0-1/git/t/t1510-repo-setup.sh 1.2.3+git2.25.1-1/git/t/t1510-repo-setup.sh
--- 1.2.1+git2.18.0-1/git/t/t1510-repo-setup.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t1510-repo-setup.sh	2020-02-17 04:47:35.000000000 +0000
@@ -234,14 +234,14 @@ test_expect_success '#0: nonbare repo, n
 	try_repo 0 unset unset unset "" unset \
 		.git "$here/0" "$here/0" "(null)" \
 		.git "$here/0" "$here/0" sub/ 2>message &&
-	! test -s message
+	test_must_be_empty message
 '
 
 test_expect_success '#1: GIT_WORK_TREE without explicit GIT_DIR is accepted' '
 	try_repo 1 "$here" unset unset "" unset \
 		"$here/1/.git" "$here" "$here" 1/ \
 		"$here/1/.git" "$here" "$here" 1/sub/ 2>message &&
-	! test -s message
+	test_must_be_empty message
 '
 
 test_expect_success '#2: worktree defaults to cwd with explicit GIT_DIR' '
@@ -268,7 +268,7 @@ test_expect_success '#4: core.worktree w
 	try_case 4 unset unset \
 		.git "$here/4/sub" "$here/4" "(null)" \
 		"$here/4/.git" "$here/4/sub" "$here/4/sub" "(null)" 2>message &&
-	! test -s message
+	test_must_be_empty message
 '
 
 test_expect_success '#5: core.worktree + GIT_WORK_TREE is accepted' '
@@ -279,7 +279,7 @@ test_expect_success '#5: core.worktree +
 	try_repo 5a .. unset "$here/5a" "" unset \
 		"$here/5a/.git" "$here" "$here" 5a/ \
 		"$here/5a/.git" "$here/5a" "$here/5a" sub/ &&
-	! test -s message
+	test_must_be_empty message
 '
 
 test_expect_success '#6: setting GIT_DIR brings core.worktree to life' '
@@ -376,7 +376,7 @@ test_expect_success '#9: GIT_WORK_TREE a
 	try_repo 9 wt unset unset gitfile unset \
 		"$here/9.git" "$here/9/wt" "$here/9" "(null)" \
 		"$here/9.git" "$here/9/sub/wt" "$here/9/sub" "(null)" 2>message &&
-	! test -s message
+	test_must_be_empty message
 '
 
 test_expect_success '#10: GIT_DIR can point to gitfile' '
@@ -402,7 +402,7 @@ test_expect_success '#12: core.worktree
 	try_repo 12 unset unset "$here/12" gitfile unset \
 		"$here/12.git" "$here/12" "$here/12" "(null)" \
 		"$here/12.git" "$here/12" "$here/12" sub/ 2>message &&
-	! test -s message
+	test_must_be_empty message
 '
 
 test_expect_success '#13: core.worktree+GIT_WORK_TREE accepted (with gitfile)' '
@@ -410,7 +410,7 @@ test_expect_success '#13: core.worktree+
 	try_repo 13 non-existent-too unset non-existent gitfile unset \
 		"$here/13.git" "$here/13/non-existent-too" "$here/13" "(null)" \
 		"$here/13.git" "$here/13/sub/non-existent-too" "$here/13/sub" "(null)" 2>message &&
-	! test -s message
+	test_must_be_empty message
 '
 
 # case #14.
@@ -565,7 +565,7 @@ test_expect_success '#17: GIT_WORK_TREE
 	try_repo 17c "$here/17c" unset unset "" true \
 		.git "$here/17c" "$here/17c" "(null)" \
 		"$here/17c/.git" "$here/17c" "$here/17c" sub/ 2>message &&
-	! test -s message
+	test_must_be_empty message
 '
 
 test_expect_success '#18: bare .git named by GIT_DIR has no worktree' '
@@ -594,7 +594,7 @@ test_expect_success '#20a: core.worktree
 		"$here/20a/.git" "$here/20a" "$here/20a" .git/wt/ &&
 	try_case 20a/.git/wt/sub unset unset \
 		"$here/20a/.git" "$here/20a" "$here/20a" .git/wt/sub/ &&
-	! test -s message
+	test_must_be_empty message
 '
 
 test_expect_success '#20b/c: core.worktree and core.bare conflict' '
@@ -626,7 +626,7 @@ test_expect_success '#21: setup, core.wo
 		export GIT_WORK_TREE &&
 		git status >/dev/null
 	) 2>message &&
-	! test -s message
+	test_must_be_empty message
 
 '
 run_wt_tests 21
@@ -742,7 +742,7 @@ test_expect_success '#25: GIT_WORK_TREE
 	try_repo 25 "$here/25" unset unset gitfile true \
 		"$here/25.git" "$here/25" "$here/25" "(null)"  \
 		"$here/25.git" "$here/25" "$here/25" "sub/" 2>message &&
-	! test -s message
+	test_must_be_empty message
 '
 
 test_expect_success '#26: bare repo has no worktree (GIT_DIR -> gitfile case)' '
@@ -780,7 +780,7 @@ test_expect_success '#29: setup' '
 		export GIT_WORK_TREE &&
 		git status
 	) 2>message &&
-	! test -s message
+	test_must_be_empty message
 '
 run_wt_tests 29 gitfile
 
diff -pruN 1.2.1+git2.18.0-1/git/t/t1512-rev-parse-disambiguation.sh 1.2.3+git2.25.1-1/git/t/t1512-rev-parse-disambiguation.sh
--- 1.2.1+git2.18.0-1/git/t/t1512-rev-parse-disambiguation.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t1512-rev-parse-disambiguation.sh	2020-02-17 04:47:35.000000000 +0000
@@ -34,8 +34,8 @@ test_expect_success 'blob and tree' '
 		for i in 0 1 2 3 4 5 6 7 8 9
 		do
 			echo $i
-		done
-		echo
+		done &&
+		echo &&
 		echo b1rwzyc3
 	) >a0blgqsjc &&
 
@@ -222,7 +222,7 @@ test_expect_success 'more history' '
 
 	test_might_fail git rm -f a0blgqsjc &&
 	(
-		git cat-file blob $side:f5518nwu
+		git cat-file blob $side:f5518nwu &&
 		echo j3l0i9s6
 	) >ab2gs879 &&
 	git add ab2gs879 &&
@@ -282,7 +282,7 @@ test_expect_success 'rev-parse --disambi
 	# commits created by commit-tree in earlier tests share a
 	# different prefix.
 	git rev-parse --disambiguate=000000000 >actual &&
-	test $(wc -l <actual) = 16 &&
+	test_line_count = 16 actual &&
 	test "$(sed -e "s/^\(.........\).*/\1/" actual | sort -u)" = 000000000
 '
 
@@ -339,7 +339,7 @@ test_expect_success C_LOCALE_OUTPUT 'amb
 test_expect_success C_LOCALE_OUTPUT 'ambiguity hints respect type' '
 	test_must_fail git rev-parse 000000000^{commit} 2>stderr &&
 	grep ^hint: stderr >hints &&
-	# 5 commits, 1 tag (which is a commitish), plus intro line
+	# 5 commits, 1 tag (which is a committish), plus intro line
 	test_line_count = 7 hints
 '
 
@@ -388,4 +388,14 @@ test_expect_success C_LOCALE_OUTPUT 'amb
 	done
 '
 
+test_expect_success 'cat-file --batch and --batch-check show ambiguous' '
+	echo "0000 ambiguous" >expect &&
+	echo 0000 | git cat-file --batch-check >actual 2>err &&
+	test_cmp expect actual &&
+	test_i18ngrep hint: err &&
+	echo 0000 | git cat-file --batch >actual 2>err &&
+	test_cmp expect actual &&
+	test_i18ngrep hint: err
+'
+
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t1600-index.sh 1.2.3+git2.25.1-1/git/t/t1600-index.sh
--- 1.2.1+git2.18.0-1/git/t/t1600-index.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t1600-index.sh	2020-02-17 04:47:35.000000000 +0000
@@ -41,8 +41,7 @@ test_expect_success 'no warning with bog
 		GIT_INDEX_VERSION=1 &&
 		export GIT_INDEX_VERSION &&
 		git add a 2>actual.err &&
-		>expect.err &&
-		test_i18ncmp expect.err actual.err
+		test_must_be_empty actual.err
 	)
 '
 
@@ -60,17 +59,42 @@ test_expect_success 'out of bounds index
 	)
 '
 
-test_expect_success 'GIT_INDEX_VERSION takes precedence over config' '
+test_index_version () {
+	INDEX_VERSION_CONFIG=$1 &&
+	FEATURE_MANY_FILES=$2 &&
+	ENV_VAR_VERSION=$3
+	EXPECTED_OUTPUT_VERSION=$4 &&
 	(
 		rm -f .git/index &&
-		GIT_INDEX_VERSION=4 &&
-		export GIT_INDEX_VERSION &&
-		git config --add index.version 2 &&
+		rm -f .git/config &&
+		if test "$INDEX_VERSION_CONFIG" -ne 0
+		then
+			git config --add index.version $INDEX_VERSION_CONFIG
+		fi &&
+		git config --add feature.manyFiles $FEATURE_MANY_FILES
+		if test "$ENV_VAR_VERSION" -ne 0
+		then
+			GIT_INDEX_VERSION=$ENV_VAR_VERSION &&
+			export GIT_INDEX_VERSION
+		else
+			unset GIT_INDEX_VERSION
+		fi &&
 		git add a 2>&1 &&
-		echo 4 >expect &&
+		echo $EXPECTED_OUTPUT_VERSION >expect &&
 		test-tool index-version <.git/index >actual &&
 		test_cmp expect actual
 	)
+}
+
+test_expect_success 'index version config precedence' '
+	test_index_version 0 false 0 2 &&
+	test_index_version 2 false 0 2 &&
+	test_index_version 3 false 0 2 &&
+	test_index_version 4 false 0 4 &&
+	test_index_version 2 false 4 4 &&
+	test_index_version 2 true 0 2 &&
+	test_index_version 0 true 0 4 &&
+	test_index_version 0 true 2 2
 '
 
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t1700-split-index.sh 1.2.3+git2.25.1-1/git/t/t1700-split-index.sh
--- 1.2.1+git2.18.0-1/git/t/t1700-split-index.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t1700-split-index.sh	2020-02-17 04:47:35.000000000 +0000
@@ -6,21 +6,52 @@ test_description='split index mode tests
 
 # We need total control of index splitting here
 sane_unset GIT_TEST_SPLIT_INDEX
-sane_unset GIT_FSMONITOR_TEST
+
+# Testing a hard coded SHA against an index with an extension
+# that can vary from run to run is problematic so we disable
+# those extensions.
+sane_unset GIT_TEST_FSMONITOR
+sane_unset GIT_TEST_INDEX_THREADS
+
+# Create a file named as $1 with content read from stdin.
+# Set the file's mtime to a few seconds in the past to avoid racy situations.
+create_non_racy_file () {
+	cat >"$1" &&
+	test-tool chmtime =-5 "$1"
+}
+
+test_expect_success 'setup' '
+	test_oid_cache <<-EOF
+	own_v3 sha1:8299b0bcd1ac364e5f1d7768efb62fa2da79a339
+	own_v3 sha256:38a6d2925e3eceec33ad7b34cbff4e0086caa0daf28f31e51f5bd94b4a7af86b
+
+	base_v3 sha1:39d890139ee5356c7ef572216cebcd27aa41f9df
+	base_v3 sha256:c9baeadf905112bf6c17aefbd7d02267afd70ded613c30cafed2d40cb506e1ed
+
+	own_v4 sha1:432ef4b63f32193984f339431fd50ca796493569
+	own_v4 sha256:6738ac6319c25b694afa7bcc313deb182d1a59b68bf7a47b4296de83478c0420
+
+	base_v4 sha1:508851a7f0dfa8691e9f69c7f055865389012491
+	base_v4 sha256:3177d4adfdd4b6904f7e921d91d715a471c0dde7cf6a4bba574927f02b699508
+	EOF
+'
 
 test_expect_success 'enable split index' '
 	git config splitIndex.maxPercentChange 100 &&
 	git update-index --split-index &&
 	test-tool dump-split-index .git/index >actual &&
 	indexversion=$(test-tool index-version <.git/index) &&
+
+	# NEEDSWORK: Stop hard-coding checksums.
 	if test "$indexversion" = "4"
 	then
-		own=432ef4b63f32193984f339431fd50ca796493569
-		base=508851a7f0dfa8691e9f69c7f055865389012491
+		own=$(test_oid own_v4)
+		base=$(test_oid base_v4)
 	else
-		own=8299b0bcd1ac364e5f1d7768efb62fa2da79a339
-		base=39d890139ee5356c7ef572216cebcd27aa41f9df
+		own=$(test_oid own_v3)
+		base=$(test_oid base_v3)
 	fi &&
+
 	cat >expect <<-EOF &&
 	own $own
 	base $base
@@ -31,7 +62,7 @@ test_expect_success 'enable split index'
 '
 
 test_expect_success 'add one file' '
-	: >one &&
+	create_non_racy_file one &&
 	git update-index --add one &&
 	git ls-files --stage >ls-files.actual &&
 	cat >ls-files.expect <<-EOF &&
@@ -57,7 +88,7 @@ test_expect_success 'disable split index
 	EOF
 	test_cmp ls-files.expect ls-files.actual &&
 
-	BASE=$(test-tool dump-split-index .git/index | grep "^own" | sed "s/own/base/") &&
+	BASE=$(test-tool dump-split-index .git/index | sed -n "s/^own/base/p") &&
 	test-tool dump-split-index .git/index | sed "/^own/d" >actual &&
 	cat >expect <<-EOF &&
 	not a split index
@@ -83,18 +114,19 @@ test_expect_success 'enable split index
 '
 
 test_expect_success 'modify original file, base index untouched' '
-	echo modified >one &&
+	echo modified | create_non_racy_file one &&
+	file1_blob=$(git hash-object one) &&
 	git update-index one &&
 	git ls-files --stage >ls-files.actual &&
 	cat >ls-files.expect <<-EOF &&
-	100644 2e0996000b7e9019eabcad29391bf0f5c7702f0b 0	one
+	100644 $file1_blob 0	one
 	EOF
 	test_cmp ls-files.expect ls-files.actual &&
 
 	test-tool dump-split-index .git/index | sed "/^own/d" >actual &&
 	q_to_tab >expect <<-EOF &&
 	$BASE
-	100644 2e0996000b7e9019eabcad29391bf0f5c7702f0b 0Q
+	100644 $file1_blob 0Q
 	replacements: 0
 	deletions:
 	EOF
@@ -102,11 +134,11 @@ test_expect_success 'modify original fil
 '
 
 test_expect_success 'add another file, which stays index' '
-	: >two &&
+	create_non_racy_file two &&
 	git update-index --add two &&
 	git ls-files --stage >ls-files.actual &&
 	cat >ls-files.expect <<-EOF &&
-	100644 2e0996000b7e9019eabcad29391bf0f5c7702f0b 0	one
+	100644 $file1_blob 0	one
 	100644 $EMPTY_BLOB 0	two
 	EOF
 	test_cmp ls-files.expect ls-files.actual &&
@@ -114,7 +146,7 @@ test_expect_success 'add another file, w
 	test-tool dump-split-index .git/index | sed "/^own/d" >actual &&
 	q_to_tab >expect <<-EOF &&
 	$BASE
-	100644 2e0996000b7e9019eabcad29391bf0f5c7702f0b 0Q
+	100644 $file1_blob 0Q
 	100644 $EMPTY_BLOB 0	two
 	replacements: 0
 	deletions:
@@ -126,14 +158,14 @@ test_expect_success 'remove file not in
 	git update-index --force-remove two &&
 	git ls-files --stage >ls-files.actual &&
 	cat >ls-files.expect <<-EOF &&
-	100644 2e0996000b7e9019eabcad29391bf0f5c7702f0b 0	one
+	100644 $file1_blob 0	one
 	EOF
 	test_cmp ls-files.expect ls-files.actual &&
 
 	test-tool dump-split-index .git/index | sed "/^own/d" >actual &&
 	q_to_tab >expect <<-EOF &&
 	$BASE
-	100644 2e0996000b7e9019eabcad29391bf0f5c7702f0b 0Q
+	100644 $file1_blob 0Q
 	replacements: 0
 	deletions:
 	EOF
@@ -143,9 +175,7 @@ test_expect_success 'remove file not in
 test_expect_success 'remove file in base index' '
 	git update-index --force-remove one &&
 	git ls-files --stage >ls-files.actual &&
-	cat >ls-files.expect <<-EOF &&
-	EOF
-	test_cmp ls-files.expect ls-files.actual &&
+	test_must_be_empty ls-files.actual &&
 
 	test-tool dump-split-index .git/index | sed "/^own/d" >actual &&
 	cat >expect <<-EOF &&
@@ -157,7 +187,7 @@ test_expect_success 'remove file in base
 '
 
 test_expect_success 'add original file back' '
-	: >one &&
+	create_non_racy_file one &&
 	git update-index --add one &&
 	git ls-files --stage >ls-files.actual &&
 	cat >ls-files.expect <<-EOF &&
@@ -176,7 +206,7 @@ test_expect_success 'add original file b
 '
 
 test_expect_success 'add new file' '
-	: >two &&
+	create_non_racy_file two &&
 	git update-index --add two &&
 	git ls-files --stage >actual &&
 	cat >expect <<-EOF &&
@@ -220,13 +250,13 @@ test_expect_success 'rev-parse --shared-
 
 test_expect_success 'set core.splitIndex config variable to true' '
 	git config core.splitIndex true &&
-	: >three &&
+	create_non_racy_file three &&
 	git update-index --add three &&
 	git ls-files --stage >ls-files.actual &&
 	cat >ls-files.expect <<-EOF &&
-	100644 e69de29bb2d1d6434b8b29ae775ad8c2e48c5391 0	one
-	100644 e69de29bb2d1d6434b8b29ae775ad8c2e48c5391 0	three
-	100644 e69de29bb2d1d6434b8b29ae775ad8c2e48c5391 0	two
+	100644 $EMPTY_BLOB 0	one
+	100644 $EMPTY_BLOB 0	three
+	100644 $EMPTY_BLOB 0	two
 	EOF
 	test_cmp ls-files.expect ls-files.actual &&
 	BASE=$(test-tool dump-split-index .git/index | grep "^base") &&
@@ -244,8 +274,8 @@ test_expect_success 'set core.splitIndex
 	git update-index --force-remove three &&
 	git ls-files --stage >ls-files.actual &&
 	cat >ls-files.expect <<-EOF &&
-	100644 e69de29bb2d1d6434b8b29ae775ad8c2e48c5391 0	one
-	100644 e69de29bb2d1d6434b8b29ae775ad8c2e48c5391 0	two
+	100644 $EMPTY_BLOB 0	one
+	100644 $EMPTY_BLOB 0	two
 	EOF
 	test_cmp ls-files.expect ls-files.actual &&
 	test-tool dump-split-index .git/index | sed "/^own/d" >actual &&
@@ -255,9 +285,9 @@ test_expect_success 'set core.splitIndex
 	test_cmp expect actual
 '
 
-test_expect_success 'set core.splitIndex config variable to true' '
+test_expect_success 'set core.splitIndex config variable back to true' '
 	git config core.splitIndex true &&
-	: >three &&
+	create_non_racy_file three &&
 	git update-index --add three &&
 	BASE=$(test-tool dump-split-index .git/index | grep "^base") &&
 	test-tool dump-split-index .git/index | sed "/^own/d" >actual &&
@@ -267,12 +297,12 @@ test_expect_success 'set core.splitIndex
 	deletions:
 	EOF
 	test_cmp expect actual &&
-	: >four &&
+	create_non_racy_file four &&
 	git update-index --add four &&
 	test-tool dump-split-index .git/index | sed "/^own/d" >actual &&
 	cat >expect <<-EOF &&
 	$BASE
-	100644 e69de29bb2d1d6434b8b29ae775ad8c2e48c5391 0	four
+	100644 $EMPTY_BLOB 0	four
 	replacements:
 	deletions:
 	EOF
@@ -281,7 +311,7 @@ test_expect_success 'set core.splitIndex
 
 test_expect_success 'check behavior with splitIndex.maxPercentChange unset' '
 	git config --unset splitIndex.maxPercentChange &&
-	: >five &&
+	create_non_racy_file five &&
 	git update-index --add five &&
 	BASE=$(test-tool dump-split-index .git/index | grep "^base") &&
 	test-tool dump-split-index .git/index | sed "/^own/d" >actual &&
@@ -291,12 +321,12 @@ test_expect_success 'check behavior with
 	deletions:
 	EOF
 	test_cmp expect actual &&
-	: >six &&
+	create_non_racy_file six &&
 	git update-index --add six &&
 	test-tool dump-split-index .git/index | sed "/^own/d" >actual &&
 	cat >expect <<-EOF &&
 	$BASE
-	100644 e69de29bb2d1d6434b8b29ae775ad8c2e48c5391 0	six
+	100644 $EMPTY_BLOB 0	six
 	replacements:
 	deletions:
 	EOF
@@ -305,7 +335,7 @@ test_expect_success 'check behavior with
 
 test_expect_success 'check splitIndex.maxPercentChange set to 0' '
 	git config splitIndex.maxPercentChange 0 &&
-	: >seven &&
+	create_non_racy_file seven &&
 	git update-index --add seven &&
 	BASE=$(test-tool dump-split-index .git/index | grep "^base") &&
 	test-tool dump-split-index .git/index | sed "/^own/d" >actual &&
@@ -315,7 +345,7 @@ test_expect_success 'check splitIndex.ma
 	deletions:
 	EOF
 	test_cmp expect actual &&
-	: >eight &&
+	create_non_racy_file eight &&
 	git update-index --add eight &&
 	BASE=$(test-tool dump-split-index .git/index | grep "^base") &&
 	test-tool dump-split-index .git/index | sed "/^own/d" >actual &&
@@ -328,17 +358,17 @@ test_expect_success 'check splitIndex.ma
 '
 
 test_expect_success 'shared index files expire after 2 weeks by default' '
-	: >ten &&
+	create_non_racy_file ten &&
 	git update-index --add ten &&
 	test $(ls .git/sharedindex.* | wc -l) -gt 2 &&
 	just_under_2_weeks_ago=$((5-14*86400)) &&
 	test-tool chmtime =$just_under_2_weeks_ago .git/sharedindex.* &&
-	: >eleven &&
+	create_non_racy_file eleven &&
 	git update-index --add eleven &&
 	test $(ls .git/sharedindex.* | wc -l) -gt 2 &&
 	just_over_2_weeks_ago=$((-1-14*86400)) &&
 	test-tool chmtime =$just_over_2_weeks_ago .git/sharedindex.* &&
-	: >twelve &&
+	create_non_racy_file twelve &&
 	git update-index --add twelve &&
 	test $(ls .git/sharedindex.* | wc -l) -le 2
 '
@@ -346,12 +376,12 @@ test_expect_success 'shared index files
 test_expect_success 'check splitIndex.sharedIndexExpire set to 16 days' '
 	git config splitIndex.sharedIndexExpire "16.days.ago" &&
 	test-tool chmtime =$just_over_2_weeks_ago .git/sharedindex.* &&
-	: >thirteen &&
+	create_non_racy_file thirteen &&
 	git update-index --add thirteen &&
 	test $(ls .git/sharedindex.* | wc -l) -gt 2 &&
 	just_over_16_days_ago=$((-1-16*86400)) &&
 	test-tool chmtime =$just_over_16_days_ago .git/sharedindex.* &&
-	: >fourteen &&
+	create_non_racy_file fourteen &&
 	git update-index --add fourteen &&
 	test $(ls .git/sharedindex.* | wc -l) -le 2
 '
@@ -360,17 +390,37 @@ test_expect_success 'check splitIndex.sh
 	git config splitIndex.sharedIndexExpire never &&
 	just_10_years_ago=$((-365*10*86400)) &&
 	test-tool chmtime =$just_10_years_ago .git/sharedindex.* &&
-	: >fifteen &&
+	create_non_racy_file fifteen &&
 	git update-index --add fifteen &&
 	test $(ls .git/sharedindex.* | wc -l) -gt 2 &&
 	git config splitIndex.sharedIndexExpire now &&
 	just_1_second_ago=-1 &&
 	test-tool chmtime =$just_1_second_ago .git/sharedindex.* &&
-	: >sixteen &&
+	create_non_racy_file sixteen &&
 	git update-index --add sixteen &&
 	test $(ls .git/sharedindex.* | wc -l) -le 2
 '
 
+test_expect_success POSIXPERM 'same mode for index & split index' '
+	git init same-mode &&
+	(
+		cd same-mode &&
+		test_commit A &&
+		test_modebits .git/index >index_mode &&
+		test_must_fail git config core.sharedRepository &&
+		git -c core.splitIndex=true status &&
+		shared=$(ls .git/sharedindex.*) &&
+		case "$shared" in
+		*" "*)
+			# we have more than one???
+			false ;;
+		*)
+			test_modebits "$shared" >split_index_mode &&
+			test_cmp index_mode split_index_mode ;;
+		esac
+	)
+'
+
 while read -r mode modebits
 do
 	test_expect_success POSIXPERM "split index respects core.sharedrepository $mode" '
@@ -381,7 +431,7 @@ do
 		# Create one new shared index file
 		git config core.sharedrepository "$mode" &&
 		git config core.splitIndex true &&
-		: >one &&
+		create_non_racy_file one &&
 		git update-index --add one &&
 		echo "$modebits" >expect &&
 		test_modebits .git/index >actual &&
@@ -435,8 +485,26 @@ test_expect_success 'writing split index
 	commit=$(git commit-tree $tree -p HEAD <msg) &&
 	git update-ref HEAD "$commit" &&
 	GIT_ALLOW_NULL_SHA1=1 git reset --hard &&
-	(test-tool dump-cache-tree >cache-tree.out || true) &&
+	test_might_fail test-tool dump-cache-tree >cache-tree.out &&
 	test_line_count = 0 cache-tree.out
 '
 
+test_expect_success 'do not refresh null base index' '
+	test_create_repo merge &&
+	(
+		cd merge &&
+		test_commit initial &&
+		git checkout -b side-branch &&
+		test_commit extra &&
+		git checkout master &&
+		git update-index --split-index &&
+		test_commit more &&
+		# must not write a new shareindex, or we wont catch the problem
+		git -c splitIndex.maxPercentChange=100 merge --no-edit side-branch 2>err &&
+		# i.e. do not expect warnings like
+		# could not freshen shared index .../shareindex.00000...
+		test_must_be_empty err
+	)
+'
+
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t1701-racy-split-index.sh 1.2.3+git2.25.1-1/git/t/t1701-racy-split-index.sh
--- 1.2.1+git2.18.0-1/git/t/t1701-racy-split-index.sh	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t1701-racy-split-index.sh	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,214 @@
+#!/bin/sh
+
+# This test can give false success if your machine is sufficiently
+# slow or all trials happened to happen on second boundaries.
+
+test_description='racy split index'
+
+. ./test-lib.sh
+
+test_expect_success 'setup' '
+	# Only split the index when the test explicitly says so.
+	sane_unset GIT_TEST_SPLIT_INDEX &&
+	git config splitIndex.maxPercentChange 100 &&
+
+	echo "cached content" >racy-file &&
+	git add racy-file &&
+	git commit -m initial &&
+
+	echo something >other-file &&
+	# No raciness with this file.
+	test-tool chmtime =-20 other-file &&
+
+	echo "+cached content" >expect
+'
+
+check_cached_diff () {
+	git diff-index --patch --cached $EMPTY_TREE racy-file >diff &&
+	tail -1 diff >actual &&
+	test_cmp expect actual
+}
+
+trials="0 1 2 3 4"
+for trial in $trials
+do
+	test_expect_success "split the index while adding a racily clean file #$trial" '
+		rm -f .git/index .git/sharedindex.* &&
+
+		# The next three commands must be run within the same
+		# second (so both writes to racy-file result in the same
+		# mtime) to create the interesting racy situation.
+		echo "cached content" >racy-file &&
+
+		# Update and split the index.  The cache entry of
+		# racy-file will be stored only in the shared index.
+		git update-index --split-index --add racy-file &&
+
+		# File size must stay the same.
+		echo "dirty worktree" >racy-file &&
+
+		# Subsequent git commands should notice that racy-file
+		# and the split index have the same mtime, and check
+		# the content of the file to see if it is actually
+		# clean.
+		check_cached_diff
+	'
+done
+
+for trial in $trials
+do
+	test_expect_success "add a racily clean file to an already split index #$trial" '
+		rm -f .git/index .git/sharedindex.* &&
+
+		git update-index --split-index &&
+
+		# The next three commands must be run within the same
+		# second.
+		echo "cached content" >racy-file &&
+
+		# Update the split index.  The cache entry of racy-file
+		# will be stored only in the split index.
+		git update-index --add racy-file &&
+
+		# File size must stay the same.
+		echo "dirty worktree" >racy-file &&
+
+		# Subsequent git commands should notice that racy-file
+		# and the split index have the same mtime, and check
+		# the content of the file to see if it is actually
+		# clean.
+		check_cached_diff
+	'
+done
+
+for trial in $trials
+do
+	test_expect_success "split the index when the index contains a racily clean cache entry #$trial" '
+		rm -f .git/index .git/sharedindex.* &&
+
+		# The next three commands must be run within the same
+		# second.
+		echo "cached content" >racy-file &&
+
+		git update-index --add racy-file &&
+
+		# File size must stay the same.
+		echo "dirty worktree" >racy-file &&
+
+		# Now wait a bit to ensure that the split index written
+		# below will get a more recent mtime than racy-file.
+		sleep 1 &&
+
+		# Update and split the index when the index contains
+		# the racily clean cache entry of racy-file.
+		# A corresponding replacement cache entry with smudged
+		# stat data should be added to the new split index.
+		git update-index --split-index --add other-file &&
+
+		# Subsequent git commands should notice the smudged
+		# stat data in the replacement cache entry and that it
+		# doesnt match with the file the worktree.
+		check_cached_diff
+	'
+done
+
+for trial in $trials
+do
+	test_expect_success "update the split index when it contains a new racily clean cache entry #$trial" '
+		rm -f .git/index .git/sharedindex.* &&
+
+		git update-index --split-index &&
+
+		# The next three commands must be run within the same
+		# second.
+		echo "cached content" >racy-file &&
+
+		# Update the split index.  The cache entry of racy-file
+		# will be stored only in the split index.
+		git update-index --add racy-file &&
+
+		# File size must stay the same.
+		echo "dirty worktree" >racy-file &&
+
+		# Now wait a bit to ensure that the split index written
+		# below will get a more recent mtime than racy-file.
+		sleep 1 &&
+
+		# Update the split index when the racily clean cache
+		# entry of racy-file is only stored in the split index.
+		# An updated cache entry with smudged stat data should
+		# be added to the new split index.
+		git update-index --add other-file &&
+
+		# Subsequent git commands should notice the smudged
+		# stat data.
+		check_cached_diff
+	'
+done
+
+for trial in $trials
+do
+	test_expect_success "update the split index when a racily clean cache entry is stored only in the shared index #$trial" '
+		rm -f .git/index .git/sharedindex.* &&
+
+		# The next three commands must be run within the same
+		# second.
+		echo "cached content" >racy-file &&
+
+		# Update and split the index.  The cache entry of
+		# racy-file will be stored only in the shared index.
+		git update-index --split-index --add racy-file &&
+
+		# File size must stay the same.
+		echo "dirty worktree" >racy-file &&
+
+		# Now wait a bit to ensure that the split index written
+		# below will get a more recent mtime than racy-file.
+		sleep 1 &&
+
+		# Update the split index when the racily clean cache
+		# entry of racy-file is only stored in the shared index.
+		# A corresponding replacement cache entry with smudged
+		# stat data should be added to the new split index.
+		git update-index --add other-file &&
+
+		# Subsequent git commands should notice the smudged
+		# stat data.
+		check_cached_diff
+	'
+done
+
+for trial in $trials
+do
+	test_expect_success "update the split index after unpack trees() copied a racily clean cache entry from the shared index #$trial" '
+		rm -f .git/index .git/sharedindex.* &&
+
+		# The next three commands must be run within the same
+		# second.
+		echo "cached content" >racy-file &&
+
+		# Update and split the index.  The cache entry of
+		# racy-file will be stored only in the shared index.
+		git update-index --split-index --add racy-file &&
+
+		# File size must stay the same.
+		echo "dirty worktree" >racy-file &&
+
+		# Now wait a bit to ensure that the split index written
+		# below will get a more recent mtime than racy-file.
+		sleep 1 &&
+
+		# Update the split index after unpack_trees() copied the
+		# racily clean cache entry of racy-file from the shared
+		# index.  A corresponding replacement cache entry
+		# with smudged stat data should be added to the new
+		# split index.
+		git read-tree -m HEAD &&
+
+		# Subsequent git commands should notice the smudged
+		# stat data.
+		check_cached_diff
+	'
+done
+
+test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t2000-checkout-cache-clash.sh 1.2.3+git2.25.1-1/git/t/t2000-checkout-cache-clash.sh
--- 1.2.1+git2.18.0-1/git/t/t2000-checkout-cache-clash.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t2000-checkout-cache-clash.sh	1970-01-01 00:00:00.000000000 +0000
@@ -1,60 +0,0 @@
-#!/bin/sh
-#
-# Copyright (c) 2005 Junio C Hamano
-#
-
-test_description='git checkout-index test.
-
-This test registers the following filesystem structure in the
-cache:
-
-    path0       - a file
-    path1/file1 - a file in a directory
-
-And then tries to checkout in a work tree that has the following:
-
-    path0/file0 - a file in a directory
-    path1       - a file
-
-The git checkout-index command should fail when attempting to checkout
-path0, finding it is occupied by a directory, and path1/file1, finding
-path1 is occupied by a non-directory.  With "-f" flag, it should remove
-the conflicting paths and succeed.
-'
-. ./test-lib.sh
-
-date >path0
-mkdir path1
-date >path1/file1
-
-test_expect_success \
-    'git update-index --add various paths.' \
-    'git update-index --add path0 path1/file1'
-
-rm -fr path0 path1
-mkdir path0
-date >path0/file0
-date >path1
-
-test_expect_success \
-    'git checkout-index without -f should fail on conflicting work tree.' \
-    'test_must_fail git checkout-index -a'
-
-test_expect_success \
-    'git checkout-index with -f should succeed.' \
-    'git checkout-index -f -a'
-
-test_expect_success \
-    'git checkout-index conflicting paths.' \
-    'test -f path0 && test -d path1 && test -f path1/file1'
-
-test_expect_success SYMLINKS 'checkout-index -f twice with --prefix' '
-	mkdir -p tar/get &&
-	ln -s tar/get there &&
-	echo first &&
-	git checkout-index -a -f --prefix=there/ &&
-	echo second &&
-	git checkout-index -a -f --prefix=there/
-'
-
-test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t2000-conflict-when-checking-files-out.sh 1.2.3+git2.25.1-1/git/t/t2000-conflict-when-checking-files-out.sh
--- 1.2.1+git2.18.0-1/git/t/t2000-conflict-when-checking-files-out.sh	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t2000-conflict-when-checking-files-out.sh	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,135 @@
+#!/bin/sh
+#
+# Copyright (c) 2005 Junio C Hamano
+#
+
+test_description='git conflicts when checking files out test.'
+
+# The first test registers the following filesystem structure in the
+# cache:
+#
+#     path0       - a file
+#     path1/file1 - a file in a directory
+#
+# And then tries to checkout in a work tree that has the following:
+#
+#     path0/file0 - a file in a directory
+#     path1       - a file
+#
+# The git checkout-index command should fail when attempting to checkout
+# path0, finding it is occupied by a directory, and path1/file1, finding
+# path1 is occupied by a non-directory.  With "-f" flag, it should remove
+# the conflicting paths and succeed.
+
+. ./test-lib.sh
+
+show_files() {
+	# show filesystem files, just [-dl] for type and name
+	find path? -ls |
+	sed -e 's/^[0-9]* * [0-9]* * \([-bcdl]\)[^ ]* *[0-9]* *[^ ]* *[^ ]* *[0-9]* [A-Z][a-z][a-z] [0-9][0-9] [^ ]* /fs: \1 /'
+	# what's in the cache, just mode and name
+	git ls-files --stage |
+	sed -e 's/^\([0-9]*\) [0-9a-f]* [0-3] /ca: \1 /'
+	# what's in the tree, just mode and name.
+	git ls-tree -r "$1" |
+	sed -e 's/^\([0-9]*\)	[^ ]*	[0-9a-f]*	/tr: \1 /'
+}
+
+date >path0
+mkdir path1
+date >path1/file1
+
+test_expect_success \
+    'git update-index --add various paths.' \
+    'git update-index --add path0 path1/file1'
+
+rm -fr path0 path1
+mkdir path0
+date >path0/file0
+date >path1
+
+test_expect_success \
+    'git checkout-index without -f should fail on conflicting work tree.' \
+    'test_must_fail git checkout-index -a'
+
+test_expect_success \
+    'git checkout-index with -f should succeed.' \
+    'git checkout-index -f -a'
+
+test_expect_success \
+    'git checkout-index conflicting paths.' \
+    'test -f path0 && test -d path1 && test -f path1/file1'
+
+test_expect_success SYMLINKS 'checkout-index -f twice with --prefix' '
+	mkdir -p tar/get &&
+	ln -s tar/get there &&
+	echo first &&
+	git checkout-index -a -f --prefix=there/ &&
+	echo second &&
+	git checkout-index -a -f --prefix=there/
+'
+
+# The second test registers the following filesystem structure in the cache:
+#
+#     path2/file0	- a file in a directory
+#     path3/file1 - a file in a directory
+#
+# and attempts to check it out when the work tree has:
+#
+#     path2/file0 - a file in a directory
+#     path3       - a symlink pointing at "path2"
+#
+# Checkout cache should fail to extract path3/file1 because the leading
+# path path3 is occupied by a non-directory.  With "-f" it should remove
+# the symlink path3 and create directory path3 and file path3/file1.
+
+mkdir path2
+date >path2/file0
+test_expect_success \
+    'git update-index --add path2/file0' \
+    'git update-index --add path2/file0'
+test_expect_success \
+    'writing tree out with git write-tree' \
+    'tree1=$(git write-tree)'
+test_debug 'show_files $tree1'
+
+mkdir path3
+date >path3/file1
+test_expect_success \
+    'git update-index --add path3/file1' \
+    'git update-index --add path3/file1'
+test_expect_success \
+    'writing tree out with git write-tree' \
+    'tree2=$(git write-tree)'
+test_debug 'show_files $tree2'
+
+rm -fr path3
+test_expect_success \
+    'read previously written tree and checkout.' \
+    'git read-tree -m $tree1 && git checkout-index -f -a'
+test_debug 'show_files $tree1'
+
+test_expect_success \
+    'add a symlink' \
+    'test_ln_s_add path2 path3'
+test_expect_success \
+    'writing tree out with git write-tree' \
+    'tree3=$(git write-tree)'
+test_debug 'show_files $tree3'
+
+# Morten says "Got that?" here.
+# Test begins.
+
+test_expect_success \
+    'read previously written tree and checkout.' \
+    'git read-tree $tree2 && git checkout-index -f -a'
+test_debug 'show_files $tree2'
+
+test_expect_success \
+    'checking out conflicting path with -f' \
+    'test ! -h path2 && test -d path2 &&
+     test ! -h path3 && test -d path3 &&
+     test ! -h path2/file0 && test -f path2/file0 &&
+     test ! -h path3/file1 && test -f path3/file1'
+
+test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t2001-checkout-cache-clash.sh 1.2.3+git2.25.1-1/git/t/t2001-checkout-cache-clash.sh
--- 1.2.1+git2.18.0-1/git/t/t2001-checkout-cache-clash.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t2001-checkout-cache-clash.sh	1970-01-01 00:00:00.000000000 +0000
@@ -1,85 +0,0 @@
-#!/bin/sh
-#
-# Copyright (c) 2005 Junio C Hamano
-#
-
-test_description='git checkout-index test.
-
-This test registers the following filesystem structure in the cache:
-
-    path0/file0	- a file in a directory
-    path1/file1 - a file in a directory
-
-and attempts to check it out when the work tree has:
-
-    path0/file0 - a file in a directory
-    path1       - a symlink pointing at "path0"
-
-Checkout cache should fail to extract path1/file1 because the leading
-path path1 is occupied by a non-directory.  With "-f" it should remove
-the symlink path1 and create directory path1 and file path1/file1.
-'
-. ./test-lib.sh
-
-show_files() {
-	# show filesystem files, just [-dl] for type and name
-	find path? -ls |
-	sed -e 's/^[0-9]* * [0-9]* * \([-bcdl]\)[^ ]* *[0-9]* *[^ ]* *[^ ]* *[0-9]* [A-Z][a-z][a-z] [0-9][0-9] [^ ]* /fs: \1 /'
-	# what's in the cache, just mode and name
-	git ls-files --stage |
-	sed -e 's/^\([0-9]*\) [0-9a-f]* [0-3] /ca: \1 /'
-	# what's in the tree, just mode and name.
-	git ls-tree -r "$1" |
-	sed -e 's/^\([0-9]*\)	[^ ]*	[0-9a-f]*	/tr: \1 /'
-}
-
-mkdir path0
-date >path0/file0
-test_expect_success \
-    'git update-index --add path0/file0' \
-    'git update-index --add path0/file0'
-test_expect_success \
-    'writing tree out with git write-tree' \
-    'tree1=$(git write-tree)'
-test_debug 'show_files $tree1'
-
-mkdir path1
-date >path1/file1
-test_expect_success \
-    'git update-index --add path1/file1' \
-    'git update-index --add path1/file1'
-test_expect_success \
-    'writing tree out with git write-tree' \
-    'tree2=$(git write-tree)'
-test_debug 'show_files $tree2'
-
-rm -fr path1
-test_expect_success \
-    'read previously written tree and checkout.' \
-    'git read-tree -m $tree1 && git checkout-index -f -a'
-test_debug 'show_files $tree1'
-
-test_expect_success \
-    'add a symlink' \
-    'test_ln_s_add path0 path1'
-test_expect_success \
-    'writing tree out with git write-tree' \
-    'tree3=$(git write-tree)'
-test_debug 'show_files $tree3'
-
-# Morten says "Got that?" here.
-# Test begins.
-
-test_expect_success \
-    'read previously written tree and checkout.' \
-    'git read-tree $tree2 && git checkout-index -f -a'
-test_debug 'show_files $tree2'
-
-test_expect_success \
-    'checking out conflicting path with -f' \
-    'test ! -h path0 && test -d path0 &&
-     test ! -h path1 && test -d path1 &&
-     test ! -h path0/file0 && test -f path0/file0 &&
-     test ! -h path1/file1 && test -f path1/file1'
-
-test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t2013-checkout-submodule.sh 1.2.3+git2.25.1-1/git/t/t2013-checkout-submodule.sh
--- 1.2.1+git2.18.0-1/git/t/t2013-checkout-submodule.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t2013-checkout-submodule.sh	2020-02-17 04:47:35.000000000 +0000
@@ -44,7 +44,7 @@ test_expect_success '"checkout <submodul
 	git config diff.ignoreSubmodules dirty &&
 	echo x> submodule/untracked &&
 	git checkout HEAD >actual 2>&1 &&
-	! test -s actual
+	test_must_be_empty actual
 '
 
 test_expect_success '"checkout <submodule>" honors submodule.*.ignore from .gitmodules' '
@@ -52,7 +52,7 @@ test_expect_success '"checkout <submodul
 	git config -f .gitmodules submodule.submodule.path submodule &&
 	git config -f .gitmodules submodule.submodule.ignore untracked &&
 	git checkout HEAD >actual 2>&1 &&
-	! test -s actual
+	test_must_be_empty actual
 '
 
 test_expect_success '"checkout <submodule>" honors submodule.*.ignore from .git/config' '
@@ -60,7 +60,7 @@ test_expect_success '"checkout <submodul
 	git config submodule.submodule.path submodule &&
 	git config submodule.submodule.ignore all &&
 	git checkout HEAD >actual 2>&1 &&
-	! test -s actual
+	test_must_be_empty actual
 '
 
 KNOWN_FAILURE_DIRECTORY_SUBMODULE_CONFLICTS=1
diff -pruN 1.2.1+git2.18.0-1/git/t/t2014-checkout-switch.sh 1.2.3+git2.25.1-1/git/t/t2014-checkout-switch.sh
--- 1.2.1+git2.18.0-1/git/t/t2014-checkout-switch.sh	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t2014-checkout-switch.sh	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,28 @@
+#!/bin/sh
+
+test_description='Peter MacMillan'
+. ./test-lib.sh
+
+test_expect_success setup '
+	echo Hello >file &&
+	git add file &&
+	test_tick &&
+	git commit -m V1 &&
+	echo Hello world >file &&
+	git add file &&
+	git checkout -b other
+'
+
+test_expect_success 'check all changes are staged' '
+	git diff --exit-code
+'
+
+test_expect_success 'second commit' '
+	git commit -m V2
+'
+
+test_expect_success 'check' '
+	git diff --cached --exit-code
+'
+
+test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t2014-switch.sh 1.2.3+git2.25.1-1/git/t/t2014-switch.sh
--- 1.2.1+git2.18.0-1/git/t/t2014-switch.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t2014-switch.sh	1970-01-01 00:00:00.000000000 +0000
@@ -1,28 +0,0 @@
-#!/bin/sh
-
-test_description='Peter MacMillan'
-. ./test-lib.sh
-
-test_expect_success setup '
-	echo Hello >file &&
-	git add file &&
-	test_tick &&
-	git commit -m V1 &&
-	echo Hello world >file &&
-	git add file &&
-	git checkout -b other
-'
-
-test_expect_success 'check all changes are staged' '
-	git diff --exit-code
-'
-
-test_expect_success 'second commit' '
-	git commit -m V2
-'
-
-test_expect_success 'check' '
-	git diff --cached --exit-code
-'
-
-test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t2016-checkout-patch.sh 1.2.3+git2.25.1-1/git/t/t2016-checkout-patch.sh
--- 1.2.1+git2.18.0-1/git/t/t2016-checkout-patch.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t2016-checkout-patch.sh	2020-02-17 04:47:35.000000000 +0000
@@ -20,33 +20,33 @@ test_expect_success PERL 'setup' '
 
 test_expect_success PERL 'saying "n" does nothing' '
 	set_and_save_state dir/foo work head &&
-	(echo n; echo n) | git checkout -p &&
+	test_write_lines n n | git checkout -p &&
 	verify_saved_state bar &&
 	verify_saved_state dir/foo
 '
 
 test_expect_success PERL 'git checkout -p' '
-	(echo n; echo y) | git checkout -p &&
+	test_write_lines n y | git checkout -p &&
 	verify_saved_state bar &&
 	verify_state dir/foo head head
 '
 
 test_expect_success PERL 'git checkout -p with staged changes' '
 	set_state dir/foo work index &&
-	(echo n; echo y) | git checkout -p &&
+	test_write_lines n y | git checkout -p &&
 	verify_saved_state bar &&
 	verify_state dir/foo index index
 '
 
 test_expect_success PERL 'git checkout -p HEAD with NO staged changes: abort' '
 	set_and_save_state dir/foo work head &&
-	(echo n; echo y; echo n) | git checkout -p HEAD &&
+	test_write_lines n y n | git checkout -p HEAD &&
 	verify_saved_state bar &&
 	verify_saved_state dir/foo
 '
 
 test_expect_success PERL 'git checkout -p HEAD with NO staged changes: apply' '
-	(echo n; echo y; echo y) | git checkout -p HEAD &&
+	test_write_lines n y y | git checkout -p HEAD &&
 	verify_saved_state bar &&
 	verify_state dir/foo head head
 '
@@ -54,14 +54,14 @@ test_expect_success PERL 'git checkout -
 test_expect_success PERL 'git checkout -p HEAD with change already staged' '
 	set_state dir/foo index index &&
 	# the third n is to get out in case it mistakenly does not apply
-	(echo n; echo y; echo n) | git checkout -p HEAD &&
+	test_write_lines n y n | git checkout -p HEAD &&
 	verify_saved_state bar &&
 	verify_state dir/foo head head
 '
 
 test_expect_success PERL 'git checkout -p HEAD^' '
 	# the third n is to get out in case it mistakenly does not apply
-	(echo n; echo y; echo n) | git checkout -p HEAD^ &&
+	test_write_lines n y n | git checkout -p HEAD^ &&
 	verify_saved_state bar &&
 	verify_state dir/foo parent parent
 '
@@ -69,7 +69,7 @@ test_expect_success PERL 'git checkout -
 test_expect_success PERL 'git checkout -p handles deletion' '
 	set_state dir/foo work index &&
 	rm dir/foo &&
-	(echo n; echo y) | git checkout -p &&
+	test_write_lines n y | git checkout -p &&
 	verify_saved_state bar &&
 	verify_state dir/foo index index
 '
@@ -81,21 +81,21 @@ test_expect_success PERL 'git checkout -
 
 test_expect_success PERL 'path limiting works: dir' '
 	set_state dir/foo work head &&
-	(echo y; echo n) | git checkout -p dir &&
+	test_write_lines y n | git checkout -p dir &&
 	verify_saved_state bar &&
 	verify_state dir/foo head head
 '
 
 test_expect_success PERL 'path limiting works: -- dir' '
 	set_state dir/foo work head &&
-	(echo y; echo n) | git checkout -p -- dir &&
+	test_write_lines y n | git checkout -p -- dir &&
 	verify_saved_state bar &&
 	verify_state dir/foo head head
 '
 
 test_expect_success PERL 'path limiting works: HEAD^ -- dir' '
 	# the third n is to get out in case it mistakenly does not apply
-	(echo y; echo n; echo n) | git checkout -p HEAD^ -- dir &&
+	test_write_lines y n n | git checkout -p HEAD^ -- dir &&
 	verify_saved_state bar &&
 	verify_state dir/foo parent parent
 '
@@ -103,7 +103,7 @@ test_expect_success PERL 'path limiting
 test_expect_success PERL 'path limiting works: foo inside dir' '
 	set_state dir/foo work head &&
 	# the third n is to get out in case it mistakenly does not apply
-	(echo y; echo n; echo n) | (cd dir && git checkout -p foo) &&
+	test_write_lines y n n | (cd dir && git checkout -p foo) &&
 	verify_saved_state bar &&
 	verify_state dir/foo head head
 '
diff -pruN 1.2.1+git2.18.0-1/git/t/t2018-checkout-branch.sh 1.2.3+git2.25.1-1/git/t/t2018-checkout-branch.sh
--- 1.2.1+git2.18.0-1/git/t/t2018-checkout-branch.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t2018-checkout-branch.sh	2020-02-17 04:47:35.000000000 +0000
@@ -60,38 +60,47 @@ test_expect_success 'setup' '
 '
 
 test_expect_success 'checkout -b to a new branch, set to HEAD' '
+	test_when_finished "
+		git checkout branch1 &&
+		test_might_fail git branch -D branch2" &&
 	do_checkout branch2
 '
 
-test_expect_success 'checkout -b to a new branch, set to an explicit ref' '
-	git checkout branch1 &&
-	git branch -D branch2 &&
+test_expect_success 'checkout -b to a merge base' '
+	test_when_finished "
+		git checkout branch1 &&
+		test_might_fail git branch -D branch2" &&
+	git checkout -b branch2 branch1...
+'
 
+test_expect_success 'checkout -b to a new branch, set to an explicit ref' '
+	test_when_finished "
+		git checkout branch1 &&
+		test_might_fail git branch -D branch2" &&
 	do_checkout branch2 $HEAD1
 '
 
 test_expect_success 'checkout -b to a new branch with unmergeable changes fails' '
-	git checkout branch1 &&
-
-	# clean up from previous test
-	git branch -D branch2 &&
-
 	setup_dirty_unmergeable &&
 	test_must_fail do_checkout branch2 $HEAD1 &&
 	test_dirty_unmergeable
 '
 
 test_expect_success 'checkout -f -b to a new branch with unmergeable changes discards changes' '
+	test_when_finished "
+		git checkout branch1 &&
+		test_might_fail git branch -D branch2" &&
+
 	# still dirty and on branch1
 	do_checkout branch2 $HEAD1 "-f -b" &&
 	test_must_fail test_dirty_unmergeable
 '
 
 test_expect_success 'checkout -b to a new branch preserves mergeable changes' '
-	git checkout branch1 &&
-
-	# clean up from previous test
-	git branch -D branch2 &&
+	test_when_finished "
+		git reset --hard &&
+		git checkout branch1 &&
+		test_might_fail git branch -D branch2" &&
 
 	setup_dirty_mergeable &&
 	do_checkout branch2 $HEAD1 &&
@@ -99,27 +108,18 @@ test_expect_success 'checkout -b to a ne
 '
 
 test_expect_success 'checkout -f -b to a new branch with mergeable changes discards changes' '
-	# clean up from previous test
-	git reset --hard &&
-
-	git checkout branch1 &&
-
-	# clean up from previous test
-	git branch -D branch2 &&
-
+	test_when_finished git reset --hard HEAD &&
 	setup_dirty_mergeable &&
 	do_checkout branch2 $HEAD1 "-f -b" &&
 	test_must_fail test_dirty_mergeable
 '
 
 test_expect_success 'checkout -b to an existing branch fails' '
-	git reset --hard HEAD &&
-
+	test_when_finished git reset --hard HEAD &&
 	test_must_fail do_checkout branch2 $HEAD2
 '
 
 test_expect_success 'checkout -b to @{-1} fails with the right branch name' '
-	git reset --hard HEAD &&
 	git checkout branch1 &&
 	git checkout branch2 &&
 	echo  >expect "fatal: A branch named '\''branch1'\'' already exists." &&
@@ -133,6 +133,12 @@ test_expect_success 'checkout -B to an e
 	do_checkout branch2 "" -B
 '
 
+test_expect_success 'checkout -B to a merge base' '
+	git checkout branch1 &&
+
+	git checkout -B branch2 branch1...
+'
+
 test_expect_success 'checkout -B to an existing branch from detached HEAD resets branch to HEAD' '
 	git checkout $(git rev-parse --verify HEAD) &&
 
@@ -160,6 +166,7 @@ test_expect_success 'checkout -f -B to a
 '
 
 test_expect_success 'checkout -B to an existing branch preserves mergeable changes' '
+	test_when_finished git reset --hard &&
 	git checkout branch1 &&
 
 	setup_dirty_mergeable &&
@@ -168,9 +175,6 @@ test_expect_success 'checkout -B to an e
 '
 
 test_expect_success 'checkout -f -B to an existing branch with mergeable changes discards changes' '
-	# clean up from previous test
-	git reset --hard &&
-
 	git checkout branch1 &&
 
 	setup_dirty_mergeable &&
@@ -198,4 +202,13 @@ test_expect_success 'checkout -B to the
 	test_dirty_mergeable
 '
 
+test_expect_success 'checkout -b after clone --no-checkout does a checkout of HEAD' '
+	git init src &&
+	test_commit -C src a &&
+	rev="$(git -C src rev-parse HEAD)" &&
+	git clone --no-checkout src dest &&
+	git -C dest checkout "$rev" -b branch &&
+	test_path_is_file dest/a.t
+'
+
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t2020-checkout-detach.sh 1.2.3+git2.25.1-1/git/t/t2020-checkout-detach.sh
--- 1.2.1+git2.18.0-1/git/t/t2020-checkout-detach.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t2020-checkout-detach.sh	2020-02-17 04:47:35.000000000 +0000
@@ -195,16 +195,22 @@ test_expect_success 'describe_detached_h
 
 	# The first detach operation is more chatty than the following ones.
 	cat >1st_detach <<-EOF &&
-	Note: checking out 'HEAD^'.
+	Note: switching to 'HEAD^'.
 
 	You are in 'detached HEAD' state. You can look around, make experimental
 	changes and commit them, and you can discard any commits you make in this
-	state without impacting any branches by performing another checkout.
+	state without impacting any branches by switching back to a branch.
 
 	If you want to create a new branch to retain commits you create, you may
-	do so (now or later) by using -b with the checkout command again. Example:
+	do so (now or later) by using -c with the switch command. Example:
 
-	  git checkout -b <new-branch-name>
+	  git switch -c <new-branch-name>
+
+	Or undo this operation with:
+
+	  git switch -
+
+	Turn off this advice by setting config variable advice.detachedHead to false
 
 	HEAD is now at \$commit three
 	EOF
@@ -271,16 +277,22 @@ test_expect_success 'describe_detached_h
 
 	# The first detach operation is more chatty than the following ones.
 	cat >1st_detach <<-EOF &&
-	Note: checking out 'HEAD^'.
+	Note: switching to 'HEAD^'.
 
 	You are in 'detached HEAD' state. You can look around, make experimental
 	changes and commit them, and you can discard any commits you make in this
-	state without impacting any branches by performing another checkout.
+	state without impacting any branches by switching back to a branch.
 
 	If you want to create a new branch to retain commits you create, you may
-	do so (now or later) by using -b with the checkout command again. Example:
+	do so (now or later) by using -c with the switch command. Example:
+
+	  git switch -c <new-branch-name>
+
+	Or undo this operation with:
+
+	  git switch -
 
-	  git checkout -b <new-branch-name>
+	Turn off this advice by setting config variable advice.detachedHead to false
 
 	HEAD is now at \$commit... three
 	EOF
diff -pruN 1.2.1+git2.18.0-1/git/t/t2022-checkout-paths.sh 1.2.3+git2.25.1-1/git/t/t2022-checkout-paths.sh
--- 1.2.1+git2.18.0-1/git/t/t2022-checkout-paths.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t2022-checkout-paths.sh	2020-02-17 04:47:35.000000000 +0000
@@ -78,4 +78,15 @@ test_expect_success 'do not touch files
 	test_cmp expect actual
 '
 
+test_expect_success 'checkout HEAD adds deleted intent-to-add file back to index' '
+	echo "nonempty" >nonempty &&
+	>empty &&
+	git add nonempty empty &&
+	git commit -m "create files to be deleted" &&
+	git rm --cached nonempty empty &&
+	git add -N nonempty empty &&
+	git checkout HEAD nonempty empty &&
+	git diff --cached --exit-code
+'
+
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t2023-checkout-m.sh 1.2.3+git2.25.1-1/git/t/t2023-checkout-m.sh
--- 1.2.1+git2.18.0-1/git/t/t2023-checkout-m.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t2023-checkout-m.sh	2020-02-17 04:47:35.000000000 +0000
@@ -46,4 +46,28 @@ test_expect_success '-m restores 3-way c
 	test_cmp both.txt.conflicted.cleaned both.txt.cleaned
 '
 
+test_expect_success 'force checkout a conflict file creates stage zero entry' '
+	git init co-force &&
+	(
+		cd co-force &&
+		echo a >a &&
+		git add a &&
+		git commit -ama &&
+		A_OBJ=$(git rev-parse :a) &&
+		git branch topic &&
+		echo b >a &&
+		git commit -amb &&
+		B_OBJ=$(git rev-parse :a) &&
+		git checkout topic &&
+		echo c >a &&
+		C_OBJ=$(git hash-object a) &&
+		git checkout -m master &&
+		test_cmp_rev :1:a $A_OBJ &&
+		test_cmp_rev :2:a $B_OBJ &&
+		test_cmp_rev :3:a $C_OBJ &&
+		git checkout -f topic &&
+		test_cmp_rev :0:a $A_OBJ
+	)
+'
+
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t2024-checkout-dwim.sh 1.2.3+git2.25.1-1/git/t/t2024-checkout-dwim.sh
--- 1.2.1+git2.18.0-1/git/t/t2024-checkout-dwim.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t2024-checkout-dwim.sh	2020-02-17 04:47:35.000000000 +0000
@@ -23,6 +23,11 @@ test_branch_upstream () {
 	test_cmp expect.upstream actual.upstream
 }
 
+status_uno_is_clean () {
+	git status -uno --porcelain >status.actual &&
+	test_must_be_empty status.actual
+}
+
 test_expect_success 'setup' '
 	test_commit my_master &&
 	git init repo_a &&
@@ -55,6 +60,7 @@ test_expect_success 'checkout of non-exi
 	test_might_fail git branch -D xyzzy &&
 
 	test_must_fail git checkout xyzzy &&
+	status_uno_is_clean &&
 	test_must_fail git rev-parse --verify refs/heads/xyzzy &&
 	test_branch master
 '
@@ -64,15 +70,52 @@ test_expect_success 'checkout of branch
 	test_might_fail git branch -D foo &&
 
 	test_must_fail git checkout foo &&
+	status_uno_is_clean &&
 	test_must_fail git rev-parse --verify refs/heads/foo &&
 	test_branch master
 '
 
+test_expect_success 'checkout of branch from multiple remotes fails with advice' '
+	git checkout -B master &&
+	test_might_fail git branch -D foo &&
+	test_must_fail git checkout foo 2>stderr &&
+	test_branch master &&
+	status_uno_is_clean &&
+	test_i18ngrep "^hint: " stderr &&
+	test_must_fail git -c advice.checkoutAmbiguousRemoteBranchName=false \
+		checkout foo 2>stderr &&
+	test_branch master &&
+	status_uno_is_clean &&
+	test_i18ngrep ! "^hint: " stderr
+'
+
+test_expect_success PERL 'checkout -p with multiple remotes does not print advice' '
+	git checkout -B master &&
+	test_might_fail git branch -D foo &&
+
+	git checkout -p foo 2>stderr &&
+	test_i18ngrep ! "^hint: " stderr &&
+	status_uno_is_clean
+'
+
+test_expect_success 'checkout of branch from multiple remotes succeeds with checkout.defaultRemote #1' '
+	git checkout -B master &&
+	status_uno_is_clean &&
+	test_might_fail git branch -D foo &&
+
+	git -c checkout.defaultRemote=repo_a checkout foo &&
+	status_uno_is_clean &&
+	test_branch foo &&
+	test_cmp_rev remotes/repo_a/foo HEAD &&
+	test_branch_upstream foo repo_a foo
+'
+
 test_expect_success 'checkout of branch from a single remote succeeds #1' '
 	git checkout -B master &&
 	test_might_fail git branch -D bar &&
 
 	git checkout bar &&
+	status_uno_is_clean &&
 	test_branch bar &&
 	test_cmp_rev remotes/repo_a/bar HEAD &&
 	test_branch_upstream bar repo_a bar
@@ -83,6 +126,7 @@ test_expect_success 'checkout of branch
 	test_might_fail git branch -D baz &&
 
 	git checkout baz &&
+	status_uno_is_clean &&
 	test_branch baz &&
 	test_cmp_rev remotes/other_b/baz HEAD &&
 	test_branch_upstream baz repo_b baz
@@ -90,6 +134,7 @@ test_expect_success 'checkout of branch
 
 test_expect_success '--no-guess suppresses branch auto-vivification' '
 	git checkout -B master &&
+	status_uno_is_clean &&
 	test_might_fail git branch -D bar &&
 
 	test_must_fail git checkout --no-guess bar &&
@@ -99,6 +144,7 @@ test_expect_success '--no-guess suppress
 
 test_expect_success 'setup more remotes with unconventional refspecs' '
 	git checkout -B master &&
+	status_uno_is_clean &&
 	git init repo_c &&
 	(
 		cd repo_c &&
@@ -128,27 +174,33 @@ test_expect_success 'setup more remotes
 
 test_expect_success 'checkout of branch from multiple remotes fails #2' '
 	git checkout -B master &&
+	status_uno_is_clean &&
 	test_might_fail git branch -D bar &&
 
 	test_must_fail git checkout bar &&
+	status_uno_is_clean &&
 	test_must_fail git rev-parse --verify refs/heads/bar &&
 	test_branch master
 '
 
 test_expect_success 'checkout of branch from multiple remotes fails #3' '
 	git checkout -B master &&
+	status_uno_is_clean &&
 	test_might_fail git branch -D baz &&
 
 	test_must_fail git checkout baz &&
+	status_uno_is_clean &&
 	test_must_fail git rev-parse --verify refs/heads/baz &&
 	test_branch master
 '
 
 test_expect_success 'checkout of branch from a single remote succeeds #3' '
 	git checkout -B master &&
+	status_uno_is_clean &&
 	test_might_fail git branch -D spam &&
 
 	git checkout spam &&
+	status_uno_is_clean &&
 	test_branch spam &&
 	test_cmp_rev refs/remotes/extra_dir/repo_c/extra_dir/spam HEAD &&
 	test_branch_upstream spam repo_c spam
@@ -156,9 +208,11 @@ test_expect_success 'checkout of branch
 
 test_expect_success 'checkout of branch from a single remote succeeds #4' '
 	git checkout -B master &&
+	status_uno_is_clean &&
 	test_might_fail git branch -D eggs &&
 
 	git checkout eggs &&
+	status_uno_is_clean &&
 	test_branch eggs &&
 	test_cmp_rev refs/repo_d/eggs HEAD &&
 	test_branch_upstream eggs repo_d eggs
@@ -166,32 +220,38 @@ test_expect_success 'checkout of branch
 
 test_expect_success 'checkout of branch with a file having the same name fails' '
 	git checkout -B master &&
+	status_uno_is_clean &&
 	test_might_fail git branch -D spam &&
 
 	>spam &&
 	test_must_fail git checkout spam &&
+	status_uno_is_clean &&
 	test_must_fail git rev-parse --verify refs/heads/spam &&
 	test_branch master
 '
 
 test_expect_success 'checkout of branch with a file in subdir having the same name fails' '
 	git checkout -B master &&
+	status_uno_is_clean &&
 	test_might_fail git branch -D spam &&
 
 	>spam &&
 	mkdir sub &&
 	mv spam sub/spam &&
 	test_must_fail git -C sub checkout spam &&
+	status_uno_is_clean &&
 	test_must_fail git rev-parse --verify refs/heads/spam &&
 	test_branch master
 '
 
 test_expect_success 'checkout <branch> -- succeeds, even if a file with the same name exists' '
 	git checkout -B master &&
+	status_uno_is_clean &&
 	test_might_fail git branch -D spam &&
 
 	>spam &&
 	git checkout spam -- &&
+	status_uno_is_clean &&
 	test_branch spam &&
 	test_cmp_rev refs/remotes/extra_dir/repo_c/extra_dir/spam HEAD &&
 	test_branch_upstream spam repo_c spam
@@ -200,6 +260,7 @@ test_expect_success 'checkout <branch> -
 test_expect_success 'loosely defined local base branch is reported correctly' '
 
 	git checkout master &&
+	status_uno_is_clean &&
 	git branch strict &&
 	git branch loose &&
 	git commit --allow-empty -m "a bit more" &&
@@ -210,9 +271,42 @@ test_expect_success 'loosely defined loc
 	test_config branch.loose.merge master &&
 
 	git checkout strict | sed -e "s/strict/BRANCHNAME/g" >expect &&
+	status_uno_is_clean &&
 	git checkout loose | sed -e "s/loose/BRANCHNAME/g" >actual &&
+	status_uno_is_clean &&
 
 	test_cmp expect actual
 '
 
+test_expect_success 'reject when arg could be part of dwim branch' '
+	git remote add foo file://non-existent-place &&
+	git update-ref refs/remotes/foo/dwim-arg HEAD &&
+	echo foo >dwim-arg &&
+	git add dwim-arg &&
+	echo bar >dwim-arg &&
+	test_must_fail git checkout dwim-arg &&
+	test_must_fail git rev-parse refs/heads/dwim-arg -- &&
+	grep bar dwim-arg
+'
+
+test_expect_success 'disambiguate dwim branch and checkout path (1)' '
+	git update-ref refs/remotes/foo/dwim-arg1 HEAD &&
+	echo foo >dwim-arg1 &&
+	git add dwim-arg1 &&
+	echo bar >dwim-arg1 &&
+	git checkout -- dwim-arg1 &&
+	test_must_fail git rev-parse refs/heads/dwim-arg1 -- &&
+	grep foo dwim-arg1
+'
+
+test_expect_success 'disambiguate dwim branch and checkout path (2)' '
+	git update-ref refs/remotes/foo/dwim-arg2 HEAD &&
+	echo foo >dwim-arg2 &&
+	git add dwim-arg2 &&
+	echo bar >dwim-arg2 &&
+	git checkout dwim-arg2 -- &&
+	git rev-parse refs/heads/dwim-arg2 -- &&
+	grep bar dwim-arg2
+'
+
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t2025-checkout-no-overlay.sh 1.2.3+git2.25.1-1/git/t/t2025-checkout-no-overlay.sh
--- 1.2.1+git2.18.0-1/git/t/t2025-checkout-no-overlay.sh	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t2025-checkout-no-overlay.sh	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,47 @@
+#!/bin/sh
+
+test_description='checkout --no-overlay <tree-ish> -- <pathspec>'
+
+. ./test-lib.sh
+
+test_expect_success 'setup' '
+	git commit --allow-empty -m "initial"
+'
+
+test_expect_success 'checkout --no-overlay deletes files not in <tree-ish>' '
+	>file &&
+	mkdir dir &&
+	>dir/file1 &&
+	git add file dir/file1 &&
+	git checkout --no-overlay HEAD -- file &&
+	test_path_is_missing file &&
+	test_path_is_file dir/file1
+'
+
+test_expect_success 'checkout --no-overlay removing last file from directory' '
+	git checkout --no-overlay HEAD -- dir/file1 &&
+	test_path_is_missing dir
+'
+
+test_expect_success 'checkout -p --overlay is disallowed' '
+	test_must_fail git checkout -p --overlay HEAD 2>actual &&
+	test_i18ngrep "fatal: -p and --overlay are mutually exclusive" actual
+'
+
+test_expect_success '--no-overlay --theirs with D/F conflict deletes file' '
+	test_commit file1 file1 &&
+	test_commit file2 file2 &&
+	git rm --cached file1 &&
+	echo 1234 >file1 &&
+	F1=$(git rev-parse HEAD:file1) &&
+	F2=$(git rev-parse HEAD:file2) &&
+	{
+		echo "100644 $F1 1	file1" &&
+		echo "100644 $F2 2	file1"
+	} | git update-index --index-info &&
+	test_path_is_file file1 &&
+	git checkout --theirs --no-overlay -- file1 &&
+	test_path_is_missing file1
+'
+
+test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t2025-worktree-add.sh 1.2.3+git2.25.1-1/git/t/t2025-worktree-add.sh
--- 1.2.1+git2.18.0-1/git/t/t2025-worktree-add.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t2025-worktree-add.sh	1970-01-01 00:00:00.000000000 +0000
@@ -1,530 +0,0 @@
-#!/bin/sh
-
-test_description='test git worktree add'
-
-. ./test-lib.sh
-
-. "$TEST_DIRECTORY"/lib-rebase.sh
-
-test_expect_success 'setup' '
-	test_commit init
-'
-
-test_expect_success '"add" an existing worktree' '
-	mkdir -p existing/subtree &&
-	test_must_fail git worktree add --detach existing master
-'
-
-test_expect_success '"add" an existing empty worktree' '
-	mkdir existing_empty &&
-	git worktree add --detach existing_empty master
-'
-
-test_expect_success '"add" using shorthand - fails when no previous branch' '
-	test_must_fail git worktree add existing_short -
-'
-
-test_expect_success '"add" using - shorthand' '
-	git checkout -b newbranch &&
-	echo hello >myworld &&
-	git add myworld &&
-	git commit -m myworld &&
-	git checkout master &&
-	git worktree add short-hand - &&
-	echo refs/heads/newbranch >expect &&
-	git -C short-hand rev-parse --symbolic-full-name HEAD >actual &&
-	test_cmp expect actual
-'
-
-test_expect_success '"add" refuses to checkout locked branch' '
-	test_must_fail git worktree add zere master &&
-	! test -d zere &&
-	! test -d .git/worktrees/zere
-'
-
-test_expect_success 'checking out paths not complaining about linked checkouts' '
-	(
-	cd existing_empty &&
-	echo dirty >>init.t &&
-	git checkout master -- init.t
-	)
-'
-
-test_expect_success '"add" worktree' '
-	git rev-parse HEAD >expect &&
-	git worktree add --detach here master &&
-	(
-		cd here &&
-		test_cmp ../init.t init.t &&
-		test_must_fail git symbolic-ref HEAD &&
-		git rev-parse HEAD >actual &&
-		test_cmp ../expect actual &&
-		git fsck
-	)
-'
-
-test_expect_success '"add" worktree with lock' '
-	git rev-parse HEAD >expect &&
-	git worktree add --detach --lock here-with-lock master &&
-	test -f .git/worktrees/here-with-lock/locked
-'
-
-test_expect_success '"add" worktree from a subdir' '
-	(
-		mkdir sub &&
-		cd sub &&
-		git worktree add --detach here master &&
-		cd here &&
-		test_cmp ../../init.t init.t
-	)
-'
-
-test_expect_success '"add" from a linked checkout' '
-	(
-		cd here &&
-		git worktree add --detach nested-here master &&
-		cd nested-here &&
-		git fsck
-	)
-'
-
-test_expect_success '"add" worktree creating new branch' '
-	git worktree add -b newmaster there master &&
-	(
-		cd there &&
-		test_cmp ../init.t init.t &&
-		git symbolic-ref HEAD >actual &&
-		echo refs/heads/newmaster >expect &&
-		test_cmp expect actual &&
-		git fsck
-	)
-'
-
-test_expect_success 'die the same branch is already checked out' '
-	(
-		cd here &&
-		test_must_fail git checkout newmaster
-	)
-'
-
-test_expect_success SYMLINKS 'die the same branch is already checked out (symlink)' '
-	head=$(git -C there rev-parse --git-path HEAD) &&
-	ref=$(git -C there symbolic-ref HEAD) &&
-	rm "$head" &&
-	ln -s "$ref" "$head" &&
-	test_must_fail git -C here checkout newmaster
-'
-
-test_expect_success 'not die the same branch is already checked out' '
-	(
-		cd here &&
-		git worktree add --force anothernewmaster newmaster
-	)
-'
-
-test_expect_success 'not die on re-checking out current branch' '
-	(
-		cd there &&
-		git checkout newmaster
-	)
-'
-
-test_expect_success '"add" from a bare repo' '
-	(
-		git clone --bare . bare &&
-		cd bare &&
-		git worktree add -b bare-master ../there2 master
-	)
-'
-
-test_expect_success 'checkout from a bare repo without "add"' '
-	(
-		cd bare &&
-		test_must_fail git checkout master
-	)
-'
-
-test_expect_success '"add" default branch of a bare repo' '
-	(
-		git clone --bare . bare2 &&
-		cd bare2 &&
-		git worktree add ../there3 master
-	)
-'
-
-test_expect_success 'checkout with grafts' '
-	test_when_finished rm .git/info/grafts &&
-	test_commit abc &&
-	SHA1=$(git rev-parse HEAD) &&
-	test_commit def &&
-	test_commit xyz &&
-	echo "$(git rev-parse HEAD) $SHA1" >.git/info/grafts &&
-	cat >expected <<-\EOF &&
-	xyz
-	abc
-	EOF
-	git log --format=%s -2 >actual &&
-	test_cmp expected actual &&
-	git worktree add --detach grafted master &&
-	git --git-dir=grafted/.git log --format=%s -2 >actual &&
-	test_cmp expected actual
-'
-
-test_expect_success '"add" from relative HEAD' '
-	test_commit a &&
-	test_commit b &&
-	test_commit c &&
-	git rev-parse HEAD~1 >expected &&
-	git worktree add relhead HEAD~1 &&
-	git -C relhead rev-parse HEAD >actual &&
-	test_cmp expected actual
-'
-
-test_expect_success '"add -b" with <branch> omitted' '
-	git worktree add -b burble flornk &&
-	test_cmp_rev HEAD burble
-'
-
-test_expect_success '"add --detach" with <branch> omitted' '
-	git worktree add --detach fishhook &&
-	git rev-parse HEAD >expected &&
-	git -C fishhook rev-parse HEAD >actual &&
-	test_cmp expected actual &&
-	test_must_fail git -C fishhook symbolic-ref HEAD
-'
-
-test_expect_success '"add" with <branch> omitted' '
-	git worktree add wiffle/bat &&
-	test_cmp_rev HEAD bat
-'
-
-test_expect_success '"add" checks out existing branch of dwimd name' '
-	git branch dwim HEAD~1 &&
-	git worktree add dwim &&
-	test_cmp_rev HEAD~1 dwim &&
-	(
-		cd dwim &&
-		test_cmp_rev HEAD dwim
-	)
-'
-
-test_expect_success '"add <path>" dwim fails with checked out branch' '
-	git checkout -b test-branch &&
-	test_must_fail git worktree add test-branch &&
-	test_path_is_missing test-branch
-'
-
-test_expect_success '"add --force" with existing dwimd name doesnt die' '
-	git checkout test-branch &&
-	git worktree add --force test-branch
-'
-
-test_expect_success '"add" no auto-vivify with --detach and <branch> omitted' '
-	git worktree add --detach mish/mash &&
-	test_must_fail git rev-parse mash -- &&
-	test_must_fail git -C mish/mash symbolic-ref HEAD
-'
-
-test_expect_success '"add" -b/-B mutually exclusive' '
-	test_must_fail git worktree add -b poodle -B poodle bamboo master
-'
-
-test_expect_success '"add" -b/--detach mutually exclusive' '
-	test_must_fail git worktree add -b poodle --detach bamboo master
-'
-
-test_expect_success '"add" -B/--detach mutually exclusive' '
-	test_must_fail git worktree add -B poodle --detach bamboo master
-'
-
-test_expect_success '"add -B" fails if the branch is checked out' '
-	git rev-parse newmaster >before &&
-	test_must_fail git worktree add -B newmaster bamboo master &&
-	git rev-parse newmaster >after &&
-	test_cmp before after
-'
-
-test_expect_success 'add -B' '
-	git worktree add -B poodle bamboo2 master^ &&
-	git -C bamboo2 symbolic-ref HEAD >actual &&
-	echo refs/heads/poodle >expected &&
-	test_cmp expected actual &&
-	test_cmp_rev master^ poodle
-'
-
-test_expect_success 'local clone from linked checkout' '
-	git clone --local here here-clone &&
-	( cd here-clone && git fsck )
-'
-
-test_expect_success 'local clone --shared from linked checkout' '
-	git -C bare worktree add --detach ../baretree &&
-	git clone --local --shared baretree bare-clone &&
-	grep /bare/ bare-clone/.git/objects/info/alternates
-'
-
-test_expect_success '"add" worktree with --no-checkout' '
-	git worktree add --no-checkout -b swamp swamp &&
-	! test -e swamp/init.t &&
-	git -C swamp reset --hard &&
-	test_cmp init.t swamp/init.t
-'
-
-test_expect_success '"add" worktree with --checkout' '
-	git worktree add --checkout -b swmap2 swamp2 &&
-	test_cmp init.t swamp2/init.t
-'
-
-test_expect_success 'put a worktree under rebase' '
-	git worktree add under-rebase &&
-	(
-		cd under-rebase &&
-		set_fake_editor &&
-		FAKE_LINES="edit 1" git rebase -i HEAD^ &&
-		git worktree list | grep "under-rebase.*detached HEAD"
-	)
-'
-
-test_expect_success 'add a worktree, checking out a rebased branch' '
-	test_must_fail git worktree add new-rebase under-rebase &&
-	! test -d new-rebase
-'
-
-test_expect_success 'checking out a rebased branch from another worktree' '
-	git worktree add new-place &&
-	test_must_fail git -C new-place checkout under-rebase
-'
-
-test_expect_success 'not allow to delete a branch under rebase' '
-	(
-		cd under-rebase &&
-		test_must_fail git branch -D under-rebase
-	)
-'
-
-test_expect_success 'rename a branch under rebase not allowed' '
-	test_must_fail git branch -M under-rebase rebase-with-new-name
-'
-
-test_expect_success 'check out from current worktree branch ok' '
-	(
-		cd under-rebase &&
-		git checkout under-rebase &&
-		git checkout - &&
-		git rebase --abort
-	)
-'
-
-test_expect_success 'checkout a branch under bisect' '
-	git worktree add under-bisect &&
-	(
-		cd under-bisect &&
-		git bisect start &&
-		git bisect bad &&
-		git bisect good HEAD~2 &&
-		git worktree list | grep "under-bisect.*detached HEAD" &&
-		test_must_fail git worktree add new-bisect under-bisect &&
-		! test -d new-bisect
-	)
-'
-
-test_expect_success 'rename a branch under bisect not allowed' '
-	test_must_fail git branch -M under-bisect bisect-with-new-name
-'
-# Is branch "refs/heads/$1" set to pull from "$2/$3"?
-test_branch_upstream () {
-	printf "%s\n" "$2" "refs/heads/$3" >expect.upstream &&
-	{
-		git config "branch.$1.remote" &&
-		git config "branch.$1.merge"
-	} >actual.upstream &&
-	test_cmp expect.upstream actual.upstream
-}
-
-test_expect_success '--track sets up tracking' '
-	test_when_finished rm -rf track &&
-	git worktree add --track -b track track master &&
-	test_branch_upstream track . master
-'
-
-# setup remote repository $1 and repository $2 with $1 set up as
-# remote.  The remote has two branches, master and foo.
-setup_remote_repo () {
-	git init $1 &&
-	(
-		cd $1 &&
-		test_commit $1_master &&
-		git checkout -b foo &&
-		test_commit upstream_foo
-	) &&
-	git init $2 &&
-	(
-		cd $2 &&
-		test_commit $2_master &&
-		git remote add $1 ../$1 &&
-		git config remote.$1.fetch \
-			"refs/heads/*:refs/remotes/$1/*" &&
-		git fetch --all
-	)
-}
-
-test_expect_success '--no-track avoids setting up tracking' '
-	test_when_finished rm -rf repo_upstream repo_local foo &&
-	setup_remote_repo repo_upstream repo_local &&
-	(
-		cd repo_local &&
-		git worktree add --no-track -b foo ../foo repo_upstream/foo
-	) &&
-	(
-		cd foo &&
-		test_must_fail git config "branch.foo.remote" &&
-		test_must_fail git config "branch.foo.merge" &&
-		test_cmp_rev refs/remotes/repo_upstream/foo refs/heads/foo
-	)
-'
-
-test_expect_success '"add" <path> <non-existent-branch> fails' '
-	test_must_fail git worktree add foo non-existent
-'
-
-test_expect_success '"add" <path> <branch> dwims' '
-	test_when_finished rm -rf repo_upstream repo_dwim foo &&
-	setup_remote_repo repo_upstream repo_dwim &&
-	git init repo_dwim &&
-	(
-		cd repo_dwim &&
-		git worktree add ../foo foo
-	) &&
-	(
-		cd foo &&
-		test_branch_upstream foo repo_upstream foo &&
-		test_cmp_rev refs/remotes/repo_upstream/foo refs/heads/foo
-	)
-'
-
-test_expect_success 'git worktree add does not match remote' '
-	test_when_finished rm -rf repo_a repo_b foo &&
-	setup_remote_repo repo_a repo_b &&
-	(
-		cd repo_b &&
-		git worktree add ../foo
-	) &&
-	(
-		cd foo &&
-		test_must_fail git config "branch.foo.remote" &&
-		test_must_fail git config "branch.foo.merge" &&
-		! test_cmp_rev refs/remotes/repo_a/foo refs/heads/foo
-	)
-'
-
-test_expect_success 'git worktree add --guess-remote sets up tracking' '
-	test_when_finished rm -rf repo_a repo_b foo &&
-	setup_remote_repo repo_a repo_b &&
-	(
-		cd repo_b &&
-		git worktree add --guess-remote ../foo
-	) &&
-	(
-		cd foo &&
-		test_branch_upstream foo repo_a foo &&
-		test_cmp_rev refs/remotes/repo_a/foo refs/heads/foo
-	)
-'
-
-test_expect_success 'git worktree add with worktree.guessRemote sets up tracking' '
-	test_when_finished rm -rf repo_a repo_b foo &&
-	setup_remote_repo repo_a repo_b &&
-	(
-		cd repo_b &&
-		git config worktree.guessRemote true &&
-		git worktree add ../foo
-	) &&
-	(
-		cd foo &&
-		test_branch_upstream foo repo_a foo &&
-		test_cmp_rev refs/remotes/repo_a/foo refs/heads/foo
-	)
-'
-
-test_expect_success 'git worktree --no-guess-remote option overrides config' '
-	test_when_finished rm -rf repo_a repo_b foo &&
-	setup_remote_repo repo_a repo_b &&
-	(
-		cd repo_b &&
-		git config worktree.guessRemote true &&
-		git worktree add --no-guess-remote ../foo
-	) &&
-	(
-		cd foo &&
-		test_must_fail git config "branch.foo.remote" &&
-		test_must_fail git config "branch.foo.merge" &&
-		! test_cmp_rev refs/remotes/repo_a/foo refs/heads/foo
-	)
-'
-
-post_checkout_hook () {
-	gitdir=${1:-.git}
-	test_when_finished "rm -f $gitdir/hooks/post-checkout" &&
-	mkdir -p $gitdir/hooks &&
-	write_script $gitdir/hooks/post-checkout <<-\EOF
-	{
-		echo $*
-		git rev-parse --git-dir --show-toplevel
-	} >hook.actual
-	EOF
-}
-
-test_expect_success '"add" invokes post-checkout hook (branch)' '
-	post_checkout_hook &&
-	{
-		echo $ZERO_OID $(git rev-parse HEAD) 1 &&
-		echo $(pwd)/.git/worktrees/gumby &&
-		echo $(pwd)/gumby
-	} >hook.expect &&
-	git worktree add gumby &&
-	test_cmp hook.expect gumby/hook.actual
-'
-
-test_expect_success '"add" invokes post-checkout hook (detached)' '
-	post_checkout_hook &&
-	{
-		echo $ZERO_OID $(git rev-parse HEAD) 1 &&
-		echo $(pwd)/.git/worktrees/grumpy &&
-		echo $(pwd)/grumpy
-	} >hook.expect &&
-	git worktree add --detach grumpy &&
-	test_cmp hook.expect grumpy/hook.actual
-'
-
-test_expect_success '"add --no-checkout" suppresses post-checkout hook' '
-	post_checkout_hook &&
-	rm -f hook.actual &&
-	git worktree add --no-checkout gloopy &&
-	test_path_is_missing gloopy/hook.actual
-'
-
-test_expect_success '"add" in other worktree invokes post-checkout hook' '
-	post_checkout_hook &&
-	{
-		echo $ZERO_OID $(git rev-parse HEAD) 1 &&
-		echo $(pwd)/.git/worktrees/guppy &&
-		echo $(pwd)/guppy
-	} >hook.expect &&
-	git -C gloopy worktree add --detach ../guppy &&
-	test_cmp hook.expect guppy/hook.actual
-'
-
-test_expect_success '"add" in bare repo invokes post-checkout hook' '
-	rm -rf bare &&
-	git clone --bare . bare &&
-	{
-		echo $ZERO_OID $(git --git-dir=bare rev-parse HEAD) 1 &&
-		echo $(pwd)/bare/worktrees/goozy &&
-		echo $(pwd)/goozy
-	} >hook.expect &&
-	post_checkout_hook bare &&
-	git -C bare worktree add --detach ../goozy &&
-	test_cmp hook.expect goozy/hook.actual
-'
-
-test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t2026-checkout-pathspec-file.sh 1.2.3+git2.25.1-1/git/t/t2026-checkout-pathspec-file.sh
--- 1.2.1+git2.18.0-1/git/t/t2026-checkout-pathspec-file.sh	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t2026-checkout-pathspec-file.sh	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,139 @@
+#!/bin/sh
+
+test_description='checkout --pathspec-from-file'
+
+. ./test-lib.sh
+
+test_tick
+
+test_expect_success setup '
+	test_commit file0 &&
+
+	echo 1 >fileA.t &&
+	echo 1 >fileB.t &&
+	echo 1 >fileC.t &&
+	echo 1 >fileD.t &&
+	git add fileA.t fileB.t fileC.t fileD.t &&
+	git commit -m "files 1" &&
+
+	echo 2 >fileA.t &&
+	echo 2 >fileB.t &&
+	echo 2 >fileC.t &&
+	echo 2 >fileD.t &&
+	git add fileA.t fileB.t fileC.t fileD.t &&
+	git commit -m "files 2" &&
+
+	git tag checkpoint
+'
+
+restore_checkpoint () {
+	git reset --hard checkpoint
+}
+
+verify_expect () {
+	git status --porcelain --untracked-files=no -- fileA.t fileB.t fileC.t fileD.t >actual &&
+	test_cmp expect actual
+}
+
+test_expect_success '--pathspec-from-file from stdin' '
+	restore_checkpoint &&
+
+	echo fileA.t | git checkout --pathspec-from-file=- HEAD^1 &&
+
+	cat >expect <<-\EOF &&
+	M  fileA.t
+	EOF
+	verify_expect
+'
+
+test_expect_success '--pathspec-from-file from file' '
+	restore_checkpoint &&
+
+	echo fileA.t >list &&
+	git checkout --pathspec-from-file=list HEAD^1 &&
+
+	cat >expect <<-\EOF &&
+	M  fileA.t
+	EOF
+	verify_expect
+'
+
+test_expect_success 'NUL delimiters' '
+	restore_checkpoint &&
+
+	printf "fileA.t\0fileB.t\0" | git checkout --pathspec-from-file=- --pathspec-file-nul HEAD^1 &&
+
+	cat >expect <<-\EOF &&
+	M  fileA.t
+	M  fileB.t
+	EOF
+	verify_expect
+'
+
+test_expect_success 'LF delimiters' '
+	restore_checkpoint &&
+
+	printf "fileA.t\nfileB.t\n" | git checkout --pathspec-from-file=- HEAD^1 &&
+
+	cat >expect <<-\EOF &&
+	M  fileA.t
+	M  fileB.t
+	EOF
+	verify_expect
+'
+
+test_expect_success 'no trailing delimiter' '
+	restore_checkpoint &&
+
+	printf "fileA.t\nfileB.t" | git checkout --pathspec-from-file=- HEAD^1 &&
+
+	cat >expect <<-\EOF &&
+	M  fileA.t
+	M  fileB.t
+	EOF
+	verify_expect
+'
+
+test_expect_success 'CRLF delimiters' '
+	restore_checkpoint &&
+
+	printf "fileA.t\r\nfileB.t\r\n" | git checkout --pathspec-from-file=- HEAD^1 &&
+
+	cat >expect <<-\EOF &&
+	M  fileA.t
+	M  fileB.t
+	EOF
+	verify_expect
+'
+
+test_expect_success 'quotes' '
+	restore_checkpoint &&
+
+	printf "\"file\\101.t\"" | git checkout --pathspec-from-file=- HEAD^1 &&
+
+	cat >expect <<-\EOF &&
+	M  fileA.t
+	EOF
+	verify_expect
+'
+
+test_expect_success 'quotes not compatible with --pathspec-file-nul' '
+	restore_checkpoint &&
+
+	printf "\"file\\101.t\"" >list &&
+	test_must_fail git checkout --pathspec-from-file=list --pathspec-file-nul HEAD^1
+'
+
+test_expect_success 'only touches what was listed' '
+	restore_checkpoint &&
+
+	printf "fileB.t\nfileC.t\n" | git checkout --pathspec-from-file=- HEAD^1 &&
+
+	cat >expect <<-\EOF &&
+	M  fileB.t
+	M  fileC.t
+	EOF
+	verify_expect
+'
+
+test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t2026-worktree-prune.sh 1.2.3+git2.25.1-1/git/t/t2026-worktree-prune.sh
--- 1.2.1+git2.18.0-1/git/t/t2026-worktree-prune.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t2026-worktree-prune.sh	1970-01-01 00:00:00.000000000 +0000
@@ -1,95 +0,0 @@
-#!/bin/sh
-
-test_description='prune $GIT_DIR/worktrees'
-
-. ./test-lib.sh
-
-test_expect_success initialize '
-	git commit --allow-empty -m init
-'
-
-test_expect_success 'worktree prune on normal repo' '
-	git worktree prune &&
-	test_must_fail git worktree prune abc
-'
-
-test_expect_success 'prune files inside $GIT_DIR/worktrees' '
-	mkdir .git/worktrees &&
-	: >.git/worktrees/abc &&
-	git worktree prune --verbose >actual &&
-	cat >expect <<EOF &&
-Removing worktrees/abc: not a valid directory
-EOF
-	test_i18ncmp expect actual &&
-	! test -f .git/worktrees/abc &&
-	! test -d .git/worktrees
-'
-
-test_expect_success 'prune directories without gitdir' '
-	mkdir -p .git/worktrees/def/abc &&
-	: >.git/worktrees/def/def &&
-	cat >expect <<EOF &&
-Removing worktrees/def: gitdir file does not exist
-EOF
-	git worktree prune --verbose >actual &&
-	test_i18ncmp expect actual &&
-	! test -d .git/worktrees/def &&
-	! test -d .git/worktrees
-'
-
-test_expect_success SANITY 'prune directories with unreadable gitdir' '
-	mkdir -p .git/worktrees/def/abc &&
-	: >.git/worktrees/def/def &&
-	: >.git/worktrees/def/gitdir &&
-	chmod u-r .git/worktrees/def/gitdir &&
-	git worktree prune --verbose >actual &&
-	test_i18ngrep "Removing worktrees/def: unable to read gitdir file" actual &&
-	! test -d .git/worktrees/def &&
-	! test -d .git/worktrees
-'
-
-test_expect_success 'prune directories with invalid gitdir' '
-	mkdir -p .git/worktrees/def/abc &&
-	: >.git/worktrees/def/def &&
-	: >.git/worktrees/def/gitdir &&
-	git worktree prune --verbose >actual &&
-	test_i18ngrep "Removing worktrees/def: invalid gitdir file" actual &&
-	! test -d .git/worktrees/def &&
-	! test -d .git/worktrees
-'
-
-test_expect_success 'prune directories with gitdir pointing to nowhere' '
-	mkdir -p .git/worktrees/def/abc &&
-	: >.git/worktrees/def/def &&
-	echo "$(pwd)"/nowhere >.git/worktrees/def/gitdir &&
-	git worktree prune --verbose >actual &&
-	test_i18ngrep "Removing worktrees/def: gitdir file points to non-existent location" actual &&
-	! test -d .git/worktrees/def &&
-	! test -d .git/worktrees
-'
-
-test_expect_success 'not prune locked checkout' '
-	test_when_finished rm -r .git/worktrees &&
-	mkdir -p .git/worktrees/ghi &&
-	: >.git/worktrees/ghi/locked &&
-	git worktree prune &&
-	test -d .git/worktrees/ghi
-'
-
-test_expect_success 'not prune recent checkouts' '
-	test_when_finished rm -r .git/worktrees &&
-	git worktree add jlm HEAD &&
-	test -d .git/worktrees/jlm &&
-	rm -rf jlm &&
-	git worktree prune --verbose --expire=2.days.ago &&
-	test -d .git/worktrees/jlm
-'
-
-test_expect_success 'not prune proper checkouts' '
-	test_when_finished rm -r .git/worktrees &&
-	git worktree add --detach "$PWD/nop" master &&
-	git worktree prune &&
-	test -d .git/worktrees/nop
-'
-
-test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t2027-worktree-list.sh 1.2.3+git2.25.1-1/git/t/t2027-worktree-list.sh
--- 1.2.1+git2.18.0-1/git/t/t2027-worktree-list.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t2027-worktree-list.sh	1970-01-01 00:00:00.000000000 +0000
@@ -1,154 +0,0 @@
-#!/bin/sh
-
-test_description='test git worktree list'
-
-. ./test-lib.sh
-
-test_expect_success 'setup' '
-	test_commit init
-'
-
-test_expect_success 'rev-parse --git-common-dir on main worktree' '
-	git rev-parse --git-common-dir >actual &&
-	echo .git >expected &&
-	test_cmp expected actual &&
-	mkdir sub &&
-	git -C sub rev-parse --git-common-dir >actual2 &&
-	echo ../.git >expected2 &&
-	test_cmp expected2 actual2
-'
-
-test_expect_success 'rev-parse --git-path objects linked worktree' '
-	echo "$(git rev-parse --show-toplevel)/.git/objects" >expect &&
-	test_when_finished "rm -rf linked-tree actual expect && git worktree prune" &&
-	git worktree add --detach linked-tree master &&
-	git -C linked-tree rev-parse --git-path objects >actual &&
-	test_cmp expect actual
-'
-
-test_expect_success '"list" all worktrees from main' '
-	echo "$(git rev-parse --show-toplevel) $(git rev-parse --short HEAD) [$(git symbolic-ref --short HEAD)]" >expect &&
-	test_when_finished "rm -rf here out actual expect && git worktree prune" &&
-	git worktree add --detach here master &&
-	echo "$(git -C here rev-parse --show-toplevel) $(git rev-parse --short HEAD) (detached HEAD)" >>expect &&
-	git worktree list >out &&
-	sed "s/  */ /g" <out >actual &&
-	test_cmp expect actual
-'
-
-test_expect_success '"list" all worktrees from linked' '
-	echo "$(git rev-parse --show-toplevel) $(git rev-parse --short HEAD) [$(git symbolic-ref --short HEAD)]" >expect &&
-	test_when_finished "rm -rf here out actual expect && git worktree prune" &&
-	git worktree add --detach here master &&
-	echo "$(git -C here rev-parse --show-toplevel) $(git rev-parse --short HEAD) (detached HEAD)" >>expect &&
-	git -C here worktree list >out &&
-	sed "s/  */ /g" <out >actual &&
-	test_cmp expect actual
-'
-
-test_expect_success '"list" all worktrees --porcelain' '
-	echo "worktree $(git rev-parse --show-toplevel)" >expect &&
-	echo "HEAD $(git rev-parse HEAD)" >>expect &&
-	echo "branch $(git symbolic-ref HEAD)" >>expect &&
-	echo >>expect &&
-	test_when_finished "rm -rf here actual expect && git worktree prune" &&
-	git worktree add --detach here master &&
-	echo "worktree $(git -C here rev-parse --show-toplevel)" >>expect &&
-	echo "HEAD $(git rev-parse HEAD)" >>expect &&
-	echo "detached" >>expect &&
-	echo >>expect &&
-	git worktree list --porcelain >actual &&
-	test_cmp expect actual
-'
-
-test_expect_success 'bare repo setup' '
-	git init --bare bare1 &&
-	echo "data" >file1 &&
-	git add file1 &&
-	git commit -m"File1: add data" &&
-	git push bare1 master &&
-	git reset --hard HEAD^
-'
-
-test_expect_success '"list" all worktrees from bare main' '
-	test_when_finished "rm -rf there out actual expect && git -C bare1 worktree prune" &&
-	git -C bare1 worktree add --detach ../there master &&
-	echo "$(pwd)/bare1 (bare)" >expect &&
-	echo "$(git -C there rev-parse --show-toplevel) $(git -C there rev-parse --short HEAD) (detached HEAD)" >>expect &&
-	git -C bare1 worktree list >out &&
-	sed "s/  */ /g" <out >actual &&
-	test_cmp expect actual
-'
-
-test_expect_success '"list" all worktrees --porcelain from bare main' '
-	test_when_finished "rm -rf there actual expect && git -C bare1 worktree prune" &&
-	git -C bare1 worktree add --detach ../there master &&
-	echo "worktree $(pwd)/bare1" >expect &&
-	echo "bare" >>expect &&
-	echo >>expect &&
-	echo "worktree $(git -C there rev-parse --show-toplevel)" >>expect &&
-	echo "HEAD $(git -C there rev-parse HEAD)" >>expect &&
-	echo "detached" >>expect &&
-	echo >>expect &&
-	git -C bare1 worktree list --porcelain >actual &&
-	test_cmp expect actual
-'
-
-test_expect_success '"list" all worktrees from linked with a bare main' '
-	test_when_finished "rm -rf there out actual expect && git -C bare1 worktree prune" &&
-	git -C bare1 worktree add --detach ../there master &&
-	echo "$(pwd)/bare1 (bare)" >expect &&
-	echo "$(git -C there rev-parse --show-toplevel) $(git -C there rev-parse --short HEAD) (detached HEAD)" >>expect &&
-	git -C there worktree list >out &&
-	sed "s/  */ /g" <out >actual &&
-	test_cmp expect actual
-'
-
-test_expect_success 'bare repo cleanup' '
-	rm -rf bare1
-'
-
-test_expect_success 'broken main worktree still at the top' '
-	git init broken-main &&
-	(
-		cd broken-main &&
-		test_commit new &&
-		git worktree add linked &&
-		cat >expected <<-EOF &&
-		worktree $(pwd)
-		HEAD $ZERO_OID
-
-		EOF
-		cd linked &&
-		echo "worktree $(pwd)" >expected &&
-		echo "ref: .broken" >../.git/HEAD &&
-		git worktree list --porcelain >out &&
-		head -n 3 out >actual &&
-		test_cmp ../expected actual &&
-		git worktree list >out &&
-		head -n 1 out >actual.2 &&
-		grep -F "(error)" actual.2
-	)
-'
-
-test_expect_success 'linked worktrees are sorted' '
-	mkdir sorted &&
-	git init sorted/main &&
-	(
-		cd sorted/main &&
-		test_tick &&
-		test_commit new &&
-		git worktree add ../first &&
-		git worktree add ../second &&
-		git worktree list --porcelain >out &&
-		grep ^worktree out >actual
-	) &&
-	cat >expected <<-EOF &&
-	worktree $(pwd)/sorted/main
-	worktree $(pwd)/sorted/first
-	worktree $(pwd)/sorted/second
-	EOF
-	test_cmp expected sorted/main/actual
-'
-
-test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t2028-worktree-move.sh 1.2.3+git2.25.1-1/git/t/t2028-worktree-move.sh
--- 1.2.1+git2.18.0-1/git/t/t2028-worktree-move.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t2028-worktree-move.sh	1970-01-01 00:00:00.000000000 +0000
@@ -1,144 +0,0 @@
-#!/bin/sh
-
-test_description='test git worktree move, remove, lock and unlock'
-
-. ./test-lib.sh
-
-test_expect_success 'setup' '
-	test_commit init &&
-	git worktree add source &&
-	git worktree list --porcelain >out &&
-	grep "^worktree" out >actual &&
-	cat <<-EOF >expected &&
-	worktree $(pwd)
-	worktree $(pwd)/source
-	EOF
-	test_cmp expected actual
-'
-
-test_expect_success 'lock main worktree' '
-	test_must_fail git worktree lock .
-'
-
-test_expect_success 'lock linked worktree' '
-	git worktree lock --reason hahaha source &&
-	echo hahaha >expected &&
-	test_cmp expected .git/worktrees/source/locked
-'
-
-test_expect_success 'lock linked worktree from another worktree' '
-	rm .git/worktrees/source/locked &&
-	git worktree add elsewhere &&
-	git -C elsewhere worktree lock --reason hahaha ../source &&
-	echo hahaha >expected &&
-	test_cmp expected .git/worktrees/source/locked
-'
-
-test_expect_success 'lock worktree twice' '
-	test_must_fail git worktree lock source &&
-	echo hahaha >expected &&
-	test_cmp expected .git/worktrees/source/locked
-'
-
-test_expect_success 'lock worktree twice (from the locked worktree)' '
-	test_must_fail git -C source worktree lock . &&
-	echo hahaha >expected &&
-	test_cmp expected .git/worktrees/source/locked
-'
-
-test_expect_success 'unlock main worktree' '
-	test_must_fail git worktree unlock .
-'
-
-test_expect_success 'unlock linked worktree' '
-	git worktree unlock source &&
-	test_path_is_missing .git/worktrees/source/locked
-'
-
-test_expect_success 'unlock worktree twice' '
-	test_must_fail git worktree unlock source &&
-	test_path_is_missing .git/worktrees/source/locked
-'
-
-test_expect_success 'move non-worktree' '
-	mkdir abc &&
-	test_must_fail git worktree move abc def
-'
-
-test_expect_success 'move locked worktree' '
-	git worktree lock source &&
-	test_when_finished "git worktree unlock source" &&
-	test_must_fail git worktree move source destination
-'
-
-test_expect_success 'move worktree' '
-	git worktree move source destination &&
-	test_path_is_missing source &&
-	git worktree list --porcelain >out &&
-	grep "^worktree.*/destination$" out &&
-	! grep "^worktree.*/source$" out &&
-	git -C destination log --format=%s >actual2 &&
-	echo init >expected2 &&
-	test_cmp expected2 actual2
-'
-
-test_expect_success 'move main worktree' '
-	test_must_fail git worktree move . def
-'
-
-test_expect_success 'move worktree to another dir' '
-	mkdir some-dir &&
-	git worktree move destination some-dir &&
-	test_when_finished "git worktree move some-dir/destination destination" &&
-	test_path_is_missing destination &&
-	git worktree list --porcelain >out &&
-	grep "^worktree.*/some-dir/destination$" out &&
-	git -C some-dir/destination log --format=%s >actual2 &&
-	echo init >expected2 &&
-	test_cmp expected2 actual2
-'
-
-test_expect_success 'remove main worktree' '
-	test_must_fail git worktree remove .
-'
-
-test_expect_success 'remove locked worktree' '
-	git worktree lock destination &&
-	test_when_finished "git worktree unlock destination" &&
-	test_must_fail git worktree remove destination
-'
-
-test_expect_success 'remove worktree with dirty tracked file' '
-	echo dirty >>destination/init.t &&
-	test_when_finished "git -C destination checkout init.t" &&
-	test_must_fail git worktree remove destination
-'
-
-test_expect_success 'remove worktree with untracked file' '
-	: >destination/untracked &&
-	test_must_fail git worktree remove destination
-'
-
-test_expect_success 'force remove worktree with untracked file' '
-	git worktree remove --force destination &&
-	test_path_is_missing destination
-'
-
-test_expect_success 'remove missing worktree' '
-	git worktree add to-be-gone &&
-	test -d .git/worktrees/to-be-gone &&
-	mv to-be-gone gone &&
-	git worktree remove to-be-gone &&
-	test_path_is_missing .git/worktrees/to-be-gone
-'
-
-test_expect_success 'NOT remove missing-but-locked worktree' '
-	git worktree add gone-but-locked &&
-	git worktree lock gone-but-locked &&
-	test -d .git/worktrees/gone-but-locked &&
-	mv gone-but-locked really-gone-now &&
-	test_must_fail git worktree remove gone-but-locked &&
-	test_path_is_dir .git/worktrees/gone-but-locked
-'
-
-test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t2060-switch.sh 1.2.3+git2.25.1-1/git/t/t2060-switch.sh
--- 1.2.1+git2.18.0-1/git/t/t2060-switch.sh	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t2060-switch.sh	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,96 @@
+#!/bin/sh
+
+test_description='switch basic functionality'
+
+. ./test-lib.sh
+
+test_expect_success 'setup' '
+	test_commit first &&
+	git branch first-branch &&
+	test_commit second &&
+	test_commit third &&
+	git remote add origin nohost:/nopath &&
+	git update-ref refs/remotes/origin/foo first-branch
+'
+
+test_expect_success 'switch branch no arguments' '
+	test_must_fail git switch
+'
+
+test_expect_success 'switch branch' '
+	git switch first-branch &&
+	test_path_is_missing second.t
+'
+
+test_expect_success 'switch and detach' '
+	test_when_finished git switch master &&
+	test_must_fail git switch master^{commit} &&
+	git switch --detach master^{commit} &&
+	test_must_fail git symbolic-ref HEAD
+'
+
+test_expect_success 'switch and detach current branch' '
+	test_when_finished git switch master &&
+	git switch master &&
+	git switch --detach &&
+	test_must_fail git symbolic-ref HEAD
+'
+
+test_expect_success 'switch and create branch' '
+	test_when_finished git switch master &&
+	git switch -c temp master^ &&
+	test_cmp_rev master^ refs/heads/temp &&
+	echo refs/heads/temp >expected-branch &&
+	git symbolic-ref HEAD >actual-branch &&
+	test_cmp expected-branch actual-branch
+'
+
+test_expect_success 'force create branch from HEAD' '
+	test_when_finished git switch master &&
+	git switch --detach master &&
+	test_must_fail git switch -c temp &&
+	git switch -C temp &&
+	test_cmp_rev master refs/heads/temp &&
+	echo refs/heads/temp >expected-branch &&
+	git symbolic-ref HEAD >actual-branch &&
+	test_cmp expected-branch actual-branch
+'
+
+test_expect_success 'new orphan branch from empty' '
+	test_when_finished git switch master &&
+	test_must_fail git switch --orphan new-orphan HEAD &&
+	git switch --orphan new-orphan &&
+	test_commit orphan &&
+	git cat-file commit refs/heads/new-orphan >commit &&
+	! grep ^parent commit &&
+	git ls-files >tracked-files &&
+	echo orphan.t >expected &&
+	test_cmp expected tracked-files
+'
+
+test_expect_success 'switching ignores file of same branch name' '
+	test_when_finished git switch master &&
+	: >first-branch &&
+	git switch first-branch &&
+	echo refs/heads/first-branch >expected &&
+	git symbolic-ref HEAD >actual &&
+	test_cmp expected actual
+'
+
+test_expect_success 'guess and create branch ' '
+	test_when_finished git switch master &&
+	test_must_fail git switch --no-guess foo &&
+	git switch foo &&
+	echo refs/heads/foo >expected &&
+	git symbolic-ref HEAD >actual &&
+	test_cmp expected actual
+'
+
+test_expect_success 'not switching when something is in progress' '
+	test_when_finished rm -f .git/MERGE_HEAD &&
+	# fake a merge-in-progress
+	cp .git/HEAD .git/MERGE_HEAD &&
+	test_must_fail git switch -d @^
+'
+
+test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t2070-restore.sh 1.2.3+git2.25.1-1/git/t/t2070-restore.sh
--- 1.2.1+git2.18.0-1/git/t/t2070-restore.sh	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t2070-restore.sh	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,126 @@
+#!/bin/sh
+
+test_description='restore basic functionality'
+
+. ./test-lib.sh
+
+test_expect_success 'setup' '
+	test_commit first &&
+	echo first-and-a-half >>first.t &&
+	git add first.t &&
+	test_commit second &&
+	echo one >one &&
+	echo two >two &&
+	echo untracked >untracked &&
+	echo ignored >ignored &&
+	echo /ignored >.gitignore &&
+	git add one two .gitignore &&
+	git update-ref refs/heads/one master
+'
+
+test_expect_success 'restore without pathspec is not ok' '
+	test_must_fail git restore &&
+	test_must_fail git restore --source=first
+'
+
+test_expect_success 'restore a file, ignoring branch of same name' '
+	cat one >expected &&
+	echo dirty >>one &&
+	git restore one &&
+	test_cmp expected one
+'
+
+test_expect_success 'restore a file on worktree from another ref' '
+	test_when_finished git reset --hard &&
+	git cat-file blob first:./first.t >expected &&
+	git restore --source=first first.t &&
+	test_cmp expected first.t &&
+	git cat-file blob HEAD:./first.t >expected &&
+	git show :first.t >actual &&
+	test_cmp expected actual
+'
+
+test_expect_success 'restore a file in the index from another ref' '
+	test_when_finished git reset --hard &&
+	git cat-file blob first:./first.t >expected &&
+	git restore --source=first --staged first.t &&
+	git show :first.t >actual &&
+	test_cmp expected actual &&
+	git cat-file blob HEAD:./first.t >expected &&
+	test_cmp expected first.t
+'
+
+test_expect_success 'restore a file in both the index and worktree from another ref' '
+	test_when_finished git reset --hard &&
+	git cat-file blob first:./first.t >expected &&
+	git restore --source=first --staged --worktree first.t &&
+	git show :first.t >actual &&
+	test_cmp expected actual &&
+	test_cmp expected first.t
+'
+
+test_expect_success 'restore --staged uses HEAD as source' '
+	test_when_finished git reset --hard &&
+	git cat-file blob :./first.t >expected &&
+	echo index-dirty >>first.t &&
+	git add first.t &&
+	git restore --staged first.t &&
+	git cat-file blob :./first.t >actual &&
+	test_cmp expected actual
+'
+
+test_expect_success 'restore --ignore-unmerged ignores unmerged entries' '
+	git init unmerged &&
+	(
+		cd unmerged &&
+		echo one >unmerged &&
+		echo one >common &&
+		git add unmerged common &&
+		git commit -m common &&
+		git switch -c first &&
+		echo first >unmerged &&
+		git commit -am first &&
+		git switch -c second master &&
+		echo second >unmerged &&
+		git commit -am second &&
+		test_must_fail git merge first &&
+
+		echo dirty >>common &&
+		test_must_fail git restore . &&
+
+		git restore --ignore-unmerged --quiet . >output 2>&1 &&
+		git diff common >diff-output &&
+		test_must_be_empty output &&
+		test_must_be_empty diff-output
+	)
+'
+
+test_expect_success 'restore --staged adds deleted intent-to-add file back to index' '
+	echo "nonempty" >nonempty &&
+	>empty &&
+	git add nonempty empty &&
+	git commit -m "create files to be deleted" &&
+	git rm --cached nonempty empty &&
+	git add -N nonempty empty &&
+	git restore --staged nonempty empty &&
+	git diff --cached --exit-code
+'
+
+test_expect_success 'restore --staged invalidates cache tree for deletions' '
+	test_when_finished git reset --hard &&
+	>new1 &&
+	>new2 &&
+	git add new1 new2 &&
+
+	# It is important to commit and then reset here, so that the index
+	# contains a valid cache-tree for the "both" tree.
+	git commit -m both &&
+	git reset --soft HEAD^ &&
+
+	git restore --staged new1 &&
+	git commit -m "just new2" &&
+	git rev-parse HEAD:new2 &&
+	test_must_fail git rev-parse HEAD:new1
+'
+
+test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t2071-restore-patch.sh 1.2.3+git2.25.1-1/git/t/t2071-restore-patch.sh
--- 1.2.1+git2.18.0-1/git/t/t2071-restore-patch.sh	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t2071-restore-patch.sh	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,110 @@
+#!/bin/sh
+
+test_description='git restore --patch'
+
+. ./lib-patch-mode.sh
+
+test_expect_success PERL 'setup' '
+	mkdir dir &&
+	echo parent >dir/foo &&
+	echo dummy >bar &&
+	git add bar dir/foo &&
+	git commit -m initial &&
+	test_tick &&
+	test_commit second dir/foo head &&
+	set_and_save_state bar bar_work bar_index &&
+	save_head
+'
+
+test_expect_success PERL 'restore -p without pathspec is fine' '
+	echo q >cmd &&
+	git restore -p <cmd
+'
+
+# note: bar sorts before dir/foo, so the first 'n' is always to skip 'bar'
+
+test_expect_success PERL 'saying "n" does nothing' '
+	set_and_save_state dir/foo work head &&
+	test_write_lines n n | git restore -p &&
+	verify_saved_state bar &&
+	verify_saved_state dir/foo
+'
+
+test_expect_success PERL 'git restore -p' '
+	set_and_save_state dir/foo work head &&
+	test_write_lines n y | git restore -p &&
+	verify_saved_state bar &&
+	verify_state dir/foo head head
+'
+
+test_expect_success PERL 'git restore -p with staged changes' '
+	set_state dir/foo work index &&
+	test_write_lines n y | git restore -p &&
+	verify_saved_state bar &&
+	verify_state dir/foo index index
+'
+
+test_expect_success PERL 'git restore -p --source=HEAD' '
+	set_state dir/foo work index &&
+	# the third n is to get out in case it mistakenly does not apply
+	test_write_lines n y n | git restore -p --source=HEAD &&
+	verify_saved_state bar &&
+	verify_state dir/foo head index
+'
+
+test_expect_success PERL 'git restore -p --source=HEAD^' '
+	set_state dir/foo work index &&
+	# the third n is to get out in case it mistakenly does not apply
+	test_write_lines n y n | git restore -p --source=HEAD^ &&
+	verify_saved_state bar &&
+	verify_state dir/foo parent index
+'
+
+test_expect_success PERL 'git restore -p handles deletion' '
+	set_state dir/foo work index &&
+	rm dir/foo &&
+	test_write_lines n y | git restore -p &&
+	verify_saved_state bar &&
+	verify_state dir/foo index index
+'
+
+# The idea in the rest is that bar sorts first, so we always say 'y'
+# first and if the path limiter fails it'll apply to bar instead of
+# dir/foo.  There's always an extra 'n' to reject edits to dir/foo in
+# the failure case (and thus get out of the loop).
+
+test_expect_success PERL 'path limiting works: dir' '
+	set_state dir/foo work head &&
+	test_write_lines y n | git restore -p dir &&
+	verify_saved_state bar &&
+	verify_state dir/foo head head
+'
+
+test_expect_success PERL 'path limiting works: -- dir' '
+	set_state dir/foo work head &&
+	test_write_lines y n | git restore -p -- dir &&
+	verify_saved_state bar &&
+	verify_state dir/foo head head
+'
+
+test_expect_success PERL 'path limiting works: HEAD^ -- dir' '
+	set_state dir/foo work head &&
+	# the third n is to get out in case it mistakenly does not apply
+	test_write_lines y n n | git restore -p --source=HEAD^ -- dir &&
+	verify_saved_state bar &&
+	verify_state dir/foo parent head
+'
+
+test_expect_success PERL 'path limiting works: foo inside dir' '
+	set_state dir/foo work head &&
+	# the third n is to get out in case it mistakenly does not apply
+	test_write_lines y n n | (cd dir && git restore -p foo) &&
+	verify_saved_state bar &&
+	verify_state dir/foo head head
+'
+
+test_expect_success PERL 'none of this moved HEAD' '
+	verify_saved_head
+'
+
+test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t2072-restore-pathspec-file.sh 1.2.3+git2.25.1-1/git/t/t2072-restore-pathspec-file.sh
--- 1.2.1+git2.18.0-1/git/t/t2072-restore-pathspec-file.sh	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t2072-restore-pathspec-file.sh	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,139 @@
+#!/bin/sh
+
+test_description='restore --pathspec-from-file'
+
+. ./test-lib.sh
+
+test_tick
+
+test_expect_success setup '
+	test_commit file0 &&
+
+	echo 1 >fileA.t &&
+	echo 1 >fileB.t &&
+	echo 1 >fileC.t &&
+	echo 1 >fileD.t &&
+	git add fileA.t fileB.t fileC.t fileD.t &&
+	git commit -m "files 1" &&
+
+	echo 2 >fileA.t &&
+	echo 2 >fileB.t &&
+	echo 2 >fileC.t &&
+	echo 2 >fileD.t &&
+	git add fileA.t fileB.t fileC.t fileD.t &&
+	git commit -m "files 2" &&
+
+	git tag checkpoint
+'
+
+restore_checkpoint () {
+	git reset --hard checkpoint
+}
+
+verify_expect () {
+	git status --porcelain --untracked-files=no -- fileA.t fileB.t fileC.t fileD.t >actual &&
+	test_cmp expect actual
+}
+
+test_expect_success '--pathspec-from-file from stdin' '
+	restore_checkpoint &&
+
+	echo fileA.t | git restore --pathspec-from-file=- --source=HEAD^1 &&
+
+	cat >expect <<-\EOF &&
+	 M fileA.t
+	EOF
+	verify_expect
+'
+
+test_expect_success '--pathspec-from-file from file' '
+	restore_checkpoint &&
+
+	echo fileA.t >list &&
+	git restore --pathspec-from-file=list --source=HEAD^1 &&
+
+	cat >expect <<-\EOF &&
+	 M fileA.t
+	EOF
+	verify_expect
+'
+
+test_expect_success 'NUL delimiters' '
+	restore_checkpoint &&
+
+	printf "fileA.t\0fileB.t\0" | git restore --pathspec-from-file=- --pathspec-file-nul --source=HEAD^1 &&
+
+	cat >expect <<-\EOF &&
+	 M fileA.t
+	 M fileB.t
+	EOF
+	verify_expect
+'
+
+test_expect_success 'LF delimiters' '
+	restore_checkpoint &&
+
+	printf "fileA.t\nfileB.t\n" | git restore --pathspec-from-file=- --source=HEAD^1 &&
+
+	cat >expect <<-\EOF &&
+	 M fileA.t
+	 M fileB.t
+	EOF
+	verify_expect
+'
+
+test_expect_success 'no trailing delimiter' '
+	restore_checkpoint &&
+
+	printf "fileA.t\nfileB.t" | git restore --pathspec-from-file=- --source=HEAD^1 &&
+
+	cat >expect <<-\EOF &&
+	 M fileA.t
+	 M fileB.t
+	EOF
+	verify_expect
+'
+
+test_expect_success 'CRLF delimiters' '
+	restore_checkpoint &&
+
+	printf "fileA.t\r\nfileB.t\r\n" | git restore --pathspec-from-file=- --source=HEAD^1 &&
+
+	cat >expect <<-\EOF &&
+	 M fileA.t
+	 M fileB.t
+	EOF
+	verify_expect
+'
+
+test_expect_success 'quotes' '
+	restore_checkpoint &&
+
+	printf "\"file\\101.t\"" | git restore --pathspec-from-file=- --source=HEAD^1 &&
+
+	cat >expect <<-\EOF &&
+	 M fileA.t
+	EOF
+	verify_expect
+'
+
+test_expect_success 'quotes not compatible with --pathspec-file-nul' '
+	restore_checkpoint &&
+
+	printf "\"file\\101.t\"" >list &&
+	test_must_fail git restore --pathspec-from-file=list --pathspec-file-nul --source=HEAD^1
+'
+
+test_expect_success 'only touches what was listed' '
+	restore_checkpoint &&
+
+	printf "fileB.t\nfileC.t\n" | git restore --pathspec-from-file=- --source=HEAD^1 &&
+
+	cat >expect <<-\EOF &&
+	 M fileB.t
+	 M fileC.t
+	EOF
+	verify_expect
+'
+
+test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t2101-update-index-reupdate.sh 1.2.3+git2.25.1-1/git/t/t2101-update-index-reupdate.sh
--- 1.2.1+git2.18.0-1/git/t/t2101-update-index-reupdate.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t2101-update-index-reupdate.sh	2020-02-17 04:47:35.000000000 +0000
@@ -73,7 +73,7 @@ test_expect_success 'update-index --upda
 	100644 $(git hash-object dir1/file3) 0	dir1/file3
 	100644 $file2 0	file2
 	EOF
-	test_cmp current expected
+	test_cmp expected current
 '
 
 test_expect_success 'update-index --update with pathspec' '
diff -pruN 1.2.1+git2.18.0-1/git/t/t2103-update-index-ignore-missing.sh 1.2.3+git2.25.1-1/git/t/t2103-update-index-ignore-missing.sh
--- 1.2.1+git2.18.0-1/git/t/t2103-update-index-ignore-missing.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t2103-update-index-ignore-missing.sh	2020-02-17 04:47:35.000000000 +0000
@@ -32,7 +32,7 @@ test_expect_success basics '
 		test_create_repo xyzzy &&
 		cd xyzzy &&
 		>file &&
-		git add file
+		git add file &&
 		git commit -m "sub initial"
 	) &&
 	git add xyzzy &&
diff -pruN 1.2.1+git2.18.0-1/git/t/t2200-add-update.sh 1.2.3+git2.25.1-1/git/t/t2200-add-update.sh
--- 1.2.1+git2.18.0-1/git/t/t2200-add-update.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t2200-add-update.sh	2020-02-17 04:47:35.000000000 +0000
@@ -88,9 +88,8 @@ test_expect_success 'non-qualified updat
 		echo even more >>sub2 &&
 		git add -u
 	) &&
-	: >expect &&
 	git diff-files --name-only >actual &&
-	test_cmp expect actual
+	test_must_be_empty actual
 '
 
 test_expect_success 'replace a file with a symlink' '
diff -pruN 1.2.1+git2.18.0-1/git/t/t2202-add-addremove.sh 1.2.3+git2.25.1-1/git/t/t2202-add-addremove.sh
--- 1.2.1+git2.18.0-1/git/t/t2202-add-addremove.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t2202-add-addremove.sh	2020-02-17 04:47:35.000000000 +0000
@@ -6,12 +6,12 @@ test_description='git add --all'
 
 test_expect_success setup '
 	(
-		echo .gitignore
+		echo .gitignore &&
 		echo will-remove
 	) >expect &&
 	(
-		echo actual
-		echo expect
+		echo actual &&
+		echo expect &&
 		echo ignored
 	) >.gitignore &&
 	git --literal-pathspecs add --all &&
@@ -25,10 +25,10 @@ test_expect_success setup '
 
 test_expect_success 'git add --all' '
 	(
-		echo .gitignore
-		echo not-ignored
-		echo "M	.gitignore"
-		echo "A	not-ignored"
+		echo .gitignore &&
+		echo not-ignored &&
+		echo "M	.gitignore" &&
+		echo "A	not-ignored" &&
 		echo "D	will-remove"
 	) >expect &&
 	>ignored &&
@@ -48,8 +48,7 @@ test_expect_success 'Just "git add" is a
 	>will-not-be-added &&
 	git add &&
 	git diff-index --name-status --cached HEAD >actual &&
-	>expect &&
-	test_cmp expect actual
+	test_must_be_empty actual
 '
 
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t2203-add-intent.sh 1.2.3+git2.25.1-1/git/t/t2203-add-intent.sh
--- 1.2.1+git2.18.0-1/git/t/t2203-add-intent.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t2203-add-intent.sh	2020-02-17 04:47:35.000000000 +0000
@@ -70,8 +70,7 @@ test_expect_success 'i-t-a entry is simp
 	git commit -m second &&
 	test $(git ls-tree HEAD -- nitfol | wc -l) = 0 &&
 	test $(git diff --name-only HEAD -- nitfol | wc -l) = 1 &&
-	test $(git diff --name-only --ita-invisible-in-index HEAD -- nitfol | wc -l) = 0 &&
-	test $(git diff --name-only --ita-invisible-in-index -- nitfol | wc -l) = 1
+	test $(git diff --name-only -- nitfol | wc -l) = 1
 '
 
 test_expect_success 'can commit with an unrelated i-t-a entry in index' '
@@ -99,13 +98,13 @@ test_expect_success 'cache-tree invalida
 
 	: >dir/bar &&
 	git add -N dir/bar &&
-	git diff --cached --name-only >actual &&
+	git diff --name-only >actual &&
 	echo dir/bar >expect &&
 	test_cmp expect actual &&
 
 	git write-tree >/dev/null &&
 
-	git diff --cached --name-only >actual &&
+	git diff --name-only >actual &&
 	echo dir/bar >expect &&
 	test_cmp expect actual
 '
@@ -186,7 +185,18 @@ test_expect_success 'rename detection fi
 		cat >expected.3 <<-EOF &&
 		2 .R N... 100644 100644 100644 $hash $hash R100 third	first
 		EOF
-		test_cmp expected.3 actual.3
+		test_cmp expected.3 actual.3 &&
+
+		git diff --stat >actual.4 &&
+		cat >expected.4 <<-EOF &&
+		 first => third | 0
+		 1 file changed, 0 insertions(+), 0 deletions(-)
+		EOF
+		test_cmp expected.4 actual.4 &&
+
+		git diff --cached --stat >actual.5 &&
+		test_must_be_empty actual.5
+
 	)
 '
 
@@ -222,5 +232,47 @@ test_expect_success 'double rename detec
 	)
 '
 
-test_done
+test_expect_success 'diff-files/diff-cached shows ita as new/not-new files' '
+	git reset --hard &&
+	echo new >new-ita &&
+	git add -N new-ita &&
+	git diff --summary >actual &&
+	echo " create mode 100644 new-ita" >expected &&
+	test_cmp expected actual &&
+	git diff --cached --summary >actual2 &&
+	test_must_be_empty actual2
+'
+
 
+test_expect_success '"diff HEAD" includes ita as new files' '
+	git reset --hard &&
+	echo new >new-ita &&
+	oid=$(git hash-object new-ita) &&
+	oid=$(git rev-parse --short $oid) &&
+	git add -N new-ita &&
+	git diff HEAD >actual &&
+	cat >expected <<-EOF &&
+	diff --git a/new-ita b/new-ita
+	new file mode 100644
+	index 0000000..$oid
+	--- /dev/null
+	+++ b/new-ita
+	@@ -0,0 +1 @@
+	+new
+	EOF
+	test_cmp expected actual
+'
+
+test_expect_success 'apply --intent-to-add' '
+	git reset --hard &&
+	echo new >new-ita &&
+	git add -N new-ita &&
+	git diff >expected &&
+	grep "new file" expected &&
+	git reset --hard &&
+	git apply --intent-to-add expected &&
+	git diff >actual &&
+	test_cmp expected actual
+'
+
+test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t2204-add-ignored.sh 1.2.3+git2.25.1-1/git/t/t2204-add-ignored.sh
--- 1.2.1+git2.18.0-1/git/t/t2204-add-ignored.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t2204-add-ignored.sh	2020-02-17 04:47:35.000000000 +0000
@@ -31,7 +31,7 @@ do
 		rm -f .git/index &&
 		test_must_fail git add "$i" 2>err &&
 		git ls-files "$i" >out &&
-		! test -s out
+		test_must_be_empty out
 	'
 
 	test_expect_success "complaints for ignored $i output" '
@@ -42,7 +42,7 @@ do
 		rm -f .git/index &&
 		test_must_fail git add "$i" file 2>err &&
 		git ls-files "$i" >out &&
-		! test -s out
+		test_must_be_empty out
 	'
 	test_expect_success "complaints for ignored $i with unignored file output" '
 		test_i18ngrep -e "Use -f if" err
@@ -57,7 +57,7 @@ do
 			cd dir &&
 			test_must_fail git add "$i" 2>err &&
 			git ls-files "$i" >out &&
-			! test -s out
+			test_must_be_empty out
 		)
 	'
 
@@ -77,7 +77,7 @@ do
 			cd sub &&
 			test_must_fail git add "$i" 2>err &&
 			git ls-files "$i" >out &&
-			! test -s out
+			test_must_be_empty out
 		)
 	'
 
diff -pruN 1.2.1+git2.18.0-1/git/t/t2400-worktree-add.sh 1.2.3+git2.25.1-1/git/t/t2400-worktree-add.sh
--- 1.2.1+git2.18.0-1/git/t/t2400-worktree-add.sh	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t2400-worktree-add.sh	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,614 @@
+#!/bin/sh
+
+test_description='test git worktree add'
+
+. ./test-lib.sh
+
+. "$TEST_DIRECTORY"/lib-rebase.sh
+
+test_expect_success 'setup' '
+	test_commit init
+'
+
+test_expect_success '"add" an existing worktree' '
+	mkdir -p existing/subtree &&
+	test_must_fail git worktree add --detach existing master
+'
+
+test_expect_success '"add" an existing empty worktree' '
+	mkdir existing_empty &&
+	git worktree add --detach existing_empty master
+'
+
+test_expect_success '"add" using shorthand - fails when no previous branch' '
+	test_must_fail git worktree add existing_short -
+'
+
+test_expect_success '"add" using - shorthand' '
+	git checkout -b newbranch &&
+	echo hello >myworld &&
+	git add myworld &&
+	git commit -m myworld &&
+	git checkout master &&
+	git worktree add short-hand - &&
+	echo refs/heads/newbranch >expect &&
+	git -C short-hand rev-parse --symbolic-full-name HEAD >actual &&
+	test_cmp expect actual
+'
+
+test_expect_success '"add" refuses to checkout locked branch' '
+	test_must_fail git worktree add zere master &&
+	! test -d zere &&
+	! test -d .git/worktrees/zere
+'
+
+test_expect_success 'checking out paths not complaining about linked checkouts' '
+	(
+	cd existing_empty &&
+	echo dirty >>init.t &&
+	git checkout master -- init.t
+	)
+'
+
+test_expect_success '"add" worktree' '
+	git rev-parse HEAD >expect &&
+	git worktree add --detach here master &&
+	(
+		cd here &&
+		test_cmp ../init.t init.t &&
+		test_must_fail git symbolic-ref HEAD &&
+		git rev-parse HEAD >actual &&
+		test_cmp ../expect actual &&
+		git fsck
+	)
+'
+
+test_expect_success '"add" worktree with lock' '
+	git rev-parse HEAD >expect &&
+	git worktree add --detach --lock here-with-lock master &&
+	test -f .git/worktrees/here-with-lock/locked
+'
+
+test_expect_success '"add" worktree from a subdir' '
+	(
+		mkdir sub &&
+		cd sub &&
+		git worktree add --detach here master &&
+		cd here &&
+		test_cmp ../../init.t init.t
+	)
+'
+
+test_expect_success '"add" from a linked checkout' '
+	(
+		cd here &&
+		git worktree add --detach nested-here master &&
+		cd nested-here &&
+		git fsck
+	)
+'
+
+test_expect_success '"add" worktree creating new branch' '
+	git worktree add -b newmaster there master &&
+	(
+		cd there &&
+		test_cmp ../init.t init.t &&
+		git symbolic-ref HEAD >actual &&
+		echo refs/heads/newmaster >expect &&
+		test_cmp expect actual &&
+		git fsck
+	)
+'
+
+test_expect_success 'die the same branch is already checked out' '
+	(
+		cd here &&
+		test_must_fail git checkout newmaster
+	)
+'
+
+test_expect_success SYMLINKS 'die the same branch is already checked out (symlink)' '
+	head=$(git -C there rev-parse --git-path HEAD) &&
+	ref=$(git -C there symbolic-ref HEAD) &&
+	rm "$head" &&
+	ln -s "$ref" "$head" &&
+	test_must_fail git -C here checkout newmaster
+'
+
+test_expect_success 'not die the same branch is already checked out' '
+	(
+		cd here &&
+		git worktree add --force anothernewmaster newmaster
+	)
+'
+
+test_expect_success 'not die on re-checking out current branch' '
+	(
+		cd there &&
+		git checkout newmaster
+	)
+'
+
+test_expect_success '"add" from a bare repo' '
+	(
+		git clone --bare . bare &&
+		cd bare &&
+		git worktree add -b bare-master ../there2 master
+	)
+'
+
+test_expect_success 'checkout from a bare repo without "add"' '
+	(
+		cd bare &&
+		test_must_fail git checkout master
+	)
+'
+
+test_expect_success '"add" default branch of a bare repo' '
+	(
+		git clone --bare . bare2 &&
+		cd bare2 &&
+		git worktree add ../there3 master
+	)
+'
+
+test_expect_success 'checkout with grafts' '
+	test_when_finished rm .git/info/grafts &&
+	test_commit abc &&
+	SHA1=$(git rev-parse HEAD) &&
+	test_commit def &&
+	test_commit xyz &&
+	echo "$(git rev-parse HEAD) $SHA1" >.git/info/grafts &&
+	cat >expected <<-\EOF &&
+	xyz
+	abc
+	EOF
+	git log --format=%s -2 >actual &&
+	test_cmp expected actual &&
+	git worktree add --detach grafted master &&
+	git --git-dir=grafted/.git log --format=%s -2 >actual &&
+	test_cmp expected actual
+'
+
+test_expect_success '"add" from relative HEAD' '
+	test_commit a &&
+	test_commit b &&
+	test_commit c &&
+	git rev-parse HEAD~1 >expected &&
+	git worktree add relhead HEAD~1 &&
+	git -C relhead rev-parse HEAD >actual &&
+	test_cmp expected actual
+'
+
+test_expect_success '"add -b" with <branch> omitted' '
+	git worktree add -b burble flornk &&
+	test_cmp_rev HEAD burble
+'
+
+test_expect_success '"add --detach" with <branch> omitted' '
+	git worktree add --detach fishhook &&
+	git rev-parse HEAD >expected &&
+	git -C fishhook rev-parse HEAD >actual &&
+	test_cmp expected actual &&
+	test_must_fail git -C fishhook symbolic-ref HEAD
+'
+
+test_expect_success '"add" with <branch> omitted' '
+	git worktree add wiffle/bat &&
+	test_cmp_rev HEAD bat
+'
+
+test_expect_success '"add" checks out existing branch of dwimd name' '
+	git branch dwim HEAD~1 &&
+	git worktree add dwim &&
+	test_cmp_rev HEAD~1 dwim &&
+	(
+		cd dwim &&
+		test_cmp_rev HEAD dwim
+	)
+'
+
+test_expect_success '"add <path>" dwim fails with checked out branch' '
+	git checkout -b test-branch &&
+	test_must_fail git worktree add test-branch &&
+	test_path_is_missing test-branch
+'
+
+test_expect_success '"add --force" with existing dwimd name doesnt die' '
+	git checkout test-branch &&
+	git worktree add --force test-branch
+'
+
+test_expect_success '"add" no auto-vivify with --detach and <branch> omitted' '
+	git worktree add --detach mish/mash &&
+	test_must_fail git rev-parse mash -- &&
+	test_must_fail git -C mish/mash symbolic-ref HEAD
+'
+
+test_expect_success '"add" -b/-B mutually exclusive' '
+	test_must_fail git worktree add -b poodle -B poodle bamboo master
+'
+
+test_expect_success '"add" -b/--detach mutually exclusive' '
+	test_must_fail git worktree add -b poodle --detach bamboo master
+'
+
+test_expect_success '"add" -B/--detach mutually exclusive' '
+	test_must_fail git worktree add -B poodle --detach bamboo master
+'
+
+test_expect_success '"add -B" fails if the branch is checked out' '
+	git rev-parse newmaster >before &&
+	test_must_fail git worktree add -B newmaster bamboo master &&
+	git rev-parse newmaster >after &&
+	test_cmp before after
+'
+
+test_expect_success 'add -B' '
+	git worktree add -B poodle bamboo2 master^ &&
+	git -C bamboo2 symbolic-ref HEAD >actual &&
+	echo refs/heads/poodle >expected &&
+	test_cmp expected actual &&
+	test_cmp_rev master^ poodle
+'
+
+test_expect_success 'add --quiet' '
+	git worktree add --quiet another-worktree master 2>actual &&
+	test_must_be_empty actual
+'
+
+test_expect_success 'local clone from linked checkout' '
+	git clone --local here here-clone &&
+	( cd here-clone && git fsck )
+'
+
+test_expect_success 'local clone --shared from linked checkout' '
+	git -C bare worktree add --detach ../baretree &&
+	git clone --local --shared baretree bare-clone &&
+	grep /bare/ bare-clone/.git/objects/info/alternates
+'
+
+test_expect_success '"add" worktree with --no-checkout' '
+	git worktree add --no-checkout -b swamp swamp &&
+	! test -e swamp/init.t &&
+	git -C swamp reset --hard &&
+	test_cmp init.t swamp/init.t
+'
+
+test_expect_success '"add" worktree with --checkout' '
+	git worktree add --checkout -b swmap2 swamp2 &&
+	test_cmp init.t swamp2/init.t
+'
+
+test_expect_success 'put a worktree under rebase' '
+	git worktree add under-rebase &&
+	(
+		cd under-rebase &&
+		set_fake_editor &&
+		FAKE_LINES="edit 1" git rebase -i HEAD^ &&
+		git worktree list | grep "under-rebase.*detached HEAD"
+	)
+'
+
+test_expect_success 'add a worktree, checking out a rebased branch' '
+	test_must_fail git worktree add new-rebase under-rebase &&
+	! test -d new-rebase
+'
+
+test_expect_success 'checking out a rebased branch from another worktree' '
+	git worktree add new-place &&
+	test_must_fail git -C new-place checkout under-rebase
+'
+
+test_expect_success 'not allow to delete a branch under rebase' '
+	(
+		cd under-rebase &&
+		test_must_fail git branch -D under-rebase
+	)
+'
+
+test_expect_success 'rename a branch under rebase not allowed' '
+	test_must_fail git branch -M under-rebase rebase-with-new-name
+'
+
+test_expect_success 'check out from current worktree branch ok' '
+	(
+		cd under-rebase &&
+		git checkout under-rebase &&
+		git checkout - &&
+		git rebase --abort
+	)
+'
+
+test_expect_success 'checkout a branch under bisect' '
+	git worktree add under-bisect &&
+	(
+		cd under-bisect &&
+		git bisect start &&
+		git bisect bad &&
+		git bisect good HEAD~2 &&
+		git worktree list | grep "under-bisect.*detached HEAD" &&
+		test_must_fail git worktree add new-bisect under-bisect &&
+		! test -d new-bisect
+	)
+'
+
+test_expect_success 'rename a branch under bisect not allowed' '
+	test_must_fail git branch -M under-bisect bisect-with-new-name
+'
+# Is branch "refs/heads/$1" set to pull from "$2/$3"?
+test_branch_upstream () {
+	printf "%s\n" "$2" "refs/heads/$3" >expect.upstream &&
+	{
+		git config "branch.$1.remote" &&
+		git config "branch.$1.merge"
+	} >actual.upstream &&
+	test_cmp expect.upstream actual.upstream
+}
+
+test_expect_success '--track sets up tracking' '
+	test_when_finished rm -rf track &&
+	git worktree add --track -b track track master &&
+	test_branch_upstream track . master
+'
+
+# setup remote repository $1 and repository $2 with $1 set up as
+# remote.  The remote has two branches, master and foo.
+setup_remote_repo () {
+	git init $1 &&
+	(
+		cd $1 &&
+		test_commit $1_master &&
+		git checkout -b foo &&
+		test_commit upstream_foo
+	) &&
+	git init $2 &&
+	(
+		cd $2 &&
+		test_commit $2_master &&
+		git remote add $1 ../$1 &&
+		git config remote.$1.fetch \
+			"refs/heads/*:refs/remotes/$1/*" &&
+		git fetch --all
+	)
+}
+
+test_expect_success '--no-track avoids setting up tracking' '
+	test_when_finished rm -rf repo_upstream repo_local foo &&
+	setup_remote_repo repo_upstream repo_local &&
+	(
+		cd repo_local &&
+		git worktree add --no-track -b foo ../foo repo_upstream/foo
+	) &&
+	(
+		cd foo &&
+		test_must_fail git config "branch.foo.remote" &&
+		test_must_fail git config "branch.foo.merge" &&
+		test_cmp_rev refs/remotes/repo_upstream/foo refs/heads/foo
+	)
+'
+
+test_expect_success '"add" <path> <non-existent-branch> fails' '
+	test_must_fail git worktree add foo non-existent
+'
+
+test_expect_success '"add" <path> <branch> dwims' '
+	test_when_finished rm -rf repo_upstream repo_dwim foo &&
+	setup_remote_repo repo_upstream repo_dwim &&
+	git init repo_dwim &&
+	(
+		cd repo_dwim &&
+		git worktree add ../foo foo
+	) &&
+	(
+		cd foo &&
+		test_branch_upstream foo repo_upstream foo &&
+		test_cmp_rev refs/remotes/repo_upstream/foo refs/heads/foo
+	)
+'
+
+test_expect_success '"add" <path> <branch> dwims with checkout.defaultRemote' '
+	test_when_finished rm -rf repo_upstream repo_dwim foo &&
+	setup_remote_repo repo_upstream repo_dwim &&
+	git init repo_dwim &&
+	(
+		cd repo_dwim &&
+		git remote add repo_upstream2 ../repo_upstream &&
+		git fetch repo_upstream2 &&
+		test_must_fail git worktree add ../foo foo &&
+		git -c checkout.defaultRemote=repo_upstream worktree add ../foo foo &&
+		git status -uno --porcelain >status.actual &&
+		test_must_be_empty status.actual
+	) &&
+	(
+		cd foo &&
+		test_branch_upstream foo repo_upstream foo &&
+		test_cmp_rev refs/remotes/repo_upstream/foo refs/heads/foo
+	)
+'
+
+test_expect_success 'git worktree add does not match remote' '
+	test_when_finished rm -rf repo_a repo_b foo &&
+	setup_remote_repo repo_a repo_b &&
+	(
+		cd repo_b &&
+		git worktree add ../foo
+	) &&
+	(
+		cd foo &&
+		test_must_fail git config "branch.foo.remote" &&
+		test_must_fail git config "branch.foo.merge" &&
+		test_cmp_rev ! refs/remotes/repo_a/foo refs/heads/foo
+	)
+'
+
+test_expect_success 'git worktree add --guess-remote sets up tracking' '
+	test_when_finished rm -rf repo_a repo_b foo &&
+	setup_remote_repo repo_a repo_b &&
+	(
+		cd repo_b &&
+		git worktree add --guess-remote ../foo
+	) &&
+	(
+		cd foo &&
+		test_branch_upstream foo repo_a foo &&
+		test_cmp_rev refs/remotes/repo_a/foo refs/heads/foo
+	)
+'
+
+test_expect_success 'git worktree add with worktree.guessRemote sets up tracking' '
+	test_when_finished rm -rf repo_a repo_b foo &&
+	setup_remote_repo repo_a repo_b &&
+	(
+		cd repo_b &&
+		git config worktree.guessRemote true &&
+		git worktree add ../foo
+	) &&
+	(
+		cd foo &&
+		test_branch_upstream foo repo_a foo &&
+		test_cmp_rev refs/remotes/repo_a/foo refs/heads/foo
+	)
+'
+
+test_expect_success 'git worktree --no-guess-remote option overrides config' '
+	test_when_finished rm -rf repo_a repo_b foo &&
+	setup_remote_repo repo_a repo_b &&
+	(
+		cd repo_b &&
+		git config worktree.guessRemote true &&
+		git worktree add --no-guess-remote ../foo
+	) &&
+	(
+		cd foo &&
+		test_must_fail git config "branch.foo.remote" &&
+		test_must_fail git config "branch.foo.merge" &&
+		test_cmp_rev ! refs/remotes/repo_a/foo refs/heads/foo
+	)
+'
+
+post_checkout_hook () {
+	gitdir=${1:-.git}
+	test_when_finished "rm -f $gitdir/hooks/post-checkout" &&
+	mkdir -p $gitdir/hooks &&
+	write_script $gitdir/hooks/post-checkout <<-\EOF
+	{
+		echo $*
+		git rev-parse --git-dir --show-toplevel
+	} >hook.actual
+	EOF
+}
+
+test_expect_success '"add" invokes post-checkout hook (branch)' '
+	post_checkout_hook &&
+	{
+		echo $ZERO_OID $(git rev-parse HEAD) 1 &&
+		echo $(pwd)/.git/worktrees/gumby &&
+		echo $(pwd)/gumby
+	} >hook.expect &&
+	git worktree add gumby &&
+	test_cmp hook.expect gumby/hook.actual
+'
+
+test_expect_success '"add" invokes post-checkout hook (detached)' '
+	post_checkout_hook &&
+	{
+		echo $ZERO_OID $(git rev-parse HEAD) 1 &&
+		echo $(pwd)/.git/worktrees/grumpy &&
+		echo $(pwd)/grumpy
+	} >hook.expect &&
+	git worktree add --detach grumpy &&
+	test_cmp hook.expect grumpy/hook.actual
+'
+
+test_expect_success '"add --no-checkout" suppresses post-checkout hook' '
+	post_checkout_hook &&
+	rm -f hook.actual &&
+	git worktree add --no-checkout gloopy &&
+	test_path_is_missing gloopy/hook.actual
+'
+
+test_expect_success '"add" in other worktree invokes post-checkout hook' '
+	post_checkout_hook &&
+	{
+		echo $ZERO_OID $(git rev-parse HEAD) 1 &&
+		echo $(pwd)/.git/worktrees/guppy &&
+		echo $(pwd)/guppy
+	} >hook.expect &&
+	git -C gloopy worktree add --detach ../guppy &&
+	test_cmp hook.expect guppy/hook.actual
+'
+
+test_expect_success '"add" in bare repo invokes post-checkout hook' '
+	rm -rf bare &&
+	git clone --bare . bare &&
+	{
+		echo $ZERO_OID $(git --git-dir=bare rev-parse HEAD) 1 &&
+		echo $(pwd)/bare/worktrees/goozy &&
+		echo $(pwd)/goozy
+	} >hook.expect &&
+	post_checkout_hook bare &&
+	git -C bare worktree add --detach ../goozy &&
+	test_cmp hook.expect goozy/hook.actual
+'
+
+test_expect_success '"add" an existing but missing worktree' '
+	git worktree add --detach pneu &&
+	test_must_fail git worktree add --detach pneu &&
+	rm -fr pneu &&
+	test_must_fail git worktree add --detach pneu &&
+	git worktree add --force --detach pneu
+'
+
+test_expect_success '"add" an existing locked but missing worktree' '
+	git worktree add --detach gnoo &&
+	git worktree lock gnoo &&
+	test_when_finished "git worktree unlock gnoo || :" &&
+	rm -fr gnoo &&
+	test_must_fail git worktree add --detach gnoo &&
+	test_must_fail git worktree add --force --detach gnoo &&
+	git worktree add --force --force --detach gnoo
+'
+
+test_expect_success FUNNYNAMES 'sanitize generated worktree name' '
+	git worktree add --detach ".  weird*..?.lock.lock" &&
+	test -d .git/worktrees/---weird-.-
+'
+
+test_expect_success '"add" should not fail because of another bad worktree' '
+	git init add-fail &&
+	(
+		cd add-fail &&
+		test_commit first &&
+		mkdir sub &&
+		git worktree add sub/to-be-deleted &&
+		rm -rf sub &&
+		git worktree add second
+	)
+'
+
+test_expect_success '"add" with uninitialized submodule, with submodule.recurse unset' '
+	test_create_repo submodule &&
+	test_commit -C submodule first &&
+	test_create_repo project &&
+	git -C project submodule add ../submodule &&
+	git -C project add submodule &&
+	test_tick &&
+	git -C project commit -m add_sub &&
+	git clone project project-clone &&
+	git -C project-clone worktree add ../project-2
+'
+test_expect_success '"add" with uninitialized submodule, with submodule.recurse set' '
+	git -C project-clone -c submodule.recurse worktree add ../project-3
+'
+
+test_expect_success '"add" with initialized submodule, with submodule.recurse unset' '
+	git -C project-clone submodule update --init &&
+	git -C project-clone worktree add ../project-4
+'
+
+test_expect_success '"add" with initialized submodule, with submodule.recurse set' '
+	git -C project-clone -c submodule.recurse worktree add ../project-5
+'
+
+test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t2401-worktree-prune.sh 1.2.3+git2.25.1-1/git/t/t2401-worktree-prune.sh
--- 1.2.1+git2.18.0-1/git/t/t2401-worktree-prune.sh	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t2401-worktree-prune.sh	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,95 @@
+#!/bin/sh
+
+test_description='prune $GIT_DIR/worktrees'
+
+. ./test-lib.sh
+
+test_expect_success initialize '
+	git commit --allow-empty -m init
+'
+
+test_expect_success 'worktree prune on normal repo' '
+	git worktree prune &&
+	test_must_fail git worktree prune abc
+'
+
+test_expect_success 'prune files inside $GIT_DIR/worktrees' '
+	mkdir .git/worktrees &&
+	: >.git/worktrees/abc &&
+	git worktree prune --verbose >actual &&
+	cat >expect <<EOF &&
+Removing worktrees/abc: not a valid directory
+EOF
+	test_i18ncmp expect actual &&
+	! test -f .git/worktrees/abc &&
+	! test -d .git/worktrees
+'
+
+test_expect_success 'prune directories without gitdir' '
+	mkdir -p .git/worktrees/def/abc &&
+	: >.git/worktrees/def/def &&
+	cat >expect <<EOF &&
+Removing worktrees/def: gitdir file does not exist
+EOF
+	git worktree prune --verbose >actual &&
+	test_i18ncmp expect actual &&
+	! test -d .git/worktrees/def &&
+	! test -d .git/worktrees
+'
+
+test_expect_success SANITY 'prune directories with unreadable gitdir' '
+	mkdir -p .git/worktrees/def/abc &&
+	: >.git/worktrees/def/def &&
+	: >.git/worktrees/def/gitdir &&
+	chmod u-r .git/worktrees/def/gitdir &&
+	git worktree prune --verbose >actual &&
+	test_i18ngrep "Removing worktrees/def: unable to read gitdir file" actual &&
+	! test -d .git/worktrees/def &&
+	! test -d .git/worktrees
+'
+
+test_expect_success 'prune directories with invalid gitdir' '
+	mkdir -p .git/worktrees/def/abc &&
+	: >.git/worktrees/def/def &&
+	: >.git/worktrees/def/gitdir &&
+	git worktree prune --verbose >actual &&
+	test_i18ngrep "Removing worktrees/def: invalid gitdir file" actual &&
+	! test -d .git/worktrees/def &&
+	! test -d .git/worktrees
+'
+
+test_expect_success 'prune directories with gitdir pointing to nowhere' '
+	mkdir -p .git/worktrees/def/abc &&
+	: >.git/worktrees/def/def &&
+	echo "$(pwd)"/nowhere >.git/worktrees/def/gitdir &&
+	git worktree prune --verbose >actual &&
+	test_i18ngrep "Removing worktrees/def: gitdir file points to non-existent location" actual &&
+	! test -d .git/worktrees/def &&
+	! test -d .git/worktrees
+'
+
+test_expect_success 'not prune locked checkout' '
+	test_when_finished rm -r .git/worktrees &&
+	mkdir -p .git/worktrees/ghi &&
+	: >.git/worktrees/ghi/locked &&
+	git worktree prune &&
+	test -d .git/worktrees/ghi
+'
+
+test_expect_success 'not prune recent checkouts' '
+	test_when_finished rm -r .git/worktrees &&
+	git worktree add jlm HEAD &&
+	test -d .git/worktrees/jlm &&
+	rm -rf jlm &&
+	git worktree prune --verbose --expire=2.days.ago &&
+	test -d .git/worktrees/jlm
+'
+
+test_expect_success 'not prune proper checkouts' '
+	test_when_finished rm -r .git/worktrees &&
+	git worktree add --detach "$PWD/nop" master &&
+	git worktree prune &&
+	test -d .git/worktrees/nop
+'
+
+test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t2402-worktree-list.sh 1.2.3+git2.25.1-1/git/t/t2402-worktree-list.sh
--- 1.2.1+git2.18.0-1/git/t/t2402-worktree-list.sh	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t2402-worktree-list.sh	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,154 @@
+#!/bin/sh
+
+test_description='test git worktree list'
+
+. ./test-lib.sh
+
+test_expect_success 'setup' '
+	test_commit init
+'
+
+test_expect_success 'rev-parse --git-common-dir on main worktree' '
+	git rev-parse --git-common-dir >actual &&
+	echo .git >expected &&
+	test_cmp expected actual &&
+	mkdir sub &&
+	git -C sub rev-parse --git-common-dir >actual2 &&
+	echo ../.git >expected2 &&
+	test_cmp expected2 actual2
+'
+
+test_expect_success 'rev-parse --git-path objects linked worktree' '
+	echo "$(git rev-parse --show-toplevel)/.git/objects" >expect &&
+	test_when_finished "rm -rf linked-tree actual expect && git worktree prune" &&
+	git worktree add --detach linked-tree master &&
+	git -C linked-tree rev-parse --git-path objects >actual &&
+	test_cmp expect actual
+'
+
+test_expect_success '"list" all worktrees from main' '
+	echo "$(git rev-parse --show-toplevel) $(git rev-parse --short HEAD) [$(git symbolic-ref --short HEAD)]" >expect &&
+	test_when_finished "rm -rf here out actual expect && git worktree prune" &&
+	git worktree add --detach here master &&
+	echo "$(git -C here rev-parse --show-toplevel) $(git rev-parse --short HEAD) (detached HEAD)" >>expect &&
+	git worktree list >out &&
+	sed "s/  */ /g" <out >actual &&
+	test_cmp expect actual
+'
+
+test_expect_success '"list" all worktrees from linked' '
+	echo "$(git rev-parse --show-toplevel) $(git rev-parse --short HEAD) [$(git symbolic-ref --short HEAD)]" >expect &&
+	test_when_finished "rm -rf here out actual expect && git worktree prune" &&
+	git worktree add --detach here master &&
+	echo "$(git -C here rev-parse --show-toplevel) $(git rev-parse --short HEAD) (detached HEAD)" >>expect &&
+	git -C here worktree list >out &&
+	sed "s/  */ /g" <out >actual &&
+	test_cmp expect actual
+'
+
+test_expect_success '"list" all worktrees --porcelain' '
+	echo "worktree $(git rev-parse --show-toplevel)" >expect &&
+	echo "HEAD $(git rev-parse HEAD)" >>expect &&
+	echo "branch $(git symbolic-ref HEAD)" >>expect &&
+	echo >>expect &&
+	test_when_finished "rm -rf here actual expect && git worktree prune" &&
+	git worktree add --detach here master &&
+	echo "worktree $(git -C here rev-parse --show-toplevel)" >>expect &&
+	echo "HEAD $(git rev-parse HEAD)" >>expect &&
+	echo "detached" >>expect &&
+	echo >>expect &&
+	git worktree list --porcelain >actual &&
+	test_cmp expect actual
+'
+
+test_expect_success 'bare repo setup' '
+	git init --bare bare1 &&
+	echo "data" >file1 &&
+	git add file1 &&
+	git commit -m"File1: add data" &&
+	git push bare1 master &&
+	git reset --hard HEAD^
+'
+
+test_expect_success '"list" all worktrees from bare main' '
+	test_when_finished "rm -rf there out actual expect && git -C bare1 worktree prune" &&
+	git -C bare1 worktree add --detach ../there master &&
+	echo "$(pwd)/bare1 (bare)" >expect &&
+	echo "$(git -C there rev-parse --show-toplevel) $(git -C there rev-parse --short HEAD) (detached HEAD)" >>expect &&
+	git -C bare1 worktree list >out &&
+	sed "s/  */ /g" <out >actual &&
+	test_cmp expect actual
+'
+
+test_expect_success '"list" all worktrees --porcelain from bare main' '
+	test_when_finished "rm -rf there actual expect && git -C bare1 worktree prune" &&
+	git -C bare1 worktree add --detach ../there master &&
+	echo "worktree $(pwd)/bare1" >expect &&
+	echo "bare" >>expect &&
+	echo >>expect &&
+	echo "worktree $(git -C there rev-parse --show-toplevel)" >>expect &&
+	echo "HEAD $(git -C there rev-parse HEAD)" >>expect &&
+	echo "detached" >>expect &&
+	echo >>expect &&
+	git -C bare1 worktree list --porcelain >actual &&
+	test_cmp expect actual
+'
+
+test_expect_success '"list" all worktrees from linked with a bare main' '
+	test_when_finished "rm -rf there out actual expect && git -C bare1 worktree prune" &&
+	git -C bare1 worktree add --detach ../there master &&
+	echo "$(pwd)/bare1 (bare)" >expect &&
+	echo "$(git -C there rev-parse --show-toplevel) $(git -C there rev-parse --short HEAD) (detached HEAD)" >>expect &&
+	git -C there worktree list >out &&
+	sed "s/  */ /g" <out >actual &&
+	test_cmp expect actual
+'
+
+test_expect_success 'bare repo cleanup' '
+	rm -rf bare1
+'
+
+test_expect_success 'broken main worktree still at the top' '
+	git init broken-main &&
+	(
+		cd broken-main &&
+		test_commit new &&
+		git worktree add linked &&
+		cat >expected <<-EOF &&
+		worktree $(pwd)
+		HEAD $ZERO_OID
+
+		EOF
+		cd linked &&
+		echo "worktree $(pwd)" >expected &&
+		echo "ref: .broken" >../.git/HEAD &&
+		git worktree list --porcelain >out &&
+		head -n 3 out >actual &&
+		test_cmp ../expected actual &&
+		git worktree list >out &&
+		head -n 1 out >actual.2 &&
+		grep -F "(error)" actual.2
+	)
+'
+
+test_expect_success 'linked worktrees are sorted' '
+	mkdir sorted &&
+	git init sorted/main &&
+	(
+		cd sorted/main &&
+		test_tick &&
+		test_commit new &&
+		git worktree add ../first &&
+		git worktree add ../second &&
+		git worktree list --porcelain >out &&
+		grep ^worktree out >actual
+	) &&
+	cat >expected <<-EOF &&
+	worktree $(pwd)/sorted/main
+	worktree $(pwd)/sorted/first
+	worktree $(pwd)/sorted/second
+	EOF
+	test_cmp expected sorted/main/actual
+'
+
+test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t2403-worktree-move.sh 1.2.3+git2.25.1-1/git/t/t2403-worktree-move.sh
--- 1.2.1+git2.18.0-1/git/t/t2403-worktree-move.sh	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t2403-worktree-move.sh	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,225 @@
+#!/bin/sh
+
+test_description='test git worktree move, remove, lock and unlock'
+
+. ./test-lib.sh
+
+test_expect_success 'setup' '
+	test_commit init &&
+	git worktree add source &&
+	git worktree list --porcelain >out &&
+	grep "^worktree" out >actual &&
+	cat <<-EOF >expected &&
+	worktree $(pwd)
+	worktree $(pwd)/source
+	EOF
+	test_cmp expected actual
+'
+
+test_expect_success 'lock main worktree' '
+	test_must_fail git worktree lock .
+'
+
+test_expect_success 'lock linked worktree' '
+	git worktree lock --reason hahaha source &&
+	echo hahaha >expected &&
+	test_cmp expected .git/worktrees/source/locked
+'
+
+test_expect_success 'lock linked worktree from another worktree' '
+	rm .git/worktrees/source/locked &&
+	git worktree add elsewhere &&
+	git -C elsewhere worktree lock --reason hahaha ../source &&
+	echo hahaha >expected &&
+	test_cmp expected .git/worktrees/source/locked
+'
+
+test_expect_success 'lock worktree twice' '
+	test_must_fail git worktree lock source &&
+	echo hahaha >expected &&
+	test_cmp expected .git/worktrees/source/locked
+'
+
+test_expect_success 'lock worktree twice (from the locked worktree)' '
+	test_must_fail git -C source worktree lock . &&
+	echo hahaha >expected &&
+	test_cmp expected .git/worktrees/source/locked
+'
+
+test_expect_success 'unlock main worktree' '
+	test_must_fail git worktree unlock .
+'
+
+test_expect_success 'unlock linked worktree' '
+	git worktree unlock source &&
+	test_path_is_missing .git/worktrees/source/locked
+'
+
+test_expect_success 'unlock worktree twice' '
+	test_must_fail git worktree unlock source &&
+	test_path_is_missing .git/worktrees/source/locked
+'
+
+test_expect_success 'move non-worktree' '
+	mkdir abc &&
+	test_must_fail git worktree move abc def
+'
+
+test_expect_success 'move locked worktree' '
+	git worktree lock source &&
+	test_when_finished "git worktree unlock source" &&
+	test_must_fail git worktree move source destination
+'
+
+test_expect_success 'move worktree' '
+	git worktree move source destination &&
+	test_path_is_missing source &&
+	git worktree list --porcelain >out &&
+	grep "^worktree.*/destination$" out &&
+	! grep "^worktree.*/source$" out &&
+	git -C destination log --format=%s >actual2 &&
+	echo init >expected2 &&
+	test_cmp expected2 actual2
+'
+
+test_expect_success 'move main worktree' '
+	test_must_fail git worktree move . def
+'
+
+test_expect_success 'move worktree to another dir' '
+	mkdir some-dir &&
+	git worktree move destination some-dir &&
+	test_when_finished "git worktree move some-dir/destination destination" &&
+	test_path_is_missing destination &&
+	git worktree list --porcelain >out &&
+	grep "^worktree.*/some-dir/destination$" out &&
+	git -C some-dir/destination log --format=%s >actual2 &&
+	echo init >expected2 &&
+	test_cmp expected2 actual2
+'
+
+test_expect_success 'move locked worktree (force)' '
+	test_when_finished "
+		git worktree unlock flump || :
+		git worktree remove flump || :
+		git worktree unlock ploof || :
+		git worktree remove ploof || :
+		" &&
+	git worktree add --detach flump &&
+	git worktree lock flump &&
+	test_must_fail git worktree move flump ploof" &&
+	test_must_fail git worktree move --force flump ploof" &&
+	git worktree move --force --force flump ploof
+'
+
+test_expect_success 'move a repo with uninitialized submodule' '
+	git init withsub &&
+	(
+		cd withsub &&
+		test_commit initial &&
+		git submodule add "$PWD"/.git sub &&
+		git commit -m withsub &&
+		git worktree add second HEAD &&
+		git worktree move second third
+	)
+'
+
+test_expect_success 'not move a repo with initialized submodule' '
+	(
+		cd withsub &&
+		git -C third submodule update &&
+		test_must_fail git worktree move third forth
+	)
+'
+
+test_expect_success 'remove main worktree' '
+	test_must_fail git worktree remove .
+'
+
+test_expect_success 'remove locked worktree' '
+	git worktree lock destination &&
+	test_when_finished "git worktree unlock destination" &&
+	test_must_fail git worktree remove destination
+'
+
+test_expect_success 'remove worktree with dirty tracked file' '
+	echo dirty >>destination/init.t &&
+	test_when_finished "git -C destination checkout init.t" &&
+	test_must_fail git worktree remove destination
+'
+
+test_expect_success 'remove worktree with untracked file' '
+	: >destination/untracked &&
+	test_must_fail git worktree remove destination
+'
+
+test_expect_success 'force remove worktree with untracked file' '
+	git worktree remove --force destination &&
+	test_path_is_missing destination
+'
+
+test_expect_success 'remove missing worktree' '
+	git worktree add to-be-gone &&
+	test -d .git/worktrees/to-be-gone &&
+	mv to-be-gone gone &&
+	git worktree remove to-be-gone &&
+	test_path_is_missing .git/worktrees/to-be-gone
+'
+
+test_expect_success 'NOT remove missing-but-locked worktree' '
+	git worktree add gone-but-locked &&
+	git worktree lock gone-but-locked &&
+	test -d .git/worktrees/gone-but-locked &&
+	mv gone-but-locked really-gone-now &&
+	test_must_fail git worktree remove gone-but-locked &&
+	test_path_is_dir .git/worktrees/gone-but-locked
+'
+
+test_expect_success 'proper error when worktree not found' '
+	for i in noodle noodle/bork
+	do
+		test_must_fail git worktree lock $i 2>err &&
+		test_i18ngrep "not a working tree" err || return 1
+	done
+'
+
+test_expect_success 'remove locked worktree (force)' '
+	git worktree add --detach gumby &&
+	test_when_finished "git worktree remove gumby || :" &&
+	git worktree lock gumby &&
+	test_when_finished "git worktree unlock gumby || :" &&
+	test_must_fail git worktree remove gumby &&
+	test_must_fail git worktree remove --force gumby &&
+	git worktree remove --force --force gumby
+'
+
+test_expect_success 'remove cleans up .git/worktrees when empty' '
+	git init moog &&
+	(
+		cd moog &&
+		test_commit bim &&
+		git worktree add --detach goom &&
+		test_path_exists .git/worktrees &&
+		git worktree remove goom &&
+		test_path_is_missing .git/worktrees
+	)
+'
+
+test_expect_success 'remove a repo with uninitialized submodule' '
+	(
+		cd withsub &&
+		git worktree add to-remove HEAD &&
+		git worktree remove to-remove
+	)
+'
+
+test_expect_success 'not remove a repo with initialized submodule' '
+	(
+		cd withsub &&
+		git worktree add to-remove HEAD &&
+		git -C to-remove submodule update &&
+		test_must_fail git worktree remove to-remove
+	)
+'
+
+test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t2404-worktree-config.sh 1.2.3+git2.25.1-1/git/t/t2404-worktree-config.sh
--- 1.2.1+git2.18.0-1/git/t/t2404-worktree-config.sh	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t2404-worktree-config.sh	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,79 @@
+#!/bin/sh
+
+test_description="config file in multi worktree"
+
+. ./test-lib.sh
+
+test_expect_success 'setup' '
+	test_commit start
+'
+
+test_expect_success 'config --worktree in single worktree' '
+	git config --worktree foo.bar true &&
+	test_cmp_config true foo.bar
+'
+
+test_expect_success 'add worktrees' '
+	git worktree add wt1 &&
+	git worktree add wt2
+'
+
+test_expect_success 'config --worktree without extension' '
+	test_must_fail git config --worktree foo.bar false
+'
+
+test_expect_success 'enable worktreeConfig extension' '
+	git config extensions.worktreeConfig true &&
+	test_cmp_config true extensions.worktreeConfig
+'
+
+test_expect_success 'config is shared as before' '
+	git config this.is shared &&
+	test_cmp_config shared this.is &&
+	test_cmp_config -C wt1 shared this.is &&
+	test_cmp_config -C wt2 shared this.is
+'
+
+test_expect_success 'config is shared (set from another worktree)' '
+	git -C wt1 config that.is also-shared &&
+	test_cmp_config also-shared that.is &&
+	test_cmp_config -C wt1 also-shared that.is &&
+	test_cmp_config -C wt2 also-shared that.is
+'
+
+test_expect_success 'config private to main worktree' '
+	git config --worktree this.is for-main &&
+	test_cmp_config for-main this.is &&
+	test_cmp_config -C wt1 shared this.is &&
+	test_cmp_config -C wt2 shared this.is
+'
+
+test_expect_success 'config private to linked worktree' '
+	git -C wt1 config --worktree this.is for-wt1 &&
+	test_cmp_config for-main this.is &&
+	test_cmp_config -C wt1 for-wt1 this.is &&
+	test_cmp_config -C wt2 shared this.is
+'
+
+test_expect_success 'core.bare no longer for main only' '
+	test_config core.bare true &&
+	test "$(git rev-parse --is-bare-repository)" = true &&
+	test "$(git -C wt1 rev-parse --is-bare-repository)" = true &&
+	test "$(git -C wt2 rev-parse --is-bare-repository)" = true
+'
+
+test_expect_success 'per-worktree core.bare is picked up' '
+	git -C wt1 config --worktree core.bare true &&
+	test "$(git rev-parse --is-bare-repository)" = false &&
+	test "$(git -C wt1 rev-parse --is-bare-repository)" = true &&
+	test "$(git -C wt2 rev-parse --is-bare-repository)" = false
+'
+
+test_expect_success 'config.worktree no longer read without extension' '
+	git config --unset extensions.worktreeConfig &&
+	test_cmp_config shared this.is &&
+	test_cmp_config -C wt1 shared this.is &&
+	test_cmp_config -C wt2 shared this.is
+'
+
+test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t3000-ls-files-others.sh 1.2.3+git2.25.1-1/git/t/t3000-ls-files-others.sh
--- 1.2.1+git2.18.0-1/git/t/t3000-ls-files-others.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t3000-ls-files-others.sh	2020-02-17 04:47:35.000000000 +0000
@@ -3,7 +3,7 @@
 # Copyright (c) 2005 Junio C Hamano
 #
 
-test_description='git ls-files test (--others should pick up symlinks).
+test_description='basic tests for ls-files --others
 
 This test runs git ls-files --others with the following on the
 filesystem.
@@ -84,7 +84,7 @@ test_expect_success SYMLINKS 'ls-files -
 	) &&
 	(
 		cd super &&
-		"$SHELL_PATH" "$TEST_DIRECTORY/../contrib/workdir/git-new-workdir" ../sub sub
+		"$SHELL_PATH" "$TEST_DIRECTORY/../contrib/workdir/git-new-workdir" ../sub sub &&
 		git ls-files --others --exclude-standard >../actual
 	) &&
 	echo sub/ >expect &&
diff -pruN 1.2.1+git2.18.0-1/git/t/t3001-ls-files-others-exclude.sh 1.2.3+git2.25.1-1/git/t/t3001-ls-files-others-exclude.sh
--- 1.2.1+git2.18.0-1/git/t/t3001-ls-files-others-exclude.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t3001-ls-files-others-exclude.sh	2020-02-17 04:47:35.000000000 +0000
@@ -210,8 +210,7 @@ test_expect_success 'subdirectory ignore
 		cd top &&
 		git ls-files -o --exclude-standard
 	) >actual &&
-	>expect &&
-	test_cmp expect actual
+	test_must_be_empty actual
 '
 
 test_expect_success 'subdirectory ignore (l1/l2)' '
@@ -219,8 +218,7 @@ test_expect_success 'subdirectory ignore
 		cd top/l1/l2 &&
 		git ls-files -o --exclude-standard
 	) >actual &&
-	>expect &&
-	test_cmp expect actual
+	test_must_be_empty actual
 '
 
 test_expect_success 'subdirectory ignore (l1)' '
@@ -228,8 +226,7 @@ test_expect_success 'subdirectory ignore
 		cd top/l1 &&
 		git ls-files -o --exclude-standard
 	) >actual &&
-	>expect &&
-	test_cmp expect actual
+	test_must_be_empty actual
 '
 
 test_expect_success 'show/hide empty ignored directory (setup)' '
@@ -251,8 +248,7 @@ test_expect_success 'hide empty ignored
 		cd top &&
 		git ls-files -o -i --exclude l1 --directory --no-empty-directory
 	) >actual &&
-	>expect &&
-	test_cmp expect actual
+	test_must_be_empty actual
 '
 
 test_expect_success 'show/hide empty ignored sub-directory (setup)' '
@@ -277,14 +273,12 @@ test_expect_success 'hide empty ignored
 		cd top &&
 		git ls-files -o -i --exclude l1 --directory --no-empty-directory
 	) >actual &&
-	>expect &&
-	test_cmp expect actual
+	test_must_be_empty actual
 '
 
 test_expect_success 'pattern matches prefix completely' '
-	: >expect &&
 	git ls-files -i -o --exclude "/three/a.3[abc]" >actual &&
-	test_cmp expect actual
+	test_must_be_empty actual
 '
 
 test_expect_success 'ls-files with "**" patterns' '
@@ -300,9 +294,8 @@ EOF
 
 
 test_expect_success 'ls-files with "**" patterns and no slashes' '
-	: >expect &&
 	git ls-files -o -i --exclude "one**a.1" >actual &&
-	test_cmp expect actual
+	test_must_be_empty actual
 '
 
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t3004-ls-files-basic.sh 1.2.3+git2.25.1-1/git/t/t3004-ls-files-basic.sh
--- 1.2.1+git2.18.0-1/git/t/t3004-ls-files-basic.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t3004-ls-files-basic.sh	2020-02-17 04:47:35.000000000 +0000
@@ -8,16 +8,14 @@ command-line arguments.
 
 . ./test-lib.sh
 
->empty
-
 test_expect_success 'ls-files in empty repository' '
 	git ls-files >actual &&
-	test_cmp empty actual
+	test_must_be_empty actual
 '
 
 test_expect_success 'ls-files with nonexistent path' '
 	git ls-files doesnotexist >actual &&
-	test_cmp empty actual
+	test_must_be_empty actual
 '
 
 test_expect_success 'ls-files with nonsense option' '
diff -pruN 1.2.1+git2.18.0-1/git/t/t3005-ls-files-relative.sh 1.2.3+git2.25.1-1/git/t/t3005-ls-files-relative.sh
--- 1.2.1+git2.18.0-1/git/t/t3005-ls-files-relative.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t3005-ls-files-relative.sh	2020-02-17 04:47:35.000000000 +0000
@@ -7,10 +7,6 @@ This test runs git ls-files with various
 
 . ./test-lib.sh
 
-new_line='
-'
-sq=\'
-
 test_expect_success 'prepare' '
 	: >never-mind-me &&
 	git add never-mind-me &&
@@ -44,13 +40,13 @@ test_expect_success 'ls-files -c' '
 		cd top/sub &&
 		for f in ../y*
 		do
-			echo "error: pathspec $sq$f$sq did not match any file(s) known to git."
+			echo "error: pathspec $SQ$f$SQ did not match any file(s) known to git"
 		done >expect.err &&
-		echo "Did you forget to ${sq}git add${sq}?" >>expect.err &&
+		echo "Did you forget to ${SQ}git add${SQ}?" >>expect.err &&
 		ls ../x* >expect.out &&
 		test_must_fail git ls-files -c --error-unmatch ../[xy]* >actual.out 2>actual.err &&
 		test_cmp expect.out actual.out &&
-		test_cmp expect.err actual.err
+		test_i18ncmp expect.err actual.err
 	)
 '
 
@@ -59,13 +55,13 @@ test_expect_success 'ls-files -o' '
 		cd top/sub &&
 		for f in ../x*
 		do
-			echo "error: pathspec $sq$f$sq did not match any file(s) known to git."
+			echo "error: pathspec $SQ$f$SQ did not match any file(s) known to git"
 		done >expect.err &&
-		echo "Did you forget to ${sq}git add${sq}?" >>expect.err &&
+		echo "Did you forget to ${SQ}git add${SQ}?" >>expect.err &&
 		ls ../y* >expect.out &&
 		test_must_fail git ls-files -o --error-unmatch ../[xy]* >actual.out 2>actual.err &&
 		test_cmp expect.out actual.out &&
-		test_cmp expect.err actual.err
+		test_i18ncmp expect.err actual.err
 	)
 '
 
diff -pruN 1.2.1+git2.18.0-1/git/t/t3006-ls-files-long.sh 1.2.3+git2.25.1-1/git/t/t3006-ls-files-long.sh
--- 1.2.1+git2.18.0-1/git/t/t3006-ls-files-long.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t3006-ls-files-long.sh	2020-02-17 04:47:35.000000000 +0000
@@ -29,7 +29,7 @@ test_expect_success 'overly-long path do
 	printf "$pat" "$blob_a" "$path_a" "$blob_z" "$path_z" |
 	git update-index --add --index-info &&
 	(
-		echo "$path_a"
+		echo "$path_a" &&
 		echo "$path_z"
 	) >expect &&
 	git ls-files >actual &&
diff -pruN 1.2.1+git2.18.0-1/git/t/t3008-ls-files-lazy-init-name-hash.sh 1.2.3+git2.25.1-1/git/t/t3008-ls-files-lazy-init-name-hash.sh
--- 1.2.1+git2.18.0-1/git/t/t3008-ls-files-lazy-init-name-hash.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t3008-ls-files-lazy-init-name-hash.sh	2020-02-17 04:47:35.000000000 +0000
@@ -4,7 +4,7 @@ test_description='Test the lazy init nam
 
 . ./test-lib.sh
 
-if test 1 -eq $($GIT_BUILD_DIR/t/helper/test-tool online-cpus)
+if test 1 -eq $(test-tool online-cpus)
 then
 	skip_all='skipping lazy-init tests, single cpu'
 	test_done
@@ -14,10 +14,10 @@ LAZY_THREAD_COST=2000
 
 test_expect_success 'no buffer overflow in lazy_init_name_hash' '
 	(
-	    test_seq $LAZY_THREAD_COST | sed "s/^/a_/"
-	    echo b/b/b
-	    test_seq $LAZY_THREAD_COST | sed "s/^/c_/"
-	    test_seq 50 | sed "s/^/d_/" | tr "\n" "/"; echo d
+	    test_seq $LAZY_THREAD_COST | sed "s/^/a_/" &&
+	    echo b/b/b &&
+	    test_seq $LAZY_THREAD_COST | sed "s/^/c_/" &&
+	    test_seq 50 | sed "s/^/d_/" | tr "\n" "/" && echo d
 	) |
 	sed "s/^/100644 $EMPTY_BLOB	/" |
 	git update-index --index-info &&
diff -pruN 1.2.1+git2.18.0-1/git/t/t3009-ls-files-others-nonsubmodule.sh 1.2.3+git2.25.1-1/git/t/t3009-ls-files-others-nonsubmodule.sh
--- 1.2.1+git2.18.0-1/git/t/t3009-ls-files-others-nonsubmodule.sh	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t3009-ls-files-others-nonsubmodule.sh	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,50 @@
+#!/bin/sh
+
+test_description='test git ls-files --others with non-submodule repositories
+
+This test runs git ls-files --others with the following working tree:
+
+    nonrepo-no-files/
+      plain directory with no files
+    nonrepo-untracked-file/
+      plain directory with an untracked file
+    repo-no-commit-no-files/
+      git repository without a commit or a file
+    repo-no-commit-untracked-file/
+      git repository without a commit but with an untracked file
+    repo-with-commit-no-files/
+      git repository with a commit and no untracked files
+    repo-with-commit-untracked-file/
+      git repository with a commit and an untracked file
+'
+
+. ./test-lib.sh
+
+test_expect_success 'setup: directories' '
+	mkdir nonrepo-no-files/ &&
+	mkdir nonrepo-untracked-file &&
+	: >nonrepo-untracked-file/untracked &&
+	git init repo-no-commit-no-files &&
+	git init repo-no-commit-untracked-file &&
+	: >repo-no-commit-untracked-file/untracked &&
+	git init repo-with-commit-no-files &&
+	git -C repo-with-commit-no-files commit --allow-empty -mmsg &&
+	git init repo-with-commit-untracked-file &&
+	test_commit -C repo-with-commit-untracked-file msg &&
+	: >repo-with-commit-untracked-file/untracked
+'
+
+test_expect_success 'ls-files --others handles untracked git repositories' '
+	git ls-files -o >output &&
+	cat >expect <<-EOF &&
+	nonrepo-untracked-file/untracked
+	output
+	repo-no-commit-no-files/
+	repo-no-commit-untracked-file/
+	repo-with-commit-no-files/
+	repo-with-commit-untracked-file/
+	EOF
+	test_cmp expect output
+'
+
+test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t3011-common-prefixes-and-directory-traversal.sh 1.2.3+git2.25.1-1/git/t/t3011-common-prefixes-and-directory-traversal.sh
--- 1.2.1+git2.18.0-1/git/t/t3011-common-prefixes-and-directory-traversal.sh	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t3011-common-prefixes-and-directory-traversal.sh	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,209 @@
+#!/bin/sh
+
+test_description='directory traversal handling, especially with common prefixes'
+
+. ./test-lib.sh
+
+test_expect_success 'setup' '
+	test_commit hello &&
+
+	>empty &&
+	mkdir untracked_dir &&
+	>untracked_dir/empty &&
+	git init untracked_repo &&
+	>untracked_repo/empty &&
+
+	cat <<-EOF >.gitignore &&
+	ignored
+	an_ignored_dir/
+	EOF
+	mkdir an_ignored_dir &&
+	mkdir an_untracked_dir &&
+	>an_ignored_dir/ignored &&
+	>an_ignored_dir/untracked &&
+	>an_untracked_dir/ignored &&
+	>an_untracked_dir/untracked
+'
+
+test_expect_success 'git ls-files -o shows the right entries' '
+	cat <<-EOF >expect &&
+	.gitignore
+	actual
+	an_ignored_dir/ignored
+	an_ignored_dir/untracked
+	an_untracked_dir/ignored
+	an_untracked_dir/untracked
+	empty
+	expect
+	untracked_dir/empty
+	untracked_repo/
+	EOF
+	git ls-files -o >actual &&
+	test_cmp expect actual
+'
+
+test_expect_success 'git ls-files -o --exclude-standard shows the right entries' '
+	cat <<-EOF >expect &&
+	.gitignore
+	actual
+	an_untracked_dir/untracked
+	empty
+	expect
+	untracked_dir/empty
+	untracked_repo/
+	EOF
+	git ls-files -o --exclude-standard >actual &&
+	test_cmp expect actual
+'
+
+test_expect_success 'git ls-files -o untracked_dir recurses' '
+	echo untracked_dir/empty >expect &&
+	git ls-files -o untracked_dir >actual &&
+	test_cmp expect actual
+'
+
+test_expect_success 'git ls-files -o untracked_dir/ recurses' '
+	echo untracked_dir/empty >expect &&
+	git ls-files -o untracked_dir/ >actual &&
+	test_cmp expect actual
+'
+
+test_expect_success 'git ls-files -o --directory untracked_dir does not recurse' '
+	echo untracked_dir/ >expect &&
+	git ls-files -o --directory untracked_dir >actual &&
+	test_cmp expect actual
+'
+
+test_expect_success 'git ls-files -o --directory untracked_dir/ does not recurse' '
+	echo untracked_dir/ >expect &&
+	git ls-files -o --directory untracked_dir/ >actual &&
+	test_cmp expect actual
+'
+
+test_expect_success 'git ls-files -o untracked_repo does not recurse' '
+	echo untracked_repo/ >expect &&
+	git ls-files -o untracked_repo >actual &&
+	test_cmp expect actual
+'
+
+test_expect_success 'git ls-files -o untracked_repo/ does not recurse' '
+	echo untracked_repo/ >expect &&
+	git ls-files -o untracked_repo/ >actual &&
+	test_cmp expect actual
+'
+
+test_expect_success 'git ls-files -o untracked_dir untracked_repo recurses into untracked_dir only' '
+	cat <<-EOF >expect &&
+	untracked_dir/empty
+	untracked_repo/
+	EOF
+	git ls-files -o untracked_dir untracked_repo >actual &&
+	test_cmp expect actual
+'
+
+test_expect_success 'git ls-files -o untracked_dir/ untracked_repo/ recurses into untracked_dir only' '
+	cat <<-EOF >expect &&
+	untracked_dir/empty
+	untracked_repo/
+	EOF
+	git ls-files -o untracked_dir/ untracked_repo/ >actual &&
+	test_cmp expect actual
+'
+
+test_expect_success 'git ls-files -o --directory untracked_dir untracked_repo does not recurse' '
+	cat <<-EOF >expect &&
+	untracked_dir/
+	untracked_repo/
+	EOF
+	git ls-files -o --directory untracked_dir untracked_repo >actual &&
+	test_cmp expect actual
+'
+
+test_expect_success 'git ls-files -o --directory untracked_dir/ untracked_repo/ does not recurse' '
+	cat <<-EOF >expect &&
+	untracked_dir/
+	untracked_repo/
+	EOF
+	git ls-files -o --directory untracked_dir/ untracked_repo/ >actual &&
+	test_cmp expect actual
+'
+
+test_expect_success 'git ls-files -o .git shows nothing' '
+	git ls-files -o .git >actual &&
+	test_must_be_empty actual
+'
+
+test_expect_success 'git ls-files -o .git/ shows nothing' '
+	git ls-files -o .git/ >actual &&
+	test_must_be_empty actual
+'
+
+test_expect_success FUNNYNAMES 'git ls-files -o untracked_* recurses appropriately' '
+	mkdir "untracked_*" &&
+	>"untracked_*/empty" &&
+
+	cat <<-EOF >expect &&
+	untracked_*/empty
+	untracked_dir/empty
+	untracked_repo/
+	EOF
+	git ls-files -o "untracked_*" >actual &&
+	test_cmp expect actual
+'
+
+# It turns out fill_directory returns the right paths, but ls-files' post-call
+# filtering in show_dir_entry() via calling dir_path_match() which ends up
+# in git_fnmatch() has logic for PATHSPEC_ONESTAR that assumes the pathspec
+# must match the full path; it doesn't check it for matching a leading
+# directory.
+test_expect_failure FUNNYNAMES 'git ls-files -o untracked_*/ recurses appropriately' '
+	cat <<-EOF >expect &&
+	untracked_*/empty
+	untracked_dir/empty
+	untracked_repo/
+	EOF
+	git ls-files -o "untracked_*/" >actual &&
+	test_cmp expect actual
+'
+
+test_expect_success FUNNYNAMES 'git ls-files -o --directory untracked_* does not recurse' '
+	cat <<-EOF >expect &&
+	untracked_*/
+	untracked_dir/
+	untracked_repo/
+	EOF
+	git ls-files -o --directory "untracked_*" >actual &&
+	test_cmp expect actual
+'
+
+test_expect_success FUNNYNAMES 'git ls-files -o --directory untracked_*/ does not recurse' '
+	cat <<-EOF >expect &&
+	untracked_*/
+	untracked_dir/
+	untracked_repo/
+	EOF
+	git ls-files -o --directory "untracked_*/" >actual &&
+	test_cmp expect actual
+'
+
+test_expect_success 'git ls-files -o consistent between one or two dirs' '
+	git ls-files -o --exclude-standard an_ignored_dir/ an_untracked_dir/ >tmp &&
+	! grep ^an_ignored_dir/ tmp >expect &&
+	git ls-files -o --exclude-standard an_ignored_dir/ >actual &&
+	test_cmp expect actual
+'
+
+# ls-files doesn't have a way to request showing both untracked and ignored
+# files at the same time, so use `git status --ignored`
+test_expect_success 'git status --ignored shows same files under dir with or without pathspec' '
+	cat <<-EOF >expect &&
+	?? an_untracked_dir/
+	!! an_untracked_dir/ignored
+	EOF
+	git status --porcelain --ignored >output &&
+	grep an_untracked_dir output >expect &&
+	git status --porcelain --ignored an_untracked_dir/ >actual &&
+	test_cmp expect actual
+'
+
+test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t3030-merge-recursive.sh 1.2.3+git2.25.1-1/git/t/t3030-merge-recursive.sh
--- 1.2.1+git2.18.0-1/git/t/t3030-merge-recursive.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t3030-merge-recursive.sh	2020-02-17 04:47:35.000000000 +0000
@@ -36,15 +36,15 @@ test_expect_success 'setup 1' '
 	test_tick &&
 	git commit -m "master modifies a and d/e" &&
 	c1=$(git rev-parse --verify HEAD) &&
-	( git ls-tree -r HEAD ; git ls-files -s ) >actual &&
+	( git ls-tree -r HEAD && git ls-files -s ) >actual &&
 	(
-		echo "100644 blob $o1	a"
-		echo "100644 blob $o0	b"
-		echo "100644 blob $o0	c"
-		echo "100644 blob $o1	d/e"
-		echo "100644 $o1 0	a"
-		echo "100644 $o0 0	b"
-		echo "100644 $o0 0	c"
+		echo "100644 blob $o1	a" &&
+		echo "100644 blob $o0	b" &&
+		echo "100644 blob $o0	c" &&
+		echo "100644 blob $o1	d/e" &&
+		echo "100644 $o1 0	a" &&
+		echo "100644 $o0 0	b" &&
+		echo "100644 $o0 0	c" &&
 		echo "100644 $o1 0	d/e"
 	) >expected &&
 	test_cmp expected actual
@@ -54,15 +54,15 @@ test_expect_success 'setup 2' '
 
 	rm -rf [abcd] &&
 	git checkout side &&
-	( git ls-tree -r HEAD ; git ls-files -s ) >actual &&
+	( git ls-tree -r HEAD && git ls-files -s ) >actual &&
 	(
-		echo "100644 blob $o0	a"
-		echo "100644 blob $o0	b"
-		echo "100644 blob $o0	c"
-		echo "100644 blob $o0	d/e"
-		echo "100644 $o0 0	a"
-		echo "100644 $o0 0	b"
-		echo "100644 $o0 0	c"
+		echo "100644 blob $o0	a" &&
+		echo "100644 blob $o0	b" &&
+		echo "100644 blob $o0	c" &&
+		echo "100644 blob $o0	d/e" &&
+		echo "100644 $o0 0	a" &&
+		echo "100644 $o0 0	b" &&
+		echo "100644 $o0 0	c" &&
 		echo "100644 $o0 0	d/e"
 	) >expected &&
 	test_cmp expected actual &&
@@ -75,15 +75,15 @@ test_expect_success 'setup 2' '
 	test_tick &&
 	git commit -m "side modifies a" &&
 	c2=$(git rev-parse --verify HEAD) &&
-	( git ls-tree -r HEAD ; git ls-files -s ) >actual &&
+	( git ls-tree -r HEAD && git ls-files -s ) >actual &&
 	(
-		echo "100644 blob $o2	a"
-		echo "100644 blob $o0	b"
-		echo "100644 blob $o0	c"
-		echo "100644 blob $o0	d/e"
-		echo "100644 $o2 0	a"
-		echo "100644 $o0 0	b"
-		echo "100644 $o0 0	c"
+		echo "100644 blob $o2	a" &&
+		echo "100644 blob $o0	b" &&
+		echo "100644 blob $o0	c" &&
+		echo "100644 blob $o0	d/e" &&
+		echo "100644 $o2 0	a" &&
+		echo "100644 $o0 0	b" &&
+		echo "100644 $o0 0	c" &&
 		echo "100644 $o0 0	d/e"
 	) >expected &&
 	test_cmp expected actual
@@ -93,15 +93,15 @@ test_expect_success 'setup 3' '
 
 	rm -rf [abcd] &&
 	git checkout df-1 &&
-	( git ls-tree -r HEAD ; git ls-files -s ) >actual &&
+	( git ls-tree -r HEAD && git ls-files -s ) >actual &&
 	(
-		echo "100644 blob $o0	a"
-		echo "100644 blob $o0	b"
-		echo "100644 blob $o0	c"
-		echo "100644 blob $o0	d/e"
-		echo "100644 $o0 0	a"
-		echo "100644 $o0 0	b"
-		echo "100644 $o0 0	c"
+		echo "100644 blob $o0	a" &&
+		echo "100644 blob $o0	b" &&
+		echo "100644 blob $o0	c" &&
+		echo "100644 blob $o0	d/e" &&
+		echo "100644 $o0 0	a" &&
+		echo "100644 $o0 0	b" &&
+		echo "100644 $o0 0	c" &&
 		echo "100644 $o0 0	d/e"
 	) >expected &&
 	test_cmp expected actual &&
@@ -112,15 +112,15 @@ test_expect_success 'setup 3' '
 	test_tick &&
 	git commit -m "df-1 makes b/c" &&
 	c3=$(git rev-parse --verify HEAD) &&
-	( git ls-tree -r HEAD ; git ls-files -s ) >actual &&
+	( git ls-tree -r HEAD && git ls-files -s ) >actual &&
 	(
-		echo "100644 blob $o0	a"
-		echo "100644 blob $o3	b/c"
-		echo "100644 blob $o0	c"
-		echo "100644 blob $o0	d/e"
-		echo "100644 $o0 0	a"
-		echo "100644 $o3 0	b/c"
-		echo "100644 $o0 0	c"
+		echo "100644 blob $o0	a" &&
+		echo "100644 blob $o3	b/c" &&
+		echo "100644 blob $o0	c" &&
+		echo "100644 blob $o0	d/e" &&
+		echo "100644 $o0 0	a" &&
+		echo "100644 $o3 0	b/c" &&
+		echo "100644 $o0 0	c" &&
 		echo "100644 $o0 0	d/e"
 	) >expected &&
 	test_cmp expected actual
@@ -130,15 +130,15 @@ test_expect_success 'setup 4' '
 
 	rm -rf [abcd] &&
 	git checkout df-2 &&
-	( git ls-tree -r HEAD ; git ls-files -s ) >actual &&
+	( git ls-tree -r HEAD && git ls-files -s ) >actual &&
 	(
-		echo "100644 blob $o0	a"
-		echo "100644 blob $o0	b"
-		echo "100644 blob $o0	c"
-		echo "100644 blob $o0	d/e"
-		echo "100644 $o0 0	a"
-		echo "100644 $o0 0	b"
-		echo "100644 $o0 0	c"
+		echo "100644 blob $o0	a" &&
+		echo "100644 blob $o0	b" &&
+		echo "100644 blob $o0	c" &&
+		echo "100644 blob $o0	d/e" &&
+		echo "100644 $o0 0	a" &&
+		echo "100644 $o0 0	b" &&
+		echo "100644 $o0 0	c" &&
 		echo "100644 $o0 0	d/e"
 	) >expected &&
 	test_cmp expected actual &&
@@ -149,15 +149,15 @@ test_expect_success 'setup 4' '
 	test_tick &&
 	git commit -m "df-2 makes a/c" &&
 	c4=$(git rev-parse --verify HEAD) &&
-	( git ls-tree -r HEAD ; git ls-files -s ) >actual &&
+	( git ls-tree -r HEAD && git ls-files -s ) >actual &&
 	(
-		echo "100644 blob $o4	a/c"
-		echo "100644 blob $o0	b"
-		echo "100644 blob $o0	c"
-		echo "100644 blob $o0	d/e"
-		echo "100644 $o4 0	a/c"
-		echo "100644 $o0 0	b"
-		echo "100644 $o0 0	c"
+		echo "100644 blob $o4	a/c" &&
+		echo "100644 blob $o0	b" &&
+		echo "100644 blob $o0	c" &&
+		echo "100644 blob $o0	d/e" &&
+		echo "100644 $o4 0	a/c" &&
+		echo "100644 $o0 0	b" &&
+		echo "100644 $o0 0	c" &&
 		echo "100644 $o0 0	d/e"
 	) >expected &&
 	test_cmp expected actual
@@ -167,15 +167,15 @@ test_expect_success 'setup 5' '
 
 	rm -rf [abcd] &&
 	git checkout remove &&
-	( git ls-tree -r HEAD ; git ls-files -s ) >actual &&
+	( git ls-tree -r HEAD && git ls-files -s ) >actual &&
 	(
-		echo "100644 blob $o0	a"
-		echo "100644 blob $o0	b"
-		echo "100644 blob $o0	c"
-		echo "100644 blob $o0	d/e"
-		echo "100644 $o0 0	a"
-		echo "100644 $o0 0	b"
-		echo "100644 $o0 0	c"
+		echo "100644 blob $o0	a" &&
+		echo "100644 blob $o0	b" &&
+		echo "100644 blob $o0	c" &&
+		echo "100644 blob $o0	d/e" &&
+		echo "100644 $o0 0	a" &&
+		echo "100644 $o0 0	b" &&
+		echo "100644 $o0 0	c" &&
 		echo "100644 $o0 0	d/e"
 	) >expected &&
 	test_cmp expected actual &&
@@ -190,13 +190,13 @@ test_expect_success 'setup 5' '
 	test_tick &&
 	git commit -m "remove removes b and modifies a" &&
 	c5=$(git rev-parse --verify HEAD) &&
-	( git ls-tree -r HEAD ; git ls-files -s ) >actual &&
+	( git ls-tree -r HEAD && git ls-files -s ) >actual &&
 	(
-		echo "100644 blob $o5	a"
-		echo "100644 blob $o0	c"
-		echo "100644 blob $o0	d/e"
-		echo "100644 $o5 0	a"
-		echo "100644 $o0 0	c"
+		echo "100644 blob $o5	a" &&
+		echo "100644 blob $o0	c" &&
+		echo "100644 blob $o0	d/e" &&
+		echo "100644 $o5 0	a" &&
+		echo "100644 $o0 0	c" &&
 		echo "100644 $o0 0	d/e"
 	) >expected &&
 	test_cmp expected actual
@@ -207,15 +207,15 @@ test_expect_success 'setup 6' '
 
 	rm -rf [abcd] &&
 	git checkout df-3 &&
-	( git ls-tree -r HEAD ; git ls-files -s ) >actual &&
+	( git ls-tree -r HEAD && git ls-files -s ) >actual &&
 	(
-		echo "100644 blob $o0	a"
-		echo "100644 blob $o0	b"
-		echo "100644 blob $o0	c"
-		echo "100644 blob $o0	d/e"
-		echo "100644 $o0 0	a"
-		echo "100644 $o0 0	b"
-		echo "100644 $o0 0	c"
+		echo "100644 blob $o0	a" &&
+		echo "100644 blob $o0	b" &&
+		echo "100644 blob $o0	c" &&
+		echo "100644 blob $o0	d/e" &&
+		echo "100644 $o0 0	a" &&
+		echo "100644 $o0 0	b" &&
+		echo "100644 $o0 0	c" &&
 		echo "100644 $o0 0	d/e"
 	) >expected &&
 	test_cmp expected actual &&
@@ -226,15 +226,15 @@ test_expect_success 'setup 6' '
 	test_tick &&
 	git commit -m "df-3 makes d" &&
 	c6=$(git rev-parse --verify HEAD) &&
-	( git ls-tree -r HEAD ; git ls-files -s ) >actual &&
+	( git ls-tree -r HEAD && git ls-files -s ) >actual &&
 	(
-		echo "100644 blob $o0	a"
-		echo "100644 blob $o0	b"
-		echo "100644 blob $o0	c"
-		echo "100644 blob $o6	d"
-		echo "100644 $o0 0	a"
-		echo "100644 $o0 0	b"
-		echo "100644 $o0 0	c"
+		echo "100644 blob $o0	a" &&
+		echo "100644 blob $o0	b" &&
+		echo "100644 blob $o0	c" &&
+		echo "100644 blob $o6	d" &&
+		echo "100644 $o0 0	a" &&
+		echo "100644 $o0 0	b" &&
+		echo "100644 $o0 0	c" &&
 		echo "100644 $o6 0	d"
 	) >expected &&
 	test_cmp expected actual
@@ -286,11 +286,11 @@ test_expect_success 'merge-recursive res
 
 	git ls-files -s >actual &&
 	(
-		echo "100644 $o0 1	a"
-		echo "100644 $o2 2	a"
-		echo "100644 $o1 3	a"
-		echo "100644 $o0 0	b"
-		echo "100644 $o0 0	c"
+		echo "100644 $o0 1	a" &&
+		echo "100644 $o2 2	a" &&
+		echo "100644 $o1 3	a" &&
+		echo "100644 $o0 0	b" &&
+		echo "100644 $o0 0	c" &&
 		echo "100644 $o1 0	d/e"
 	) >expected &&
 	test_cmp expected actual
@@ -325,10 +325,10 @@ test_expect_success 'merge-recursive rem
 
 	git ls-files -s >actual &&
 	(
-		echo "100644 $o0 1	a"
-		echo "100644 $o1 2	a"
-		echo "100644 $o5 3	a"
-		echo "100644 $o0 0	c"
+		echo "100644 $o0 1	a" &&
+		echo "100644 $o1 2	a" &&
+		echo "100644 $o5 3	a" &&
+		echo "100644 $o0 0	c" &&
 		echo "100644 $o1 0	d/e"
 	) >expected &&
 	test_cmp expected actual
@@ -347,9 +347,9 @@ test_expect_success 'merge-recursive res
 
 	git ls-files -s >actual &&
 	(
-		echo "100644 $o1 0	a"
-		echo "100644 $o3 0	b/c"
-		echo "100644 $o0 0	c"
+		echo "100644 $o1 0	a" &&
+		echo "100644 $o3 0	b/c" &&
+		echo "100644 $o0 0	c" &&
 		echo "100644 $o1 0	d/e"
 	) >expected &&
 	test_cmp expected actual
@@ -369,11 +369,11 @@ test_expect_success 'merge-recursive d/f
 
 	git ls-files -s >actual &&
 	(
-		echo "100644 $o0 1	a"
-		echo "100644 $o1 2	a"
-		echo "100644 $o4 0	a/c"
-		echo "100644 $o0 0	b"
-		echo "100644 $o0 0	c"
+		echo "100644 $o0 1	a" &&
+		echo "100644 $o1 2	a" &&
+		echo "100644 $o4 0	a/c" &&
+		echo "100644 $o0 0	b" &&
+		echo "100644 $o0 0	c" &&
 		echo "100644 $o1 0	d/e"
 	) >expected &&
 	test_cmp expected actual
@@ -393,11 +393,11 @@ test_expect_success 'merge-recursive d/f
 
 	git ls-files -s >actual &&
 	(
-		echo "100644 $o0 1	a"
-		echo "100644 $o1 3	a"
-		echo "100644 $o4 0	a/c"
-		echo "100644 $o0 0	b"
-		echo "100644 $o0 0	c"
+		echo "100644 $o0 1	a" &&
+		echo "100644 $o1 3	a" &&
+		echo "100644 $o4 0	a/c" &&
+		echo "100644 $o0 0	b" &&
+		echo "100644 $o0 0	c" &&
 		echo "100644 $o1 0	d/e"
 	) >expected &&
 	test_cmp expected actual
@@ -417,11 +417,11 @@ test_expect_success 'merge-recursive d/f
 
 	git ls-files -s >actual &&
 	(
-		echo "100644 $o1 0	a"
-		echo "100644 $o0 0	b"
-		echo "100644 $o0 0	c"
-		echo "100644 $o6 3	d"
-		echo "100644 $o0 1	d/e"
+		echo "100644 $o1 0	a" &&
+		echo "100644 $o0 0	b" &&
+		echo "100644 $o0 0	c" &&
+		echo "100644 $o6 3	d" &&
+		echo "100644 $o0 1	d/e" &&
 		echo "100644 $o1 2	d/e"
 	) >expected &&
 	test_cmp expected actual
@@ -441,17 +441,45 @@ test_expect_success 'merge-recursive d/f
 
 	git ls-files -s >actual &&
 	(
-		echo "100644 $o1 0	a"
-		echo "100644 $o0 0	b"
-		echo "100644 $o0 0	c"
-		echo "100644 $o6 2	d"
-		echo "100644 $o0 1	d/e"
+		echo "100644 $o1 0	a" &&
+		echo "100644 $o0 0	b" &&
+		echo "100644 $o0 0	c" &&
+		echo "100644 $o6 2	d" &&
+		echo "100644 $o0 1	d/e" &&
 		echo "100644 $o1 3	d/e"
 	) >expected &&
 	test_cmp expected actual
 
 '
 
+test_expect_success SYMLINKS 'dir in working tree with symlink ancestor does not produce d/f conflict' '
+	git init sym &&
+	(
+		cd sym &&
+		ln -s . foo &&
+		mkdir bar &&
+		>bar/file &&
+		git add foo bar/file &&
+		git commit -m "foo symlink" &&
+
+		git checkout -b branch1 &&
+		git commit --allow-empty -m "empty commit" &&
+
+		git checkout master &&
+		git rm foo &&
+		mkdir foo &&
+		>foo/bar &&
+		git add foo/bar &&
+		git commit -m "replace foo symlink with real foo dir and foo/bar file" &&
+
+		git checkout branch1 &&
+
+		git cherry-pick master &&
+		test_path_is_dir foo &&
+		test_path_is_file foo/bar
+	)
+'
+
 test_expect_success 'reset and 3-way merge' '
 
 	git reset --hard "$c2" &&
@@ -465,13 +493,13 @@ test_expect_success 'reset and bind merg
 	git read-tree --prefix=M/ master &&
 	git ls-files -s >actual &&
 	(
-		echo "100644 $o1 0	M/a"
-		echo "100644 $o0 0	M/b"
-		echo "100644 $o0 0	M/c"
-		echo "100644 $o1 0	M/d/e"
-		echo "100644 $o1 0	a"
-		echo "100644 $o0 0	b"
-		echo "100644 $o0 0	c"
+		echo "100644 $o1 0	M/a" &&
+		echo "100644 $o0 0	M/b" &&
+		echo "100644 $o0 0	M/c" &&
+		echo "100644 $o1 0	M/d/e" &&
+		echo "100644 $o1 0	a" &&
+		echo "100644 $o0 0	b" &&
+		echo "100644 $o0 0	c" &&
 		echo "100644 $o1 0	d/e"
 	) >expected &&
 	test_cmp expected actual &&
@@ -479,17 +507,17 @@ test_expect_success 'reset and bind merg
 	git read-tree --prefix=a1/ master &&
 	git ls-files -s >actual &&
 	(
-		echo "100644 $o1 0	M/a"
-		echo "100644 $o0 0	M/b"
-		echo "100644 $o0 0	M/c"
-		echo "100644 $o1 0	M/d/e"
-		echo "100644 $o1 0	a"
-		echo "100644 $o1 0	a1/a"
-		echo "100644 $o0 0	a1/b"
-		echo "100644 $o0 0	a1/c"
-		echo "100644 $o1 0	a1/d/e"
-		echo "100644 $o0 0	b"
-		echo "100644 $o0 0	c"
+		echo "100644 $o1 0	M/a" &&
+		echo "100644 $o0 0	M/b" &&
+		echo "100644 $o0 0	M/c" &&
+		echo "100644 $o1 0	M/d/e" &&
+		echo "100644 $o1 0	a" &&
+		echo "100644 $o1 0	a1/a" &&
+		echo "100644 $o0 0	a1/b" &&
+		echo "100644 $o0 0	a1/c" &&
+		echo "100644 $o1 0	a1/d/e" &&
+		echo "100644 $o0 0	b" &&
+		echo "100644 $o0 0	c" &&
 		echo "100644 $o1 0	d/e"
 	) >expected &&
 	test_cmp expected actual &&
@@ -497,21 +525,21 @@ test_expect_success 'reset and bind merg
 	git read-tree --prefix=z/ master &&
 	git ls-files -s >actual &&
 	(
-		echo "100644 $o1 0	M/a"
-		echo "100644 $o0 0	M/b"
-		echo "100644 $o0 0	M/c"
-		echo "100644 $o1 0	M/d/e"
-		echo "100644 $o1 0	a"
-		echo "100644 $o1 0	a1/a"
-		echo "100644 $o0 0	a1/b"
-		echo "100644 $o0 0	a1/c"
-		echo "100644 $o1 0	a1/d/e"
-		echo "100644 $o0 0	b"
-		echo "100644 $o0 0	c"
-		echo "100644 $o1 0	d/e"
-		echo "100644 $o1 0	z/a"
-		echo "100644 $o0 0	z/b"
-		echo "100644 $o0 0	z/c"
+		echo "100644 $o1 0	M/a" &&
+		echo "100644 $o0 0	M/b" &&
+		echo "100644 $o0 0	M/c" &&
+		echo "100644 $o1 0	M/d/e" &&
+		echo "100644 $o1 0	a" &&
+		echo "100644 $o1 0	a1/a" &&
+		echo "100644 $o0 0	a1/b" &&
+		echo "100644 $o0 0	a1/c" &&
+		echo "100644 $o1 0	a1/d/e" &&
+		echo "100644 $o0 0	b" &&
+		echo "100644 $o0 0	c" &&
+		echo "100644 $o1 0	d/e" &&
+		echo "100644 $o1 0	z/a" &&
+		echo "100644 $o0 0	z/b" &&
+		echo "100644 $o0 0	z/c" &&
 		echo "100644 $o1 0	z/d/e"
 	) >expected &&
 	test_cmp expected actual
@@ -589,8 +617,8 @@ test_expect_success 'merge-recursive sim
 
 	git ls-files -s >actual &&
 	(
-		echo "100644 $o5 0	a"
-		echo "100644 $o0 0	c"
+		echo "100644 $o5 0	a" &&
+		echo "100644 $o0 0	c" &&
 		echo "160000 $c1 0	d"
 	) >expected &&
 	test_cmp expected actual
@@ -601,13 +629,13 @@ test_expect_success 'merge-recursive cop
 	git merge rename &&
 	( git ls-tree -r HEAD && git ls-files -s ) >actual &&
 	(
-		echo "100644 blob $o0	b"
-		echo "100644 blob $o0	c"
-		echo "100644 blob $o0	d/e"
-		echo "100644 blob $o0	e"
-		echo "100644 $o0 0	b"
-		echo "100644 $o0 0	c"
-		echo "100644 $o0 0	d/e"
+		echo "100644 blob $o0	b" &&
+		echo "100644 blob $o0	c" &&
+		echo "100644 blob $o0	d/e" &&
+		echo "100644 blob $o0	e" &&
+		echo "100644 $o0 0	b" &&
+		echo "100644 $o0 0	c" &&
+		echo "100644 $o0 0	d/e" &&
 		echo "100644 $o0 0	e"
 	) >expected &&
 	test_cmp expected actual
@@ -617,17 +645,17 @@ test_expect_failure 'merge-recursive ren
 
 	git checkout -f rename &&
 	git merge rename-ln &&
-	( git ls-tree -r HEAD ; git ls-files -s ) >actual &&
+	( git ls-tree -r HEAD && git ls-files -s ) >actual &&
 	(
-		echo "120000 blob $oln	a"
-		echo "100644 blob $o0	b"
-		echo "100644 blob $o0	c"
-		echo "100644 blob $o0	d/e"
-		echo "100644 blob $o0	e"
-		echo "120000 $oln 0	a"
-		echo "100644 $o0 0	b"
-		echo "100644 $o0 0	c"
-		echo "100644 $o0 0	d/e"
+		echo "120000 blob $oln	a" &&
+		echo "100644 blob $o0	b" &&
+		echo "100644 blob $o0	c" &&
+		echo "100644 blob $o0	d/e" &&
+		echo "100644 blob $o0	e" &&
+		echo "120000 $oln 0	a" &&
+		echo "100644 $o0 0	b" &&
+		echo "100644 $o0 0	c" &&
+		echo "100644 $o0 0	d/e" &&
 		echo "100644 $o0 0	e"
 	) >expected &&
 	test_cmp expected actual
@@ -667,15 +695,22 @@ test_expect_success 'merging with triple
 test_expect_success 'merge-recursive remembers the names of all base trees' '
 	git reset --hard HEAD &&
 
+	# make the index match $c1 so that merge-recursive below does not
+	# fail early
+	git diff --binary HEAD $c1 -- | git apply --cached &&
+
 	# more trees than static slots used by oid_to_hex()
 	for commit in $c0 $c2 $c4 $c5 $c6 $c7
 	do
 		git rev-parse "$commit^{tree}"
 	done >trees &&
 
-	# ignore the return code -- it only fails because the input is weird
+	# ignore the return code; it only fails because the input is weird...
 	test_must_fail git -c merge.verbosity=5 merge-recursive $(cat trees) -- $c1 $c3 >out &&
 
+	# ...but make sure it fails in the expected way
+	test_i18ngrep CONFLICT.*rename/rename out &&
+
 	# merge-recursive prints in reverse order, but we do not care
 	sort <trees >expect &&
 	sed -n "s/^virtual //p" out | sort >actual &&
diff -pruN 1.2.1+git2.18.0-1/git/t/t3031-merge-criscross.sh 1.2.3+git2.25.1-1/git/t/t3031-merge-criscross.sh
--- 1.2.1+git2.18.0-1/git/t/t3031-merge-criscross.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t3031-merge-criscross.sh	2020-02-17 04:47:35.000000000 +0000
@@ -88,7 +88,7 @@ test_expect_success 'setup repo with cri
 	git branch G
 '
 
-test_expect_success 'recursive merge between F and G, causes segfault' '
+test_expect_success 'recursive merge between F and G does not cause segfault' '
 	git merge F
 '
 
diff -pruN 1.2.1+git2.18.0-1/git/t/t3035-merge-sparse.sh 1.2.3+git2.25.1-1/git/t/t3035-merge-sparse.sh
--- 1.2.1+git2.18.0-1/git/t/t3035-merge-sparse.sh	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t3035-merge-sparse.sh	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,58 @@
+#!/bin/sh
+
+test_description='merge with sparse files'
+
+. ./test-lib.sh
+
+# test_file $filename $content
+test_file () {
+	echo "$2" > "$1" &&
+	git add "$1"
+}
+
+# test_commit_this $message_and_tag
+test_commit_this () {
+	git commit -m "$1" &&
+	git tag "$1"
+}
+
+test_expect_success 'setup' '
+	test_file checked-out init &&
+	test_file modify_delete modify_delete_init &&
+	test_commit_this init &&
+	test_file modify_delete modify_delete_theirs &&
+	test_commit_this theirs &&
+	git reset --hard init &&
+	git rm modify_delete &&
+	test_commit_this ours &&
+	git config core.sparseCheckout true &&
+	echo "/checked-out" >.git/info/sparse-checkout &&
+	git reset --hard &&
+	! git merge theirs
+'
+
+test_expect_success 'reset --hard works after the conflict' '
+	git reset --hard
+'
+
+test_expect_success 'is reset properly' '
+	git status --porcelain -- modify_delete >out &&
+	test_must_be_empty out &&
+	test_path_is_missing modify_delete
+'
+
+test_expect_success 'setup: conflict back' '
+	! git merge theirs
+'
+
+test_expect_success 'Merge abort works after the conflict' '
+	git merge --abort
+'
+
+test_expect_success 'is aborted properly' '
+	git status --porcelain -- modify_delete >out &&
+	test_must_be_empty out &&
+	test_path_is_missing modify_delete
+'
+
+test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t3050-subprojects-fetch.sh 1.2.3+git2.25.1-1/git/t/t3050-subprojects-fetch.sh
--- 1.2.1+git2.18.0-1/git/t/t3050-subprojects-fetch.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t3050-subprojects-fetch.sh	2020-02-17 04:47:35.000000000 +0000
@@ -21,10 +21,10 @@ test_expect_success setup '
 
 test_expect_success clone '
 	git clone "file://$(pwd)/.git" cloned &&
-	(git rev-parse HEAD; git ls-files -s) >expected &&
+	(git rev-parse HEAD && git ls-files -s) >expected &&
 	(
 		cd cloned &&
-		(git rev-parse HEAD; git ls-files -s) >../actual
+		(git rev-parse HEAD && git ls-files -s) >../actual
 	) &&
 	test_cmp expected actual
 '
@@ -40,11 +40,11 @@ test_expect_success advance '
 '
 
 test_expect_success fetch '
-	(git rev-parse HEAD; git ls-files -s) >expected &&
+	(git rev-parse HEAD && git ls-files -s) >expected &&
 	(
 		cd cloned &&
 		git pull &&
-		(git rev-parse HEAD; git ls-files -s) >../actual
+		(git rev-parse HEAD && git ls-files -s) >../actual
 	) &&
 	test_cmp expected actual
 '
diff -pruN 1.2.1+git2.18.0-1/git/t/t3060-ls-files-with-tree.sh 1.2.3+git2.25.1-1/git/t/t3060-ls-files-with-tree.sh
--- 1.2.1+git2.18.0-1/git/t/t3060-ls-files-with-tree.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t3060-ls-files-with-tree.sh	2020-02-17 04:47:35.000000000 +0000
@@ -47,7 +47,7 @@ test_expect_success setup '
 	git add .
 '
 
-test_expect_success 'git -ls-files --with-tree should succeed from subdir' '
+test_expect_success 'git ls-files --with-tree should succeed from subdir' '
 	# We have to run from a sub-directory to trigger prune_path
 	# Then we finally get to run our --with-tree test
 	(
@@ -57,7 +57,7 @@ test_expect_success 'git -ls-files --wit
 '
 
 test_expect_success \
-    'git -ls-files --with-tree should add entries from named tree.' \
+    'git ls-files --with-tree should add entries from named tree.' \
     'test_cmp expected output'
 
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t3070-wildmatch.sh 1.2.3+git2.25.1-1/git/t/t3070-wildmatch.sh
--- 1.2.1+git2.18.0-1/git/t/t3070-wildmatch.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t3070-wildmatch.sh	2020-02-17 04:47:35.000000000 +0000
@@ -101,8 +101,7 @@ match_with_ls_files() {
 
 	match_stdout_stderr_cmp="
 		tr -d '\0' <actual.raw >actual &&
-		>expect.err &&
-		test_cmp expect.err actual.err &&
+		test_must_be_empty actual.err &&
 		test_cmp expect actual"
 
 	if test "$match_expect" = 'E'
@@ -238,7 +237,7 @@ match 0 0 0 0 foobar 'foo\*bar'
 match 1 1 1 1 'f\oo' 'f\\oo'
 match 1 1 1 1 ball '*[al]?'
 match 0 0 0 0 ten '[ten]'
-match 0 0 1 1 ten '**[!te]'
+match 1 1 1 1 ten '**[!te]'
 match 0 0 0 0 ten '**[!ten]'
 match 1 1 1 1 ten 't[a-g]n'
 match 0 0 0 0 ten 't[!a-g]n'
@@ -254,7 +253,7 @@ match 1 1 1 1 ']' ']'
 # Extended slash-matching features
 match 0 0 1 1 'foo/baz/bar' 'foo*bar'
 match 0 0 1 1 'foo/baz/bar' 'foo**bar'
-match 0 0 1 1 'foobazbar' 'foo**bar'
+match 1 1 1 1 'foobazbar' 'foo**bar'
 match 1 1 1 1 'foo/baz/bar' 'foo/**/bar'
 match 1 1 0 0 'foo/baz/bar' 'foo/**/**/bar'
 match 1 1 1 1 'foo/b/a/z/bar' 'foo/**/bar'
diff -pruN 1.2.1+git2.18.0-1/git/t/t3102-ls-tree-wildcards.sh 1.2.3+git2.25.1-1/git/t/t3102-ls-tree-wildcards.sh
--- 1.2.1+git2.18.0-1/git/t/t3102-ls-tree-wildcards.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t3102-ls-tree-wildcards.sh	2020-02-17 04:47:35.000000000 +0000
@@ -23,7 +23,7 @@ test_expect_success 'ls-tree outside pre
 	cat >expect <<-EOF &&
 	100644 blob $EMPTY_BLOB	../a[a]/three
 	EOF
-	( cd aa && git ls-tree -r HEAD "../a[a]"; ) >actual &&
+	( cd aa && git ls-tree -r HEAD "../a[a]" ) >actual &&
 	test_cmp expect actual
 '
 
diff -pruN 1.2.1+git2.18.0-1/git/t/t3200-branch.sh 1.2.3+git2.25.1-1/git/t/t3200-branch.sh
--- 1.2.1+git2.18.0-1/git/t/t3200-branch.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t3200-branch.sh	2020-02-17 04:47:35.000000000 +0000
@@ -42,6 +42,10 @@ test_expect_success 'git branch a/b/c sh
 	git branch a/b/c && test_path_is_file .git/refs/heads/a/b/c
 '
 
+test_expect_success 'git branch mb master... should create a branch' '
+	git branch mb master... && test_path_is_file .git/refs/heads/mb
+'
+
 test_expect_success 'git branch HEAD should fail' '
 	test_must_fail git branch HEAD
 '
@@ -49,9 +53,9 @@ test_expect_success 'git branch HEAD sho
 cat >expect <<EOF
 $ZERO_OID $HEAD $GIT_COMMITTER_NAME <$GIT_COMMITTER_EMAIL> 1117150200 +0000	branch: Created from master
 EOF
-test_expect_success 'git branch -l d/e/f should create a branch and a log' '
+test_expect_success 'git branch --create-reflog d/e/f should create a branch and a log' '
 	GIT_COMMITTER_DATE="2005-05-26 23:30" \
-	git branch -l d/e/f &&
+	git -c core.logallrefupdates=false branch --create-reflog d/e/f &&
 	test_path_is_file .git/refs/heads/d/e/f &&
 	test_path_is_file .git/logs/refs/heads/d/e/f &&
 	test_cmp expect .git/logs/refs/heads/d/e/f
@@ -82,7 +86,7 @@ test_expect_success 'git branch -m dumps
 
 test_expect_success 'git branch -m m broken_symref should work' '
 	test_when_finished "git branch -D broken_symref" &&
-	git branch -l m &&
+	git branch --create-reflog m &&
 	git symbolic-ref refs/heads/broken_symref refs/heads/i_am_broken &&
 	git branch -m m broken_symref &&
 	git reflog exists refs/heads/broken_symref &&
@@ -90,13 +94,13 @@ test_expect_success 'git branch -m m bro
 '
 
 test_expect_success 'git branch -m m m/m should work' '
-	git branch -l m &&
+	git branch --create-reflog m &&
 	git branch -m m m/m &&
 	git reflog exists refs/heads/m/m
 '
 
 test_expect_success 'git branch -m n/n n should work' '
-	git branch -l n/n &&
+	git branch --create-reflog n/n &&
 	git branch -m n/n n &&
 	git reflog exists refs/heads/n
 '
@@ -202,18 +206,22 @@ test_expect_success 'git branch -M baz b
 	git worktree add -f bazdir2 baz &&
 	git branch -M baz bam &&
 	test $(git -C bazdir rev-parse --abbrev-ref HEAD) = bam &&
-	test $(git -C bazdir2 rev-parse --abbrev-ref HEAD) = bam
+	test $(git -C bazdir2 rev-parse --abbrev-ref HEAD) = bam &&
+	rm -r bazdir bazdir2 &&
+	git worktree prune
 '
 
 test_expect_success 'git branch -M baz bam should succeed within a worktree in which baz is checked out' '
 	git checkout -b baz &&
-	git worktree add -f bazdir3 baz &&
+	git worktree add -f bazdir baz &&
 	(
-		cd bazdir3 &&
+		cd bazdir &&
 		git branch -M baz bam &&
 		test $(git rev-parse --abbrev-ref HEAD) = bam
 	) &&
-	test $(git rev-parse --abbrev-ref HEAD) = bam
+	test $(git rev-parse --abbrev-ref HEAD) = bam &&
+	rm -r bazdir &&
+	git worktree prune
 '
 
 test_expect_success 'git branch -M master should work when master is checked out' '
@@ -264,6 +272,30 @@ test_expect_success 'git branch --list -
 	test_must_fail git rev-parse refs/heads/t
 '
 
+test_expect_success 'deleting checked-out branch from repo that is a submodule' '
+	test_when_finished "rm -rf repo1 repo2" &&
+
+	git init repo1 &&
+	git init repo1/sub &&
+	test_commit -C repo1/sub x &&
+	git -C repo1 submodule add ./sub &&
+	git -C repo1 commit -m "adding sub" &&
+
+	git clone --recurse-submodules repo1 repo2 &&
+	git -C repo2/sub checkout -b work &&
+	test_must_fail git -C repo2/sub branch -D work
+'
+
+test_expect_success 'bare main worktree has HEAD at branch deleted by secondary worktree' '
+	test_when_finished "rm -rf nonbare base secondary" &&
+
+	git init nonbare &&
+	test_commit -C nonbare x &&
+	git clone --bare nonbare bare &&
+	git -C bare worktree add --detach ../secondary master &&
+	git -C secondary branch -D master
+'
+
 test_expect_success 'git branch --list -v with --abbrev' '
 	test_when_finished "git branch -D t" &&
 	git branch t &&
@@ -292,8 +324,8 @@ test_expect_success 'git branch --list -
 test_expect_success 'git branch --column' '
 	COLUMNS=81 git branch --column=column >actual &&
 	cat >expected <<\EOF &&
-  a/b/c     bam       foo       l       * master    n         o/p       r
-  abc       bar       j/k       m/m       master2   o/o       q
+  a/b/c     bam       foo       l       * master    mb        o/o       q
+  abc       bar       j/k       m/m       master2   n         o/p       r
 EOF
 	test_cmp expected actual
 '
@@ -315,6 +347,7 @@ test_expect_success 'git branch --column
   m/m
 * master
   master2
+  mb
   n
   o/o
   o/p
@@ -332,8 +365,8 @@ test_expect_success 'git branch with col
 	git config --unset column.branch &&
 	git config --unset column.ui &&
 	cat >expected <<\EOF &&
-  a/b/c   bam   foo   l   * master    n     o/p   r
-  abc     bar   j/k   m/m   master2   o/o   q
+  a/b/c   bam   foo   l   * master    mb   o/o   q
+  abc     bar   j/k   m/m   master2   n    o/p   r
 EOF
 	test_cmp expected actual
 '
@@ -357,6 +390,7 @@ test_expect_success 'git branch -v with
   m/m
 * master
   master2
+  mb
   n
   o/o
   o/p
@@ -378,9 +412,9 @@ mv .git/config-saved .git/config
 git config branch.s/s.dummy Hello
 
 test_expect_success 'git branch -m s/s s should work when s/t is deleted' '
-	git branch -l s/s &&
+	git branch --create-reflog s/s &&
 	git reflog exists refs/heads/s/s &&
-	git branch -l s/t &&
+	git branch --create-reflog s/t &&
 	git reflog exists refs/heads/s/t &&
 	git branch -d s/t &&
 	git branch -m s/s s &&
@@ -444,7 +478,7 @@ test_expect_success 'git branch --copy d
 '
 
 test_expect_success 'git branch -c d e should work' '
-	git branch -l d &&
+	git branch --create-reflog d &&
 	git reflog exists refs/heads/d &&
 	git config branch.d.dummy Hello &&
 	git branch -c d e &&
@@ -459,7 +493,7 @@ test_expect_success 'git branch -c d e s
 '
 
 test_expect_success 'git branch --copy is a synonym for -c' '
-	git branch -l copy &&
+	git branch --create-reflog copy &&
 	git reflog exists refs/heads/copy &&
 	git config branch.copy.dummy Hello &&
 	git branch --copy copy copy-to &&
@@ -486,7 +520,7 @@ test_expect_success 'git branch -c ee ef
 '
 
 test_expect_success 'git branch -c f/f g/g should work' '
-	git branch -l f/f &&
+	git branch --create-reflog f/f &&
 	git reflog exists refs/heads/f/f &&
 	git config branch.f/f.dummy Hello &&
 	git branch -c f/f g/g &&
@@ -497,7 +531,7 @@ test_expect_success 'git branch -c f/f g
 '
 
 test_expect_success 'git branch -c m2 m2 should work' '
-	git branch -l m2 &&
+	git branch --create-reflog m2 &&
 	git reflog exists refs/heads/m2 &&
 	git config branch.m2.dummy Hello &&
 	git branch -c m2 m2 &&
@@ -506,18 +540,18 @@ test_expect_success 'git branch -c m2 m2
 '
 
 test_expect_success 'git branch -c zz zz/zz should fail' '
-	git branch -l zz &&
+	git branch --create-reflog zz &&
 	git reflog exists refs/heads/zz &&
 	test_must_fail git branch -c zz zz/zz
 '
 
 test_expect_success 'git branch -c b/b b should fail' '
-	git branch -l b/b &&
+	git branch --create-reflog b/b &&
 	test_must_fail git branch -c b/b b
 '
 
 test_expect_success 'git branch -C o/q o/p should work when o/p exists' '
-	git branch -l o/q &&
+	git branch --create-reflog o/q &&
 	git reflog exists refs/heads/o/q &&
 	git reflog exists refs/heads/o/p &&
 	git branch -C o/q o/p
@@ -570,10 +604,10 @@ test_expect_success 'git branch -C maste
 '
 
 test_expect_success 'git branch -C ab cd should overwrite existing config for cd' '
-	git branch -l cd &&
+	git branch --create-reflog cd &&
 	git reflog exists refs/heads/cd &&
 	git config branch.cd.dummy CD &&
-	git branch -l ab &&
+	git branch --create-reflog ab &&
 	git reflog exists refs/heads/ab &&
 	git config branch.ab.dummy AB &&
 	git branch -C ab cd &&
@@ -685,7 +719,7 @@ test_expect_success 'renaming a symref i
 '
 
 test_expect_success SYMLINKS 'git branch -m u v should fail when the reflog for u is a symlink' '
-	git branch -l u &&
+	git branch --create-reflog u &&
 	mv .git/logs/refs/heads/u real-u &&
 	ln -s real-u .git/logs/refs/heads/u &&
 	test_must_fail git branch -m u v
@@ -774,7 +808,9 @@ test_expect_success 'test deleting branc
 test_expect_success 'deleting currently checked out branch fails' '
 	git worktree add -b my7 my7 &&
 	test_must_fail git -C my7 branch -d my7 &&
-	test_must_fail git branch -d my7
+	test_must_fail git branch -d my7 &&
+	rm -r my7 &&
+	git worktree prune
 '
 
 test_expect_success 'test --track without .fetch entries' '
@@ -1221,7 +1257,7 @@ test_expect_success 'use --edit-descript
 	EOF
 	EDITOR=./editor git branch --edit-description &&
 	echo "New contents" >expect &&
-	test_cmp EDITOR_OUTPUT expect
+	test_cmp expect EDITOR_OUTPUT
 '
 
 test_expect_success 'detect typo in branch name when using --edit-description' '
@@ -1305,4 +1341,50 @@ test_expect_success 'tracking with unexp
 	)
 '
 
+test_expect_success 'configured committerdate sort' '
+	git init sort &&
+	(
+		cd sort &&
+		git config branch.sort committerdate &&
+		test_commit initial &&
+		git checkout -b a &&
+		test_commit a &&
+		git checkout -b c &&
+		test_commit c &&
+		git checkout -b b &&
+		test_commit b &&
+		git branch >actual &&
+		cat >expect <<-\EOF &&
+		  master
+		  a
+		  c
+		* b
+		EOF
+		test_cmp expect actual
+	)
+'
+
+test_expect_success 'option override configured sort' '
+	(
+		cd sort &&
+		git config branch.sort committerdate &&
+		git branch --sort=refname >actual &&
+		cat >expect <<-\EOF &&
+		  a
+		* b
+		  c
+		  master
+		EOF
+		test_cmp expect actual
+	)
+'
+
+test_expect_success 'invalid sort parameter in configuration' '
+	(
+		cd sort &&
+		git config branch.sort "v:notvalid" &&
+		test_must_fail git branch
+	)
+'
+
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t3201-branch-contains.sh 1.2.3+git2.25.1-1/git/t/t3201-branch-contains.sh
--- 1.2.1+git2.18.0-1/git/t/t3201-branch-contains.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t3201-branch-contains.sh	2020-02-17 04:47:35.000000000 +0000
@@ -48,16 +48,14 @@ test_expect_success 'branch --contains m
 test_expect_success 'branch --no-contains=master' '
 
 	git branch --no-contains=master >actual &&
-	>expect &&
-	test_cmp expect actual
+	test_must_be_empty actual
 
 '
 
 test_expect_success 'branch --no-contains master' '
 
 	git branch --no-contains master >actual &&
-	>expect &&
-	test_cmp expect actual
+	test_must_be_empty actual
 
 '
 
@@ -94,8 +92,7 @@ test_expect_success 'branch --contains w
 test_expect_success 'branch --no-contains with pattern implies --list' '
 
 	git branch --no-contains=master master >actual &&
-	>expect &&
-	test_cmp expect actual
+	test_must_be_empty actual
 
 '
 
@@ -123,8 +120,7 @@ test_expect_success 'branch --merged wit
 test_expect_success 'side: branch --no-merged' '
 
 	git branch --no-merged >actual &&
-	>expect &&
-	test_cmp expect actual
+	test_must_be_empty actual
 
 '
 
@@ -152,8 +148,7 @@ test_expect_success 'master: branch --no
 test_expect_success 'branch --no-merged with pattern implies --list' '
 
 	git branch --no-merged=master master >actual &&
-	>expect &&
-	test_cmp expect actual
+	test_must_be_empty actual
 
 '
 
@@ -197,10 +192,10 @@ test_expect_success 'branch --merged wit
 	EOF
 	test_cmp expect actual &&
 	git branch --verbose --merged topic >actual &&
-	cat >expect <<-\EOF &&
-	  master c77a0a9 second on master
-	* topic  2c939f4 [ahead 1] foo
-	  zzz    c77a0a9 second on master
+	cat >expect <<-EOF &&
+	  master $(git rev-parse --short master) second on master
+	* topic  $(git rev-parse --short topic ) [ahead 1] foo
+	  zzz    $(git rev-parse --short zzz   ) second on master
 	EOF
 	test_i18ncmp expect actual
 '
diff -pruN 1.2.1+git2.18.0-1/git/t/t3203-branch-output.sh 1.2.3+git2.25.1-1/git/t/t3203-branch-output.sh
--- 1.2.1+git2.18.0-1/git/t/t3203-branch-output.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t3203-branch-output.sh	2020-02-17 04:47:35.000000000 +0000
@@ -100,6 +100,53 @@ test_expect_success 'git branch -v patte
 	test_must_fail git branch -v branch*
 '
 
+test_expect_success 'git branch `--show-current` shows current branch' '
+	cat >expect <<-\EOF &&
+	branch-two
+	EOF
+	git checkout branch-two &&
+	git branch --show-current >actual &&
+	test_cmp expect actual
+'
+
+test_expect_success 'git branch `--show-current` is silent when detached HEAD' '
+	git checkout HEAD^0 &&
+	git branch --show-current >actual &&
+	test_must_be_empty actual
+'
+
+test_expect_success 'git branch `--show-current` works properly when tag exists' '
+	cat >expect <<-\EOF &&
+	branch-and-tag-name
+	EOF
+	test_when_finished "
+		git checkout branch-one
+		git branch -D branch-and-tag-name
+	" &&
+	git checkout -b branch-and-tag-name &&
+	test_when_finished "git tag -d branch-and-tag-name" &&
+	git tag branch-and-tag-name &&
+	git branch --show-current >actual &&
+	test_cmp expect actual
+'
+
+test_expect_success 'git branch `--show-current` works properly with worktrees' '
+	cat >expect <<-\EOF &&
+	branch-one
+	branch-two
+	EOF
+	git checkout branch-one &&
+	test_when_finished "
+		git worktree remove worktree_dir
+	" &&
+	git worktree add worktree_dir branch-two &&
+	{
+		git branch --show-current &&
+		git -C worktree_dir branch --show-current
+	} >actual &&
+	test_cmp expect actual
+'
+
 test_expect_success 'git branch shows detached HEAD properly' '
 	cat >expect <<EOF &&
 * (HEAD detached at $(git rev-parse --short HEAD^0))
@@ -240,6 +287,24 @@ test_expect_success 'git branch --format
 	test_i18ncmp expect actual
 '
 
+test_expect_success 'worktree colors correct' '
+	cat >expect <<-EOF &&
+	* <GREEN>(HEAD detached from fromtag)<RESET>
+	  ambiguous<RESET>
+	  branch-one<RESET>
+	+ <CYAN>branch-two<RESET>
+	  master<RESET>
+	  ref-to-branch<RESET> -> branch-one
+	  ref-to-remote<RESET> -> origin/branch-one
+	EOF
+	git worktree add worktree_dir branch-two &&
+	git branch --color >actual.raw &&
+	rm -r worktree_dir &&
+	git worktree prune &&
+	test_decode_color <actual.raw >actual &&
+	test_i18ncmp expect actual
+'
+
 test_expect_success "set up color tests" '
 	echo "<RED>master<RESET>" >expect.color &&
 	echo "master" >expect.bare &&
@@ -264,4 +329,23 @@ test_expect_success '--color overrides a
 	test_cmp expect.color actual
 '
 
+test_expect_success 'verbose output lists worktree path' '
+	one=$(git rev-parse --short HEAD) &&
+	two=$(git rev-parse --short master) &&
+	cat >expect <<-EOF &&
+	* (HEAD detached from fromtag) $one one
+	  ambiguous                    $one one
+	  branch-one                   $two two
+	+ branch-two                   $one ($(pwd)/worktree_dir) one
+	  master                       $two two
+	  ref-to-branch                $two two
+	  ref-to-remote                $two two
+	EOF
+	git worktree add worktree_dir branch-two &&
+	git branch -vv >actual &&
+	rm -r worktree_dir &&
+	git worktree prune &&
+	test_i18ncmp expect actual
+'
+
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t3206/history.export 1.2.3+git2.25.1-1/git/t/t3206/history.export
--- 1.2.1+git2.18.0-1/git/t/t3206/history.export	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t3206/history.export	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,709 @@
+blob
+mark :1
+data 51
+1
+2
+3
+4
+5
+6
+7
+8
+9
+10
+11
+12
+13
+14
+15
+16
+17
+18
+19
+20
+
+reset refs/heads/renamed-file
+commit refs/heads/renamed-file
+mark :2
+author Thomas Rast <trast@inf.ethz.ch> 1374424921 +0200
+committer Thomas Rast <trast@inf.ethz.ch> 1374484724 +0200
+data 8
+initial
+M 100644 :1 file
+
+blob
+mark :3
+data 51
+1
+2
+3
+4
+A
+6
+7
+8
+9
+10
+11
+12
+13
+14
+15
+16
+17
+18
+19
+20
+
+commit refs/heads/mode-only-change
+mark :4
+author Thomas Rast <trast@inf.ethz.ch> 1374485014 +0200
+committer Thomas Rast <trast@inf.ethz.ch> 1374485014 +0200
+data 7
+s/5/A/
+from :2
+M 100644 :3 file
+
+blob
+mark :5
+data 51
+1
+2
+3
+A
+A
+6
+7
+8
+9
+10
+11
+12
+13
+14
+15
+16
+17
+18
+19
+20
+
+commit refs/heads/topic
+mark :6
+author Thomas Rast <trast@inf.ethz.ch> 1374485024 +0200
+committer Thomas Rast <trast@inf.ethz.ch> 1374485024 +0200
+data 7
+s/4/A/
+from :4
+M 100644 :5 file
+
+blob
+mark :7
+data 50
+1
+2
+3
+A
+A
+6
+7
+8
+9
+10
+B
+12
+13
+14
+15
+16
+17
+18
+19
+20
+
+commit refs/heads/topic
+mark :8
+author Thomas Rast <trast@inf.ethz.ch> 1374485036 +0200
+committer Thomas Rast <trast@inf.ethz.ch> 1374485036 +0200
+data 8
+s/11/B/
+from :6
+M 100644 :7 file
+
+blob
+mark :9
+data 49
+1
+2
+3
+A
+A
+6
+7
+8
+9
+10
+B
+B
+13
+14
+15
+16
+17
+18
+19
+20
+
+commit refs/heads/topic
+mark :10
+author Thomas Rast <trast@inf.ethz.ch> 1374485044 +0200
+committer Thomas Rast <trast@inf.ethz.ch> 1374485044 +0200
+data 8
+s/12/B/
+from :8
+M 100644 :9 file
+
+blob
+mark :11
+data 10
+unrelated
+
+commit refs/heads/master
+mark :12
+author Thomas Rast <trast@inf.ethz.ch> 1374485127 +0200
+committer Thomas Rast <trast@inf.ethz.ch> 1374485127 +0200
+data 10
+unrelated
+from :2
+M 100644 :11 otherfile
+
+commit refs/heads/rebased
+mark :13
+author Thomas Rast <trast@inf.ethz.ch> 1374485014 +0200
+committer Thomas Rast <trast@inf.ethz.ch> 1374485137 +0200
+data 7
+s/5/A/
+from :12
+M 100644 :3 file
+
+commit refs/heads/rebased
+mark :14
+author Thomas Rast <trast@inf.ethz.ch> 1374485024 +0200
+committer Thomas Rast <trast@inf.ethz.ch> 1374485138 +0200
+data 7
+s/4/A/
+from :13
+M 100644 :5 file
+
+commit refs/heads/rebased
+mark :15
+author Thomas Rast <trast@inf.ethz.ch> 1374485036 +0200
+committer Thomas Rast <trast@inf.ethz.ch> 1374485138 +0200
+data 8
+s/11/B/
+from :14
+M 100644 :7 file
+
+commit refs/heads/rebased
+mark :16
+author Thomas Rast <trast@inf.ethz.ch> 1374485044 +0200
+committer Thomas Rast <trast@inf.ethz.ch> 1374485138 +0200
+data 8
+s/12/B/
+from :15
+M 100644 :9 file
+
+commit refs/heads/added
+mark :17
+author Thomas Rast <trast@inf.ethz.ch> 1374485014 +0200
+committer Thomas Rast <trast@inf.ethz.ch> 1374485341 +0200
+data 7
+s/5/A/
+from :2
+M 100644 :3 file
+
+commit refs/heads/added
+mark :18
+author Thomas Rast <trast@inf.ethz.ch> 1374485024 +0200
+committer Thomas Rast <trast@inf.ethz.ch> 1374485341 +0200
+data 7
+s/4/A/
+from :17
+M 100644 :5 file
+
+blob
+mark :19
+data 51
+1
+2
+3
+A
+A
+A
+7
+8
+9
+10
+11
+12
+13
+14
+15
+16
+17
+18
+19
+20
+
+commit refs/heads/added
+mark :20
+author Thomas Rast <trast@inf.ethz.ch> 1374485186 +0200
+committer Thomas Rast <trast@inf.ethz.ch> 1374485341 +0200
+data 7
+s/6/A/
+from :18
+M 100644 :19 file
+
+blob
+mark :21
+data 50
+1
+2
+3
+A
+A
+A
+7
+8
+9
+10
+B
+12
+13
+14
+15
+16
+17
+18
+19
+20
+
+commit refs/heads/added
+mark :22
+author Thomas Rast <trast@inf.ethz.ch> 1374485036 +0200
+committer Thomas Rast <trast@inf.ethz.ch> 1374485341 +0200
+data 8
+s/11/B/
+from :20
+M 100644 :21 file
+
+blob
+mark :23
+data 49
+1
+2
+3
+A
+A
+A
+7
+8
+9
+10
+B
+B
+13
+14
+15
+16
+17
+18
+19
+20
+
+commit refs/heads/added
+mark :24
+author Thomas Rast <trast@inf.ethz.ch> 1374485044 +0200
+committer Thomas Rast <trast@inf.ethz.ch> 1374485341 +0200
+data 8
+s/12/B/
+from :22
+M 100644 :23 file
+
+commit refs/heads/reordered
+mark :25
+author Thomas Rast <trast@inf.ethz.ch> 1374485014 +0200
+committer Thomas Rast <trast@inf.ethz.ch> 1374485350 +0200
+data 7
+s/5/A/
+from :2
+M 100644 :3 file
+
+blob
+mark :26
+data 50
+1
+2
+3
+4
+A
+6
+7
+8
+9
+10
+B
+12
+13
+14
+15
+16
+17
+18
+19
+20
+
+commit refs/heads/reordered
+mark :27
+author Thomas Rast <trast@inf.ethz.ch> 1374485036 +0200
+committer Thomas Rast <trast@inf.ethz.ch> 1374485350 +0200
+data 8
+s/11/B/
+from :25
+M 100644 :26 file
+
+blob
+mark :28
+data 49
+1
+2
+3
+4
+A
+6
+7
+8
+9
+10
+B
+B
+13
+14
+15
+16
+17
+18
+19
+20
+
+commit refs/heads/reordered
+mark :29
+author Thomas Rast <trast@inf.ethz.ch> 1374485044 +0200
+committer Thomas Rast <trast@inf.ethz.ch> 1374485350 +0200
+data 8
+s/12/B/
+from :27
+M 100644 :28 file
+
+commit refs/heads/reordered
+mark :30
+author Thomas Rast <trast@inf.ethz.ch> 1374485024 +0200
+committer Thomas Rast <trast@inf.ethz.ch> 1374485350 +0200
+data 7
+s/4/A/
+from :29
+M 100644 :9 file
+
+commit refs/heads/changed
+mark :31
+author Thomas Rast <trast@inf.ethz.ch> 1374485014 +0200
+committer Thomas Rast <trast@inf.ethz.ch> 1374485507 +0200
+data 7
+s/5/A/
+from :2
+M 100644 :3 file
+
+commit refs/heads/changed
+mark :32
+author Thomas Rast <trast@inf.ethz.ch> 1374485024 +0200
+committer Thomas Rast <trast@inf.ethz.ch> 1374485507 +0200
+data 7
+s/4/A/
+from :31
+M 100644 :5 file
+
+blob
+mark :33
+data 51
+1
+2
+3
+A
+A
+6
+7
+8
+9
+10
+BB
+12
+13
+14
+15
+16
+17
+18
+19
+20
+
+commit refs/heads/changed
+mark :34
+author Thomas Rast <trast@inf.ethz.ch> 1374485036 +0200
+committer Thomas Rast <trast@inf.ethz.ch> 1374485507 +0200
+data 8
+s/11/B/
+from :32
+M 100644 :33 file
+
+blob
+mark :35
+data 50
+1
+2
+3
+A
+A
+6
+7
+8
+9
+10
+BB
+B
+13
+14
+15
+16
+17
+18
+19
+20
+
+commit refs/heads/changed
+mark :36
+author Thomas Rast <trast@inf.ethz.ch> 1374485044 +0200
+committer Thomas Rast <trast@inf.ethz.ch> 1374485507 +0200
+data 8
+s/12/B/
+from :34
+M 100644 :35 file
+
+commit refs/heads/changed-message
+mark :37
+author Thomas Rast <trast@inf.ethz.ch> 1374485014 +0200
+committer Thomas Rast <trast@inf.ethz.ch> 1374485530 +0200
+data 7
+s/5/A/
+from :2
+M 100644 :3 file
+
+commit refs/heads/changed-message
+mark :38
+author Thomas Rast <trast@inf.ethz.ch> 1374485024 +0200
+committer Thomas Rast <trast@inf.ethz.ch> 1374485530 +0200
+data 35
+s/4/A/
+
+Also a silly comment here!
+from :37
+M 100644 :5 file
+
+commit refs/heads/changed-message
+mark :39
+author Thomas Rast <trast@inf.ethz.ch> 1374485036 +0200
+committer Thomas Rast <trast@inf.ethz.ch> 1374485536 +0200
+data 8
+s/11/B/
+from :38
+M 100644 :7 file
+
+commit refs/heads/changed-message
+mark :40
+author Thomas Rast <trast@inf.ethz.ch> 1374485044 +0200
+committer Thomas Rast <trast@inf.ethz.ch> 1374485536 +0200
+data 8
+s/12/B/
+from :39
+M 100644 :9 file
+
+commit refs/heads/unmodified
+mark :41
+author Thomas Rast <trast@inf.ethz.ch> 1374485014 +0200
+committer Thomas Rast <trast@inf.ethz.ch> 1374485631 +0200
+data 7
+s/5/A/
+from :2
+M 100644 :3 file
+
+commit refs/heads/unmodified
+mark :42
+author Thomas Rast <trast@inf.ethz.ch> 1374485024 +0200
+committer Thomas Rast <trast@inf.ethz.ch> 1374485631 +0200
+data 7
+s/4/A/
+from :41
+M 100644 :5 file
+
+commit refs/heads/unmodified
+mark :43
+author Thomas Rast <trast@inf.ethz.ch> 1374485036 +0200
+committer Thomas Rast <trast@inf.ethz.ch> 1374485632 +0200
+data 8
+s/11/B/
+from :42
+M 100644 :7 file
+
+commit refs/heads/unmodified
+mark :44
+author Thomas Rast <trast@inf.ethz.ch> 1374485044 +0200
+committer Thomas Rast <trast@inf.ethz.ch> 1374485632 +0200
+data 8
+s/12/B/
+from :43
+M 100644 :9 file
+
+commit refs/heads/removed
+mark :45
+author Thomas Rast <trast@inf.ethz.ch> 1374485014 +0200
+committer Thomas Rast <trast@inf.ethz.ch> 1374486061 +0200
+data 7
+s/5/A/
+from :2
+M 100644 :3 file
+
+commit refs/heads/removed
+mark :46
+author Thomas Rast <trast@inf.ethz.ch> 1374485036 +0200
+committer Thomas Rast <trast@inf.ethz.ch> 1374486061 +0200
+data 8
+s/11/B/
+from :45
+M 100644 :26 file
+
+commit refs/heads/removed
+mark :47
+author Thomas Rast <trast@inf.ethz.ch> 1374485044 +0200
+committer Thomas Rast <trast@inf.ethz.ch> 1374486061 +0200
+data 8
+s/12/B/
+from :46
+M 100644 :28 file
+
+commit refs/heads/added-removed
+mark :48
+author Thomas Rast <trast@inf.ethz.ch> 1374485014 +0200
+committer Thomas Gummerer <t.gummerer@gmail.com> 1556574151 +0100
+data 7
+s/5/A/
+from :2
+M 100644 :3 file
+
+blob
+mark :49
+data 0
+
+commit refs/heads/added-removed
+mark :50
+author Thomas Rast <trast@inf.ethz.ch> 1374485024 +0200
+committer Thomas Gummerer <t.gummerer@gmail.com> 1556574177 +0100
+data 18
+s/4/A/ + new-file
+from :48
+M 100644 :5 file
+M 100644 :49 new-file
+
+commit refs/heads/added-removed
+mark :51
+author Thomas Rast <trast@inf.ethz.ch> 1374485036 +0200
+committer Thomas Gummerer <t.gummerer@gmail.com> 1556574177 +0100
+data 22
+s/11/B/ + remove file
+from :50
+M 100644 :7 file
+D new-file
+
+commit refs/heads/added-removed
+mark :52
+author Thomas Rast <trast@inf.ethz.ch> 1374485044 +0200
+committer Thomas Gummerer <t.gummerer@gmail.com> 1556574177 +0100
+data 8
+s/12/B/
+from :51
+M 100644 :9 file
+
+commit refs/heads/renamed-file
+mark :53
+author Thomas Rast <trast@inf.ethz.ch> 1374485014 +0200
+committer Thomas Gummerer <t.gummerer@gmail.com> 1556574309 +0100
+data 7
+s/5/A/
+from :2
+M 100644 :3 file
+
+commit refs/heads/renamed-file
+mark :54
+author Thomas Rast <trast@inf.ethz.ch> 1374485024 +0200
+committer Thomas Gummerer <t.gummerer@gmail.com> 1556574312 +0100
+data 21
+s/4/A/ + rename file
+from :53
+D file
+M 100644 :5 renamed-file
+
+commit refs/heads/renamed-file
+mark :55
+author Thomas Rast <trast@inf.ethz.ch> 1374485036 +0200
+committer Thomas Gummerer <t.gummerer@gmail.com> 1556574319 +0100
+data 8
+s/11/B/
+from :54
+M 100644 :7 renamed-file
+
+commit refs/heads/renamed-file
+mark :56
+author Thomas Rast <trast@inf.ethz.ch> 1374485044 +0200
+committer Thomas Gummerer <t.gummerer@gmail.com> 1556574319 +0100
+data 8
+s/12/B/
+from :55
+M 100644 :9 renamed-file
+
+commit refs/heads/mode-only-change
+mark :57
+author Thomas Rast <trast@inf.ethz.ch> 1374485024 +0200
+committer Thomas Gummerer <t.gummerer@gmail.com> 1570473767 +0100
+data 24
+s/4/A/ + add other-file
+from :4
+M 100644 :5 file
+M 100644 :49 other-file
+
+commit refs/heads/mode-only-change
+mark :58
+author Thomas Rast <trast@inf.ethz.ch> 1374485036 +0200
+committer Thomas Gummerer <t.gummerer@gmail.com> 1570473768 +0100
+data 33
+s/11/B/ + mode change other-file
+from :57
+M 100644 :7 file
+M 100755 :49 other-file
+
+commit refs/heads/mode-only-change
+mark :59
+author Thomas Rast <trast@inf.ethz.ch> 1374485044 +0200
+committer Thomas Gummerer <t.gummerer@gmail.com> 1570473768 +0100
+data 8
+s/12/B/
+from :58
+M 100644 :9 file
+
diff -pruN 1.2.1+git2.18.0-1/git/t/t3206-range-diff.sh 1.2.3+git2.25.1-1/git/t/t3206-range-diff.sh
--- 1.2.1+git2.18.0-1/git/t/t3206-range-diff.sh	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t3206-range-diff.sh	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,706 @@
+#!/bin/sh
+
+test_description='range-diff tests'
+
+. ./test-lib.sh
+
+# Note that because of the range-diff's heuristics, test_commit does more
+# harm than good.  We need some real history.
+
+test_expect_success 'setup' '
+	git fast-import <"$TEST_DIRECTORY"/t3206/history.export &&
+	test_oid_cache <<-\EOF
+	# topic
+	t1 sha1:4de457d
+	t2 sha1:fccce22
+	t3 sha1:147e64e
+	t4 sha1:a63e992
+	t1 sha256:b89f8b9
+	t2 sha256:5f12aad
+	t3 sha256:ea8b273
+	t4 sha256:14b7336
+
+	# unmodified
+	u1 sha1:35b9b25
+	u2 sha1:de345ab
+	u3 sha1:9af6654
+	u4 sha1:2901f77
+	u1 sha256:e3731be
+	u2 sha256:14fadf8
+	u3 sha256:736c4bc
+	u4 sha256:673e77d
+
+	# reordered
+	r1 sha1:aca177a
+	r2 sha1:14ad629
+	r3 sha1:ee58208
+	r4 sha1:307b27a
+	r1 sha256:f59d3aa
+	r2 sha256:fb261a8
+	r3 sha256:cb2649b
+	r4 sha256:958577e
+
+	# removed (deleted)
+	d1 sha1:7657159
+	d2 sha1:43d84d3
+	d3 sha1:a740396
+	d1 sha256:e312513
+	d2 sha256:eb19258
+	d3 sha256:1ccb3c1
+
+	# added
+	a1 sha1:2716022
+	a2 sha1:b62accd
+	a3 sha1:df46cfa
+	a4 sha1:3e64548
+	a5 sha1:12b4063
+	a1 sha256:d724f4d
+	a2 sha256:1de7762
+	a3 sha256:e159431
+	a4 sha256:b3e483c
+	a5 sha256:90866a7
+
+	# rebased
+	b1 sha1:cc9c443
+	b2 sha1:c5d9641
+	b3 sha1:28cc2b6
+	b4 sha1:5628ab7
+	b5 sha1:a31b12e
+	b1 sha256:a1a8717
+	b2 sha256:20a5862
+	b3 sha256:587172a
+	b4 sha256:2721c5d
+	b5 sha256:7b57864
+
+	# changed
+	c1 sha1:a4b3333
+	c2 sha1:f51d370
+	c3 sha1:0559556
+	c4 sha1:d966c5c
+	c1 sha256:f8c2b9d
+	c2 sha256:3fb6318
+	c3 sha256:168ab68
+	c4 sha256:3526539
+
+	# changed-message
+	m1 sha1:f686024
+	m2 sha1:4ab067d
+	m3 sha1:b9cb956
+	m4 sha1:8add5f1
+	m1 sha256:31e6281
+	m2 sha256:a06bf1b
+	m3 sha256:82dc654
+	m4 sha256:48470c5
+
+	# renamed
+	n1 sha1:f258d75
+	n2 sha1:017b62d
+	n3 sha1:3ce7af6
+	n4 sha1:1e6226b
+	n1 sha256:ad52114
+	n2 sha256:3b54c8f
+	n3 sha256:3b0a644
+	n4 sha256:e461653
+
+	# added and removed
+	s1 sha1:096b1ba
+	s2 sha1:d92e698
+	s3 sha1:9a1db4d
+	s4 sha1:fea3b5c
+	s1 sha256:a7f9134
+	s2 sha256:b4c2580
+	s3 sha256:1d62aa2
+	s4 sha256:48160e8
+
+	# Empty delimiter (included so lines match neatly)
+	__ sha1:-------
+	__ sha256:-------
+	EOF
+'
+
+test_expect_success 'simple A..B A..C (unmodified)' '
+	git range-diff --no-color master..topic master..unmodified \
+		>actual &&
+	cat >expect <<-EOF &&
+	1:  $(test_oid t1) = 1:  $(test_oid u1) s/5/A/
+	2:  $(test_oid t2) = 2:  $(test_oid u2) s/4/A/
+	3:  $(test_oid t3) = 3:  $(test_oid u3) s/11/B/
+	4:  $(test_oid t4) = 4:  $(test_oid u4) s/12/B/
+	EOF
+	test_cmp expect actual
+'
+
+test_expect_success 'simple B...C (unmodified)' '
+	git range-diff --no-color topic...unmodified >actual &&
+	# same "expect" as above
+	test_cmp expect actual
+'
+
+test_expect_success 'simple A B C (unmodified)' '
+	git range-diff --no-color master topic unmodified >actual &&
+	# same "expect" as above
+	test_cmp expect actual
+'
+
+test_expect_success 'trivial reordering' '
+	git range-diff --no-color master topic reordered >actual &&
+	cat >expect <<-EOF &&
+	1:  $(test_oid t1) = 1:  $(test_oid r1) s/5/A/
+	3:  $(test_oid t3) = 2:  $(test_oid r2) s/11/B/
+	4:  $(test_oid t4) = 3:  $(test_oid r3) s/12/B/
+	2:  $(test_oid t2) = 4:  $(test_oid r4) s/4/A/
+	EOF
+	test_cmp expect actual
+'
+
+test_expect_success 'removed a commit' '
+	git range-diff --no-color master topic removed >actual &&
+	cat >expect <<-EOF &&
+	1:  $(test_oid t1) = 1:  $(test_oid d1) s/5/A/
+	2:  $(test_oid t2) < -:  $(test_oid __) s/4/A/
+	3:  $(test_oid t3) = 2:  $(test_oid d2) s/11/B/
+	4:  $(test_oid t4) = 3:  $(test_oid d3) s/12/B/
+	EOF
+	test_cmp expect actual
+'
+
+test_expect_success 'added a commit' '
+	git range-diff --no-color master topic added >actual &&
+	cat >expect <<-EOF &&
+	1:  $(test_oid t1) = 1:  $(test_oid a1) s/5/A/
+	2:  $(test_oid t2) = 2:  $(test_oid a2) s/4/A/
+	-:  $(test_oid __) > 3:  $(test_oid a3) s/6/A/
+	3:  $(test_oid t3) = 4:  $(test_oid a4) s/11/B/
+	4:  $(test_oid t4) = 5:  $(test_oid a5) s/12/B/
+	EOF
+	test_cmp expect actual
+'
+
+test_expect_success 'new base, A B C' '
+	git range-diff --no-color master topic rebased >actual &&
+	cat >expect <<-EOF &&
+	1:  $(test_oid t1) = 1:  $(test_oid b1) s/5/A/
+	2:  $(test_oid t2) = 2:  $(test_oid b2) s/4/A/
+	3:  $(test_oid t3) = 3:  $(test_oid b3) s/11/B/
+	4:  $(test_oid t4) = 4:  $(test_oid b4) s/12/B/
+	EOF
+	test_cmp expect actual
+'
+
+test_expect_success 'new base, B...C' '
+	# this syntax includes the commits from master!
+	git range-diff --no-color topic...rebased >actual &&
+	cat >expect <<-EOF &&
+	-:  $(test_oid __) > 1:  $(test_oid b5) unrelated
+	1:  $(test_oid t1) = 2:  $(test_oid b1) s/5/A/
+	2:  $(test_oid t2) = 3:  $(test_oid b2) s/4/A/
+	3:  $(test_oid t3) = 4:  $(test_oid b3) s/11/B/
+	4:  $(test_oid t4) = 5:  $(test_oid b4) s/12/B/
+	EOF
+	test_cmp expect actual
+'
+
+test_expect_success 'changed commit' '
+	git range-diff --no-color topic...changed >actual &&
+	cat >expect <<-EOF &&
+	1:  $(test_oid t1) = 1:  $(test_oid c1) s/5/A/
+	2:  $(test_oid t2) = 2:  $(test_oid c2) s/4/A/
+	3:  $(test_oid t3) ! 3:  $(test_oid c3) s/11/B/
+	    @@ file: A
+	      9
+	      10
+	     -11
+	    -+B
+	    ++BB
+	      12
+	      13
+	      14
+	4:  $(test_oid t4) ! 4:  $(test_oid c4) s/12/B/
+	    @@ file
+	     @@ file: A
+	      9
+	      10
+	    - B
+	    + BB
+	     -12
+	     +B
+	      13
+	EOF
+	test_cmp expect actual
+'
+
+test_expect_success 'changed commit with --no-patch diff option' '
+	git range-diff --no-color --no-patch topic...changed >actual &&
+	cat >expect <<-EOF &&
+	1:  $(test_oid t1) = 1:  $(test_oid c1) s/5/A/
+	2:  $(test_oid t2) = 2:  $(test_oid c2) s/4/A/
+	3:  $(test_oid t3) ! 3:  $(test_oid c3) s/11/B/
+	4:  $(test_oid t4) ! 4:  $(test_oid c4) s/12/B/
+	EOF
+	test_cmp expect actual
+'
+
+test_expect_success 'changed commit with --stat diff option' '
+	git range-diff --no-color --stat topic...changed >actual &&
+	cat >expect <<-EOF &&
+	1:  $(test_oid t1) = 1:  $(test_oid c1) s/5/A/
+	     a => b | 0
+	     1 file changed, 0 insertions(+), 0 deletions(-)
+	2:  $(test_oid t2) = 2:  $(test_oid c2) s/4/A/
+	     a => b | 0
+	     1 file changed, 0 insertions(+), 0 deletions(-)
+	3:  $(test_oid t3) ! 3:  $(test_oid c3) s/11/B/
+	     a => b | 0
+	     1 file changed, 0 insertions(+), 0 deletions(-)
+	4:  $(test_oid t4) ! 4:  $(test_oid c4) s/12/B/
+	     a => b | 0
+	     1 file changed, 0 insertions(+), 0 deletions(-)
+	EOF
+	test_cmp expect actual
+'
+
+test_expect_success 'changed commit with sm config' '
+	git range-diff --no-color --submodule=log topic...changed >actual &&
+	cat >expect <<-EOF &&
+	1:  $(test_oid t1) = 1:  $(test_oid c1) s/5/A/
+	2:  $(test_oid t2) = 2:  $(test_oid c2) s/4/A/
+	3:  $(test_oid t3) ! 3:  $(test_oid c3) s/11/B/
+	    @@ file: A
+	      9
+	      10
+	     -11
+	    -+B
+	    ++BB
+	      12
+	      13
+	      14
+	4:  $(test_oid t4) ! 4:  $(test_oid c4) s/12/B/
+	    @@ file
+	     @@ file: A
+	      9
+	      10
+	    - B
+	    + BB
+	     -12
+	     +B
+	      13
+	EOF
+	test_cmp expect actual
+'
+
+test_expect_success 'renamed file' '
+	git range-diff --no-color --submodule=log topic...renamed-file >actual &&
+	sed s/Z/\ /g >expect <<-EOF &&
+	1:  $(test_oid t1) = 1:  $(test_oid n1) s/5/A/
+	2:  $(test_oid t2) ! 2:  $(test_oid n2) s/4/A/
+	    @@ Metadata
+	    ZAuthor: Thomas Rast <trast@inf.ethz.ch>
+	    Z
+	    Z ## Commit message ##
+	    -    s/4/A/
+	    +    s/4/A/ + rename file
+	    Z
+	    - ## file ##
+	    + ## file => renamed-file ##
+	    Z@@
+	    Z 1
+	    Z 2
+	3:  $(test_oid t3) ! 3:  $(test_oid n3) s/11/B/
+	    @@ Metadata
+	    Z ## Commit message ##
+	    Z    s/11/B/
+	    Z
+	    - ## file ##
+	    -@@ file: A
+	    + ## renamed-file ##
+	    +@@ renamed-file: A
+	    Z 8
+	    Z 9
+	    Z 10
+	4:  $(test_oid t4) ! 4:  $(test_oid n4) s/12/B/
+	    @@ Metadata
+	    Z ## Commit message ##
+	    Z    s/12/B/
+	    Z
+	    - ## file ##
+	    -@@ file: A
+	    + ## renamed-file ##
+	    +@@ renamed-file: A
+	    Z 9
+	    Z 10
+	    Z B
+	EOF
+	test_cmp expect actual
+'
+
+test_expect_success 'file with mode only change' '
+	git range-diff --no-color --submodule=log topic...mode-only-change >actual &&
+	sed s/Z/\ /g >expect <<-EOF &&
+	1:  fccce22 ! 1:  4d39cb3 s/4/A/
+	    @@ Metadata
+	    ZAuthor: Thomas Rast <trast@inf.ethz.ch>
+	    Z
+	    Z ## Commit message ##
+	    -    s/4/A/
+	    +    s/4/A/ + add other-file
+	    Z
+	    Z ## file ##
+	    Z@@
+	    @@ file
+	    Z A
+	    Z 6
+	    Z 7
+	    +
+	    + ## other-file (new) ##
+	2:  147e64e ! 2:  26c107f s/11/B/
+	    @@ Metadata
+	    ZAuthor: Thomas Rast <trast@inf.ethz.ch>
+	    Z
+	    Z ## Commit message ##
+	    -    s/11/B/
+	    +    s/11/B/ + mode change other-file
+	    Z
+	    Z ## file ##
+	    Z@@ file: A
+	    @@ file: A
+	    Z 12
+	    Z 13
+	    Z 14
+	    +
+	    + ## other-file (mode change 100644 => 100755) ##
+	3:  a63e992 = 3:  4c1e0f5 s/12/B/
+	EOF
+	test_cmp expect actual
+'
+
+test_expect_success 'file added and later removed' '
+	git range-diff --no-color --submodule=log topic...added-removed >actual &&
+	sed s/Z/\ /g >expect <<-EOF &&
+	1:  $(test_oid t1) = 1:  $(test_oid s1) s/5/A/
+	2:  $(test_oid t2) ! 2:  $(test_oid s2) s/4/A/
+	    @@ Metadata
+	    ZAuthor: Thomas Rast <trast@inf.ethz.ch>
+	    Z
+	    Z ## Commit message ##
+	    -    s/4/A/
+	    +    s/4/A/ + new-file
+	    Z
+	    Z ## file ##
+	    Z@@
+	    @@ file
+	    Z A
+	    Z 6
+	    Z 7
+	    +
+	    + ## new-file (new) ##
+	3:  $(test_oid t3) ! 3:  $(test_oid s3) s/11/B/
+	    @@ Metadata
+	    ZAuthor: Thomas Rast <trast@inf.ethz.ch>
+	    Z
+	    Z ## Commit message ##
+	    -    s/11/B/
+	    +    s/11/B/ + remove file
+	    Z
+	    Z ## file ##
+	    Z@@ file: A
+	    @@ file: A
+	    Z 12
+	    Z 13
+	    Z 14
+	    +
+	    + ## new-file (deleted) ##
+	4:  $(test_oid t4) = 4:  $(test_oid s4) s/12/B/
+	EOF
+	test_cmp expect actual
+'
+
+test_expect_success 'no commits on one side' '
+	git commit --amend -m "new message" &&
+	git range-diff master HEAD@{1} HEAD
+'
+
+test_expect_success 'changed message' '
+	git range-diff --no-color topic...changed-message >actual &&
+	sed s/Z/\ /g >expect <<-EOF &&
+	1:  $(test_oid t1) = 1:  $(test_oid m1) s/5/A/
+	2:  $(test_oid t2) ! 2:  $(test_oid m2) s/4/A/
+	    @@ Metadata
+	    Z ## Commit message ##
+	    Z    s/4/A/
+	    Z
+	    +    Also a silly comment here!
+	    +
+	    Z ## file ##
+	    Z@@
+	    Z 1
+	3:  $(test_oid t3) = 3:  $(test_oid m3) s/11/B/
+	4:  $(test_oid t4) = 4:  $(test_oid m4) s/12/B/
+	EOF
+	test_cmp expect actual
+'
+
+test_expect_success 'dual-coloring' '
+	sed -e "s|^:||" >expect <<-EOF &&
+	:<YELLOW>1:  $(test_oid c1) = 1:  $(test_oid m1) s/5/A/<RESET>
+	:<RED>2:  $(test_oid c2) <RESET><YELLOW>!<RESET><GREEN> 2:  $(test_oid m2)<RESET><YELLOW> s/4/A/<RESET>
+	:    <REVERSE><CYAN>@@<RESET> <RESET>Metadata<RESET>
+	:      ## Commit message ##<RESET>
+	:         s/4/A/<RESET>
+	:     <RESET>
+	:    <REVERSE><GREEN>+<RESET><BOLD>    Also a silly comment here!<RESET>
+	:    <REVERSE><GREEN>+<RESET>
+	:      ## file ##<RESET>
+	:    <CYAN> @@<RESET>
+	:      1<RESET>
+	:<RED>3:  $(test_oid c3) <RESET><YELLOW>!<RESET><GREEN> 3:  $(test_oid m3)<RESET><YELLOW> s/11/B/<RESET>
+	:    <REVERSE><CYAN>@@<RESET> <RESET>file: A<RESET>
+	:      9<RESET>
+	:      10<RESET>
+	:    <RED> -11<RESET>
+	:    <REVERSE><RED>-<RESET><FAINT;GREEN>+BB<RESET>
+	:    <REVERSE><GREEN>+<RESET><BOLD;GREEN>+B<RESET>
+	:      12<RESET>
+	:      13<RESET>
+	:      14<RESET>
+	:<RED>4:  $(test_oid c4) <RESET><YELLOW>!<RESET><GREEN> 4:  $(test_oid m4)<RESET><YELLOW> s/12/B/<RESET>
+	:    <REVERSE><CYAN>@@<RESET> <RESET>file<RESET>
+	:    <CYAN> @@ file: A<RESET>
+	:      9<RESET>
+	:      10<RESET>
+	:    <REVERSE><RED>-<RESET><FAINT> BB<RESET>
+	:    <REVERSE><GREEN>+<RESET><BOLD> B<RESET>
+	:    <RED> -12<RESET>
+	:    <GREEN> +B<RESET>
+	:      13<RESET>
+	EOF
+	git range-diff changed...changed-message --color --dual-color >actual.raw &&
+	test_decode_color >actual <actual.raw &&
+	test_cmp expect actual
+'
+
+for prev in topic master..topic
+do
+	test_expect_success "format-patch --range-diff=$prev" '
+		git format-patch --cover-letter --range-diff=$prev \
+			master..unmodified >actual &&
+		test_when_finished "rm 000?-*" &&
+		test_line_count = 5 actual &&
+		test_i18ngrep "^Range-diff:$" 0000-* &&
+		grep "= 1: .* s/5/A" 0000-* &&
+		grep "= 2: .* s/4/A" 0000-* &&
+		grep "= 3: .* s/11/B" 0000-* &&
+		grep "= 4: .* s/12/B" 0000-*
+	'
+done
+
+test_expect_success 'format-patch --range-diff as commentary' '
+	git format-patch --range-diff=HEAD~1 HEAD~1 >actual &&
+	test_when_finished "rm 0001-*" &&
+	test_line_count = 1 actual &&
+	test_i18ngrep "^Range-diff:$" 0001-* &&
+	grep "> 1: .* new message" 0001-*
+'
+
+test_expect_success 'range-diff overrides diff.noprefix internally' '
+	git -c diff.noprefix=true range-diff HEAD^...
+'
+
+test_expect_success 'range-diff compares notes by default' '
+	git notes add -m "topic note" topic &&
+	git notes add -m "unmodified note" unmodified &&
+	test_when_finished git notes remove topic unmodified &&
+	git range-diff --no-color master..topic master..unmodified \
+		>actual &&
+	sed s/Z/\ /g >expect <<-EOF &&
+	1:  $(test_oid t1) = 1:  $(test_oid u1) s/5/A/
+	2:  $(test_oid t2) = 2:  $(test_oid u2) s/4/A/
+	3:  $(test_oid t3) = 3:  $(test_oid u3) s/11/B/
+	4:  $(test_oid t4) ! 4:  $(test_oid u4) s/12/B/
+	    @@ Commit message
+	    Z
+	    Z
+	    Z ## Notes ##
+	    -    topic note
+	    +    unmodified note
+	    Z
+	    Z ## file ##
+	    Z@@ file: A
+	EOF
+	test_cmp expect actual
+'
+
+test_expect_success 'range-diff with --no-notes' '
+	git notes add -m "topic note" topic &&
+	git notes add -m "unmodified note" unmodified &&
+	test_when_finished git notes remove topic unmodified &&
+	git range-diff --no-color --no-notes master..topic master..unmodified \
+		>actual &&
+	cat >expect <<-EOF &&
+	1:  $(test_oid t1) = 1:  $(test_oid u1) s/5/A/
+	2:  $(test_oid t2) = 2:  $(test_oid u2) s/4/A/
+	3:  $(test_oid t3) = 3:  $(test_oid u3) s/11/B/
+	4:  $(test_oid t4) = 4:  $(test_oid u4) s/12/B/
+	EOF
+	test_cmp expect actual
+'
+
+test_expect_success 'range-diff with multiple --notes' '
+	git notes --ref=note1 add -m "topic note1" topic &&
+	git notes --ref=note1 add -m "unmodified note1" unmodified &&
+	test_when_finished git notes --ref=note1 remove topic unmodified &&
+	git notes --ref=note2 add -m "topic note2" topic &&
+	git notes --ref=note2 add -m "unmodified note2" unmodified &&
+	test_when_finished git notes --ref=note2 remove topic unmodified &&
+	git range-diff --no-color --notes=note1 --notes=note2 master..topic master..unmodified \
+		>actual &&
+	sed s/Z/\ /g >expect <<-EOF &&
+	1:  $(test_oid t1) = 1:  $(test_oid u1) s/5/A/
+	2:  $(test_oid t2) = 2:  $(test_oid u2) s/4/A/
+	3:  $(test_oid t3) = 3:  $(test_oid u3) s/11/B/
+	4:  $(test_oid t4) ! 4:  $(test_oid u4) s/12/B/
+	    @@ Commit message
+	    Z
+	    Z
+	    Z ## Notes (note1) ##
+	    -    topic note1
+	    +    unmodified note1
+	    Z
+	    Z
+	    Z ## Notes (note2) ##
+	    -    topic note2
+	    +    unmodified note2
+	    Z
+	    Z ## file ##
+	    Z@@ file: A
+	EOF
+	test_cmp expect actual
+'
+
+test_expect_success 'format-patch --range-diff does not compare notes by default' '
+	git notes add -m "topic note" topic &&
+	git notes add -m "unmodified note" unmodified &&
+	test_when_finished git notes remove topic unmodified &&
+	git format-patch --cover-letter --range-diff=$prev \
+		master..unmodified >actual &&
+	test_when_finished "rm 000?-*" &&
+	test_line_count = 5 actual &&
+	test_i18ngrep "^Range-diff:$" 0000-* &&
+	grep "= 1: .* s/5/A" 0000-* &&
+	grep "= 2: .* s/4/A" 0000-* &&
+	grep "= 3: .* s/11/B" 0000-* &&
+	grep "= 4: .* s/12/B" 0000-* &&
+	! grep "Notes" 0000-* &&
+	! grep "note" 0000-*
+'
+
+test_expect_success 'format-patch --range-diff with --no-notes' '
+	git notes add -m "topic note" topic &&
+	git notes add -m "unmodified note" unmodified &&
+	test_when_finished git notes remove topic unmodified &&
+	git format-patch --no-notes --cover-letter --range-diff=$prev \
+		master..unmodified >actual &&
+	test_when_finished "rm 000?-*" &&
+	test_line_count = 5 actual &&
+	test_i18ngrep "^Range-diff:$" 0000-* &&
+	grep "= 1: .* s/5/A" 0000-* &&
+	grep "= 2: .* s/4/A" 0000-* &&
+	grep "= 3: .* s/11/B" 0000-* &&
+	grep "= 4: .* s/12/B" 0000-* &&
+	! grep "Notes" 0000-* &&
+	! grep "note" 0000-*
+'
+
+test_expect_success 'format-patch --range-diff with --notes' '
+	git notes add -m "topic note" topic &&
+	git notes add -m "unmodified note" unmodified &&
+	test_when_finished git notes remove topic unmodified &&
+	git format-patch --notes --cover-letter --range-diff=$prev \
+		master..unmodified >actual &&
+	test_when_finished "rm 000?-*" &&
+	test_line_count = 5 actual &&
+	test_i18ngrep "^Range-diff:$" 0000-* &&
+	grep "= 1: .* s/5/A" 0000-* &&
+	grep "= 2: .* s/4/A" 0000-* &&
+	grep "= 3: .* s/11/B" 0000-* &&
+	grep "! 4: .* s/12/B" 0000-* &&
+	sed s/Z/\ /g >expect <<-EOF &&
+	    @@ Commit message
+	    Z
+	    Z
+	    Z ## Notes ##
+	    -    topic note
+	    +    unmodified note
+	    Z
+	    Z ## file ##
+	    Z@@ file: A
+	EOF
+	sed "/@@ Commit message/,/@@ file: A/!d" 0000-* >actual &&
+	test_cmp expect actual
+'
+
+test_expect_success 'format-patch --range-diff with format.notes config' '
+	git notes add -m "topic note" topic &&
+	git notes add -m "unmodified note" unmodified &&
+	test_when_finished git notes remove topic unmodified &&
+	test_config format.notes true &&
+	git format-patch --cover-letter --range-diff=$prev \
+		master..unmodified >actual &&
+	test_when_finished "rm 000?-*" &&
+	test_line_count = 5 actual &&
+	test_i18ngrep "^Range-diff:$" 0000-* &&
+	grep "= 1: .* s/5/A" 0000-* &&
+	grep "= 2: .* s/4/A" 0000-* &&
+	grep "= 3: .* s/11/B" 0000-* &&
+	grep "! 4: .* s/12/B" 0000-* &&
+	sed s/Z/\ /g >expect <<-EOF &&
+	    @@ Commit message
+	    Z
+	    Z
+	    Z ## Notes ##
+	    -    topic note
+	    +    unmodified note
+	    Z
+	    Z ## file ##
+	    Z@@ file: A
+	EOF
+	sed "/@@ Commit message/,/@@ file: A/!d" 0000-* >actual &&
+	test_cmp expect actual
+'
+
+test_expect_success 'format-patch --range-diff with multiple notes' '
+	git notes --ref=note1 add -m "topic note1" topic &&
+	git notes --ref=note1 add -m "unmodified note1" unmodified &&
+	test_when_finished git notes --ref=note1 remove topic unmodified &&
+	git notes --ref=note2 add -m "topic note2" topic &&
+	git notes --ref=note2 add -m "unmodified note2" unmodified &&
+	test_when_finished git notes --ref=note2 remove topic unmodified &&
+	git format-patch --notes=note1 --notes=note2 --cover-letter --range-diff=$prev \
+		master..unmodified >actual &&
+	test_when_finished "rm 000?-*" &&
+	test_line_count = 5 actual &&
+	test_i18ngrep "^Range-diff:$" 0000-* &&
+	grep "= 1: .* s/5/A" 0000-* &&
+	grep "= 2: .* s/4/A" 0000-* &&
+	grep "= 3: .* s/11/B" 0000-* &&
+	grep "! 4: .* s/12/B" 0000-* &&
+	sed s/Z/\ /g >expect <<-EOF &&
+	    @@ Commit message
+	    Z
+	    Z
+	    Z ## Notes (note1) ##
+	    -    topic note1
+	    +    unmodified note1
+	    Z
+	    Z
+	    Z ## Notes (note2) ##
+	    -    topic note2
+	    +    unmodified note2
+	    Z
+	    Z ## file ##
+	    Z@@ file: A
+	EOF
+	sed "/@@ Commit message/,/@@ file: A/!d" 0000-* >actual &&
+	test_cmp expect actual
+'
+
+test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t3210-pack-refs.sh 1.2.3+git2.25.1-1/git/t/t3210-pack-refs.sh
--- 1.2.1+git2.18.0-1/git/t/t3210-pack-refs.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t3210-pack-refs.sh	2020-02-17 04:47:35.000000000 +0000
@@ -127,7 +127,7 @@ test_expect_success 'explicit pack-refs
 	git reflog expire --expire=all --all &&
 	git prune --expire=all &&
 	git pack-refs --all 2>result &&
-	test_cmp /dev/null result
+	test_must_be_empty result
 '
 
 test_expect_success 'delete ref with dangling packed version' '
@@ -139,7 +139,7 @@ test_expect_success 'delete ref with dan
 	git reflog expire --expire=all --all &&
 	git prune --expire=all &&
 	git branch -d lamb 2>result &&
-	test_cmp /dev/null result
+	test_must_be_empty result
 '
 
 test_expect_success 'delete ref while another dangling packed ref' '
@@ -150,7 +150,7 @@ test_expect_success 'delete ref while an
 	git reflog expire --expire=all --all &&
 	git prune --expire=all &&
 	git branch -d lamb 2>result &&
-	test_cmp /dev/null result
+	test_must_be_empty result
 '
 
 test_expect_success 'pack ref directly below refs/' '
@@ -186,7 +186,7 @@ test_expect_success 'notice d/f conflict
 
 test_expect_success 'existing directory reports concrete ref' '
 	test_must_fail git branch foo 2>stderr &&
-	grep refs/heads/foo/bar/baz stderr
+	test_i18ngrep refs/heads/foo/bar/baz stderr
 '
 
 test_expect_success 'notice d/f conflict with existing ref' '
@@ -231,16 +231,16 @@ test_expect_success 'timeout if packed-r
 test_expect_success 'retry acquiring packed-refs.lock' '
 	LOCK=.git/packed-refs.lock &&
 	>"$LOCK" &&
-	test_when_finished "wait; rm -f $LOCK" &&
+	test_when_finished "wait && rm -f $LOCK" &&
 	{
-		( sleep 1 ; rm -f $LOCK ) &
+		( sleep 1 && rm -f $LOCK ) &
 	} &&
 	git -c core.packedrefstimeout=3000 pack-refs --all --prune
 '
 
 test_expect_success SYMLINKS 'pack symlinked packed-refs' '
 	# First make sure that symlinking works when reading:
-	git update-ref refs/heads/loosy refs/heads/master &&
+	git update-ref refs/heads/lossy refs/heads/master &&
 	git for-each-ref >all-refs-before &&
 	mv .git/packed-refs .git/my-deviant-packed-refs &&
 	ln -s my-deviant-packed-refs .git/packed-refs &&
diff -pruN 1.2.1+git2.18.0-1/git/t/t3301-notes.sh 1.2.3+git2.25.1-1/git/t/t3301-notes.sh
--- 1.2.1+git2.18.0-1/git/t/t3301-notes.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t3301-notes.sh	2020-02-17 04:47:35.000000000 +0000
@@ -54,7 +54,9 @@ test_expect_success 'create notes' '
 	test_path_is_missing .git/NOTES_EDITMSG &&
 	git ls-tree -r refs/notes/commits >actual &&
 	test_line_count = 1 actual &&
-	test "b4" = "$(git notes show)" &&
+	echo b4 >expect &&
+	git notes show >actual &&
+	test_cmp expect actual &&
 	git show HEAD^ &&
 	test_must_fail git notes show HEAD^
 '
@@ -66,8 +68,9 @@ test_expect_success 'show notes entry wi
 '
 
 test_expect_success 'create reflog entry' '
+	ref=$(git rev-parse --short refs/notes/commits) &&
 	cat <<-EOF >expect &&
-		a1d8fa6 refs/notes/commits@{0}: notes: Notes added by '\''git notes add'\''
+		$ref refs/notes/commits@{0}: notes: Notes added by '\''git notes add'\''
 	EOF
 	git reflog show refs/notes/commits >actual &&
 	test_cmp expect actual
@@ -78,14 +81,21 @@ test_expect_success 'edit existing notes
 	test_path_is_missing .git/NOTES_EDITMSG &&
 	git ls-tree -r refs/notes/commits >actual &&
 	test_line_count = 1 actual &&
-	test "b3" = "$(git notes show)" &&
+	echo b3 >expect &&
+	git notes show >actual &&
+	test_cmp expect actual &&
 	git show HEAD^ &&
 	test_must_fail git notes show HEAD^
 '
 
 test_expect_success 'show notes from treeish' '
-	test "b3" = "$(git notes --ref commits^{tree} show)" &&
-	test "b4" = "$(git notes --ref commits@{1} show)"
+	echo b3 >expect &&
+	git notes --ref commits^{tree} show >actual &&
+	test_cmp expect actual &&
+
+	echo b4 >expect &&
+	git notes --ref commits@{1} show >actual &&
+	test_cmp expect actual
 '
 
 test_expect_success 'cannot edit notes from non-ref' '
@@ -98,7 +108,9 @@ test_expect_success 'cannot "git notes a
 	test_path_is_missing .git/NOTES_EDITMSG &&
 	git ls-tree -r refs/notes/commits >actual &&
 	test_line_count = 1 actual &&
-	test "b3" = "$(git notes show)" &&
+	echo b3 >expect &&
+	git notes show >actual &&
+	test_cmp expect actual &&
 	git show HEAD^ &&
 	test_must_fail git notes show HEAD^
 '
@@ -108,7 +120,9 @@ test_expect_success 'can overwrite exist
 	test_path_is_missing .git/NOTES_EDITMSG &&
 	git ls-tree -r refs/notes/commits >actual &&
 	test_line_count = 1 actual &&
-	test "b1" = "$(git notes show)" &&
+	echo b1 >expect &&
+	git notes show >actual &&
+	test_cmp expect actual &&
 	git show HEAD^ &&
 	test_must_fail git notes show HEAD^
 '
@@ -118,7 +132,9 @@ test_expect_success 'add w/no options on
 	test_path_is_missing .git/NOTES_EDITMSG &&
 	git ls-tree -r refs/notes/commits >actual &&
 	test_line_count = 1 actual &&
-	test "b2" = "$(git notes show)" &&
+	echo b2 >expect &&
+	git notes show >actual &&
+	test_cmp expect actual &&
 	git show HEAD^ &&
 	test_must_fail git notes show HEAD^
 '
@@ -128,14 +144,17 @@ test_expect_success 'can overwrite exist
 	test_path_is_missing .git/NOTES_EDITMSG &&
 	git ls-tree -r refs/notes/commits >actual &&
 	test_line_count = 1 actual &&
-	test "b1" = "$(git notes show)" &&
+	echo b1 >expect &&
+	git notes show >actual &&
+	test_cmp expect actual &&
 	git show HEAD^ &&
 	test_must_fail git notes show HEAD^
 '
 
 test_expect_success 'show notes' '
+	commit=$(git rev-parse HEAD) &&
 	cat >expect <<-EOF &&
-		commit 7a4ca6ee52a974a66cbaa78e33214535dff1d691
+		commit $commit
 		Author: A U Thor <author@example.com>
 		Date:   Thu Apr 7 15:14:13 2005 -0700
 
@@ -144,7 +163,8 @@ test_expect_success 'show notes' '
 		Notes:
 		${indent}b1
 	EOF
-	! (git cat-file commit HEAD | grep b1) &&
+	git cat-file commit HEAD >commits &&
+	! grep b1 commits &&
 	git log -1 >actual &&
 	test_cmp expect actual
 '
@@ -152,8 +172,9 @@ test_expect_success 'show notes' '
 test_expect_success 'show multi-line notes' '
 	test_commit 3rd &&
 	MSG="b3${LF}c3c3c3c3${LF}d3d3d3" git notes add &&
+	commit=$(git rev-parse HEAD) &&
 	cat >expect-multiline <<-EOF &&
-		commit d07d62e5208f22eb5695e7eb47667dc8b9860290
+		commit $commit
 		Author: A U Thor <author@example.com>
 		Date:   Thu Apr 7 15:15:13 2005 -0700
 
@@ -174,8 +195,9 @@ test_expect_success 'show -F notes' '
 	test_commit 4th &&
 	echo "xyzzy" >note5 &&
 	git notes add -F note5 &&
+	commit=$(git rev-parse HEAD) &&
 	cat >expect-F <<-EOF &&
-		commit 0f7aa3ec6325aeb88b910453bb3eb37c49d75c11
+		commit $commit
 		Author: A U Thor <author@example.com>
 		Date:   Thu Apr 7 15:16:13 2005 -0700
 
@@ -198,10 +220,13 @@ test_expect_success 'Re-adding -F notes
 '
 
 test_expect_success 'git log --pretty=raw does not show notes' '
-	cat >expect <<-EOF &&
-		commit 0f7aa3ec6325aeb88b910453bb3eb37c49d75c11
-		tree 05ac65288c4c4b3b709a020ae94b2ece2f2201ae
-		parent d07d62e5208f22eb5695e7eb47667dc8b9860290
+	commit=$(git rev-parse HEAD) &&
+	tree=$(git rev-parse HEAD^{tree}) &&
+	parent=$(git rev-parse HEAD^) &&
+	cat >expect <<-EOF &&
+		commit $commit
+		tree $tree
+		parent $parent
 		author A U Thor <author@example.com> 1112912173 -0700
 		committer C O Mitter <committer@example.com> 1112912173 -0700
 
@@ -291,8 +316,9 @@ test_expect_success 'git log --no-notes
 test_expect_success 'show -m notes' '
 	test_commit 5th &&
 	git notes add -m spam -m "foo${LF}bar${LF}baz" &&
+	commit=$(git rev-parse HEAD) &&
 	cat >expect-m <<-EOF &&
-		commit 7f9ad8836c775acb134c0a055fc55fb4cd1ba361
+		commit $commit
 		Author: A U Thor <author@example.com>
 		Date:   Thu Apr 7 15:17:13 2005 -0700
 
@@ -313,8 +339,9 @@ test_expect_success 'show -m notes' '
 
 test_expect_success 'remove note with add -f -F /dev/null' '
 	git notes add -f -F /dev/null &&
+	commit=$(git rev-parse HEAD) &&
 	cat >expect-rm-F <<-EOF &&
-		commit 7f9ad8836c775acb134c0a055fc55fb4cd1ba361
+		commit $commit
 		Author: A U Thor <author@example.com>
 		Date:   Thu Apr 7 15:17:13 2005 -0700
 
@@ -356,14 +383,16 @@ test_expect_success 'create note with co
 test_expect_success 'remove note with "git notes remove"' '
 	git notes remove HEAD^ &&
 	git notes remove &&
+	commit=$(git rev-parse HEAD) &&
+	parent=$(git rev-parse HEAD^) &&
 	cat >expect-rm-remove <<-EOF &&
-		commit 7f9ad8836c775acb134c0a055fc55fb4cd1ba361
+		commit $commit
 		Author: A U Thor <author@example.com>
 		Date:   Thu Apr 7 15:17:13 2005 -0700
 
 		${indent}5th
 
-		commit 0f7aa3ec6325aeb88b910453bb3eb37c49d75c11
+		commit $parent
 		Author: A U Thor <author@example.com>
 		Date:   Thu Apr 7 15:16:13 2005 -0700
 
@@ -459,9 +488,13 @@ test_expect_success 'removing with --std
 '
 
 test_expect_success 'list notes with "git notes list"' '
-	cat >expect <<-EOF &&
-		c9c6af7f78bc47490dbf3e822cf2f3c24d4b9061 7a4ca6ee52a974a66cbaa78e33214535dff1d691
-		c18dc024e14f08d18d14eea0d747ff692d66d6a3 d07d62e5208f22eb5695e7eb47667dc8b9860290
+	commit_2=$(git rev-parse 2nd) &&
+	commit_3=$(git rev-parse 3rd) &&
+	note_2=$(git rev-parse refs/notes/commits:$commit_2) &&
+	note_3=$(git rev-parse refs/notes/commits:$commit_3) &&
+	sort -t" " -k2 >expect <<-EOF &&
+		$note_2 $commit_2
+		$note_3 $commit_3
 	EOF
 	git notes list >actual &&
 	test_cmp expect actual
@@ -473,18 +506,14 @@ test_expect_success 'list notes with "gi
 '
 
 test_expect_success 'list specific note with "git notes list <object>"' '
-	cat >expect <<-EOF &&
-		c18dc024e14f08d18d14eea0d747ff692d66d6a3
-	EOF
+	git rev-parse refs/notes/commits:$commit_3 >expect &&
 	git notes list HEAD^^ >actual &&
 	test_cmp expect actual
 '
 
 test_expect_success 'listing non-existing notes fails' '
-	cat >expect <<-EOF &&
-	EOF
 	test_must_fail git notes list HEAD >actual &&
-	test_cmp expect actual
+	test_must_be_empty actual
 '
 
 test_expect_success 'append to existing note with "git notes append"' '
@@ -500,10 +529,12 @@ test_expect_success 'append to existing
 '
 
 test_expect_success '"git notes list" does not expand to "git notes list HEAD"' '
-	cat >expect_list <<-EOF &&
-		c9c6af7f78bc47490dbf3e822cf2f3c24d4b9061 7a4ca6ee52a974a66cbaa78e33214535dff1d691
-		4b6ad22357cc8a1296720574b8d2fbc22fab0671 7f9ad8836c775acb134c0a055fc55fb4cd1ba361
-		c18dc024e14f08d18d14eea0d747ff692d66d6a3 d07d62e5208f22eb5695e7eb47667dc8b9860290
+	commit_5=$(git rev-parse 5th) &&
+	note_5=$(git rev-parse refs/notes/commits:$commit_5) &&
+	sort -t" " -k2 >expect_list <<-EOF &&
+		$note_2 $commit_2
+		$note_3 $commit_3
+		$note_5 $commit_5
 	EOF
 	git notes list >actual &&
 	test_cmp expect_list actual
@@ -533,8 +564,9 @@ test_expect_success 'appending empty str
 test_expect_success 'create other note on a different notes ref (setup)' '
 	test_commit 6th &&
 	GIT_NOTES_REF="refs/notes/other" git notes add -m "other note" &&
+	commit=$(git rev-parse HEAD) &&
 	cat >expect-not-other <<-EOF &&
-		commit 2c125331118caba0ff8238b7f4958ac6e93fe39c
+		commit $commit
 		Author: A U Thor <author@example.com>
 		Date:   Thu Apr 7 15:18:13 2005 -0700
 
@@ -571,8 +603,10 @@ test_expect_success 'Do not show note wh
 '
 
 test_expect_success 'Show all notes when notes.displayRef=refs/notes/*' '
+	commit=$(git rev-parse HEAD) &&
+	parent=$(git rev-parse HEAD^) &&
 	cat >expect-both <<-EOF &&
-		commit 2c125331118caba0ff8238b7f4958ac6e93fe39c
+		commit $commit
 		Author: A U Thor <author@example.com>
 		Date:   Thu Apr 7 15:18:13 2005 -0700
 
@@ -584,7 +618,7 @@ test_expect_success 'Show all notes when
 		Notes (other):
 		${indent}other note
 
-		commit 7f9ad8836c775acb134c0a055fc55fb4cd1ba361
+		commit $parent
 		Author: A U Thor <author@example.com>
 		Date:   Thu Apr 7 15:17:13 2005 -0700
 
@@ -618,8 +652,9 @@ test_expect_success 'notes.displayRef ca
 '
 
 test_expect_success 'notes.displayRef respects order' '
+	commit=$(git rev-parse HEAD) &&
 	cat >expect-both-reversed <<-EOF &&
-		commit 2c125331118caba0ff8238b7f4958ac6e93fe39c
+		commit $commit
 		Author: A U Thor <author@example.com>
 		Date:   Thu Apr 7 15:18:13 2005 -0700
 
@@ -644,14 +679,16 @@ test_expect_success 'GIT_NOTES_DISPLAY_R
 '
 
 test_expect_success 'GIT_NOTES_DISPLAY_REF overrides config' '
+	commit=$(git rev-parse HEAD) &&
+	parent=$(git rev-parse HEAD^) &&
 	cat >expect-none <<-EOF &&
-		commit 2c125331118caba0ff8238b7f4958ac6e93fe39c
+		commit $commit
 		Author: A U Thor <author@example.com>
 		Date:   Thu Apr 7 15:18:13 2005 -0700
 
 		${indent}6th
 
-		commit 7f9ad8836c775acb134c0a055fc55fb4cd1ba361
+		commit $parent
 		Author: A U Thor <author@example.com>
 		Date:   Thu Apr 7 15:17:13 2005 -0700
 
@@ -668,8 +705,9 @@ test_expect_success '--show-notes=* adds
 '
 
 test_expect_success '--no-standard-notes' '
+	commit=$(git rev-parse HEAD) &&
 	cat >expect-commits <<-EOF &&
-		commit 2c125331118caba0ff8238b7f4958ac6e93fe39c
+		commit $commit
 		Author: A U Thor <author@example.com>
 		Date:   Thu Apr 7 15:18:13 2005 -0700
 
@@ -702,7 +740,8 @@ test_expect_success 'Allow notes on non-
 	git notes show HEAD: >actual &&
 	test_cmp expect actual &&
 	echo "Note on a blob" >expect &&
-	filename=$(git ls-tree --name-only HEAD | head -n1) &&
+	git ls-tree --name-only HEAD >files &&
+	filename=$(head -n1 files) &&
 	git notes add -m "Note on a blob" HEAD:$filename &&
 	git notes show HEAD:$filename >actual &&
 	test_cmp expect actual &&
@@ -714,8 +753,10 @@ test_expect_success 'Allow notes on non-
 '
 
 test_expect_success 'create note from other note with "git notes add -C"' '
+	test_commit 7th &&
+	commit=$(git rev-parse HEAD) &&
 	cat >expect <<-EOF &&
-		commit fb01e0ca8c33b6cc0c6451dde747f97df567cb5c
+		commit $commit
 		Author: A U Thor <author@example.com>
 		Date:   Thu Apr 7 15:19:13 2005 -0700
 
@@ -724,11 +765,13 @@ test_expect_success 'create note from ot
 		Notes:
 		${indent}order test
 	EOF
-	test_commit 7th &&
-	git notes add -C $(git notes list HEAD^) &&
+	note=$(git notes list HEAD^) &&
+	git notes add -C $note &&
 	git log -1 >actual &&
 	test_cmp expect actual &&
-	test "$(git notes list HEAD)" = "$(git notes list HEAD^)"
+	git notes list HEAD^ >expect &&
+	git notes list HEAD >actual &&
+	test_cmp expect actual
 '
 
 test_expect_success 'create note from non-existing note with "git notes add -C" fails' '
@@ -746,8 +789,9 @@ test_expect_success 'create note from no
 '
 
 test_expect_success 'create note from blob with "git notes add -C" reuses blob id' '
+	commit=$(git rev-parse HEAD) &&
 	cat >expect <<-EOF &&
-		commit 9a4c31c7f722b5d517e92c64e932dd751e1413bf
+		commit $commit
 		Author: A U Thor <author@example.com>
 		Date:   Thu Apr 7 15:20:13 2005 -0700
 
@@ -756,16 +800,19 @@ test_expect_success 'create note from bl
 		Notes:
 		${indent}This is a blob object
 	EOF
-	blob=$(echo "This is a blob object" | git hash-object -w --stdin) &&
-	git notes add -C $blob &&
+	echo "This is a blob object" | git hash-object -w --stdin >blob &&
+	git notes add -C $(cat blob) &&
 	git log -1 >actual &&
 	test_cmp expect actual &&
-	test "$(git notes list HEAD)" = "$blob"
+	git notes list HEAD >actual &&
+	test_cmp blob actual
 '
 
 test_expect_success 'create note from other note with "git notes add -c"' '
+	test_commit 9th &&
+	commit=$(git rev-parse HEAD) &&
 	cat >expect <<-EOF &&
-		commit 2e0db4bc649e174d667a1cde19e725cf897a5bd2
+		commit $commit
 		Author: A U Thor <author@example.com>
 		Date:   Thu Apr 7 15:21:13 2005 -0700
 
@@ -774,8 +821,8 @@ test_expect_success 'create note from ot
 		Notes:
 		${indent}yet another note
 	EOF
-	test_commit 9th &&
-	MSG="yet another note" git notes add -c $(git notes list HEAD^^) &&
+	note=$(git notes list HEAD^^) &&
+	MSG="yet another note" git notes add -c $note &&
 	git log -1 >actual &&
 	test_cmp expect actual
 '
@@ -787,8 +834,9 @@ test_expect_success 'create note from no
 '
 
 test_expect_success 'append to note from other note with "git notes append -C"' '
+	commit=$(git rev-parse HEAD^) &&
 	cat >expect <<-EOF &&
-		commit 2e0db4bc649e174d667a1cde19e725cf897a5bd2
+		commit $commit
 		Author: A U Thor <author@example.com>
 		Date:   Thu Apr 7 15:21:13 2005 -0700
 
@@ -799,14 +847,16 @@ test_expect_success 'append to note from
 		${indent}
 		${indent}yet another note
 	EOF
-	git notes append -C $(git notes list HEAD^) HEAD^ &&
+	note=$(git notes list HEAD^) &&
+	git notes append -C $note HEAD^ &&
 	git log -1 HEAD^ >actual &&
 	test_cmp expect actual
 '
 
 test_expect_success 'create note from other note with "git notes append -c"' '
+	commit=$(git rev-parse HEAD) &&
 	cat >expect <<-EOF &&
-		commit 7c3b87ab368f81e11b1ea87b2ab99a71ccd25406
+		commit $commit
 		Author: A U Thor <author@example.com>
 		Date:   Thu Apr 7 15:22:13 2005 -0700
 
@@ -815,14 +865,16 @@ test_expect_success 'create note from ot
 		Notes:
 		${indent}other note
 	EOF
-	MSG="other note" git notes append -c $(git notes list HEAD^) &&
+	note=$(git notes list HEAD^) &&
+	MSG="other note" git notes append -c $note &&
 	git log -1 >actual &&
 	test_cmp expect actual
 '
 
 test_expect_success 'append to note from other note with "git notes append -c"' '
+	commit=$(git rev-parse HEAD) &&
 	cat >expect <<-EOF &&
-		commit 7c3b87ab368f81e11b1ea87b2ab99a71ccd25406
+		commit $commit
 		Author: A U Thor <author@example.com>
 		Date:   Thu Apr 7 15:22:13 2005 -0700
 
@@ -833,14 +885,37 @@ test_expect_success 'append to note from
 		${indent}
 		${indent}yet another note
 	EOF
-	MSG="yet another note" git notes append -c $(git notes list HEAD) &&
+	note=$(git notes list HEAD) &&
+	MSG="yet another note" git notes append -c $note &&
 	git log -1 >actual &&
 	test_cmp expect actual
 '
 
 test_expect_success 'copy note with "git notes copy"' '
+	commit=$(git rev-parse 4th) &&
+	cat >expect <<-EOF &&
+		commit $commit
+		Author: A U Thor <author@example.com>
+		Date:   Thu Apr 7 15:16:13 2005 -0700
+
+		${indent}4th
+
+		Notes:
+		${indent}This is a blob object
+	EOF
+	git notes copy 8th 4th &&
+	git log 3rd..4th >actual &&
+	test_cmp expect actual &&
+	git notes list 4th >expect &&
+	git notes list 8th >actual &&
+	test_cmp expect actual
+'
+
+test_expect_success 'copy note with "git notes copy" with default' '
+	test_commit 11th &&
+	commit=$(git rev-parse HEAD) &&
 	cat >expect <<-EOF &&
-		commit a446fff8777efdc6eb8f4b7c8a5ff699484df0d5
+		commit $commit
 		Author: A U Thor <author@example.com>
 		Date:   Thu Apr 7 15:23:13 2005 -0700
 
@@ -851,23 +926,59 @@ test_expect_success 'copy note with "git
 		${indent}
 		${indent}yet another note
 	EOF
-	test_commit 11th &&
-	git notes copy HEAD^ HEAD &&
+	git notes copy HEAD^ &&
 	git log -1 >actual &&
 	test_cmp expect actual &&
-	test "$(git notes list HEAD)" = "$(git notes list HEAD^)"
+	git notes list HEAD^ >expect &&
+	git notes list HEAD >actual &&
+	test_cmp expect actual
 '
 
 test_expect_success 'prevent overwrite with "git notes copy"' '
 	test_must_fail git notes copy HEAD~2 HEAD &&
+	cat >expect <<-EOF &&
+		commit $commit
+		Author: A U Thor <author@example.com>
+		Date:   Thu Apr 7 15:23:13 2005 -0700
+
+		${indent}11th
+
+		Notes:
+		${indent}other note
+		${indent}
+		${indent}yet another note
+	EOF
 	git log -1 >actual &&
 	test_cmp expect actual &&
-	test "$(git notes list HEAD)" = "$(git notes list HEAD^)"
+	git notes list HEAD^ >expect &&
+	git notes list HEAD >actual &&
+	test_cmp expect actual
 '
 
 test_expect_success 'allow overwrite with "git notes copy -f"' '
+	commit=$(git rev-parse HEAD) &&
 	cat >expect <<-EOF &&
-		commit a446fff8777efdc6eb8f4b7c8a5ff699484df0d5
+		commit $commit
+		Author: A U Thor <author@example.com>
+		Date:   Thu Apr 7 15:23:13 2005 -0700
+
+		${indent}11th
+
+		Notes:
+		${indent}This is a blob object
+	EOF
+	git notes copy -f HEAD~3 HEAD &&
+	git log -1 >actual &&
+	test_cmp expect actual &&
+	git notes list HEAD~3 >expect &&
+	git notes list HEAD >actual &&
+	test_cmp expect actual
+'
+
+test_expect_success 'allow overwrite with "git notes copy -f" with default' '
+	commit=$(git rev-parse HEAD) &&
+	cat >expect <<-EOF &&
+		commit $commit
 		Author: A U Thor <author@example.com>
 		Date:   Thu Apr 7 15:23:13 2005 -0700
 
@@ -878,10 +989,12 @@ test_expect_success 'allow overwrite wit
 		${indent}
 		${indent}yet another note
 	EOF
-	git notes copy -f HEAD~2 HEAD &&
+	git notes copy -f HEAD~2 &&
 	git log -1 >actual &&
 	test_cmp expect actual &&
-	test "$(git notes list HEAD)" = "$(git notes list HEAD~2)"
+	git notes list HEAD~2 >expect &&
+	git notes list HEAD >actual &&
+	test_cmp expect actual
 '
 
 test_expect_success 'cannot copy note from object without notes' '
@@ -891,8 +1004,10 @@ test_expect_success 'cannot copy note fr
 '
 
 test_expect_success 'git notes copy --stdin' '
+	commit=$(git rev-parse HEAD) &&
+	parent=$(git rev-parse HEAD^) &&
 	cat >expect <<-EOF &&
-		commit e871aa61182b1d95d0a6fb75445d891722863b6b
+		commit $commit
 		Author: A U Thor <author@example.com>
 		Date:   Thu Apr 7 15:25:13 2005 -0700
 
@@ -903,7 +1018,7 @@ test_expect_success 'git notes copy --st
 		${indent}
 		${indent}yet another note
 
-		commit 65e263ded02ae4e8839bc151095113737579dc12
+		commit $parent
 		Author: A U Thor <author@example.com>
 		Date:   Thu Apr 7 15:24:13 2005 -0700
 
@@ -914,41 +1029,57 @@ test_expect_success 'git notes copy --st
 		${indent}
 		${indent}yet another note
 	EOF
-	(echo $(git rev-parse HEAD~3) $(git rev-parse HEAD^); \
-	echo $(git rev-parse HEAD~2) $(git rev-parse HEAD)) |
-	git notes copy --stdin &&
+	from=$(git rev-parse HEAD~3) &&
+	to=$(git rev-parse HEAD^) &&
+	echo "$from" "$to" >copy &&
+	from=$(git rev-parse HEAD~2) &&
+	to=$(git rev-parse HEAD) &&
+	echo "$from" "$to" >>copy &&
+	git notes copy --stdin <copy &&
 	git log -2 >actual &&
 	test_cmp expect actual &&
-	test "$(git notes list HEAD)" = "$(git notes list HEAD~2)" &&
-	test "$(git notes list HEAD^)" = "$(git notes list HEAD~3)"
+	git notes list HEAD~2 >expect &&
+	git notes list HEAD >actual &&
+	test_cmp expect actual &&
+	git notes list HEAD~3 >expect &&
+	git notes list HEAD^ >actual &&
+	test_cmp expect actual
 '
 
 test_expect_success 'git notes copy --for-rewrite (unconfigured)' '
+	test_commit 14th &&
+	test_commit 15th &&
+	commit=$(git rev-parse HEAD) &&
+	parent=$(git rev-parse HEAD^) &&
 	cat >expect <<-EOF &&
-		commit 4acf42e847e7fffbbf89ee365c20ac7caf40de89
+		commit $commit
 		Author: A U Thor <author@example.com>
 		Date:   Thu Apr 7 15:27:13 2005 -0700
 
 		${indent}15th
 
-		commit 07c85d77059393ed0154b8c96906547a59dfcddd
+		commit $parent
 		Author: A U Thor <author@example.com>
 		Date:   Thu Apr 7 15:26:13 2005 -0700
 
 		${indent}14th
 	EOF
-	test_commit 14th &&
-	test_commit 15th &&
-	(echo $(git rev-parse HEAD~3) $(git rev-parse HEAD^); \
-	echo $(git rev-parse HEAD~2) $(git rev-parse HEAD)) |
-	git notes copy --for-rewrite=foo &&
+	from=$(git rev-parse HEAD~3) &&
+	to=$(git rev-parse HEAD^) &&
+	echo "$from" "$to" >copy &&
+	from=$(git rev-parse HEAD~2) &&
+	to=$(git rev-parse HEAD) &&
+	echo "$from" "$to" >>copy &&
+	git notes copy --for-rewrite=foo <copy &&
 	git log -2 >actual &&
 	test_cmp expect actual
 '
 
 test_expect_success 'git notes copy --for-rewrite (enabled)' '
+	commit=$(git rev-parse HEAD) &&
+	parent=$(git rev-parse HEAD^) &&
 	cat >expect <<-EOF &&
-		commit 4acf42e847e7fffbbf89ee365c20ac7caf40de89
+		commit $commit
 		Author: A U Thor <author@example.com>
 		Date:   Thu Apr 7 15:27:13 2005 -0700
 
@@ -959,7 +1090,7 @@ test_expect_success 'git notes copy --fo
 		${indent}
 		${indent}yet another note
 
-		commit 07c85d77059393ed0154b8c96906547a59dfcddd
+		commit $parent
 		Author: A U Thor <author@example.com>
 		Date:   Thu Apr 7 15:26:13 2005 -0700
 
@@ -972,24 +1103,31 @@ test_expect_success 'git notes copy --fo
 	EOF
 	test_config notes.rewriteMode overwrite &&
 	test_config notes.rewriteRef "refs/notes/*" &&
-	(echo $(git rev-parse HEAD~3) $(git rev-parse HEAD^); \
-	echo $(git rev-parse HEAD~2) $(git rev-parse HEAD)) |
-	git notes copy --for-rewrite=foo &&
+	from=$(git rev-parse HEAD~3) &&
+	to=$(git rev-parse HEAD^) &&
+	echo "$from" "$to" >copy &&
+	from=$(git rev-parse HEAD~2) &&
+	to=$(git rev-parse HEAD) &&
+	echo "$from" "$to" >>copy &&
+	git notes copy --for-rewrite=foo <copy &&
 	git log -2 >actual &&
 	test_cmp expect actual
 '
 
 test_expect_success 'git notes copy --for-rewrite (disabled)' '
 	test_config notes.rewrite.bar false &&
-	echo $(git rev-parse HEAD~3) $(git rev-parse HEAD) |
-	git notes copy --for-rewrite=bar &&
+	from=$(git rev-parse HEAD~3) &&
+	to=$(git rev-parse HEAD) &&
+	echo "$from" "$to" >copy &&
+	git notes copy --for-rewrite=bar <copy &&
 	git log -2 >actual &&
 	test_cmp expect actual
 '
 
 test_expect_success 'git notes copy --for-rewrite (overwrite)' '
+	commit=$(git rev-parse HEAD) &&
 	cat >expect <<-EOF &&
-		commit 4acf42e847e7fffbbf89ee365c20ac7caf40de89
+		commit $commit
 		Author: A U Thor <author@example.com>
 		Date:   Thu Apr 7 15:27:13 2005 -0700
 
@@ -1001,8 +1139,10 @@ test_expect_success 'git notes copy --fo
 	git notes add -f -m"a fresh note" HEAD^ &&
 	test_config notes.rewriteMode overwrite &&
 	test_config notes.rewriteRef "refs/notes/*" &&
-	echo $(git rev-parse HEAD^) $(git rev-parse HEAD) |
-	git notes copy --for-rewrite=foo &&
+	from=$(git rev-parse HEAD^) &&
+	to=$(git rev-parse HEAD) &&
+	echo "$from" "$to" >copy &&
+	git notes copy --for-rewrite=foo <copy &&
 	git log -1 >actual &&
 	test_cmp expect actual
 '
@@ -1010,15 +1150,18 @@ test_expect_success 'git notes copy --fo
 test_expect_success 'git notes copy --for-rewrite (ignore)' '
 	test_config notes.rewriteMode ignore &&
 	test_config notes.rewriteRef "refs/notes/*" &&
-	echo $(git rev-parse HEAD^) $(git rev-parse HEAD) |
-	git notes copy --for-rewrite=foo &&
+	from=$(git rev-parse HEAD^) &&
+	to=$(git rev-parse HEAD) &&
+	echo "$from" "$to" >copy &&
+	git notes copy --for-rewrite=foo <copy &&
 	git log -1 >actual &&
 	test_cmp expect actual
 '
 
 test_expect_success 'git notes copy --for-rewrite (append)' '
+	commit=$(git rev-parse HEAD) &&
 	cat >expect <<-EOF &&
-		commit 4acf42e847e7fffbbf89ee365c20ac7caf40de89
+		commit $commit
 		Author: A U Thor <author@example.com>
 		Date:   Thu Apr 7 15:27:13 2005 -0700
 
@@ -1032,15 +1175,18 @@ test_expect_success 'git notes copy --fo
 	git notes add -f -m"another fresh note" HEAD^ &&
 	test_config notes.rewriteMode concatenate &&
 	test_config notes.rewriteRef "refs/notes/*" &&
-	echo $(git rev-parse HEAD^) $(git rev-parse HEAD) |
-	git notes copy --for-rewrite=foo &&
+	from=$(git rev-parse HEAD^) &&
+	to=$(git rev-parse HEAD) &&
+	echo "$from" "$to" >copy &&
+	git notes copy --for-rewrite=foo <copy &&
 	git log -1 >actual &&
 	test_cmp expect actual
 '
 
 test_expect_success 'git notes copy --for-rewrite (append two to one)' '
+	commit=$(git rev-parse HEAD) &&
 	cat >expect <<-EOF &&
-		commit 4acf42e847e7fffbbf89ee365c20ac7caf40de89
+		commit $commit
 		Author: A U Thor <author@example.com>
 		Date:   Thu Apr 7 15:27:13 2005 -0700
 
@@ -1059,9 +1205,13 @@ test_expect_success 'git notes copy --fo
 	git notes add -f -m"append 2" HEAD^^ &&
 	test_config notes.rewriteMode concatenate &&
 	test_config notes.rewriteRef "refs/notes/*" &&
-	(echo $(git rev-parse HEAD^) $(git rev-parse HEAD);
-	echo $(git rev-parse HEAD^^) $(git rev-parse HEAD)) |
-	git notes copy --for-rewrite=foo &&
+	from=$(git rev-parse HEAD^) &&
+	to=$(git rev-parse HEAD) &&
+	echo "$from" "$to" >copy &&
+	from=$(git rev-parse HEAD^^) &&
+	to=$(git rev-parse HEAD) &&
+	echo "$from" "$to" >>copy &&
+	git notes copy --for-rewrite=foo <copy &&
 	git log -1 >actual &&
 	test_cmp expect actual
 '
@@ -1070,15 +1220,18 @@ test_expect_success 'git notes copy --fo
 	git notes remove HEAD^ &&
 	test_config notes.rewriteMode concatenate &&
 	test_config notes.rewriteRef "refs/notes/*" &&
-	echo $(git rev-parse HEAD^) $(git rev-parse HEAD) |
-	git notes copy --for-rewrite=foo &&
+	from=$(git rev-parse HEAD^) &&
+	to=$(git rev-parse HEAD) &&
+	echo "$from" "$to" >copy &&
+	git notes copy --for-rewrite=foo <copy &&
 	git log -1 >actual &&
 	test_cmp expect actual
 '
 
 test_expect_success 'GIT_NOTES_REWRITE_MODE works' '
+	commit=$(git rev-parse HEAD) &&
 	cat >expect <<-EOF &&
-		commit 4acf42e847e7fffbbf89ee365c20ac7caf40de89
+		commit $commit
 		Author: A U Thor <author@example.com>
 		Date:   Thu Apr 7 15:27:13 2005 -0700
 
@@ -1090,15 +1243,18 @@ test_expect_success 'GIT_NOTES_REWRITE_M
 	test_config notes.rewriteMode concatenate &&
 	test_config notes.rewriteRef "refs/notes/*" &&
 	git notes add -f -m"replacement note 1" HEAD^ &&
-	echo $(git rev-parse HEAD^) $(git rev-parse HEAD) |
-	GIT_NOTES_REWRITE_MODE=overwrite git notes copy --for-rewrite=foo &&
+	from=$(git rev-parse HEAD^) &&
+	to=$(git rev-parse HEAD) &&
+	echo "$from" "$to" >copy &&
+	GIT_NOTES_REWRITE_MODE=overwrite git notes copy --for-rewrite=foo <copy &&
 	git log -1 >actual &&
 	test_cmp expect actual
 '
 
 test_expect_success 'GIT_NOTES_REWRITE_REF works' '
+	commit=$(git rev-parse HEAD) &&
 	cat >expect <<-EOF &&
-		commit 4acf42e847e7fffbbf89ee365c20ac7caf40de89
+		commit $commit
 		Author: A U Thor <author@example.com>
 		Date:   Thu Apr 7 15:27:13 2005 -0700
 
@@ -1110,9 +1266,11 @@ test_expect_success 'GIT_NOTES_REWRITE_R
 	git notes add -f -m"replacement note 2" HEAD^ &&
 	test_config notes.rewriteMode overwrite &&
 	test_unconfig notes.rewriteRef &&
-	echo $(git rev-parse HEAD^) $(git rev-parse HEAD) |
+	from=$(git rev-parse HEAD^) &&
+	to=$(git rev-parse HEAD) &&
+	echo "$from" "$to" >copy &&
 	GIT_NOTES_REWRITE_REF=refs/notes/commits:refs/notes/other \
-		git notes copy --for-rewrite=foo &&
+		git notes copy --for-rewrite=foo <copy &&
 	git log -1 >actual &&
 	test_cmp expect actual
 '
@@ -1121,40 +1279,55 @@ test_expect_success 'GIT_NOTES_REWRITE_R
 	git notes add -f -m"replacement note 3" HEAD^ &&
 	test_config notes.rewriteMode overwrite &&
 	test_config notes.rewriteRef refs/notes/other &&
-	echo $(git rev-parse HEAD^) $(git rev-parse HEAD) |
-	GIT_NOTES_REWRITE_REF= git notes copy --for-rewrite=foo &&
+	from=$(git rev-parse HEAD^) &&
+	to=$(git rev-parse HEAD) &&
+	echo "$from" "$to" >copy &&
+	GIT_NOTES_REWRITE_REF=refs/notes/commits \
+		git notes copy --for-rewrite=foo <copy &&
 	git log -1 >actual &&
-	test_cmp expect actual
+	grep "replacement note 3" actual
 '
 
 test_expect_success 'git notes copy diagnoses too many or too few parameters' '
-	test_must_fail git notes copy &&
-	test_must_fail git notes copy one two three
+	test_must_fail git notes copy 2>error &&
+	test_i18ngrep "too few parameters" error &&
+	test_must_fail git notes copy one two three 2>error &&
+	test_i18ngrep "too many parameters" error
 '
 
 test_expect_success 'git notes get-ref expands refs/heads/master to refs/notes/refs/heads/master' '
 	test_unconfig core.notesRef &&
 	sane_unset GIT_NOTES_REF &&
-	test "$(git notes --ref=refs/heads/master get-ref)" = "refs/notes/refs/heads/master"
+	echo refs/notes/refs/heads/master >expect &&
+	git notes --ref=refs/heads/master get-ref >actual &&
+	test_cmp expect actual
 '
 
 test_expect_success 'git notes get-ref (no overrides)' '
 	test_unconfig core.notesRef &&
 	sane_unset GIT_NOTES_REF &&
-	test "$(git notes get-ref)" = "refs/notes/commits"
+	echo refs/notes/commits >expect &&
+	git notes get-ref >actual &&
+	test_cmp expect actual
 '
 
 test_expect_success 'git notes get-ref (core.notesRef)' '
 	test_config core.notesRef refs/notes/foo &&
-	test "$(git notes get-ref)" = "refs/notes/foo"
+	echo refs/notes/foo >expect &&
+	git notes get-ref >actual &&
+	test_cmp expect actual
 '
 
 test_expect_success 'git notes get-ref (GIT_NOTES_REF)' '
-	test "$(GIT_NOTES_REF=refs/notes/bar git notes get-ref)" = "refs/notes/bar"
+	echo refs/notes/bar >expect &&
+	GIT_NOTES_REF=refs/notes/bar git notes get-ref >actual &&
+	test_cmp expect actual
 '
 
 test_expect_success 'git notes get-ref (--ref)' '
-	test "$(GIT_NOTES_REF=refs/notes/bar git notes --ref=baz get-ref)" = "refs/notes/baz"
+	echo refs/notes/baz >expect &&
+	GIT_NOTES_REF=refs/notes/bar git notes --ref=baz get-ref >actual &&
+	test_cmp expect actual
 '
 
 test_expect_success 'setup testing of empty notes' '
diff -pruN 1.2.1+git2.18.0-1/git/t/t3305-notes-fanout.sh 1.2.3+git2.25.1-1/git/t/t3305-notes-fanout.sh
--- 1.2.1+git2.18.0-1/git/t/t3305-notes-fanout.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t3305-notes-fanout.sh	2020-02-17 04:47:35.000000000 +0000
@@ -35,15 +35,10 @@ test_expect_success 'many notes created
 	git ls-tree -r --name-only refs/notes/commits |
 	while read path
 	do
-		case "$path" in
-		??/??????????????????????????????????????)
-			: true
-			;;
-		*)
+		echo $path | grep "^../[0-9a-f]*$" || {
 			echo "Invalid path \"$path\"" &&
-			return 1
-			;;
-		esac
+			return 1;
+		}
 	done
 '
 
@@ -77,15 +72,10 @@ test_expect_success 'deleting most notes
 	git ls-tree -r --name-only refs/notes/commits |
 	while read path
 	do
-		case "$path" in
-		????????????????????????????????????????)
-			: true
-			;;
-		*)
+		echo $path | grep -v "^../.*" || {
 			echo "Invalid path \"$path\"" &&
-			return 1
-			;;
-		esac
+			return 1;
+		}
 	done
 '
 
diff -pruN 1.2.1+git2.18.0-1/git/t/t3306-notes-prune.sh 1.2.3+git2.25.1-1/git/t/t3306-notes-prune.sh
--- 1.2.1+git2.18.0-1/git/t/t3306-notes-prune.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t3306-notes-prune.sh	2020-02-17 04:47:35.000000000 +0000
@@ -11,23 +11,26 @@ test_expect_success 'setup: create a few
 	test_tick &&
 	git commit -m 1st &&
 	git notes add -m "Note #1" &&
+	first=$(git rev-parse HEAD) &&
 	: > file2 &&
 	git add file2 &&
 	test_tick &&
 	git commit -m 2nd &&
 	git notes add -m "Note #2" &&
+	second=$(git rev-parse HEAD) &&
 	: > file3 &&
 	git add file3 &&
 	test_tick &&
 	git commit -m 3rd &&
-	COMMIT_FILE=.git/objects/5e/e1c35e83ea47cd3cc4f8cbee0568915fbbbd29 &&
+	third=$(git rev-parse HEAD) &&
+	COMMIT_FILE=$(echo $third | sed "s!^..!.git/objects/&/!") &&
 	test -f $COMMIT_FILE &&
 	test-tool chmtime =+0 $COMMIT_FILE &&
 	git notes add -m "Note #3"
 '
 
 cat > expect <<END_OF_LOG
-commit 5ee1c35e83ea47cd3cc4f8cbee0568915fbbbd29
+commit $third
 Author: A U Thor <author@example.com>
 Date:   Thu Apr 7 15:15:13 2005 -0700
 
@@ -36,7 +39,7 @@ Date:   Thu Apr 7 15:15:13 2005 -0700
 Notes:
     Note #3
 
-commit 08341ad9e94faa089d60fd3f523affb25c6da189
+commit $second
 Author: A U Thor <author@example.com>
 Date:   Thu Apr 7 15:14:13 2005 -0700
 
@@ -45,7 +48,7 @@ Date:   Thu Apr 7 15:14:13 2005 -0700
 Notes:
     Note #2
 
-commit ab5f302035f2e7aaf04265f08b42034c23256e1f
+commit $first
 Author: A U Thor <author@example.com>
 Date:   Thu Apr 7 15:13:13 2005 -0700
 
@@ -70,16 +73,16 @@ test_expect_success 'remove some commits
 
 test_expect_success 'verify that commits are gone' '
 
-	test_must_fail git cat-file -p 5ee1c35e83ea47cd3cc4f8cbee0568915fbbbd29 &&
-	git cat-file -p 08341ad9e94faa089d60fd3f523affb25c6da189 &&
-	git cat-file -p ab5f302035f2e7aaf04265f08b42034c23256e1f
+	test_must_fail git cat-file -p $third &&
+	git cat-file -p $second &&
+	git cat-file -p $first
 '
 
 test_expect_success 'verify that notes are still present' '
 
-	git notes show 5ee1c35e83ea47cd3cc4f8cbee0568915fbbbd29 &&
-	git notes show 08341ad9e94faa089d60fd3f523affb25c6da189 &&
-	git notes show ab5f302035f2e7aaf04265f08b42034c23256e1f
+	git notes show $third &&
+	git notes show $second &&
+	git notes show $first
 '
 
 test_expect_success 'prune -n does not remove notes' '
@@ -90,13 +93,10 @@ test_expect_success 'prune -n does not r
 	test_cmp expect actual
 '
 
-cat > expect <<EOF
-5ee1c35e83ea47cd3cc4f8cbee0568915fbbbd29
-EOF
 
 test_expect_success 'prune -n lists prunable notes' '
 
-
+	echo $third >expect &&
 	git notes prune -n > actual &&
 	test_cmp expect actual
 '
@@ -109,9 +109,9 @@ test_expect_success 'prune notes' '
 
 test_expect_success 'verify that notes are gone' '
 
-	test_must_fail git notes show 5ee1c35e83ea47cd3cc4f8cbee0568915fbbbd29 &&
-	git notes show 08341ad9e94faa089d60fd3f523affb25c6da189 &&
-	git notes show ab5f302035f2e7aaf04265f08b42034c23256e1f
+	test_must_fail git notes show $third &&
+	git notes show $second &&
+	git notes show $first
 '
 
 test_expect_success 'remove some commits' '
@@ -121,21 +121,18 @@ test_expect_success 'remove some commits
 	git gc --prune=now
 '
 
-cat > expect <<EOF
-08341ad9e94faa089d60fd3f523affb25c6da189
-EOF
-
 test_expect_success 'prune -v notes' '
 
+	echo $second >expect &&
 	git notes prune -v > actual &&
 	test_cmp expect actual
 '
 
 test_expect_success 'verify that notes are gone' '
 
-	test_must_fail git notes show 5ee1c35e83ea47cd3cc4f8cbee0568915fbbbd29 &&
-	test_must_fail git notes show 08341ad9e94faa089d60fd3f523affb25c6da189 &&
-	git notes show ab5f302035f2e7aaf04265f08b42034c23256e1f
+	test_must_fail git notes show $third &&
+	test_must_fail git notes show $second &&
+	git notes show $first
 '
 
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t3308-notes-merge.sh 1.2.3+git2.25.1-1/git/t/t3308-notes-merge.sh
--- 1.2.1+git2.18.0-1/git/t/t3308-notes-merge.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t3308-notes-merge.sh	2020-02-17 04:47:35.000000000 +0000
@@ -183,7 +183,7 @@ test_expect_success 'merge empty notes r
 	git notes add -m "foo" &&
 	git notes remove &&
 	git notes >output_notes_z &&
-	test_cmp /dev/null output_notes_z &&
+	test_must_be_empty output_notes_z &&
 	# Do the merge (z => y)
 	git config core.notesRef refs/notes/y &&
 	git notes merge z &&
diff -pruN 1.2.1+git2.18.0-1/git/t/t3310-notes-merge-manual-resolve.sh 1.2.3+git2.25.1-1/git/t/t3310-notes-merge-manual-resolve.sh
--- 1.2.1+git2.18.0-1/git/t/t3310-notes-merge-manual-resolve.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t3310-notes-merge-manual-resolve.sh	2020-02-17 04:47:35.000000000 +0000
@@ -337,7 +337,7 @@ EOF
 	git notes merge --commit &&
 	# No .git/NOTES_MERGE_* files left
 	test_might_fail ls .git/NOTES_MERGE_* >output 2>/dev/null &&
-	test_cmp /dev/null output &&
+	test_must_be_empty output &&
 	# Merge commit has pre-merge y and pre-merge z as parents
 	test "$(git rev-parse refs/notes/m^1)" = "$(cat pre_merge_y)" &&
 	test "$(git rev-parse refs/notes/m^2)" = "$(cat pre_merge_z)" &&
@@ -399,7 +399,7 @@ test_expect_success 'abort notes merge'
 	git notes merge --abort &&
 	# No .git/NOTES_MERGE_* files left
 	test_might_fail ls .git/NOTES_MERGE_* >output 2>/dev/null &&
-	test_cmp /dev/null output &&
+	test_must_be_empty output &&
 	# m has not moved (still == y)
 	test "$(git rev-parse refs/notes/m)" = "$(cat pre_merge_y)" &&
 	# Verify that other notes refs has not changed (w, x, y and z)
@@ -466,7 +466,7 @@ EOF
 	git notes merge --commit &&
 	# No .git/NOTES_MERGE_* files left
 	test_might_fail ls .git/NOTES_MERGE_* >output 2>/dev/null &&
-	test_cmp /dev/null output &&
+	test_must_be_empty output &&
 	# Merge commit has pre-merge y and pre-merge z as parents
 	test "$(git rev-parse refs/notes/m^1)" = "$(cat pre_merge_y)" &&
 	test "$(git rev-parse refs/notes/m^2)" = "$(cat pre_merge_z)" &&
@@ -541,9 +541,9 @@ EOF
 	test "$(git rev-parse refs/notes/y)" = "$(git rev-parse NOTES_MERGE_PARTIAL^1)" &&
 	test "$(git rev-parse refs/notes/m)" != "$(git rev-parse NOTES_MERGE_PARTIAL^1)" &&
 	# Mention refs/notes/m, and its current and expected value in output
-	grep -q "refs/notes/m" output &&
-	grep -q "$(git rev-parse refs/notes/m)" output &&
-	grep -q "$(git rev-parse NOTES_MERGE_PARTIAL^1)" output &&
+	test_i18ngrep -q "refs/notes/m" output &&
+	test_i18ngrep -q "$(git rev-parse refs/notes/m)" output &&
+	test_i18ngrep -q "$(git rev-parse NOTES_MERGE_PARTIAL^1)" output &&
 	# Verify that other notes refs has not changed (w, x, y and z)
 	verify_notes w &&
 	verify_notes x &&
@@ -555,7 +555,7 @@ test_expect_success 'resolve situation b
 	git notes merge --abort &&
 	# No .git/NOTES_MERGE_* files left
 	test_might_fail ls .git/NOTES_MERGE_* >output 2>/dev/null &&
-	test_cmp /dev/null output &&
+	test_must_be_empty output &&
 	# m has not moved (still == w)
 	test "$(git rev-parse refs/notes/m)" = "$(git rev-parse refs/notes/w)" &&
 	# Verify that other notes refs has not changed (w, x, y and z)
diff -pruN 1.2.1+git2.18.0-1/git/t/t3311-notes-merge-fanout.sh 1.2.3+git2.25.1-1/git/t/t3311-notes-merge-fanout.sh
--- 1.2.1+git2.18.0-1/git/t/t3311-notes-merge-fanout.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t3311-notes-merge-fanout.sh	2020-02-17 04:47:35.000000000 +0000
@@ -114,12 +114,12 @@ cp expect_log_x expect_log_y
 test_expect_success 'Add a few hundred commits w/notes to trigger fanout (x -> y)' '
 	git update-ref refs/notes/y refs/notes/x &&
 	git config core.notesRef refs/notes/y &&
-	i=5 &&
-	while test $i -lt $num
+	test_commit_bulk --start=6 --id=commit $((num - 5)) &&
+	i=0 &&
+	while test $i -lt $((num - 5))
 	do
-		i=$(($i + 1)) &&
-		test_commit "commit$i" >/dev/null &&
-		git notes add -m "notes for commit$i" || return 1
+		git notes add -m "notes for commit$i" HEAD~$i || return 1
+		i=$((i + 1))
 	done &&
 	test "$(git rev-parse refs/notes/y)" != "$(git rev-parse refs/notes/x)" &&
 	# Expected number of commits and notes
diff -pruN 1.2.1+git2.18.0-1/git/t/t3320-notes-merge-worktrees.sh 1.2.3+git2.25.1-1/git/t/t3320-notes-merge-worktrees.sh
--- 1.2.1+git2.18.0-1/git/t/t3320-notes-merge-worktrees.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t3320-notes-merge-worktrees.sh	2020-02-17 04:47:35.000000000 +0000
@@ -44,7 +44,7 @@ test_expect_success 'merge z into y fail
 	git config core.notesRef refs/notes/y &&
 	test_must_fail git notes merge z &&
 	echo "ref: refs/notes/y" >expect &&
-	test_cmp .git/NOTES_MERGE_REF expect
+	test_cmp expect .git/NOTES_MERGE_REF
 '
 
 test_expect_success 'merge z into y while mid-merge in another workdir fails' '
@@ -66,7 +66,7 @@ test_expect_success 'merge z into x whil
 		grep -v "A notes merge into refs/notes/x is already in-progress in" out
 	) &&
 	echo "ref: refs/notes/x" >expect &&
-	test_cmp .git/worktrees/worktree2/NOTES_MERGE_REF expect
+	test_cmp expect .git/worktrees/worktree2/NOTES_MERGE_REF
 '
 
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t3400-rebase.sh 1.2.3+git2.25.1-1/git/t/t3400-rebase.sh
--- 1.2.1+git2.18.0-1/git/t/t3400-rebase.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t3400-rebase.sh	2020-02-17 04:47:35.000000000 +0000
@@ -59,6 +59,14 @@ test_expect_success 'rebase against mast
 	git rebase master
 '
 
+test_expect_success 'rebase sets ORIG_HEAD to pre-rebase state' '
+	git checkout -b orig-head topic &&
+	pre="$(git rev-parse --verify HEAD)" &&
+	git rebase master &&
+	test_cmp_rev "$pre" ORIG_HEAD &&
+	test_cmp_rev ! "$pre" HEAD
+'
+
 test_expect_success 'rebase, with <onto> and <upstream> specified as :/quuxery' '
 	test_when_finished "git branch -D torebase" &&
 	git checkout -b torebase my-topic-branch^ &&
@@ -151,6 +159,12 @@ test_expect_success 'fail when upstream
 	test_must_fail git rebase
 '
 
+test_expect_success 'rebase works with format.useAutoBase' '
+	test_config format.useAutoBase true &&
+	git checkout topic &&
+	git rebase master
+'
+
 test_expect_success 'default to common base in @{upstream}s reflog if no upstream arg' '
 	git checkout -b default-base master &&
 	git checkout -b default topic &&
@@ -183,13 +197,13 @@ test_expect_success 'cherry-picked commi
 	test_commit final_B B "Final B" &&
 	git rebase &&
 	echo Amended >expect &&
-	test_cmp A expect &&
+	test_cmp expect A &&
 	echo "Final B" >expect &&
-	test_cmp B expect &&
+	test_cmp expect B &&
 	echo C >expect &&
-	test_cmp C expect &&
+	test_cmp expect C &&
 	echo D >expect &&
-	test_cmp D expect
+	test_cmp expect D
 '
 
 test_expect_success 'rebase -q is quiet' '
@@ -200,10 +214,10 @@ test_expect_success 'rebase -q is quiet'
 
 test_expect_success 'Rebase a commit that sprinkles CRs in' '
 	(
-		echo "One"
-		echo "TwoQ"
-		echo "Three"
-		echo "FQur"
+		echo "One" &&
+		echo "TwoQ" &&
+		echo "Three" &&
+		echo "FQur" &&
 		echo "Five"
 	) | q_to_cr >CR &&
 	git add CR &&
@@ -277,7 +291,7 @@ EOF
 	test_cmp From_.msg out
 '
 
-test_expect_success 'rebase--am.sh and --show-current-patch' '
+test_expect_success 'rebase --am and --show-current-patch' '
 	test_create_repo conflict-apply &&
 	(
 		cd conflict-apply &&
@@ -287,12 +301,48 @@ test_expect_success 'rebase--am.sh and -
 		echo two >>init.t &&
 		git commit -a -m two &&
 		git tag two &&
-		test_must_fail git rebase --onto init HEAD^ &&
+		test_must_fail git rebase -f --onto init HEAD^ &&
 		GIT_TRACE=1 git rebase --show-current-patch >/dev/null 2>stderr &&
 		grep "show.*$(git rev-parse two)" stderr
 	)
 '
 
+test_expect_success 'rebase --am and .gitattributes' '
+	test_create_repo attributes &&
+	(
+		cd attributes &&
+		test_commit init &&
+		git config filter.test.clean "sed -e '\''s/smudged/clean/g'\''" &&
+		git config filter.test.smudge "sed -e '\''s/clean/smudged/g'\''" &&
+
+		test_commit second &&
+		git checkout -b test HEAD^ &&
+
+		echo "*.txt filter=test" >.gitattributes &&
+		git add .gitattributes &&
+		test_commit third &&
+
+		echo "This text is smudged." >a.txt &&
+		git add a.txt &&
+		test_commit fourth &&
+
+		git checkout -b removal HEAD^ &&
+		git rm .gitattributes &&
+		git add -u &&
+		test_commit fifth &&
+		git cherry-pick test &&
+
+		git checkout test &&
+		git rebase master &&
+		grep "smudged" a.txt &&
+
+		git checkout removal &&
+		git reset --hard &&
+		git rebase master &&
+		grep "clean" a.txt
+	)
+'
+
 test_expect_success 'rebase--merge.sh and --show-current-patch' '
 	test_create_repo conflict-merge &&
 	(
@@ -311,4 +361,20 @@ test_expect_success 'rebase--merge.sh an
 	)
 '
 
+test_expect_success 'rebase -c rebase.useBuiltin=false warning' '
+	expected="rebase.useBuiltin support has been removed" &&
+
+	# Only warn when the legacy rebase is requested...
+	test_must_fail git -c rebase.useBuiltin=false rebase 2>err &&
+	test_i18ngrep "$expected" err &&
+	test_must_fail env GIT_TEST_REBASE_USE_BUILTIN=false git rebase 2>err &&
+	test_i18ngrep "$expected" err &&
+
+	# ...not when we would have used the built-in anyway
+	test_must_fail git -c rebase.useBuiltin=true rebase 2>err &&
+	test_must_be_empty err &&
+	test_must_fail env GIT_TEST_REBASE_USE_BUILTIN=true git rebase 2>err &&
+	test_must_be_empty err
+'
+
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t3401-rebase-and-am-rename.sh 1.2.3+git2.25.1-1/git/t/t3401-rebase-and-am-rename.sh
--- 1.2.1+git2.18.0-1/git/t/t3401-rebase-and-am-rename.sh	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t3401-rebase-and-am-rename.sh	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,213 @@
+#!/bin/sh
+
+test_description='git rebase + directory rename tests'
+
+. ./test-lib.sh
+. "$TEST_DIRECTORY"/lib-rebase.sh
+
+test_expect_success 'setup testcase where directory rename should be detected' '
+	test_create_repo dir-rename &&
+	(
+		cd dir-rename &&
+
+		mkdir x &&
+		test_seq  1 10 >x/a &&
+		test_seq 11 20 >x/b &&
+		test_seq 21 30 >x/c &&
+		test_write_lines a b c d e f g h i >l &&
+		git add x l &&
+		git commit -m "Initial" &&
+
+		git branch O &&
+		git branch A &&
+		git branch B &&
+
+		git checkout A &&
+		git mv x y &&
+		git mv l letters &&
+		git commit -m "Rename x to y, l to letters" &&
+
+		git checkout B &&
+		echo j >>l &&
+		test_seq 31 40 >x/d &&
+		git add l x/d &&
+		git commit -m "Modify l, add x/d"
+	)
+'
+
+test_expect_success 'rebase --interactive: directory rename detected' '
+	(
+		cd dir-rename &&
+
+		git checkout B^0 &&
+
+		set_fake_editor &&
+		FAKE_LINES="1" git -c merge.directoryRenames=true rebase --interactive A &&
+
+		git ls-files -s >out &&
+		test_line_count = 5 out &&
+
+		test_path_is_file y/d &&
+		test_path_is_missing x/d
+	)
+'
+
+test_expect_failure 'rebase (am): directory rename detected' '
+	(
+		cd dir-rename &&
+
+		git checkout B^0 &&
+
+		git -c merge.directoryRenames=true rebase A &&
+
+		git ls-files -s >out &&
+		test_line_count = 5 out &&
+
+		test_path_is_file y/d &&
+		test_path_is_missing x/d
+	)
+'
+
+test_expect_success 'rebase --merge: directory rename detected' '
+	(
+		cd dir-rename &&
+
+		git checkout B^0 &&
+
+		git -c merge.directoryRenames=true rebase --merge A &&
+
+		git ls-files -s >out &&
+		test_line_count = 5 out &&
+
+		test_path_is_file y/d &&
+		test_path_is_missing x/d
+	)
+'
+
+test_expect_failure 'am: directory rename detected' '
+	(
+		cd dir-rename &&
+
+		git checkout A^0 &&
+
+		git format-patch -1 B &&
+
+		git -c merge.directoryRenames=true am --3way 0001*.patch &&
+
+		git ls-files -s >out &&
+		test_line_count = 5 out &&
+
+		test_path_is_file y/d &&
+		test_path_is_missing x/d
+	)
+'
+
+test_expect_success 'setup testcase where directory rename should NOT be detected' '
+	test_create_repo no-dir-rename &&
+	(
+		cd no-dir-rename &&
+
+		mkdir x &&
+		test_seq  1 10 >x/a &&
+		test_seq 11 20 >x/b &&
+		test_seq 21 30 >x/c &&
+		echo original >project_info &&
+		git add x project_info &&
+		git commit -m "Initial" &&
+
+		git branch O &&
+		git branch A &&
+		git branch B &&
+
+		git checkout A &&
+		echo v2 >project_info &&
+		git add project_info &&
+		git commit -m "Modify project_info" &&
+
+		git checkout B &&
+		mkdir y &&
+		git mv x/c y/c &&
+		echo v1 >project_info &&
+		git add project_info &&
+		git commit -m "Rename x/c to y/c, modify project_info"
+	)
+'
+
+test_expect_success 'rebase --interactive: NO directory rename' '
+	test_when_finished "git -C no-dir-rename rebase --abort" &&
+	(
+		cd no-dir-rename &&
+
+		git checkout B^0 &&
+
+		set_fake_editor &&
+		test_must_fail env FAKE_LINES="1" git rebase --interactive A &&
+
+		git ls-files -s >out &&
+		test_line_count = 6 out &&
+
+		test_path_is_file x/a &&
+		test_path_is_file x/b &&
+		test_path_is_missing x/c
+	)
+'
+
+test_expect_success 'rebase (am): NO directory rename' '
+	test_when_finished "git -C no-dir-rename rebase --abort" &&
+	(
+		cd no-dir-rename &&
+
+		git checkout B^0 &&
+
+		set_fake_editor &&
+		test_must_fail git rebase A &&
+
+		git ls-files -s >out &&
+		test_line_count = 6 out &&
+
+		test_path_is_file x/a &&
+		test_path_is_file x/b &&
+		test_path_is_missing x/c
+	)
+'
+
+test_expect_success 'rebase --merge: NO directory rename' '
+	test_when_finished "git -C no-dir-rename rebase --abort" &&
+	(
+		cd no-dir-rename &&
+
+		git checkout B^0 &&
+
+		set_fake_editor &&
+		test_must_fail git rebase --merge A &&
+
+		git ls-files -s >out &&
+		test_line_count = 6 out &&
+
+		test_path_is_file x/a &&
+		test_path_is_file x/b &&
+		test_path_is_missing x/c
+	)
+'
+
+test_expect_success 'am: NO directory rename' '
+	test_when_finished "git -C no-dir-rename am --abort" &&
+	(
+		cd no-dir-rename &&
+
+		git checkout A^0 &&
+
+		git format-patch -1 B &&
+
+		test_must_fail git am --3way 0001*.patch &&
+
+		git ls-files -s >out &&
+		test_line_count = 6 out &&
+
+		test_path_is_file x/a &&
+		test_path_is_file x/b &&
+		test_path_is_missing x/c
+	)
+'
+
+test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t3402-rebase-merge.sh 1.2.3+git2.25.1-1/git/t/t3402-rebase-merge.sh
--- 1.2.1+git2.18.0-1/git/t/t3402-rebase-merge.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t3402-rebase-merge.sh	2020-02-17 04:47:35.000000000 +0000
@@ -25,7 +25,7 @@ test_expect_success setup '
 	git commit -a -m"master updates a bit more." &&
 
 	git checkout side &&
-	(echo "0 $T" ; cat original) >renamed &&
+	(echo "0 $T" && cat original) >renamed &&
 	git add renamed &&
 	git update-index --force-remove original &&
 	git commit -a -m"side renames and edits." &&
@@ -143,7 +143,7 @@ test_expect_success 'rebase -s funny -Xo
 	git checkout -b test-funny master^ &&
 	test_commit funny &&
 	(
-		PATH=./test-bin:$PATH
+		PATH=./test-bin:$PATH &&
 		git rebase -s funny -Xopt master
 	) &&
 	test -f funny.was.run
diff -pruN 1.2.1+git2.18.0-1/git/t/t3403-rebase-skip.sh 1.2.3+git2.25.1-1/git/t/t3403-rebase-skip.sh
--- 1.2.1+git2.18.0-1/git/t/t3403-rebase-skip.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t3403-rebase-skip.sh	2020-02-17 04:47:35.000000000 +0000
@@ -7,6 +7,8 @@ test_description='git rebase --merge --s
 
 . ./test-lib.sh
 
+. "$TEST_DIRECTORY"/lib-rebase.sh
+
 # we assume the default git am -3 --skip strategy is tested independently
 # and always works :)
 
@@ -20,6 +22,13 @@ test_expect_success setup '
 	git commit -a -m "hello world" &&
 	echo goodbye >> hello &&
 	git commit -a -m "goodbye" &&
+	git tag goodbye &&
+
+	git checkout --detach &&
+	git checkout HEAD^ . &&
+	test_tick &&
+	git commit -m reverted-goodbye &&
+	git tag reverted-goodbye &&
 
 	git checkout -f skip-reference &&
 	echo moo > hello &&
@@ -76,4 +85,27 @@ test_expect_success 'moved back to branc
 
 test_debug 'gitk --all & sleep 1'
 
+test_expect_success 'fixup that empties commit fails' '
+	test_when_finished "git rebase --abort" &&
+	(
+		set_fake_editor &&
+		test_must_fail env FAKE_LINES="1 fixup 2" git rebase -i \
+			goodbye^ reverted-goodbye
+	)
+'
+
+test_expect_success 'squash that empties commit fails' '
+	test_when_finished "git rebase --abort" &&
+	(
+		set_fake_editor &&
+		test_must_fail env FAKE_LINES="1 squash 2" git rebase -i \
+			goodbye^ reverted-goodbye
+	)
+'
+
+# Must be the last test in this file
+test_expect_success '$EDITOR and friends are unchanged' '
+	test_editor_unchanged
+'
+
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t3404-rebase-interactive.sh 1.2.3+git2.25.1-1/git/t/t3404-rebase-interactive.sh
--- 1.2.1+git2.18.0-1/git/t/t3404-rebase-interactive.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t3404-rebase-interactive.sh	2020-02-17 04:47:35.000000000 +0000
@@ -29,9 +29,6 @@ Initial setup:
 
 . "$TEST_DIRECTORY"/lib-rebase.sh
 
-# WARNING: Modifications to the initial repository can change the SHA ID used
-# in the expect2 file for the 'stop on conflicting pick' test.
-
 test_expect_success 'setup' '
 	test_commit A file1 &&
 	test_commit B file1 &&
@@ -75,6 +72,18 @@ test_expect_success 'rebase --keep-empty
 	test_line_count = 6 actual
 '
 
+test_expect_success 'rebase -i with empty HEAD' '
+	cat >expect <<-\EOF &&
+	error: nothing to do
+	EOF
+	(
+		set_fake_editor &&
+		test_must_fail env FAKE_LINES="1 exec_true" \
+			git rebase -i HEAD^ >actual 2>&1
+	) &&
+	test_i18ncmp expect actual
+'
+
 test_expect_success 'rebase -i with the exec command' '
 	git checkout master &&
 	(
@@ -114,32 +123,67 @@ test_expect_success 'rebase -i with exec
 	git checkout master &&
 	mkdir subdir && (cd subdir &&
 	set_fake_editor &&
-	FAKE_LINES="1 exec_cd_subdir_&&_git_rev-parse_--is-inside-work-tree" \
+	FAKE_LINES="1 x_cd_subdir_&&_git_rev-parse_--is-inside-work-tree" \
 		git rebase -i HEAD^
 	)
 '
 
+test_expect_success 'rebase -i sets work tree properly' '
+	test_when_finished "rm -rf subdir" &&
+	test_when_finished "test_might_fail git rebase --abort" &&
+	mkdir subdir &&
+	git rebase -x "(cd subdir && git rev-parse --show-toplevel)" HEAD^ \
+		>actual &&
+	! grep "/subdir$" actual
+'
+
 test_expect_success 'rebase -i with the exec command checks tree cleanness' '
 	git checkout master &&
-	set_fake_editor &&
-	test_must_fail env FAKE_LINES="exec_echo_foo_>file1 1" git rebase -i HEAD^ &&
+	(
+		set_fake_editor &&
+		test_must_fail env FAKE_LINES="exec_echo_foo_>file1 1" \
+			git rebase -i HEAD^
+	) &&
 	test_cmp_rev master^ HEAD &&
 	git reset --hard &&
 	git rebase --continue
 '
 
+test_expect_success 'rebase -x with empty command fails' '
+	test_when_finished "git rebase --abort ||:" &&
+	test_must_fail env git rebase -x "" @ 2>actual &&
+	test_write_lines "error: empty exec command" >expected &&
+	test_i18ncmp expected actual &&
+	test_must_fail env git rebase -x " " @ 2>actual &&
+	test_i18ncmp expected actual
+'
+
+test_expect_success 'rebase -x with newline in command fails' '
+	test_when_finished "git rebase --abort ||:" &&
+	test_must_fail env git rebase -x "a${LF}b" @ 2>actual &&
+	test_write_lines "error: exec commands cannot contain newlines" \
+			 >expected &&
+	test_i18ncmp expected actual
+'
+
 test_expect_success 'rebase -i with exec of inexistent command' '
 	git checkout master &&
 	test_when_finished "git rebase --abort" &&
-	set_fake_editor &&
-	test_must_fail env FAKE_LINES="exec_this-command-does-not-exist 1" \
-	git rebase -i HEAD^ >actual 2>&1 &&
+	(
+		set_fake_editor &&
+		test_must_fail env FAKE_LINES="exec_this-command-does-not-exist 1" \
+			git rebase -i HEAD^ >actual 2>&1
+	) &&
 	! grep "Maybe git-rebase is broken" actual
 '
 
+test_expect_success 'implicit interactive rebase does not invoke sequence editor' '
+	test_when_finished "git rebase --abort ||:" &&
+	GIT_SEQUENCE_EDITOR="echo bad >" git rebase -x"echo one" @^
+'
+
 test_expect_success 'no changes are a nop' '
 	git checkout branch2 &&
-	set_fake_editor &&
 	git rebase -i F &&
 	test "$(git symbolic-ref -q HEAD)" = "refs/heads/branch2" &&
 	test $(git rev-parse I) = $(git rev-parse HEAD)
@@ -149,7 +193,6 @@ test_expect_success 'test the [branch] o
 	git checkout -b dead-end &&
 	git rm file6 &&
 	git commit -m "stop here" &&
-	set_fake_editor &&
 	git rebase -i F branch2 &&
 	test "$(git symbolic-ref -q HEAD)" = "refs/heads/branch2" &&
 	test $(git rev-parse I) = $(git rev-parse branch2) &&
@@ -158,7 +201,6 @@ test_expect_success 'test the [branch] o
 
 test_expect_success 'test --onto <branch>' '
 	git checkout -b test-onto branch2 &&
-	set_fake_editor &&
 	git rebase -i --onto branch1 F &&
 	test "$(git symbolic-ref -q HEAD)" = "refs/heads/test-onto" &&
 	test $(git rev-parse HEAD^) = $(git rev-parse branch1) &&
@@ -168,7 +210,6 @@ test_expect_success 'test --onto <branch
 test_expect_success 'rebase on top of a non-conflicting commit' '
 	git checkout branch1 &&
 	git tag original-branch1 &&
-	set_fake_editor &&
 	git rebase -i branch2 &&
 	test file6 = $(git diff --name-only original-branch1) &&
 	test "$(git symbolic-ref -q HEAD)" = "refs/heads/branch1" &&
@@ -188,33 +229,35 @@ test_expect_success 'reflog for the bran
 '
 
 test_expect_success 'exchange two commits' '
-	set_fake_editor &&
-	FAKE_LINES="2 1" git rebase -i HEAD~2 &&
+	(
+		set_fake_editor &&
+		FAKE_LINES="2 1" git rebase -i HEAD~2
+	) &&
 	test H = $(git cat-file commit HEAD^ | sed -ne \$p) &&
-	test G = $(git cat-file commit HEAD | sed -ne \$p)
+	test G = $(git cat-file commit HEAD | sed -ne \$p) &&
+	blob1=$(git rev-parse --short HEAD^:file1) &&
+	blob2=$(git rev-parse --short HEAD:file1) &&
+	commit=$(git rev-parse --short HEAD)
 '
 
-cat > expect << EOF
-diff --git a/file1 b/file1
-index f70f10e..fd79235 100644
---- a/file1
-+++ b/file1
-@@ -1 +1 @@
--A
-+G
-EOF
-
-cat > expect2 << EOF
-<<<<<<< HEAD
-D
-=======
-G
->>>>>>> 5d18e54... G
-EOF
-
 test_expect_success 'stop on conflicting pick' '
+	cat >expect <<-EOF &&
+	diff --git a/file1 b/file1
+	index $blob1..$blob2 100644
+	--- a/file1
+	+++ b/file1
+	@@ -1 +1 @@
+	-A
+	+G
+	EOF
+	cat >expect2 <<-EOF &&
+	<<<<<<< HEAD
+	D
+	=======
+	G
+	>>>>>>> $commit... G
+	EOF
 	git tag new-branch1 &&
-	set_fake_editor &&
 	test_must_fail git rebase -i master &&
 	test "$(git rev-parse HEAD~3)" = "$(git rev-parse master)" &&
 	test_cmp expect .git/rebase-merge/patch &&
@@ -243,7 +286,6 @@ test_expect_success 'abort' '
 test_expect_success 'abort with error when new base cannot be checked out' '
 	git rm --cached file1 &&
 	git commit -m "remove file in base" &&
-	set_fake_editor &&
 	test_must_fail git rebase -i master > output 2>&1 &&
 	test_i18ngrep "The following untracked working tree files would be overwritten by checkout:" \
 		output &&
@@ -258,18 +300,23 @@ test_expect_success 'retain authorship'
 	test_tick &&
 	GIT_AUTHOR_NAME="Twerp Snog" git commit -m "different author" &&
 	git tag twerp &&
-	set_fake_editor &&
 	git rebase -i --onto master HEAD^ &&
 	git show HEAD | grep "^Author: Twerp Snog"
 '
 
 test_expect_success 'retain authorship w/ conflicts' '
+	oGIT_AUTHOR_NAME=$GIT_AUTHOR_NAME &&
+	test_when_finished "GIT_AUTHOR_NAME=\$oGIT_AUTHOR_NAME" &&
+
 	git reset --hard twerp &&
 	test_commit a conflict a conflict-a &&
 	git reset --hard twerp &&
-	GIT_AUTHOR_NAME=AttributeMe \
+
+	GIT_AUTHOR_NAME=AttributeMe &&
+	export GIT_AUTHOR_NAME &&
 	test_commit b conflict b conflict-b &&
-	set_fake_editor &&
+	GIT_AUTHOR_NAME=$oGIT_AUTHOR_NAME &&
+
 	test_must_fail git rebase -i conflict-a &&
 	echo resolved >conflict &&
 	git add conflict &&
@@ -285,9 +332,11 @@ test_expect_success 'squash' '
 	test_tick &&
 	GIT_AUTHOR_NAME="Nitfol" git commit -m "nitfol" file7 &&
 	echo "******************************" &&
-	set_fake_editor &&
-	FAKE_LINES="1 squash 2" EXPECT_HEADER_COUNT=2 \
-		git rebase -i --onto master HEAD~2 &&
+	(
+		set_fake_editor &&
+		FAKE_LINES="1 squash 2" EXPECT_HEADER_COUNT=2 \
+			git rebase -i --onto master HEAD~2
+	) &&
 	test B = $(cat file7) &&
 	test $(git rev-parse HEAD^) = $(git rev-parse master)
 '
@@ -296,9 +345,8 @@ test_expect_success 'retain authorship w
 	git show HEAD | grep "^Author: Twerp Snog"
 '
 
-test_expect_success '-p handles "no changes" gracefully' '
+test_expect_success REBASE_P '-p handles "no changes" gracefully' '
 	HEAD=$(git rev-parse HEAD) &&
-	set_fake_editor &&
 	git rebase -i -p HEAD^ &&
 	git update-index --refresh &&
 	git diff-files --quiet &&
@@ -306,15 +354,17 @@ test_expect_success '-p handles "no chan
 	test $HEAD = $(git rev-parse HEAD)
 '
 
-test_expect_failure 'exchange two commits with -p' '
+test_expect_failure REBASE_P 'exchange two commits with -p' '
 	git checkout H &&
-	set_fake_editor &&
-	FAKE_LINES="2 1" git rebase -i -p HEAD~2 &&
+	(
+		set_fake_editor &&
+		FAKE_LINES="2 1" git rebase -i -p HEAD~2
+	) &&
 	test H = $(git cat-file commit HEAD^ | sed -ne \$p) &&
 	test G = $(git cat-file commit HEAD | sed -ne \$p)
 '
 
-test_expect_success 'preserve merges with -p' '
+test_expect_success REBASE_P 'preserve merges with -p' '
 	git checkout -b to-be-preserved master^ &&
 	: > unrelated-file &&
 	git add unrelated-file &&
@@ -343,7 +393,6 @@ test_expect_success 'preserve merges wit
 	git commit -m M file1 &&
 	git checkout -b to-be-rebased &&
 	test_tick &&
-	set_fake_editor &&
 	git rebase -i -p --onto branch1 master &&
 	git update-index --refresh &&
 	git diff-files --quiet &&
@@ -357,9 +406,11 @@ test_expect_success 'preserve merges wit
 	test $(git show HEAD:unrelated-file) = 1
 '
 
-test_expect_success 'edit ancestor with -p' '
-	set_fake_editor &&
-	FAKE_LINES="1 2 edit 3 4" git rebase -i -p HEAD~3 &&
+test_expect_success REBASE_P 'edit ancestor with -p' '
+	(
+		set_fake_editor &&
+		FAKE_LINES="1 2 edit 3 4" git rebase -i -p HEAD~3
+	) &&
 	echo 2 > unrelated-file &&
 	test_tick &&
 	git commit -m L2-modified --amend unrelated-file &&
@@ -371,12 +422,15 @@ test_expect_success 'edit ancestor with
 '
 
 test_expect_success '--continue tries to commit' '
+	git reset --hard D &&
 	test_tick &&
-	set_fake_editor &&
-	test_must_fail git rebase -i --onto new-branch1 HEAD^ &&
-	echo resolved > file1 &&
-	git add file1 &&
-	FAKE_COMMIT_MESSAGE="chouette!" git rebase --continue &&
+	(
+		set_fake_editor &&
+		test_must_fail git rebase -i --onto new-branch1 HEAD^ &&
+		echo resolved > file1 &&
+		git add file1 &&
+		FAKE_COMMIT_MESSAGE="chouette!" git rebase --continue
+	) &&
 	test $(git rev-parse HEAD^) = $(git rev-parse new-branch1) &&
 	git show HEAD | grep chouette
 '
@@ -384,7 +438,6 @@ test_expect_success '--continue tries to
 test_expect_success 'verbose flag is heeded, even after --continue' '
 	git reset --hard master@{1} &&
 	test_tick &&
-	set_fake_editor &&
 	test_must_fail git rebase -v -i --onto new-branch1 HEAD^ &&
 	echo resolved > file1 &&
 	git add file1 &&
@@ -394,10 +447,13 @@ test_expect_success 'verbose flag is hee
 
 test_expect_success C_LOCALE_OUTPUT 'multi-squash only fires up editor once' '
 	base=$(git rev-parse HEAD~4) &&
-	set_fake_editor &&
-	FAKE_COMMIT_AMEND="ONCE" FAKE_LINES="1 squash 2 squash 3 squash 4" \
-		EXPECT_HEADER_COUNT=4 \
-		git rebase -i $base &&
+	(
+		set_fake_editor &&
+		FAKE_COMMIT_AMEND="ONCE" \
+			FAKE_LINES="1 squash 2 squash 3 squash 4" \
+			EXPECT_HEADER_COUNT=4 \
+			git rebase -i $base
+	) &&
 	test $base = $(git rev-parse HEAD^) &&
 	test 1 = $(git show | grep ONCE | wc -l)
 '
@@ -405,111 +461,132 @@ test_expect_success C_LOCALE_OUTPUT 'mul
 test_expect_success C_LOCALE_OUTPUT 'multi-fixup does not fire up editor' '
 	git checkout -b multi-fixup E &&
 	base=$(git rev-parse HEAD~4) &&
-	set_fake_editor &&
-	FAKE_COMMIT_AMEND="NEVER" FAKE_LINES="1 fixup 2 fixup 3 fixup 4" \
-		git rebase -i $base &&
+	(
+		set_fake_editor &&
+		FAKE_COMMIT_AMEND="NEVER" \
+			FAKE_LINES="1 fixup 2 fixup 3 fixup 4" \
+			git rebase -i $base
+	) &&
 	test $base = $(git rev-parse HEAD^) &&
 	test 0 = $(git show | grep NEVER | wc -l) &&
-	git checkout to-be-rebased &&
+	git checkout @{-1} &&
 	git branch -D multi-fixup
 '
 
 test_expect_success 'commit message used after conflict' '
 	git checkout -b conflict-fixup conflict-branch &&
 	base=$(git rev-parse HEAD~4) &&
-	set_fake_editor &&
-	test_must_fail env FAKE_LINES="1 fixup 3 fixup 4" git rebase -i $base &&
-	echo three > conflict &&
-	git add conflict &&
-	FAKE_COMMIT_AMEND="ONCE" EXPECT_HEADER_COUNT=2 \
-		git rebase --continue &&
+	(
+		set_fake_editor &&
+		test_must_fail env FAKE_LINES="1 fixup 3 fixup 4" \
+			git rebase -i $base &&
+		echo three > conflict &&
+		git add conflict &&
+		FAKE_COMMIT_AMEND="ONCE" EXPECT_HEADER_COUNT=2 \
+			git rebase --continue
+	) &&
 	test $base = $(git rev-parse HEAD^) &&
 	test 1 = $(git show | grep ONCE | wc -l) &&
-	git checkout to-be-rebased &&
+	git checkout @{-1} &&
 	git branch -D conflict-fixup
 '
 
 test_expect_success 'commit message retained after conflict' '
 	git checkout -b conflict-squash conflict-branch &&
 	base=$(git rev-parse HEAD~4) &&
-	set_fake_editor &&
-	test_must_fail env FAKE_LINES="1 fixup 3 squash 4" git rebase -i $base &&
-	echo three > conflict &&
-	git add conflict &&
-	FAKE_COMMIT_AMEND="TWICE" EXPECT_HEADER_COUNT=2 \
-		git rebase --continue &&
+	(
+		set_fake_editor &&
+		test_must_fail env FAKE_LINES="1 fixup 3 squash 4" \
+			git rebase -i $base &&
+		echo three > conflict &&
+		git add conflict &&
+		FAKE_COMMIT_AMEND="TWICE" EXPECT_HEADER_COUNT=2 \
+			git rebase --continue
+	) &&
 	test $base = $(git rev-parse HEAD^) &&
 	test 2 = $(git show | grep TWICE | wc -l) &&
-	git checkout to-be-rebased &&
+	git checkout @{-1} &&
 	git branch -D conflict-squash
 '
 
-cat > expect-squash-fixup << EOF
-B
-
-D
+test_expect_success C_LOCALE_OUTPUT 'squash and fixup generate correct log messages' '
+	cat >expect-squash-fixup <<-\EOF &&
+	B
 
-ONCE
-EOF
+	D
 
-test_expect_success C_LOCALE_OUTPUT 'squash and fixup generate correct log messages' '
+	ONCE
+	EOF
 	git checkout -b squash-fixup E &&
 	base=$(git rev-parse HEAD~4) &&
-	set_fake_editor &&
-	FAKE_COMMIT_AMEND="ONCE" FAKE_LINES="1 fixup 2 squash 3 fixup 4" \
-		EXPECT_HEADER_COUNT=4 \
-		git rebase -i $base &&
+	(
+		set_fake_editor &&
+		FAKE_COMMIT_AMEND="ONCE" \
+			FAKE_LINES="1 fixup 2 squash 3 fixup 4" \
+			EXPECT_HEADER_COUNT=4 \
+			git rebase -i $base
+	) &&
 	git cat-file commit HEAD | sed -e 1,/^\$/d > actual-squash-fixup &&
 	test_cmp expect-squash-fixup actual-squash-fixup &&
 	git cat-file commit HEAD@{2} |
 		grep "^# This is a combination of 3 commits\."  &&
 	git cat-file commit HEAD@{3} |
 		grep "^# This is a combination of 2 commits\."  &&
-	git checkout to-be-rebased &&
+	git checkout @{-1} &&
 	git branch -D squash-fixup
 '
 
 test_expect_success C_LOCALE_OUTPUT 'squash ignores comments' '
 	git checkout -b skip-comments E &&
 	base=$(git rev-parse HEAD~4) &&
-	set_fake_editor &&
-	FAKE_COMMIT_AMEND="ONCE" FAKE_LINES="# 1 # squash 2 # squash 3 # squash 4 #" \
-		EXPECT_HEADER_COUNT=4 \
-		git rebase -i $base &&
+	(
+		set_fake_editor &&
+		FAKE_COMMIT_AMEND="ONCE" \
+			FAKE_LINES="# 1 # squash 2 # squash 3 # squash 4 #" \
+			EXPECT_HEADER_COUNT=4 \
+			git rebase -i $base
+	) &&
 	test $base = $(git rev-parse HEAD^) &&
 	test 1 = $(git show | grep ONCE | wc -l) &&
-	git checkout to-be-rebased &&
+	git checkout @{-1} &&
 	git branch -D skip-comments
 '
 
 test_expect_success C_LOCALE_OUTPUT 'squash ignores blank lines' '
 	git checkout -b skip-blank-lines E &&
 	base=$(git rev-parse HEAD~4) &&
-	set_fake_editor &&
-	FAKE_COMMIT_AMEND="ONCE" FAKE_LINES="> 1 > squash 2 > squash 3 > squash 4 >" \
-		EXPECT_HEADER_COUNT=4 \
-		git rebase -i $base &&
+	(
+		set_fake_editor &&
+		FAKE_COMMIT_AMEND="ONCE" \
+			FAKE_LINES="> 1 > squash 2 > squash 3 > squash 4 >" \
+			EXPECT_HEADER_COUNT=4 \
+			git rebase -i $base
+	) &&
 	test $base = $(git rev-parse HEAD^) &&
 	test 1 = $(git show | grep ONCE | wc -l) &&
-	git checkout to-be-rebased &&
+	git checkout @{-1} &&
 	git branch -D skip-blank-lines
 '
 
 test_expect_success 'squash works as expected' '
 	git checkout -b squash-works no-conflict-branch &&
 	one=$(git rev-parse HEAD~3) &&
-	set_fake_editor &&
-	FAKE_LINES="1 squash 3 2" EXPECT_HEADER_COUNT=2 \
-		git rebase -i HEAD~3 &&
+	(
+		set_fake_editor &&
+		FAKE_LINES="1 s 3 2" EXPECT_HEADER_COUNT=2 git rebase -i HEAD~3
+	) &&
 	test $one = $(git rev-parse HEAD~2)
 '
 
 test_expect_success 'interrupted squash works as expected' '
 	git checkout -b interrupted-squash conflict-branch &&
 	one=$(git rev-parse HEAD~3) &&
-	set_fake_editor &&
-	test_must_fail env FAKE_LINES="1 squash 3 2" git rebase -i HEAD~3 &&
-	(echo one; echo two; echo four) > conflict &&
+	(
+		set_fake_editor &&
+		test_must_fail env FAKE_LINES="1 squash 3 2" \
+			git rebase -i HEAD~3
+	) &&
+	test_write_lines one two four > conflict &&
 	git add conflict &&
 	test_must_fail git rebase --continue &&
 	echo resolved > conflict &&
@@ -521,12 +598,15 @@ test_expect_success 'interrupted squash
 test_expect_success 'interrupted squash works as expected (case 2)' '
 	git checkout -b interrupted-squash2 conflict-branch &&
 	one=$(git rev-parse HEAD~3) &&
-	set_fake_editor &&
-	test_must_fail env FAKE_LINES="3 squash 1 2" git rebase -i HEAD~3 &&
-	(echo one; echo four) > conflict &&
+	(
+		set_fake_editor &&
+		test_must_fail env FAKE_LINES="3 squash 1 2" \
+			git rebase -i HEAD~3
+	) &&
+	test_write_lines one four > conflict &&
 	git add conflict &&
 	test_must_fail git rebase --continue &&
-	(echo one; echo two; echo four) > conflict &&
+	test_write_lines one two four > conflict &&
 	git add conflict &&
 	test_must_fail git rebase --continue &&
 	echo resolved > conflict &&
@@ -542,11 +622,13 @@ test_expect_success '--continue tries to
 	git commit -m "unrelated change" &&
 	parent=$(git rev-parse HEAD^) &&
 	test_tick &&
-	set_fake_editor &&
-	FAKE_LINES="edit 1" git rebase -i HEAD^ &&
-	echo edited > file7 &&
-	git add file7 &&
-	FAKE_COMMIT_MESSAGE="chouette!" git rebase --continue &&
+	(
+		set_fake_editor &&
+		FAKE_LINES="edit 1" git rebase -i HEAD^ &&
+		echo edited > file7 &&
+		git add file7 &&
+		FAKE_COMMIT_MESSAGE="chouette!" git rebase --continue
+	) &&
 	test edited = $(git show HEAD:file7) &&
 	git show HEAD | grep chouette &&
 	test $parent = $(git rev-parse HEAD^)
@@ -555,34 +637,41 @@ test_expect_success '--continue tries to
 test_expect_success 'aborted --continue does not squash commits after "edit"' '
 	old=$(git rev-parse HEAD) &&
 	test_tick &&
-	set_fake_editor &&
-	FAKE_LINES="edit 1" git rebase -i HEAD^ &&
-	echo "edited again" > file7 &&
-	git add file7 &&
-	test_must_fail env FAKE_COMMIT_MESSAGE=" " git rebase --continue &&
+	(
+		set_fake_editor &&
+		FAKE_LINES="edit 1" git rebase -i HEAD^ &&
+		echo "edited again" > file7 &&
+		git add file7 &&
+		test_must_fail env FAKE_COMMIT_MESSAGE=" " git rebase --continue
+	) &&
 	test $old = $(git rev-parse HEAD) &&
 	git rebase --abort
 '
 
 test_expect_success 'auto-amend only edited commits after "edit"' '
 	test_tick &&
-	set_fake_editor &&
-	FAKE_LINES="edit 1" git rebase -i HEAD^ &&
-	echo "edited again" > file7 &&
-	git add file7 &&
-	FAKE_COMMIT_MESSAGE="edited file7 again" git commit &&
-	echo "and again" > file7 &&
-	git add file7 &&
-	test_tick &&
-	test_must_fail env FAKE_COMMIT_MESSAGE="and again" git rebase --continue &&
+	(
+		set_fake_editor &&
+		FAKE_LINES="edit 1" git rebase -i HEAD^ &&
+		echo "edited again" > file7 &&
+		git add file7 &&
+		FAKE_COMMIT_MESSAGE="edited file7 again" git commit &&
+		echo "and again" > file7 &&
+		git add file7 &&
+		test_tick &&
+		test_must_fail env FAKE_COMMIT_MESSAGE="and again" \
+			git rebase --continue
+	) &&
 	git rebase --abort
 '
 
 test_expect_success 'clean error after failed "exec"' '
 	test_tick &&
 	test_when_finished "git rebase --abort || :" &&
-	set_fake_editor &&
-	test_must_fail env FAKE_LINES="1 exec_false" git rebase -i HEAD^ &&
+	(
+		set_fake_editor &&
+		test_must_fail env FAKE_LINES="1 exec_false" git rebase -i HEAD^
+	) &&
 	echo "edited again" > file7 &&
 	git add file7 &&
 	test_must_fail git rebase --continue 2>error &&
@@ -593,8 +682,10 @@ test_expect_success 'rebase a detached H
 	grandparent=$(git rev-parse HEAD~2) &&
 	git checkout $(git rev-parse HEAD) &&
 	test_tick &&
-	set_fake_editor &&
-	FAKE_LINES="2 1" git rebase -i HEAD~2 &&
+	(
+		set_fake_editor &&
+		FAKE_LINES="2 1" git rebase -i HEAD~2
+	) &&
 	test $grandparent = $(git rev-parse HEAD~2)
 '
 
@@ -609,9 +700,10 @@ test_expect_success 'rebase a commit vio
 	test_must_fail git commit -m doesnt-verify file1 &&
 	git commit -m doesnt-verify --no-verify file1 &&
 	test_tick &&
-	set_fake_editor &&
-	FAKE_LINES=2 git rebase -i HEAD~2
-
+	(
+		set_fake_editor &&
+		FAKE_LINES=2 git rebase -i HEAD~2
+	)
 '
 
 test_expect_success 'rebase with a file named HEAD in worktree' '
@@ -631,8 +723,10 @@ test_expect_success 'rebase with a file
 		git commit -m "Add body"
 	) &&
 
-	set_fake_editor &&
-	FAKE_LINES="1 squash 2" git rebase -i to-be-rebased &&
+	(
+		set_fake_editor &&
+		FAKE_LINES="1 squash 2" git rebase -i @{-1}
+	) &&
 	test "$(git show -s --pretty=format:%an)" = "Squashed Away"
 
 '
@@ -643,7 +737,6 @@ test_expect_success 'do "noop" when ther
 	GIT_EDITOR=: git commit --amend \
 		--author="Somebody else <somebody@else.com>" &&
 	test $(git rev-parse branch3) != $(git rev-parse branch4) &&
-	set_fake_editor &&
 	git rebase -i branch3 &&
 	test $(git rev-parse branch3) = $(git rev-parse branch4)
 
@@ -668,13 +761,14 @@ test_expect_success 'submodule rebase se
 		git commit -a -m "submodule second"
 	) &&
 	test_tick &&
-	set_fake_editor &&
 	git commit -a -m "Three changes submodule"
 '
 
 test_expect_success 'submodule rebase -i' '
-	set_fake_editor &&
-	FAKE_LINES="1 squash 2 3" git rebase -i A
+	(
+		set_fake_editor &&
+		FAKE_LINES="1 squash 2 3" git rebase -i A
+	)
 '
 
 test_expect_success 'submodule conflict setup' '
@@ -691,7 +785,6 @@ test_expect_success 'submodule conflict
 '
 
 test_expect_success 'rebase -i continue with only submodule staged' '
-	set_fake_editor &&
 	test_must_fail git rebase -i submodule-base &&
 	git add sub &&
 	git rebase --continue &&
@@ -701,7 +794,6 @@ test_expect_success 'rebase -i continue
 test_expect_success 'rebase -i continue with unstaged submodule' '
 	git checkout submodule-topic &&
 	git reset --hard &&
-	set_fake_editor &&
 	test_must_fail git rebase -i submodule-base &&
 	git reset &&
 	git rebase --continue &&
@@ -714,7 +806,6 @@ test_expect_success 'avoid unnecessary r
 	test-tool chmtime =123456789 file3 &&
 	git update-index --refresh &&
 	HEAD=$(git rev-parse HEAD) &&
-	set_fake_editor &&
 	git rebase -i HEAD~4 &&
 	test $HEAD = $(git rev-parse HEAD) &&
 	MTIME=$(test-tool chmtime --get file3) &&
@@ -723,16 +814,22 @@ test_expect_success 'avoid unnecessary r
 
 test_expect_success 'reword' '
 	git checkout -b reword-branch master &&
-	set_fake_editor &&
-	FAKE_LINES="1 2 3 reword 4" FAKE_COMMIT_MESSAGE="E changed" git rebase -i A &&
-	git show HEAD | grep "E changed" &&
-	test $(git rev-parse master) != $(git rev-parse HEAD) &&
-	test $(git rev-parse master^) = $(git rev-parse HEAD^) &&
-	FAKE_LINES="1 2 reword 3 4" FAKE_COMMIT_MESSAGE="D changed" git rebase -i A &&
-	git show HEAD^ | grep "D changed" &&
-	FAKE_LINES="reword 1 2 3 4" FAKE_COMMIT_MESSAGE="B changed" git rebase -i A &&
-	git show HEAD~3 | grep "B changed" &&
-	FAKE_LINES="1 reword 2 3 4" FAKE_COMMIT_MESSAGE="C changed" git rebase -i A &&
+	(
+		set_fake_editor &&
+		FAKE_LINES="1 2 3 reword 4" FAKE_COMMIT_MESSAGE="E changed" \
+			git rebase -i A &&
+		git show HEAD | grep "E changed" &&
+		test $(git rev-parse master) != $(git rev-parse HEAD) &&
+		test $(git rev-parse master^) = $(git rev-parse HEAD^) &&
+		FAKE_LINES="1 2 reword 3 4" FAKE_COMMIT_MESSAGE="D changed" \
+			git rebase -i A &&
+		git show HEAD^ | grep "D changed" &&
+		FAKE_LINES="reword 1 2 3 4" FAKE_COMMIT_MESSAGE="B changed" \
+			git rebase -i A &&
+		git show HEAD~3 | grep "B changed" &&
+		FAKE_LINES="1 r 2 pick 3 p 4" FAKE_COMMIT_MESSAGE="C changed" \
+			git rebase -i A
+	) &&
 	git show HEAD~2 | grep "C changed"
 '
 
@@ -743,22 +840,23 @@ test_expect_success 'rebase -i can copy
 	test_commit n2 &&
 	test_commit n3 &&
 	git notes add -m"a note" n3 &&
-	set_fake_editor &&
 	git rebase -i --onto n1 n2 &&
 	test "a note" = "$(git notes show HEAD)"
 '
 
-cat >expect <<EOF
-an earlier note
-
-a note
-EOF
-
 test_expect_success 'rebase -i can copy notes over a fixup' '
+	cat >expect <<-\EOF &&
+	an earlier note
+
+	a note
+	EOF
 	git reset --hard n3 &&
 	git notes add -m"an earlier note" n2 &&
-	set_fake_editor &&
-	GIT_NOTES_REWRITE_MODE=concatenate FAKE_LINES="1 fixup 2" git rebase -i n1 &&
+	(
+		set_fake_editor &&
+		GIT_NOTES_REWRITE_MODE=concatenate FAKE_LINES="1 f 2" \
+			git rebase -i n1
+	) &&
 	git notes show > output &&
 	test_cmp expect output
 '
@@ -767,8 +865,10 @@ test_expect_success 'rebase while detach
 	git symbolic-ref HEAD &&
 	grandparent=$(git rev-parse HEAD~2) &&
 	test_tick &&
-	set_fake_editor &&
-	FAKE_LINES="2 1" git rebase -i HEAD~2 HEAD^0 &&
+	(
+		set_fake_editor &&
+		FAKE_LINES="2 1" git rebase -i HEAD~2 HEAD^0
+	) &&
 	test $grandparent = $(git rev-parse HEAD~2) &&
 	test_must_fail git symbolic-ref HEAD
 '
@@ -777,18 +877,16 @@ test_tick # Ensure that the rebased comm
 test_expect_success 'always cherry-pick with --no-ff' '
 	git checkout no-ff-branch &&
 	git tag original-no-ff-branch &&
-	set_fake_editor &&
 	git rebase -i --no-ff A &&
-	touch empty &&
 	for p in 0 1 2
 	do
 		test ! $(git rev-parse HEAD~$p) = $(git rev-parse original-no-ff-branch~$p) &&
 		git diff HEAD~$p original-no-ff-branch~$p > out &&
-		test_cmp empty out
+		test_must_be_empty out
 	done &&
 	test $(git rev-parse HEAD~3) = $(git rev-parse original-no-ff-branch~3) &&
 	git diff HEAD~3 original-no-ff-branch~3 > out &&
-	test_cmp empty out
+	test_must_be_empty out
 '
 
 test_expect_success 'set up commits with funny messages' '
@@ -810,8 +908,10 @@ test_expect_success 'set up commits with
 test_expect_success 'rebase-i history with funny messages' '
 	git rev-list A..funny >expect &&
 	test_tick &&
-	set_fake_editor &&
-	FAKE_LINES="1 2 3 4" git rebase -i A &&
+	(
+		set_fake_editor &&
+		FAKE_LINES="1 2 3 4" git rebase -i A
+	) &&
 	git rev-list A.. >actual &&
 	test_cmp expect actual
 '
@@ -825,9 +925,9 @@ test_expect_success 'prepare for rebase
 '
 
 test_expect_success 'running "git rebase -i --exec git show HEAD"' '
-	set_fake_editor &&
-	git rebase -i --exec "git show HEAD" HEAD~2 >actual &&
 	(
+		set_fake_editor &&
+		git rebase -i --exec "git show HEAD" HEAD~2 >actual &&
 		FAKE_LINES="1 exec_git_show_HEAD 2 exec_git_show_HEAD" &&
 		export FAKE_LINES &&
 		git rebase -i HEAD~2 >expect
@@ -838,9 +938,9 @@ test_expect_success 'running "git rebase
 
 test_expect_success 'running "git rebase --exec git show HEAD -i"' '
 	git reset --hard execute &&
-	set_fake_editor &&
-	git rebase --exec "git show HEAD" -i HEAD~2 >actual &&
 	(
+		set_fake_editor &&
+		git rebase --exec "git show HEAD" -i HEAD~2 >actual &&
 		FAKE_LINES="1 exec_git_show_HEAD 2 exec_git_show_HEAD" &&
 		export FAKE_LINES &&
 		git rebase -i HEAD~2 >expect
@@ -851,9 +951,9 @@ test_expect_success 'running "git rebase
 
 test_expect_success 'running "git rebase -ix git show HEAD"' '
 	git reset --hard execute &&
-	set_fake_editor &&
-	git rebase -ix "git show HEAD" HEAD~2 >actual &&
 	(
+		set_fake_editor &&
+		git rebase -ix "git show HEAD" HEAD~2 >actual &&
 		FAKE_LINES="1 exec_git_show_HEAD 2 exec_git_show_HEAD" &&
 		export FAKE_LINES &&
 		git rebase -i HEAD~2 >expect
@@ -865,9 +965,9 @@ test_expect_success 'running "git rebase
 
 test_expect_success 'rebase -ix with several <CMD>' '
 	git reset --hard execute &&
-	set_fake_editor &&
-	git rebase -ix "git show HEAD; pwd" HEAD~2 >actual &&
 	(
+		set_fake_editor &&
+		git rebase -ix "git show HEAD; pwd" HEAD~2 >actual &&
 		FAKE_LINES="1 exec_git_show_HEAD;_pwd 2 exec_git_show_HEAD;_pwd" &&
 		export FAKE_LINES &&
 		git rebase -i HEAD~2 >expect
@@ -878,9 +978,9 @@ test_expect_success 'rebase -ix with sev
 
 test_expect_success 'rebase -ix with several instances of --exec' '
 	git reset --hard execute &&
-	set_fake_editor &&
-	git rebase -i --exec "git show HEAD" --exec "pwd" HEAD~2 >actual &&
 	(
+		set_fake_editor &&
+		git rebase -i --exec "git show HEAD" --exec "pwd" HEAD~2 >actual &&
 		FAKE_LINES="1 exec_git_show_HEAD exec_pwd 2
 				exec_git_show_HEAD exec_pwd" &&
 		export FAKE_LINES &&
@@ -899,13 +999,11 @@ test_expect_success C_LOCALE_OUTPUT 'reb
 	echo bis >bis.txt &&
 	git add bis.txt &&
 	git commit -m "fixup! two_exec" &&
-	set_fake_editor &&
-	(
-		git checkout -b autosquash_actual &&
-		git rebase -i --exec "git show HEAD" --autosquash HEAD~4 >actual
-	) &&
+	git checkout -b autosquash_actual &&
+	git rebase -i --exec "git show HEAD" --autosquash HEAD~4 >actual &&
 	git checkout autosquash &&
 	(
+		set_fake_editor &&
 		git checkout -b autosquash_expected &&
 		FAKE_LINES="1 fixup 3 fixup 4 exec_git_show_HEAD 2 exec_git_show_HEAD" &&
 		export FAKE_LINES &&
@@ -926,7 +1024,6 @@ test_expect_success 'rebase --exec works
 
 test_expect_success 'rebase -i --exec without <CMD>' '
 	git reset --hard execute &&
-	set_fake_editor &&
 	test_must_fail git rebase -i --exec 2>actual &&
 	test_i18ngrep "requires a value" actual &&
 	git checkout master
@@ -934,8 +1031,10 @@ test_expect_success 'rebase -i --exec wi
 
 test_expect_success 'rebase -i --root re-order and drop commits' '
 	git checkout E &&
-	set_fake_editor &&
-	FAKE_LINES="3 1 2 5" git rebase -i --root &&
+	(
+		set_fake_editor &&
+		FAKE_LINES="3 1 2 5" git rebase -i --root
+	) &&
 	test E = $(git cat-file commit HEAD | sed -ne \$p) &&
 	test B = $(git cat-file commit HEAD^ | sed -ne \$p) &&
 	test A = $(git cat-file commit HEAD^^ | sed -ne \$p) &&
@@ -948,55 +1047,111 @@ test_expect_success 'rebase -i --root re
 	echo B >file7 &&
 	git add file7 &&
 	GIT_AUTHOR_NAME="Twerp Snog" git commit -m "different author" &&
-	set_fake_editor &&
-	FAKE_LINES="2" git rebase -i --root &&
+	(
+		set_fake_editor &&
+		FAKE_LINES="2" git rebase -i --root
+	) &&
 	git cat-file commit HEAD | grep -q "^author Twerp Snog" &&
 	git cat-file commit HEAD | grep -q "^different author$"
 '
 
 test_expect_success 'rebase -i --root temporary sentinel commit' '
 	git checkout B &&
-	set_fake_editor &&
-	test_must_fail env FAKE_LINES="2" git rebase -i --root &&
-	git cat-file commit HEAD | grep "^tree 4b825dc642cb" &&
+	(
+		set_fake_editor &&
+		test_must_fail env FAKE_LINES="2" git rebase -i --root
+	) &&
+	git cat-file commit HEAD | grep "^tree $EMPTY_TREE" &&
 	git rebase --abort
 '
 
 test_expect_success 'rebase -i --root fixup root commit' '
 	git checkout B &&
-	set_fake_editor &&
-	FAKE_LINES="1 fixup 2" git rebase -i --root &&
+	(
+		set_fake_editor &&
+		FAKE_LINES="1 fixup 2" git rebase -i --root
+	) &&
 	test A = $(git cat-file commit HEAD | sed -ne \$p) &&
 	test B = $(git show HEAD:file1) &&
 	test 0 = $(git cat-file commit HEAD | grep -c ^parent\ )
 '
 
-test_expect_success 'rebase -i --root reword root commit' '
+test_expect_success 'rebase -i --root reword original root commit' '
 	test_when_finished "test_might_fail git rebase --abort" &&
-	git checkout -b reword-root-branch master &&
-	set_fake_editor &&
-	FAKE_LINES="reword 1 2" FAKE_COMMIT_MESSAGE="A changed" \
-	git rebase -i --root &&
+	git checkout -b reword-original-root-branch master &&
+	(
+		set_fake_editor &&
+		FAKE_LINES="reword 1 2" FAKE_COMMIT_MESSAGE="A changed" \
+			git rebase -i --root
+	) &&
 	git show HEAD^ | grep "A changed" &&
 	test -z "$(git show -s --format=%p HEAD^)"
 '
 
+test_expect_success 'rebase -i --root reword new root commit' '
+	test_when_finished "test_might_fail git rebase --abort" &&
+	git checkout -b reword-now-root-branch master &&
+	(
+		set_fake_editor &&
+		FAKE_LINES="reword 3 1" FAKE_COMMIT_MESSAGE="C changed" \
+		git rebase -i --root
+	) &&
+	git show HEAD^ | grep "C changed" &&
+	test -z "$(git show -s --format=%p HEAD^)"
+'
+
+test_expect_success 'rebase -i --root when root has untracked file conflict' '
+	test_when_finished "reset_rebase" &&
+	git checkout -b failing-root-pick A &&
+	echo x >file2 &&
+	git rm file1 &&
+	git commit -m "remove file 1 add file 2" &&
+	echo z >file1 &&
+	(
+		set_fake_editor &&
+		test_must_fail env FAKE_LINES="1 2" git rebase -i --root
+	) &&
+	rm file1 &&
+	git rebase --continue &&
+	test "$(git log -1 --format=%B)" = "remove file 1 add file 2" &&
+	test "$(git rev-list --count HEAD)" = 2
+'
+
+test_expect_success 'rebase -i --root reword root when root has untracked file conflict' '
+	test_when_finished "reset_rebase" &&
+	echo z>file1 &&
+	(
+		set_fake_editor &&
+		test_must_fail env FAKE_LINES="reword 1 2" \
+			FAKE_COMMIT_MESSAGE="Modified A" git rebase -i --root &&
+		rm file1 &&
+		FAKE_COMMIT_MESSAGE="Reworded A" git rebase --continue
+	) &&
+	test "$(git log -1 --format=%B HEAD^)" = "Reworded A" &&
+	test "$(git rev-list --count HEAD)" = 2
+'
+
 test_expect_success C_LOCALE_OUTPUT 'rebase --edit-todo does not work on non-interactive rebase' '
+	git checkout reword-original-root-branch &&
 	git reset --hard &&
 	git checkout conflict-branch &&
-	set_fake_editor &&
-	test_must_fail git rebase --onto HEAD~2 HEAD~ &&
-	test_must_fail git rebase --edit-todo &&
+	(
+		set_fake_editor &&
+		test_must_fail git rebase -f --onto HEAD~2 HEAD~ &&
+		test_must_fail git rebase --edit-todo
+	) &&
 	git rebase --abort
 '
 
 test_expect_success 'rebase --edit-todo can be used to modify todo' '
 	git reset --hard &&
 	git checkout no-conflict-branch^0 &&
-	set_fake_editor &&
-	FAKE_LINES="edit 1 2 3" git rebase -i HEAD~3 &&
-	FAKE_LINES="2 1" git rebase --edit-todo &&
-	git rebase --continue &&
+	(
+		set_fake_editor &&
+		FAKE_LINES="edit 1 2 3" git rebase -i HEAD~3 &&
+		FAKE_LINES="2 1" git rebase --edit-todo &&
+		git rebase --continue
+	) &&
 	test M = $(git cat-file commit HEAD^ | sed -ne \$p) &&
 	test L = $(git cat-file commit HEAD | sed -ne \$p)
 '
@@ -1004,7 +1159,6 @@ test_expect_success 'rebase --edit-todo
 test_expect_success 'rebase -i produces readable reflog' '
 	git reset --hard &&
 	git branch -f branch-reflog-test H &&
-	set_fake_editor &&
 	git rebase -i --onto I F branch-reflog-test &&
 	cat >expect <<-\EOF &&
 	rebase -i (finish): returning to refs/heads/branch-reflog-test
@@ -1025,8 +1179,10 @@ test_expect_success 'rebase -i respects
 	sed -e "2,\$s/^/\\\\/" "$1" >"$1.tmp" &&
 	mv "$1.tmp" "$1"
 	EOF
-	test_set_editor "$(pwd)/remove-all-but-first.sh" &&
-	git rebase -i B &&
+	(
+		test_set_editor "$(pwd)/remove-all-but-first.sh" &&
+		git rebase -i B
+	) &&
 	test B = $(git cat-file commit HEAD^ | sed -ne \$p)
 '
 
@@ -1035,9 +1191,11 @@ test_expect_success 'rebase -i respects
 	write_script copy-edit-script.sh <<-\EOF &&
 	cp "$1" edit-script
 	EOF
-	test_set_editor "$(pwd)/copy-edit-script.sh" &&
 	test_when_finished "git rebase --abort || :" &&
-	git rebase -i HEAD^ &&
+	(
+		test_set_editor "$(pwd)/copy-edit-script.sh" &&
+		git rebase -i HEAD^
+	) &&
 	test -z "$(grep -ve "^#" -e "^\$" -e "^pick" edit-script)"
 '
 
@@ -1072,8 +1230,11 @@ test_expect_success 'interrupted rebase
 	echo five >conflict &&
 	echo Z >file1 &&
 	git commit -a -m "one file conflict" &&
-	set_fake_editor &&
-	FAKE_LINES="edit 1 2" git rebase -i --strategy=recursive -Xours conflict-branch &&
+	(
+		set_fake_editor &&
+		FAKE_LINES="edit 1 2" git rebase -i --strategy=recursive \
+			-Xours conflict-branch
+	) &&
 	git rebase --continue &&
 	test $(git show conflict-branch:conflict) = $(cat conflict) &&
 	test $(cat file1) = Z
@@ -1088,7 +1249,7 @@ test_expect_success 'rebase -i error on
 	test_expect_code 1 grep  "	emp" error
 '
 
-test_expect_success 'short SHA-1 setup' '
+test_expect_success SHA1 'short SHA-1 setup' '
 	test_when_finished "git checkout master" &&
 	git checkout --orphan collide &&
 	git rm -rf . &&
@@ -1100,22 +1261,24 @@ test_expect_success 'short SHA-1 setup'
 	)
 '
 
-test_expect_success 'short SHA-1 collide' '
+test_expect_success SHA1 'short SHA-1 collide' '
 	test_when_finished "reset_rebase && git checkout master" &&
 	git checkout collide &&
 	(
-	unset test_tick &&
-	test_tick &&
-	set_fake_editor &&
-	FAKE_COMMIT_MESSAGE="collide2 ac4f2ee" \
-	FAKE_LINES="reword 1 2" git rebase -i HEAD~2
+		unset test_tick &&
+		test_tick &&
+		set_fake_editor &&
+		FAKE_COMMIT_MESSAGE="collide2 ac4f2ee" \
+		FAKE_LINES="reword 1 2" git rebase -i HEAD~2
 	)
 '
 
 test_expect_success 'respect core.abbrev' '
 	git config core.abbrev 12 &&
-	set_cat_todo_editor &&
-	test_must_fail git rebase -i HEAD~4 >todo-list &&
+	(
+		set_cat_todo_editor &&
+		test_must_fail git rebase -i HEAD~4 >todo-list
+	) &&
 	test 4 = $(grep -c "pick [0-9a-f]\{12,\}" todo-list)
 '
 
@@ -1123,16 +1286,20 @@ test_expect_success 'todo count' '
 	write_script dump-raw.sh <<-\EOF &&
 		cat "$1"
 	EOF
-	test_set_editor "$(pwd)/dump-raw.sh" &&
-	git rebase -i HEAD~4 >actual &&
+	(
+		test_set_editor "$(pwd)/dump-raw.sh" &&
+		git rebase -i HEAD~4 >actual
+	) &&
 	test_i18ngrep "^# Rebase ..* onto ..* ([0-9]" actual
 '
 
 test_expect_success 'rebase -i commits that overwrite untracked files (pick)' '
 	git checkout --force branch2 &&
 	git clean -f &&
-	set_fake_editor &&
-	FAKE_LINES="edit 1 2" git rebase -i A &&
+	(
+		set_fake_editor &&
+		FAKE_LINES="edit 1 2" git rebase -i A
+	) &&
 	test_cmp_rev HEAD F &&
 	test_path_is_missing file6 &&
 	>file6 &&
@@ -1147,8 +1314,10 @@ test_expect_success 'rebase -i commits t
 	git checkout --force branch2 &&
 	git clean -f &&
 	git tag original-branch2 &&
-	set_fake_editor &&
-	FAKE_LINES="edit 1 squash 2" git rebase -i A &&
+	(
+		set_fake_editor &&
+		FAKE_LINES="edit 1 squash 2" git rebase -i A
+	) &&
 	test_cmp_rev HEAD F &&
 	test_path_is_missing file6 &&
 	>file6 &&
@@ -1163,8 +1332,10 @@ test_expect_success 'rebase -i commits t
 test_expect_success 'rebase -i commits that overwrite untracked files (no ff)' '
 	git checkout --force branch2 &&
 	git clean -f &&
-	set_fake_editor &&
-	FAKE_LINES="edit 1 2" git rebase -i --no-ff A &&
+	(
+		set_fake_editor &&
+		FAKE_LINES="edit 1 2" git rebase -i --no-ff A
+	) &&
 	test $(git cat-file commit HEAD | sed -ne \$p) = F &&
 	test_path_is_missing file6 &&
 	>file6 &&
@@ -1187,8 +1358,10 @@ test_expect_success 'rebase --continue r
 	git tag seq-onto &&
 	git reset --hard HEAD~2 &&
 	git cherry-pick seq-onto &&
-	set_fake_editor &&
-	test_must_fail env FAKE_LINES= git rebase -i seq-onto &&
+	(
+		set_fake_editor &&
+		test_must_fail env FAKE_LINES= git rebase -i seq-onto
+	) &&
 	test -d .git/rebase-merge &&
 	git rebase --continue &&
 	git diff --exit-code seq-onto &&
@@ -1202,13 +1375,15 @@ rebase_setup_and_clean () {
 		test_might_fail git branch -D $1 &&
 		test_might_fail git rebase --abort
 	" &&
-	git checkout -b $1 master
+	git checkout -b $1 ${2:-master}
 }
 
 test_expect_success 'drop' '
 	rebase_setup_and_clean drop-test &&
-	set_fake_editor &&
-	FAKE_LINES="1 drop 2 3 drop 4 5" git rebase -i --root &&
+	(
+		set_fake_editor &&
+		FAKE_LINES="1 drop 2 3 d 4 5" git rebase -i --root
+	) &&
 	test E = $(git cat-file commit HEAD | sed -ne \$p) &&
 	test C = $(git cat-file commit HEAD^ | sed -ne \$p) &&
 	test A = $(git cat-file commit HEAD^^ | sed -ne \$p)
@@ -1217,71 +1392,59 @@ test_expect_success 'drop' '
 test_expect_success 'rebase -i respects rebase.missingCommitsCheck = ignore' '
 	test_config rebase.missingCommitsCheck ignore &&
 	rebase_setup_and_clean missing-commit &&
-	set_fake_editor &&
-	FAKE_LINES="1 2 3 4" \
-		git rebase -i --root 2>actual &&
+	(
+		set_fake_editor &&
+		FAKE_LINES="1 2 3 4" git rebase -i --root 2>actual
+	) &&
 	test D = $(git cat-file commit HEAD | sed -ne \$p) &&
 	test_i18ngrep \
 		"Successfully rebased and updated refs/heads/missing-commit" \
 		actual
 '
 
-cat >expect <<EOF
-Warning: some commits may have been dropped accidentally.
-Dropped commits (newer to older):
- - $(git rev-list --pretty=oneline --abbrev-commit -1 master)
-To avoid this message, use "drop" to explicitly remove a commit.
-
-Use 'git config rebase.missingCommitsCheck' to change the level of warnings.
-The possible behaviours are: ignore, warn, error.
-
-Rebasing (1/4)
-Rebasing (2/4)
-Rebasing (3/4)
-Rebasing (4/4)
-Successfully rebased and updated refs/heads/missing-commit.
-EOF
-
-cr_to_nl () {
-	tr '\015' '\012'
-}
-
 test_expect_success 'rebase -i respects rebase.missingCommitsCheck = warn' '
+	cat >expect <<-EOF &&
+	Warning: some commits may have been dropped accidentally.
+	Dropped commits (newer to older):
+	 - $(git rev-list --pretty=oneline --abbrev-commit -1 master)
+	To avoid this message, use "drop" to explicitly remove a commit.
+	EOF
 	test_config rebase.missingCommitsCheck warn &&
 	rebase_setup_and_clean missing-commit &&
-	set_fake_editor &&
-	FAKE_LINES="1 2 3 4" \
-		git rebase -i --root 2>actual.2 &&
-	cr_to_nl <actual.2 >actual &&
+	(
+		set_fake_editor &&
+		FAKE_LINES="1 2 3 4" git rebase -i --root 2>actual.2
+	) &&
+	head -n4 actual.2 >actual &&
 	test_i18ncmp expect actual &&
 	test D = $(git cat-file commit HEAD | sed -ne \$p)
 '
 
-cat >expect <<EOF
-Warning: some commits may have been dropped accidentally.
-Dropped commits (newer to older):
- - $(git rev-list --pretty=oneline --abbrev-commit -1 master)
- - $(git rev-list --pretty=oneline --abbrev-commit -1 master~2)
-To avoid this message, use "drop" to explicitly remove a commit.
-
-Use 'git config rebase.missingCommitsCheck' to change the level of warnings.
-The possible behaviours are: ignore, warn, error.
-
-You can fix this with 'git rebase --edit-todo' and then run 'git rebase --continue'.
-Or you can abort the rebase with 'git rebase --abort'.
-EOF
-
 test_expect_success 'rebase -i respects rebase.missingCommitsCheck = error' '
+	cat >expect <<-EOF &&
+	Warning: some commits may have been dropped accidentally.
+	Dropped commits (newer to older):
+	 - $(git rev-list --pretty=oneline --abbrev-commit -1 master)
+	 - $(git rev-list --pretty=oneline --abbrev-commit -1 master~2)
+	To avoid this message, use "drop" to explicitly remove a commit.
+
+	Use '\''git config rebase.missingCommitsCheck'\'' to change the level of warnings.
+	The possible behaviours are: ignore, warn, error.
+
+	You can fix this with '\''git rebase --edit-todo'\'' and then run '\''git rebase --continue'\''.
+	Or you can abort the rebase with '\''git rebase --abort'\''.
+	EOF
 	test_config rebase.missingCommitsCheck error &&
 	rebase_setup_and_clean missing-commit &&
-	set_fake_editor &&
-	test_must_fail env FAKE_LINES="1 2 4" \
-		git rebase -i --root 2>actual &&
-	test_i18ncmp expect actual &&
-	cp .git/rebase-merge/git-rebase-todo.backup \
-		.git/rebase-merge/git-rebase-todo &&
-	FAKE_LINES="1 2 drop 3 4 drop 5" \
-		git rebase --edit-todo &&
+	(
+		set_fake_editor &&
+		test_must_fail env FAKE_LINES="1 2 4" \
+			git rebase -i --root 2>actual &&
+		test_i18ncmp expect actual &&
+		cp .git/rebase-merge/git-rebase-todo.backup \
+			.git/rebase-merge/git-rebase-todo &&
+		FAKE_LINES="1 2 drop 3 4 drop 5" git rebase --edit-todo
+	) &&
 	git rebase --continue &&
 	test D = $(git cat-file commit HEAD | sed -ne \$p) &&
 	test B = $(git cat-file commit HEAD^ | sed -ne \$p)
@@ -1302,21 +1465,27 @@ test_expect_success 'respects rebase.abb
 	x git show HEAD
 	EOF
 	git checkout abbrevcmd &&
-	set_cat_todo_editor &&
 	test_config rebase.abbreviateCommands true &&
-	test_must_fail git rebase -i --exec "git show HEAD" \
-		--autosquash master >actual &&
+	(
+		set_cat_todo_editor &&
+		test_must_fail git rebase -i --exec "git show HEAD" \
+			--autosquash master >actual
+	) &&
 	test_cmp expected actual
 '
 
 test_expect_success 'static check of bad command' '
 	rebase_setup_and_clean bad-cmd &&
-	set_fake_editor &&
-	test_must_fail env FAKE_LINES="1 2 3 bad 4 5" \
+	(
+		set_fake_editor &&
+		test_must_fail env FAKE_LINES="1 2 3 bad 4 5" \
 		git rebase -i --root 2>actual &&
-	test_i18ngrep "badcmd $(git rev-list --oneline -1 master~1)" actual &&
-	test_i18ngrep "You can fix this with .git rebase --edit-todo.." actual &&
-	FAKE_LINES="1 2 3 drop 4 5" git rebase --edit-todo &&
+		test_i18ngrep "badcmd $(git rev-list --oneline -1 master~1)" \
+				actual &&
+		test_i18ngrep "You can fix this with .git rebase --edit-todo.." \
+				actual &&
+		FAKE_LINES="1 2 3 drop 4 5" git rebase --edit-todo
+	) &&
 	git rebase --continue &&
 	test E = $(git cat-file commit HEAD | sed -ne \$p) &&
 	test C = $(git cat-file commit HEAD^ | sed -ne \$p)
@@ -1332,19 +1501,24 @@ test_expect_success 'tabs and spaces are
 	) >"$1.new"
 	mv "$1.new" "$1"
 	EOF
-	test_set_editor "$(pwd)/add-indent.sh" &&
-	git rebase -i HEAD^^^ &&
+	(
+		test_set_editor "$(pwd)/add-indent.sh" &&
+		git rebase -i HEAD^^^
+	) &&
 	test E = $(git cat-file commit HEAD | sed -ne \$p)
 '
 
 test_expect_success 'static check of bad SHA-1' '
 	rebase_setup_and_clean bad-sha &&
-	set_fake_editor &&
-	test_must_fail env FAKE_LINES="1 2 edit fakesha 3 4 5 #" \
-		git rebase -i --root 2>actual &&
-	test_i18ngrep "edit XXXXXXX False commit" actual &&
-	test_i18ngrep "You can fix this with .git rebase --edit-todo.." actual &&
-	FAKE_LINES="1 2 4 5 6" git rebase --edit-todo &&
+	(
+		set_fake_editor &&
+		test_must_fail env FAKE_LINES="1 2 edit fakesha 3 4 5 #" \
+			git rebase -i --root 2>actual &&
+			test_i18ngrep "edit XXXXXXX False commit" actual &&
+			test_i18ngrep "You can fix this with .git rebase --edit-todo.." \
+					actual &&
+		FAKE_LINES="1 2 4 5 6" git rebase --edit-todo
+	) &&
 	git rebase --continue &&
 	test E = $(git cat-file commit HEAD | sed -ne \$p)
 '
@@ -1361,22 +1535,73 @@ test_expect_success 'editor saves as CR/
 	)
 '
 
-SQ="'"
 test_expect_success 'rebase -i --gpg-sign=<key-id>' '
 	test_when_finished "test_might_fail git rebase --abort" &&
-	set_fake_editor &&
-	FAKE_LINES="edit 1" git rebase -i --gpg-sign="\"S I Gner\"" HEAD^ \
-		>out 2>err &&
+	(
+		set_fake_editor &&
+		FAKE_LINES="edit 1" git rebase -i --gpg-sign="\"S I Gner\"" \
+			HEAD^ >out 2>err
+	) &&
 	test_i18ngrep "$SQ-S\"S I Gner\"$SQ" err
 '
 
 test_expect_success 'rebase -i --gpg-sign=<key-id> overrides commit.gpgSign' '
 	test_when_finished "test_might_fail git rebase --abort" &&
 	test_config commit.gpgsign true &&
-	set_fake_editor &&
-	FAKE_LINES="edit 1" git rebase -i --gpg-sign="\"S I Gner\"" HEAD^ \
-		>out 2>err &&
+	(
+		set_fake_editor &&
+		FAKE_LINES="edit 1" git rebase -i --gpg-sign="\"S I Gner\"" \
+			HEAD^ >out 2>err
+	) &&
 	test_i18ngrep "$SQ-S\"S I Gner\"$SQ" err
 '
 
+test_expect_success 'valid author header after --root swap' '
+	rebase_setup_and_clean author-header no-conflict-branch &&
+	git commit --amend --author="Au ${SQ}thor <author@example.com>" --no-edit &&
+	git cat-file commit HEAD | grep ^author >expected &&
+	(
+		set_fake_editor &&
+		FAKE_LINES="5 1" git rebase -i --root
+	) &&
+	git cat-file commit HEAD^ | grep ^author >actual &&
+	test_cmp expected actual
+'
+
+test_expect_success 'valid author header when author contains single quote' '
+	rebase_setup_and_clean author-header no-conflict-branch &&
+	git commit --amend --author="Au ${SQ}thor <author@example.com>" --no-edit &&
+	git cat-file commit HEAD | grep ^author >expected &&
+	(
+		set_fake_editor &&
+		FAKE_LINES="2" git rebase -i HEAD~2
+	) &&
+	git cat-file commit HEAD | grep ^author >actual &&
+	test_cmp expected actual
+'
+
+test_expect_success 'post-commit hook is called' '
+	test_when_finished "rm -f .git/hooks/post-commit" &&
+	>actual &&
+	mkdir -p .git/hooks &&
+	write_script .git/hooks/post-commit <<-\EOS &&
+	git rev-parse HEAD >>actual
+	EOS
+	(
+		set_fake_editor &&
+		FAKE_LINES="edit 4 1 reword 2 fixup 3" git rebase -i A E &&
+		echo x>file3 &&
+		git add file3 &&
+		FAKE_COMMIT_MESSAGE=edited git rebase --continue
+	) &&
+	git rev-parse HEAD@{5} HEAD@{4} HEAD@{3} HEAD@{2} HEAD@{1} HEAD \
+		>expect &&
+	test_cmp expect actual
+'
+
+# This must be the last test in this file
+test_expect_success '$EDITOR and friends are unchanged' '
+	test_editor_unchanged
+'
+
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t3405-rebase-malformed.sh 1.2.3+git2.25.1-1/git/t/t3405-rebase-malformed.sh
--- 1.2.1+git2.18.0-1/git/t/t3405-rebase-malformed.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t3405-rebase-malformed.sh	2020-02-17 04:47:35.000000000 +0000
@@ -77,19 +77,14 @@ test_expect_success 'rebase commit with
 '
 
 test_expect_success 'rebase -m commit with empty message' '
-	test_must_fail git rebase -m master empty-message-merge &&
-	git rebase --abort &&
-	git rebase -m --allow-empty-message master empty-message-merge
+	git rebase -m master empty-message-merge
 '
 
 test_expect_success 'rebase -i commit with empty message' '
 	git checkout diff-in-message &&
 	set_fake_editor &&
 	test_must_fail env FAKE_COMMIT_MESSAGE=" " FAKE_LINES="reword 1" \
-		git rebase -i HEAD^ &&
-	git rebase --abort &&
-	FAKE_COMMIT_MESSAGE=" " FAKE_LINES="reword 1" \
-		git rebase -i --allow-empty-message HEAD^
+		git rebase -i HEAD^
 '
 
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t3406-rebase-message.sh 1.2.3+git2.25.1-1/git/t/t3406-rebase-message.sh
--- 1.2.1+git2.18.0-1/git/t/t3406-rebase-message.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t3406-rebase-message.sh	2020-02-17 04:47:35.000000000 +0000
@@ -17,14 +17,9 @@ test_expect_success 'setup' '
 	git tag start
 '
 
-cat >expect <<\EOF
-Already applied: 0001 A
-Already applied: 0002 B
-Committed: 0003 Z
-EOF
-
 test_expect_success 'rebase -m' '
 	git rebase -m master >report &&
+	>expect &&
 	sed -n -e "/^Already applied: /p" \
 		-e "/^Committed: /p" report >actual &&
 	test_cmp expect actual
@@ -77,11 +72,54 @@ test_expect_success 'rebase -n overrides
 #     "Does not point to a valid commit: invalid-ref"
 #
 # NEEDSWORK: This "grep" is fine in real non-C locales, but
-# GETTEXT_POISON poisons the refname along with the enclosing
+# GIT_TEST_GETTEXT_POISON poisons the refname along with the enclosing
 # error message.
 test_expect_success 'rebase --onto outputs the invalid ref' '
 	test_must_fail git rebase --onto invalid-ref HEAD HEAD 2>err &&
 	test_i18ngrep "invalid-ref" err
 '
 
+test_expect_success 'error out early upon -C<n> or --whitespace=<bad>' '
+	test_must_fail git rebase -Cnot-a-number HEAD 2>err &&
+	test_i18ngrep "numerical value" err &&
+	test_must_fail git rebase --whitespace=bad HEAD 2>err &&
+	test_i18ngrep "Invalid whitespace option" err
+'
+
+test_expect_success 'GIT_REFLOG_ACTION' '
+	git checkout start &&
+	test_commit reflog-onto &&
+	git checkout -b reflog-topic start &&
+	test_commit reflog-to-rebase &&
+
+	git rebase reflog-onto &&
+	git log -g --format=%gs -3 >actual &&
+	cat >expect <<-\EOF &&
+	rebase finished: returning to refs/heads/reflog-topic
+	rebase: reflog-to-rebase
+	rebase: checkout reflog-onto
+	EOF
+	test_cmp expect actual &&
+
+	git checkout -b reflog-prefix reflog-to-rebase &&
+	GIT_REFLOG_ACTION=change-the-reflog git rebase reflog-onto &&
+	git log -g --format=%gs -3 >actual &&
+	cat >expect <<-\EOF &&
+	rebase finished: returning to refs/heads/reflog-prefix
+	change-the-reflog: reflog-to-rebase
+	change-the-reflog: checkout reflog-onto
+	EOF
+	test_cmp expect actual
+'
+
+test_expect_success 'rebase -i onto unrelated history' '
+	git init unrelated &&
+	test_commit -C unrelated 1 &&
+	git -C unrelated remote add -f origin "$PWD" &&
+	git -C unrelated branch --set-upstream-to=origin/master &&
+	git -C unrelated -c core.editor=true rebase -i -v --stat >actual &&
+	test_i18ngrep "Changes to " actual &&
+	test_i18ngrep "5 files changed" actual
+'
+
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t3408-rebase-multi-line.sh 1.2.3+git2.25.1-1/git/t/t3408-rebase-multi-line.sh
--- 1.2.1+git2.18.0-1/git/t/t3408-rebase-multi-line.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t3408-rebase-multi-line.sh	2020-02-17 04:47:35.000000000 +0000
@@ -52,7 +52,7 @@ test_expect_success rebase '
 	test_cmp expect actual
 
 '
-test_expect_success rebasep '
+test_expect_success REBASE_P rebasep '
 
 	git checkout side-merge &&
 	git rebase -p side &&
diff -pruN 1.2.1+git2.18.0-1/git/t/t3409-rebase-preserve-merges.sh 1.2.3+git2.25.1-1/git/t/t3409-rebase-preserve-merges.sh
--- 1.2.1+git2.18.0-1/git/t/t3409-rebase-preserve-merges.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t3409-rebase-preserve-merges.sh	2020-02-17 04:47:35.000000000 +0000
@@ -8,6 +8,11 @@ Run "git rebase -p" and check that merge
 '
 . ./test-lib.sh
 
+if ! test_have_prereq REBASE_P; then
+	skip_all='skipping git rebase -p tests, as asked for'
+	test_done
+fi
+
 GIT_AUTHOR_EMAIL=bogus_email_address
 export GIT_AUTHOR_EMAIL
 
diff -pruN 1.2.1+git2.18.0-1/git/t/t3410-rebase-preserve-dropped-merges.sh 1.2.3+git2.25.1-1/git/t/t3410-rebase-preserve-dropped-merges.sh
--- 1.2.1+git2.18.0-1/git/t/t3410-rebase-preserve-dropped-merges.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t3410-rebase-preserve-dropped-merges.sh	2020-02-17 04:47:35.000000000 +0000
@@ -11,6 +11,11 @@ rewritten.
 '
 . ./test-lib.sh
 
+if ! test_have_prereq REBASE_P; then
+	skip_all='skipping git rebase -p tests, as asked for'
+	test_done
+fi
+
 # set up two branches like this:
 #
 # A - B - C - D - E
diff -pruN 1.2.1+git2.18.0-1/git/t/t3411-rebase-preserve-around-merges.sh 1.2.3+git2.25.1-1/git/t/t3411-rebase-preserve-around-merges.sh
--- 1.2.1+git2.18.0-1/git/t/t3411-rebase-preserve-around-merges.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t3411-rebase-preserve-around-merges.sh	2020-02-17 04:47:35.000000000 +0000
@@ -10,6 +10,11 @@ a merge to before the merge.
 '
 . ./test-lib.sh
 
+if ! test_have_prereq REBASE_P; then
+	skip_all='skipping git rebase -p tests, as asked for'
+	test_done
+fi
+
 . "$TEST_DIRECTORY"/lib-rebase.sh
 
 set_fake_editor
diff -pruN 1.2.1+git2.18.0-1/git/t/t3412-rebase-root.sh 1.2.3+git2.25.1-1/git/t/t3412-rebase-root.sh
--- 1.2.1+git2.18.0-1/git/t/t3412-rebase-root.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t3412-rebase-root.sh	2020-02-17 04:47:35.000000000 +0000
@@ -86,14 +86,14 @@ test_expect_success 'pre-rebase got corr
 	test "z$(cat .git/PRE-REBASE-INPUT)" = z--root,work4
 '
 
-test_expect_success 'rebase -i -p with linear history' '
+test_expect_success REBASE_P 'rebase -i -p with linear history' '
 	git checkout -b work5 other &&
 	git rebase -i -p --root --onto master &&
 	git log --pretty=tformat:"%s" > rebased5 &&
 	test_cmp expect rebased5
 '
 
-test_expect_success 'pre-rebase got correct input (5)' '
+test_expect_success REBASE_P 'pre-rebase got correct input (5)' '
 	test "z$(cat .git/PRE-REBASE-INPUT)" = z--root,
 '
 
@@ -120,7 +120,7 @@ commit work6~4
 1
 EOF
 
-test_expect_success 'rebase -i -p with merge' '
+test_expect_success REBASE_P 'rebase -i -p with merge' '
 	git checkout -b work6 other &&
 	git rebase -i -p --root --onto master &&
 	log_with_names work6 > rebased6 &&
@@ -155,7 +155,7 @@ commit work7~5
 1
 EOF
 
-test_expect_success 'rebase -i -p with two roots' '
+test_expect_success REBASE_P 'rebase -i -p with two roots' '
 	git checkout -b work7 other &&
 	git rebase -i -p --root --onto master &&
 	log_with_names work7 > rebased7 &&
@@ -261,7 +261,7 @@ commit conflict3~6
 1
 EOF
 
-test_expect_success 'rebase -i -p --root with conflict (first part)' '
+test_expect_success REBASE_P 'rebase -i -p --root with conflict (first part)' '
 	git checkout -b conflict3 other &&
 	test_must_fail git rebase -i -p --root --onto master &&
 	git ls-files -u | grep "B$"
@@ -272,7 +272,7 @@ test_expect_success 'fix the conflict' '
 	git add B
 '
 
-test_expect_success 'rebase -i -p --root with conflict (second part)' '
+test_expect_success REBASE_P 'rebase -i -p --root with conflict (second part)' '
 	git rebase --continue &&
 	log_with_names conflict3 >out &&
 	test_cmp expect-conflict-p out
diff -pruN 1.2.1+git2.18.0-1/git/t/t3414-rebase-preserve-onto.sh 1.2.3+git2.25.1-1/git/t/t3414-rebase-preserve-onto.sh
--- 1.2.1+git2.18.0-1/git/t/t3414-rebase-preserve-onto.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t3414-rebase-preserve-onto.sh	2020-02-17 04:47:35.000000000 +0000
@@ -10,6 +10,11 @@ aren'"'"'t on top of $ONTO, even if they
 '
 . ./test-lib.sh
 
+if ! test_have_prereq REBASE_P; then
+	skip_all='skipping git rebase -p tests, as asked for'
+	test_done
+fi
+
 . "$TEST_DIRECTORY"/lib-rebase.sh
 
 # Set up branches like this:
diff -pruN 1.2.1+git2.18.0-1/git/t/t3415-rebase-autosquash.sh 1.2.3+git2.25.1-1/git/t/t3415-rebase-autosquash.sh
--- 1.2.1+git2.18.0-1/git/t/t3415-rebase-autosquash.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t3415-rebase-autosquash.sh	2020-02-17 04:47:35.000000000 +0000
@@ -277,7 +277,7 @@ test_expect_success 'autosquash with emp
 	(
 		set_cat_todo_editor &&
 		test_must_fail git -c rebase.instructionFormat= \
-			rebase --autosquash  --force -i HEAD^ >actual &&
+			rebase --autosquash  --force-rebase -i HEAD^ >actual &&
 		git log -1 --format="pick %h %s" >expect &&
 		test_cmp expect actual
 	)
@@ -330,4 +330,23 @@ test_expect_success 'wrapped original su
 	test $base = $parent
 '
 
+test_expect_success 'abort last squash' '
+	test_when_finished "test_might_fail git rebase --abort" &&
+	test_when_finished "git checkout master" &&
+
+	git checkout -b some-squashes &&
+	git commit --allow-empty -m first &&
+	git commit --allow-empty --squash HEAD &&
+	git commit --allow-empty -m second &&
+	git commit --allow-empty --squash HEAD &&
+
+	test_must_fail git -c core.editor="grep -q ^pick" \
+		rebase -ki --autosquash HEAD~4 &&
+	: do not finish the squash, but resolve it manually &&
+	git commit --allow-empty --amend -m edited-first &&
+	git rebase --skip &&
+	git show >actual &&
+	! grep first actual
+'
+
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t3416-rebase-onto-threedots.sh 1.2.3+git2.25.1-1/git/t/t3416-rebase-onto-threedots.sh
--- 1.2.1+git2.18.0-1/git/t/t3416-rebase-onto-threedots.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t3416-rebase-onto-threedots.sh	2020-02-17 04:47:35.000000000 +0000
@@ -99,7 +99,64 @@ test_expect_success 'rebase -i --onto ma
 	git checkout side &&
 	git reset --hard K &&
 
+	set_fake_editor &&
 	test_must_fail git rebase -i --onto master...side J
 '
 
+test_expect_success 'rebase --keep-base --onto incompatible' '
+	test_must_fail git rebase --keep-base --onto master...
+'
+
+test_expect_success 'rebase --keep-base --root incompatible' '
+	test_must_fail git rebase --keep-base --root
+'
+
+test_expect_success 'rebase --keep-base master from topic' '
+	git reset --hard &&
+	git checkout topic &&
+	git reset --hard G &&
+
+	git rebase --keep-base master &&
+	git rev-parse C >base.expect &&
+	git merge-base master HEAD >base.actual &&
+	test_cmp base.expect base.actual &&
+
+	git rev-parse HEAD~2 >actual &&
+	git rev-parse C^0 >expect &&
+	test_cmp expect actual
+'
+
+test_expect_success 'rebase --keep-base master from side' '
+	git reset --hard &&
+	git checkout side &&
+	git reset --hard K &&
+
+	test_must_fail git rebase --keep-base master
+'
+
+test_expect_success 'rebase -i --keep-base master from topic' '
+	git reset --hard &&
+	git checkout topic &&
+	git reset --hard G &&
+
+	set_fake_editor &&
+	EXPECT_COUNT=2 git rebase -i --keep-base master &&
+	git rev-parse C >base.expect &&
+	git merge-base master HEAD >base.actual &&
+	test_cmp base.expect base.actual &&
+
+	git rev-parse HEAD~2 >actual &&
+	git rev-parse C^0 >expect &&
+	test_cmp expect actual
+'
+
+test_expect_success 'rebase -i --keep-base master from side' '
+	git reset --hard &&
+	git checkout side &&
+	git reset --hard K &&
+
+	set_fake_editor &&
+	test_must_fail git rebase -i --keep-base master
+'
+
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t3417-rebase-whitespace-fix.sh 1.2.3+git2.25.1-1/git/t/t3417-rebase-whitespace-fix.sh
--- 1.2.1+git2.18.0-1/git/t/t3417-rebase-whitespace-fix.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t3417-rebase-whitespace-fix.sh	2020-02-17 04:47:35.000000000 +0000
@@ -55,7 +55,7 @@ test_expect_success 'blank line at end o
 	git add file &&	git commit -m second &&
 	git rebase --whitespace=fix HEAD^^ &&
 	git diff --exit-code HEAD^:file expect-first &&
-	test_cmp file expect-second
+	test_cmp expect-second file
 '
 
 # prepare third revision of "file"
@@ -82,7 +82,7 @@ test_expect_success 'two blanks line at
 	cp third file && git add file && git commit -m third &&
 	git rebase --whitespace=fix HEAD^^ &&
 	git diff --exit-code HEAD^:file expect-second &&
-	test_cmp file expect-third
+	test_cmp expect-third file
 '
 
 test_expect_success 'same, but do not remove trailing spaces' '
@@ -120,7 +120,7 @@ test_expect_success 'at beginning of fil
 	done >> file &&
 	git commit -m more file	&&
 	git rebase --whitespace=fix HEAD^^ &&
-	test_cmp file expect-beginning
+	test_cmp expect-beginning file
 '
 
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t3418-rebase-continue.sh 1.2.3+git2.25.1-1/git/t/t3418-rebase-continue.sh
--- 1.2.1+git2.18.0-1/git/t/t3418-rebase-continue.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t3418-rebase-continue.sh	2020-02-17 04:47:35.000000000 +0000
@@ -60,7 +60,7 @@ test_expect_success 'rebase --continue r
 	EOF
 	chmod +x test-bin/git-merge-funny &&
 	(
-		PATH=./test-bin:$PATH
+		PATH=./test-bin:$PATH &&
 		test_must_fail git rebase -s funny -Xopt master topic
 	) &&
 	test -f funny.was.run &&
@@ -68,13 +68,45 @@ test_expect_success 'rebase --continue r
 	echo "Resolved" >F2 &&
 	git add F2 &&
 	(
-		PATH=./test-bin:$PATH
+		PATH=./test-bin:$PATH &&
 		git rebase --continue
 	) &&
 	test -f funny.was.run
 '
 
-test_expect_success 'rebase passes merge strategy options correctly' '
+test_expect_success 'rebase -i --continue handles merge strategy and options' '
+	rm -fr .git/rebase-* &&
+	git reset --hard commit-new-file-F2-on-topic-branch &&
+	test_commit "commit-new-file-F3-on-topic-branch-for-dash-i" F3 32 &&
+	test_when_finished "rm -fr test-bin funny.was.run funny.args" &&
+	mkdir test-bin &&
+	cat >test-bin/git-merge-funny <<-EOF &&
+	#!$SHELL_PATH
+	echo "\$@" >>funny.args
+	case "\$1" in --opt) ;; *) exit 2 ;; esac
+	case "\$2" in --foo) ;; *) exit 2 ;; esac
+	case "\$4" in --) ;; *) exit 2 ;; esac
+	shift 2 &&
+	>funny.was.run &&
+	exec git merge-recursive "\$@"
+	EOF
+	chmod +x test-bin/git-merge-funny &&
+	(
+		PATH=./test-bin:$PATH &&
+		test_must_fail git rebase -i -s funny -Xopt -Xfoo master topic
+	) &&
+	test -f funny.was.run &&
+	rm funny.was.run &&
+	echo "Resolved" >F2 &&
+	git add F2 &&
+	(
+		PATH=./test-bin:$PATH &&
+		git rebase --continue
+	) &&
+	test -f funny.was.run
+'
+
+test_expect_success REBASE_P 'rebase passes merge strategy options correctly' '
 	rm -fr .git/rebase-* &&
 	git reset --hard commit-new-file-F3-on-topic-branch &&
 	test_commit theirs-to-merge &&
@@ -88,6 +120,20 @@ test_expect_success 'rebase passes merge
 	git rebase --continue
 '
 
+test_expect_success 'rebase -r passes merge strategy options correctly' '
+	rm -fr .git/rebase-* &&
+	git reset --hard commit-new-file-F3-on-topic-branch &&
+	test_commit merge-theirs &&
+	git reset --hard HEAD^ &&
+	test_commit some-other-commit &&
+	test_tick &&
+	git merge --no-ff merge-theirs &&
+	FAKE_LINES="1 3 edit 4 5 7 8 9" git rebase -i -f -r -m \
+		-s recursive --strategy-option=theirs HEAD~2 &&
+	test_commit force-change-ours &&
+	git rebase --continue
+'
+
 test_expect_success '--skip after failed fixup cleans commit message' '
 	test_when_finished "test_might_fail git rebase --abort" &&
 	git checkout -b with-conflicting-fixup &&
@@ -128,13 +174,15 @@ test_expect_success '--skip after failed
 	: The first squash was skipped, therefore: &&
 	git show HEAD >out &&
 	test_i18ngrep "# This is a combination of 2 commits" out &&
+	test_i18ngrep "# This is the commit message #2:" out &&
 
 	(test_set_editor "$PWD/copy-editor.sh" && git rebase --skip) &&
 	git show HEAD >out &&
 	test_i18ngrep ! "# This is a combination" out &&
 
 	: Final squash failed, but there was still a squash &&
-	test_i18ngrep "# This is a combination of 2 commits" .git/copy.txt
+	test_i18ngrep "# This is a combination of 2 commits" .git/copy.txt &&
+	test_i18ngrep "# This is the commit message #2:" .git/copy.txt
 '
 
 test_expect_success 'setup rerere database' '
@@ -143,6 +191,7 @@ test_expect_success 'setup rerere databa
 	git checkout master &&
 	test_commit "commit-new-file-F3" F3 3 &&
 	test_config rerere.enabled true &&
+	git update-ref refs/heads/topic commit-new-file-F3-on-topic-branch &&
 	test_must_fail git rebase -m master topic &&
 	echo "Resolved" >F2 &&
 	cp F2 expected-F2 &&
@@ -206,6 +255,36 @@ test_rerere_autoupdate
 test_rerere_autoupdate -m
 GIT_SEQUENCE_EDITOR=: && export GIT_SEQUENCE_EDITOR
 test_rerere_autoupdate -i
-test_rerere_autoupdate --preserve-merges
+test_have_prereq !REBASE_P || test_rerere_autoupdate --preserve-merges
+unset GIT_SEQUENCE_EDITOR
+
+test_expect_success 'the todo command "break" works' '
+	rm -f execed &&
+	FAKE_LINES="break b exec_>execed" git rebase -i HEAD &&
+	test_path_is_missing execed &&
+	git rebase --continue &&
+	test_path_is_missing execed &&
+	git rebase --continue &&
+	test_path_is_file execed
+'
+
+test_expect_success '--reschedule-failed-exec' '
+	test_when_finished "git rebase --abort" &&
+	test_must_fail git rebase -x false --reschedule-failed-exec HEAD^ &&
+	grep "^exec false" .git/rebase-merge/git-rebase-todo &&
+	git rebase --abort &&
+	test_must_fail git -c rebase.rescheduleFailedExec=true \
+		rebase -x false HEAD^ 2>err &&
+	grep "^exec false" .git/rebase-merge/git-rebase-todo &&
+	test_i18ngrep "has been rescheduled" err
+'
+
+test_expect_success 'rebase.reschedulefailedexec only affects `rebase -i`' '
+	test_config rebase.reschedulefailedexec true &&
+	test_must_fail git rebase -x false HEAD^ &&
+	grep "^exec false" .git/rebase-merge/git-rebase-todo &&
+	git rebase --abort &&
+	git rebase HEAD^
+'
 
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t3420-rebase-autostash.sh 1.2.3+git2.25.1-1/git/t/t3420-rebase-autostash.sh
--- 1.2.1+git2.18.0-1/git/t/t3420-rebase-autostash.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t3420-rebase-autostash.sh	2020-02-17 04:47:35.000000000 +0000
@@ -30,13 +30,13 @@ test_expect_success setup '
 	echo conflicting-change >file2 &&
 	git add . &&
 	test_tick &&
-	git commit -m "related commit"
+	git commit -m "related commit" &&
+	remove_progress_re="$(printf "s/.*\\r//")"
 '
 
 create_expected_success_am () {
 	cat >expected <<-EOF
 	$(grep "^Created autostash: [0-9a-f][0-9a-f]*\$" actual)
-	HEAD is now at $(git rev-parse --short feature-branch) third commit
 	First, rewinding head to replay your work on top of it...
 	Applying: second commit
 	Applying: third commit
@@ -47,51 +47,14 @@ create_expected_success_am () {
 create_expected_success_interactive () {
 	q_to_cr >expected <<-EOF
 	$(grep "^Created autostash: [0-9a-f][0-9a-f]*\$" actual)
-	HEAD is now at $(git rev-parse --short feature-branch) third commit
-	Rebasing (1/2)QRebasing (2/2)QApplied autostash.
-	Successfully rebased and updated refs/heads/rebased-feature-branch.
-	EOF
-}
-
-create_expected_success_merge () {
-	cat >expected <<-EOF
-	$(grep "^Created autostash: [0-9a-f][0-9a-f]*\$" actual)
-	HEAD is now at $(git rev-parse --short feature-branch) third commit
-	First, rewinding head to replay your work on top of it...
-	Merging unrelated-onto-branch with HEAD~1
-	Merging:
-	$(git rev-parse --short unrelated-onto-branch) unrelated commit
-	$(git rev-parse --short feature-branch^) second commit
-	found 1 common ancestor:
-	$(git rev-parse --short feature-branch~2) initial commit
-	[detached HEAD $(git rev-parse --short rebased-feature-branch~1)] second commit
-	 Author: A U Thor <author@example.com>
-	 Date: Thu Apr 7 15:14:13 2005 -0700
-	 2 files changed, 2 insertions(+)
-	 create mode 100644 file1
-	 create mode 100644 file2
-	Committed: 0001 second commit
-	Merging unrelated-onto-branch with HEAD~0
-	Merging:
-	$(git rev-parse --short rebased-feature-branch~1) second commit
-	$(git rev-parse --short feature-branch) third commit
-	found 1 common ancestor:
-	$(git rev-parse --short feature-branch~1) second commit
-	[detached HEAD $(git rev-parse --short rebased-feature-branch)] third commit
-	 Author: A U Thor <author@example.com>
-	 Date: Thu Apr 7 15:15:13 2005 -0700
-	 1 file changed, 1 insertion(+)
-	 create mode 100644 file3
-	Committed: 0002 third commit
-	All done.
 	Applied autostash.
+	Successfully rebased and updated refs/heads/rebased-feature-branch.
 	EOF
 }
 
 create_expected_failure_am () {
 	cat >expected <<-EOF
 	$(grep "^Created autostash: [0-9a-f][0-9a-f]*\$" actual)
-	HEAD is now at $(git rev-parse --short feature-branch) third commit
 	First, rewinding head to replay your work on top of it...
 	Applying: second commit
 	Applying: third commit
@@ -102,50 +65,12 @@ create_expected_failure_am () {
 }
 
 create_expected_failure_interactive () {
-	q_to_cr >expected <<-EOF
-	$(grep "^Created autostash: [0-9a-f][0-9a-f]*\$" actual)
-	HEAD is now at $(git rev-parse --short feature-branch) third commit
-	Rebasing (1/2)QRebasing (2/2)QApplying autostash resulted in conflicts.
-	Your changes are safe in the stash.
-	You can run "git stash pop" or "git stash drop" at any time.
-	Successfully rebased and updated refs/heads/rebased-feature-branch.
-	EOF
-}
-
-create_expected_failure_merge () {
 	cat >expected <<-EOF
 	$(grep "^Created autostash: [0-9a-f][0-9a-f]*\$" actual)
-	HEAD is now at $(git rev-parse --short feature-branch) third commit
-	First, rewinding head to replay your work on top of it...
-	Merging unrelated-onto-branch with HEAD~1
-	Merging:
-	$(git rev-parse --short unrelated-onto-branch) unrelated commit
-	$(git rev-parse --short feature-branch^) second commit
-	found 1 common ancestor:
-	$(git rev-parse --short feature-branch~2) initial commit
-	[detached HEAD $(git rev-parse --short rebased-feature-branch~1)] second commit
-	 Author: A U Thor <author@example.com>
-	 Date: Thu Apr 7 15:14:13 2005 -0700
-	 2 files changed, 2 insertions(+)
-	 create mode 100644 file1
-	 create mode 100644 file2
-	Committed: 0001 second commit
-	Merging unrelated-onto-branch with HEAD~0
-	Merging:
-	$(git rev-parse --short rebased-feature-branch~1) second commit
-	$(git rev-parse --short feature-branch) third commit
-	found 1 common ancestor:
-	$(git rev-parse --short feature-branch~1) second commit
-	[detached HEAD $(git rev-parse --short rebased-feature-branch)] third commit
-	 Author: A U Thor <author@example.com>
-	 Date: Thu Apr 7 15:15:13 2005 -0700
-	 1 file changed, 1 insertion(+)
-	 create mode 100644 file3
-	Committed: 0002 third commit
-	All done.
 	Applying autostash resulted in conflicts.
 	Your changes are safe in the stash.
 	You can run "git stash pop" or "git stash drop" at any time.
+	Successfully rebased and updated refs/heads/rebased-feature-branch.
 	EOF
 }
 
@@ -177,8 +102,12 @@ testrebase () {
 	test_expect_success "rebase$type --autostash: check output" '
 		test_when_finished git branch -D rebased-feature-branch &&
 		suffix=${type#\ --} && suffix=${suffix:-am} &&
+		if test ${suffix} = "merge"; then
+			suffix=interactive
+		fi &&
 		create_expected_success_$suffix &&
-		test_i18ncmp expected actual
+		sed "$remove_progress_re" <actual >actual2 &&
+		test_i18ncmp expected actual2
 	'
 
 	test_expect_success "rebase$type: dirty index, non-conflicting rebase" '
@@ -202,7 +131,7 @@ testrebase () {
 		echo dirty >>file3 &&
 		test_must_fail git rebase$type related-onto-branch &&
 		test_path_is_file $dotest/autostash &&
-		! grep dirty file3 &&
+		test_path_is_missing file3 &&
 		rm -rf $dotest &&
 		git reset --hard &&
 		git checkout feature-branch
@@ -216,7 +145,7 @@ testrebase () {
 		echo dirty >>file3 &&
 		test_must_fail git rebase$type related-onto-branch &&
 		test_path_is_file $dotest/autostash &&
-		! grep dirty file3 &&
+		test_path_is_missing file3 &&
 		echo "conflicting-plus-goodbye" >file2 &&
 		git add file2 &&
 		git rebase --continue &&
@@ -233,7 +162,7 @@ testrebase () {
 		echo dirty >>file3 &&
 		test_must_fail git rebase$type related-onto-branch &&
 		test_path_is_file $dotest/autostash &&
-		! grep dirty file3 &&
+		test_path_is_missing file3 &&
 		git rebase --skip &&
 		test_path_is_missing $dotest/autostash &&
 		grep dirty file3 &&
@@ -248,7 +177,7 @@ testrebase () {
 		echo dirty >>file3 &&
 		test_must_fail git rebase$type related-onto-branch &&
 		test_path_is_file $dotest/autostash &&
-		! grep dirty file3 &&
+		test_path_is_missing file3 &&
 		git rebase --abort &&
 		test_path_is_missing $dotest/autostash &&
 		grep dirty file3 &&
@@ -274,8 +203,12 @@ testrebase () {
 	test_expect_success "rebase$type: check output with conflicting stash" '
 		test_when_finished git branch -D rebased-feature-branch &&
 		suffix=${type#\ --} && suffix=${suffix:-am} &&
+		if test ${suffix} = "merge"; then
+			suffix=interactive
+		fi &&
 		create_expected_failure_$suffix &&
-		test_i18ncmp expected actual
+		sed "$remove_progress_re" <actual >actual2 &&
+		test_i18ncmp expected actual2
 	'
 }
 
@@ -351,4 +284,30 @@ test_expect_success 'autostash is saved
 	test_cmp expected file0
 '
 
+test_expect_success 'autostash with dirty submodules' '
+	test_when_finished "git reset --hard && git checkout master" &&
+	git checkout -b with-submodule &&
+	git submodule add ./ sub &&
+	test_tick &&
+	git commit -m add-submodule &&
+	echo changed >sub/file0 &&
+	git rebase -i --autostash HEAD
+'
+
+test_expect_success 'branch is left alone when possible' '
+	git checkout -b unchanged-branch &&
+	echo changed >file0 &&
+	git rebase --autostash unchanged-branch &&
+	test changed = "$(cat file0)" &&
+	test unchanged-branch = "$(git rev-parse --abbrev-ref HEAD)"
+'
+
+test_expect_success 'never change active branch' '
+	git checkout -b not-the-feature-branch unrelated-onto-branch &&
+	test_when_finished "git reset --hard && git checkout master" &&
+	echo changed >file0 &&
+	git rebase --autostash not-the-feature-branch feature-branch &&
+	test_cmp_rev not-the-feature-branch unrelated-onto-branch
+'
+
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t3421-rebase-topology-linear.sh 1.2.3+git2.25.1-1/git/t/t3421-rebase-topology-linear.sh
--- 1.2.1+git2.18.0-1/git/t/t3421-rebase-topology-linear.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t3421-rebase-topology-linear.sh	2020-02-17 04:47:35.000000000 +0000
@@ -29,7 +29,17 @@ test_run_rebase () {
 test_run_rebase success ''
 test_run_rebase success -m
 test_run_rebase success -i
-test_run_rebase success -p
+test_have_prereq !REBASE_P || test_run_rebase success -p
+
+test_expect_success 'setup branches and remote tracking' '
+	git tag -l >tags &&
+	for tag in $(cat tags)
+	do
+		git branch branch-$tag $tag || return 1
+	done &&
+	git remote add origin "file://$PWD" &&
+	git fetch origin
+'
 
 test_run_rebase () {
 	result=$1
@@ -43,7 +53,7 @@ test_run_rebase () {
 test_run_rebase success ''
 test_run_rebase success -m
 test_run_rebase success -i
-test_run_rebase success -p
+test_have_prereq !REBASE_P || test_run_rebase success -p
 
 test_run_rebase () {
 	result=$1
@@ -51,15 +61,33 @@ test_run_rebase () {
 	test_expect_$result "rebase $* -f rewrites even if upstream is an ancestor" "
 		reset_rebase &&
 		git rebase $* -f b e &&
-		! test_cmp_rev e HEAD &&
+		test_cmp_rev ! e HEAD &&
 		test_cmp_rev b HEAD~2 &&
 		test_linear_range 'd e' b..
 	"
 }
 test_run_rebase success ''
+test_run_rebase success --fork-point
 test_run_rebase success -m
 test_run_rebase success -i
-test_run_rebase failure -p
+test_have_prereq !REBASE_P || test_run_rebase failure -p
+
+test_run_rebase () {
+	result=$1
+	shift
+	test_expect_$result "rebase $* -f rewrites even if remote upstream is an ancestor" "
+		reset_rebase &&
+		git rebase $* -f branch-b branch-e &&
+		test_cmp_rev ! branch-e origin/branch-e &&
+		test_cmp_rev branch-b HEAD~2 &&
+		test_linear_range 'd e' branch-b..
+	"
+}
+test_run_rebase success ''
+test_run_rebase success --fork-point
+test_run_rebase success -m
+test_run_rebase success -i
+test_have_prereq !REBASE_P || test_run_rebase success -p
 
 test_run_rebase () {
 	result=$1
@@ -71,9 +99,10 @@ test_run_rebase () {
 	"
 }
 test_run_rebase success ''
+test_run_rebase success --fork-point
 test_run_rebase success -m
 test_run_rebase success -i
-test_run_rebase success -p
+test_have_prereq !REBASE_P || test_run_rebase success -p
 
 #       f
 #      /
@@ -111,9 +140,9 @@ test_run_rebase () {
 	"
 }
 test_run_rebase success ''
-test_run_rebase failure -m
+test_run_rebase success -m
 test_run_rebase success -i
-test_run_rebase success -p
+test_have_prereq !REBASE_P || test_run_rebase success -p
 
 test_run_rebase () {
 	result=$1
@@ -126,9 +155,9 @@ test_run_rebase () {
 	"
 }
 test_run_rebase success ''
-test_run_rebase failure -m
+test_run_rebase success -m
 test_run_rebase success -i
-test_run_rebase success -p
+test_have_prereq !REBASE_P || test_run_rebase success -p
 
 test_run_rebase () {
 	result=$1
@@ -141,9 +170,9 @@ test_run_rebase () {
 	"
 }
 test_run_rebase success ''
-test_run_rebase failure -m
+test_run_rebase success -m
 test_run_rebase success -i
-test_run_rebase success -p
+test_have_prereq !REBASE_P || test_run_rebase success -p
 
 test_run_rebase () {
 	result=$1
@@ -158,7 +187,7 @@ test_run_rebase () {
 test_run_rebase success ''
 test_run_rebase success -m
 test_run_rebase success -i
-test_run_rebase success -p
+test_have_prereq !REBASE_P || test_run_rebase success -p
 
 # a---b---c---j!
 #      \
@@ -186,7 +215,7 @@ test_run_rebase () {
 test_run_rebase success ''
 test_run_rebase success -m
 test_run_rebase success -i
-test_run_rebase success -p
+test_have_prereq !REBASE_P || test_run_rebase success -p
 
 test_run_rebase () {
 	result=$1
@@ -201,7 +230,7 @@ test_run_rebase () {
 test_run_rebase success ''
 test_run_rebase success -m
 test_run_rebase success -i
-test_run_rebase failure -p
+test_have_prereq !REBASE_P || test_run_rebase failure -p
 
 test_run_rebase () {
 	result=$1
@@ -216,7 +245,7 @@ test_run_rebase () {
 test_run_rebase success ''
 test_run_rebase success -m
 test_run_rebase success -i
-test_run_rebase failure -p
+test_have_prereq !REBASE_P || test_run_rebase failure -p
 test_run_rebase success --rebase-merges
 
 #       m
@@ -256,7 +285,7 @@ test_run_rebase () {
 test_run_rebase success ''
 test_run_rebase success -m
 test_run_rebase success -i
-test_run_rebase success -p
+test_have_prereq !REBASE_P || test_run_rebase success -p
 
 test_run_rebase () {
 	result=$1
@@ -271,7 +300,7 @@ test_run_rebase () {
 test_run_rebase success ''
 test_run_rebase success -m
 test_run_rebase success -i
-test_run_rebase failure -p
+test_have_prereq !REBASE_P || test_run_rebase failure -p
 
 test_run_rebase () {
 	result=$1
@@ -284,9 +313,9 @@ test_run_rebase () {
 	"
 }
 test_run_rebase success ''
-test_run_rebase failure -m
+test_run_rebase success -m
 test_run_rebase success -i
-test_run_rebase success -p
+test_have_prereq !REBASE_P || test_run_rebase success -p
 
 test_run_rebase () {
 	result=$1
@@ -302,7 +331,7 @@ test_run_rebase () {
 test_run_rebase success ''
 test_run_rebase success -m
 test_run_rebase success -i
-test_run_rebase failure -p
+test_have_prereq !REBASE_P || test_run_rebase failure -p
 
 test_run_rebase () {
 	result=$1
@@ -315,9 +344,9 @@ test_run_rebase () {
 	"
 }
 test_run_rebase success ''
-test_run_rebase failure -m
+test_run_rebase success -m
 test_run_rebase success -i
-test_run_rebase failure -p
+test_have_prereq !REBASE_P || test_run_rebase failure -p
 
 test_run_rebase () {
 	result=$1
@@ -331,7 +360,7 @@ test_run_rebase () {
 test_run_rebase success ''
 test_run_rebase success -m
 test_run_rebase success -i
-test_run_rebase failure -p
+test_have_prereq !REBASE_P || test_run_rebase failure -p
 
 test_run_rebase () {
 	result=$1
@@ -339,13 +368,13 @@ test_run_rebase () {
 	test_expect_$result "rebase $* -f --root on linear history causes re-write" "
 		reset_rebase &&
 		git rebase $* -f --root c &&
-		! test_cmp_rev a HEAD~2 &&
+		test_cmp_rev ! a HEAD~2 &&
 		test_linear_range 'a b c' HEAD
 	"
 }
 test_run_rebase success ''
 test_run_rebase success -m
 test_run_rebase success -i
-test_run_rebase success -p
+test_have_prereq !REBASE_P || test_run_rebase success -p
 
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t3422-rebase-incompatible-options.sh 1.2.3+git2.25.1-1/git/t/t3422-rebase-incompatible-options.sh
--- 1.2.1+git2.18.0-1/git/t/t3422-rebase-incompatible-options.sh	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t3422-rebase-incompatible-options.sh	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,79 @@
+#!/bin/sh
+
+test_description='test if rebase detects and aborts on incompatible options'
+. ./test-lib.sh
+
+test_expect_success 'setup' '
+	test_seq 2 9 >foo &&
+	git add foo &&
+	git commit -m orig &&
+
+	git branch A &&
+	git branch B &&
+
+	git checkout A &&
+	test_seq 1 9 >foo &&
+	git add foo &&
+	git commit -m A &&
+
+	git checkout B &&
+	echo "q qfoo();" | q_to_tab >>foo &&
+	git add foo &&
+	git commit -m B
+'
+
+#
+# Rebase has lots of useful options like --whitepsace=fix, which are
+# actually all built in terms of flags to git-am.  Since neither
+# --merge nor --interactive (nor any options that imply those two) use
+# git-am, using them together will result in flags like --whitespace=fix
+# being ignored.  Make sure rebase warns the user and aborts instead.
+#
+
+test_rebase_am_only () {
+	opt=$1
+	shift
+	test_expect_success "$opt incompatible with --merge" "
+		git checkout B^0 &&
+		test_must_fail git rebase $opt --merge A
+	"
+
+	test_expect_success "$opt incompatible with --strategy=ours" "
+		git checkout B^0 &&
+		test_must_fail git rebase $opt --strategy=ours A
+	"
+
+	test_expect_success "$opt incompatible with --strategy-option=ours" "
+		git checkout B^0 &&
+		test_must_fail git rebase $opt --strategy-option=ours A
+	"
+
+	test_expect_success "$opt incompatible with --interactive" "
+		git checkout B^0 &&
+		test_must_fail git rebase $opt --interactive A
+	"
+
+	test_expect_success "$opt incompatible with --exec" "
+		git checkout B^0 &&
+		test_must_fail git rebase $opt --exec 'true' A
+	"
+
+}
+
+test_rebase_am_only --whitespace=fix
+test_rebase_am_only --ignore-whitespace
+test_rebase_am_only --committer-date-is-author-date
+test_rebase_am_only -C4
+
+test_expect_success REBASE_P '--preserve-merges incompatible with --signoff' '
+	git checkout B^0 &&
+	test_must_fail git rebase --preserve-merges --signoff A
+'
+
+test_expect_success REBASE_P \
+	'--preserve-merges incompatible with --rebase-merges' '
+	git checkout B^0 &&
+	test_must_fail git rebase --preserve-merges --rebase-merges A
+'
+
+test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t3423-rebase-reword.sh 1.2.3+git2.25.1-1/git/t/t3423-rebase-reword.sh
--- 1.2.1+git2.18.0-1/git/t/t3423-rebase-reword.sh	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t3423-rebase-reword.sh	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,48 @@
+#!/bin/sh
+
+test_description='git rebase interactive with rewording'
+
+. ./test-lib.sh
+
+. "$TEST_DIRECTORY"/lib-rebase.sh
+
+test_expect_success 'setup' '
+	test_commit master file-1 test &&
+
+	git checkout -b stuff &&
+
+	test_commit feature_a file-2 aaa &&
+	test_commit feature_b file-2 ddd
+'
+
+test_expect_success 'reword without issues functions as intended' '
+	test_when_finished "reset_rebase" &&
+
+	git checkout stuff^0 &&
+
+	set_fake_editor &&
+	FAKE_LINES="pick 1 reword 2" FAKE_COMMIT_MESSAGE="feature_b_reworded" \
+		git rebase -i -v master &&
+
+	test "$(git log -1 --format=%B)" = "feature_b_reworded" &&
+	test $(git rev-list --count HEAD) = 3
+'
+
+test_expect_success 'reword after a conflict preserves commit' '
+	test_when_finished "reset_rebase" &&
+
+	git checkout stuff^0 &&
+
+	set_fake_editor &&
+	test_must_fail env FAKE_LINES="reword 2" \
+		git rebase -i -v master &&
+
+	git checkout --theirs file-2 &&
+	git add file-2 &&
+	FAKE_COMMIT_MESSAGE="feature_b_reworded" git rebase --continue &&
+
+	test "$(git log -1 --format=%B)" = "feature_b_reworded" &&
+	test $(git rev-list --count HEAD) = 2
+'
+
+test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t3425-rebase-topology-merges.sh 1.2.3+git2.25.1-1/git/t/t3425-rebase-topology-merges.sh
--- 1.2.1+git2.18.0-1/git/t/t3425-rebase-topology-merges.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t3425-rebase-topology-merges.sh	2020-02-17 04:47:35.000000000 +0000
@@ -70,9 +70,8 @@ test_run_rebase () {
 		test_linear_range "\'"$expected"\'" d..
 	"
 }
-#TODO: make order consistent across all flavors of rebase
-test_run_rebase success 'e n o' ''
-test_run_rebase success 'e n o' -m
+test_run_rebase success 'n o e' ''
+test_run_rebase success 'n o e' -m
 test_run_rebase success 'n o e' -i
 
 test_run_rebase () {
@@ -87,9 +86,8 @@ test_run_rebase () {
 		test_linear_range "\'"$expected"\'" c..
 	"
 }
-#TODO: make order consistent across all flavors of rebase
-test_run_rebase success 'd e n o' ''
-test_run_rebase success 'd e n o' -m
+test_run_rebase success 'd n o e' ''
+test_run_rebase success 'd n o e' -m
 test_run_rebase success 'd n o e' -i
 
 test_run_rebase () {
@@ -104,11 +102,15 @@ test_run_rebase () {
 		test_linear_range "\'"$expected"\'" c..
 	"
 }
-#TODO: make order consistent across all flavors of rebase
-test_run_rebase success 'd e n o' ''
-test_run_rebase success 'd e n o' -m
+test_run_rebase success 'd n o e' ''
+test_run_rebase success 'd n o e' -m
 test_run_rebase success 'd n o e' -i
 
+if ! test_have_prereq REBASE_P; then
+	skip_all='skipping git rebase -p tests, as asked for'
+	test_done
+fi
+
 test_expect_success "rebase -p is no-op in non-linear history" "
 	reset_rebase &&
 	git rebase -p d w &&
diff -pruN 1.2.1+git2.18.0-1/git/t/t3427-rebase-subtree.sh 1.2.3+git2.25.1-1/git/t/t3427-rebase-subtree.sh
--- 1.2.1+git2.18.0-1/git/t/t3427-rebase-subtree.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t3427-rebase-subtree.sh	2020-02-17 04:47:35.000000000 +0000
@@ -11,108 +11,99 @@ commit_message() {
 	git log --pretty=format:%s -1 "$1"
 }
 
+# There are a few bugs in the rebase with regards to the subtree strategy, and
+# this test script tries to document them.  First, the following commit history
+# is generated (the onelines are shown, time flows from left to right):
+#
+# master1 - master2 - master3
+#                             \
+# README ---------------------- Add subproject master - master4 - files_subtree/master5
+#
+# Where the merge moves the files master[123].t into the subdirectory
+# files_subtree/ and master4 as well as files_subtree/master5 add files to that
+# directory directly.
+#
+# Then, in subsequent test cases, `git filter-branch` is used to distill just
+# the commits that touch files_subtree/. To give it a final pre-rebase touch,
+# an empty commit is added on top. The pre-rebase commit history looks like
+# this:
+#
+# Add subproject master - master4 - files_subtree/master5 - Empty commit
+#
+# where the root commit adds three files: master1.t, master2.t and master3.t.
+#
+# This commit history is then rebased onto `master3` with the
+# `-Xsubtree=files_subtree` option in three different ways:
+#
+# 1. using `--preserve-merges`
+# 2. using `--preserve-merges` and --keep-empty
+# 3. without specifying a rebase backend
+
 test_expect_success 'setup' '
 	test_commit README &&
-	mkdir files &&
-	(
-		cd files &&
-		git init &&
-		test_commit master1 &&
-		test_commit master2 &&
-		test_commit master3
-	) &&
-	git fetch files master &&
-	git branch files-master FETCH_HEAD &&
-	git read-tree --prefix=files_subtree files-master &&
-	git checkout -- files_subtree &&
-	tree=$(git write-tree) &&
-	head=$(git rev-parse HEAD) &&
-	rev=$(git rev-parse --verify files-master^0) &&
-	commit=$(git commit-tree -p $head -p $rev -m "Add subproject master" $tree) &&
-	git update-ref HEAD $commit &&
-	(
-		cd files_subtree &&
-		test_commit master4
-	) &&
-	test_commit files_subtree/master5
-'
 
-# FAILURE: Does not preserve master4.
-test_expect_failure 'Rebase -Xsubtree --preserve-merges --onto commit 4' '
-	reset_rebase &&
-	git checkout -b rebase-preserve-merges-4 master &&
-	git filter-branch --prune-empty -f --subdirectory-filter files_subtree &&
-	git commit -m "Empty commit" --allow-empty &&
-	git rebase -Xsubtree=files_subtree --preserve-merges --onto files-master master &&
-	verbose test "$(commit_message HEAD~)" = "files_subtree/master4"
+	git init files &&
+	test_commit -C files master1 &&
+	test_commit -C files master2 &&
+	test_commit -C files master3 &&
+
+	: perform subtree merge into files_subtree/ &&
+	git fetch files refs/heads/master:refs/heads/files-master &&
+	git merge -s ours --no-commit --allow-unrelated-histories \
+		files-master &&
+	git read-tree --prefix=files_subtree -u files-master &&
+	git commit -m "Add subproject master" &&
+
+	: add two extra commits to rebase &&
+	test_commit -C files_subtree master4 &&
+	test_commit files_subtree/master5 &&
+
+	git checkout -b to-rebase &&
+	git fast-export --no-data HEAD -- files_subtree/ |
+		sed -e "s%\([0-9a-f]\{40\} \)files_subtree/%\1%" |
+		git fast-import --force --quiet &&
+	git reset --hard &&
+	git commit -m "Empty commit" --allow-empty
 '
 
-# FAILURE: Does not preserve master5.
-test_expect_failure 'Rebase -Xsubtree --preserve-merges --onto commit 5' '
+# FAILURE: Does not preserve master4.
+test_expect_failure REBASE_P 'Rebase -Xsubtree --preserve-merges --onto commit' '
 	reset_rebase &&
-	git checkout -b rebase-preserve-merges-5 master &&
-	git filter-branch --prune-empty -f --subdirectory-filter files_subtree &&
-	git commit -m "Empty commit" --allow-empty &&
+	git checkout -b rebase-preserve-merges to-rebase &&
 	git rebase -Xsubtree=files_subtree --preserve-merges --onto files-master master &&
+	verbose test "$(commit_message HEAD~)" = "master4" &&
 	verbose test "$(commit_message HEAD)" = "files_subtree/master5"
 '
 
 # FAILURE: Does not preserve master4.
-test_expect_failure 'Rebase -Xsubtree --keep-empty --preserve-merges --onto commit 4' '
+test_expect_failure REBASE_P 'Rebase -Xsubtree --keep-empty --preserve-merges --onto commit' '
 	reset_rebase &&
-	git checkout -b rebase-keep-empty-4 master &&
-	git filter-branch --prune-empty -f --subdirectory-filter files_subtree &&
-	git commit -m "Empty commit" --allow-empty &&
-	git rebase -Xsubtree=files_subtree --keep-empty --preserve-merges --onto files-master master &&
-	verbose test "$(commit_message HEAD~2)" = "files_subtree/master4"
-'
-
-# FAILURE: Does not preserve master5.
-test_expect_failure 'Rebase -Xsubtree --keep-empty --preserve-merges --onto commit 5' '
-	reset_rebase &&
-	git checkout -b rebase-keep-empty-5 master &&
-	git filter-branch --prune-empty -f --subdirectory-filter files_subtree &&
-	git commit -m "Empty commit" --allow-empty &&
-	git rebase -Xsubtree=files_subtree --keep-empty --preserve-merges --onto files-master master &&
-	verbose test "$(commit_message HEAD~)" = "files_subtree/master5"
-'
-
-# FAILURE: Does not preserve Empty.
-test_expect_failure 'Rebase -Xsubtree --keep-empty --preserve-merges --onto empty commit' '
-	reset_rebase &&
-	git checkout -b rebase-keep-empty-empty master &&
-	git filter-branch --prune-empty -f --subdirectory-filter files_subtree &&
-	git commit -m "Empty commit" --allow-empty &&
+	git checkout -b rebase-keep-empty to-rebase &&
 	git rebase -Xsubtree=files_subtree --keep-empty --preserve-merges --onto files-master master &&
+	verbose test "$(commit_message HEAD~2)" = "master4" &&
+	verbose test "$(commit_message HEAD~)" = "files_subtree/master5" &&
 	verbose test "$(commit_message HEAD)" = "Empty commit"
 '
 
-# FAILURE: fatal: Could not parse object
-test_expect_failure 'Rebase -Xsubtree --onto commit 4' '
+test_expect_success 'Rebase -Xsubtree --keep-empty --onto commit' '
 	reset_rebase &&
-	git checkout -b rebase-onto-4 master &&
-	git filter-branch --prune-empty -f --subdirectory-filter files_subtree &&
-	git commit -m "Empty commit" --allow-empty &&
-	git rebase -Xsubtree=files_subtree --onto files-master master &&
-	verbose test "$(commit_message HEAD~2)" = "files_subtree/master4"
+	git checkout -b rebase-onto to-rebase &&
+	test_must_fail git rebase -Xsubtree=files_subtree --keep-empty --onto files-master master &&
+	: first pick results in no changes &&
+	git rebase --continue &&
+	verbose test "$(commit_message HEAD~2)" = "master4" &&
+	verbose test "$(commit_message HEAD~)" = "files_subtree/master5" &&
+	verbose test "$(commit_message HEAD)" = "Empty commit"
 '
 
-# FAILURE: fatal: Could not parse object
-test_expect_failure 'Rebase -Xsubtree --onto commit 5' '
-	reset_rebase &&
-	git checkout -b rebase-onto-5 master &&
-	git filter-branch --prune-empty -f --subdirectory-filter files_subtree &&
-	git commit -m "Empty commit" --allow-empty &&
-	git rebase -Xsubtree=files_subtree --onto files-master master &&
-	verbose test "$(commit_message HEAD~)" = "files_subtree/master5"
-'
-# FAILURE: fatal: Could not parse object
-test_expect_failure 'Rebase -Xsubtree --onto empty commit' '
+test_expect_success 'Rebase -Xsubtree --keep-empty --rebase-merges --onto commit' '
 	reset_rebase &&
-	git checkout -b rebase-onto-empty master &&
-	git filter-branch --prune-empty -f --subdirectory-filter files_subtree &&
-	git commit -m "Empty commit" --allow-empty &&
-	git rebase -Xsubtree=files_subtree --onto files-master master &&
+	git checkout -b rebase-merges-onto to-rebase &&
+	test_must_fail git rebase -Xsubtree=files_subtree --keep-empty --rebase-merges --onto files-master --root &&
+	: first pick results in no changes &&
+	git rebase --continue &&
+	verbose test "$(commit_message HEAD~2)" = "master4" &&
+	verbose test "$(commit_message HEAD~)" = "files_subtree/master5" &&
 	verbose test "$(commit_message HEAD)" = "Empty commit"
 '
 
diff -pruN 1.2.1+git2.18.0-1/git/t/t3429-rebase-edit-todo.sh 1.2.3+git2.25.1-1/git/t/t3429-rebase-edit-todo.sh
--- 1.2.1+git2.18.0-1/git/t/t3429-rebase-edit-todo.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t3429-rebase-edit-todo.sh	2020-02-17 04:47:35.000000000 +0000
@@ -3,12 +3,83 @@
 test_description='rebase should reread the todo file if an exec modifies it'
 
 . ./test-lib.sh
+. "$TEST_DIRECTORY"/lib-rebase.sh
+
+test_expect_success 'setup' '
+	test_commit first file &&
+	test_commit second file &&
+	test_commit third file
+'
 
 test_expect_success 'rebase exec modifies rebase-todo' '
-	test_commit initial &&
 	todo=.git/rebase-merge/git-rebase-todo &&
 	git rebase HEAD -x "echo exec touch F >>$todo" &&
 	test -e F
 '
 
+test_expect_success 'loose object cache vs re-reading todo list' '
+	GIT_REBASE_TODO=.git/rebase-merge/git-rebase-todo &&
+	export GIT_REBASE_TODO &&
+	write_script append-todo.sh <<-\EOS &&
+	# For values 5 and 6, this yields SHA-1s with the same first two digits
+	echo "pick $(git rev-parse --short \
+		$(printf "%s\\n" \
+			"tree $EMPTY_TREE" \
+			"author A U Thor <author@example.org> $1 +0000" \
+			"committer A U Thor <author@example.org> $1 +0000" \
+			"" \
+			"$1" |
+		  git hash-object -t commit -w --stdin))" >>$GIT_REBASE_TODO
+
+	shift
+	test -z "$*" ||
+	echo "exec $0 $*" >>$GIT_REBASE_TODO
+	EOS
+
+	git rebase HEAD -x "./append-todo.sh 5 6"
+'
+
+test_expect_success 'todo is re-read after reword and squash' '
+	write_script reword-editor.sh <<-\EOS &&
+	GIT_SEQUENCE_EDITOR="echo \"exec echo $(cat file) >>actual\" >>" \
+		git rebase --edit-todo
+	EOS
+
+	test_write_lines first third >expected &&
+	set_fake_editor &&
+	GIT_SEQUENCE_EDITOR="$EDITOR" FAKE_LINES="reword 1 squash 2 fixup 3" \
+		GIT_EDITOR=./reword-editor.sh git rebase -i --root third &&
+	test_cmp expected actual
+'
+
+test_expect_success 're-reading todo doesnt interfere with revert --edit' '
+	git reset --hard third &&
+
+	git revert --edit third second &&
+
+	cat >expect <<-\EOF &&
+	Revert "second"
+	Revert "third"
+	third
+	second
+	first
+	EOF
+	git log --format="%s" >actual &&
+	test_cmp expect actual
+'
+
+test_expect_success 're-reading todo doesnt interfere with cherry-pick --edit' '
+	git reset --hard first &&
+
+	git cherry-pick --edit second third &&
+
+	cat >expect <<-\EOF &&
+	third
+	second
+	first
+	EOF
+	git log --format="%s" >actual &&
+	test_cmp expect actual
+'
+
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t3430-rebase-merges.sh 1.2.3+git2.25.1-1/git/t/t3430-rebase-merges.sh
--- 1.2.1+git2.18.0-1/git/t/t3430-rebase-merges.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t3430-rebase-merges.sh	2020-02-17 04:47:35.000000000 +0000
@@ -13,8 +13,10 @@ Initial setup:
     -- B --                   (first)
    /       \
  A - C - D - E - H            (master)
-       \       /
-         F - G                (second)
+   \    \       /
+    \    F - G                (second)
+     \
+      Conflicting-G
 '
 . ./test-lib.sh
 . "$TEST_DIRECTORY"/lib-rebase.sh
@@ -35,21 +37,30 @@ test_expect_success 'setup' '
 	test_commit A &&
 	git checkout -b first &&
 	test_commit B &&
+	b=$(git rev-parse --short HEAD) &&
 	git checkout master &&
 	test_commit C &&
+	c=$(git rev-parse --short HEAD) &&
 	test_commit D &&
+	d=$(git rev-parse --short HEAD) &&
 	git merge --no-commit B &&
 	test_tick &&
 	git commit -m E &&
 	git tag -m E E &&
+	e=$(git rev-parse --short HEAD) &&
 	git checkout -b second C &&
 	test_commit F &&
+	f=$(git rev-parse --short HEAD) &&
 	test_commit G &&
+	g=$(git rev-parse --short HEAD) &&
 	git checkout master &&
 	git merge --no-commit G &&
 	test_tick &&
 	git commit -m H &&
-	git tag -m H H
+	h=$(git rev-parse --short HEAD) &&
+	git tag -m H H &&
+	git checkout A &&
+	test_commit conflicting-G G.t
 '
 
 test_expect_success 'create completely different structure' '
@@ -72,7 +83,7 @@ test_expect_success 'create completely d
 	EOF
 	test_config sequence.editor \""$PWD"/replace-editor.sh\" &&
 	test_tick &&
-	git rebase -i -r A &&
+	git rebase -i -r A master &&
 	test_cmp_graph <<-\EOF
 	*   Merge the topic branch '\''onebranch'\''
 	|\
@@ -89,24 +100,24 @@ test_expect_success 'create completely d
 '
 
 test_expect_success 'generate correct todo list' '
-	cat >expect <<-\EOF &&
+	cat >expect <<-EOF &&
 	label onto
 
 	reset onto
-	pick d9df450 B
+	pick $b B
 	label E
 
 	reset onto
-	pick 5dee784 C
+	pick $c C
 	label branch-point
-	pick ca2c861 F
-	pick 088b00a G
+	pick $f F
+	pick $g G
 	label H
 
 	reset branch-point # C
-	pick 12bd07b D
-	merge -C 2051b56 E # E
-	merge -C 233d48a H # H
+	pick $d D
+	merge -C $e E # E
+	merge -C $h H # H
 
 	EOF
 
@@ -121,11 +132,11 @@ test_expect_success '`reset` refuses to
 	: >dont-overwrite-untracked.t &&
 	echo "reset refs/tags/dont-overwrite-untracked" >script-from-scratch &&
 	test_config sequence.editor \""$PWD"/replace-editor.sh\" &&
-	test_must_fail git rebase -r HEAD &&
+	test_must_fail git rebase -ir HEAD &&
 	git rebase --abort
 '
 
-test_expect_success 'failed `merge` writes patch (may be rescheduled, too)' '
+test_expect_success 'failed `merge -C` writes patch (may be rescheduled, too)' '
 	test_when_finished "test_might_fail git rebase --abort" &&
 	git checkout -b conflicting-merge A &&
 
@@ -141,13 +152,37 @@ test_expect_success 'failed `merge` writ
 
 	: fail because of merge conflict &&
 	rm G.t .git/rebase-merge/patch &&
-	git reset --hard &&
-	test_commit conflicting-G G.t not-G conflicting-G &&
+	git reset --hard conflicting-G &&
 	test_must_fail git rebase --continue &&
 	! grep "^merge -C .* G$" .git/rebase-merge/git-rebase-todo &&
 	test_path_is_file .git/rebase-merge/patch
 '
 
+test_expect_success 'failed `merge <branch>` does not crash' '
+	test_when_finished "test_might_fail git rebase --abort" &&
+	git checkout conflicting-G &&
+
+	echo "merge G" >script-from-scratch &&
+	test_config sequence.editor \""$PWD"/replace-editor.sh\" &&
+	test_tick &&
+	test_must_fail git rebase -ir HEAD &&
+	! grep "^merge G$" .git/rebase-merge/git-rebase-todo &&
+	grep "^Merge branch ${SQ}G${SQ}$" .git/rebase-merge/message
+'
+
+test_expect_success 'fast-forward merge -c still rewords' '
+	git checkout -b fast-forward-merge-c H &&
+	(
+		set_fake_editor &&
+		FAKE_COMMIT_MESSAGE=edited \
+			GIT_SEQUENCE_EDITOR="echo merge -c H G >" \
+			git rebase -ir @^
+	) &&
+	echo edited >expected &&
+	git log --pretty=format:%B -1 >actual &&
+	test_cmp expected actual
+'
+
 test_expect_success 'with a branch tip that was cherry-picked already' '
 	git checkout -b already-upstream master &&
 	base="$(git rev-parse --verify HEAD)" &&
@@ -208,8 +243,24 @@ test_expect_success 'refs/rewritten/* is
 	test_cmp_rev HEAD "$(cat wt/b)"
 '
 
+test_expect_success '--abort cleans up refs/rewritten' '
+	git checkout -b abort-cleans-refs-rewritten H &&
+	GIT_SEQUENCE_EDITOR="echo break >>" git rebase -ir @^ &&
+	git rev-parse --verify refs/rewritten/onto &&
+	git rebase --abort &&
+	test_must_fail git rev-parse --verify refs/rewritten/onto
+'
+
+test_expect_success '--quit cleans up refs/rewritten' '
+	git checkout -b quit-cleans-refs-rewritten H &&
+	GIT_SEQUENCE_EDITOR="echo break >>" git rebase -ir @^ &&
+	git rev-parse --verify refs/rewritten/onto &&
+	git rebase --quit &&
+	test_must_fail git rev-parse --verify refs/rewritten/onto
+'
+
 test_expect_success 'post-rewrite hook and fixups work for merges' '
-	git checkout -b post-rewrite &&
+	git checkout -b post-rewrite H &&
 	test_commit same1 &&
 	git reset --hard HEAD^ &&
 	test_commit same2 &&
@@ -255,7 +306,7 @@ test_expect_success 'root commits' '
 	EOF
 	test_config sequence.editor \""$PWD"/replace-editor.sh\" &&
 	test_tick &&
-	git rebase -i --force --root -r &&
+	git rebase -i --force-rebase --root -r &&
 	test "Parsnip" = "$(git show -s --format=%an HEAD^)" &&
 	test $(git rev-parse second-root^0) != $(git rev-parse HEAD^) &&
 	test $(git rev-parse second-root:second-root.t) = \
@@ -295,7 +346,7 @@ test_expect_success 'A root commit can b
 	git merge --allow-unrelated-histories khnum &&
 	test_tick &&
 	git rebase -f -r HEAD^ &&
-	! test_cmp_rev HEAD^2 khnum &&
+	test_cmp_rev ! HEAD^2 khnum &&
 	test_cmp_graph HEAD^.. <<-\EOF &&
 	*   Merge branch '\''khnum'\'' into asherah
 	|\
@@ -329,4 +380,119 @@ test_expect_success 'labels that are obj
 	! grep "^label $third$" .git/ORIGINAL-TODO
 '
 
+test_expect_success 'octopus merges' '
+	git checkout -b three &&
+	test_commit before-octopus &&
+	test_commit three &&
+	git checkout -b two HEAD^ &&
+	test_commit two &&
+	git checkout -b one HEAD^ &&
+	test_commit one &&
+	test_tick &&
+	(GIT_AUTHOR_NAME="Hank" GIT_AUTHOR_EMAIL="hank@sea.world" \
+	 git merge -m "Tüntenfüsch" two three) &&
+
+	: fast forward if possible &&
+	before="$(git rev-parse --verify HEAD)" &&
+	test_tick &&
+	git rebase -i -r HEAD^^ &&
+	test_cmp_rev HEAD $before &&
+
+	test_tick &&
+	git rebase -i --force-rebase -r HEAD^^ &&
+	test "Hank" = "$(git show -s --format=%an HEAD)" &&
+	test "$before" != $(git rev-parse HEAD) &&
+	test_cmp_graph HEAD^^.. <<-\EOF
+	*-.   Tüntenfüsch
+	|\ \
+	| | * three
+	| * | two
+	| |/
+	* / one
+	|/
+	o before-octopus
+	EOF
+'
+
+test_expect_success 'with --autosquash and --exec' '
+	git checkout -b with-exec H &&
+	echo Booh >B.t &&
+	test_tick &&
+	git commit --fixup B B.t &&
+	write_script show.sh <<-\EOF &&
+	subject="$(git show -s --format=%s HEAD)"
+	content="$(git diff HEAD^! | tail -n 1)"
+	echo "$subject: $content"
+	EOF
+	test_tick &&
+	git rebase -ir --autosquash --exec ./show.sh A >actual &&
+	grep "B: +Booh" actual &&
+	grep "E: +Booh" actual &&
+	grep "G: +G" actual
+'
+
+test_expect_success '--continue after resolving conflicts after a merge' '
+	git checkout -b already-has-g E &&
+	git cherry-pick E..G &&
+	test_commit H2 &&
+
+	git checkout -b conflicts-in-merge H &&
+	test_commit H2 H2.t conflicts H2-conflict &&
+	test_must_fail git rebase -r already-has-g &&
+	grep conflicts H2.t &&
+	echo resolved >H2.t &&
+	git add -u &&
+	git rebase --continue &&
+	test_must_fail git rev-parse --verify HEAD^2 &&
+	test_path_is_missing .git/MERGE_HEAD
+'
+
+test_expect_success '--rebase-merges with strategies' '
+	git checkout -b with-a-strategy F &&
+	test_tick &&
+	git merge -m "Merge conflicting-G" conflicting-G &&
+
+	: first, test with a merge strategy option &&
+	git rebase -ir -Xtheirs G &&
+	echo conflicting-G >expect &&
+	test_cmp expect G.t &&
+
+	: now, try with a merge strategy other than recursive &&
+	git reset --hard @{1} &&
+	write_script git-merge-override <<-\EOF &&
+	echo overridden$1 >>G.t
+	git add G.t
+	EOF
+	PATH="$PWD:$PATH" git rebase -ir -s override -Xxopt G &&
+	test_write_lines G overridden--xopt >expect &&
+	test_cmp expect G.t
+'
+
+test_expect_success '--rebase-merges with commit that can generate bad characters for filename' '
+	git checkout -b colon-in-label E &&
+	git merge -m "colon: this should work" G &&
+	git rebase --rebase-merges --force-rebase E
+'
+
+test_expect_success '--rebase-merges with message matched with onto label' '
+	git checkout -b onto-label E &&
+	git merge -m onto G &&
+	git rebase --rebase-merges --force-rebase E &&
+	test_cmp_graph <<-\EOF
+	*   onto
+	|\
+	| * G
+	| * F
+	* |   E
+	|\ \
+	| * | B
+	* | | D
+	| |/
+	|/|
+	* | C
+	|/
+	* A
+	EOF
+'
+
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t3431-rebase-fork-point.sh 1.2.3+git2.25.1-1/git/t/t3431-rebase-fork-point.sh
--- 1.2.1+git2.18.0-1/git/t/t3431-rebase-fork-point.sh	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t3431-rebase-fork-point.sh	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,57 @@
+#!/bin/sh
+#
+# Copyright (c) 2019 Denton Liu
+#
+
+test_description='git rebase --fork-point test'
+
+. ./test-lib.sh
+
+# A---B---D---E    (master)
+#      \
+#       C*---F---G (side)
+#
+# C was formerly part of master but master was rewound to remove C
+#
+test_expect_success setup '
+	test_commit A &&
+	test_commit B &&
+	test_commit C &&
+	git branch -t side &&
+	git reset --hard HEAD^ &&
+	test_commit D &&
+	test_commit E &&
+	git checkout side &&
+	test_commit F &&
+	test_commit G
+'
+
+test_rebase () {
+	expected="$1" &&
+	shift &&
+	test_expect_success "git rebase $*" "
+		git checkout master &&
+		git reset --hard E &&
+		git checkout side &&
+		git reset --hard G &&
+		git rebase $* &&
+		test_write_lines $expected >expect &&
+		git log --pretty=%s >actual &&
+		test_cmp expect actual
+	"
+}
+
+test_rebase 'G F E D B A'
+test_rebase 'G F D B A' --onto D
+test_rebase 'G F B A' --keep-base
+test_rebase 'G F C E D B A' --no-fork-point
+test_rebase 'G F C D B A' --no-fork-point --onto D
+test_rebase 'G F C B A' --no-fork-point --keep-base
+test_rebase 'G F E D B A' --fork-point refs/heads/master
+test_rebase 'G F D B A' --fork-point --onto D refs/heads/master
+test_rebase 'G F B A' --fork-point --keep-base refs/heads/master
+test_rebase 'G F C E D B A' refs/heads/master
+test_rebase 'G F C D B A' --onto D refs/heads/master
+test_rebase 'G F C B A' --keep-base refs/heads/master
+
+test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t3432-rebase-fast-forward.sh 1.2.3+git2.25.1-1/git/t/t3432-rebase-fast-forward.sh
--- 1.2.1+git2.18.0-1/git/t/t3432-rebase-fast-forward.sh	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t3432-rebase-fast-forward.sh	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,125 @@
+#!/bin/sh
+#
+# Copyright (c) 2019 Denton Liu
+#
+
+test_description='ensure rebase fast-forwards commits when possible'
+
+. ./test-lib.sh
+
+test_expect_success setup '
+	test_commit A &&
+	test_commit B &&
+	test_commit C &&
+	test_commit D &&
+	git checkout -t -b side
+'
+
+test_rebase_same_head () {
+	status_n="$1" &&
+	shift &&
+	what_n="$1" &&
+	shift &&
+	cmp_n="$1" &&
+	shift &&
+	status_f="$1" &&
+	shift &&
+	what_f="$1" &&
+	shift &&
+	cmp_f="$1" &&
+	shift &&
+	test_rebase_same_head_ $status_n $what_n $cmp_n "" "$*" &&
+	test_rebase_same_head_ $status_f $what_f $cmp_f " --no-ff" "$*"
+}
+
+test_rebase_same_head_ () {
+	status="$1" &&
+	shift &&
+	what="$1" &&
+	shift &&
+	cmp="$1" &&
+	shift &&
+	flag="$1"
+	shift &&
+	test_expect_$status "git rebase$flag $* with $changes is $what with $cmp HEAD" "
+		oldhead=\$(git rev-parse HEAD) &&
+		test_when_finished 'git reset --hard \$oldhead' &&
+		git rebase$flag $* >stdout &&
+		if test $what = work
+		then
+			# Must check this case first, for 'is up to
+			# date, rebase forced[...]rewinding head' cases
+			test_i18ngrep 'rewinding head' stdout
+		elif test $what = noop
+		then
+			test_i18ngrep 'is up to date' stdout &&
+			test_i18ngrep ! 'rebase forced' stdout
+		elif test $what = noop-force
+		then
+			test_i18ngrep 'is up to date, rebase forced' stdout
+		fi &&
+		newhead=\$(git rev-parse HEAD) &&
+		if test $cmp = same
+		then
+			test_cmp_rev \$oldhead \$newhead
+		elif test $cmp = diff
+		then
+			test_cmp_rev ! \$oldhead \$newhead
+		fi
+	"
+}
+
+changes='no changes'
+test_rebase_same_head success noop same success work same
+test_rebase_same_head success noop same success noop-force same master
+test_rebase_same_head success noop same success noop-force diff --onto B B
+test_rebase_same_head success noop same success noop-force diff --onto B... B
+test_rebase_same_head success noop same success noop-force same --onto master... master
+test_rebase_same_head success noop same success noop-force same --keep-base master
+test_rebase_same_head success noop same success noop-force same --keep-base
+test_rebase_same_head success noop same success noop-force same --no-fork-point
+test_rebase_same_head success noop same success noop-force same --keep-base --no-fork-point
+test_rebase_same_head success noop same success work same --fork-point master
+test_rebase_same_head success noop same success work diff --fork-point --onto B B
+test_rebase_same_head success noop same success work diff --fork-point --onto B... B
+test_rebase_same_head success noop same success work same --fork-point --onto master... master
+test_rebase_same_head success noop same success work same --keep-base --keep-base master
+
+test_expect_success 'add work same to side' '
+	test_commit E
+'
+
+changes='our changes'
+test_rebase_same_head success noop same success work same
+test_rebase_same_head success noop same success noop-force same master
+test_rebase_same_head success noop same success noop-force diff --onto B B
+test_rebase_same_head success noop same success noop-force diff --onto B... B
+test_rebase_same_head success noop same success noop-force same --onto master... master
+test_rebase_same_head success noop same success noop-force same --keep-base master
+test_rebase_same_head success noop same success noop-force same --keep-base
+test_rebase_same_head success noop same success noop-force same --no-fork-point
+test_rebase_same_head success noop same success noop-force same --keep-base --no-fork-point
+test_rebase_same_head success noop same success work same --fork-point master
+test_rebase_same_head success noop same success work diff --fork-point --onto B B
+test_rebase_same_head success noop same success work diff --fork-point --onto B... B
+test_rebase_same_head success noop same success work same --fork-point --onto master... master
+test_rebase_same_head success noop same success work same --fork-point --keep-base master
+
+test_expect_success 'add work same to upstream' '
+	git checkout master &&
+	test_commit F &&
+	git checkout side
+'
+
+changes='our and their changes'
+test_rebase_same_head success noop same success noop-force diff --onto B B
+test_rebase_same_head success noop same success noop-force diff --onto B... B
+test_rebase_same_head success noop same success work diff --onto master... master
+test_rebase_same_head success noop same success work diff --keep-base master
+test_rebase_same_head success noop same success work diff --keep-base
+test_rebase_same_head failure work same success work diff --fork-point --onto B B
+test_rebase_same_head failure work same success work diff --fork-point --onto B... B
+test_rebase_same_head success noop same success work diff --fork-point --onto master... master
+test_rebase_same_head success noop same success work diff --fork-point --keep-base master
+
+test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t3434/eucJP.txt 1.2.3+git2.25.1-1/git/t/t3434/eucJP.txt
--- 1.2.1+git2.18.0-1/git/t/t3434/eucJP.txt	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t3434/eucJP.txt	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,4 @@
+ϤҤۤ
+
+ƤΤΤǡ
+ͤۤפݤޤӤء
diff -pruN 1.2.1+git2.18.0-1/git/t/t3434/ISO8859-1.txt 1.2.3+git2.25.1-1/git/t/t3434/ISO8859-1.txt
--- 1.2.1+git2.18.0-1/git/t/t3434/ISO8859-1.txt	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t3434/ISO8859-1.txt	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,3 @@
+
+
+bdfg
diff -pruN 1.2.1+git2.18.0-1/git/t/t3434-rebase-i18n.sh 1.2.3+git2.25.1-1/git/t/t3434-rebase-i18n.sh
--- 1.2.1+git2.18.0-1/git/t/t3434-rebase-i18n.sh	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t3434-rebase-i18n.sh	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,84 @@
+#!/bin/sh
+#
+# Copyright (c) 2019 Doan Tran Cong Danh
+#
+
+test_description='rebase with changing encoding
+
+Initial setup:
+
+1 - 2              master
+ \
+  3 - 4            first
+   \
+    5 - 6          second
+'
+
+. ./test-lib.sh
+
+compare_msg () {
+	iconv -f "$2" -t "$3" "$TEST_DIRECTORY/t3434/$1" >expect &&
+	git cat-file commit HEAD >raw &&
+	sed "1,/^$/d" raw >actual &&
+	test_cmp expect actual
+}
+
+test_expect_success setup '
+	test_commit one &&
+	git branch first &&
+	test_commit two &&
+	git switch first &&
+	test_commit three &&
+	git branch second &&
+	test_commit four &&
+	git switch second &&
+	test_commit five &&
+	test_commit six
+'
+
+test_expect_success 'rebase --rebase-merges update encoding eucJP to UTF-8' '
+	git switch -c merge-eucJP-UTF-8 first &&
+	git config i18n.commitencoding eucJP &&
+	git merge -F "$TEST_DIRECTORY/t3434/eucJP.txt" second &&
+	git config i18n.commitencoding UTF-8 &&
+	git rebase --rebase-merges master &&
+	compare_msg eucJP.txt eucJP UTF-8
+'
+
+test_expect_success 'rebase --rebase-merges update encoding eucJP to ISO-2022-JP' '
+	git switch -c merge-eucJP-ISO-2022-JP first &&
+	git config i18n.commitencoding eucJP &&
+	git merge -F "$TEST_DIRECTORY/t3434/eucJP.txt" second &&
+	git config i18n.commitencoding ISO-2022-JP &&
+	git rebase --rebase-merges master &&
+	compare_msg eucJP.txt eucJP ISO-2022-JP
+'
+
+test_rebase_continue_update_encode () {
+	old=$1
+	new=$2
+	msgfile=$3
+	test_expect_success "rebase --continue update from $old to $new" '
+		(git rebase --abort || : abort current git-rebase failure) &&
+		git switch -c conflict-$old-$new one &&
+		echo for-conflict >two.t &&
+		git add two.t &&
+		git config i18n.commitencoding $old &&
+		git commit -F "$TEST_DIRECTORY/t3434/$msgfile" &&
+		git config i18n.commitencoding $new &&
+		test_must_fail git rebase -m master &&
+		test -f .git/rebase-merge/message &&
+		git stripspace <.git/rebase-merge/message >two.t &&
+		git add two.t &&
+		git rebase --continue &&
+		compare_msg $msgfile $old $new &&
+		: git-commit assume invalid utf-8 is latin1 &&
+		test_cmp expect two.t
+	'
+}
+
+test_rebase_continue_update_encode ISO-8859-1 UTF-8 ISO8859-1.txt
+test_rebase_continue_update_encode eucJP UTF-8 eucJP.txt
+test_rebase_continue_update_encode eucJP ISO-2022-JP eucJP.txt
+
+test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t3501-revert-cherry-pick.sh 1.2.3+git2.25.1-1/git/t/t3501-revert-cherry-pick.sh
--- 1.2.1+git2.18.0-1/git/t/t3501-revert-cherry-pick.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t3501-revert-cherry-pick.sh	2020-02-17 04:47:35.000000000 +0000
@@ -106,7 +106,7 @@ test_expect_success 'cherry-pick on unbo
 	rm -rf * &&
 	git cherry-pick initial &&
 	git diff --quiet initial &&
-	! test_cmp_rev initial HEAD
+	test_cmp_rev ! initial HEAD
 '
 
 test_expect_success 'cherry-pick "-" to pick from previous branch' '
@@ -150,7 +150,7 @@ test_expect_success 'cherry-pick works w
 	test_tick &&
 	git commit -m renamed &&
 	echo modified >renamed &&
-	git cherry-pick refs/heads/unrelated >out &&
+	git cherry-pick refs/heads/unrelated &&
 	test $(git rev-parse :0:renamed) = $(git rev-parse HEAD~2:to-rename.t) &&
 	grep -q "^modified$" renamed
 '
diff -pruN 1.2.1+git2.18.0-1/git/t/t3502-cherry-pick-merge.sh 1.2.3+git2.25.1-1/git/t/t3502-cherry-pick-merge.sh
--- 1.2.1+git2.18.0-1/git/t/t3502-cherry-pick-merge.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t3502-cherry-pick-merge.sh	2020-02-17 04:47:35.000000000 +0000
@@ -40,12 +40,12 @@ test_expect_success 'cherry-pick -m comp
 	test_expect_code 129 git cherry-pick -m 0 b
 '
 
-test_expect_success 'cherry-pick a non-merge with -m should fail' '
+test_expect_success 'cherry-pick explicit first parent of a non-merge' '
 
 	git reset --hard &&
 	git checkout a^0 &&
-	test_expect_code 128 git cherry-pick -m 1 b &&
-	git diff --exit-code a --
+	git cherry-pick -m 1 b &&
+	git diff --exit-code c --
 
 '
 
@@ -84,12 +84,12 @@ test_expect_success 'cherry pick a merge
 
 '
 
-test_expect_success 'revert a non-merge with -m should fail' '
+test_expect_success 'revert explicit first parent of a non-merge' '
 
 	git reset --hard &&
 	git checkout c^0 &&
-	test_must_fail git revert -m 1 b &&
-	git diff --exit-code c
+	git revert -m 1 b &&
+	git diff --exit-code a --
 
 '
 
diff -pruN 1.2.1+git2.18.0-1/git/t/t3505-cherry-pick-empty.sh 1.2.3+git2.25.1-1/git/t/t3505-cherry-pick-empty.sh
--- 1.2.1+git2.18.0-1/git/t/t3505-cherry-pick-empty.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t3505-cherry-pick-empty.sh	2020-02-17 04:47:35.000000000 +0000
@@ -11,17 +11,14 @@ test_expect_success setup '
 	test_tick &&
 	git commit -m "first" &&
 
-	git checkout -b empty-branch &&
-	test_tick &&
-	git commit --allow-empty -m "empty" &&
-
+	git checkout -b empty-message-branch &&
 	echo third >> file1 &&
 	git add file1 &&
 	test_tick &&
 	git commit --allow-empty-message -m "" &&
 
 	git checkout master &&
-	git checkout -b empty-branch2 &&
+	git checkout -b empty-change-branch &&
 	test_tick &&
 	git commit --allow-empty -m "empty"
 
@@ -29,7 +26,7 @@ test_expect_success setup '
 
 test_expect_success 'cherry-pick an empty commit' '
 	git checkout master &&
-	test_expect_code 1 git cherry-pick empty-branch^
+	test_expect_code 1 git cherry-pick empty-change-branch
 '
 
 test_expect_success 'index lockfile was removed' '
@@ -37,8 +34,9 @@ test_expect_success 'index lockfile was
 '
 
 test_expect_success 'cherry-pick a commit with an empty message' '
+	test_when_finished "git reset --hard empty-message-branch~1" &&
 	git checkout master &&
-	test_expect_code 1 git cherry-pick empty-branch
+	git cherry-pick empty-message-branch
 '
 
 test_expect_success 'index lockfile was removed' '
@@ -47,7 +45,7 @@ test_expect_success 'index lockfile was
 
 test_expect_success 'cherry-pick a commit with an empty message with --allow-empty-message' '
 	git checkout -f master &&
-	git cherry-pick --allow-empty-message empty-branch
+	git cherry-pick --allow-empty-message empty-message-branch
 '
 
 test_expect_success 'cherry pick an empty non-ff commit without --allow-empty' '
@@ -55,12 +53,12 @@ test_expect_success 'cherry pick an empt
 	echo fourth >>file2 &&
 	git add file2 &&
 	git commit -m "fourth" &&
-	test_must_fail git cherry-pick empty-branch2
+	test_must_fail git cherry-pick empty-change-branch
 '
 
 test_expect_success 'cherry pick an empty non-ff commit with --allow-empty' '
 	git checkout master &&
-	git cherry-pick --allow-empty empty-branch2
+	git cherry-pick --allow-empty empty-change-branch
 '
 
 test_expect_success 'cherry pick with --keep-redundant-commits' '
diff -pruN 1.2.1+git2.18.0-1/git/t/t3506-cherry-pick-ff.sh 1.2.3+git2.25.1-1/git/t/t3506-cherry-pick-ff.sh
--- 1.2.1+git2.18.0-1/git/t/t3506-cherry-pick-ff.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t3506-cherry-pick-ff.sh	2020-02-17 04:47:35.000000000 +0000
@@ -16,7 +16,11 @@ test_expect_success setup '
 	git add file1 &&
 	test_tick &&
 	git commit -m "second" &&
-	git tag second
+	git tag second &&
+	test_oid_cache <<-EOF
+	cp_ff sha1:1df192cd8bc58a2b275d842cede4d221ad9000d1
+	cp_ff sha256:e70d6b7fc064bddb516b8d512c9057094b96ce6ff08e12080acc4fe7f1d60a1d
+	EOF
 '
 
 test_expect_success 'cherry-pick using --ff fast forwards' '
@@ -64,10 +68,10 @@ test_expect_success 'merge setup' '
 	git checkout -b new A
 '
 
-test_expect_success 'cherry-pick a non-merge with --ff and -m should fail' '
+test_expect_success 'cherry-pick explicit first parent of a non-merge with --ff' '
 	git reset --hard A -- &&
-	test_must_fail git cherry-pick --ff -m 1 B &&
-	git diff --exit-code A --
+	git cherry-pick --ff -m 1 B &&
+	git diff --exit-code C --
 '
 
 test_expect_success 'cherry pick a merge with --ff but without -m should fail' '
@@ -102,7 +106,7 @@ test_expect_success 'cherry pick a root
 	git add file2 &&
 	git commit --amend -m "file2" &&
 	git cherry-pick --ff first &&
-	test "$(git rev-parse --verify HEAD)" = "1df192cd8bc58a2b275d842cede4d221ad9000d1"
+	test "$(git rev-parse --verify HEAD)" = "$(test_oid cp_ff)"
 '
 
 test_expect_success 'cherry-pick --ff on unborn branch' '
diff -pruN 1.2.1+git2.18.0-1/git/t/t3507-cherry-pick-conflict.sh 1.2.3+git2.25.1-1/git/t/t3507-cherry-pick-conflict.sh
--- 1.2.1+git2.18.0-1/git/t/t3507-cherry-pick-conflict.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t3507-cherry-pick-conflict.sh	2020-02-17 04:47:35.000000000 +0000
@@ -25,6 +25,11 @@ test_expect_success setup '
 	test_commit base foo b &&
 	test_commit picked foo c &&
 	test_commit --signoff picked-signed foo d &&
+	git checkout -b topic initial &&
+	test_commit redundant-pick foo c redundant &&
+	git commit --allow-empty --allow-empty-message &&
+	git tag empty &&
+	git checkout master &&
 	git config advice.detachedhead false
 
 '
@@ -88,7 +93,7 @@ test_expect_success 'cherry-pick --no-co
 
 test_expect_success 'cherry-pick w/dirty tree does not set CHERRY_PICK_HEAD' '
 	pristine_detach initial &&
-	echo foo > foo &&
+	echo foo >foo &&
 	test_must_fail git cherry-pick base &&
 	test_must_fail git rev-parse --verify CHERRY_PICK_HEAD
 '
@@ -96,7 +101,7 @@ test_expect_success 'cherry-pick w/dirty
 test_expect_success \
 	'cherry-pick --strategy=resolve w/dirty tree does not set CHERRY_PICK_HEAD' '
 	pristine_detach initial &&
-	echo foo > foo &&
+	echo foo >foo &&
 	test_must_fail git cherry-pick --strategy=resolve base &&
 	test_must_fail git rev-parse --verify CHERRY_PICK_HEAD
 '
@@ -156,6 +161,25 @@ test_expect_success 'successful commit c
 
 	test_must_fail git rev-parse --verify CHERRY_PICK_HEAD
 '
+test_expect_success 'successful final commit clears cherry-pick state' '
+	pristine_detach initial &&
+
+	test_must_fail git cherry-pick base picked-signed &&
+	echo resolved >foo &&
+	test_path_is_file .git/sequencer/todo &&
+	git commit -a &&
+	test_must_fail test_path_exists .git/sequencer
+'
+
+test_expect_success 'reset after final pick clears cherry-pick state' '
+	pristine_detach initial &&
+
+	test_must_fail git cherry-pick base picked-signed &&
+	echo resolved >foo &&
+	test_path_is_file .git/sequencer/todo &&
+	git reset &&
+	test_must_fail test_path_exists .git/sequencer
+'
 
 test_expect_success 'failed cherry-pick produces dirty index' '
 	pristine_detach initial &&
@@ -175,23 +199,63 @@ test_expect_success 'failed cherry-pick
 		git ls-files --stage foo &&
 		git checkout picked -- foo &&
 		git ls-files --stage foo
-	} > stages &&
+	} >stages &&
 	sed "
 		1 s/ 0	/ 1	/
 		2 s/ 0	/ 2	/
 		3 s/ 0	/ 3	/
-	" < stages > expected &&
+	" stages >expected &&
 	git read-tree -u --reset HEAD &&
 
 	test_must_fail git cherry-pick picked &&
-	git ls-files --stage --unmerged > actual &&
+	git ls-files --stage --unmerged >actual &&
 
 	test_cmp expected actual
 '
 
+test_expect_success \
+	'cherry-pick conflict, ensure commit.cleanup = scissors places scissors line properly' '
+	pristine_detach initial &&
+	git config commit.cleanup scissors &&
+	cat <<-EOF >expected &&
+		picked
+
+		# ------------------------ >8 ------------------------
+		# Do not modify or remove the line above.
+		# Everything below it will be ignored.
+		#
+		# Conflicts:
+		#	foo
+		EOF
+
+	test_must_fail git cherry-pick picked &&
+
+	test_i18ncmp expected .git/MERGE_MSG
+'
+
+test_expect_success \
+	'cherry-pick conflict, ensure cleanup=scissors places scissors line properly' '
+	pristine_detach initial &&
+	git config --unset commit.cleanup &&
+	cat <<-EOF >expected &&
+		picked
+
+		# ------------------------ >8 ------------------------
+		# Do not modify or remove the line above.
+		# Everything below it will be ignored.
+		#
+		# Conflicts:
+		#	foo
+		EOF
+
+	test_must_fail git cherry-pick --cleanup=scissors picked &&
+
+	test_i18ncmp expected .git/MERGE_MSG
+'
+
 test_expect_success 'failed cherry-pick describes conflict in work tree' '
 	pristine_detach initial &&
-	cat <<-EOF > expected &&
+	cat <<-EOF >expected &&
 	<<<<<<< HEAD
 	a
 	=======
@@ -201,14 +265,14 @@ test_expect_success 'failed cherry-pick
 
 	test_must_fail git cherry-pick picked &&
 
-	sed "s/[a-f0-9]*\.\.\./objid/" foo > actual &&
+	sed "s/[a-f0-9]*\.\.\./objid/" foo >actual &&
 	test_cmp expected actual
 '
 
 test_expect_success 'diff3 -m style' '
 	pristine_detach initial &&
 	git config merge.conflictstyle diff3 &&
-	cat <<-EOF > expected &&
+	cat <<-EOF >expected &&
 	<<<<<<< HEAD
 	a
 	||||||| parent of objid picked
@@ -220,14 +284,14 @@ test_expect_success 'diff3 -m style' '
 
 	test_must_fail git cherry-pick picked &&
 
-	sed "s/[a-f0-9]*\.\.\./objid/" foo > actual &&
+	sed "s/[a-f0-9]*\.\.\./objid/" foo >actual &&
 	test_cmp expected actual
 '
 
 test_expect_success 'revert also handles conflicts sanely' '
 	git config --unset merge.conflictstyle &&
 	pristine_detach initial &&
-	cat <<-EOF > expected &&
+	cat <<-EOF >expected &&
 	<<<<<<< HEAD
 	a
 	=======
@@ -241,24 +305,24 @@ test_expect_success 'revert also handles
 		git ls-files --stage foo &&
 		git checkout base -- foo &&
 		git ls-files --stage foo
-	} > stages &&
+	} >stages &&
 	sed "
 		1 s/ 0	/ 1	/
 		2 s/ 0	/ 2	/
 		3 s/ 0	/ 3	/
-	" < stages > expected-stages &&
+	" stages >expected-stages &&
 	git read-tree -u --reset HEAD &&
 
 	head=$(git rev-parse HEAD) &&
 	test_must_fail git revert picked &&
 	newhead=$(git rev-parse HEAD) &&
-	git ls-files --stage --unmerged > actual-stages &&
+	git ls-files --stage --unmerged >actual-stages &&
 
 	test "$head" = "$newhead" &&
 	test_must_fail git update-index --refresh -q &&
 	test_must_fail git diff-index --exit-code HEAD &&
 	test_cmp expected-stages actual-stages &&
-	sed "s/[a-f0-9]*\.\.\./objid/" foo > actual &&
+	sed "s/[a-f0-9]*\.\.\./objid/" foo >actual &&
 	test_cmp expected actual
 '
 
@@ -284,7 +348,7 @@ test_expect_success 'revert --no-commit
 
 test_expect_success 'revert w/dirty tree does not set REVERT_HEAD' '
 	pristine_detach base &&
-	echo foo > foo &&
+	echo foo >foo &&
 	test_must_fail git revert base &&
 	test_must_fail git rev-parse --verify CHERRY_PICK_HEAD &&
 	test_must_fail git rev-parse --verify REVERT_HEAD
@@ -316,10 +380,30 @@ test_expect_success 'failed commit does
 	test_cmp_rev picked REVERT_HEAD
 '
 
+test_expect_success 'successful final commit clears revert state' '
+       pristine_detach picked-signed &&
+
+       test_must_fail git revert picked-signed base &&
+       echo resolved >foo &&
+       test_path_is_file .git/sequencer/todo &&
+       git commit -a &&
+       test_must_fail test_path_exists .git/sequencer
+'
+
+test_expect_success 'reset after final pick clears revert state' '
+       pristine_detach picked-signed &&
+
+       test_must_fail git revert picked-signed base &&
+       echo resolved >foo &&
+       test_path_is_file .git/sequencer/todo &&
+       git reset &&
+       test_must_fail test_path_exists .git/sequencer
+'
+
 test_expect_success 'revert conflict, diff3 -m style' '
 	pristine_detach initial &&
 	git config merge.conflictstyle diff3 &&
-	cat <<-EOF > expected &&
+	cat <<-EOF >expected &&
 	<<<<<<< HEAD
 	a
 	||||||| objid picked
@@ -331,10 +415,56 @@ test_expect_success 'revert conflict, di
 
 	test_must_fail git revert picked &&
 
-	sed "s/[a-f0-9]*\.\.\./objid/" foo > actual &&
+	sed "s/[a-f0-9]*\.\.\./objid/" foo >actual &&
 	test_cmp expected actual
 '
 
+test_expect_success \
+	'revert conflict, ensure commit.cleanup = scissors places scissors line properly' '
+	pristine_detach initial &&
+	git config commit.cleanup scissors &&
+	cat >expected <<-EOF &&
+		Revert "picked"
+
+		This reverts commit OBJID.
+
+		# ------------------------ >8 ------------------------
+		# Do not modify or remove the line above.
+		# Everything below it will be ignored.
+		#
+		# Conflicts:
+		#	foo
+		EOF
+
+	test_must_fail git revert picked &&
+
+	sed "s/$OID_REGEX/OBJID/" .git/MERGE_MSG >actual &&
+	test_i18ncmp expected actual
+'
+
+test_expect_success \
+	'revert conflict, ensure cleanup=scissors places scissors line properly' '
+	pristine_detach initial &&
+	git config --unset commit.cleanup &&
+	cat >expected <<-EOF &&
+		Revert "picked"
+
+		This reverts commit OBJID.
+
+		# ------------------------ >8 ------------------------
+		# Do not modify or remove the line above.
+		# Everything below it will be ignored.
+		#
+		# Conflicts:
+		#	foo
+		EOF
+
+	test_must_fail git revert --cleanup=scissors picked &&
+
+	sed "s/$OID_REGEX/OBJID/" .git/MERGE_MSG >actual &&
+	test_i18ncmp expected actual
+'
+
 test_expect_success 'failed cherry-pick does not forget -s' '
 	pristine_detach initial &&
 	test_must_fail git cherry-pick -s picked &&
@@ -345,7 +475,7 @@ test_expect_success 'commit after failed
 	pristine_detach initial &&
 	test_must_fail git cherry-pick -s picked-signed &&
 	git commit -a -s &&
-	test $(git show -s |grep -c "Signed-off-by") = 1
+	test $(git show -s >tmp && grep -c "Signed-off-by" tmp && rm tmp) = 1
 '
 
 test_expect_success 'commit after failed cherry-pick adds -s at the right place' '
@@ -359,7 +489,7 @@ test_expect_success 'commit after failed
 	Signed-off-by: C O Mitter <committer@example.com>
 	# Conflicts:
 	EOF
-	grep -e "^# Conflicts:" -e '^Signed-off-by' <.git/COMMIT_EDITMSG >actual &&
+	grep -e "^# Conflicts:" -e '^Signed-off-by' .git/COMMIT_EDITMSG >actual &&
 	test_cmp expect actual &&
 
 	cat <<-\EOF >expected &&
@@ -378,7 +508,7 @@ test_expect_success 'commit --amend -s p
 
 	# emulate old-style conflicts block
 	mv .git/MERGE_MSG .git/MERGE_MSG+ &&
-	sed -e "/^# Conflicts:/,\$s/^# *//" <.git/MERGE_MSG+ >.git/MERGE_MSG &&
+	sed -e "/^# Conflicts:/,\$s/^# *//" .git/MERGE_MSG+ >.git/MERGE_MSG &&
 
 	git commit -a &&
 	git commit --amend -s &&
@@ -388,8 +518,40 @@ test_expect_success 'commit --amend -s p
 	Signed-off-by: C O Mitter <committer@example.com>
 	Conflicts:
 	EOF
-	grep -e "^Conflicts:" -e '^Signed-off-by' <.git/COMMIT_EDITMSG >actual &&
+	grep -e "^Conflicts:" -e '^Signed-off-by' .git/COMMIT_EDITMSG >actual &&
 	test_cmp expect actual
 '
 
+test_expect_success 'cherry-pick preserves sparse-checkout' '
+	pristine_detach initial &&
+	test_config core.sparseCheckout true &&
+	test_when_finished "
+		echo \"/*\" >.git/info/sparse-checkout
+		git read-tree --reset -u HEAD
+		rm .git/info/sparse-checkout" &&
+	echo /unrelated >.git/info/sparse-checkout &&
+	git read-tree --reset -u HEAD &&
+	test_must_fail git cherry-pick -Xours picked>actual &&
+	test_i18ngrep ! "Changes not staged for commit:" actual
+'
+
+test_expect_success 'cherry-pick --continue remembers --keep-redundant-commits' '
+	test_when_finished "git cherry-pick --abort || :" &&
+	pristine_detach initial &&
+	test_must_fail git cherry-pick --keep-redundant-commits picked redundant &&
+	echo c >foo &&
+	git add foo &&
+	git cherry-pick --continue
+'
+
+test_expect_success 'cherry-pick --continue remembers --allow-empty and --allow-empty-message' '
+	test_when_finished "git cherry-pick --abort || :" &&
+	pristine_detach initial &&
+	test_must_fail git cherry-pick --allow-empty --allow-empty-message \
+				       picked empty &&
+	echo c >foo &&
+	git add foo &&
+	git cherry-pick --continue
+'
+
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t3508-cherry-pick-many-commits.sh 1.2.3+git2.25.1-1/git/t/t3508-cherry-pick-many-commits.sh
--- 1.2.1+git2.18.0-1/git/t/t3508-cherry-pick-many-commits.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t3508-cherry-pick-many-commits.sh	2020-02-17 04:47:35.000000000 +0000
@@ -5,7 +5,7 @@ test_description='test cherry-picking ma
 . ./test-lib.sh
 
 check_head_differs_from() {
-	! test_cmp_rev HEAD "$1"
+	test_cmp_rev ! HEAD "$1"
 }
 
 check_head_equals() {
diff -pruN 1.2.1+git2.18.0-1/git/t/t3510-cherry-pick-sequence.sh 1.2.3+git2.25.1-1/git/t/t3510-cherry-pick-sequence.sh
--- 1.2.1+git2.18.0-1/git/t/t3510-cherry-pick-sequence.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t3510-cherry-pick-sequence.sh	2020-02-17 04:47:35.000000000 +0000
@@ -61,7 +61,11 @@ test_expect_success 'cherry-pick mid-che
 
 test_expect_success 'cherry-pick persists opts correctly' '
 	pristine_detach initial &&
-	test_expect_code 128 git cherry-pick -s -m 1 --strategy=recursive -X patience -X ours initial..anotherpick &&
+	# to make sure that the session to cherry-pick a sequence
+	# gets interrupted, use a high-enough number that is larger
+	# than the number of parents of any commit we have created
+	mainline=4 &&
+	test_expect_code 128 git cherry-pick -s -m $mainline --strategy=recursive -X patience -X ours initial..anotherpick &&
 	test_path_is_dir .git/sequencer &&
 	test_path_is_file .git/sequencer/head &&
 	test_path_is_file .git/sequencer/todo &&
@@ -69,7 +73,7 @@ test_expect_success 'cherry-pick persist
 	echo "true" >expect &&
 	git config --file=.git/sequencer/opts --get-all options.signoff >actual &&
 	test_cmp expect actual &&
-	echo "1" >expect &&
+	echo "$mainline" >expect &&
 	git config --file=.git/sequencer/opts --get-all options.mainline >actual &&
 	test_cmp expect actual &&
 	echo "recursive" >expect &&
@@ -89,6 +93,128 @@ test_expect_success 'cherry-pick cleans
 	test_path_is_missing .git/sequencer
 '
 
+test_expect_success 'cherry-pick --skip requires cherry-pick in progress' '
+	pristine_detach initial &&
+	test_must_fail git cherry-pick --skip
+'
+
+test_expect_success 'revert --skip requires revert in progress' '
+	pristine_detach initial &&
+	test_must_fail git revert --skip
+'
+
+test_expect_success 'cherry-pick --skip to skip commit' '
+	pristine_detach initial &&
+	test_must_fail git cherry-pick anotherpick &&
+	test_must_fail git revert --skip &&
+	git cherry-pick --skip &&
+	test_cmp_rev initial HEAD &&
+	test_path_is_missing .git/CHERRY_PICK_HEAD
+'
+
+test_expect_success 'revert --skip to skip commit' '
+	pristine_detach anotherpick &&
+	test_must_fail git revert anotherpick~1 &&
+	test_must_fail git cherry-pick --skip &&
+	git revert --skip &&
+	test_cmp_rev anotherpick HEAD
+'
+
+test_expect_success 'skip "empty" commit' '
+	pristine_detach picked &&
+	test_commit dummy foo d &&
+	test_must_fail git cherry-pick anotherpick &&
+	git cherry-pick --skip &&
+	test_cmp_rev dummy HEAD
+'
+
+test_expect_success 'skip a commit and check if rest of sequence is correct' '
+	pristine_detach initial &&
+	echo e >expect &&
+	cat >expect.log <<-EOF &&
+	OBJID
+	:100644 100644 OBJID OBJID M	foo
+	OBJID
+	:100644 100644 OBJID OBJID M	foo
+	OBJID
+	:100644 100644 OBJID OBJID M	unrelated
+	OBJID
+	:000000 100644 OBJID OBJID A	foo
+	:000000 100644 OBJID OBJID A	unrelated
+	EOF
+	test_must_fail git cherry-pick base..yetanotherpick &&
+	test_must_fail git cherry-pick --skip &&
+	echo d >foo &&
+	git add foo &&
+	git cherry-pick --continue &&
+	{
+		git rev-list HEAD |
+		git diff-tree --root --stdin |
+		sed "s/$OID_REGEX/OBJID/g"
+	} >actual.log &&
+	test_cmp expect foo &&
+	test_cmp expect.log actual.log
+'
+
+test_expect_success 'check advice when we move HEAD by committing' '
+	pristine_detach initial &&
+	cat >expect <<-EOF &&
+	error: there is nothing to skip
+	hint: have you committed already?
+	hint: try "git cherry-pick --continue"
+	fatal: cherry-pick failed
+	EOF
+	test_must_fail git cherry-pick base..yetanotherpick &&
+	echo c >foo &&
+	git commit -a &&
+	test_path_is_missing .git/CHERRY_PICK_HEAD &&
+	test_must_fail git cherry-pick --skip 2>advice &&
+	test_i18ncmp expect advice
+'
+
+test_expect_success 'selectively advise --skip while launching another sequence' '
+	pristine_detach initial &&
+	cat >expect <<-EOF &&
+	error: cherry-pick is already in progress
+	hint: try "git cherry-pick (--continue | --skip | --abort | --quit)"
+	fatal: cherry-pick failed
+	EOF
+	test_must_fail git cherry-pick picked..yetanotherpick &&
+	test_must_fail git cherry-pick picked..yetanotherpick 2>advice &&
+	test_i18ncmp expect advice &&
+	cat >expect <<-EOF &&
+	error: cherry-pick is already in progress
+	hint: try "git cherry-pick (--continue | --abort | --quit)"
+	fatal: cherry-pick failed
+	EOF
+	git reset --merge &&
+	test_must_fail git cherry-pick picked..yetanotherpick 2>advice &&
+	test_i18ncmp expect advice
+'
+
+test_expect_success 'allow skipping commit but not abort for a new history' '
+	pristine_detach initial &&
+	cat >expect <<-EOF &&
+	error: cannot abort from a branch yet to be born
+	fatal: cherry-pick failed
+	EOF
+	git checkout --orphan new_disconnected &&
+	git reset --hard &&
+	test_must_fail git cherry-pick anotherpick &&
+	test_must_fail git cherry-pick --abort 2>advice &&
+	git cherry-pick --skip &&
+	test_i18ncmp expect advice
+'
+
+test_expect_success 'allow skipping stopped cherry-pick because of untracked file modifications' '
+	pristine_detach initial &&
+	git rm --cached unrelated &&
+	git commit -m "untrack unrelated" &&
+	test_must_fail git cherry-pick initial base &&
+	test_path_is_missing .git/CHERRY_PICK_HEAD &&
+	git cherry-pick --skip
+'
+
 test_expect_success '--quit does not complain when no cherry-pick is in progress' '
 	pristine_detach initial &&
 	git cherry-pick --quit
@@ -103,7 +229,8 @@ test_expect_success '--quit cleans up se
 	pristine_detach initial &&
 	test_expect_code 1 git cherry-pick base..picked &&
 	git cherry-pick --quit &&
-	test_path_is_missing .git/sequencer
+	test_path_is_missing .git/sequencer &&
+	test_path_is_missing .git/CHERRY_PICK_HEAD
 '
 
 test_expect_success '--quit keeps HEAD and conflicted index intact' '
@@ -132,6 +259,7 @@ test_expect_success '--abort to cancel m
 	test_expect_code 1 git cherry-pick base..anotherpick &&
 	git cherry-pick --abort &&
 	test_path_is_missing .git/sequencer &&
+	test_path_is_missing .git/CHERRY_PICK_HEAD &&
 	test_cmp_rev initial HEAD &&
 	git update-index --refresh &&
 	git diff-index --exit-code HEAD
@@ -142,6 +270,7 @@ test_expect_success '--abort to cancel s
 	test_expect_code 1 git cherry-pick picked &&
 	git cherry-pick --abort &&
 	test_path_is_missing .git/sequencer &&
+	test_path_is_missing .git/CHERRY_PICK_HEAD &&
 	test_cmp_rev initial HEAD &&
 	git update-index --refresh &&
 	git diff-index --exit-code HEAD
@@ -162,6 +291,7 @@ test_expect_success 'cherry-pick --abort
 	test_expect_code 1 git revert base..picked &&
 	git cherry-pick --abort &&
 	test_path_is_missing .git/sequencer &&
+	test_path_is_missing .git/CHERRY_PICK_HEAD &&
 	test_cmp_rev anotherpick HEAD &&
 	git update-index --refresh &&
 	git diff-index --exit-code HEAD
@@ -239,6 +369,7 @@ test_expect_success '--abort after last
 	test_expect_code 1 git cherry-pick base..picked &&
 	git cherry-pick --abort &&
 	test_path_is_missing .git/sequencer &&
+	test_path_is_missing .git/CHERRY_PICK_HEAD &&
 	test_cmp_rev initial HEAD &&
 	git update-index --refresh &&
 	git diff-index --exit-code HEAD
@@ -480,11 +611,16 @@ test_expect_success 'malformed instructi
 	test_expect_code 128 git cherry-pick --continue
 '
 
-test_expect_success 'empty commit set' '
+test_expect_success 'empty commit set (no commits to walk)' '
 	pristine_detach initial &&
 	test_expect_code 128 git cherry-pick base..base
 '
 
+test_expect_success 'empty commit set (culled during walk)' '
+	pristine_detach initial &&
+	test_expect_code 128 git cherry-pick -2 --author=no.such.author base
+'
+
 test_expect_success 'malformed instruction sheet 3' '
 	pristine_detach initial &&
 	test_expect_code 1 git cherry-pick base..anotherpick &&
diff -pruN 1.2.1+git2.18.0-1/git/t/t3511-cherry-pick-x.sh 1.2.3+git2.25.1-1/git/t/t3511-cherry-pick-x.sh
--- 1.2.1+git2.18.0-1/git/t/t3511-cherry-pick-x.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t3511-cherry-pick-x.sh	2020-02-17 04:47:35.000000000 +0000
@@ -298,4 +298,24 @@ test_expect_success 'cherry-pick preserv
 	test_cmp expect actual
 '
 
+test_expect_success 'cherry-pick -x cleans commit message' '
+	pristine_detach initial &&
+	git cherry-pick -x mesg-unclean &&
+	git log -1 --pretty=format:%B >actual &&
+	printf "%s\n(cherry picked from commit %s)\n" \
+		"$mesg_unclean" $(git rev-parse mesg-unclean) |
+			git stripspace >expect &&
+	test_cmp expect actual
+'
+
+test_expect_success 'cherry-pick -x respects commit.cleanup' '
+	pristine_detach initial &&
+	git -c commit.cleanup=strip cherry-pick -x mesg-unclean &&
+	git log -1 --pretty=format:%B >actual &&
+	printf "%s\n(cherry picked from commit %s)\n" \
+		"$mesg_unclean" $(git rev-parse mesg-unclean) |
+			git stripspace -s >expect &&
+	test_cmp expect actual
+'
+
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t3600-rm.sh 1.2.3+git2.25.1-1/git/t/t3600-rm.sh
--- 1.2.1+git2.18.0-1/git/t/t3600-rm.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t3600-rm.sh	2020-02-17 04:47:35.000000000 +0000
@@ -8,93 +8,92 @@ test_description='Test of the various op
 . ./test-lib.sh
 
 # Setup some files to be removed, some with funny characters
-test_expect_success \
-    'Initialize test directory' \
-    "touch -- foo bar baz 'space embedded' -q &&
-     git add -- foo bar baz 'space embedded' -q &&
-     git commit -m 'add normal files'"
+test_expect_success 'Initialize test directory' '
+	touch -- foo bar baz "space embedded" -q &&
+	git add -- foo bar baz "space embedded" -q &&
+	git commit -m "add normal files"
+'
 
-if test_have_prereq !MINGW && touch -- 'tab	embedded' 'newline
-embedded' 2>/dev/null
+if test_have_prereq !FUNNYNAMES
 then
-	test_set_prereq FUNNYNAMES
-else
 	say 'Your filesystem does not allow tabs in filenames.'
 fi
 
-test_expect_success FUNNYNAMES 'add files with funny names' "
-     git add -- 'tab	embedded' 'newline
-embedded' &&
-     git commit -m 'add files with tabs and newlines'
-"
-
-test_expect_success \
-    'Pre-check that foo exists and is in index before git rm foo' \
-    '[ -f foo ] && git ls-files --error-unmatch foo'
-
-test_expect_success \
-    'Test that git rm foo succeeds' \
-    'git rm --cached foo'
-
-test_expect_success \
-    'Test that git rm --cached foo succeeds if the index matches the file' \
-    'echo content >foo &&
-     git add foo &&
-     git rm --cached foo'
-
-test_expect_success \
-    'Test that git rm --cached foo succeeds if the index matches the file' \
-    'echo content >foo &&
-     git add foo &&
-     git commit -m foo &&
-     echo "other content" >foo &&
-     git rm --cached foo'
-
-test_expect_success \
-    'Test that git rm --cached foo fails if the index matches neither the file nor HEAD' '
-     echo content >foo &&
-     git add foo &&
-     git commit -m foo --allow-empty &&
-     echo "other content" >foo &&
-     git add foo &&
-     echo "yet another content" >foo &&
-     test_must_fail git rm --cached foo
-'
-
-test_expect_success \
-    'Test that git rm --cached -f foo works in case where --cached only did not' \
-    'echo content >foo &&
-     git add foo &&
-     git commit -m foo --allow-empty &&
-     echo "other content" >foo &&
-     git add foo &&
-     echo "yet another content" >foo &&
-     git rm --cached -f foo'
-
-test_expect_success \
-    'Post-check that foo exists but is not in index after git rm foo' \
-    '[ -f foo ] && test_must_fail git ls-files --error-unmatch foo'
-
-test_expect_success \
-    'Pre-check that bar exists and is in index before "git rm bar"' \
-    '[ -f bar ] && git ls-files --error-unmatch bar'
-
-test_expect_success \
-    'Test that "git rm bar" succeeds' \
-    'git rm bar'
-
-test_expect_success \
-    'Post-check that bar does not exist and is not in index after "git rm -f bar"' \
-    '! [ -f bar ] && test_must_fail git ls-files --error-unmatch bar'
-
-test_expect_success \
-    'Test that "git rm -- -q" succeeds (remove a file that looks like an option)' \
-    'git rm -- -q'
-
-test_expect_success FUNNYNAMES \
-    "Test that \"git rm -f\" succeeds with embedded space, tab, or newline characters." \
-    "git rm -f 'space embedded' 'tab	embedded' 'newline
-embedded'"
+test_expect_success FUNNYNAMES 'add files with funny names' '
+	touch -- "tab	embedded" "newline${LF}embedded" &&
+	git add -- "tab	embedded" "newline${LF}embedded" &&
+	git commit -m "add files with tabs and newlines"
+'
+
+test_expect_success 'Pre-check that foo exists and is in index before git rm foo' '
+	test_path_is_file foo &&
+	git ls-files --error-unmatch foo
+'
+
+test_expect_success 'Test that git rm foo succeeds' '
+	git rm --cached foo
+'
+
+test_expect_success 'Test that git rm --cached foo succeeds if the index matches the file' '
+	echo content >foo &&
+	git add foo &&
+	git rm --cached foo
+'
+
+test_expect_success 'Test that git rm --cached foo succeeds if the index matches the file' '
+	echo content >foo &&
+	git add foo &&
+	git commit -m foo &&
+	echo "other content" >foo &&
+	git rm --cached foo
+'
+
+test_expect_success 'Test that git rm --cached foo fails if the index matches neither the file nor HEAD' '
+	echo content >foo &&
+	git add foo &&
+	git commit -m foo --allow-empty &&
+	echo "other content" >foo &&
+	git add foo &&
+	echo "yet another content" >foo &&
+	test_must_fail git rm --cached foo
+'
+
+test_expect_success 'Test that git rm --cached -f foo works in case where --cached only did not' '
+	echo content >foo &&
+	git add foo &&
+	git commit -m foo --allow-empty &&
+	echo "other content" >foo &&
+	git add foo &&
+	echo "yet another content" >foo &&
+	git rm --cached -f foo
+'
+
+test_expect_success 'Post-check that foo exists but is not in index after git rm foo' '
+	test_path_is_file foo &&
+	test_must_fail git ls-files --error-unmatch foo
+'
+
+test_expect_success 'Pre-check that bar exists and is in index before "git rm bar"' '
+	test_path_is_file bar &&
+	git ls-files --error-unmatch bar
+'
+
+test_expect_success 'Test that "git rm bar" succeeds' '
+	git rm bar
+'
+
+test_expect_success 'Post-check that bar does not exist and is not in index after "git rm -f bar"' '
+	test_path_is_missing bar &&
+	test_must_fail git ls-files --error-unmatch bar
+'
+
+test_expect_success 'Test that "git rm -- -q" succeeds (remove a file that looks like an option)' '
+	git rm -- -q
+'
+
+test_expect_success FUNNYNAMES 'Test that "git rm -f" succeeds with embedded space, tab, or newline characters.' '
+	git rm -f "space embedded" "tab	embedded" "newline${LF}embedded"
+'
 
 test_expect_success SANITY 'Test that "git rm -f" fails if its rm fails' '
 	test_when_finished "chmod 775 ." &&
@@ -102,9 +101,9 @@ test_expect_success SANITY 'Test that "g
 	test_must_fail git rm -f baz
 '
 
-test_expect_success \
-    'When the rm in "git rm -f" fails, it should not remove the file from the index' \
-    'git ls-files --error-unmatch baz'
+test_expect_success 'When the rm in "git rm -f" fails, it should not remove the file from the index' '
+	git ls-files --error-unmatch baz
+'
 
 test_expect_success 'Remove nonexistent file with --ignore-unmatch' '
 	git rm --ignore-unmatch nonexistent
@@ -114,9 +113,10 @@ test_expect_success '"rm" command printe
 	echo frotz >test-file &&
 	git add test-file &&
 	git commit -m "add file for rm test" &&
-	git rm test-file >rm-output &&
-	test $(grep "^rm " rm-output | wc -l) = 1 &&
-	rm -f test-file rm-output &&
+	git rm test-file >rm-output.raw &&
+	grep "^rm " rm-output.raw >rm-output &&
+	test_line_count = 1 rm-output &&
+	rm -f test-file rm-output.raw rm-output &&
 	git commit -m "remove file from rm test"
 '
 
@@ -139,15 +139,15 @@ test_expect_success 'Re-add foo and baz'
 test_expect_success 'Modify foo -- rm should refuse' '
 	echo >>foo &&
 	test_must_fail git rm foo baz &&
-	test -f foo &&
-	test -f baz &&
+	test_path_is_file foo &&
+	test_path_is_file baz &&
 	git ls-files --error-unmatch foo baz
 '
 
 test_expect_success 'Modified foo -- rm -f should work' '
 	git rm -f foo baz &&
-	test ! -f foo &&
-	test ! -f baz &&
+	test_path_is_missing foo &&
+	test_path_is_missing baz &&
 	test_must_fail git ls-files --error-unmatch foo &&
 	test_must_fail git ls-files --error-unmatch bar
 '
@@ -161,15 +161,15 @@ test_expect_success 'Re-add foo and baz
 
 test_expect_success 'foo is different in index from HEAD -- rm should refuse' '
 	test_must_fail git rm foo baz &&
-	test -f foo &&
-	test -f baz &&
+	test_path_is_file foo &&
+	test_path_is_file baz &&
 	git ls-files --error-unmatch foo baz
 '
 
 test_expect_success 'but with -f it should work.' '
 	git rm -f foo baz &&
-	test ! -f foo &&
-	test ! -f baz &&
+	test_path_is_missing foo &&
+	test_path_is_missing baz &&
 	test_must_fail git ls-files --error-unmatch foo &&
 	test_must_fail git ls-files --error-unmatch baz
 '
@@ -196,21 +196,21 @@ test_expect_success 'Recursive test setu
 
 test_expect_success 'Recursive without -r fails' '
 	test_must_fail git rm frotz &&
-	test -d frotz &&
-	test -f frotz/nitfol
+	test_path_is_dir frotz &&
+	test_path_is_file frotz/nitfol
 '
 
 test_expect_success 'Recursive with -r but dirty' '
 	echo qfwfq >>frotz/nitfol &&
 	test_must_fail git rm -r frotz &&
-	test -d frotz &&
-	test -f frotz/nitfol
+	test_path_is_dir frotz &&
+	test_path_is_file frotz/nitfol
 '
 
 test_expect_success 'Recursive with -r -f' '
 	git rm -f -r frotz &&
-	! test -f frotz/nitfol &&
-	! test -d frotz
+	test_path_is_missing frotz/nitfol &&
+	test_path_is_missing frotz
 '
 
 test_expect_success 'Remove nonexistent file returns nonzero exit status' '
@@ -219,44 +219,62 @@ test_expect_success 'Remove nonexistent
 
 test_expect_success 'Call "rm" from outside the work tree' '
 	mkdir repo &&
-	(cd repo &&
-	 git init &&
-	 echo something >somefile &&
-	 git add somefile &&
-	 git commit -m "add a file" &&
-	 (cd .. &&
-	  git --git-dir=repo/.git --work-tree=repo rm somefile) &&
-	test_must_fail git ls-files --error-unmatch somefile)
+	(
+		cd repo &&
+		git init &&
+		echo something >somefile &&
+		git add somefile &&
+		git commit -m "add a file" &&
+		(
+			cd .. &&
+			git --git-dir=repo/.git --work-tree=repo rm somefile
+		) &&
+		test_must_fail git ls-files --error-unmatch somefile
+	)
 '
 
 test_expect_success 'refresh index before checking if it is up-to-date' '
-
 	git reset --hard &&
 	test-tool chmtime -86400 frotz/nitfol &&
 	git rm frotz/nitfol &&
-	test ! -f frotz/nitfol
-
+	test_path_is_missing frotz/nitfol
 '
 
 test_expect_success 'choking "git rm" should not let it die with cruft' '
+	test_oid_init &&
 	git reset -q --hard &&
 	test_when_finished "rm -f .git/index.lock && git reset -q --hard" &&
 	i=0 &&
+	hash=$(test_oid deadbeef) &&
 	while test $i -lt 12000
 	do
-	    echo "100644 1234567890123456789012345678901234567890 0	some-file-$i"
-	    i=$(( $i + 1 ))
+		echo "100644 $hash 0	some-file-$i"
+		i=$(( $i + 1 ))
 	done | git update-index --index-info &&
+	# git command is intentionally placed upstream of pipe to induce SIGPIPE
 	git rm -n "some-file-*" | : &&
 	test_path_is_missing .git/index.lock
 '
 
+test_expect_success 'Resolving by removal is not a warning-worthy event' '
+	git reset -q --hard &&
+	test_when_finished "rm -f .git/index.lock msg && git reset -q --hard" &&
+	blob=$(echo blob | git hash-object -w --stdin) &&
+	for stage in 1 2 3
+	do
+		echo "100644 $blob $stage	blob"
+	done | git update-index --index-info &&
+	git rm blob >msg 2>&1 &&
+	test_i18ngrep ! "needs merge" msg &&
+	test_must_fail git ls-files -s --error-unmatch blob
+'
+
 test_expect_success 'rm removes subdirectories recursively' '
 	mkdir -p dir/subdir/subsubdir &&
 	echo content >dir/subdir/subsubdir/file &&
 	git add dir/subdir/subsubdir/file &&
 	git rm -f dir/subdir/subsubdir/file &&
-	! test -d dir
+	test_path_is_missing dir
 '
 
 cat >expect <<EOF
@@ -287,14 +305,15 @@ EOF
 
 test_expect_success 'rm removes empty submodules from work tree' '
 	mkdir submod &&
-	git update-index --add --cacheinfo 160000 $(git rev-parse HEAD) submod &&
+	hash=$(git rev-parse HEAD) &&
+	git update-index --add --cacheinfo 160000 "$hash" submod &&
 	git config -f .gitmodules submodule.sub.url ./. &&
 	git config -f .gitmodules submodule.sub.path submod &&
 	git submodule init &&
 	git add .gitmodules &&
 	git commit -m "add submodule" &&
 	git rm submod &&
-	test ! -e submod &&
+	test_path_is_missing submod &&
 	git status -s -uno --ignore-submodules=none >actual &&
 	test_cmp expect actual &&
 	test_must_fail git config -f .gitmodules submodule.sub.url &&
@@ -316,7 +335,7 @@ test_expect_success 'rm removes work tre
 	git reset --hard &&
 	git submodule update &&
 	git rm submod &&
-	test ! -d submod &&
+	test_path_is_missing submod &&
 	git status -s -uno --ignore-submodules=none >actual &&
 	test_cmp expect actual &&
 	test_must_fail git config -f .gitmodules submodule.sub.url &&
@@ -327,7 +346,7 @@ test_expect_success 'rm removes a submod
 	git reset --hard &&
 	git submodule update &&
 	git rm submod/ &&
-	test ! -d submod &&
+	test_path_is_missing submod &&
 	git status -s -uno --ignore-submodules=none >actual &&
 	test_cmp expect actual
 '
@@ -345,12 +364,12 @@ test_expect_success 'rm of a populated s
 	git submodule update &&
 	git -C submod checkout HEAD^ &&
 	test_must_fail git rm submod &&
-	test -d submod &&
-	test -f submod/.git &&
+	test_path_is_dir submod &&
+	test_path_is_file submod/.git &&
 	git status -s -uno --ignore-submodules=none >actual &&
 	test_cmp expect.modified actual &&
 	git rm -f submod &&
-	test ! -d submod &&
+	test_path_is_missing submod &&
 	git status -s -uno --ignore-submodules=none >actual &&
 	test_cmp expect actual &&
 	test_must_fail git config -f .gitmodules submodule.sub.url &&
@@ -361,8 +380,8 @@ test_expect_success 'rm --cached leaves
 	git reset --hard &&
 	git submodule update &&
 	git rm --cached submod &&
-	test -d submod &&
-	test -f submod/.git &&
+	test_path_is_dir submod &&
+	test_path_is_file submod/.git &&
 	git status -s -uno >actual &&
 	test_cmp expect.cached actual &&
 	git config -f .gitmodules submodule.sub.url &&
@@ -373,7 +392,7 @@ test_expect_success 'rm --dry-run does n
 	git reset --hard &&
 	git submodule update &&
 	git rm -n submod &&
-	test -f submod/.git &&
+	test_path_is_file submod/.git &&
 	git diff-index --exit-code HEAD
 '
 
@@ -382,9 +401,9 @@ test_expect_success 'rm does not complai
 	git submodule update &&
 	git rm .gitmodules &&
 	git rm submod >actual 2>actual.err &&
-	! test -s actual.err &&
-	! test -d submod &&
-	! test -f submod/.git &&
+	test_must_be_empty actual.err &&
+	test_path_is_missing submod &&
+	test_path_is_missing submod/.git &&
 	git status -s -uno >actual &&
 	test_cmp expect.both_deleted actual
 '
@@ -394,15 +413,15 @@ test_expect_success 'rm will error out o
 	git submodule update &&
 	git config -f .gitmodules foo.bar true &&
 	test_must_fail git rm submod >actual 2>actual.err &&
-	test -s actual.err &&
-	test -d submod &&
-	test -f submod/.git &&
+	test_file_not_empty actual.err &&
+	test_path_is_dir submod &&
+	test_path_is_file submod/.git &&
 	git diff-files --quiet -- submod &&
 	git add .gitmodules &&
 	git rm submod >actual 2>actual.err &&
-	! test -s actual.err &&
-	! test -d submod &&
-	! test -f submod/.git &&
+	test_must_be_empty actual.err &&
+	test_path_is_missing submod &&
+	test_path_is_missing submod/.git &&
 	git status -s -uno >actual &&
 	test_cmp expect actual
 '
@@ -415,8 +434,8 @@ test_expect_success 'rm issues a warning
 	echo "warning: Could not find section in .gitmodules where path=submod" >expect.err &&
 	git rm submod >actual 2>actual.err &&
 	test_i18ncmp expect.err actual.err &&
-	! test -d submod &&
-	! test -f submod/.git &&
+	test_path_is_missing submod &&
+	test_path_is_missing submod/.git &&
 	git status -s -uno >actual &&
 	test_cmp expect actual
 '
@@ -426,12 +445,12 @@ test_expect_success 'rm of a populated s
 	git submodule update &&
 	echo X >submod/empty &&
 	test_must_fail git rm submod &&
-	test -d submod &&
-	test -f submod/.git &&
+	test_path_is_dir submod &&
+	test_path_is_file submod/.git &&
 	git status -s -uno --ignore-submodules=none >actual &&
 	test_cmp expect.modified_inside actual &&
 	git rm -f submod &&
-	test ! -d submod &&
+	test_path_is_missing submod &&
 	git status -s -uno --ignore-submodules=none >actual &&
 	test_cmp expect actual
 '
@@ -441,12 +460,12 @@ test_expect_success 'rm of a populated s
 	git submodule update &&
 	echo X >submod/untracked &&
 	test_must_fail git rm submod &&
-	test -d submod &&
-	test -f submod/.git &&
+	test_path_is_dir submod &&
+	test_path_is_file submod/.git &&
 	git status -s -uno --ignore-submodules=none >actual &&
 	test_cmp expect.modified_untracked actual &&
 	git rm -f submod &&
-	test ! -d submod &&
+	test_path_is_missing submod &&
 	git status -s -uno --ignore-submodules=none >actual &&
 	test_cmp expect actual
 '
@@ -483,7 +502,7 @@ test_expect_success 'rm removes work tre
 	git submodule update &&
 	test_must_fail git merge conflict2 &&
 	git rm submod &&
-	test ! -d submod &&
+	test_path_is_missing submod &&
 	git status -s -uno --ignore-submodules=none >actual &&
 	test_cmp expect actual
 '
@@ -495,12 +514,12 @@ test_expect_success 'rm of a conflicted
 	git -C submod checkout HEAD^ &&
 	test_must_fail git merge conflict2 &&
 	test_must_fail git rm submod &&
-	test -d submod &&
-	test -f submod/.git &&
+	test_path_is_dir submod &&
+	test_path_is_file submod/.git &&
 	git status -s -uno --ignore-submodules=none >actual &&
 	test_cmp expect.conflict actual &&
 	git rm -f submod &&
-	test ! -d submod &&
+	test_path_is_missing submod &&
 	git status -s -uno --ignore-submodules=none >actual &&
 	test_cmp expect actual &&
 	test_must_fail git config -f .gitmodules submodule.sub.url &&
@@ -514,12 +533,12 @@ test_expect_success 'rm of a conflicted
 	echo X >submod/empty &&
 	test_must_fail git merge conflict2 &&
 	test_must_fail git rm submod &&
-	test -d submod &&
-	test -f submod/.git &&
+	test_path_is_dir submod &&
+	test_path_is_file submod/.git &&
 	git status -s -uno --ignore-submodules=none >actual &&
 	test_cmp expect.conflict actual &&
 	git rm -f submod &&
-	test ! -d submod &&
+	test_path_is_missing submod &&
 	git status -s -uno --ignore-submodules=none >actual &&
 	test_cmp expect actual &&
 	test_must_fail git config -f .gitmodules submodule.sub.url &&
@@ -533,12 +552,12 @@ test_expect_success 'rm of a conflicted
 	echo X >submod/untracked &&
 	test_must_fail git merge conflict2 &&
 	test_must_fail git rm submod &&
-	test -d submod &&
-	test -f submod/.git &&
+	test_path_is_dir submod &&
+	test_path_is_file submod/.git &&
 	git status -s -uno --ignore-submodules=none >actual &&
 	test_cmp expect.conflict actual &&
 	git rm -f submod &&
-	test ! -d submod &&
+	test_path_is_missing submod &&
 	git status -s -uno --ignore-submodules=none >actual &&
 	test_cmp expect actual
 '
@@ -547,20 +566,21 @@ test_expect_success 'rm of a conflicted
 	git checkout conflict1 &&
 	git reset --hard &&
 	git submodule update &&
-	(cd submod &&
+	(
+		cd submod &&
 		rm .git &&
 		cp -R ../.git/modules/sub .git &&
 		GIT_WORK_TREE=. git config --unset core.worktree
 	) &&
 	test_must_fail git merge conflict2 &&
 	test_must_fail git rm submod &&
-	test -d submod &&
-	test -d submod/.git &&
+	test_path_is_dir submod &&
+	test_path_is_dir submod/.git &&
 	git status -s -uno --ignore-submodules=none >actual &&
 	test_cmp expect.conflict actual &&
 	test_must_fail git rm -f submod &&
-	test -d submod &&
-	test -d submod/.git &&
+	test_path_is_dir submod &&
+	test_path_is_dir submod/.git &&
 	git status -s -uno --ignore-submodules=none >actual &&
 	test_cmp expect.conflict actual &&
 	git merge --abort &&
@@ -572,7 +592,7 @@ test_expect_success 'rm of a conflicted
 	git reset --hard &&
 	test_must_fail git merge conflict2 &&
 	git rm submod &&
-	test ! -d submod &&
+	test_path_is_missing submod &&
 	git status -s -uno --ignore-submodules=none >actual &&
 	test_cmp expect actual
 '
@@ -581,17 +601,18 @@ test_expect_success 'rm of a populated s
 	git checkout -f master &&
 	git reset --hard &&
 	git submodule update &&
-	(cd submod &&
+	(
+		cd submod &&
 		rm .git &&
 		cp -R ../.git/modules/sub .git &&
 		GIT_WORK_TREE=. git config --unset core.worktree &&
 		rm -r ../.git/modules/sub
 	) &&
 	git rm submod 2>output.err &&
-	! test -d submod &&
-	! test -d submod/.git &&
+	test_path_is_missing submod &&
+	test_path_is_missing submod/.git &&
 	git status -s -uno --ignore-submodules=none >actual &&
-	test -s actual &&
+	test_file_not_empty actual &&
 	test_i18ngrep Migrating output.err
 '
 
@@ -602,8 +623,10 @@ EOF
 test_expect_success 'setup subsubmodule' '
 	git reset --hard &&
 	git submodule update &&
-	(cd submod &&
-		git update-index --add --cacheinfo 160000 $(git rev-parse HEAD) subsubmod &&
+	(
+		cd submod &&
+		hash=$(git rev-parse HEAD) &&
+		git update-index --add --cacheinfo 160000 "$hash" subsubmod &&
 		git config -f .gitmodules submodule.sub.url ../. &&
 		git config -f .gitmodules submodule.sub.path subsubmod &&
 		git submodule init &&
@@ -616,7 +639,7 @@ test_expect_success 'setup subsubmodule'
 
 test_expect_success 'rm recursively removes work tree of unmodified submodules' '
 	git rm submod &&
-	test ! -d submod &&
+	test_path_is_missing submod &&
 	git status -s -uno --ignore-submodules=none >actual &&
 	test_cmp expect actual
 '
@@ -626,12 +649,12 @@ test_expect_success 'rm of a populated n
 	git submodule update --recursive &&
 	git -C submod/subsubmod checkout HEAD^ &&
 	test_must_fail git rm submod &&
-	test -d submod &&
-	test -f submod/.git &&
+	test_path_is_dir submod &&
+	test_path_is_file submod/.git &&
 	git status -s -uno --ignore-submodules=none >actual &&
 	test_cmp expect.modified_inside actual &&
 	git rm -f submod &&
-	test ! -d submod &&
+	test_path_is_missing submod &&
 	git status -s -uno --ignore-submodules=none >actual &&
 	test_cmp expect actual
 '
@@ -641,12 +664,12 @@ test_expect_success 'rm of a populated n
 	git submodule update --recursive &&
 	echo X >submod/subsubmod/empty &&
 	test_must_fail git rm submod &&
-	test -d submod &&
-	test -f submod/.git &&
+	test_path_is_dir submod &&
+	test_path_is_file submod/.git &&
 	git status -s -uno --ignore-submodules=none >actual &&
 	test_cmp expect.modified_inside actual &&
 	git rm -f submod &&
-	test ! -d submod &&
+	test_path_is_missing submod &&
 	git status -s -uno --ignore-submodules=none >actual &&
 	test_cmp expect actual
 '
@@ -656,12 +679,12 @@ test_expect_success 'rm of a populated n
 	git submodule update --recursive &&
 	echo X >submod/subsubmod/untracked &&
 	test_must_fail git rm submod &&
-	test -d submod &&
-	test -f submod/.git &&
+	test_path_is_dir submod &&
+	test_path_is_file submod/.git &&
 	git status -s -uno --ignore-submodules=none >actual &&
 	test_cmp expect.modified_untracked actual &&
 	git rm -f submod &&
-	test ! -d submod &&
+	test_path_is_missing submod &&
 	git status -s -uno --ignore-submodules=none >actual &&
 	test_cmp expect actual
 '
@@ -669,16 +692,17 @@ test_expect_success 'rm of a populated n
 test_expect_success "rm absorbs submodule's nested .git directory" '
 	git reset --hard &&
 	git submodule update --recursive &&
-	(cd submod/subsubmod &&
+	(
+		cd submod/subsubmod &&
 		rm .git &&
 		mv ../../.git/modules/sub/modules/sub .git &&
 		GIT_WORK_TREE=. git config --unset core.worktree
 	) &&
 	git rm submod 2>output.err &&
-	! test -d submod &&
-	! test -d submod/subsubmod/.git &&
+	test_path_is_missing submod &&
+	test_path_is_missing submod/subsubmod/.git &&
 	git status -s -uno --ignore-submodules=none >actual &&
-	test -s actual &&
+	test_file_not_empty actual &&
 	test_i18ngrep Migrating output.err
 '
 
@@ -694,7 +718,7 @@ test_expect_success 'checking out a comm
 	test_cmp expected actual &&
 	rm -rf submod &&
 	git status -s -uno --ignore-submodules=none >actual &&
-	! test -s actual
+	test_must_be_empty actual
 '
 
 test_expect_success 'rm of d/f when d has become a non-directory' '
diff -pruN 1.2.1+git2.18.0-1/git/t/t3700-add.sh 1.2.3+git2.25.1-1/git/t/t3700-add.sh
--- 1.2.1+git2.18.0-1/git/t/t3700-add.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t3700-add.sh	2020-02-17 04:47:35.000000000 +0000
@@ -156,9 +156,9 @@ test_expect_success 'git add with filemo
 test_expect_success 'git add with filemode=0, symlinks=0 prefers stage 2 over stage 1' '
 	git rm --cached -f file symlink &&
 	(
-		echo "100644 $(git hash-object -w stage1) 1	file"
-		echo "100755 $(git hash-object -w stage2) 2	file"
-		echo "100644 $(printf 1 | git hash-object -w -t blob --stdin) 1	symlink"
+		echo "100644 $(git hash-object -w stage1) 1	file" &&
+		echo "100755 $(git hash-object -w stage2) 2	file" &&
+		echo "100644 $(printf 1 | git hash-object -w -t blob --stdin) 1	symlink" &&
 		echo "120000 $(printf 2 | git hash-object -w -t blob --stdin) 2	symlink"
 	) | git update-index --index-info &&
 	git config core.filemode 0 &&
@@ -188,9 +188,8 @@ test_expect_success 'git add --refresh w
 	git add foo bar baz && H=$(git rev-parse :foo) && git rm -f foo &&
 	echo "100644 $H 3	foo" | git update-index --index-info &&
 	test-tool chmtime -60 bar baz &&
-	>expect &&
 	git add --refresh bar >actual &&
-	test_cmp expect actual &&
+	test_must_be_empty actual &&
 
 	git diff-files --name-only >actual &&
 	! grep bar actual&&
@@ -265,7 +264,7 @@ test_expect_success 'git add to resolve
 	git reset --hard &&
 	H=$(git rev-parse :1/2/a) &&
 	(
-		echo "100644 $H 1	track-this"
+		echo "100644 $H 1	track-this" &&
 		echo "100644 $H 3	track-this"
 	) | git update-index --index-info &&
 	echo track-this >>.gitignore &&
@@ -297,6 +296,17 @@ test_expect_success '"git add ." in empt
 	)
 '
 
+test_expect_success 'error on a repository with no commits' '
+	rm -fr empty &&
+	git init empty &&
+	test_must_fail git add empty >actual 2>&1 &&
+	cat >expect <<-EOF &&
+	error: '"'empty/'"' does not have a commit checked out
+	fatal: adding files failed
+	EOF
+	test_i18ncmp expect actual
+'
+
 test_expect_success 'git add --dry-run of existing changed file' "
 	echo new >>track-this &&
 	git add --dry-run track-this >actual 2>&1 &&
@@ -397,10 +407,18 @@ test_expect_success 'no file status chan
 '
 
 test_expect_success 'all statuses changed in folder if . is given' '
+	rm -fr empty &&
 	git add --chmod=+x . &&
 	test $(git ls-files --stage | grep ^100644 | wc -l) -eq 0 &&
 	git add --chmod=-x . &&
 	test $(git ls-files --stage | grep ^100755 | wc -l) -eq 0
 '
 
+test_expect_success CASE_INSENSITIVE_FS 'path is case-insensitive' '
+	path="$(pwd)/BLUB" &&
+	touch "$path" &&
+	downcased="$(echo "$path" | tr A-Z a-z)" &&
+	git add "$downcased"
+'
+
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t3701-add-interactive.sh 1.2.3+git2.25.1-1/git/t/t3701-add-interactive.sh
--- 1.2.1+git2.18.0-1/git/t/t3701-add-interactive.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t3701-add-interactive.sh	2020-02-17 04:47:35.000000000 +0000
@@ -23,6 +23,17 @@ diff_cmp () {
 	test_cmp "$1.filtered" "$2.filtered"
 }
 
+# This function uses a trick to manipulate the interactive add to use color:
+# the `want_color()` function special-cases the situation where a pager was
+# spawned and Git now wants to output colored text: to detect that situation,
+# the environment variable `GIT_PAGER_IN_USE` is set. However, color is
+# suppressed despite that environment variable if the `TERM` variable
+# indicates a dumb terminal, so we set that variable, too.
+
+force_color () {
+	env GIT_PAGER_IN_USE=true TERM=vt100 "$@"
+}
+
 test_expect_success 'setup (initial)' '
 	echo content >file &&
 	git add file &&
@@ -46,13 +57,13 @@ test_expect_success 'setup expected' '
 '
 
 test_expect_success 'diff works (initial)' '
-	(echo d; echo 1) | git add -i >output &&
+	test_write_lines d 1 | git add -i >output &&
 	sed -ne "/new file/,/content/p" <output >diff &&
 	diff_cmp expected diff
 '
 test_expect_success 'revert works (initial)' '
 	git add file &&
-	(echo r; echo 1) | git add -i &&
+	test_write_lines r 1 | git add -i &&
 	git ls-files >output &&
 	! grep . output
 '
@@ -83,18 +94,17 @@ test_expect_success 'setup expected' '
 '
 
 test_expect_success 'diff works (commit)' '
-	(echo d; echo 1) | git add -i >output &&
+	test_write_lines d 1 | git add -i >output &&
 	sed -ne "/^index/,/content/p" <output >diff &&
 	diff_cmp expected diff
 '
 test_expect_success 'revert works (commit)' '
 	git add file &&
-	(echo r; echo 1) | git add -i &&
+	test_write_lines r 1 | git add -i &&
 	git add -i </dev/null >output &&
 	grep "unchanged *+3/-0 file" output
 '
 
-
 test_expect_success 'setup expected' '
 	cat >expected <<-\EOF
 	EOF
@@ -102,7 +112,7 @@ test_expect_success 'setup expected' '
 
 test_expect_success 'dummy edit works' '
 	test_set_editor : &&
-	(echo e; echo a) | git add -p &&
+	test_write_lines e a | git add -p &&
 	git diff > diff &&
 	diff_cmp expected diff
 '
@@ -127,7 +137,7 @@ test_expect_success 'setup fake editor'
 
 test_expect_success 'bad edit rejected' '
 	git reset &&
-	(echo e; echo n; echo d) | git add -p >output &&
+	test_write_lines e n d | git add -p >output &&
 	grep "hunk does not apply" output
 '
 
@@ -140,7 +150,7 @@ test_expect_success 'setup patch' '
 
 test_expect_success 'garbage edit rejected' '
 	git reset &&
-	(echo e; echo n; echo d) | git add -p >output &&
+	test_write_lines e n d | git add -p >output &&
 	grep "hunk does not apply" output
 '
 
@@ -170,7 +180,50 @@ test_expect_success 'setup expected' '
 '
 
 test_expect_success 'real edit works' '
-	(echo e; echo n; echo d) | git add -p &&
+	test_write_lines e n d | git add -p &&
+	git diff >output &&
+	diff_cmp expected output
+'
+
+test_expect_success 'setup file' '
+	test_write_lines a "" b "" c >file &&
+	git add file &&
+	test_write_lines a "" d "" c >file
+'
+
+test_expect_success 'setup patch' '
+	SP=" " &&
+	NULL="" &&
+	cat >patch <<-EOF
+	@@ -1,4 +1,4 @@
+	 a
+	$NULL
+	-b
+	+f
+	$SP
+	c
+	EOF
+'
+
+test_expect_success 'setup expected' '
+	cat >expected <<-EOF
+	diff --git a/file b/file
+	index b5dd6c9..f910ae9 100644
+	--- a/file
+	+++ b/file
+	@@ -1,5 +1,5 @@
+	 a
+	$SP
+	-f
+	+d
+	$SP
+	 c
+	EOF
+'
+
+test_expect_success 'edit can strip spaces from empty context lines' '
+	test_write_lines e n q | git add -p 2>error &&
+	test_must_be_empty error &&
 	git diff >output &&
 	diff_cmp expected output
 '
@@ -220,6 +273,35 @@ test_expect_success FILEMODE 'stage mode
 
 # end of tests disabled when filemode is not usable
 
+test_expect_success 'different prompts for mode change/deleted' '
+	git reset --hard &&
+	>file &&
+	>deleted &&
+	git add --chmod=+x file deleted &&
+	echo changed >file &&
+	rm deleted &&
+	test_write_lines n n n |
+	git -c core.filemode=true add -p >actual &&
+	sed -n "s/^\(([0-9/]*) Stage .*?\).*/\1/p" actual >actual.filtered &&
+	cat >expect <<-\EOF &&
+	(1/1) Stage deletion [y,n,q,a,d,?]?
+	(1/2) Stage mode change [y,n,q,a,d,j,J,g,/,?]?
+	(2/2) Stage this hunk [y,n,q,a,d,K,g,/,e,?]?
+	EOF
+	test_cmp expect actual.filtered
+'
+
+test_expect_success 'correct message when there is nothing to do' '
+	git reset --hard &&
+	git add -p 2>err &&
+	test_i18ngrep "No changes" err &&
+	printf "\\0123" >binary &&
+	git add binary &&
+	printf "\\0abc" >binary &&
+	git add -p 2>err &&
+	test_i18ngrep "Only binary files changed" err
+'
+
 test_expect_success 'setup again' '
 	git reset --hard &&
 	test_chmod +x file &&
@@ -271,7 +353,7 @@ test_expect_success C_LOCALE_OUTPUT 'add
 	git commit -am "clear local changes" &&
 	git apply patch &&
 	printf "%s\n" s y y | git add -p file 2>error |
-		sed -n -e "s/^Stage this hunk[^@]*\(@@ .*\)/\1/" \
+		sed -n -e "s/^([1-2]\/[1-2]) Stage this hunk[^@]*\(@@ .*\)/\1/" \
 		       -e "/^[-+@ \\\\]"/p  >output &&
 	test_must_be_empty error &&
 	git diff --cached >diff &&
@@ -331,6 +413,36 @@ test_expect_success 'split hunk setup' '
 	test_write_lines 10 15 20 21 22 23 24 30 40 50 60 >test
 '
 
+test_expect_success 'goto hunk' '
+	test_when_finished "git reset" &&
+	tr _ " " >expect <<-EOF &&
+	(2/2) Stage this hunk [y,n,q,a,d,K,g,/,e,?]? + 1:  -1,2 +1,3          +15
+	_ 2:  -2,4 +3,8          +21
+	go to which hunk? @@ -1,2 +1,3 @@
+	_10
+	+15
+	_20
+	(1/2) Stage this hunk [y,n,q,a,d,j,J,g,/,e,?]?_
+	EOF
+	test_write_lines s y g 1 | git add -p >actual &&
+	tail -n 7 <actual >actual.trimmed &&
+	test_cmp expect actual.trimmed
+'
+
+test_expect_success 'navigate to hunk via regex' '
+	test_when_finished "git reset" &&
+	tr _ " " >expect <<-EOF &&
+	(2/2) Stage this hunk [y,n,q,a,d,K,g,/,e,?]? @@ -1,2 +1,3 @@
+	_10
+	+15
+	_20
+	(1/2) Stage this hunk [y,n,q,a,d,j,J,g,/,e,?]?_
+	EOF
+	test_write_lines s y /1,2 | git add -p >actual &&
+	tail -n 5 <actual >actual.trimmed &&
+	test_cmp expect actual.trimmed
+'
+
 test_expect_success 'split hunk "add -p (edit)"' '
 	# Split, say Edit and do nothing.  Then:
 	#
@@ -360,6 +472,40 @@ test_expect_failure 'split hunk "add -p
 	! grep "^+31" actual
 '
 
+test_expect_success 'split hunk with incomplete line at end' '
+	git reset --hard &&
+	printf "missing LF" >>test &&
+	git add test &&
+	test_write_lines before 10 20 30 40 50 60 70 >test &&
+	git grep --cached missing &&
+	test_write_lines s n y q | git add -p &&
+	test_must_fail git grep --cached missing &&
+	git grep before &&
+	test_must_fail git grep --cached before
+'
+
+test_expect_failure 'edit, adding lines to the first hunk' '
+	test_write_lines 10 11 20 30 40 50 51 60 >test &&
+	git reset &&
+	tr _ " " >patch <<-EOF &&
+	@@ -1,5 +1,6 @@
+	_10
+	+11
+	+12
+	_20
+	+21
+	+22
+	_30
+	EOF
+	# test sequence is s(plit), e(dit), n(o)
+	# q n q q is there to make sure we exit at the end.
+	printf "%s\n" s e n   q n q q |
+	EDITOR=./fake_editor.sh git add -p 2>error &&
+	test_must_be_empty error &&
+	git diff --cached >actual &&
+	grep "^+22" actual
+'
+
 test_expect_success 'patch mode ignores unmerged entries' '
 	git reset --hard &&
 	test_commit conflict &&
@@ -386,35 +532,48 @@ test_expect_success 'patch mode ignores
 	diff_cmp expected diff
 '
 
-test_expect_success TTY 'diffs can be colorized' '
+test_expect_success 'diffs can be colorized' '
 	git reset --hard &&
 
 	echo content >test &&
-	printf y | test_terminal git add -p >output 2>&1 &&
+	printf y >y &&
+	force_color git add -p >output 2>&1 <y &&
 
 	# We do not want to depend on the exact coloring scheme
 	# git uses for diffs, so just check that we saw some kind of color.
 	grep "$(printf "\\033")" output
 '
 
-test_expect_success TTY 'diffFilter filters diff' '
+test_expect_success 'diffFilter filters diff' '
 	git reset --hard &&
 
 	echo content >test &&
 	test_config interactive.diffFilter "sed s/^/foo:/" &&
-	printf y | test_terminal git add -p >output 2>&1 &&
+	printf y >y &&
+	force_color git add -p >output 2>&1 <y &&
 
 	# avoid depending on the exact coloring or content of the prompts,
 	# and just make sure we saw our diff prefixed
 	grep foo:.*content output
 '
 
-test_expect_success TTY 'detect bogus diffFilter output' '
+test_expect_success 'detect bogus diffFilter output' '
 	git reset --hard &&
 
 	echo content >test &&
 	test_config interactive.diffFilter "echo too-short" &&
-	printf y | test_must_fail test_terminal git add -p
+	printf y >y &&
+	test_must_fail force_color git add -p <y
+'
+
+test_expect_success 'diff.algorithm is passed to `git diff-files`' '
+	git reset --hard &&
+
+	>file &&
+	git add file &&
+	echo changed >file &&
+	test_must_fail git -c diff.algorithm=bogus add -p 2>err &&
+	test_i18ngrep "error: option diff-algorithm accepts " err
 '
 
 test_expect_success 'patch-mode via -i prompts for files' '
@@ -497,7 +656,7 @@ test_expect_success 'add -p does not exp
 	# update it, but we want to be sure that our "." pathspec
 	# was not expanded into the argument list of any command.
 	# So look only for "not-changed".
-	! grep not-changed trace.out
+	! grep -E "^trace: (built-in|exec|run_command): .*not-changed" trace.out
 '
 
 test_expect_success 'hunk-editing handles custom comment char' '
@@ -596,4 +755,37 @@ test_expect_success 'add -p patch editin
 	test_cmp expected-2 actual
 '
 
+test_expect_success 'checkout -p works with pathological context lines' '
+	test_write_lines a a a a a a >a &&
+	git add a &&
+	test_write_lines a b a b a b a b a b a > a&&
+	test_write_lines s n n y q | git checkout -p &&
+	test_write_lines a b a b a a b a b a >expect &&
+	test_cmp expect a
+'
+
+test_expect_success 'show help from add--helper' '
+	git reset --hard &&
+	cat >expect <<-EOF &&
+
+	<BOLD>*** Commands ***<RESET>
+	  1: <BOLD;BLUE>s<RESET>tatus	  2: <BOLD;BLUE>u<RESET>pdate	  3: <BOLD;BLUE>r<RESET>evert	  4: <BOLD;BLUE>a<RESET>dd untracked
+	  5: <BOLD;BLUE>p<RESET>atch	  6: <BOLD;BLUE>d<RESET>iff	  7: <BOLD;BLUE>q<RESET>uit	  8: <BOLD;BLUE>h<RESET>elp
+	<BOLD;BLUE>What now<RESET>> <BOLD;RED>status        - show paths with changes<RESET>
+	<BOLD;RED>update        - add working tree state to the staged set of changes<RESET>
+	<BOLD;RED>revert        - revert staged set of changes back to the HEAD version<RESET>
+	<BOLD;RED>patch         - pick hunks and update selectively<RESET>
+	<BOLD;RED>diff          - view diff between HEAD and index<RESET>
+	<BOLD;RED>add untracked - add contents of untracked files to the staged set of changes<RESET>
+	<BOLD>*** Commands ***<RESET>
+	  1: <BOLD;BLUE>s<RESET>tatus	  2: <BOLD;BLUE>u<RESET>pdate	  3: <BOLD;BLUE>r<RESET>evert	  4: <BOLD;BLUE>a<RESET>dd untracked
+	  5: <BOLD;BLUE>p<RESET>atch	  6: <BOLD;BLUE>d<RESET>iff	  7: <BOLD;BLUE>q<RESET>uit	  8: <BOLD;BLUE>h<RESET>elp
+	<BOLD;BLUE>What now<RESET>>$SP
+	Bye.
+	EOF
+	test_write_lines h | force_color git add -i >actual.colored &&
+	test_decode_color <actual.colored >actual &&
+	test_i18ncmp expect actual
+'
+
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t3702-add-edit.sh 1.2.3+git2.25.1-1/git/t/t3702-add-edit.sh
--- 1.2.1+git2.18.0-1/git/t/t3702-add-edit.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t3702-add-edit.sh	2020-02-17 04:47:35.000000000 +0000
@@ -110,10 +110,10 @@ test_expect_success 'add -e' '
 	cp second-part file &&
 	git add -e &&
 	test_cmp second-part file &&
-	test_cmp orig-patch expected-patch &&
+	test_cmp expected-patch orig-patch &&
 	git diff --cached >actual &&
 	grep -v index actual >out &&
-	test_cmp out expected
+	test_cmp expected out
 
 '
 
diff -pruN 1.2.1+git2.18.0-1/git/t/t3704-add-pathspec-file.sh 1.2.3+git2.25.1-1/git/t/t3704-add-pathspec-file.sh
--- 1.2.1+git2.18.0-1/git/t/t3704-add-pathspec-file.sh	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t3704-add-pathspec-file.sh	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,127 @@
+#!/bin/sh
+
+test_description='add --pathspec-from-file'
+
+. ./test-lib.sh
+
+test_tick
+
+test_expect_success setup '
+	test_commit file0 &&
+	echo A >fileA.t &&
+	echo B >fileB.t &&
+	echo C >fileC.t &&
+	echo D >fileD.t
+'
+
+restore_checkpoint () {
+	git reset
+}
+
+verify_expect () {
+	git status --porcelain --untracked-files=no -- fileA.t fileB.t fileC.t fileD.t >actual &&
+	test_cmp expect actual
+}
+
+test_expect_success '--pathspec-from-file from stdin' '
+	restore_checkpoint &&
+
+	echo fileA.t | git add --pathspec-from-file=- &&
+
+	cat >expect <<-\EOF &&
+	A  fileA.t
+	EOF
+	verify_expect
+'
+
+test_expect_success '--pathspec-from-file from file' '
+	restore_checkpoint &&
+
+	echo fileA.t >list &&
+	git add --pathspec-from-file=list &&
+
+	cat >expect <<-\EOF &&
+	A  fileA.t
+	EOF
+	verify_expect
+'
+
+test_expect_success 'NUL delimiters' '
+	restore_checkpoint &&
+
+	printf "fileA.t\0fileB.t\0" | git add --pathspec-from-file=- --pathspec-file-nul &&
+
+	cat >expect <<-\EOF &&
+	A  fileA.t
+	A  fileB.t
+	EOF
+	verify_expect
+'
+
+test_expect_success 'LF delimiters' '
+	restore_checkpoint &&
+
+	printf "fileA.t\nfileB.t\n" | git add --pathspec-from-file=- &&
+
+	cat >expect <<-\EOF &&
+	A  fileA.t
+	A  fileB.t
+	EOF
+	verify_expect
+'
+
+test_expect_success 'no trailing delimiter' '
+	restore_checkpoint &&
+
+	printf "fileA.t\nfileB.t" | git add --pathspec-from-file=- &&
+
+	cat >expect <<-\EOF &&
+	A  fileA.t
+	A  fileB.t
+	EOF
+	verify_expect
+'
+
+test_expect_success 'CRLF delimiters' '
+	restore_checkpoint &&
+
+	printf "fileA.t\r\nfileB.t\r\n" | git add --pathspec-from-file=- &&
+
+	cat >expect <<-\EOF &&
+	A  fileA.t
+	A  fileB.t
+	EOF
+	verify_expect
+'
+
+test_expect_success 'quotes' '
+	restore_checkpoint &&
+
+	printf "\"file\\101.t\"" | git add --pathspec-from-file=- &&
+
+	cat >expect <<-\EOF &&
+	A  fileA.t
+	EOF
+	verify_expect
+'
+
+test_expect_success 'quotes not compatible with --pathspec-file-nul' '
+	restore_checkpoint &&
+
+	printf "\"file\\101.t\"" >list &&
+	test_must_fail git add --pathspec-from-file=list --pathspec-file-nul
+'
+
+test_expect_success 'only touches what was listed' '
+	restore_checkpoint &&
+
+	printf "fileB.t\nfileC.t\n" | git add --pathspec-from-file=- &&
+
+	cat >expect <<-\EOF &&
+	A  fileB.t
+	A  fileC.t
+	EOF
+	verify_expect
+'
+
+test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t3800-mktag.sh 1.2.3+git2.25.1-1/git/t/t3800-mktag.sh
--- 1.2.1+git2.18.0-1/git/t/t3800-mktag.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t3800-mktag.sh	2020-02-17 04:47:35.000000000 +0000
@@ -23,6 +23,7 @@ check_verify_failure () {
 # first create a commit, so we have a valid object/type
 # for the tag.
 test_expect_success 'setup' '
+	test_oid_init &&
 	echo Hello >A &&
 	git update-index --add A &&
 	git commit -m "Initial commit" &&
@@ -69,28 +70,28 @@ check_verify_failure '"object" line SHA1
 #  4. type line label check
 
 cat >tag.sig <<EOF
-object 779e9b33986b1c2670fff52c5067603117b3e895
+object $head
 xxxx tag
 tag mytag
 tagger . <> 0 +0000
 
 EOF
 
-check_verify_failure '"type" line label check' '^error: char47: .*"\\ntype "$'
+check_verify_failure '"type" line label check' '^error: char.*: .*"\\ntype "$'
 
 ############################################################
 #  5. type line eol check
 
-echo "object 779e9b33986b1c2670fff52c5067603117b3e895" >tag.sig
+echo "object $head" >tag.sig
 printf "type tagsssssssssssssssssssssssssssssss" >>tag.sig
 
-check_verify_failure '"type" line eol check' '^error: char48: .*"\\n"$'
+check_verify_failure '"type" line eol check' '^error: char.*: .*"\\n"$'
 
 ############################################################
 #  6. tag line label check #1
 
 cat >tag.sig <<EOF
-object 779e9b33986b1c2670fff52c5067603117b3e895
+object $head
 type tag
 xxx mytag
 tagger . <> 0 +0000
@@ -98,37 +99,37 @@ tagger . <> 0 +0000
 EOF
 
 check_verify_failure '"tag" line label check #1' \
-	'^error: char57: no "tag " found$'
+	'^error: char.*: no "tag " found$'
 
 ############################################################
 #  7. tag line label check #2
 
 cat >tag.sig <<EOF
-object 779e9b33986b1c2670fff52c5067603117b3e895
+object $head
 type taggggggggggggggggggggggggggggggg
 tag
 EOF
 
 check_verify_failure '"tag" line label check #2' \
-	'^error: char87: no "tag " found$'
+	'^error: char.*: no "tag " found$'
 
 ############################################################
 #  8. type line type-name length check
 
 cat >tag.sig <<EOF
-object 779e9b33986b1c2670fff52c5067603117b3e895
+object $head
 type taggggggggggggggggggggggggggggggg
 tag mytag
 EOF
 
 check_verify_failure '"type" line type-name length check' \
-	'^error: char53: type too long$'
+	'^error: char.*: type too long$'
 
 ############################################################
 #  9. verify object (SHA1/type) check
 
 cat >tag.sig <<EOF
-object 779e9b33986b1c2670fff52c5067603117b3e895
+object $(test_oid deadbeef)
 type tagggg
 tag mytag
 tagger . <> 0 +0000
@@ -150,7 +151,7 @@ tagger . <> 0 +0000
 EOF
 
 check_verify_failure 'verify tag-name check' \
-	'^error: char67: could not verify tag name$'
+	'^error: char.*: could not verify tag name$'
 
 ############################################################
 # 11. tagger line label check #1
@@ -164,7 +165,7 @@ This is filler
 EOF
 
 check_verify_failure '"tagger" line label check #1' \
-	'^error: char70: could not find "tagger "$'
+	'^error: char.*: could not find "tagger "$'
 
 ############################################################
 # 12. tagger line label check #2
@@ -179,7 +180,7 @@ This is filler
 EOF
 
 check_verify_failure '"tagger" line label check #2' \
-	'^error: char70: could not find "tagger "$'
+	'^error: char.*: could not find "tagger "$'
 
 ############################################################
 # 13. disallow missing tag author name
@@ -194,7 +195,7 @@ This is filler
 EOF
 
 check_verify_failure 'disallow missing tag author name' \
-	'^error: char77: missing tagger name$'
+	'^error: char.*: missing tagger name$'
 
 ############################################################
 # 14. disallow missing tag author name
@@ -209,7 +210,7 @@ tagger T A Gger <
 EOF
 
 check_verify_failure 'disallow malformed tagger' \
-	'^error: char77: malformed tagger field$'
+	'^error: char.*: malformed tagger field$'
 
 ############################################################
 # 15. allow empty tag email
@@ -238,7 +239,7 @@ tagger T A Gger <tag ger@example.com> 0
 EOF
 
 check_verify_failure 'disallow spaces in tag email' \
-	'^error: char77: malformed tagger field$'
+	'^error: char.*: malformed tagger field$'
 
 ############################################################
 # 17. disallow missing tag timestamp
@@ -252,7 +253,7 @@ tagger T A Gger <tagger@example.com>__
 EOF
 
 check_verify_failure 'disallow missing tag timestamp' \
-	'^error: char107: missing tag timestamp$'
+	'^error: char.*: missing tag timestamp$'
 
 ############################################################
 # 18. detect invalid tag timestamp1
@@ -266,7 +267,7 @@ tagger T A Gger <tagger@example.com> Tue
 EOF
 
 check_verify_failure 'detect invalid tag timestamp1' \
-	'^error: char107: missing tag timestamp$'
+	'^error: char.*: missing tag timestamp$'
 
 ############################################################
 # 19. detect invalid tag timestamp2
@@ -280,7 +281,7 @@ tagger T A Gger <tagger@example.com> 200
 EOF
 
 check_verify_failure 'detect invalid tag timestamp2' \
-	'^error: char111: malformed tag timestamp$'
+	'^error: char.*: malformed tag timestamp$'
 
 ############################################################
 # 20. detect invalid tag timezone1
@@ -294,7 +295,7 @@ tagger T A Gger <tagger@example.com> 120
 EOF
 
 check_verify_failure 'detect invalid tag timezone1' \
-	'^error: char118: malformed tag timezone$'
+	'^error: char.*: malformed tag timezone$'
 
 ############################################################
 # 21. detect invalid tag timezone2
@@ -308,7 +309,7 @@ tagger T A Gger <tagger@example.com> 120
 EOF
 
 check_verify_failure 'detect invalid tag timezone2' \
-	'^error: char118: malformed tag timezone$'
+	'^error: char.*: malformed tag timezone$'
 
 ############################################################
 # 22. detect invalid tag timezone3
@@ -322,7 +323,7 @@ tagger T A Gger <tagger@example.com> 120
 EOF
 
 check_verify_failure 'detect invalid tag timezone3' \
-	'^error: char118: malformed tag timezone$'
+	'^error: char.*: malformed tag timezone$'
 
 ############################################################
 # 23. detect invalid header entry
@@ -337,7 +338,7 @@ this line should not be here
 EOF
 
 check_verify_failure 'detect invalid header entry' \
-	'^error: char124: trailing garbage in tag header$'
+	'^error: char.*: trailing garbage in tag header$'
 
 ############################################################
 # 24. create valid tag
diff -pruN 1.2.1+git2.18.0-1/git/t/t3900-i18n-commit.sh 1.2.3+git2.25.1-1/git/t/t3900-i18n-commit.sh
--- 1.2.1+git2.18.0-1/git/t/t3900-i18n-commit.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t3900-i18n-commit.sh	2020-02-17 04:47:35.000000000 +0000
@@ -204,4 +204,41 @@ test_commit_autosquash_flags eucJP fixup
 
 test_commit_autosquash_flags ISO-2022-JP squash
 
+test_commit_autosquash_multi_encoding () {
+	flag=$1
+	old=$2
+	new=$3
+	msg=$4
+	test_expect_success "commit --$flag into $old from $new" '
+		git checkout -b $flag-$old-$new C0 &&
+		git config i18n.commitencoding $old &&
+		echo $old >>F &&
+		git commit -a -F "$TEST_DIRECTORY"/t3900/$msg &&
+		test_tick &&
+		echo intermediate stuff >>G &&
+		git add G &&
+		git commit -a -m "intermediate commit" &&
+		test_tick &&
+		git config i18n.commitencoding $new &&
+		echo $new-$flag >>F &&
+		git commit -a --$flag HEAD^ &&
+		git rebase --autosquash -i HEAD^^^ &&
+		git rev-list HEAD >actual &&
+		test_line_count = 3 actual &&
+		iconv -f $old -t UTF-8 "$TEST_DIRECTORY"/t3900/$msg >expect &&
+		if test $flag = squash; then
+			subject="$(head -1 expect)" &&
+			printf "\nsquash! %s\n" "$subject" >>expect
+		fi &&
+		git cat-file commit HEAD^ >raw &&
+		(sed "1,/^$/d" raw | iconv -f $new -t utf-8) >actual &&
+		test_cmp expect actual
+	'
+}
+
+test_commit_autosquash_multi_encoding fixup UTF-8 ISO-8859-1 1-UTF-8.txt
+test_commit_autosquash_multi_encoding squash ISO-8859-1 UTF-8 ISO8859-1.txt
+test_commit_autosquash_multi_encoding squash eucJP ISO-2022-JP eucJP.txt
+test_commit_autosquash_multi_encoding fixup ISO-2022-JP UTF-8 ISO-2022-JP.txt
+
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t3903-stash.sh 1.2.3+git2.25.1-1/git/t/t3903-stash.sh
--- 1.2.1+git2.18.0-1/git/t/t3903-stash.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t3903-stash.sh	2020-02-17 04:47:35.000000000 +0000
@@ -7,23 +7,35 @@ test_description='Test git stash'
 
 . ./test-lib.sh
 
+diff_cmp () {
+	for i in "$1" "$2"
+	do
+		sed -e 's/^index 0000000\.\.[0-9a-f]*/index 0000000..1234567/' \
+		-e 's/^index [0-9a-f]*\.\.[0-9a-f]*/index 1234567..89abcde/' \
+		-e 's/^index [0-9a-f]*,[0-9a-f]*\.\.[0-9a-f]*/index 1234567,7654321..89abcde/' \
+		"$i" >"$i.compare" || return 1
+	done &&
+	test_cmp "$1.compare" "$2.compare" &&
+	rm -f "$1.compare" "$2.compare"
+}
+
 test_expect_success 'stash some dirty working directory' '
-	echo 1 > file &&
+	echo 1 >file &&
 	git add file &&
 	echo unrelated >other-file &&
 	git add other-file &&
 	test_tick &&
 	git commit -m initial &&
-	echo 2 > file &&
+	echo 2 >file &&
 	git add file &&
-	echo 3 > file &&
+	echo 3 >file &&
 	test_tick &&
 	git stash &&
 	git diff-files --quiet &&
 	git diff-index --cached --quiet HEAD
 '
 
-cat > expect << EOF
+cat >expect <<EOF
 diff --git a/file b/file
 index 0cfbf08..00750ed 100644
 --- a/file
@@ -35,8 +47,8 @@ EOF
 
 test_expect_success 'parents of stash' '
 	test $(git rev-parse stash^) = $(git rev-parse HEAD) &&
-	git diff stash^2..stash > output &&
-	test_cmp output expect
+	git diff stash^2..stash >output &&
+	diff_cmp expect output
 '
 
 test_expect_success 'applying bogus stash does nothing' '
@@ -74,7 +86,7 @@ test_expect_success 'apply stashed chang
 
 test_expect_success 'apply stashed changes (including index)' '
 	git reset --hard HEAD^ &&
-	echo 6 > other-file &&
+	echo 6 >other-file &&
 	git add other-file &&
 	test_tick &&
 	git commit -m other-file &&
@@ -99,12 +111,12 @@ test_expect_success 'stash drop complain
 
 test_expect_success 'drop top stash' '
 	git reset --hard &&
-	git stash list > stashlist1 &&
-	echo 7 > file &&
+	git stash list >expected &&
+	echo 7 >file &&
 	git stash &&
 	git stash drop &&
-	git stash list > stashlist2 &&
-	test_cmp stashlist1 stashlist2 &&
+	git stash list >actual &&
+	test_cmp expected actual &&
 	git stash apply &&
 	test 3 = $(cat file) &&
 	test 1 = $(git show :file) &&
@@ -113,9 +125,9 @@ test_expect_success 'drop top stash' '
 
 test_expect_success 'drop middle stash' '
 	git reset --hard &&
-	echo 8 > file &&
+	echo 8 >file &&
 	git stash &&
-	echo 9 > file &&
+	echo 9 >file &&
 	git stash &&
 	git stash drop stash@{1} &&
 	test 2 = $(git stash list | wc -l) &&
@@ -160,7 +172,7 @@ test_expect_success 'stash pop' '
 	test 0 = $(git stash list | wc -l)
 '
 
-cat > expect << EOF
+cat >expect <<EOF
 diff --git a/file2 b/file2
 new file mode 100644
 index 0000000..1fe912c
@@ -170,7 +182,7 @@ index 0000000..1fe912c
 +bar2
 EOF
 
-cat > expect1 << EOF
+cat >expect1 <<EOF
 diff --git a/file b/file
 index 257cc56..5716ca5 100644
 --- a/file
@@ -180,7 +192,7 @@ index 257cc56..5716ca5 100644
 +bar
 EOF
 
-cat > expect2 << EOF
+cat >expect2 <<EOF
 diff --git a/file b/file
 index 7601807..5716ca5 100644
 --- a/file
@@ -198,79 +210,84 @@ index 0000000..1fe912c
 EOF
 
 test_expect_success 'stash branch' '
-	echo foo > file &&
+	echo foo >file &&
 	git commit file -m first &&
-	echo bar > file &&
-	echo bar2 > file2 &&
+	echo bar >file &&
+	echo bar2 >file2 &&
 	git add file2 &&
 	git stash &&
-	echo baz > file &&
+	echo baz >file &&
 	git commit file -m second &&
 	git stash branch stashbranch &&
 	test refs/heads/stashbranch = $(git symbolic-ref HEAD) &&
 	test $(git rev-parse HEAD) = $(git rev-parse master^) &&
-	git diff --cached > output &&
-	test_cmp output expect &&
-	git diff > output &&
-	test_cmp output expect1 &&
+	git diff --cached >output &&
+	diff_cmp expect output &&
+	git diff >output &&
+	diff_cmp expect1 output &&
 	git add file &&
 	git commit -m alternate\ second &&
-	git diff master..stashbranch > output &&
-	test_cmp output expect2 &&
+	git diff master..stashbranch >output &&
+	diff_cmp output expect2 &&
 	test 0 = $(git stash list | wc -l)
 '
 
 test_expect_success 'apply -q is quiet' '
-	echo foo > file &&
+	echo foo >file &&
 	git stash &&
-	git stash apply -q > output.out 2>&1 &&
+	git stash apply -q >output.out 2>&1 &&
 	test_must_be_empty output.out
 '
 
 test_expect_success 'save -q is quiet' '
-	git stash save --quiet > output.out 2>&1 &&
+	git stash save --quiet >output.out 2>&1 &&
 	test_must_be_empty output.out
 '
 
-test_expect_success 'pop -q is quiet' '
-	git stash pop -q > output.out 2>&1 &&
+test_expect_success 'pop -q works and is quiet' '
+	git stash pop -q >output.out 2>&1 &&
+	echo bar >expect &&
+	git show :file >actual &&
+	test_cmp expect actual &&
 	test_must_be_empty output.out
 '
 
 test_expect_success 'pop -q --index works and is quiet' '
-	echo foo > file &&
+	echo foo >file &&
 	git add file &&
 	git stash save --quiet &&
-	git stash pop -q --index > output.out 2>&1 &&
+	git stash pop -q --index >output.out 2>&1 &&
+	git diff-files file2 >file2.diff &&
+	test_must_be_empty file2.diff &&
 	test foo = "$(git show :file)" &&
 	test_must_be_empty output.out
 '
 
 test_expect_success 'drop -q is quiet' '
 	git stash &&
-	git stash drop -q > output.out 2>&1 &&
+	git stash drop -q >output.out 2>&1 &&
 	test_must_be_empty output.out
 '
 
 test_expect_success 'stash -k' '
-	echo bar3 > file &&
-	echo bar4 > file2 &&
+	echo bar3 >file &&
+	echo bar4 >file2 &&
 	git add file2 &&
 	git stash -k &&
 	test bar,bar4 = $(cat file),$(cat file2)
 '
 
 test_expect_success 'stash --no-keep-index' '
-	echo bar33 > file &&
-	echo bar44 > file2 &&
+	echo bar33 >file &&
+	echo bar44 >file2 &&
 	git add file2 &&
 	git stash --no-keep-index &&
 	test bar,bar2 = $(cat file),$(cat file2)
 '
 
 test_expect_success 'stash --invalid-option' '
-	echo bar5 > file &&
-	echo bar6 > file2 &&
+	echo bar5 >file &&
+	echo bar6 >file2 &&
 	git add file2 &&
 	test_must_fail git stash --invalid-option &&
 	test_must_fail git stash save --invalid-option &&
@@ -287,6 +304,14 @@ test_expect_success 'stash an added file
 	test new = "$(cat file3)"
 '
 
+test_expect_success 'stash --intent-to-add file' '
+	git reset --hard &&
+	echo new >file4 &&
+	git add --intent-to-add file4 &&
+	test_when_finished "git rm -f file4" &&
+	test_must_fail git stash
+'
+
 test_expect_success 'stash rm then recreate' '
 	git reset --hard &&
 	git rm file &&
@@ -444,6 +469,36 @@ test_expect_failure 'stash file to direc
 	test foo = "$(cat file/file)"
 '
 
+test_expect_success 'giving too many ref arguments does not modify files' '
+	git stash clear &&
+	test_when_finished "git reset --hard HEAD" &&
+	echo foo >file2 &&
+	git stash &&
+	echo bar >file2 &&
+	git stash &&
+	test-tool chmtime =123456789 file2 &&
+	for type in apply pop "branch stash-branch"
+	do
+		test_must_fail git stash $type stash@{0} stash@{1} 2>err &&
+		test_i18ngrep "Too many revisions" err &&
+		test 123456789 = $(test-tool chmtime -g file2) || return 1
+	done
+'
+
+test_expect_success 'drop: too many arguments errors out (does nothing)' '
+	git stash list >expect &&
+	test_must_fail git stash drop stash@{0} stash@{1} 2>err &&
+	test_i18ngrep "Too many revisions" err &&
+	git stash list >actual &&
+	test_cmp expect actual
+'
+
+test_expect_success 'show: too many arguments errors out (does nothing)' '
+	test_must_fail git stash show stash@{0} stash@{1} 2>err 1>out &&
+	test_i18ngrep "Too many revisions" err &&
+	test_must_be_empty out
+'
+
 test_expect_success 'stash create - no changes' '
 	git stash clear &&
 	test_when_finished "git reset --hard HEAD" &&
@@ -456,11 +511,12 @@ test_expect_success 'stash branch - no s
 	git stash clear &&
 	test_when_finished "git reset --hard HEAD" &&
 	git reset --hard &&
-	echo foo >> file &&
+	echo foo >>file &&
 	STASH_ID=$(git stash create) &&
 	git reset --hard &&
 	git stash branch stash-branch ${STASH_ID} &&
-	test_when_finished "git reset --hard HEAD && git checkout master && git branch -D stash-branch" &&
+	test_when_finished "git reset --hard HEAD && git checkout master &&
+	git branch -D stash-branch" &&
 	test $(git ls-files --modified | wc -l) -eq 1
 '
 
@@ -468,25 +524,31 @@ test_expect_success 'stash branch - stas
 	git stash clear &&
 	test_when_finished "git reset --hard HEAD" &&
 	git reset --hard &&
-	echo foo >> file &&
+	echo foo >>file &&
 	git stash &&
 	test_when_finished "git stash drop" &&
-	echo bar >> file &&
+	echo bar >>file &&
 	STASH_ID=$(git stash create) &&
 	git reset --hard &&
 	git stash branch stash-branch ${STASH_ID} &&
-	test_when_finished "git reset --hard HEAD && git checkout master && git branch -D stash-branch" &&
+	test_when_finished "git reset --hard HEAD && git checkout master &&
+	git branch -D stash-branch" &&
 	test $(git ls-files --modified | wc -l) -eq 1
 '
 
+test_expect_success 'stash branch complains with no arguments' '
+	test_must_fail git stash branch 2>err &&
+	test_i18ngrep "No branch name specified" err
+'
+
 test_expect_success 'stash show format defaults to --stat' '
 	git stash clear &&
 	test_when_finished "git reset --hard HEAD" &&
 	git reset --hard &&
-	echo foo >> file &&
+	echo foo >>file &&
 	git stash &&
 	test_when_finished "git stash drop" &&
-	echo bar >> file &&
+	echo bar >>file &&
 	STASH_ID=$(git stash create) &&
 	git reset --hard &&
 	cat >expected <<-EOF &&
@@ -501,10 +563,10 @@ test_expect_success 'stash show - stashe
 	git stash clear &&
 	test_when_finished "git reset --hard HEAD" &&
 	git reset --hard &&
-	echo foo >> file &&
+	echo foo >>file &&
 	git stash &&
 	test_when_finished "git stash drop" &&
-	echo bar >> file &&
+	echo bar >>file &&
 	STASH_ID=$(git stash create) &&
 	git reset --hard &&
 	echo "1	0	file" >expected &&
@@ -516,10 +578,10 @@ test_expect_success 'stash show -p - sta
 	git stash clear &&
 	test_when_finished "git reset --hard HEAD" &&
 	git reset --hard &&
-	echo foo >> file &&
+	echo foo >>file &&
 	git stash &&
 	test_when_finished "git stash drop" &&
-	echo bar >> file &&
+	echo bar >>file &&
 	STASH_ID=$(git stash create) &&
 	git reset --hard &&
 	cat >expected <<-EOF &&
@@ -532,14 +594,14 @@ test_expect_success 'stash show -p - sta
 	+bar
 	EOF
 	git stash show -p ${STASH_ID} >actual &&
-	test_cmp expected actual
+	diff_cmp expected actual
 '
 
 test_expect_success 'stash show - no stashes on stack, stash-like argument' '
 	git stash clear &&
 	test_when_finished "git reset --hard HEAD" &&
 	git reset --hard &&
-	echo foo >> file &&
+	echo foo >>file &&
 	STASH_ID=$(git stash create) &&
 	git reset --hard &&
 	echo "1	0	file" >expected &&
@@ -551,7 +613,7 @@ test_expect_success 'stash show -p - no
 	git stash clear &&
 	test_when_finished "git reset --hard HEAD" &&
 	git reset --hard &&
-	echo foo >> file &&
+	echo foo >>file &&
 	STASH_ID=$(git stash create) &&
 	git reset --hard &&
 	cat >expected <<-EOF &&
@@ -564,16 +626,34 @@ test_expect_success 'stash show -p - no
 	+foo
 	EOF
 	git stash show -p ${STASH_ID} >actual &&
-	test_cmp expected actual
+	diff_cmp expected actual
 '
 
-test_expect_success 'stash drop - fail early if specified stash is not a stash reference' '
+test_expect_success 'stash show --patience shows diff' '
+	git reset --hard &&
+	echo foo >>file &&
+	STASH_ID=$(git stash create) &&
+	git reset --hard &&
+	cat >expected <<-EOF &&
+	diff --git a/file b/file
+	index 7601807..71b52c4 100644
+	--- a/file
+	+++ b/file
+	@@ -1 +1,2 @@
+	 baz
+	+foo
+	EOF
+	git stash show --patience ${STASH_ID} >actual &&
+	diff_cmp expected actual
+'
+
+test_expect_success 'drop: fail early if specified stash is not a stash ref' '
 	git stash clear &&
 	test_when_finished "git reset --hard HEAD && git stash clear" &&
 	git reset --hard &&
-	echo foo > file &&
+	echo foo >file &&
 	git stash &&
-	echo bar > file &&
+	echo bar >file &&
 	git stash &&
 	test_must_fail git stash drop $(git rev-parse stash@{0}) &&
 	git stash pop &&
@@ -581,13 +661,13 @@ test_expect_success 'stash drop - fail e
 	git reset --hard HEAD
 '
 
-test_expect_success 'stash pop - fail early if specified stash is not a stash reference' '
+test_expect_success 'pop: fail early if specified stash is not a stash ref' '
 	git stash clear &&
 	test_when_finished "git reset --hard HEAD && git stash clear" &&
 	git reset --hard &&
-	echo foo > file &&
+	echo foo >file &&
 	git stash &&
-	echo bar > file &&
+	echo bar >file &&
 	git stash &&
 	test_must_fail git stash pop $(git rev-parse stash@{0}) &&
 	git stash pop &&
@@ -597,8 +677,8 @@ test_expect_success 'stash pop - fail ea
 
 test_expect_success 'ref with non-existent reflog' '
 	git stash clear &&
-	echo bar5 > file &&
-	echo bar6 > file2 &&
+	echo bar5 >file &&
+	echo bar6 >file2 &&
 	git add file2 &&
 	git stash &&
 	test_must_fail git rev-parse --quiet --verify does-not-exist &&
@@ -618,8 +698,8 @@ test_expect_success 'ref with non-existe
 test_expect_success 'invalid ref of the form stash@{n}, n >= N' '
 	git stash clear &&
 	test_must_fail git stash drop stash@{0} &&
-	echo bar5 > file &&
-	echo bar6 > file2 &&
+	echo bar5 >file &&
+	echo bar6 >file2 &&
 	git add file2 &&
 	git stash &&
 	test_must_fail git stash drop stash@{1} &&
@@ -645,7 +725,25 @@ test_expect_success 'invalid ref of the
 	git stash drop
 '
 
-test_expect_success 'stash branch should not drop the stash if the branch exists' '
+test_expect_success 'valid ref of the form "n", n < N' '
+	git stash clear &&
+	echo bar5 >file &&
+	echo bar6 >file2 &&
+	git add file2 &&
+	git stash &&
+	git stash show 0 &&
+	git stash branch tmp 0 &&
+	git checkout master &&
+	git stash &&
+	git stash apply 0 &&
+	git reset --hard &&
+	git stash pop 0 &&
+	git stash &&
+	git stash drop 0 &&
+	test_must_fail git stash drop
+'
+
+test_expect_success 'branch: do not drop the stash if the branch exists' '
 	git stash clear &&
 	echo foo >file &&
 	git add file &&
@@ -656,7 +754,7 @@ test_expect_success 'stash branch should
 	git rev-parse stash@{0} --
 '
 
-test_expect_success 'stash branch should not drop the stash if the apply fails' '
+test_expect_success 'branch: should not drop the stash if the apply fails' '
 	git stash clear &&
 	git reset HEAD~1 --hard &&
 	echo foo >file &&
@@ -670,7 +768,7 @@ test_expect_success 'stash branch should
 	git rev-parse stash@{0} --
 '
 
-test_expect_success 'stash apply shows status same as git status (relative to current directory)' '
+test_expect_success 'apply: show same status as git status (relative to ./)' '
 	git stash clear &&
 	echo 1 >subdir/subfile1 &&
 	echo 2 >subdir/subfile2 &&
@@ -689,7 +787,7 @@ test_expect_success 'stash apply shows s
 	test_i18ncmp expect actual
 '
 
-cat > expect << EOF
+cat >expect <<EOF
 diff --git a/HEAD b/HEAD
 new file mode 100644
 index 0000000..fe0cbee
@@ -702,15 +800,15 @@ EOF
 test_expect_success 'stash where working directory contains "HEAD" file' '
 	git stash clear &&
 	git reset --hard &&
-	echo file-not-a-ref > HEAD &&
+	echo file-not-a-ref >HEAD &&
 	git add HEAD &&
 	test_tick &&
 	git stash &&
 	git diff-files --quiet &&
 	git diff-index --cached --quiet HEAD &&
 	test "$(git rev-parse stash^)" = "$(git rev-parse HEAD)" &&
-	git diff stash^..stash > output &&
-	test_cmp output expect
+	git diff stash^..stash >output &&
+	diff_cmp expect output
 '
 
 test_expect_success 'store called with invalid commit' '
@@ -724,7 +822,7 @@ test_expect_success 'store updates stash
 	git add bazzy &&
 	STASH_ID=$(git stash create) &&
 	git reset --hard &&
-	! grep quux bazzy &&
+	test_path_is_missing bazzy &&
 	git stash store -m quuxery $STASH_ID &&
 	test $(git rev-parse stash) = $STASH_ID &&
 	git reflog --format=%H stash| grep $STASH_ID &&
@@ -766,7 +864,7 @@ test_expect_success 'stash list implies
 	+working
 	EOF
 	git stash list --format=%gd -p >actual &&
-	test_cmp expect actual
+	diff_cmp expect actual
 '
 
 test_expect_success 'stash list --cc shows combined diff' '
@@ -783,7 +881,7 @@ test_expect_success 'stash list --cc sho
 	++working
 	EOF
 	git stash list --format=%gd -p --cc >actual &&
-	test_cmp expect actual
+	diff_cmp expect actual
 '
 
 test_expect_success 'stash is not confused by partial renames' '
@@ -1011,7 +1109,7 @@ test_expect_success 'stash push -p with
 	test_i18ncmp expect actual
 '
 
-test_expect_success 'stash push with pathspec shows no changes when there are none' '
+test_expect_success 'push <pathspec>: show no changes when there are none' '
 	>foo &&
 	git add foo &&
 	git commit -m "tmp" &&
@@ -1021,12 +1119,35 @@ test_expect_success 'stash push with pat
 	test_i18ncmp expect actual
 '
 
-test_expect_success 'stash push with pathspec not in the repository errors out' '
+test_expect_success 'push: <pathspec> not in the repository errors out' '
 	>untracked &&
 	test_must_fail git stash push untracked &&
 	test_path_is_file untracked
 '
 
+test_expect_success 'push: -q is quiet with changes' '
+	>foo &&
+	git add foo &&
+	git stash push -q >output 2>&1 &&
+	test_must_be_empty output
+'
+
+test_expect_success 'push: -q is quiet with no changes' '
+	git stash push -q >output 2>&1 &&
+	test_must_be_empty output
+'
+
+test_expect_success 'push: -q is quiet even if there is no initial commit' '
+	git init foo_dir &&
+	test_when_finished rm -rf foo_dir &&
+	(
+		cd foo_dir &&
+		>bar &&
+		test_must_fail git stash push -q >output 2>&1 &&
+		test_must_be_empty output
+	)
+'
+
 test_expect_success 'untracked files are left in place when -u is not given' '
 	>file &&
 	git add file &&
@@ -1096,4 +1217,72 @@ test_expect_success 'stash -- <subdir> w
 	test_path_is_file subdir/untracked
 '
 
+test_expect_success 'stash with user.name and user.email set works' '
+	test_config user.name "A U Thor" &&
+	test_config user.email "a.u@thor" &&
+	git stash
+'
+
+test_expect_success 'stash works when user.name and user.email are not set' '
+	git reset &&
+	>1 &&
+	git add 1 &&
+	echo "$GIT_AUTHOR_NAME <$GIT_AUTHOR_EMAIL>" >expect &&
+	git stash &&
+	git show -s --format="%an <%ae>" refs/stash >actual &&
+	test_cmp expect actual &&
+	>2 &&
+	git add 2 &&
+	test_config user.useconfigonly true &&
+	test_config stash.usebuiltin true &&
+	(
+		sane_unset GIT_AUTHOR_NAME &&
+		sane_unset GIT_AUTHOR_EMAIL &&
+		sane_unset GIT_COMMITTER_NAME &&
+		sane_unset GIT_COMMITTER_EMAIL &&
+		test_unconfig user.email &&
+		test_unconfig user.name &&
+		test_must_fail git commit -m "should fail" &&
+		echo "git stash <git@stash>" >expect &&
+		>2 &&
+		git stash &&
+		git show -s --format="%an <%ae>" refs/stash >actual &&
+		test_cmp expect actual
+	)
+'
+
+test_expect_success 'stash --keep-index with file deleted in index does not resurrect it on disk' '
+	test_commit to-remove to-remove &&
+	git rm to-remove &&
+	git stash --keep-index &&
+	test_path_is_missing to-remove
+'
+
+test_expect_success 'stash apply should succeed with unmodified file' '
+	echo base >file &&
+	git add file &&
+	git commit -m base &&
+
+	# now stash a modification
+	echo modified >file &&
+	git stash &&
+
+	# make the file stat dirty
+	cp file other &&
+	mv other file &&
+
+	git stash apply
+'
+
+test_expect_success 'stash handles skip-worktree entries nicely' '
+	test_commit A &&
+	echo changed >A.t &&
+	git add A.t &&
+	git update-index --skip-worktree A.t &&
+	rm A.t &&
+	git stash &&
+
+	git rev-parse --verify refs/stash:A.t
+'
+
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t3904-stash-patch.sh 1.2.3+git2.25.1-1/git/t/t3904-stash-patch.sh
--- 1.2.1+git2.18.0-1/git/t/t3904-stash-patch.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t3904-stash-patch.sh	2020-02-17 04:47:35.000000000 +0000
@@ -29,14 +29,14 @@ test_expect_success 'setup' '
 test_expect_success 'saying "n" does nothing' '
 	set_state HEAD HEADfile_work HEADfile_index &&
 	set_state dir/foo work index &&
-	(echo n; echo n; echo n) | test_must_fail git stash save -p &&
+	test_write_lines n n n | test_must_fail git stash save -p &&
 	verify_state HEAD HEADfile_work HEADfile_index &&
 	verify_saved_state bar &&
 	verify_state dir/foo work index
 '
 
 test_expect_success 'git stash -p' '
-	(echo y; echo n; echo y) | git stash save -p &&
+	test_write_lines y n y | git stash save -p &&
 	verify_state HEAD committed HEADfile_index &&
 	verify_saved_state bar &&
 	verify_state dir/foo head index &&
@@ -51,7 +51,7 @@ test_expect_success 'git stash -p --no-k
 	set_state HEAD HEADfile_work HEADfile_index &&
 	set_state bar bar_work bar_index &&
 	set_state dir/foo work index &&
-	(echo y; echo n; echo y) | git stash save -p --no-keep-index &&
+	test_write_lines y n y | git stash save -p --no-keep-index &&
 	verify_state HEAD committed committed &&
 	verify_state bar bar_work dummy &&
 	verify_state dir/foo head head &&
@@ -66,7 +66,7 @@ test_expect_success 'git stash --no-keep
 	set_state HEAD HEADfile_work HEADfile_index &&
 	set_state bar bar_work bar_index &&
 	set_state dir/foo work index &&
-	(echo y; echo n; echo y) | git stash save --no-keep-index -p &&
+	test_write_lines y n y | git stash save --no-keep-index -p &&
 	verify_state HEAD committed committed &&
 	verify_state dir/foo head head &&
 	verify_state bar bar_work dummy &&
diff -pruN 1.2.1+git2.18.0-1/git/t/t3905-stash-include-untracked.sh 1.2.3+git2.25.1-1/git/t/t3905-stash-include-untracked.sh
--- 1.2.1+git2.18.0-1/git/t/t3905-stash-include-untracked.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t3905-stash-include-untracked.sh	2020-02-17 04:47:35.000000000 +0000
@@ -142,7 +142,7 @@ test_expect_success 'stash save --includ
 	rm -f file &&
 	git stash save --include-untracked &&
 	echo 1 > expect &&
-	test_cmp file expect
+	test_cmp expect file
 '
 
 rm -f expect
@@ -277,10 +277,16 @@ test_expect_success 'stash -u -- <ignore
 	test_path_is_file ignored.d/bar
 '
 
-test_expect_success 'stash -u -- <non-existant> shows no changes when there are none' '
-	git stash push -u -- non-existant >actual &&
+test_expect_success 'stash -u -- <non-existent> shows no changes when there are none' '
+	git stash push -u -- non-existent >actual &&
 	echo "No local changes to save" >expect &&
 	test_i18ncmp expect actual
 '
 
+test_expect_success 'stash -u with globs' '
+	>untracked.txt &&
+	git stash -u -- ":(glob)**/*.txt" &&
+	test_path_is_missing untracked.txt
+'
+
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t3906-stash-submodule.sh 1.2.3+git2.25.1-1/git/t/t3906-stash-submodule.sh
--- 1.2.1+git2.18.0-1/git/t/t3906-stash-submodule.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t3906-stash-submodule.sh	2020-02-17 04:47:35.000000000 +0000
@@ -1,6 +1,6 @@
 #!/bin/sh
 
-test_description='stash apply can handle submodules'
+test_description='stash can handle submodules'
 
 . ./test-lib.sh
 . "$TEST_DIRECTORY"/lib-submodule-update.sh
@@ -21,4 +21,44 @@ KNOWN_FAILURE_CHERRY_PICK_SEES_EMPTY_COM
 KNOWN_FAILURE_NOFF_MERGE_DOESNT_CREATE_EMPTY_SUBMODULE_DIR=1
 test_submodule_switch "git_stash"
 
+setup_basic () {
+	test_when_finished "rm -rf main sub" &&
+	git init sub &&
+	(
+		cd sub &&
+		test_commit sub_file
+	) &&
+	git init main &&
+	(
+		cd main &&
+		git submodule add ../sub &&
+		test_commit main_file
+	)
+}
+
+test_expect_success 'stash push with submodule.recurse=true preserves dirty submodule worktree' '
+	setup_basic &&
+	(
+		cd main &&
+		git config submodule.recurse true &&
+		echo "x" >main_file.t &&
+		echo "y" >sub/sub_file.t &&
+		git stash push &&
+		test_must_fail git -C sub diff --quiet
+	)
+'
+
+test_expect_success 'stash push and pop with submodule.recurse=true preserves dirty submodule worktree' '
+	setup_basic &&
+	(
+		cd main &&
+		git config submodule.recurse true &&
+		echo "x" >main_file.t &&
+		echo "y" >sub/sub_file.t &&
+		git stash push &&
+		git stash pop &&
+		test_must_fail git -C sub diff --quiet
+	)
+'
+
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t3907-stash-show-config.sh 1.2.3+git2.25.1-1/git/t/t3907-stash-show-config.sh
--- 1.2.1+git2.18.0-1/git/t/t3907-stash-show-config.sh	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t3907-stash-show-config.sh	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,83 @@
+#!/bin/sh
+
+test_description='Test git stash show configuration.'
+
+. ./test-lib.sh
+
+test_expect_success 'setup' '
+	test_commit file
+'
+
+# takes three parameters:
+# 1. the stash.showStat value (or "<unset>")
+# 2. the stash.showPatch value (or "<unset>")
+# 3. the diff options of the expected output (or nothing for no output)
+test_stat_and_patch () {
+	if test "<unset>" = "$1"
+	then
+		test_unconfig stash.showStat
+	else
+		test_config stash.showStat "$1"
+	fi &&
+
+	if test "<unset>" = "$2"
+	then
+		test_unconfig stash.showPatch
+	else
+		test_config stash.showPatch "$2"
+	fi &&
+
+	shift 2 &&
+	echo 2 >file.t &&
+	if test $# != 0
+	then
+		git diff "$@" >expect
+	fi &&
+	git stash &&
+	git stash show >actual &&
+
+	if test $# = 0
+	then
+		test_must_be_empty actual
+	else
+		test_cmp expect actual
+	fi
+}
+
+test_expect_success 'showStat unset showPatch unset' '
+	test_stat_and_patch "<unset>" "<unset>" --stat
+'
+
+test_expect_success 'showStat unset showPatch false' '
+	test_stat_and_patch "<unset>" false --stat
+'
+
+test_expect_success 'showStat unset showPatch true' '
+	test_stat_and_patch "<unset>" true --stat -p
+'
+
+test_expect_success 'showStat false showPatch unset' '
+	test_stat_and_patch false "<unset>"
+'
+
+test_expect_success 'showStat false showPatch false' '
+	test_stat_and_patch false false
+'
+
+test_expect_success 'showStat false showPatch true' '
+	test_stat_and_patch false true -p
+'
+
+test_expect_success 'showStat true showPatch unset' '
+	test_stat_and_patch true "<unset>" --stat
+'
+
+test_expect_success 'showStat true showPatch false' '
+	test_stat_and_patch true false --stat
+'
+
+test_expect_success 'showStat true showPatch true' '
+	test_stat_and_patch true true --stat -p
+'
+
+test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t3908-stash-in-worktree.sh 1.2.3+git2.25.1-1/git/t/t3908-stash-in-worktree.sh
--- 1.2.1+git2.18.0-1/git/t/t3908-stash-in-worktree.sh	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t3908-stash-in-worktree.sh	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,27 @@
+#!/bin/sh
+#
+# Copyright (c) 2019 Johannes E Schindelin
+#
+
+test_description='Test git stash in a worktree'
+
+. ./test-lib.sh
+
+test_expect_success 'setup' '
+	test_commit initial &&
+	git worktree add wt &&
+	test_commit -C wt in-worktree
+'
+
+test_expect_success 'apply in subdirectory' '
+	mkdir wt/subdir &&
+	(
+		cd wt/subdir &&
+		echo modified >../initial.t &&
+		git stash &&
+		git stash apply >out
+	) &&
+	grep "\.\.\/initial\.t" wt/subdir/out
+'
+
+test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t3910-mac-os-precompose.sh 1.2.3+git2.25.1-1/git/t/t3910-mac-os-precompose.sh
--- 1.2.1+git2.18.0-1/git/t/t3910-mac-os-precompose.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t3910-mac-os-precompose.sh	2020-02-17 04:47:35.000000000 +0000
@@ -187,9 +187,8 @@ test_expect_failure 'handle existing dec
 	echo content >"verbatim.$Adiarnfd" &&
 	git -c core.precomposeunicode=false add "verbatim.$Adiarnfd" &&
 	git commit -m "existing decomposed file" &&
-	>expect &&
 	git ls-files --exclude-standard -o "verbatim*" >untracked &&
-	test_cmp expect untracked
+	test_must_be_empty untracked
 '
 
 # Test if the global core.precomposeunicode stops autosensing
diff -pruN 1.2.1+git2.18.0-1/git/t/t4000-diff-format.sh 1.2.3+git2.25.1-1/git/t/t4000-diff-format.sh
--- 1.2.1+git2.18.0-1/git/t/t4000-diff-format.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t4000-diff-format.sh	2020-02-17 04:47:35.000000000 +0000
@@ -78,7 +78,7 @@ test_expect_success 'git diff-files --no
 
 test_expect_success 'git diff-files --no-patch --patch-with-raw shows the patch and raw data' '
 	git diff-files --no-patch --patch-with-raw >actual &&
-	grep -q "^:100644 100755 .* 0000000000000000000000000000000000000000 M	path0\$" actual &&
+	grep -q "^:100644 100755 .* $ZERO_OID M	path0\$" actual &&
 	tail -n +4 actual >actual-patch &&
 	compare_diff_patch expected actual-patch
 '
diff -pruN 1.2.1+git2.18.0-1/git/t/t4001-diff-rename.sh 1.2.3+git2.25.1-1/git/t/t4001-diff-rename.sh
--- 1.2.1+git2.18.0-1/git/t/t4001-diff-rename.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t4001-diff-rename.sh	2020-02-17 04:47:35.000000000 +0000
@@ -180,7 +180,7 @@ test_expect_success 'setup for many rena
 	git add "path??" &&
 	test_tick &&
 	git commit -m "hundred" &&
-	(cat path1; echo new) >new-path &&
+	(cat path1 && echo new) >new-path &&
 	echo old >>path1 &&
 	git add new-path path1 &&
 	git diff -l 4 -C -C --cached --name-status >actual 2>actual.err &&
diff -pruN 1.2.1+git2.18.0-1/git/t/t4002-diff-basic.sh 1.2.3+git2.25.1-1/git/t/t4002-diff-basic.sh
--- 1.2.1+git2.18.0-1/git/t/t4002-diff-basic.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t4002-diff-basic.sh	2020-02-17 04:47:35.000000000 +0000
@@ -7,123 +7,272 @@ test_description='Test diff raw-output.
 
 '
 . ./test-lib.sh
+
 . "$TEST_DIRECTORY"/lib-read-tree-m-3way.sh
 
-cat >.test-plain-OA <<\EOF
-:000000 100644 0000000000000000000000000000000000000000 ccba72ad3888a3520b39efcf780b9ee64167535d A	AA
-:000000 100644 0000000000000000000000000000000000000000 7e426fb079479fd67f6d81f984e4ec649a44bc25 A	AN
-:100644 000000 bcc68ef997017466d5c9094bcf7692295f588c9a 0000000000000000000000000000000000000000 D	DD
-:000000 040000 0000000000000000000000000000000000000000 6d50f65d3bdab91c63444294d38f08aeff328e42 A	DF
-:100644 000000 141c1f1642328e4bc46a7d801a71da392e66791e 0000000000000000000000000000000000000000 D	DM
-:100644 000000 35abde1506ddf806572ff4d407bd06885d0f8ee9 0000000000000000000000000000000000000000 D	DN
-:000000 100644 0000000000000000000000000000000000000000 1d41122ebdd7a640f29d3c9cc4f9d70094374762 A	LL
-:100644 100644 03f24c8c4700babccfd28b654e7e8eac402ad6cd 103d9f89b50b9aad03054b579be5e7aa665f2d57 M	MD
-:100644 100644 b258508afb7ceb449981bd9d63d2d3e971bf8d34 b431b272d829ff3aa4d1a5085f4394ab4d3305b6 M	MM
-:100644 100644 bd084b0c27c7b6cc34f11d6d0509a29be3caf970 a716d58de4a570e0038f5c307bd8db34daea021f M	MN
-:100644 100644 40c959f984c8b89a2b02520d17f00d717f024397 2ac547ae9614a00d1b28275de608131f7a0e259f M	SS
-:100644 100644 4ac13458899ab908ef3b1128fa378daefc88d356 4c86f9a85fbc5e6804ee2e17a797538fbe785bca M	TT
-:040000 040000 7d670fdcdb9929f6c7dac196ff78689cd1c566a1 5e5f22072bb39f6e12cf663a57cb634c76eefb49 M	Z
-EOF
-
-cat >.test-recursive-OA <<\EOF
-:000000 100644 0000000000000000000000000000000000000000 ccba72ad3888a3520b39efcf780b9ee64167535d A	AA
-:000000 100644 0000000000000000000000000000000000000000 7e426fb079479fd67f6d81f984e4ec649a44bc25 A	AN
-:100644 000000 bcc68ef997017466d5c9094bcf7692295f588c9a 0000000000000000000000000000000000000000 D	DD
-:000000 100644 0000000000000000000000000000000000000000 68a6d8b91da11045cf4aa3a5ab9f2a781c701249 A	DF/DF
-:100644 000000 141c1f1642328e4bc46a7d801a71da392e66791e 0000000000000000000000000000000000000000 D	DM
-:100644 000000 35abde1506ddf806572ff4d407bd06885d0f8ee9 0000000000000000000000000000000000000000 D	DN
-:000000 100644 0000000000000000000000000000000000000000 1d41122ebdd7a640f29d3c9cc4f9d70094374762 A	LL
-:100644 100644 03f24c8c4700babccfd28b654e7e8eac402ad6cd 103d9f89b50b9aad03054b579be5e7aa665f2d57 M	MD
-:100644 100644 b258508afb7ceb449981bd9d63d2d3e971bf8d34 b431b272d829ff3aa4d1a5085f4394ab4d3305b6 M	MM
-:100644 100644 bd084b0c27c7b6cc34f11d6d0509a29be3caf970 a716d58de4a570e0038f5c307bd8db34daea021f M	MN
-:100644 100644 40c959f984c8b89a2b02520d17f00d717f024397 2ac547ae9614a00d1b28275de608131f7a0e259f M	SS
-:100644 100644 4ac13458899ab908ef3b1128fa378daefc88d356 4c86f9a85fbc5e6804ee2e17a797538fbe785bca M	TT
-:000000 100644 0000000000000000000000000000000000000000 8acb8e9750e3f644bf323fcf3d338849db106c77 A	Z/AA
-:000000 100644 0000000000000000000000000000000000000000 087494262084cefee7ed484d20c8dc0580791272 A	Z/AN
-:100644 000000 879007efae624d2b1307214b24a956f0a8d686a8 0000000000000000000000000000000000000000 D	Z/DD
-:100644 000000 9b541b2275c06e3a7b13f28badf5294e2ae63df4 0000000000000000000000000000000000000000 D	Z/DM
-:100644 000000 beb5d38c55283d280685ea21a0e50cfcc0ca064a 0000000000000000000000000000000000000000 D	Z/DN
-:100644 100644 d41fda41b7ec4de46b43cb7ea42a45001ae393d5 a79ac3be9377639e1c7d1edf1ae1b3a5f0ccd8a9 M	Z/MD
-:100644 100644 4ca22bae2527d3d9e1676498a0fba3b355bd1278 61422ba9c2c873416061a88cd40a59a35b576474 M	Z/MM
-:100644 100644 b16d7b25b869f2beb124efa53467d8a1550ad694 a5c544c21cfcb07eb80a4d89a5b7d1570002edfd M	Z/MN
-EOF
-cat >.test-plain-OB <<\EOF
-:000000 100644 0000000000000000000000000000000000000000 6aa2b5335b16431a0ef71e5c0a28be69183cf6a2 A	AA
-:100644 000000 bcc68ef997017466d5c9094bcf7692295f588c9a 0000000000000000000000000000000000000000 D	DD
-:000000 100644 0000000000000000000000000000000000000000 71420ab81e254145d26d6fc0cddee64c1acd4787 A	DF
-:100644 100644 141c1f1642328e4bc46a7d801a71da392e66791e 3c4d8de5fbad08572bab8e10eef8dbb264cf0231 M	DM
-:000000 100644 0000000000000000000000000000000000000000 1d41122ebdd7a640f29d3c9cc4f9d70094374762 A	LL
-:100644 000000 03f24c8c4700babccfd28b654e7e8eac402ad6cd 0000000000000000000000000000000000000000 D	MD
-:100644 100644 b258508afb7ceb449981bd9d63d2d3e971bf8d34 19989d4559aae417fedee240ccf2ba315ea4dc2b M	MM
-:000000 100644 0000000000000000000000000000000000000000 15885881ea69115351c09b38371f0348a3fb8c67 A	NA
-:100644 000000 a4e179e4291e5536a5e1c82e091052772d2c5a93 0000000000000000000000000000000000000000 D	ND
-:100644 100644 c8f25781e8f1792e3e40b74225e20553041b5226 cdb9a8c3da571502ac30225e9c17beccb8387983 M	NM
-:100644 100644 40c959f984c8b89a2b02520d17f00d717f024397 2ac547ae9614a00d1b28275de608131f7a0e259f M	SS
-:100644 100644 4ac13458899ab908ef3b1128fa378daefc88d356 c4e4a12231b9fa79a0053cb6077fcb21bb5b135a M	TT
-:040000 040000 7d670fdcdb9929f6c7dac196ff78689cd1c566a1 1ba523955d5160681af65cb776411f574c1e8155 M	Z
-EOF
-cat >.test-recursive-OB <<\EOF
-:000000 100644 0000000000000000000000000000000000000000 6aa2b5335b16431a0ef71e5c0a28be69183cf6a2 A	AA
-:100644 000000 bcc68ef997017466d5c9094bcf7692295f588c9a 0000000000000000000000000000000000000000 D	DD
-:000000 100644 0000000000000000000000000000000000000000 71420ab81e254145d26d6fc0cddee64c1acd4787 A	DF
-:100644 100644 141c1f1642328e4bc46a7d801a71da392e66791e 3c4d8de5fbad08572bab8e10eef8dbb264cf0231 M	DM
-:000000 100644 0000000000000000000000000000000000000000 1d41122ebdd7a640f29d3c9cc4f9d70094374762 A	LL
-:100644 000000 03f24c8c4700babccfd28b654e7e8eac402ad6cd 0000000000000000000000000000000000000000 D	MD
-:100644 100644 b258508afb7ceb449981bd9d63d2d3e971bf8d34 19989d4559aae417fedee240ccf2ba315ea4dc2b M	MM
-:000000 100644 0000000000000000000000000000000000000000 15885881ea69115351c09b38371f0348a3fb8c67 A	NA
-:100644 000000 a4e179e4291e5536a5e1c82e091052772d2c5a93 0000000000000000000000000000000000000000 D	ND
-:100644 100644 c8f25781e8f1792e3e40b74225e20553041b5226 cdb9a8c3da571502ac30225e9c17beccb8387983 M	NM
-:100644 100644 40c959f984c8b89a2b02520d17f00d717f024397 2ac547ae9614a00d1b28275de608131f7a0e259f M	SS
-:100644 100644 4ac13458899ab908ef3b1128fa378daefc88d356 c4e4a12231b9fa79a0053cb6077fcb21bb5b135a M	TT
-:000000 100644 0000000000000000000000000000000000000000 6c0b99286d0bce551ac4a7b3dff8b706edff3715 A	Z/AA
-:100644 000000 879007efae624d2b1307214b24a956f0a8d686a8 0000000000000000000000000000000000000000 D	Z/DD
-:100644 100644 9b541b2275c06e3a7b13f28badf5294e2ae63df4 d77371d15817fcaa57eeec27f770c505ba974ec1 M	Z/DM
-:100644 000000 d41fda41b7ec4de46b43cb7ea42a45001ae393d5 0000000000000000000000000000000000000000 D	Z/MD
-:100644 100644 4ca22bae2527d3d9e1676498a0fba3b355bd1278 697aad7715a1e7306ca76290a3dd4208fbaeddfa M	Z/MM
-:000000 100644 0000000000000000000000000000000000000000 d12979c22fff69c59ca9409e7a8fe3ee25eaee80 A	Z/NA
-:100644 000000 a18393c636b98e9bd7296b8b437ea4992b72440c 0000000000000000000000000000000000000000 D	Z/ND
-:100644 100644 3fdbe17fd013303a2e981e1ca1c6cd6e72789087 7e09d6a3a14bd630913e8c75693cea32157b606d M	Z/NM
-EOF
-cat >.test-plain-AB <<\EOF
-:100644 100644 ccba72ad3888a3520b39efcf780b9ee64167535d 6aa2b5335b16431a0ef71e5c0a28be69183cf6a2 M	AA
-:100644 000000 7e426fb079479fd67f6d81f984e4ec649a44bc25 0000000000000000000000000000000000000000 D	AN
-:000000 100644 0000000000000000000000000000000000000000 71420ab81e254145d26d6fc0cddee64c1acd4787 A	DF
-:040000 000000 6d50f65d3bdab91c63444294d38f08aeff328e42 0000000000000000000000000000000000000000 D	DF
-:000000 100644 0000000000000000000000000000000000000000 3c4d8de5fbad08572bab8e10eef8dbb264cf0231 A	DM
-:000000 100644 0000000000000000000000000000000000000000 35abde1506ddf806572ff4d407bd06885d0f8ee9 A	DN
-:100644 000000 103d9f89b50b9aad03054b579be5e7aa665f2d57 0000000000000000000000000000000000000000 D	MD
-:100644 100644 b431b272d829ff3aa4d1a5085f4394ab4d3305b6 19989d4559aae417fedee240ccf2ba315ea4dc2b M	MM
-:100644 100644 a716d58de4a570e0038f5c307bd8db34daea021f bd084b0c27c7b6cc34f11d6d0509a29be3caf970 M	MN
-:000000 100644 0000000000000000000000000000000000000000 15885881ea69115351c09b38371f0348a3fb8c67 A	NA
-:100644 000000 a4e179e4291e5536a5e1c82e091052772d2c5a93 0000000000000000000000000000000000000000 D	ND
-:100644 100644 c8f25781e8f1792e3e40b74225e20553041b5226 cdb9a8c3da571502ac30225e9c17beccb8387983 M	NM
-:100644 100644 4c86f9a85fbc5e6804ee2e17a797538fbe785bca c4e4a12231b9fa79a0053cb6077fcb21bb5b135a M	TT
-:040000 040000 5e5f22072bb39f6e12cf663a57cb634c76eefb49 1ba523955d5160681af65cb776411f574c1e8155 M	Z
-EOF
-cat >.test-recursive-AB <<\EOF
-:100644 100644 ccba72ad3888a3520b39efcf780b9ee64167535d 6aa2b5335b16431a0ef71e5c0a28be69183cf6a2 M	AA
-:100644 000000 7e426fb079479fd67f6d81f984e4ec649a44bc25 0000000000000000000000000000000000000000 D	AN
-:000000 100644 0000000000000000000000000000000000000000 71420ab81e254145d26d6fc0cddee64c1acd4787 A	DF
-:100644 000000 68a6d8b91da11045cf4aa3a5ab9f2a781c701249 0000000000000000000000000000000000000000 D	DF/DF
-:000000 100644 0000000000000000000000000000000000000000 3c4d8de5fbad08572bab8e10eef8dbb264cf0231 A	DM
-:000000 100644 0000000000000000000000000000000000000000 35abde1506ddf806572ff4d407bd06885d0f8ee9 A	DN
-:100644 000000 103d9f89b50b9aad03054b579be5e7aa665f2d57 0000000000000000000000000000000000000000 D	MD
-:100644 100644 b431b272d829ff3aa4d1a5085f4394ab4d3305b6 19989d4559aae417fedee240ccf2ba315ea4dc2b M	MM
-:100644 100644 a716d58de4a570e0038f5c307bd8db34daea021f bd084b0c27c7b6cc34f11d6d0509a29be3caf970 M	MN
-:000000 100644 0000000000000000000000000000000000000000 15885881ea69115351c09b38371f0348a3fb8c67 A	NA
-:100644 000000 a4e179e4291e5536a5e1c82e091052772d2c5a93 0000000000000000000000000000000000000000 D	ND
-:100644 100644 c8f25781e8f1792e3e40b74225e20553041b5226 cdb9a8c3da571502ac30225e9c17beccb8387983 M	NM
-:100644 100644 4c86f9a85fbc5e6804ee2e17a797538fbe785bca c4e4a12231b9fa79a0053cb6077fcb21bb5b135a M	TT
-:100644 100644 8acb8e9750e3f644bf323fcf3d338849db106c77 6c0b99286d0bce551ac4a7b3dff8b706edff3715 M	Z/AA
-:100644 000000 087494262084cefee7ed484d20c8dc0580791272 0000000000000000000000000000000000000000 D	Z/AN
-:000000 100644 0000000000000000000000000000000000000000 d77371d15817fcaa57eeec27f770c505ba974ec1 A	Z/DM
-:000000 100644 0000000000000000000000000000000000000000 beb5d38c55283d280685ea21a0e50cfcc0ca064a A	Z/DN
-:100644 000000 a79ac3be9377639e1c7d1edf1ae1b3a5f0ccd8a9 0000000000000000000000000000000000000000 D	Z/MD
-:100644 100644 61422ba9c2c873416061a88cd40a59a35b576474 697aad7715a1e7306ca76290a3dd4208fbaeddfa M	Z/MM
-:100644 100644 a5c544c21cfcb07eb80a4d89a5b7d1570002edfd b16d7b25b869f2beb124efa53467d8a1550ad694 M	Z/MN
-:000000 100644 0000000000000000000000000000000000000000 d12979c22fff69c59ca9409e7a8fe3ee25eaee80 A	Z/NA
-:100644 000000 a18393c636b98e9bd7296b8b437ea4992b72440c 0000000000000000000000000000000000000000 D	Z/ND
-:100644 100644 3fdbe17fd013303a2e981e1ca1c6cd6e72789087 7e09d6a3a14bd630913e8c75693cea32157b606d M	Z/NM
+test_oid_init
+
+test_oid_cache <<\EOF
+aa_1 sha1:ccba72ad3888a3520b39efcf780b9ee64167535d
+aa_1 sha256:9febfbf18197819b2735c45291f138525d2476d59470f98239647544586ba403
+
+aa_2 sha1:6aa2b5335b16431a0ef71e5c0a28be69183cf6a2
+aa_2 sha256:6eaa3437de83f145a4aaa6ba355303075ade547b128ec6a2cd00a81ff7ce7a56
+
+an_1 sha1:7e426fb079479fd67f6d81f984e4ec649a44bc25
+an_1 sha256:8f92a0bec99e399a38e3bd0e1bf19fbf121e0160efb29b857df79d439f1c4536
+
+dd_1 sha1:bcc68ef997017466d5c9094bcf7692295f588c9a
+dd_1 sha256:07e17428b00639b85485d2b01083d219e2f3e3ba8579e9ca44e9cc8dd554d952
+
+df_1 sha1:6d50f65d3bdab91c63444294d38f08aeff328e42
+df_1 sha256:e367cecc27e9bf5451b1c65828cb21938d36a5f8e39c1b03ad6509cc36bb8e9d
+
+df_2 sha1:71420ab81e254145d26d6fc0cddee64c1acd4787
+df_2 sha256:0f0a86d10347ff6921d03a3c954679f3f1d14fa3d5cd82f57b32c09755f3a47d
+
+dfd1 sha1:68a6d8b91da11045cf4aa3a5ab9f2a781c701249
+dfd1 sha256:f3bd3265b02b6978ce86490d8ad026c573639c974b3de1d9faf30d8d5a77d3d5
+
+dm_1 sha1:141c1f1642328e4bc46a7d801a71da392e66791e
+dm_1 sha256:c89f8656e7b94e21ee5fbaf0e2149bbf783c51edbe2ce110349cac13059ee7ed
+
+dm_2 sha1:3c4d8de5fbad08572bab8e10eef8dbb264cf0231
+dm_2 sha256:83a572e37e0c94086294dae2cecc43d9131afd6f6c906e495c78972230b54988
+
+dn_1 sha1:35abde1506ddf806572ff4d407bd06885d0f8ee9
+dn_1 sha256:775d5852582070e620be63327bfa515fab8f71c7ac3e4f0c3cd6267b4377ba28
+
+ll_2 sha1:1d41122ebdd7a640f29d3c9cc4f9d70094374762
+ll_2 sha256:7917b4948a883cfed0a77d3d5a625dc8577d6ddcc3c6c3bbc56c4d4226a2246d
+
+md_1 sha1:03f24c8c4700babccfd28b654e7e8eac402ad6cd
+md_1 sha256:fc9f30369b978595ad685ba11ca9a17de0af16d79cd4b629975f4f1590033902
+
+md_2 sha1:103d9f89b50b9aad03054b579be5e7aa665f2d57
+md_2 sha256:fc78ec75275628762fe520479a6b2398dec295ce7aabcb1d15e5963c7b4e9317
+
+mm_1 sha1:b258508afb7ceb449981bd9d63d2d3e971bf8d34
+mm_1 sha256:a4b7847d228e900e3000285e240c20fd96f9dd41ce1445305f6eada126d4a04a
+
+mm_2 sha1:b431b272d829ff3aa4d1a5085f4394ab4d3305b6
+mm_2 sha256:3f8b83ea36aacf689bcf1a1290a9a8ed341564d32682ea6f76fea9a979186782
+
+mm_3 sha1:19989d4559aae417fedee240ccf2ba315ea4dc2b
+mm_3 sha256:71b3bfc5747ac033fff9ea0ab39ee453a3af2969890e75d6ef547b87544e2681
+
+mn_1 sha1:bd084b0c27c7b6cc34f11d6d0509a29be3caf970
+mn_1 sha256:47a67450583d7a329eb01a7c4ba644945af72c0ed2c7c95eb5a00d6e46d4d483
+
+mn_2 sha1:a716d58de4a570e0038f5c307bd8db34daea021f
+mn_2 sha256:f95104c1ebe27acb84bac25a7be98c71f6b8d3054b21f357a5be0c524ad97e08
+
+nm_1 sha1:c8f25781e8f1792e3e40b74225e20553041b5226
+nm_1 sha256:09baddc7afaa62e62e152c23c9c3ab94bf15a3894031e227e9be7fe68e1f4e49
+
+nm_2 sha1:cdb9a8c3da571502ac30225e9c17beccb8387983
+nm_2 sha256:58b5227956ac2d2a08d0efa513c0ae37430948b16791ea3869a1308dbf05536d
+
+na_1 sha1:15885881ea69115351c09b38371f0348a3fb8c67
+na_1 sha256:18e4fdd1670cd7968ee23d35bfd29e5418d56fb190c840094c1c57ceee0aad8f
+
+nd_1 sha1:a4e179e4291e5536a5e1c82e091052772d2c5a93
+nd_1 sha256:07dac9b01d00956ea0c65bd993d7de4864aeef2ed3cbb1255d9f1d949fcd6df6
+
+ss_1 sha1:40c959f984c8b89a2b02520d17f00d717f024397
+ss_1 sha256:50fc1b5df74d9910db2f9270993484235f15b69b75b01bcfb53e059289d14af9
+
+ss_2 sha1:2ac547ae9614a00d1b28275de608131f7a0e259f
+ss_2 sha256:a90f02e6044f1497d13db587d22ab12f90150a7d1e084afcf96065fab35ae2bc
+
+tt_1 sha1:4ac13458899ab908ef3b1128fa378daefc88d356
+tt_1 sha256:c53113c7dd5060e86b5b251428bd058f6726f66273c6a24bff1c61a04f498dd3
+
+tt_2 sha1:4c86f9a85fbc5e6804ee2e17a797538fbe785bca
+tt_2 sha256:0775f2a296129a7cf2862b46bc0e88c14d593f2773a3e3fb1c5193db6f5a7e77
+
+tt_3 sha1:c4e4a12231b9fa79a0053cb6077fcb21bb5b135a
+tt_3 sha256:47860f93cdd211f96443e0560f21c57ab6c2f4b0ac27ff03651a352e53fe8484
+
+z__1 sha1:7d670fdcdb9929f6c7dac196ff78689cd1c566a1
+z__1 sha256:44d0f37aff5e51cfcfdd1134c93a6419bcca7b9964f792ffcd5f9b4fcba1ee63
+
+z__2 sha1:5e5f22072bb39f6e12cf663a57cb634c76eefb49
+z__2 sha256:d29de162113190fed104eb5f010820cef4e315f89b9326e8497f7219fb737894
+
+z__3 sha1:1ba523955d5160681af65cb776411f574c1e8155
+z__3 sha256:07422d772b07794ab4369a5648e617719f89c2d2212cbeab05d97214b6471636
+
+zaa1 sha1:8acb8e9750e3f644bf323fcf3d338849db106c77
+zaa1 sha256:e79b029282c8abec2d9f3f7faceaf2a1405e02d1f368e66450ae66cf5b68d1f4
+
+zaa2 sha1:6c0b99286d0bce551ac4a7b3dff8b706edff3715
+zaa2 sha256:c82bd78c3e69ea1796e6b1a7a3ba45bb106c50e819296475b862123d3f5cc5a0
+
+zan1 sha1:087494262084cefee7ed484d20c8dc0580791272
+zan1 sha256:4b159eb3804d05599023dd074f771d06d02870f4ab24a7165add8ac3d703b8d3
+
+zdd1 sha1:879007efae624d2b1307214b24a956f0a8d686a8
+zdd1 sha256:eecfdd4d8092dd0363fb6d4548b54c6afc8982c3ed9b34e393f1d6a921d8eaa3
+
+zdm1 sha1:9b541b2275c06e3a7b13f28badf5294e2ae63df4
+zdm1 sha256:ab136e88e19a843c4bf7713d2090d5a2186ba16a6a80dacc12eeddd256a8e556
+
+zdm2 sha1:d77371d15817fcaa57eeec27f770c505ba974ec1
+zdm2 sha256:1c1a5f57363f46a15d95ce8527b3c2c158d88d16853b4acbf81bd20fd2c89a46
+
+zdn1 sha1:beb5d38c55283d280685ea21a0e50cfcc0ca064a
+zdn1 sha256:0f0eca66183617b0aa5ad74b256540329f841470922ca6760263c996d825eb18
+
+zmd1 sha1:d41fda41b7ec4de46b43cb7ea42a45001ae393d5
+zmd1 sha256:1ed32d481852eddf31a0ce12652a0ad14bf5b7a842667b5dbb0b50f35bf1c80a
+
+zmd2 sha1:a79ac3be9377639e1c7d1edf1ae1b3a5f0ccd8a9
+zmd2 sha256:b238da211b404f8917df2d9c6f7030535e904b2186131007a3c292ec6902f933
+
+zmm1 sha1:4ca22bae2527d3d9e1676498a0fba3b355bd1278
+zmm1 sha256:072b1d85b5f34fabc99dfa46008c5418df68302d3e317430006f49b32d244226
+
+zmm2 sha1:61422ba9c2c873416061a88cd40a59a35b576474
+zmm2 sha256:81dd5d2b3c5cda16fef552256aed4e2ea0802a8450a08f308a92142112ff6dda
+
+zmm3 sha1:697aad7715a1e7306ca76290a3dd4208fbaeddfa
+zmm3 sha256:8b10fab49e9be3414aa5e9a93d0e46f9569053440138a7c19a5eb5536d8e95bf
+
+zmn1 sha1:b16d7b25b869f2beb124efa53467d8a1550ad694
+zmn1 sha256:609e4f75d1295e844c826feeba213acb0b6cfc609adfe8ff705b19e3829ae3e9
+
+zmn2 sha1:a5c544c21cfcb07eb80a4d89a5b7d1570002edfd
+zmn2 sha256:d6d03edf2dc1a3b267a8205de5f41a2ff4b03def8c7ae02052b543fb09d589fc
+
+zna1 sha1:d12979c22fff69c59ca9409e7a8fe3ee25eaee80
+zna1 sha256:b37b80e789e8ea32aa323f004628f02013f632124b0282c7fe00a127d3c64c3c
+
+znd1 sha1:a18393c636b98e9bd7296b8b437ea4992b72440c
+znd1 sha256:af92a22eee8c38410a0c9d2b5135a10aeb052cbc7cf675541ed9a67bfcaf7cf9
+
+znm1 sha1:3fdbe17fd013303a2e981e1ca1c6cd6e72789087
+znm1 sha256:f75aeaa0c11e76918e381c105f0752932c6150e941fec565d24fa31098a13dc1
+
+znm2 sha1:7e09d6a3a14bd630913e8c75693cea32157b606d
+znm2 sha256:938d73cfbaa1c902a84fb5b3afd9736aa0590367fb9bd59c6c4d072ce70fcd6d
+EOF
+
+cat >.test-plain-OA <<EOF
+:000000 100644 $(test_oid zero) $(test_oid aa_1) A	AA
+:000000 100644 $(test_oid zero) $(test_oid an_1) A	AN
+:100644 000000 $(test_oid dd_1) $(test_oid zero) D	DD
+:000000 040000 $(test_oid zero) $(test_oid df_1) A	DF
+:100644 000000 $(test_oid dm_1) $(test_oid zero) D	DM
+:100644 000000 $(test_oid dn_1) $(test_oid zero) D	DN
+:000000 100644 $(test_oid zero) $(test_oid ll_2) A	LL
+:100644 100644 $(test_oid md_1) $(test_oid md_2) M	MD
+:100644 100644 $(test_oid mm_1) $(test_oid mm_2) M	MM
+:100644 100644 $(test_oid mn_1) $(test_oid mn_2) M	MN
+:100644 100644 $(test_oid ss_1) $(test_oid ss_2) M	SS
+:100644 100644 $(test_oid tt_1) $(test_oid tt_2) M	TT
+:040000 040000 $(test_oid z__1) $(test_oid z__2) M	Z
+EOF
+
+cat >.test-recursive-OA <<EOF
+:000000 100644 $(test_oid zero) $(test_oid aa_1) A	AA
+:000000 100644 $(test_oid zero) $(test_oid an_1) A	AN
+:100644 000000 $(test_oid dd_1) $(test_oid zero) D	DD
+:000000 100644 $(test_oid zero) $(test_oid dfd1) A	DF/DF
+:100644 000000 $(test_oid dm_1) $(test_oid zero) D	DM
+:100644 000000 $(test_oid dn_1) $(test_oid zero) D	DN
+:000000 100644 $(test_oid zero) $(test_oid ll_2) A	LL
+:100644 100644 $(test_oid md_1) $(test_oid md_2) M	MD
+:100644 100644 $(test_oid mm_1) $(test_oid mm_2) M	MM
+:100644 100644 $(test_oid mn_1) $(test_oid mn_2) M	MN
+:100644 100644 $(test_oid ss_1) $(test_oid ss_2) M	SS
+:100644 100644 $(test_oid tt_1) $(test_oid tt_2) M	TT
+:000000 100644 $(test_oid zero) $(test_oid zaa1) A	Z/AA
+:000000 100644 $(test_oid zero) $(test_oid zan1) A	Z/AN
+:100644 000000 $(test_oid zdd1) $(test_oid zero) D	Z/DD
+:100644 000000 $(test_oid zdm1) $(test_oid zero) D	Z/DM
+:100644 000000 $(test_oid zdn1) $(test_oid zero) D	Z/DN
+:100644 100644 $(test_oid zmd1) $(test_oid zmd2) M	Z/MD
+:100644 100644 $(test_oid zmm1) $(test_oid zmm2) M	Z/MM
+:100644 100644 $(test_oid zmn1) $(test_oid zmn2) M	Z/MN
+EOF
+cat >.test-plain-OB <<EOF
+:000000 100644 $(test_oid zero) $(test_oid aa_2) A	AA
+:100644 000000 $(test_oid dd_1) $(test_oid zero) D	DD
+:000000 100644 $(test_oid zero) $(test_oid df_2) A	DF
+:100644 100644 $(test_oid dm_1) $(test_oid dm_2) M	DM
+:000000 100644 $(test_oid zero) $(test_oid ll_2) A	LL
+:100644 000000 $(test_oid md_1) $(test_oid zero) D	MD
+:100644 100644 $(test_oid mm_1) $(test_oid mm_3) M	MM
+:000000 100644 $(test_oid zero) $(test_oid na_1) A	NA
+:100644 000000 $(test_oid nd_1) $(test_oid zero) D	ND
+:100644 100644 $(test_oid nm_1) $(test_oid nm_2) M	NM
+:100644 100644 $(test_oid ss_1) $(test_oid ss_2) M	SS
+:100644 100644 $(test_oid tt_1) $(test_oid tt_3) M	TT
+:040000 040000 $(test_oid z__1) $(test_oid z__3) M	Z
+EOF
+cat >.test-recursive-OB <<EOF
+:000000 100644 $(test_oid zero) $(test_oid aa_2) A	AA
+:100644 000000 $(test_oid dd_1) $(test_oid zero) D	DD
+:000000 100644 $(test_oid zero) $(test_oid df_2) A	DF
+:100644 100644 $(test_oid dm_1) $(test_oid dm_2) M	DM
+:000000 100644 $(test_oid zero) $(test_oid ll_2) A	LL
+:100644 000000 $(test_oid md_1) $(test_oid zero) D	MD
+:100644 100644 $(test_oid mm_1) $(test_oid mm_3) M	MM
+:000000 100644 $(test_oid zero) $(test_oid na_1) A	NA
+:100644 000000 $(test_oid nd_1) $(test_oid zero) D	ND
+:100644 100644 $(test_oid nm_1) $(test_oid nm_2) M	NM
+:100644 100644 $(test_oid ss_1) $(test_oid ss_2) M	SS
+:100644 100644 $(test_oid tt_1) $(test_oid tt_3) M	TT
+:000000 100644 $(test_oid zero) $(test_oid zaa2) A	Z/AA
+:100644 000000 $(test_oid zdd1) $(test_oid zero) D	Z/DD
+:100644 100644 $(test_oid zdm1) $(test_oid zdm2) M	Z/DM
+:100644 000000 $(test_oid zmd1) $(test_oid zero) D	Z/MD
+:100644 100644 $(test_oid zmm1) $(test_oid zmm3) M	Z/MM
+:000000 100644 $(test_oid zero) $(test_oid zna1) A	Z/NA
+:100644 000000 $(test_oid znd1) $(test_oid zero) D	Z/ND
+:100644 100644 $(test_oid znm1) $(test_oid znm2) M	Z/NM
+EOF
+cat >.test-plain-AB <<EOF
+:100644 100644 $(test_oid aa_1) $(test_oid aa_2) M	AA
+:100644 000000 $(test_oid an_1) $(test_oid zero) D	AN
+:000000 100644 $(test_oid zero) $(test_oid df_2) A	DF
+:040000 000000 $(test_oid df_1) $(test_oid zero) D	DF
+:000000 100644 $(test_oid zero) $(test_oid dm_2) A	DM
+:000000 100644 $(test_oid zero) $(test_oid dn_1) A	DN
+:100644 000000 $(test_oid md_2) $(test_oid zero) D	MD
+:100644 100644 $(test_oid mm_2) $(test_oid mm_3) M	MM
+:100644 100644 $(test_oid mn_2) $(test_oid mn_1) M	MN
+:000000 100644 $(test_oid zero) $(test_oid na_1) A	NA
+:100644 000000 $(test_oid nd_1) $(test_oid zero) D	ND
+:100644 100644 $(test_oid nm_1) $(test_oid nm_2) M	NM
+:100644 100644 $(test_oid tt_2) $(test_oid tt_3) M	TT
+:040000 040000 $(test_oid z__2) $(test_oid z__3) M	Z
+EOF
+cat >.test-recursive-AB <<EOF
+:100644 100644 $(test_oid aa_1) $(test_oid aa_2) M	AA
+:100644 000000 $(test_oid an_1) $(test_oid zero) D	AN
+:000000 100644 $(test_oid zero) $(test_oid df_2) A	DF
+:100644 000000 $(test_oid dfd1) $(test_oid zero) D	DF/DF
+:000000 100644 $(test_oid zero) $(test_oid dm_2) A	DM
+:000000 100644 $(test_oid zero) $(test_oid dn_1) A	DN
+:100644 000000 $(test_oid md_2) $(test_oid zero) D	MD
+:100644 100644 $(test_oid mm_2) $(test_oid mm_3) M	MM
+:100644 100644 $(test_oid mn_2) $(test_oid mn_1) M	MN
+:000000 100644 $(test_oid zero) $(test_oid na_1) A	NA
+:100644 000000 $(test_oid nd_1) $(test_oid zero) D	ND
+:100644 100644 $(test_oid nm_1) $(test_oid nm_2) M	NM
+:100644 100644 $(test_oid tt_2) $(test_oid tt_3) M	TT
+:100644 100644 $(test_oid zaa1) $(test_oid zaa2) M	Z/AA
+:100644 000000 $(test_oid zan1) $(test_oid zero) D	Z/AN
+:000000 100644 $(test_oid zero) $(test_oid zdm2) A	Z/DM
+:000000 100644 $(test_oid zero) $(test_oid zdn1) A	Z/DN
+:100644 000000 $(test_oid zmd2) $(test_oid zero) D	Z/MD
+:100644 100644 $(test_oid zmm2) $(test_oid zmm3) M	Z/MM
+:100644 100644 $(test_oid zmn2) $(test_oid zmn1) M	Z/MN
+:000000 100644 $(test_oid zero) $(test_oid zna1) A	Z/NA
+:100644 000000 $(test_oid znd1) $(test_oid zero) D	Z/ND
+:100644 100644 $(test_oid znm1) $(test_oid znm2) M	Z/NM
 EOF
 
 cmp_diff_files_output () {
diff -pruN 1.2.1+git2.18.0-1/git/t/t4006-diff-mode.sh 1.2.3+git2.25.1-1/git/t/t4006-diff-mode.sh
--- 1.2.1+git2.18.0-1/git/t/t4006-diff-mode.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t4006-diff-mode.sh	2020-02-17 04:47:35.000000000 +0000
@@ -32,28 +32,37 @@ test_expect_success 'prepare binary file
 	git commit -m binbin
 '
 
-# test_expect_success '--stat output after text chmod' '
-# 	test_chmod -x rezrov &&
-# 	echo " 0 files changed" >expect &&
-# 	git diff HEAD --stat >actual &&
-#	test_i18ncmp expect actual
-# '
-#
-# test_expect_success '--shortstat output after text chmod' '
-# 	git diff HEAD --shortstat >actual &&
-# 	test_i18ncmp expect actual
-# '
-#
-# test_expect_success '--stat output after binary chmod' '
-# 	test_chmod +x binbin &&
-# 	echo " 0 files changed" >expect &&
-# 	git diff HEAD --stat >actual &&
-# 	test_i18ncmp expect actual
-# '
-#
-# test_expect_success '--shortstat output after binary chmod' '
-# 	git diff HEAD --shortstat >actual &&
-# 	test_i18ncmp expect actual
-# '
+test_expect_success '--stat output after text chmod' '
+	test_chmod -x rezrov &&
+	cat >expect <<-\EOF &&
+	 rezrov | 0
+	 1 file changed, 0 insertions(+), 0 deletions(-)
+	EOF
+	git diff HEAD --stat >actual &&
+	test_i18ncmp expect actual
+'
+
+test_expect_success '--shortstat output after text chmod' '
+	tail -n 1 <expect >expect.short &&
+	git diff HEAD --shortstat >actual &&
+	test_i18ncmp expect.short actual
+'
+
+test_expect_success '--stat output after binary chmod' '
+	test_chmod +x binbin &&
+	cat >expect <<-EOF &&
+	 binbin | Bin
+	 rezrov |   0
+	 2 files changed, 0 insertions(+), 0 deletions(-)
+	EOF
+	git diff HEAD --stat >actual &&
+	test_i18ncmp expect actual
+'
+
+test_expect_success '--shortstat output after binary chmod' '
+	tail -n 1 <expect >expect.short &&
+	git diff HEAD --shortstat >actual &&
+	test_i18ncmp expect.short actual
+'
 
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t4009-diff-rename-4.sh 1.2.3+git2.25.1-1/git/t/t4009-diff-rename-4.sh
--- 1.2.1+git2.18.0-1/git/t/t4009-diff-rename-4.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t4009-diff-rename-4.sh	2020-02-17 04:47:35.000000000 +0000
@@ -14,6 +14,7 @@ test_expect_success \
     'cat "$TEST_DIRECTORY"/diff-lib/COPYING >COPYING &&
      echo frotz >rezrov &&
     git update-index --add COPYING rezrov &&
+    orig=$(git hash-object COPYING) &&
     tree=$(git write-tree) &&
     echo $tree'
 
@@ -22,6 +23,8 @@ test_expect_success \
     'sed -e 's/HOWEVER/However/' <COPYING >COPYING.1 &&
     sed -e 's/GPL/G.P.L/g' <COPYING >COPYING.2 &&
     rm -f COPYING &&
+    c1=$(git hash-object COPYING.1) &&
+    c2=$(git hash-object COPYING.2) &&
     git update-index --add --remove COPYING COPYING.?'
 
 # tree has COPYING and rezrov.  work tree has COPYING.1 and COPYING.2,
@@ -31,11 +34,11 @@ test_expect_success \
 
 git diff-index -z -C $tree >current
 
-cat >expected <<\EOF
-:100644 100644 6ff87c4664981e4397625791c8ea3bbb5f2279a3 0603b3238a076dc6c8022aedc6648fa523a17178 C1234
+cat >expected <<EOF
+:100644 100644 $orig $c1 C1234
 COPYING
 COPYING.1
-:100644 100644 6ff87c4664981e4397625791c8ea3bbb5f2279a3 06c67961bbaed34a127f76d261f4c0bf73eda471 R1234
+:100644 100644 $orig $c2 R1234
 COPYING
 COPYING.2
 EOF
@@ -57,10 +60,10 @@ test_expect_success \
 # about rezrov.
 
 git diff-index -z -C $tree >current
-cat >expected <<\EOF
-:100644 100644 6ff87c4664981e4397625791c8ea3bbb5f2279a3 06c67961bbaed34a127f76d261f4c0bf73eda471 M
+cat >expected <<EOF
+:100644 100644 $orig $c2 M
 COPYING
-:100644 100644 6ff87c4664981e4397625791c8ea3bbb5f2279a3 0603b3238a076dc6c8022aedc6648fa523a17178 C1234
+:100644 100644 $orig $c1 C1234
 COPYING
 COPYING.1
 EOF
@@ -82,8 +85,8 @@ test_expect_success \
      git update-index --add --remove COPYING COPYING.1'
 
 git diff-index -z -C --find-copies-harder $tree >current
-cat >expected <<\EOF
-:100644 100644 6ff87c4664981e4397625791c8ea3bbb5f2279a3 0603b3238a076dc6c8022aedc6648fa523a17178 C1234
+cat >expected <<EOF
+:100644 100644 $orig $c1 C1234
 COPYING
 COPYING.1
 EOF
diff -pruN 1.2.1+git2.18.0-1/git/t/t4010-diff-pathspec.sh 1.2.3+git2.25.1-1/git/t/t4010-diff-pathspec.sh
--- 1.2.1+git2.18.0-1/git/t/t4010-diff-pathspec.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t4010-diff-pathspec.sh	2020-02-17 04:47:35.000000000 +0000
@@ -17,11 +17,15 @@ test_expect_success \
     'echo frotz >file0 &&
      mkdir path1 &&
      echo rezrov >path1/file1 &&
+     before0=$(git hash-object file0) &&
+     before1=$(git hash-object path1/file1) &&
      git update-index --add file0 path1/file1 &&
      tree=$(git write-tree) &&
      echo "$tree" &&
      echo nitfol >file0 &&
      echo yomin >path1/file1 &&
+     after0=$(git hash-object file0) &&
+     after1=$(git hash-object path1/file1) &&
      git update-index file0 path1/file1'
 
 cat >expected <<\EOF
@@ -31,32 +35,32 @@ test_expect_success \
     'git diff-index --cached $tree -- path >current &&
      compare_diff_raw current expected'
 
-cat >expected <<\EOF
-:100644 100644 766498d93a4b06057a8e49d23f4068f1170ff38f 0a41e115ab61be0328a19b29f18cdcb49338d516 M	path1/file1
+cat >expected <<EOF
+:100644 100644 $before1 $after1 M	path1/file1
 EOF
 test_expect_success \
     'limit to path1 should show path1/file1' \
     'git diff-index --cached $tree -- path1 >current &&
      compare_diff_raw current expected'
 
-cat >expected <<\EOF
-:100644 100644 766498d93a4b06057a8e49d23f4068f1170ff38f 0a41e115ab61be0328a19b29f18cdcb49338d516 M	path1/file1
+cat >expected <<EOF
+:100644 100644 $before1 $after1 M	path1/file1
 EOF
 test_expect_success \
     'limit to path1/ should show path1/file1' \
     'git diff-index --cached $tree -- path1/ >current &&
      compare_diff_raw current expected'
 
-cat >expected <<\EOF
-:100644 100644 766498d93a4b06057a8e49d23f4068f1170ff38f 0a41e115ab61be0328a19b29f18cdcb49338d516 M	path1/file1
+cat >expected <<EOF
+:100644 100644 $before1 $after1 M	path1/file1
 EOF
 test_expect_success \
     '"*file1" should show path1/file1' \
     'git diff-index --cached $tree -- "*file1" >current &&
      compare_diff_raw current expected'
 
-cat >expected <<\EOF
-:100644 100644 8e4020bb5a8d8c873b25de15933e75cc0fc275df dca6b92303befc93086aa025d90a5facd7eb2812 M	file0
+cat >expected <<EOF
+:100644 100644 $before0 $after0 M	file0
 EOF
 test_expect_success \
     'limit to file0 should show file0' \
@@ -74,8 +78,7 @@ test_expect_success 'diff-tree pathspec'
 	tree2=$(git write-tree) &&
 	echo "$tree2" &&
 	git diff-tree -r --name-only $tree $tree2 -- pa path1/a >current &&
-	>expected &&
-	test_cmp expected current
+	test_must_be_empty current
 '
 
 test_expect_success 'diff-tree with wildcard shows dir also matches' '
@@ -111,10 +114,10 @@ test_expect_success 'diff-tree -r with w
 test_expect_success 'setup submodules' '
 	test_tick &&
 	git init submod &&
-	( cd submod && test_commit first; ) &&
+	( cd submod && test_commit first ) &&
 	git add submod &&
 	git commit -m first &&
-	( cd submod && test_commit second; ) &&
+	( cd submod && test_commit second ) &&
 	git add submod &&
 	git commit -m second
 '
diff -pruN 1.2.1+git2.18.0-1/git/t/t4011-diff-symlink.sh 1.2.3+git2.25.1-1/git/t/t4011-diff-symlink.sh
--- 1.2.1+git2.18.0-1/git/t/t4011-diff-symlink.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t4011-diff-symlink.sh	2020-02-17 04:47:35.000000000 +0000
@@ -9,11 +9,24 @@ test_description='Test diff of symlinks.
 . ./test-lib.sh
 . "$TEST_DIRECTORY"/diff-lib.sh
 
+# Print the short OID of a symlink with the given name.
+symlink_oid () {
+	local oid=$(printf "%s" "$1" | git hash-object --stdin) &&
+	git rev-parse --short "$oid"
+}
+
+# Print the short OID of the given file.
+short_oid () {
+	local oid=$(git hash-object "$1") &&
+	git rev-parse --short "$oid"
+}
+
 test_expect_success 'diff new symlink and file' '
-	cat >expected <<-\EOF &&
+	symlink=$(symlink_oid xyzzy) &&
+	cat >expected <<-EOF &&
 	diff --git a/frotz b/frotz
 	new file mode 120000
-	index 0000000..7c465af
+	index 0000000..$symlink
 	--- /dev/null
 	+++ b/frotz
 	@@ -0,0 +1 @@
@@ -21,7 +34,7 @@ test_expect_success 'diff new symlink an
 	\ No newline at end of file
 	diff --git a/nitfol b/nitfol
 	new file mode 100644
-	index 0000000..7c465af
+	index 0000000..$symlink
 	--- /dev/null
 	+++ b/nitfol
 	@@ -0,0 +1 @@
@@ -46,10 +59,10 @@ test_expect_success 'diff unchanged syml
 '
 
 test_expect_success 'diff removed symlink and file' '
-	cat >expected <<-\EOF &&
+	cat >expected <<-EOF &&
 	diff --git a/frotz b/frotz
 	deleted file mode 120000
-	index 7c465af..0000000
+	index $symlink..0000000
 	--- a/frotz
 	+++ /dev/null
 	@@ -1 +0,0 @@
@@ -57,7 +70,7 @@ test_expect_success 'diff removed symlin
 	\ No newline at end of file
 	diff --git a/nitfol b/nitfol
 	deleted file mode 100644
-	index 7c465af..0000000
+	index $symlink..0000000
 	--- a/nitfol
 	+++ /dev/null
 	@@ -1 +0,0 @@
@@ -90,9 +103,10 @@ test_expect_success 'diff identical, but
 '
 
 test_expect_success 'diff different symlink and file' '
-	cat >expected <<-\EOF &&
+	new=$(symlink_oid yxyyz) &&
+	cat >expected <<-EOF &&
 	diff --git a/frotz b/frotz
-	index 7c465af..df1db54 120000
+	index $symlink..$new 120000
 	--- a/frotz
 	+++ b/frotz
 	@@ -1 +1 @@
@@ -101,7 +115,7 @@ test_expect_success 'diff different syml
 	+yxyyz
 	\ No newline at end of file
 	diff --git a/nitfol b/nitfol
-	index 7c465af..df1db54 100644
+	index $symlink..$new 100644
 	--- a/nitfol
 	+++ b/nitfol
 	@@ -1 +1 @@
@@ -126,7 +140,7 @@ test_expect_success SYMLINKS 'diff symli
 	ln -s take\ over brain &&
 	test_must_fail git diff --no-index pinky brain >output 2>output.err &&
 	grep narf output &&
-	! test -s output.err
+	test_must_be_empty output.err
 '
 
 test_expect_success SYMLINKS 'setup symlinks with attributes' '
@@ -137,13 +151,17 @@ test_expect_success SYMLINKS 'setup syml
 '
 
 test_expect_success SYMLINKS 'symlinks do not respect userdiff config by path' '
-	cat >expect <<-\EOF &&
+	file=$(short_oid file.bin) &&
+	link=$(symlink_oid file.bin) &&
+	cat >expect <<-EOF &&
 	diff --git a/file.bin b/file.bin
-	index e69de29..d95f3ad 100644
-	Binary files a/file.bin and b/file.bin differ
+	new file mode 100644
+	index 0000000..$file
+	Binary files /dev/null and b/file.bin differ
 	diff --git a/link.bin b/link.bin
-	index e69de29..dce41ec 120000
-	--- a/link.bin
+	new file mode 120000
+	index 0000000..$link
+	--- /dev/null
 	+++ b/link.bin
 	@@ -0,0 +1 @@
 	+file.bin
diff -pruN 1.2.1+git2.18.0-1/git/t/t4012-diff-binary.sh 1.2.3+git2.25.1-1/git/t/t4012-diff-binary.sh
--- 1.2.1+git2.18.0-1/git/t/t4012-diff-binary.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t4012-diff-binary.sh	2020-02-17 04:47:35.000000000 +0000
@@ -102,10 +102,8 @@ test_expect_success 'apply binary patch'
 
 test_expect_success 'diff --no-index with binary creation' '
 	echo Q | q_to_nul >binary &&
-	(: hide error code from diff, which just indicates differences
-	 git diff --binary --no-index /dev/null binary >current ||
-	 true
-	) &&
+	# hide error code from diff, which just indicates differences
+	test_might_fail git diff --binary --no-index /dev/null binary >current &&
 	rm binary &&
 	git apply --binary <current &&
 	echo Q >expected &&
diff -pruN 1.2.1+git2.18.0-1/git/t/t4013/diff.diff_--dirstat_--cc_master~1_master 1.2.3+git2.25.1-1/git/t/t4013/diff.diff_--dirstat_--cc_master~1_master
--- 1.2.1+git2.18.0-1/git/t/t4013/diff.diff_--dirstat_--cc_master~1_master	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t4013/diff.diff_--dirstat_--cc_master~1_master	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,3 @@
+$ git diff --dirstat --cc master~1 master
+  40.0% dir/
+$
diff -pruN 1.2.1+git2.18.0-1/git/t/t4013/diff.diff-tree_--cc_--shortstat_master 1.2.3+git2.25.1-1/git/t/t4013/diff.diff-tree_--cc_--shortstat_master
--- 1.2.1+git2.18.0-1/git/t/t4013/diff.diff-tree_--cc_--shortstat_master	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t4013/diff.diff-tree_--cc_--shortstat_master	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,4 @@
+$ git diff-tree --cc --shortstat master
+59d314ad6f356dd08601a4cd5e530381da3e3c64
+ 2 files changed, 5 insertions(+)
+$
diff -pruN 1.2.1+git2.18.0-1/git/t/t4013/diff.diff-tree_--cc_--summary_REVERSE 1.2.3+git2.25.1-1/git/t/t4013/diff.diff-tree_--cc_--summary_REVERSE
--- 1.2.1+git2.18.0-1/git/t/t4013/diff.diff-tree_--cc_--summary_REVERSE	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t4013/diff.diff-tree_--cc_--summary_REVERSE	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,6 @@
+$ git diff-tree --cc --summary REVERSE
+2562325a7ee916efb2481da93073b82cec801cbc
+ create mode 100644 file1
+ delete mode 100644 file2
+ delete mode 100644 file3
+$
diff -pruN 1.2.1+git2.18.0-1/git/t/t4013/diff.diff_-U1_initial..side 1.2.3+git2.25.1-1/git/t/t4013/diff.diff_-U1_initial..side
--- 1.2.1+git2.18.0-1/git/t/t4013/diff.diff_-U1_initial..side	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t4013/diff.diff_-U1_initial..side	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,29 @@
+$ git diff -U1 initial..side
+diff --git a/dir/sub b/dir/sub
+index 35d242b..7289e35 100644
+--- a/dir/sub
++++ b/dir/sub
+@@ -2 +2,3 @@ A
+ B
++1
++2
+diff --git a/file0 b/file0
+index 01e79c3..f4615da 100644
+--- a/file0
++++ b/file0
+@@ -3 +3,4 @@
+ 3
++A
++B
++C
+diff --git a/file3 b/file3
+new file mode 100644
+index 0000000..7289e35
+--- /dev/null
++++ b/file3
+@@ -0,0 +1,4 @@
++A
++B
++1
++2
+$
diff -pruN 1.2.1+git2.18.0-1/git/t/t4013/diff.diff_-U2_initial..side 1.2.3+git2.25.1-1/git/t/t4013/diff.diff_-U2_initial..side
--- 1.2.1+git2.18.0-1/git/t/t4013/diff.diff_-U2_initial..side	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t4013/diff.diff_-U2_initial..side	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,31 @@
+$ git diff -U2 initial..side
+diff --git a/dir/sub b/dir/sub
+index 35d242b..7289e35 100644
+--- a/dir/sub
++++ b/dir/sub
+@@ -1,2 +1,4 @@
+ A
+ B
++1
++2
+diff --git a/file0 b/file0
+index 01e79c3..f4615da 100644
+--- a/file0
++++ b/file0
+@@ -2,2 +2,5 @@
+ 2
+ 3
++A
++B
++C
+diff --git a/file3 b/file3
+new file mode 100644
+index 0000000..7289e35
+--- /dev/null
++++ b/file3
+@@ -0,0 +1,4 @@
++A
++B
++1
++2
+$
diff -pruN 1.2.1+git2.18.0-1/git/t/t4013/diff.diff_-U_initial..side 1.2.3+git2.25.1-1/git/t/t4013/diff.diff_-U_initial..side
--- 1.2.1+git2.18.0-1/git/t/t4013/diff.diff_-U_initial..side	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t4013/diff.diff_-U_initial..side	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,32 @@
+$ git diff -U initial..side
+diff --git a/dir/sub b/dir/sub
+index 35d242b..7289e35 100644
+--- a/dir/sub
++++ b/dir/sub
+@@ -1,2 +1,4 @@
+ A
+ B
++1
++2
+diff --git a/file0 b/file0
+index 01e79c3..f4615da 100644
+--- a/file0
++++ b/file0
+@@ -1,3 +1,6 @@
+ 1
+ 2
+ 3
++A
++B
++C
+diff --git a/file3 b/file3
+new file mode 100644
+index 0000000..7289e35
+--- /dev/null
++++ b/file3
+@@ -0,0 +1,4 @@
++A
++B
++1
++2
+$
diff -pruN 1.2.1+git2.18.0-1/git/t/t4013-diff-various.sh 1.2.3+git2.25.1-1/git/t/t4013-diff-various.sh
--- 1.2.1+git2.18.0-1/git/t/t4013-diff-various.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t4013-diff-various.sh	2020-02-17 04:47:35.000000000 +0000
@@ -7,9 +7,6 @@ test_description='Various diff formattin
 
 . ./test-lib.sh
 
-LF='
-'
-
 test_expect_success setup '
 
 	GIT_AUTHOR_DATE="2006-06-26 00:00:00 +0000" &&
@@ -98,6 +95,12 @@ test_expect_success setup '
 	git commit -m "update mode" &&
 	git checkout -f master &&
 
+	# Same merge as master, but with parents reversed. Hide it in a
+	# pseudo-ref to avoid impacting tests with --all.
+	commit=$(echo reverse |
+		 git commit-tree -p master^2 -p master^1 master^{tree}) &&
+	git update-ref REVERSE $commit &&
+
 	git config diff.renames false &&
 
 	git show-branch
@@ -129,7 +132,7 @@ do
 		case "$magic" in
 		noellipses) ;;
 		*)
-			die "bug in t4103: unknown magic $magic" ;;
+			BUG "unknown magic $magic" ;;
 		esac ;;
 	*)
 		cmd="$magic $cmd" magic=
@@ -140,7 +143,7 @@ do
 	expect="$TEST_DIRECTORY/t4013/diff.$test"
 	actual="$pfx-diff.$test"
 
-	test_expect_success "git $cmd # magic is ${magic:-"(not used)"}" '
+	test_expect_success "git $cmd # magic is ${magic:-(not used)}" '
 		{
 			echo "$ git $cmd"
 			case "$magic" in
@@ -239,6 +242,8 @@ diff-tree --cc --stat --summary master
 # stat summary should show the diffstat and summary with the first parent
 diff-tree -c --stat --summary side
 diff-tree --cc --stat --summary side
+diff-tree --cc --shortstat master
+diff-tree --cc --summary REVERSE
 # improved by Timo's patch
 diff-tree --cc --patch-with-stat master
 # improved by Timo's patch
@@ -330,6 +335,8 @@ format-patch --inline --stdout initial..
 format-patch --stdout --cover-letter -n initial..master^
 
 diff --abbrev initial..side
+diff -U initial..side
+diff -U1 initial..side
 diff -r initial..side
 diff --stat initial..side
 diff -r --stat initial..side
@@ -350,6 +357,7 @@ diff --line-prefix=abc master master^ si
 diff --dirstat master~1 master~2
 diff --dirstat initial rearrange
 diff --dirstat-by-file initial rearrange
+diff --dirstat --cc master~1 master
 # No-index --abbrev and --no-abbrev
 diff --raw initial
 :noellipses diff --raw initial
diff -pruN 1.2.1+git2.18.0-1/git/t/t4014-format-patch.sh 1.2.3+git2.25.1-1/git/t/t4014-format-patch.sh
--- 1.2.1+git2.18.0-1/git/t/t4014-format-patch.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t4014-format-patch.sh	2020-02-17 04:47:35.000000000 +0000
@@ -9,7 +9,6 @@ test_description='various format-patch t
 . "$TEST_DIRECTORY"/lib-terminal.sh
 
 test_expect_success setup '
-
 	for i in 1 2 3 4 5 6 7 8 9 10; do echo "$i"; done >file &&
 	cat file >elif &&
 	git add file elif &&
@@ -34,39 +33,54 @@ test_expect_success setup '
 	git commit -m "Side changes #3 with \\n backslash-n in it." &&
 
 	git checkout master &&
-	git diff-tree -p C2 | git apply --index &&
+	git diff-tree -p C2 >patch &&
+	git apply --index <patch &&
 	test_tick &&
-	git commit -m "Master accepts moral equivalent of #2"
+	git commit -m "Master accepts moral equivalent of #2" &&
 
-'
+	git checkout side &&
+	git checkout -b patchid &&
+	for i in 5 6 1 2 3 A 4 B C 7 8 9 10 D E F; do echo "$i"; done >file2 &&
+	for i in 1 2 3 A 4 B C 7 8 9 10 D E F 5 6; do echo "$i"; done >file3 &&
+	for i in 8 9 10; do echo "$i"; done >file &&
+	git add file file2 file3 &&
+	test_tick &&
+	git commit -m "patchid 1" &&
+	for i in 4 A B 7 8 9 10; do echo "$i"; done >file2 &&
+	for i in 8 9 10 5 6; do echo "$i"; done >file3 &&
+	git add file2 file3 &&
+	test_tick &&
+	git commit -m "patchid 2" &&
+	for i in 10 5 6; do echo "$i"; done >file &&
+	git add file &&
+	test_tick &&
+	git commit -m "patchid 3" &&
 
-test_expect_success "format-patch --ignore-if-in-upstream" '
+	git checkout master
+'
 
+test_expect_success 'format-patch --ignore-if-in-upstream' '
 	git format-patch --stdout master..side >patch0 &&
-	cnt=$(grep "^From " patch0 | wc -l) &&
-	test $cnt = 3
-
+	grep "^From " patch0 >from0 &&
+	test_line_count = 3 from0
 '
 
-test_expect_success "format-patch --ignore-if-in-upstream" '
-
+test_expect_success 'format-patch --ignore-if-in-upstream' '
 	git format-patch --stdout \
 		--ignore-if-in-upstream master..side >patch1 &&
-	cnt=$(grep "^From " patch1 | wc -l) &&
-	test $cnt = 2
-
+	grep "^From " patch1 >from1 &&
+	test_line_count = 2 from1
 '
 
-test_expect_success "format-patch --ignore-if-in-upstream handles tags" '
+test_expect_success 'format-patch --ignore-if-in-upstream handles tags' '
 	git tag -a v1 -m tag side &&
 	git tag -a v2 -m tag master &&
 	git format-patch --stdout --ignore-if-in-upstream v2..v1 >patch1 &&
-	cnt=$(grep "^From " patch1 | wc -l) &&
-	test $cnt = 2
+	grep "^From " patch1 >from1 &&
+	test_line_count = 2 from1
 '
 
 test_expect_success "format-patch doesn't consider merge commits" '
-
 	git checkout -b slave master &&
 	echo "Another line" >>file &&
 	test_tick &&
@@ -77,148 +91,138 @@ test_expect_success "format-patch doesn'
 	git checkout -b merger master &&
 	test_tick &&
 	git merge --no-ff slave &&
-	cnt=$(git format-patch -3 --stdout | grep "^From " | wc -l) &&
-	test $cnt = 3
+	git format-patch -3 --stdout >patch &&
+	grep "^From " patch >from &&
+	test_line_count = 3 from
 '
 
-test_expect_success "format-patch result applies" '
-
+test_expect_success 'format-patch result applies' '
 	git checkout -b rebuild-0 master &&
 	git am -3 patch0 &&
-	cnt=$(git rev-list master.. | wc -l) &&
-	test $cnt = 2
+	git rev-list master.. >list &&
+	test_line_count = 2 list
 '
 
-test_expect_success "format-patch --ignore-if-in-upstream result applies" '
-
+test_expect_success 'format-patch --ignore-if-in-upstream result applies' '
 	git checkout -b rebuild-1 master &&
 	git am -3 patch1 &&
-	cnt=$(git rev-list master.. | wc -l) &&
-	test $cnt = 2
+	git rev-list master.. >list &&
+	test_line_count = 2 list
 '
 
 test_expect_success 'commit did not screw up the log message' '
-
-	git cat-file commit side | grep "^Side .* with .* backslash-n"
-
+	git cat-file commit side >actual &&
+	grep "^Side .* with .* backslash-n" actual
 '
 
 test_expect_success 'format-patch did not screw up the log message' '
-
 	grep "^Subject: .*Side changes #3 with .* backslash-n" patch0 &&
 	grep "^Subject: .*Side changes #3 with .* backslash-n" patch1
-
 '
 
 test_expect_success 'replay did not screw up the log message' '
-
-	git cat-file commit rebuild-1 | grep "^Side .* with .* backslash-n"
-
+	git cat-file commit rebuild-1 >actual &&
+	grep "^Side .* with .* backslash-n" actual
 '
 
 test_expect_success 'extra headers' '
-
 	git config format.headers "To: R E Cipient <rcipient@example.com>
 " &&
 	git config --add format.headers "Cc: S E Cipient <scipient@example.com>
 " &&
-	git format-patch --stdout master..side > patch2 &&
-	sed -e "/^\$/q" patch2 > hdrs2 &&
+	git format-patch --stdout master..side >patch2 &&
+	sed -e "/^\$/q" patch2 >hdrs2 &&
 	grep "^To: R E Cipient <rcipient@example.com>\$" hdrs2 &&
 	grep "^Cc: S E Cipient <scipient@example.com>\$" hdrs2
-
 '
 
 test_expect_success 'extra headers without newlines' '
-
 	git config --replace-all format.headers "To: R E Cipient <rcipient@example.com>" &&
 	git config --add format.headers "Cc: S E Cipient <scipient@example.com>" &&
 	git format-patch --stdout master..side >patch3 &&
-	sed -e "/^\$/q" patch3 > hdrs3 &&
+	sed -e "/^\$/q" patch3 >hdrs3 &&
 	grep "^To: R E Cipient <rcipient@example.com>\$" hdrs3 &&
 	grep "^Cc: S E Cipient <scipient@example.com>\$" hdrs3
-
 '
 
 test_expect_success 'extra headers with multiple To:s' '
-
 	git config --replace-all format.headers "To: R E Cipient <rcipient@example.com>" &&
 	git config --add format.headers "To: S E Cipient <scipient@example.com>" &&
-	git format-patch --stdout master..side > patch4 &&
-	sed -e "/^\$/q" patch4 > hdrs4 &&
+	git format-patch --stdout master..side >patch4 &&
+	sed -e "/^\$/q" patch4 >hdrs4 &&
 	grep "^To: R E Cipient <rcipient@example.com>,\$" hdrs4 &&
 	grep "^ *S E Cipient <scipient@example.com>\$" hdrs4
 '
 
 test_expect_success 'additional command line cc (ascii)' '
-
 	git config --replace-all format.headers "Cc: R E Cipient <rcipient@example.com>" &&
-	git format-patch --cc="S E Cipient <scipient@example.com>" --stdout master..side | sed -e "/^\$/q" >patch5 &&
-	grep "^Cc: R E Cipient <rcipient@example.com>,\$" patch5 &&
-	grep "^ *S E Cipient <scipient@example.com>\$" patch5
+	git format-patch --cc="S E Cipient <scipient@example.com>" --stdout master..side >patch5 &&
+	sed -e "/^\$/q" patch5 >hdrs5 &&
+	grep "^Cc: R E Cipient <rcipient@example.com>,\$" hdrs5 &&
+	grep "^ *S E Cipient <scipient@example.com>\$" hdrs5
 '
 
 test_expect_failure 'additional command line cc (rfc822)' '
-
 	git config --replace-all format.headers "Cc: R E Cipient <rcipient@example.com>" &&
-	git format-patch --cc="S. E. Cipient <scipient@example.com>" --stdout master..side | sed -e "/^\$/q" >patch5 &&
-	grep "^Cc: R E Cipient <rcipient@example.com>,\$" patch5 &&
-	grep "^ *\"S. E. Cipient\" <scipient@example.com>\$" patch5
+	git format-patch --cc="S. E. Cipient <scipient@example.com>" --stdout master..side >patch5 &&
+	sed -e "/^\$/q" patch5 >hdrs5 &&
+	grep "^Cc: R E Cipient <rcipient@example.com>,\$" hdrs5 &&
+	grep "^ *\"S. E. Cipient\" <scipient@example.com>\$" hdrs5
 '
 
 test_expect_success 'command line headers' '
-
 	git config --unset-all format.headers &&
-	git format-patch --add-header="Cc: R E Cipient <rcipient@example.com>" --stdout master..side | sed -e "/^\$/q" >patch6 &&
-	grep "^Cc: R E Cipient <rcipient@example.com>\$" patch6
+	git format-patch --add-header="Cc: R E Cipient <rcipient@example.com>" --stdout master..side >patch6 &&
+	sed -e "/^\$/q" patch6 >hdrs6 &&
+	grep "^Cc: R E Cipient <rcipient@example.com>\$" hdrs6
 '
 
 test_expect_success 'configuration headers and command line headers' '
-
 	git config --replace-all format.headers "Cc: R E Cipient <rcipient@example.com>" &&
-	git format-patch --add-header="Cc: S E Cipient <scipient@example.com>" --stdout master..side | sed -e "/^\$/q" >patch7 &&
-	grep "^Cc: R E Cipient <rcipient@example.com>,\$" patch7 &&
-	grep "^ *S E Cipient <scipient@example.com>\$" patch7
+	git format-patch --add-header="Cc: S E Cipient <scipient@example.com>" --stdout master..side >patch7 &&
+	sed -e "/^\$/q" patch7 >hdrs7 &&
+	grep "^Cc: R E Cipient <rcipient@example.com>,\$" hdrs7 &&
+	grep "^ *S E Cipient <scipient@example.com>\$" hdrs7
 '
 
 test_expect_success 'command line To: header (ascii)' '
-
 	git config --unset-all format.headers &&
-	git format-patch --to="R E Cipient <rcipient@example.com>" --stdout master..side | sed -e "/^\$/q" >patch8 &&
-	grep "^To: R E Cipient <rcipient@example.com>\$" patch8
+	git format-patch --to="R E Cipient <rcipient@example.com>" --stdout master..side >patch8 &&
+	sed -e "/^\$/q" patch8 >hdrs8 &&
+	grep "^To: R E Cipient <rcipient@example.com>\$" hdrs8
 '
 
 test_expect_failure 'command line To: header (rfc822)' '
-
-	git format-patch --to="R. E. Cipient <rcipient@example.com>" --stdout master..side | sed -e "/^\$/q" >patch8 &&
-	grep "^To: \"R. E. Cipient\" <rcipient@example.com>\$" patch8
+	git format-patch --to="R. E. Cipient <rcipient@example.com>" --stdout master..side >patch8 &&
+	sed -e "/^\$/q" patch8 >hdrs8 &&
+	grep "^To: \"R. E. Cipient\" <rcipient@example.com>\$" hdrs8
 '
 
 test_expect_failure 'command line To: header (rfc2047)' '
-
-	git format-patch --to="R Ä Cipient <rcipient@example.com>" --stdout master..side | sed -e "/^\$/q" >patch8 &&
-	grep "^To: =?UTF-8?q?R=20=C3=84=20Cipient?= <rcipient@example.com>\$" patch8
+	git format-patch --to="R Ä Cipient <rcipient@example.com>" --stdout master..side >patch8 &&
+	sed -e "/^\$/q" patch8 >hdrs8 &&
+	grep "^To: =?UTF-8?q?R=20=C3=84=20Cipient?= <rcipient@example.com>\$" hdrs8
 '
 
 test_expect_success 'configuration To: header (ascii)' '
-
 	git config format.to "R E Cipient <rcipient@example.com>" &&
-	git format-patch --stdout master..side | sed -e "/^\$/q" >patch9 &&
-	grep "^To: R E Cipient <rcipient@example.com>\$" patch9
+	git format-patch --stdout master..side >patch9 &&
+	sed -e "/^\$/q" patch9 >hdrs9 &&
+	grep "^To: R E Cipient <rcipient@example.com>\$" hdrs9
 '
 
 test_expect_failure 'configuration To: header (rfc822)' '
-
 	git config format.to "R. E. Cipient <rcipient@example.com>" &&
-	git format-patch --stdout master..side | sed -e "/^\$/q" >patch9 &&
-	grep "^To: \"R. E. Cipient\" <rcipient@example.com>\$" patch9
+	git format-patch --stdout master..side >patch9 &&
+	sed -e "/^\$/q" patch9 >hdrs9 &&
+	grep "^To: \"R. E. Cipient\" <rcipient@example.com>\$" hdrs9
 '
 
 test_expect_failure 'configuration To: header (rfc2047)' '
-
 	git config format.to "R Ä Cipient <rcipient@example.com>" &&
-	git format-patch --stdout master..side | sed -e "/^\$/q" >patch9 &&
-	grep "^To: =?UTF-8?q?R=20=C3=84=20Cipient?= <rcipient@example.com>\$" patch9
+	git format-patch --stdout master..side >patch9 &&
+	sed -e "/^\$/q" patch9 >hdrs9 &&
+	grep "^To: =?UTF-8?q?R=20=C3=84=20Cipient?= <rcipient@example.com>\$" hdrs9
 '
 
 # check_patch <patch>: Verify that <patch> looks like a half-sane
@@ -230,89 +234,79 @@ check_patch () {
 }
 
 test_expect_success 'format.from=false' '
-
-	git -c format.from=false format-patch --stdout master..side |
-	sed -e "/^\$/q" >patch &&
+	git -c format.from=false format-patch --stdout master..side >patch &&
+	sed -e "/^\$/q" patch >hdrs &&
 	check_patch patch &&
-	! grep "^From: C O Mitter <committer@example.com>\$" patch
+	! grep "^From: C O Mitter <committer@example.com>\$" hdrs
 '
 
 test_expect_success 'format.from=true' '
-
-	git -c format.from=true format-patch --stdout master..side |
-	sed -e "/^\$/q" >patch &&
-	check_patch patch &&
-	grep "^From: C O Mitter <committer@example.com>\$" patch
+	git -c format.from=true format-patch --stdout master..side >patch &&
+	sed -e "/^\$/q" patch >hdrs &&
+	check_patch hdrs &&
+	grep "^From: C O Mitter <committer@example.com>\$" hdrs
 '
 
 test_expect_success 'format.from with address' '
-
-	git -c format.from="F R Om <from@example.com>" format-patch --stdout master..side |
-	sed -e "/^\$/q" >patch &&
-	check_patch patch &&
-	grep "^From: F R Om <from@example.com>\$" patch
+	git -c format.from="F R Om <from@example.com>" format-patch --stdout master..side >patch &&
+	sed -e "/^\$/q" patch >hdrs &&
+	check_patch hdrs &&
+	grep "^From: F R Om <from@example.com>\$" hdrs
 '
 
 test_expect_success '--no-from overrides format.from' '
-
-	git -c format.from="F R Om <from@example.com>" format-patch --no-from --stdout master..side |
-	sed -e "/^\$/q" >patch &&
-	check_patch patch &&
-	! grep "^From: F R Om <from@example.com>\$" patch
+	git -c format.from="F R Om <from@example.com>" format-patch --no-from --stdout master..side >patch &&
+	sed -e "/^\$/q" patch >hdrs &&
+	check_patch hdrs &&
+	! grep "^From: F R Om <from@example.com>\$" hdrs
 '
 
 test_expect_success '--from overrides format.from' '
-
-	git -c format.from="F R Om <from@example.com>" format-patch --from --stdout master..side |
-	sed -e "/^\$/q" >patch &&
-	check_patch patch &&
-	! grep "^From: F R Om <from@example.com>\$" patch
+	git -c format.from="F R Om <from@example.com>" format-patch --from --stdout master..side >patch &&
+	sed -e "/^\$/q" patch >hdrs &&
+	check_patch hdrs &&
+	! grep "^From: F R Om <from@example.com>\$" hdrs
 '
 
 test_expect_success '--no-to overrides config.to' '
-
 	git config --replace-all format.to \
 		"R E Cipient <rcipient@example.com>" &&
-	git format-patch --no-to --stdout master..side |
-	sed -e "/^\$/q" >patch10 &&
-	check_patch patch10 &&
-	! grep "^To: R E Cipient <rcipient@example.com>\$" patch10
+	git format-patch --no-to --stdout master..side >patch10 &&
+	sed -e "/^\$/q" patch10 >hdrs10 &&
+	check_patch hdrs10 &&
+	! grep "^To: R E Cipient <rcipient@example.com>\$" hdrs10
 '
 
 test_expect_success '--no-to and --to replaces config.to' '
-
 	git config --replace-all format.to \
 		"Someone <someone@out.there>" &&
 	git format-patch --no-to --to="Someone Else <else@out.there>" \
-		--stdout master..side |
-	sed -e "/^\$/q" >patch11 &&
-	check_patch patch11 &&
-	! grep "^To: Someone <someone@out.there>\$" patch11 &&
-	grep "^To: Someone Else <else@out.there>\$" patch11
+		--stdout master..side >patch11 &&
+	sed -e "/^\$/q" patch11 >hdrs11 &&
+	check_patch hdrs11 &&
+	! grep "^To: Someone <someone@out.there>\$" hdrs11 &&
+	grep "^To: Someone Else <else@out.there>\$" hdrs11
 '
 
 test_expect_success '--no-cc overrides config.cc' '
-
 	git config --replace-all format.cc \
 		"C E Cipient <rcipient@example.com>" &&
-	git format-patch --no-cc --stdout master..side |
-	sed -e "/^\$/q" >patch12 &&
-	check_patch patch12 &&
-	! grep "^Cc: C E Cipient <rcipient@example.com>\$" patch12
+	git format-patch --no-cc --stdout master..side >patch12 &&
+	sed -e "/^\$/q" patch12 >hdrs12 &&
+	check_patch hdrs12 &&
+	! grep "^Cc: C E Cipient <rcipient@example.com>\$" hdrs12
 '
 
 test_expect_success '--no-add-header overrides config.headers' '
-
 	git config --replace-all format.headers \
 		"Header1: B E Cipient <rcipient@example.com>" &&
-	git format-patch --no-add-header --stdout master..side |
-	sed -e "/^\$/q" >patch13 &&
-	check_patch patch13 &&
-	! grep "^Header1: B E Cipient <rcipient@example.com>\$" patch13
+	git format-patch --no-add-header --stdout master..side >patch13 &&
+	sed -e "/^\$/q" patch13 >hdrs13 &&
+	check_patch hdrs13 &&
+	! grep "^Header1: B E Cipient <rcipient@example.com>\$" hdrs13
 '
 
 test_expect_success 'multiple files' '
-
 	rm -rf patches/ &&
 	git checkout side &&
 	git format-patch -o patches/ master &&
@@ -338,7 +332,7 @@ test_expect_success 'reroll count (-v)'
 check_threading () {
 	expect="$1" &&
 	shift &&
-	(git format-patch --stdout "$@"; echo $? > status.out) |
+	git format-patch --stdout "$@" >patch &&
 	# Prints everything between the Message-ID and In-Reply-To,
 	# and replaces all Message-ID-lookalikes by a sequence number
 	perl -ne '
@@ -353,12 +347,11 @@ check_threading () {
 			print;
 		}
 		print "---\n" if /^From /i;
-	' > actual &&
-	test 0 = "$(cat status.out)" &&
+	' <patch >actual &&
 	test_cmp "$expect" actual
 }
 
-cat >> expect.no-threading <<EOF
+cat >>expect.no-threading <<EOF
 ---
 ---
 ---
@@ -369,7 +362,7 @@ test_expect_success 'no threading' '
 	check_threading expect.no-threading master
 '
 
-cat > expect.thread <<EOF
+cat >expect.thread <<EOF
 ---
 Message-Id: <0>
 ---
@@ -386,7 +379,7 @@ test_expect_success 'thread' '
 	check_threading expect.thread --thread master
 '
 
-cat > expect.in-reply-to <<EOF
+cat >expect.in-reply-to <<EOF
 ---
 Message-Id: <0>
 In-Reply-To: <1>
@@ -406,7 +399,7 @@ test_expect_success 'thread in-reply-to'
 		--thread master
 '
 
-cat > expect.cover-letter <<EOF
+cat >expect.cover-letter <<EOF
 ---
 Message-Id: <0>
 ---
@@ -427,7 +420,7 @@ test_expect_success 'thread cover-letter
 	check_threading expect.cover-letter --cover-letter --thread master
 '
 
-cat > expect.cl-irt <<EOF
+cat >expect.cl-irt <<EOF
 ---
 Message-Id: <0>
 In-Reply-To: <1>
@@ -459,7 +452,7 @@ test_expect_success 'thread explicit sha
 		--in-reply-to="<test.message>" --thread=shallow master
 '
 
-cat > expect.deep <<EOF
+cat >expect.deep <<EOF
 ---
 Message-Id: <0>
 ---
@@ -477,7 +470,7 @@ test_expect_success 'thread deep' '
 	check_threading expect.deep --thread=deep master
 '
 
-cat > expect.deep-irt <<EOF
+cat >expect.deep-irt <<EOF
 ---
 Message-Id: <0>
 In-Reply-To: <1>
@@ -500,7 +493,7 @@ test_expect_success 'thread deep in-repl
 		--in-reply-to="<test.message>" master
 '
 
-cat > expect.deep-cl <<EOF
+cat >expect.deep-cl <<EOF
 ---
 Message-Id: <0>
 ---
@@ -524,7 +517,7 @@ test_expect_success 'thread deep cover-l
 	check_threading expect.deep-cl --cover-letter --thread=deep master
 '
 
-cat > expect.deep-cl-irt <<EOF
+cat >expect.deep-cl-irt <<EOF
 ---
 Message-Id: <0>
 In-Reply-To: <1>
@@ -575,7 +568,6 @@ test_expect_success 'thread config + --n
 '
 
 test_expect_success 'excessive subject' '
-
 	rm -rf patches/ &&
 	git checkout side &&
 	before=$(git hash-object file) &&
@@ -589,6 +581,12 @@ test_expect_success 'excessive subject'
 	ls patches/0004-This-is-an-excessively-long-subject-line-for-a-messa.patch
 '
 
+test_expect_success 'failure to write cover-letter aborts gracefully' '
+	test_when_finished "rmdir 0000-cover-letter.patch" &&
+	mkdir 0000-cover-letter.patch &&
+	test_must_fail git format-patch --no-renames --cover-letter -1
+'
+
 test_expect_success 'cover-letter inherits diff options' '
 	git mv file foo &&
 	git commit -m foo &&
@@ -597,10 +595,9 @@ test_expect_success 'cover-letter inheri
 	! grep "file => foo .* 0 *\$" 0000-cover-letter.patch &&
 	git format-patch --cover-letter -1 -M &&
 	grep "file => foo .* 0 *\$" 0000-cover-letter.patch
-
 '
 
-cat > expect << EOF
+cat >expect <<EOF
   This is an excessively long subject line for a message due to the
     habit some projects have of not having a short, one-line subject at
     the start of the commit message, but rather sticking a whole
@@ -611,14 +608,12 @@ cat > expect << EOF
 EOF
 
 test_expect_success 'shortlog of cover-letter wraps overly-long onelines' '
-
 	git format-patch --cover-letter -2 &&
-	sed -e "1,/A U Thor/d" -e "/^\$/q" < 0000-cover-letter.patch > output &&
+	sed -e "1,/A U Thor/d" -e "/^\$/q" 0000-cover-letter.patch >output &&
 	test_cmp expect output
-
 '
 
-cat > expect << EOF
+cat >expect <<EOF
 index $before..$after 100644
 --- a/file
 +++ b/file
@@ -631,16 +626,14 @@ index $before..$after 100644
 EOF
 
 test_expect_success 'format-patch respects -U' '
-
 	git format-patch -U4 -2 &&
 	sed -e "1,/^diff/d" -e "/^+5/q" \
 		<0001-This-is-an-excessively-long-subject-line-for-a-messa.patch \
 		>output &&
 	test_cmp expect output
-
 '
 
-cat > expect << EOF
+cat >expect <<EOF
 
 diff --git a/file b/file
 index $before..$after 100644
@@ -654,11 +647,9 @@ index $before..$after 100644
 EOF
 
 test_expect_success 'format-patch -p suppresses stat' '
-
 	git format-patch -p -2 &&
-	sed -e "1,/^\$/d" -e "/^+5/q" < 0001-This-is-an-excessively-long-subject-line-for-a-messa.patch > output &&
+	sed -e "1,/^\$/d" -e "/^+5/q" 0001-This-is-an-excessively-long-subject-line-for-a-messa.patch >output &&
 	test_cmp expect output
-
 '
 
 test_expect_success 'format-patch from a subdirectory (1)' '
@@ -711,7 +702,7 @@ test_expect_success 'format-patch from a
 '
 
 test_expect_success 'format-patch --in-reply-to' '
-	git format-patch -1 --stdout --in-reply-to "baz@foo.bar" > patch8 &&
+	git format-patch -1 --stdout --in-reply-to "baz@foo.bar" >patch8 &&
 	grep "^In-Reply-To: <baz@foo.bar>" patch8 &&
 	grep "^References: <baz@foo.bar>" patch8
 '
@@ -732,21 +723,126 @@ test_expect_success 'format-patch --note
 	sed "1,/^---$/d" out | grep "test message"
 '
 
-echo "fatal: --name-only does not make sense" > expect.name-only
-echo "fatal: --name-status does not make sense" > expect.name-status
-echo "fatal: --check does not make sense" > expect.check
+test_expect_success 'format-patch notes output control' '
+	git notes add -m "notes config message" HEAD &&
+	test_when_finished git notes remove HEAD &&
+
+	git format-patch -1 --stdout >out &&
+	! grep "notes config message" out &&
+	git format-patch -1 --stdout --notes >out &&
+	grep "notes config message" out &&
+	git format-patch -1 --stdout --no-notes >out &&
+	! grep "notes config message" out &&
+	git format-patch -1 --stdout --notes --no-notes >out &&
+	! grep "notes config message" out &&
+	git format-patch -1 --stdout --no-notes --notes >out &&
+	grep "notes config message" out &&
+
+	test_config format.notes true &&
+	git format-patch -1 --stdout >out &&
+	grep "notes config message" out &&
+	git format-patch -1 --stdout --notes >out &&
+	grep "notes config message" out &&
+	git format-patch -1 --stdout --no-notes >out &&
+	! grep "notes config message" out &&
+	git format-patch -1 --stdout --notes --no-notes >out &&
+	! grep "notes config message" out &&
+	git format-patch -1 --stdout --no-notes --notes >out &&
+	grep "notes config message" out
+'
+
+test_expect_success 'format-patch with multiple notes refs' '
+	git notes --ref note1 add -m "this is note 1" HEAD &&
+	test_when_finished git notes --ref note1 remove HEAD &&
+	git notes --ref note2 add -m "this is note 2" HEAD &&
+	test_when_finished git notes --ref note2 remove HEAD &&
+
+	git format-patch -1 --stdout >out &&
+	! grep "this is note 1" out &&
+	! grep "this is note 2" out &&
+	git format-patch -1 --stdout --notes=note1 >out &&
+	grep "this is note 1" out &&
+	! grep "this is note 2" out &&
+	git format-patch -1 --stdout --notes=note2 >out &&
+	! grep "this is note 1" out &&
+	grep "this is note 2" out &&
+	git format-patch -1 --stdout --notes=note1 --notes=note2 >out &&
+	grep "this is note 1" out &&
+	grep "this is note 2" out &&
+
+	test_config format.notes note1 &&
+	git format-patch -1 --stdout >out &&
+	grep "this is note 1" out &&
+	! grep "this is note 2" out &&
+	git format-patch -1 --stdout --no-notes >out &&
+	! grep "this is note 1" out &&
+	! grep "this is note 2" out &&
+	git format-patch -1 --stdout --notes=note2 >out &&
+	grep "this is note 1" out &&
+	grep "this is note 2" out &&
+	git format-patch -1 --stdout --no-notes --notes=note2 >out &&
+	! grep "this is note 1" out &&
+	grep "this is note 2" out &&
+
+	git config --add format.notes note2 &&
+	git format-patch -1 --stdout >out &&
+	grep "this is note 1" out &&
+	grep "this is note 2" out &&
+	git format-patch -1 --stdout --no-notes >out &&
+	! grep "this is note 1" out &&
+	! grep "this is note 2" out
+'
+
+test_expect_success 'format-patch with multiple notes refs in config' '
+	test_when_finished "test_unconfig format.notes" &&
+
+	git notes --ref note1 add -m "this is note 1" HEAD &&
+	test_when_finished git notes --ref note1 remove HEAD &&
+	git notes --ref note2 add -m "this is note 2" HEAD &&
+	test_when_finished git notes --ref note2 remove HEAD &&
+
+	git config format.notes note1 &&
+	git format-patch -1 --stdout >out &&
+	grep "this is note 1" out &&
+	! grep "this is note 2" out &&
+	git config format.notes note2 &&
+	git format-patch -1 --stdout >out &&
+	! grep "this is note 1" out &&
+	grep "this is note 2" out &&
+	git config --add format.notes note1 &&
+	git format-patch -1 --stdout >out &&
+	grep "this is note 1" out &&
+	grep "this is note 2" out &&
+
+	git config --replace-all format.notes note1 &&
+	git config --add format.notes false &&
+	git format-patch -1 --stdout >out &&
+	! grep "this is note 1" out &&
+	! grep "this is note 2" out &&
+	git config --add format.notes note2 &&
+	git format-patch -1 --stdout >out &&
+	! grep "this is note 1" out &&
+	grep "this is note 2" out
+'
+
+echo "fatal: --name-only does not make sense" >expect.name-only
+echo "fatal: --name-status does not make sense" >expect.name-status
+echo "fatal: --check does not make sense" >expect.check
 
 test_expect_success 'options no longer allowed for format-patch' '
-	test_must_fail git format-patch --name-only 2> output &&
+	test_must_fail git format-patch --name-only 2>output &&
 	test_i18ncmp expect.name-only output &&
-	test_must_fail git format-patch --name-status 2> output &&
+	test_must_fail git format-patch --name-status 2>output &&
 	test_i18ncmp expect.name-status output &&
-	test_must_fail git format-patch --check 2> output &&
-	test_i18ncmp expect.check output'
+	test_must_fail git format-patch --check 2>output &&
+	test_i18ncmp expect.check output
+'
 
 test_expect_success 'format-patch --numstat should produce a patch' '
-	git format-patch --numstat --stdout master..side > output &&
-	test 5 = $(grep "^diff --git a/" output | wc -l)'
+	git format-patch --numstat --stdout master..side >output &&
+	grep "^diff --git a/" output >diff &&
+	test_line_count = 5 diff
+'
 
 test_expect_success 'format-patch -- <path>' '
 	git format-patch master..side -- file 2>error &&
@@ -757,20 +853,25 @@ test_expect_success 'format-patch --igno
 	git format-patch --ignore-if-in-upstream HEAD
 '
 
-git_version="$(git --version | sed "s/.* //")"
+test_expect_success 'get git version' '
+	git_version=$(git --version) &&
+	git_version=${git_version##* }
+'
 
 signature() {
 	printf "%s\n%s\n\n" "-- " "${1:-$git_version}"
 }
 
 test_expect_success 'format-patch default signature' '
-	git format-patch --stdout -1 | tail -n 3 >output &&
+	git format-patch --stdout -1 >patch &&
+	tail -n 3 patch >output &&
 	signature >expect &&
 	test_cmp expect output
 '
 
 test_expect_success 'format-patch --signature' '
-	git format-patch --stdout --signature="my sig" -1 | tail -n 3 >output &&
+	git format-patch --stdout --signature="my sig" -1 >patch &&
+	tail -n 3 patch >output &&
 	signature "my sig" >expect &&
 	test_cmp expect output
 '
@@ -802,8 +903,8 @@ test_expect_success 'format-patch --sign
 	git config --unset-all format.signature &&
 	git format-patch --stdout --signature="my sig" --cover-letter \
 		-1 >output &&
-	grep "my sig" output &&
-	test 2 = $(grep "my sig" output | wc -l)
+	grep "my sig" output >sig &&
+	test_line_count = 2 sig
 '
 
 test_expect_success 'format.signature="" suppresses signatures' '
@@ -840,7 +941,7 @@ test_expect_success 'prepare mail-signat
 test_expect_success '--signature-file=file works' '
 	git format-patch --stdout --signature-file=mail-signature -1 >output &&
 	check_patch output &&
-	sed -e "1,/^-- \$/d" <output >actual &&
+	sed -e "1,/^-- \$/d" output >actual &&
 	{
 		cat mail-signature && echo
 	} >expect &&
@@ -851,7 +952,7 @@ test_expect_success 'format.signaturefil
 	test_config format.signaturefile mail-signature &&
 	git format-patch --stdout -1 >output &&
 	check_patch output &&
-	sed -e "1,/^-- \$/d" <output >actual &&
+	sed -e "1,/^-- \$/d" output >actual &&
 	{
 		cat mail-signature && echo
 	} >expect &&
@@ -873,7 +974,7 @@ test_expect_success '--signature-file ov
 	git format-patch --stdout \
 			--signature-file=other-mail-signature -1 >output &&
 	check_patch output &&
-	sed -e "1,/^-- \$/d" <output >actual &&
+	sed -e "1,/^-- \$/d" output >actual &&
 	{
 		cat other-mail-signature && echo
 	} >expect &&
@@ -942,7 +1043,7 @@ test_expect_success 'format-patch wraps
 	git add file &&
 	git commit -m "$M512" &&
 	git format-patch --stdout -1 >patch &&
-	sed -n "/^Subject/p; /^ /p; /^$/q" <patch >subject &&
+	sed -n "/^Subject/p; /^ /p; /^$/q" patch >subject &&
 	test_cmp expect subject
 '
 
@@ -981,7 +1082,7 @@ test_expect_success 'format-patch wraps
 	git add file &&
 	git commit -m "$M512" &&
 	git format-patch --stdout -1 >patch &&
-	sed -n "/^Subject/p; /^ /p; /^$/q" <patch >subject &&
+	sed -n "/^Subject/p; /^ /p; /^$/q" patch >subject &&
 	test_cmp expect subject
 '
 
@@ -990,7 +1091,7 @@ check_author() {
 	git add file &&
 	GIT_AUTHOR_NAME=$1 git commit -m author-check &&
 	git format-patch --stdout -1 >patch &&
-	sed -n "/^From: /p; /^ /p; /^$/q" <patch >actual &&
+	sed -n "/^From: /p; /^ /p; /^$/q" patch >actual &&
 	test_cmp expect actual
 }
 
@@ -1110,7 +1211,7 @@ test_expect_success '--from=ident replac
 	From: A U Thor <author@example.com>
 
 	EOF
-	sed -ne "/^From:/p; /^$/p; /^---$/q" <patch >patch.head &&
+	sed -ne "/^From:/p; /^$/p; /^---$/q" patch >patch.head &&
 	test_cmp expect patch.head
 '
 
@@ -1122,7 +1223,7 @@ test_expect_success '--from uses committ
 	From: A U Thor <author@example.com>
 
 	EOF
-	sed -ne "/^From:/p; /^$/p; /^---$/q" <patch >patch.head &&
+	sed -ne "/^From:/p; /^$/p; /^---$/q" patch >patch.head &&
 	test_cmp expect patch.head
 '
 
@@ -1132,7 +1233,7 @@ test_expect_success '--from omits redund
 	From: A U Thor <author@example.com>
 
 	EOF
-	sed -ne "/^From:/p; /^$/p; /^---$/q" <patch >patch.head &&
+	sed -ne "/^From:/p; /^$/p; /^---$/q" patch >patch.head &&
 	test_cmp expect patch.head
 '
 
@@ -1147,7 +1248,7 @@ test_expect_success 'in-body headers tri
 	From: éxötìc <author@example.com>
 
 	EOF
-	sed -ne "/^From:/p; /^$/p; /^Content-Type/p; /^---$/q" <patch >patch.head &&
+	sed -ne "/^From:/p; /^$/p; /^Content-Type/p; /^---$/q" patch >patch.head &&
 	test_cmp expect patch.head
 '
 
@@ -1161,283 +1262,283 @@ append_signoff()
 
 test_expect_success 'signoff: commit with no body' '
 	append_signoff </dev/null >actual &&
-	cat <<\EOF | sed "s/EOL$//" >expected &&
-4:Subject: [PATCH] EOL
-8:
-9:Signed-off-by: C O Mitter <committer@example.com>
-EOF
-	test_cmp expected actual
+	cat <<-\EOF | sed "s/EOL$//" >expect &&
+	4:Subject: [PATCH] EOL
+	8:
+	9:Signed-off-by: C O Mitter <committer@example.com>
+	EOF
+	test_cmp expect actual
 '
 
 test_expect_success 'signoff: commit with only subject' '
 	echo subject | append_signoff >actual &&
-	cat >expected <<\EOF &&
-4:Subject: [PATCH] subject
-8:
-9:Signed-off-by: C O Mitter <committer@example.com>
-EOF
-	test_cmp expected actual
+	cat >expect <<-\EOF &&
+	4:Subject: [PATCH] subject
+	8:
+	9:Signed-off-by: C O Mitter <committer@example.com>
+	EOF
+	test_cmp expect actual
 '
 
 test_expect_success 'signoff: commit with only subject that does not end with NL' '
 	printf subject | append_signoff >actual &&
-	cat >expected <<\EOF &&
-4:Subject: [PATCH] subject
-8:
-9:Signed-off-by: C O Mitter <committer@example.com>
-EOF
-	test_cmp expected actual
+	cat >expect <<-\EOF &&
+	4:Subject: [PATCH] subject
+	8:
+	9:Signed-off-by: C O Mitter <committer@example.com>
+	EOF
+	test_cmp expect actual
 '
 
 test_expect_success 'signoff: no existing signoffs' '
-	append_signoff <<\EOF >actual &&
-subject
+	append_signoff <<-\EOF >actual &&
+	subject
 
-body
-EOF
-	cat >expected <<\EOF &&
-4:Subject: [PATCH] subject
-8:
-10:
-11:Signed-off-by: C O Mitter <committer@example.com>
-EOF
-	test_cmp expected actual
+	body
+	EOF
+	cat >expect <<-\EOF &&
+	4:Subject: [PATCH] subject
+	8:
+	10:
+	11:Signed-off-by: C O Mitter <committer@example.com>
+	EOF
+	test_cmp expect actual
 '
 
 test_expect_success 'signoff: no existing signoffs and no trailing NL' '
 	printf "subject\n\nbody" | append_signoff >actual &&
-	cat >expected <<\EOF &&
-4:Subject: [PATCH] subject
-8:
-10:
-11:Signed-off-by: C O Mitter <committer@example.com>
-EOF
-	test_cmp expected actual
+	cat >expect <<-\EOF &&
+	4:Subject: [PATCH] subject
+	8:
+	10:
+	11:Signed-off-by: C O Mitter <committer@example.com>
+	EOF
+	test_cmp expect actual
 '
 
 test_expect_success 'signoff: some random signoff' '
-	append_signoff <<\EOF >actual &&
-subject
+	append_signoff <<-\EOF >actual &&
+	subject
 
-body
+	body
 
-Signed-off-by: my@house
-EOF
-	cat >expected <<\EOF &&
-4:Subject: [PATCH] subject
-8:
-10:
-11:Signed-off-by: my@house
-12:Signed-off-by: C O Mitter <committer@example.com>
-EOF
-	test_cmp expected actual
+	Signed-off-by: my@house
+	EOF
+	cat >expect <<-\EOF &&
+	4:Subject: [PATCH] subject
+	8:
+	10:
+	11:Signed-off-by: my@house
+	12:Signed-off-by: C O Mitter <committer@example.com>
+	EOF
+	test_cmp expect actual
 '
 
 test_expect_success 'signoff: misc conforming footer elements' '
-	append_signoff <<\EOF >actual &&
-subject
+	append_signoff <<-\EOF >actual &&
+	subject
 
-body
+	body
 
-Signed-off-by: my@house
-(cherry picked from commit da39a3ee5e6b4b0d3255bfef95601890afd80709)
-Tested-by: Some One <someone@example.com>
-Bug: 1234
-EOF
-	cat >expected <<\EOF &&
-4:Subject: [PATCH] subject
-8:
-10:
-11:Signed-off-by: my@house
-15:Signed-off-by: C O Mitter <committer@example.com>
-EOF
-	test_cmp expected actual
+	Signed-off-by: my@house
+	(cherry picked from commit da39a3ee5e6b4b0d3255bfef95601890afd80709)
+	Tested-by: Some One <someone@example.com>
+	Bug: 1234
+	EOF
+	cat >expect <<-\EOF &&
+	4:Subject: [PATCH] subject
+	8:
+	10:
+	11:Signed-off-by: my@house
+	15:Signed-off-by: C O Mitter <committer@example.com>
+	EOF
+	test_cmp expect actual
 '
 
 test_expect_success 'signoff: some random signoff-alike' '
-	append_signoff <<\EOF >actual &&
-subject
+	append_signoff <<-\EOF >actual &&
+	subject
 
-body
-Fooled-by-me: my@house
-EOF
-	cat >expected <<\EOF &&
-4:Subject: [PATCH] subject
-8:
-11:
-12:Signed-off-by: C O Mitter <committer@example.com>
-EOF
-	test_cmp expected actual
+	body
+	Fooled-by-me: my@house
+	EOF
+	cat >expect <<-\EOF &&
+	4:Subject: [PATCH] subject
+	8:
+	11:
+	12:Signed-off-by: C O Mitter <committer@example.com>
+	EOF
+	test_cmp expect actual
 '
 
 test_expect_success 'signoff: not really a signoff' '
-	append_signoff <<\EOF >actual &&
-subject
+	append_signoff <<-\EOF >actual &&
+	subject
 
-I want to mention about Signed-off-by: here.
-EOF
-	cat >expected <<\EOF &&
-4:Subject: [PATCH] subject
-8:
-9:I want to mention about Signed-off-by: here.
-10:
-11:Signed-off-by: C O Mitter <committer@example.com>
-EOF
-	test_cmp expected actual
+	I want to mention about Signed-off-by: here.
+	EOF
+	cat >expect <<-\EOF &&
+	4:Subject: [PATCH] subject
+	8:
+	9:I want to mention about Signed-off-by: here.
+	10:
+	11:Signed-off-by: C O Mitter <committer@example.com>
+	EOF
+	test_cmp expect actual
 '
 
 test_expect_success 'signoff: not really a signoff (2)' '
-	append_signoff <<\EOF >actual &&
-subject
+	append_signoff <<-\EOF >actual &&
+	subject
 
-My unfortunate
-Signed-off-by: example happens to be wrapped here.
-EOF
-	cat >expected <<\EOF &&
-4:Subject: [PATCH] subject
-8:
-10:Signed-off-by: example happens to be wrapped here.
-11:Signed-off-by: C O Mitter <committer@example.com>
-EOF
-	test_cmp expected actual
+	My unfortunate
+	Signed-off-by: example happens to be wrapped here.
+	EOF
+	cat >expect <<-\EOF &&
+	4:Subject: [PATCH] subject
+	8:
+	10:Signed-off-by: example happens to be wrapped here.
+	11:Signed-off-by: C O Mitter <committer@example.com>
+	EOF
+	test_cmp expect actual
 '
 
 test_expect_success 'signoff: valid S-o-b paragraph in the middle' '
-	append_signoff <<\EOF >actual &&
-subject
+	append_signoff <<-\EOF >actual &&
+	subject
 
-Signed-off-by: my@house
-Signed-off-by: your@house
+	Signed-off-by: my@house
+	Signed-off-by: your@house
 
-A lot of houses.
-EOF
-	cat >expected <<\EOF &&
-4:Subject: [PATCH] subject
-8:
-9:Signed-off-by: my@house
-10:Signed-off-by: your@house
-11:
-13:
-14:Signed-off-by: C O Mitter <committer@example.com>
-EOF
-	test_cmp expected actual
+	A lot of houses.
+	EOF
+	cat >expect <<-\EOF &&
+	4:Subject: [PATCH] subject
+	8:
+	9:Signed-off-by: my@house
+	10:Signed-off-by: your@house
+	11:
+	13:
+	14:Signed-off-by: C O Mitter <committer@example.com>
+	EOF
+	test_cmp expect actual
 '
 
 test_expect_success 'signoff: the same signoff at the end' '
-	append_signoff <<\EOF >actual &&
-subject
+	append_signoff <<-\EOF >actual &&
+	subject
 
-body
+	body
 
-Signed-off-by: C O Mitter <committer@example.com>
-EOF
-	cat >expected <<\EOF &&
-4:Subject: [PATCH] subject
-8:
-10:
-11:Signed-off-by: C O Mitter <committer@example.com>
-EOF
-	test_cmp expected actual
+	Signed-off-by: C O Mitter <committer@example.com>
+	EOF
+	cat >expect <<-\EOF &&
+	4:Subject: [PATCH] subject
+	8:
+	10:
+	11:Signed-off-by: C O Mitter <committer@example.com>
+	EOF
+	test_cmp expect actual
 '
 
 test_expect_success 'signoff: the same signoff at the end, no trailing NL' '
 	printf "subject\n\nSigned-off-by: C O Mitter <committer@example.com>" |
 		append_signoff >actual &&
-	cat >expected <<\EOF &&
-4:Subject: [PATCH] subject
-8:
-9:Signed-off-by: C O Mitter <committer@example.com>
-EOF
-	test_cmp expected actual
+	cat >expect <<-\EOF &&
+	4:Subject: [PATCH] subject
+	8:
+	9:Signed-off-by: C O Mitter <committer@example.com>
+	EOF
+	test_cmp expect actual
 '
 
 test_expect_success 'signoff: the same signoff NOT at the end' '
-	append_signoff <<\EOF >actual &&
-subject
+	append_signoff <<-\EOF >actual &&
+	subject
 
-body
+	body
 
-Signed-off-by: C O Mitter <committer@example.com>
-Signed-off-by: my@house
-EOF
-	cat >expected <<\EOF &&
-4:Subject: [PATCH] subject
-8:
-10:
-11:Signed-off-by: C O Mitter <committer@example.com>
-12:Signed-off-by: my@house
-EOF
-	test_cmp expected actual
+	Signed-off-by: C O Mitter <committer@example.com>
+	Signed-off-by: my@house
+	EOF
+	cat >expect <<-\EOF &&
+	4:Subject: [PATCH] subject
+	8:
+	10:
+	11:Signed-off-by: C O Mitter <committer@example.com>
+	12:Signed-off-by: my@house
+	EOF
+	test_cmp expect actual
 '
 
 test_expect_success 'signoff: tolerate garbage in conforming footer' '
-	append_signoff <<\EOF >actual &&
-subject
+	append_signoff <<-\EOF >actual &&
+	subject
 
-body
+	body
 
-Tested-by: my@house
-Some Trash
-Signed-off-by: C O Mitter <committer@example.com>
-EOF
-	cat >expected <<\EOF &&
-4:Subject: [PATCH] subject
-8:
-10:
-13:Signed-off-by: C O Mitter <committer@example.com>
-EOF
-	test_cmp expected actual
+	Tested-by: my@house
+	Some Trash
+	Signed-off-by: C O Mitter <committer@example.com>
+	EOF
+	cat >expect <<-\EOF &&
+	4:Subject: [PATCH] subject
+	8:
+	10:
+	13:Signed-off-by: C O Mitter <committer@example.com>
+	EOF
+	test_cmp expect actual
 '
 
 test_expect_success 'signoff: respect trailer config' '
-	append_signoff <<\EOF >actual &&
-subject
+	append_signoff <<-\EOF >actual &&
+	subject
 
-Myfooter: x
-Some Trash
-EOF
-	cat >expected <<\EOF &&
-4:Subject: [PATCH] subject
-8:
-11:
-12:Signed-off-by: C O Mitter <committer@example.com>
-EOF
-	test_cmp expected actual &&
+	Myfooter: x
+	Some Trash
+	EOF
+	cat >expect <<-\EOF &&
+	4:Subject: [PATCH] subject
+	8:
+	11:
+	12:Signed-off-by: C O Mitter <committer@example.com>
+	EOF
+	test_cmp expect actual &&
 
 	test_config trailer.Myfooter.ifexists add &&
-	append_signoff <<\EOF >actual &&
-subject
+	append_signoff <<-\EOF >actual &&
+	subject
 
-Myfooter: x
-Some Trash
-EOF
-	cat >expected <<\EOF &&
-4:Subject: [PATCH] subject
-8:
-11:Signed-off-by: C O Mitter <committer@example.com>
-EOF
-	test_cmp expected actual
+	Myfooter: x
+	Some Trash
+	EOF
+	cat >expect <<-\EOF &&
+	4:Subject: [PATCH] subject
+	8:
+	11:Signed-off-by: C O Mitter <committer@example.com>
+	EOF
+	test_cmp expect actual
 '
 
 test_expect_success 'signoff: footer begins with non-signoff without @ sign' '
-	append_signoff <<\EOF >actual &&
-subject
+	append_signoff <<-\EOF >actual &&
+	subject
 
-body
+	body
 
-Reviewed-id: Noone
-Tested-by: my@house
-Change-id: Ideadbeef
-Signed-off-by: C O Mitter <committer@example.com>
-Bug: 1234
-EOF
-	cat >expected <<\EOF &&
-4:Subject: [PATCH] subject
-8:
-10:
-14:Signed-off-by: C O Mitter <committer@example.com>
-EOF
-	test_cmp expected actual
+	Reviewed-id: Noone
+	Tested-by: my@house
+	Change-id: Ideadbeef
+	Signed-off-by: C O Mitter <committer@example.com>
+	Bug: 1234
+	EOF
+	cat >expect <<-\EOF &&
+	4:Subject: [PATCH] subject
+	8:
+	10:
+	14:Signed-off-by: C O Mitter <committer@example.com>
+	EOF
+	test_cmp expect actual
 '
 
 test_expect_success 'format patch ignores color.ui' '
@@ -1448,46 +1549,218 @@ test_expect_success 'format patch ignore
 	test_cmp expect actual
 '
 
+test_expect_success 'cover letter with invalid --cover-from-description and config' '
+	test_config branch.rebuild-1.description "config subject
+
+body" &&
+	test_must_fail git format-patch --cover-letter --cover-from-description garbage master &&
+	test_config format.coverFromDescription garbage &&
+	test_must_fail git format-patch --cover-letter master
+'
+
+test_expect_success 'cover letter with format.coverFromDescription = default' '
+	test_config branch.rebuild-1.description "config subject
+
+body" &&
+	test_config format.coverFromDescription default &&
+	git checkout rebuild-1 &&
+	git format-patch --stdout --cover-letter master >actual &&
+	grep "^Subject: \[PATCH 0/2\] \*\*\* SUBJECT HERE \*\*\*$" actual &&
+	! grep "^\*\*\* BLURB HERE \*\*\*$" actual &&
+	grep "^config subject$" actual &&
+	grep "^body$" actual
+'
+
+test_expect_success 'cover letter with --cover-from-description default' '
+	test_config branch.rebuild-1.description "config subject
+
+body" &&
+	git checkout rebuild-1 &&
+	git format-patch --stdout --cover-letter --cover-from-description default master >actual &&
+	grep "^Subject: \[PATCH 0/2\] \*\*\* SUBJECT HERE \*\*\*$" actual &&
+	! grep "^\*\*\* BLURB HERE \*\*\*$" actual &&
+	grep "^config subject$" actual &&
+	grep "^body$" actual
+'
+
+test_expect_success 'cover letter with format.coverFromDescription = none' '
+	test_config branch.rebuild-1.description "config subject
+
+body" &&
+	test_config format.coverFromDescription none &&
+	git checkout rebuild-1 &&
+	git format-patch --stdout --cover-letter master >actual &&
+	grep "^Subject: \[PATCH 0/2\] \*\*\* SUBJECT HERE \*\*\*$" actual &&
+	grep "^\*\*\* BLURB HERE \*\*\*$" actual &&
+	! grep "^config subject$" actual &&
+	! grep "^body$" actual
+'
+
+test_expect_success 'cover letter with --cover-from-description none' '
+	test_config branch.rebuild-1.description "config subject
+
+body" &&
+	git checkout rebuild-1 &&
+	git format-patch --stdout --cover-letter --cover-from-description none master >actual &&
+	grep "^Subject: \[PATCH 0/2\] \*\*\* SUBJECT HERE \*\*\*$" actual &&
+	grep "^\*\*\* BLURB HERE \*\*\*$" actual &&
+	! grep "^config subject$" actual &&
+	! grep "^body$" actual
+'
+
+test_expect_success 'cover letter with format.coverFromDescription = message' '
+	test_config branch.rebuild-1.description "config subject
+
+body" &&
+	test_config format.coverFromDescription message &&
+	git checkout rebuild-1 &&
+	git format-patch --stdout --cover-letter master >actual &&
+	grep "^Subject: \[PATCH 0/2\] \*\*\* SUBJECT HERE \*\*\*$" actual &&
+	! grep "^\*\*\* BLURB HERE \*\*\*$" actual &&
+	grep "^config subject$" actual &&
+	grep "^body$" actual
+'
+
+test_expect_success 'cover letter with --cover-from-description message' '
+	test_config branch.rebuild-1.description "config subject
+
+body" &&
+	git checkout rebuild-1 &&
+	git format-patch --stdout --cover-letter --cover-from-description message master >actual &&
+	grep "^Subject: \[PATCH 0/2\] \*\*\* SUBJECT HERE \*\*\*$" actual &&
+	! grep "^\*\*\* BLURB HERE \*\*\*$" actual &&
+	grep "^config subject$" actual &&
+	grep "^body$" actual
+'
+
+test_expect_success 'cover letter with format.coverFromDescription = subject' '
+	test_config branch.rebuild-1.description "config subject
+
+body" &&
+	test_config format.coverFromDescription subject &&
+	git checkout rebuild-1 &&
+	git format-patch --stdout --cover-letter master >actual &&
+	grep "^Subject: \[PATCH 0/2\] config subject$" actual &&
+	! grep "^\*\*\* BLURB HERE \*\*\*$" actual &&
+	! grep "^config subject$" actual &&
+	grep "^body$" actual
+'
+
+test_expect_success 'cover letter with --cover-from-description subject' '
+	test_config branch.rebuild-1.description "config subject
+
+body" &&
+	git checkout rebuild-1 &&
+	git format-patch --stdout --cover-letter --cover-from-description subject master >actual &&
+	grep "^Subject: \[PATCH 0/2\] config subject$" actual &&
+	! grep "^\*\*\* BLURB HERE \*\*\*$" actual &&
+	! grep "^config subject$" actual &&
+	grep "^body$" actual
+'
+
+test_expect_success 'cover letter with format.coverFromDescription = auto (short subject line)' '
+	test_config branch.rebuild-1.description "config subject
+
+body" &&
+	test_config format.coverFromDescription auto &&
+	git checkout rebuild-1 &&
+	git format-patch --stdout --cover-letter master >actual &&
+	grep "^Subject: \[PATCH 0/2\] config subject$" actual &&
+	! grep "^\*\*\* BLURB HERE \*\*\*$" actual &&
+	! grep "^config subject$" actual &&
+	grep "^body$" actual
+'
+
+test_expect_success 'cover letter with --cover-from-description auto (short subject line)' '
+	test_config branch.rebuild-1.description "config subject
+
+body" &&
+	git checkout rebuild-1 &&
+	git format-patch --stdout --cover-letter --cover-from-description auto master >actual &&
+	grep "^Subject: \[PATCH 0/2\] config subject$" actual &&
+	! grep "^\*\*\* BLURB HERE \*\*\*$" actual &&
+	! grep "^config subject$" actual &&
+	grep "^body$" actual
+'
+
+test_expect_success 'cover letter with format.coverFromDescription = auto (long subject line)' '
+	test_config branch.rebuild-1.description "this is a really long first line and it is over 100 characters long which is the threshold for long subjects
+
+body" &&
+	test_config format.coverFromDescription auto &&
+	git checkout rebuild-1 &&
+	git format-patch --stdout --cover-letter master >actual &&
+	grep "^Subject: \[PATCH 0/2\] \*\*\* SUBJECT HERE \*\*\*$" actual &&
+	! grep "^\*\*\* BLURB HERE \*\*\*$" actual &&
+	grep "^this is a really long first line and it is over 100 characters long which is the threshold for long subjects$" actual &&
+	grep "^body$" actual
+'
+
+test_expect_success 'cover letter with --cover-from-description auto (long subject line)' '
+	test_config branch.rebuild-1.description "this is a really long first line and it is over 100 characters long which is the threshold for long subjects
+
+body" &&
+	git checkout rebuild-1 &&
+	git format-patch --stdout --cover-letter --cover-from-description auto master >actual &&
+	grep "^Subject: \[PATCH 0/2\] \*\*\* SUBJECT HERE \*\*\*$" actual &&
+	! grep "^\*\*\* BLURB HERE \*\*\*$" actual &&
+	grep "^this is a really long first line and it is over 100 characters long which is the threshold for long subjects$" actual &&
+	grep "^body$" actual
+'
+
+test_expect_success 'cover letter with command-line --cover-from-description overrides config' '
+	test_config branch.rebuild-1.description "config subject
+
+body" &&
+	test_config format.coverFromDescription none &&
+	git checkout rebuild-1 &&
+	git format-patch --stdout --cover-letter --cover-from-description subject master >actual &&
+	grep "^Subject: \[PATCH 0/2\] config subject$" actual &&
+	! grep "^\*\*\* BLURB HERE \*\*\*$" actual &&
+	! grep "^config subject$" actual &&
+	grep "^body$" actual
+'
+
 test_expect_success 'cover letter using branch description (1)' '
 	git checkout rebuild-1 &&
 	test_config branch.rebuild-1.description hello &&
 	git format-patch --stdout --cover-letter master >actual &&
-	grep hello actual >/dev/null
+	grep hello actual
 '
 
 test_expect_success 'cover letter using branch description (2)' '
 	git checkout rebuild-1 &&
 	test_config branch.rebuild-1.description hello &&
 	git format-patch --stdout --cover-letter rebuild-1~2..rebuild-1 >actual &&
-	grep hello actual >/dev/null
+	grep hello actual
 '
 
 test_expect_success 'cover letter using branch description (3)' '
 	git checkout rebuild-1 &&
 	test_config branch.rebuild-1.description hello &&
 	git format-patch --stdout --cover-letter ^master rebuild-1 >actual &&
-	grep hello actual >/dev/null
+	grep hello actual
 '
 
 test_expect_success 'cover letter using branch description (4)' '
 	git checkout rebuild-1 &&
 	test_config branch.rebuild-1.description hello &&
 	git format-patch --stdout --cover-letter master.. >actual &&
-	grep hello actual >/dev/null
+	grep hello actual
 '
 
 test_expect_success 'cover letter using branch description (5)' '
 	git checkout rebuild-1 &&
 	test_config branch.rebuild-1.description hello &&
 	git format-patch --stdout --cover-letter -2 HEAD >actual &&
-	grep hello actual >/dev/null
+	grep hello actual
 '
 
 test_expect_success 'cover letter using branch description (6)' '
 	git checkout rebuild-1 &&
 	test_config branch.rebuild-1.description hello &&
 	git format-patch --stdout --cover-letter -2 >actual &&
-	grep hello actual >/dev/null
+	grep hello actual
 '
 
 test_expect_success 'cover letter with nothing' '
@@ -1537,11 +1810,39 @@ test_expect_success 'From line has expec
 	test_cmp from filtered
 '
 
+test_expect_success 'format-patch -o with no leading directories' '
+	rm -fr patches &&
+	git format-patch -o patches master..side &&
+	count=$(git rev-list --count master..side) &&
+	ls patches >list &&
+	test_line_count = $count list
+'
+
+test_expect_success 'format-patch -o with leading existing directories' '
+	rm -rf existing-dir &&
+	mkdir existing-dir &&
+	git format-patch -o existing-dir/patches master..side &&
+	count=$(git rev-list --count master..side) &&
+	ls existing-dir/patches >list &&
+	test_line_count = $count list
+'
+
+test_expect_success 'format-patch -o with leading non-existing directories' '
+	rm -rf non-existing-dir &&
+	git format-patch -o non-existing-dir/patches master..side &&
+	count=$(git rev-list --count master..side) &&
+	test_path_is_dir non-existing-dir &&
+	ls non-existing-dir/patches >list &&
+	test_line_count = $count list
+'
+
 test_expect_success 'format-patch format.outputDirectory option' '
 	test_config format.outputDirectory patches &&
 	rm -fr patches &&
 	git format-patch master..side &&
-	test $(git rev-list master..side | wc -l) -eq $(ls patches | wc -l)
+	count=$(git rev-list --count master..side) &&
+	ls patches >list &&
+	test_line_count = $count list
 '
 
 test_expect_success 'format-patch -o overrides format.outputDirectory' '
@@ -1553,14 +1854,44 @@ test_expect_success 'format-patch -o ove
 '
 
 test_expect_success 'format-patch --base' '
-	git checkout side &&
-	git format-patch --stdout --base=HEAD~3 -1 | tail -n 7 >actual &&
-	echo >expected &&
-	echo "base-commit: $(git rev-parse HEAD~3)" >>expected &&
-	echo "prerequisite-patch-id: $(git show --patch HEAD~2 | git patch-id --stable | awk "{print \$1}")" >>expected &&
-	echo "prerequisite-patch-id: $(git show --patch HEAD~1 | git patch-id --stable | awk "{print \$1}")" >>expected &&
-	signature >> expected &&
-	test_cmp expected actual
+	git checkout patchid &&
+
+	git format-patch --stdout --base=HEAD~3 -1 >patch &&
+	tail -n 7 patch >actual1 &&
+
+	git format-patch --stdout --base=HEAD~3 HEAD~.. >patch &&
+	tail -n 7 patch >actual2 &&
+
+	echo >expect &&
+	git rev-parse HEAD~3 >commit-id-base &&
+	echo "base-commit: $(cat commit-id-base)" >>expect &&
+
+	git show --patch HEAD~2 >patch &&
+	git patch-id --stable <patch >patch.id.raw &&
+	awk "{print \"prerequisite-patch-id:\", \$1}" <patch.id.raw >>expect &&
+
+	git show --patch HEAD~1 >patch &&
+	git patch-id --stable <patch >patch.id.raw &&
+	awk "{print \"prerequisite-patch-id:\", \$1}" <patch.id.raw >>expect &&
+
+	signature >>expect &&
+	test_cmp expect actual1 &&
+	test_cmp expect actual2 &&
+
+	echo >fail &&
+	echo "base-commit: $(cat commit-id-base)" >>fail &&
+
+	git show --patch HEAD~2 >patch &&
+	git patch-id --unstable <patch >patch.id.raw &&
+	awk "{print \"prerequisite-patch-id:\", \$1}" <patch.id.raw >>fail &&
+
+	git show --patch HEAD~1 >patch &&
+	git patch-id --unstable <patch >patch.id.raw &&
+	awk "{print \"prerequisite-patch-id:\", \$1}" <patch.id.raw >>fail &&
+
+	signature >>fail &&
+	! test_cmp fail actual1 &&
+	! test_cmp fail actual2
 '
 
 test_expect_success 'format-patch --base errors out when base commit is in revision list' '
@@ -1568,8 +1899,9 @@ test_expect_success 'format-patch --base
 	test_must_fail git format-patch --base=HEAD~1 -2 &&
 	git format-patch --stdout --base=HEAD~2 -2 >patch &&
 	grep "^base-commit:" patch >actual &&
-	echo "base-commit: $(git rev-parse HEAD~2)" >expected &&
-	test_cmp expected actual
+	git rev-parse HEAD~2 >commit-id-base &&
+	echo "base-commit: $(cat commit-id-base)" >expect &&
+	test_cmp expect actual
 '
 
 test_expect_success 'format-patch --base errors out when base commit is not ancestor of revision list' '
@@ -1595,8 +1927,8 @@ test_expect_success 'format-patch --base
 	test_must_fail git format-patch --base=$(cat commit-id-Z) -3 &&
 	git format-patch --stdout --base=$(cat commit-id-base) -3 >patch &&
 	grep "^base-commit:" patch >actual &&
-	echo "base-commit: $(cat commit-id-base)" >expected &&
-	test_cmp expected actual
+	echo "base-commit: $(cat commit-id-base)" >expect &&
+	test_cmp expect actual
 '
 
 test_expect_success 'format-patch --base=auto' '
@@ -1607,8 +1939,9 @@ test_expect_success 'format-patch --base
 	test_commit N2 &&
 	git format-patch --stdout --base=auto -2 >patch &&
 	grep "^base-commit:" patch >actual &&
-	echo "base-commit: $(git rev-parse upstream)" >expected &&
-	test_cmp expected actual
+	git rev-parse upstream >commit-id-base &&
+	echo "base-commit: $(cat commit-id-base)" >expect &&
+	test_cmp expect actual
 '
 
 test_expect_success 'format-patch errors out when history involves criss-cross' '
@@ -1638,23 +1971,29 @@ test_expect_success 'format-patch errors
 	test_must_fail 	git format-patch --base=auto -1
 '
 
-test_expect_success 'format-patch format.useAutoBaseoption' '
-	test_when_finished "git config --unset format.useAutoBase" &&
+test_expect_success 'format-patch format.useAutoBase option' '
 	git checkout local &&
-	git config format.useAutoBase true &&
+	test_config format.useAutoBase true &&
 	git format-patch --stdout -1 >patch &&
 	grep "^base-commit:" patch >actual &&
-	echo "base-commit: $(git rev-parse upstream)" >expected &&
-	test_cmp expected actual
+	git rev-parse upstream >commit-id-base &&
+	echo "base-commit: $(cat commit-id-base)" >expect &&
+	test_cmp expect actual
 '
 
 test_expect_success 'format-patch --base overrides format.useAutoBase' '
-	test_when_finished "git config --unset format.useAutoBase" &&
-	git config format.useAutoBase true &&
+	test_config format.useAutoBase true &&
 	git format-patch --stdout --base=HEAD~1 -1 >patch &&
 	grep "^base-commit:" patch >actual &&
-	echo "base-commit: $(git rev-parse HEAD~1)" >expected &&
-	test_cmp expected actual
+	git rev-parse HEAD~1 >commit-id-base &&
+	echo "base-commit: $(cat commit-id-base)" >expect &&
+	test_cmp expect actual
+'
+
+test_expect_success 'format-patch --no-base overrides format.useAutoBase' '
+	test_config format.useAutoBase true &&
+	git format-patch --stdout --no-base -1 >patch &&
+	! grep "^base-commit:" patch
 '
 
 test_expect_success 'format-patch --base with --attach' '
@@ -1715,4 +2054,38 @@ test_expect_success 'format-patch --pret
 	test_cmp expect actual
 '
 
+test_expect_success 'interdiff: setup' '
+	git checkout -b boop master &&
+	test_commit fnorp blorp &&
+	test_commit fleep blorp
+'
+
+test_expect_success 'interdiff: cover-letter' '
+	sed "y/q/ /" >expect <<-\EOF &&
+	+fleep
+	--q
+	EOF
+	git format-patch --cover-letter --interdiff=boop~2 -1 boop &&
+	test_i18ngrep "^Interdiff:$" 0000-cover-letter.patch &&
+	test_i18ngrep ! "^Interdiff:$" 0001-fleep.patch &&
+	sed "1,/^@@ /d; /^-- $/q" 0000-cover-letter.patch >actual &&
+	test_cmp expect actual
+'
+
+test_expect_success 'interdiff: reroll-count' '
+	git format-patch --cover-letter --interdiff=boop~2 -v2 -1 boop &&
+	test_i18ngrep "^Interdiff ..* v1:$" v2-0000-cover-letter.patch
+'
+
+test_expect_success 'interdiff: solo-patch' '
+	cat >expect <<-\EOF &&
+	  +fleep
+
+	EOF
+	git format-patch --interdiff=boop~2 -1 boop &&
+	test_i18ngrep "^Interdiff:$" 0001-fleep.patch &&
+	sed "1,/^  @@ /d; /^$/q" 0001-fleep.patch >actual &&
+	test_cmp expect actual
+'
+
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t4015-diff-whitespace.sh 1.2.3+git2.25.1-1/git/t/t4015-diff-whitespace.sh
--- 1.2.1+git2.18.0-1/git/t/t4015-diff-whitespace.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t4015-diff-whitespace.sh	2020-02-17 04:47:35.000000000 +0000
@@ -16,6 +16,8 @@ test_expect_success "Ray Lehtiniemi's ex
 	} while (0);
 	EOF
 	git update-index --add x &&
+	old_hash_x=$(git hash-object x) &&
+	before=$(git rev-parse --short "$old_hash_x") &&
 
 	cat <<-\EOF >x &&
 	do
@@ -24,10 +26,12 @@ test_expect_success "Ray Lehtiniemi's ex
 	}
 	while (0);
 	EOF
+	new_hash_x=$(git hash-object x) &&
+	after=$(git rev-parse --short "$new_hash_x") &&
 
-	cat <<-\EOF >expect &&
+	cat <<-EOF >expect &&
 	diff --git a/x b/x
-	index adf3937..6edc172 100644
+	index $before..$after 100644
 	--- a/x
 	+++ b/x
 	@@ -1,3 +1,5 @@
@@ -61,6 +65,8 @@ test_expect_success 'another test, witho
 	EOF
 
 	git update-index x &&
+	old_hash_x=$(git hash-object x) &&
+	before=$(git rev-parse --short "$old_hash_x") &&
 
 	tr "_" " " <<-\EOF >x &&
 	_	whitespace at beginning
@@ -70,10 +76,12 @@ test_expect_success 'another test, witho
 	unchanged line
 	CR at end
 	EOF
+	new_hash_x=$(git hash-object x) &&
+	after=$(git rev-parse --short "$new_hash_x") &&
 
-	tr "Q_" "\015 " <<-\EOF >expect &&
+	tr "Q_" "\015 " <<-EOF >expect &&
 	diff --git a/x b/x
-	index d99af23..22d9f73 100644
+	index $before..$after 100644
 	--- a/x
 	+++ b/x
 	@@ -1,6 +1,6 @@
@@ -93,25 +101,24 @@ test_expect_success 'another test, witho
 	git diff >out &&
 	test_cmp expect out &&
 
-	>expect &&
 	git diff -w >out &&
-	test_cmp expect out &&
+	test_must_be_empty out &&
 
 	git diff -w -b >out &&
-	test_cmp expect out &&
+	test_must_be_empty out &&
 
 	git diff -w --ignore-space-at-eol >out &&
-	test_cmp expect out &&
+	test_must_be_empty out &&
 
 	git diff -w -b --ignore-space-at-eol >out &&
-	test_cmp expect out &&
+	test_must_be_empty out &&
 
 	git diff -w --ignore-cr-at-eol >out &&
-	test_cmp expect out &&
+	test_must_be_empty out &&
 
-	tr "Q_" "\015 " <<-\EOF >expect &&
+	tr "Q_" "\015 " <<-EOF >expect &&
 	diff --git a/x b/x
-	index d99af23..22d9f73 100644
+	index $before..$after 100644
 	--- a/x
 	+++ b/x
 	@@ -1,6 +1,6 @@
@@ -133,9 +140,9 @@ test_expect_success 'another test, witho
 	git diff -b --ignore-cr-at-eol >out &&
 	test_cmp expect out &&
 
-	tr "Q_" "\015 " <<-\EOF >expect &&
+	tr "Q_" "\015 " <<-EOF >expect &&
 	diff --git a/x b/x
-	index d99af23..22d9f73 100644
+	index $before..$after 100644
 	--- a/x
 	+++ b/x
 	@@ -1,6 +1,6 @@
@@ -155,9 +162,9 @@ test_expect_success 'another test, witho
 	git diff --ignore-space-at-eol --ignore-cr-at-eol >out &&
 	test_cmp expect out &&
 
-	tr "Q_" "\015 " <<-\EOF >expect &&
+	tr "Q_" "\015 " <<-EOF >expect &&
 	diff --git a/x b/x
-	index_d99af23..22d9f73 100644
+	index_$before..$after 100644
 	--- a/x
 	+++ b/x
 	@@ -1,6 +1,6 @@
@@ -182,8 +189,7 @@ test_expect_success 'ignore-blank-lines:
 	test_seq 5 | sed "/3/i\\
 " >x &&
 	git diff --ignore-blank-lines >out &&
-	>expect &&
-	test_cmp expect out
+	test_must_be_empty out
 '
 
 test_expect_success 'ignore-blank-lines: only new lines with space' '
@@ -192,8 +198,7 @@ test_expect_success 'ignore-blank-lines:
 	test_seq 5 | sed "/3/i\\
  " >x &&
 	git diff -w --ignore-blank-lines >out &&
-	>expect &&
-	test_cmp expect out
+	test_must_be_empty out
 '
 
 test_expect_success 'ignore-blank-lines: after change' '
@@ -525,13 +530,15 @@ test_expect_success 'ignore-blank-lines:
 test_expect_success 'check mixed spaces and tabs in indent' '
 	# This is indented with SP HT SP.
 	echo " 	 foo();" >x &&
-	git diff --check | grep "space before tab in indent"
+	test_must_fail git diff --check >check &&
+	grep "space before tab in indent" check
 '
 
 test_expect_success 'check mixed tabs and spaces in indent' '
 	# This is indented with HT SP HT.
 	echo "	 	foo();" >x &&
-	git diff --check | grep "space before tab in indent"
+	test_must_fail git diff --check >check &&
+	grep "space before tab in indent" check
 '
 
 test_expect_success 'check with no whitespace errors' '
@@ -752,20 +759,23 @@ test_expect_success 'check tab-in-indent
 test_expect_success 'line numbers in --check output are correct' '
 	echo "" >x &&
 	echo "foo(); " >>x &&
-	git diff --check | grep "x:2:"
+	test_must_fail git diff --check >check &&
+	grep "x:2:" check
 '
 
 test_expect_success 'checkdiff detects new trailing blank lines (1)' '
 	echo "foo();" >x &&
 	echo "" >>x &&
-	git diff --check | grep "new blank line"
+	test_must_fail git diff --check >check &&
+	grep "new blank line" check
 '
 
 test_expect_success 'checkdiff detects new trailing blank lines (2)' '
-	{ echo a; echo b; echo; echo; } >x &&
+	test_write_lines a b "" "" >x &&
 	git add x &&
-	{ echo a; echo; echo; echo; echo; } >x &&
-	git diff --check | grep "new blank line"
+	test_write_lines a "" "" "" "" >x &&
+	test_must_fail git diff --check >check &&
+	grep "new blank line" check
 '
 
 test_expect_success 'checkdiff allows new blank lines' '
@@ -779,8 +789,6 @@ test_expect_success 'checkdiff allows ne
 	git diff --check
 '
 
-cat <<EOF >expect
-EOF
 test_expect_success 'whitespace-only changes not reported' '
 	git reset --hard &&
 	echo >x "hello world" &&
@@ -788,26 +796,30 @@ test_expect_success 'whitespace-only cha
 	git commit -m "hello 1" &&
 	echo >x "hello  world" &&
 	git diff -b >actual &&
-	test_cmp expect actual
+	test_must_be_empty actual
 '
 
-cat <<EOF >expect
-diff --git a/x b/z
-similarity index NUM%
-rename from x
-rename to z
-index 380c32a..a97b785 100644
-EOF
 test_expect_success 'whitespace-only changes reported across renames' '
 	git reset --hard &&
 	for i in 1 2 3 4 5 6 7 8 9; do echo "$i$i$i$i$i$i"; done >x &&
 	git add x &&
+	hash_x=$(git hash-object x) &&
+	before=$(git rev-parse --short "$hash_x") &&
 	git commit -m "base" &&
 	sed -e "5s/^/ /" x >z &&
 	git rm x &&
 	git add z &&
-	git diff -w -M --cached |
-	sed -e "/^similarity index /s/[0-9][0-9]*/NUM/" >actual &&
+	hash_z=$(git hash-object z) &&
+	after=$(git rev-parse --short "$hash_z") &&
+	git diff -w -M --cached >actual.raw &&
+	sed -e "/^similarity index /s/[0-9][0-9]*/NUM/" actual.raw >actual &&
+	cat <<-EOF >expect &&
+	diff --git a/x b/z
+	similarity index NUM%
+	rename from x
+	rename to z
+	index $before..$after 100644
+	EOF
 	test_cmp expect actual
 '
 
@@ -839,7 +851,8 @@ test_expect_success 'combined diff with
 	git config core.autocrlf true &&
 	test_must_fail git merge master &&
 
-	git diff | sed -e "1,/^@@@/d" >actual &&
+	git diff >actual.raw &&
+	sed -e "1,/^@@@/d" actual.raw >actual &&
 	! grep "^-" actual
 
 '
@@ -863,13 +876,18 @@ test_expect_success 'diff that introduce
 	git config core.whitespace blank-at-eol &&
 	git reset --hard &&
 	echo "test" >x &&
+	old_hash_x=$(git hash-object x) &&
+	before=$(git rev-parse --short "$old_hash_x") &&
 	git commit -m "initial" x &&
 	echo "{NTN}" | tr "NT" "\n\t" >>x &&
-	git diff --color | test_decode_color >current &&
+	new_hash_x=$(git hash-object x) &&
+	after=$(git rev-parse --short "$new_hash_x") &&
+	git diff --color >current.raw &&
+	test_decode_color <current.raw >current &&
 
-	cat >expected <<-\EOF &&
+	cat >expected <<-EOF &&
 	<BOLD>diff --git a/x b/x<RESET>
-	<BOLD>index 9daeafb..2874b91 100644<RESET>
+	<BOLD>index $before..$after 100644<RESET>
 	<BOLD>--- a/x<RESET>
 	<BOLD>+++ b/x<RESET>
 	<CYAN>@@ -1 +1,4 @@<RESET>
@@ -888,19 +906,23 @@ test_expect_success 'diff that introduce
 		echo "0. blank-at-eol " &&
 		echo "1. blank-at-eol "
 	} >x &&
+	old_hash_x=$(git hash-object x) &&
+	before=$(git rev-parse --short "$old_hash_x") &&
 	git commit -a --allow-empty -m preimage &&
 	{
 		echo "0. blank-at-eol " &&
 		echo "1. still-blank-at-eol " &&
 		echo "2. and a new line "
 	} >x &&
+	new_hash_x=$(git hash-object x) &&
+	after=$(git rev-parse --short "$new_hash_x") &&
 
-	git diff --color |
-	test_decode_color >current &&
+	git diff --color >current.raw &&
+	test_decode_color <current.raw >current &&
 
-	cat >expected <<-\EOF &&
+	cat >expected <<-EOF &&
 	<BOLD>diff --git a/x b/x<RESET>
-	<BOLD>index d0233a2..700886e 100644<RESET>
+	<BOLD>index $before..$after 100644<RESET>
 	<BOLD>--- a/x<RESET>
 	<BOLD>+++ b/x<RESET>
 	<CYAN>@@ -1,2 +1,3 @@<RESET>
@@ -920,16 +942,20 @@ test_expect_success 'ws-error-highlight
 		echo "0. blank-at-eol " &&
 		echo "1. blank-at-eol "
 	} >x &&
+	old_hash_x=$(git hash-object x) &&
+	before=$(git rev-parse --short "$old_hash_x") &&
 	git commit -a --allow-empty -m preimage &&
 	{
 		echo "0. blank-at-eol " &&
 		echo "1. still-blank-at-eol " &&
 		echo "2. and a new line "
 	} >x &&
+	new_hash_x=$(git hash-object x) &&
+	after=$(git rev-parse --short "$new_hash_x") &&
 
-	cat >expect.default-old <<-\EOF &&
+	cat >expect.default-old <<-EOF &&
 	<BOLD>diff --git a/x b/x<RESET>
-	<BOLD>index d0233a2..700886e 100644<RESET>
+	<BOLD>index $before..$after 100644<RESET>
 	<BOLD>--- a/x<RESET>
 	<BOLD>+++ b/x<RESET>
 	<CYAN>@@ -1,2 +1,3 @@<RESET>
@@ -939,9 +965,9 @@ test_expect_success 'ws-error-highlight
 	<GREEN>+<RESET><GREEN>2. and a new line<RESET><BLUE> <RESET>
 	EOF
 
-	cat >expect.all <<-\EOF &&
+	cat >expect.all <<-EOF &&
 	<BOLD>diff --git a/x b/x<RESET>
-	<BOLD>index d0233a2..700886e 100644<RESET>
+	<BOLD>index $before..$after 100644<RESET>
 	<BOLD>--- a/x<RESET>
 	<BOLD>+++ b/x<RESET>
 	<CYAN>@@ -1,2 +1,3 @@<RESET>
@@ -951,9 +977,9 @@ test_expect_success 'ws-error-highlight
 	<GREEN>+<RESET><GREEN>2. and a new line<RESET><BLUE> <RESET>
 	EOF
 
-	cat >expect.none <<-\EOF
+	cat >expect.none <<-EOF
 	<BOLD>diff --git a/x b/x<RESET>
-	<BOLD>index d0233a2..700886e 100644<RESET>
+	<BOLD>index $before..$after 100644<RESET>
 	<BOLD>--- a/x<RESET>
 	<BOLD>+++ b/x<RESET>
 	<CYAN>@@ -1,2 +1,3 @@<RESET>
@@ -967,32 +993,32 @@ test_expect_success 'ws-error-highlight
 
 test_expect_success 'test --ws-error-highlight option' '
 
-	git diff --color --ws-error-highlight=default,old |
-	test_decode_color >current &&
+	git diff --color --ws-error-highlight=default,old >current.raw &&
+	test_decode_color <current.raw >current &&
 	test_cmp expect.default-old current &&
 
-	git diff --color --ws-error-highlight=all |
-	test_decode_color >current &&
+	git diff --color --ws-error-highlight=all >current.raw &&
+	test_decode_color <current.raw >current &&
 	test_cmp expect.all current &&
 
-	git diff --color --ws-error-highlight=none |
-	test_decode_color >current &&
+	git diff --color --ws-error-highlight=none >current.raw &&
+	test_decode_color <current.raw >current &&
 	test_cmp expect.none current
 
 '
 
 test_expect_success 'test diff.wsErrorHighlight config' '
 
-	git -c diff.wsErrorHighlight=default,old diff --color |
-	test_decode_color >current &&
+	git -c diff.wsErrorHighlight=default,old diff --color >current.raw &&
+	test_decode_color <current.raw >current &&
 	test_cmp expect.default-old current &&
 
-	git -c diff.wsErrorHighlight=all diff --color |
-	test_decode_color >current &&
+	git -c diff.wsErrorHighlight=all diff --color >current.raw &&
+	test_decode_color <current.raw >current &&
 	test_cmp expect.all current &&
 
-	git -c diff.wsErrorHighlight=none diff --color |
-	test_decode_color >current &&
+	git -c diff.wsErrorHighlight=none diff --color >current.raw &&
+	test_decode_color <current.raw >current &&
 	test_cmp expect.none current
 
 '
@@ -1000,18 +1026,18 @@ test_expect_success 'test diff.wsErrorHi
 test_expect_success 'option overrides diff.wsErrorHighlight' '
 
 	git -c diff.wsErrorHighlight=none \
-		diff --color --ws-error-highlight=default,old |
-	test_decode_color >current &&
+		diff --color --ws-error-highlight=default,old >current.raw &&
+	test_decode_color <current.raw >current &&
 	test_cmp expect.default-old current &&
 
 	git -c diff.wsErrorHighlight=default \
-		diff --color --ws-error-highlight=all |
-	test_decode_color >current &&
+		diff --color --ws-error-highlight=all >current.raw &&
+	test_decode_color <current.raw >current &&
 	test_cmp expect.all current &&
 
 	git -c diff.wsErrorHighlight=all \
-		diff --color --ws-error-highlight=none |
-	test_decode_color >current &&
+		diff --color --ws-error-highlight=none >current.raw &&
+	test_decode_color <current.raw >current &&
 	test_cmp expect.none current
 
 '
@@ -1027,14 +1053,16 @@ test_expect_success 'detect moved code,
 	EOF
 	git add test.c &&
 	git commit -m "add main function" &&
+	file=$(git rev-parse --short HEAD:test.c) &&
 	git mv test.c main.c &&
 	test_config color.diff.oldMoved "normal red" &&
 	test_config color.diff.newMoved "normal green" &&
-	git diff HEAD --color-moved=zebra --color --no-renames | test_decode_color >actual &&
-	cat >expected <<-\EOF &&
+	git diff HEAD --color-moved=zebra --color --no-renames >actual.raw &&
+	test_decode_color <actual.raw >actual &&
+	cat >expected <<-EOF &&
 	<BOLD>diff --git a/main.c b/main.c<RESET>
 	<BOLD>new file mode 100644<RESET>
-	<BOLD>index 0000000..a986c57<RESET>
+	<BOLD>index 0000000..$file<RESET>
 	<BOLD>--- /dev/null<RESET>
 	<BOLD>+++ b/main.c<RESET>
 	<CYAN>@@ -0,0 +1,5 @@<RESET>
@@ -1045,7 +1073,7 @@ test_expect_success 'detect moved code,
 	<BGREEN>+<RESET><BGREEN>}<RESET>
 	<BOLD>diff --git a/test.c b/test.c<RESET>
 	<BOLD>deleted file mode 100644<RESET>
-	<BOLD>index a986c57..0000000<RESET>
+	<BOLD>index $file..0000000<RESET>
 	<BOLD>--- a/test.c<RESET>
 	<BOLD>+++ /dev/null<RESET>
 	<CYAN>@@ -1,5 +0,0 @@<RESET>
@@ -1099,6 +1127,8 @@ test_expect_success 'detect malicious mo
 	EOF
 	git add main.c test.c &&
 	git commit -m "add main and test file" &&
+	before_main=$(git rev-parse --short HEAD:main.c) &&
+	before_test=$(git rev-parse --short HEAD:test.c) &&
 	cat <<-\EOF >main.c &&
 		#include<stdio.h>
 		int stuff()
@@ -1131,10 +1161,15 @@ test_expect_success 'detect malicious mo
 			bar();
 		}
 	EOF
-	git diff HEAD --no-renames --color-moved=zebra --color | test_decode_color >actual &&
-	cat <<-\EOF >expected &&
+	hash_main=$(git hash-object main.c) &&
+	after_main=$(git rev-parse --short "$hash_main") &&
+	hash_test=$(git hash-object test.c) &&
+	after_test=$(git rev-parse --short "$hash_test") &&
+	git diff HEAD --no-renames --color-moved=zebra --color >actual.raw &&
+	test_decode_color <actual.raw >actual &&
+	cat <<-EOF >expected &&
 	<BOLD>diff --git a/main.c b/main.c<RESET>
-	<BOLD>index 27a619c..7cf9336 100644<RESET>
+	<BOLD>index $before_main..$after_main 100644<RESET>
 	<BOLD>--- a/main.c<RESET>
 	<BOLD>+++ b/main.c<RESET>
 	<CYAN>@@ -5,13 +5,6 @@<RESET> <RESET>printf("Hello ");<RESET>
@@ -1152,7 +1187,7 @@ test_expect_success 'detect malicious mo
 	 {<RESET>
 	 foo();<RESET>
 	<BOLD>diff --git a/test.c b/test.c<RESET>
-	<BOLD>index 1dc1d85..2bedec9 100644<RESET>
+	<BOLD>index $before_test..$after_test 100644<RESET>
 	<BOLD>--- a/test.c<RESET>
 	<BOLD>+++ b/test.c<RESET>
 	<CYAN>@@ -4,6 +4,13 @@<RESET> <RESET>int bar()<RESET>
@@ -1180,10 +1215,11 @@ test_expect_success 'plain moved code, i
 	test_config color.diff.oldMovedAlternative "blue" &&
 	test_config color.diff.newMovedAlternative "yellow" &&
 	# needs previous test as setup
-	git diff HEAD --no-renames --color-moved=plain --color | test_decode_color >actual &&
-	cat <<-\EOF >expected &&
+	git diff HEAD --no-renames --color-moved=plain --color >actual.raw &&
+	test_decode_color <actual.raw >actual &&
+	cat <<-EOF >expected &&
 	<BOLD>diff --git a/main.c b/main.c<RESET>
-	<BOLD>index 27a619c..7cf9336 100644<RESET>
+	<BOLD>index $before_main..$after_main 100644<RESET>
 	<BOLD>--- a/main.c<RESET>
 	<BOLD>+++ b/main.c<RESET>
 	<CYAN>@@ -5,13 +5,6 @@<RESET> <RESET>printf("Hello ");<RESET>
@@ -1201,7 +1237,7 @@ test_expect_success 'plain moved code, i
 	 {<RESET>
 	 foo();<RESET>
 	<BOLD>diff --git a/test.c b/test.c<RESET>
-	<BOLD>index 1dc1d85..2bedec9 100644<RESET>
+	<BOLD>index $before_test..$after_test 100644<RESET>
 	<BOLD>--- a/test.c<RESET>
 	<BOLD>+++ b/test.c<RESET>
 	<CYAN>@@ -4,6 +4,13 @@<RESET> <RESET>int bar()<RESET>
@@ -1223,7 +1259,7 @@ test_expect_success 'plain moved code, i
 	test_cmp expected actual
 '
 
-test_expect_success 'detect permutations inside moved code -- dimmed_zebra' '
+test_expect_success 'detect blocks of moved code' '
 	git reset --hard &&
 	cat <<-\EOF >lines.txt &&
 		long line 1
@@ -1271,9 +1307,52 @@ test_expect_success 'detect permutations
 	test_config color.diff.newMovedDimmed "normal cyan" &&
 	test_config color.diff.oldMovedAlternativeDimmed "normal blue" &&
 	test_config color.diff.newMovedAlternativeDimmed "normal yellow" &&
-	git diff HEAD --no-renames --color-moved=dimmed_zebra --color |
-		grep -v "index" |
-		test_decode_color >actual &&
+	git diff HEAD --no-renames --color-moved=blocks --color >actual.raw &&
+	grep -v "index" actual.raw | test_decode_color >actual &&
+	cat <<-\EOF >expected &&
+	<BOLD>diff --git a/lines.txt b/lines.txt<RESET>
+	<BOLD>--- a/lines.txt<RESET>
+	<BOLD>+++ b/lines.txt<RESET>
+	<CYAN>@@ -1,16 +1,16 @@<RESET>
+	<MAGENTA>-long line 1<RESET>
+	<MAGENTA>-long line 2<RESET>
+	<MAGENTA>-long line 3<RESET>
+	 line 4<RESET>
+	 line 5<RESET>
+	 line 6<RESET>
+	 line 7<RESET>
+	 line 8<RESET>
+	 line 9<RESET>
+	<CYAN>+<RESET><CYAN>long line 1<RESET>
+	<CYAN>+<RESET><CYAN>long line 2<RESET>
+	<CYAN>+<RESET><CYAN>long line 3<RESET>
+	<CYAN>+<RESET><CYAN>long line 14<RESET>
+	<CYAN>+<RESET><CYAN>long line 15<RESET>
+	<CYAN>+<RESET><CYAN>long line 16<RESET>
+	 line 10<RESET>
+	 line 11<RESET>
+	 line 12<RESET>
+	 line 13<RESET>
+	<MAGENTA>-long line 14<RESET>
+	<MAGENTA>-long line 15<RESET>
+	<MAGENTA>-long line 16<RESET>
+	EOF
+	test_cmp expected actual
+
+'
+
+test_expect_success 'detect permutations inside moved code -- dimmed-zebra' '
+	# reuse setup from test before!
+	test_config color.diff.oldMoved "magenta" &&
+	test_config color.diff.newMoved "cyan" &&
+	test_config color.diff.oldMovedAlternative "blue" &&
+	test_config color.diff.newMovedAlternative "yellow" &&
+	test_config color.diff.oldMovedDimmed "normal magenta" &&
+	test_config color.diff.newMovedDimmed "normal cyan" &&
+	test_config color.diff.oldMovedAlternativeDimmed "normal blue" &&
+	test_config color.diff.newMovedAlternativeDimmed "normal yellow" &&
+	git diff HEAD --no-renames --color-moved=dimmed-zebra --color >actual.raw &&
+	grep -v "index" actual.raw | test_decode_color >actual &&
 	cat <<-\EOF >expected &&
 	<BOLD>diff --git a/lines.txt b/lines.txt<RESET>
 	<BOLD>--- a/lines.txt<RESET>
@@ -1315,9 +1394,8 @@ test_expect_success 'cmd option assumes
 	test_config color.diff.oldMovedAlternativeDimmed "normal blue" &&
 	test_config color.diff.newMovedAlternativeDimmed "normal yellow" &&
 	test_config diff.colorMoved zebra &&
-	git diff HEAD --no-renames --color-moved --color |
-		grep -v "index" |
-		test_decode_color >actual &&
+	git diff HEAD --no-renames --color-moved --color >actual.raw &&
+	grep -v "index" actual.raw | test_decode_color >actual &&
 	cat <<-\EOF >expected &&
 	<BOLD>diff --git a/lines.txt b/lines.txt<RESET>
 	<BOLD>--- a/lines.txt<RESET>
@@ -1395,9 +1473,8 @@ test_expect_success 'move detection igno
 	line 4
 	line 5
 	EOF
-	git diff HEAD --no-renames --color-moved --color |
-		grep -v "index" |
-		test_decode_color >actual &&
+	git diff HEAD --no-renames --color-moved --color >actual.raw &&
+	grep -v "index" actual.raw | test_decode_color >actual &&
 	cat <<-\EOF >expected &&
 	<BOLD>diff --git a/lines.txt b/lines.txt<RESET>
 	<BOLD>--- a/lines.txt<RESET>
@@ -1419,9 +1496,9 @@ test_expect_success 'move detection igno
 	EOF
 	test_cmp expected actual &&
 
-	git diff HEAD --no-renames -w --color-moved --color |
-		grep -v "index" |
-		test_decode_color >actual &&
+	git diff HEAD --no-renames --color-moved --color \
+		--color-moved-ws=ignore-all-space >actual.raw &&
+	grep -v "index" actual.raw | test_decode_color >actual &&
 	cat <<-\EOF >expected &&
 	<BOLD>diff --git a/lines.txt b/lines.txt<RESET>
 	<BOLD>--- a/lines.txt<RESET>
@@ -1459,9 +1536,8 @@ test_expect_success 'move detection igno
 	line 5
 	EOF
 
-	git diff HEAD --no-renames --color-moved --color |
-		grep -v "index" |
-		test_decode_color >actual &&
+	git diff HEAD --no-renames --color-moved --color >actual.raw &&
+	grep -v "index" actual.raw | test_decode_color >actual &&
 	cat <<-\EOF >expected &&
 	<BOLD>diff --git a/lines.txt b/lines.txt<RESET>
 	<BOLD>--- a/lines.txt<RESET>
@@ -1483,9 +1559,9 @@ test_expect_success 'move detection igno
 	EOF
 	test_cmp expected actual &&
 
-	git diff HEAD --no-renames -b --color-moved --color |
-		grep -v "index" |
-		test_decode_color >actual &&
+	git diff HEAD --no-renames --color-moved --color \
+		--color-moved-ws=ignore-space-change >actual.raw &&
+	grep -v "index" actual.raw | test_decode_color >actual &&
 	cat <<-\EOF >expected &&
 	<BOLD>diff --git a/lines.txt b/lines.txt<RESET>
 	<BOLD>--- a/lines.txt<RESET>
@@ -1526,9 +1602,8 @@ test_expect_success 'move detection igno
 	# avoid cluttering the output with complaints about our eol whitespace
 	test_config core.whitespace -blank-at-eol &&
 
-	git diff HEAD --no-renames --color-moved --color |
-		grep -v "index" |
-		test_decode_color >actual &&
+	git diff HEAD --no-renames --color-moved --color >actual.raw &&
+	grep -v "index" actual.raw | test_decode_color >actual &&
 	cat <<-\EOF >expected &&
 	<BOLD>diff --git a/lines.txt b/lines.txt<RESET>
 	<BOLD>--- a/lines.txt<RESET>
@@ -1550,9 +1625,9 @@ test_expect_success 'move detection igno
 	EOF
 	test_cmp expected actual &&
 
-	git diff HEAD --no-renames --ignore-space-at-eol --color-moved --color |
-		grep -v "index" |
-		test_decode_color >actual &&
+	git diff HEAD --no-renames --color-moved --color \
+		--color-moved-ws=ignore-space-at-eol >actual.raw &&
+	grep -v "index" actual.raw | test_decode_color >actual &&
 	cat <<-\EOF >expected &&
 	<BOLD>diff --git a/lines.txt b/lines.txt<RESET>
 	<BOLD>--- a/lines.txt<RESET>
@@ -1597,9 +1672,8 @@ test_expect_success '--color-moved block
 	irrelevant_line
 	EOF
 
-	git diff HEAD --color-moved=zebra --color --no-renames |
-		grep -v "index" |
-		test_decode_color >actual &&
+	git diff HEAD --color-moved=zebra --color --no-renames >actual.raw &&
+	grep -v "index" actual.raw | test_decode_color >actual &&
 	cat >expected <<-\EOF &&
 	<BOLD>diff --git a/bar b/bar<RESET>
 	<BOLD>--- a/bar<RESET>
@@ -1636,9 +1710,8 @@ test_expect_success '--color-moved respe
 	nineteen chars 456789
 	EOF
 
-	git diff HEAD --color-moved=zebra --color --no-renames |
-		grep -v "index" |
-		test_decode_color >actual &&
+	git diff HEAD --color-moved=zebra --color --no-renames >actual.raw &&
+	grep -v "index" actual.raw | test_decode_color >actual &&
 	cat >expected <<-\EOF &&
 	<BOLD>diff --git a/bar b/bar<RESET>
 	<BOLD>--- a/bar<RESET>
@@ -1679,7 +1752,8 @@ test_expect_success '--color-moved treat
 	7charsA
 	EOF
 
-	git diff HEAD --color-moved=zebra --color --no-renames | grep -v "index" | test_decode_color >actual &&
+	git diff HEAD --color-moved=zebra --color --no-renames >actual.raw &&
+	grep -v "index" actual.raw | test_decode_color >actual &&
 	cat >expected <<-\EOF &&
 	<BOLD>diff --git a/bar b/bar<RESET>
 	<BOLD>--- a/bar<RESET>
@@ -1721,8 +1795,300 @@ test_expect_success 'move detection with
 	! grep BRED decoded_actual &&
 
 	# nor did we mess with it another way
-	git diff --submodule=diff --color | test_decode_color >expect &&
-	test_cmp expect decoded_actual
+	git diff --submodule=diff --color >expect.raw &&
+	test_decode_color <expect.raw >expect &&
+	test_cmp expect decoded_actual &&
+	rm -rf bananas &&
+	git submodule deinit bananas
+'
+
+test_expect_success 'only move detection ignores white spaces' '
+	git reset --hard &&
+	q_to_tab <<-\EOF >text.txt &&
+		a long line to exceed per-line minimum
+		another long line to exceed per-line minimum
+		original file
+	EOF
+	git add text.txt &&
+	git commit -m "add text" &&
+	q_to_tab <<-\EOF >text.txt &&
+		Qa long line to exceed per-line minimum
+		Qanother long line to exceed per-line minimum
+		new file
+	EOF
+
+	# Make sure we get a different diff using -w
+	git diff --color --color-moved -w >actual.raw &&
+	grep -v "index" actual.raw | test_decode_color >actual &&
+	q_to_tab <<-\EOF >expected &&
+	<BOLD>diff --git a/text.txt b/text.txt<RESET>
+	<BOLD>--- a/text.txt<RESET>
+	<BOLD>+++ b/text.txt<RESET>
+	<CYAN>@@ -1,3 +1,3 @@<RESET>
+	 Qa long line to exceed per-line minimum<RESET>
+	 Qanother long line to exceed per-line minimum<RESET>
+	<RED>-original file<RESET>
+	<GREEN>+<RESET><GREEN>new file<RESET>
+	EOF
+	test_cmp expected actual &&
+
+	# And now ignoring white space only in the move detection
+	git diff --color --color-moved \
+		--color-moved-ws=ignore-all-space,ignore-space-change,ignore-space-at-eol >actual.raw &&
+	grep -v "index" actual.raw | test_decode_color >actual &&
+	q_to_tab <<-\EOF >expected &&
+	<BOLD>diff --git a/text.txt b/text.txt<RESET>
+	<BOLD>--- a/text.txt<RESET>
+	<BOLD>+++ b/text.txt<RESET>
+	<CYAN>@@ -1,3 +1,3 @@<RESET>
+	<BOLD;MAGENTA>-a long line to exceed per-line minimum<RESET>
+	<BOLD;MAGENTA>-another long line to exceed per-line minimum<RESET>
+	<RED>-original file<RESET>
+	<BOLD;CYAN>+<RESET>Q<BOLD;CYAN>a long line to exceed per-line minimum<RESET>
+	<BOLD;CYAN>+<RESET>Q<BOLD;CYAN>another long line to exceed per-line minimum<RESET>
+	<GREEN>+<RESET><GREEN>new file<RESET>
+	EOF
+	test_cmp expected actual
+'
+
+test_expect_success 'compare whitespace delta across moved blocks' '
+
+	git reset --hard &&
+	q_to_tab <<-\EOF >text.txt &&
+	QIndented
+	QText across
+	Qsome lines
+	QBut! <- this stands out
+	QAdjusting with
+	QQdifferent starting
+	Qwhite spaces
+	QAnother outlier
+	QQQIndented
+	QQQText across
+	QQQfive lines
+	QQQthat has similar lines
+	QQQto previous blocks, but with different indent
+	QQQYetQAnotherQoutlierQ
+	QLine with internal w h i t e s p a c e change
+	EOF
+
+	git add text.txt &&
+	git commit -m "add text.txt" &&
+
+	q_to_tab <<-\EOF >text.txt &&
+	QQIndented
+	QQText across
+	QQsome lines
+	QQQBut! <- this stands out
+	Adjusting with
+	Qdifferent starting
+	white spaces
+	AnotherQoutlier
+	QQIndented
+	QQText across
+	QQfive lines
+	QQthat has similar lines
+	QQto previous blocks, but with different indent
+	QQYetQAnotherQoutlier
+	QLine with internal whitespace change
+	EOF
+
+	git diff --color --color-moved --color-moved-ws=allow-indentation-change >actual.raw &&
+	grep -v "index" actual.raw | test_decode_color >actual &&
+
+	q_to_tab <<-\EOF >expected &&
+		<BOLD>diff --git a/text.txt b/text.txt<RESET>
+		<BOLD>--- a/text.txt<RESET>
+		<BOLD>+++ b/text.txt<RESET>
+		<CYAN>@@ -1,15 +1,15 @@<RESET>
+		<BOLD;MAGENTA>-QIndented<RESET>
+		<BOLD;MAGENTA>-QText across<RESET>
+		<BOLD;MAGENTA>-Qsome lines<RESET>
+		<RED>-QBut! <- this stands out<RESET>
+		<BOLD;MAGENTA>-QAdjusting with<RESET>
+		<BOLD;MAGENTA>-QQdifferent starting<RESET>
+		<BOLD;MAGENTA>-Qwhite spaces<RESET>
+		<RED>-QAnother outlier<RESET>
+		<BOLD;MAGENTA>-QQQIndented<RESET>
+		<BOLD;MAGENTA>-QQQText across<RESET>
+		<BOLD;MAGENTA>-QQQfive lines<RESET>
+		<BOLD;MAGENTA>-QQQthat has similar lines<RESET>
+		<BOLD;MAGENTA>-QQQto previous blocks, but with different indent<RESET>
+		<RED>-QQQYetQAnotherQoutlierQ<RESET>
+		<RED>-QLine with internal w h i t e s p a c e change<RESET>
+		<BOLD;CYAN>+<RESET>QQ<BOLD;CYAN>Indented<RESET>
+		<BOLD;CYAN>+<RESET>QQ<BOLD;CYAN>Text across<RESET>
+		<BOLD;CYAN>+<RESET>QQ<BOLD;CYAN>some lines<RESET>
+		<GREEN>+<RESET>QQQ<GREEN>But! <- this stands out<RESET>
+		<BOLD;CYAN>+<RESET><BOLD;CYAN>Adjusting with<RESET>
+		<BOLD;CYAN>+<RESET>Q<BOLD;CYAN>different starting<RESET>
+		<BOLD;CYAN>+<RESET><BOLD;CYAN>white spaces<RESET>
+		<GREEN>+<RESET><GREEN>AnotherQoutlier<RESET>
+		<BOLD;CYAN>+<RESET>QQ<BOLD;CYAN>Indented<RESET>
+		<BOLD;CYAN>+<RESET>QQ<BOLD;CYAN>Text across<RESET>
+		<BOLD;CYAN>+<RESET>QQ<BOLD;CYAN>five lines<RESET>
+		<BOLD;CYAN>+<RESET>QQ<BOLD;CYAN>that has similar lines<RESET>
+		<BOLD;CYAN>+<RESET>QQ<BOLD;CYAN>to previous blocks, but with different indent<RESET>
+		<GREEN>+<RESET>QQ<GREEN>YetQAnotherQoutlier<RESET>
+		<GREEN>+<RESET>Q<GREEN>Line with internal whitespace change<RESET>
+	EOF
+
+	test_cmp expected actual
+'
+
+test_expect_success 'bogus settings in move detection erroring out' '
+	test_must_fail git diff --color-moved=bogus 2>err &&
+	test_i18ngrep "must be one of" err &&
+	test_i18ngrep bogus err &&
+
+	test_must_fail git -c diff.colormoved=bogus diff 2>err &&
+	test_i18ngrep "must be one of" err &&
+	test_i18ngrep "from command-line config" err &&
+
+	test_must_fail git diff --color-moved-ws=bogus 2>err &&
+	test_i18ngrep "possible values" err &&
+	test_i18ngrep bogus err &&
+
+	test_must_fail git -c diff.colormovedws=bogus diff 2>err &&
+	test_i18ngrep "possible values" err &&
+	test_i18ngrep "from command-line config" err
+'
+
+test_expect_success 'compare whitespace delta incompatible with other space options' '
+	test_must_fail git diff \
+		--color-moved-ws=allow-indentation-change,ignore-all-space \
+		2>err &&
+	test_i18ngrep allow-indentation-change err
+'
+
+EMPTY=''
+test_expect_success 'compare mixed whitespace delta across moved blocks' '
+
+	git reset --hard &&
+	tr Q_ "\t " <<-EOF >text.txt &&
+	${EMPTY}
+	____too short without
+	${EMPTY}
+	___being grouped across blank line
+	${EMPTY}
+	context
+	lines
+	to
+	anchor
+	____Indented text to
+	_Q____be further indented by four spaces across
+	____Qseveral lines
+	QQ____These two lines have had their
+	____indentation reduced by four spaces
+	Qdifferent indentation change
+	____too short
+	EOF
+
+	git add text.txt &&
+	git commit -m "add text.txt" &&
+
+	tr Q_ "\t " <<-EOF >text.txt &&
+	context
+	lines
+	to
+	anchor
+	QIndented text to
+	QQbe further indented by four spaces across
+	Q____several lines
+	${EMPTY}
+	QQtoo short without
+	${EMPTY}
+	Q_______being grouped across blank line
+	${EMPTY}
+	Q_QThese two lines have had their
+	indentation reduced by four spaces
+	QQdifferent indentation change
+	__Qtoo short
+	EOF
+
+	git -c color.diff.whitespace="normal red" \
+		-c core.whitespace=space-before-tab \
+		diff --color --color-moved --ws-error-highlight=all \
+		--color-moved-ws=allow-indentation-change >actual.raw &&
+	grep -v "index" actual.raw | test_decode_color >actual &&
+
+	cat <<-\EOF >expected &&
+	<BOLD>diff --git a/text.txt b/text.txt<RESET>
+	<BOLD>--- a/text.txt<RESET>
+	<BOLD>+++ b/text.txt<RESET>
+	<CYAN>@@ -1,16 +1,16 @@<RESET>
+	<BOLD;MAGENTA>-<RESET>
+	<BOLD;MAGENTA>-<RESET><BOLD;MAGENTA>    too short without<RESET>
+	<BOLD;MAGENTA>-<RESET>
+	<BOLD;MAGENTA>-<RESET><BOLD;MAGENTA>   being grouped across blank line<RESET>
+	<BOLD;MAGENTA>-<RESET>
+	 <RESET>context<RESET>
+	 <RESET>lines<RESET>
+	 <RESET>to<RESET>
+	 <RESET>anchor<RESET>
+	<BOLD;MAGENTA>-<RESET><BOLD;MAGENTA>    Indented text to<RESET>
+	<BOLD;MAGENTA>-<RESET><BRED> <RESET>	<BOLD;MAGENTA>    be further indented by four spaces across<RESET>
+	<BOLD;MAGENTA>-<RESET><BRED>    <RESET>	<BOLD;MAGENTA>several lines<RESET>
+	<BOLD;BLUE>-<RESET>		<BOLD;BLUE>    These two lines have had their<RESET>
+	<BOLD;BLUE>-<RESET><BOLD;BLUE>    indentation reduced by four spaces<RESET>
+	<BOLD;MAGENTA>-<RESET>	<BOLD;MAGENTA>different indentation change<RESET>
+	<RED>-<RESET><RED>    too short<RESET>
+	<BOLD;CYAN>+<RESET>	<BOLD;CYAN>Indented text to<RESET>
+	<BOLD;CYAN>+<RESET>		<BOLD;CYAN>be further indented by four spaces across<RESET>
+	<BOLD;CYAN>+<RESET>	<BOLD;CYAN>    several lines<RESET>
+	<BOLD;YELLOW>+<RESET>
+	<BOLD;YELLOW>+<RESET>		<BOLD;YELLOW>too short without<RESET>
+	<BOLD;YELLOW>+<RESET>
+	<BOLD;YELLOW>+<RESET>	<BOLD;YELLOW>       being grouped across blank line<RESET>
+	<BOLD;YELLOW>+<RESET>
+	<BOLD;CYAN>+<RESET>	<BRED> <RESET>	<BOLD;CYAN>These two lines have had their<RESET>
+	<BOLD;CYAN>+<RESET><BOLD;CYAN>indentation reduced by four spaces<RESET>
+	<BOLD;YELLOW>+<RESET>		<BOLD;YELLOW>different indentation change<RESET>
+	<GREEN>+<RESET><BRED>  <RESET>	<GREEN>too short<RESET>
+	EOF
+
+	test_cmp expected actual
+'
+
+test_expect_success 'combine --ignore-blank-lines with --function-context' '
+	test_write_lines 1 "" 2 3 4 5 >a &&
+	test_write_lines 1    2 3 4   >b &&
+	test_must_fail git diff --no-index \
+		--ignore-blank-lines --function-context a b >actual.raw &&
+	sed -n "/@@/,\$p" <actual.raw >actual &&
+	cat <<-\EOF >expect &&
+	@@ -1,6 +1,4 @@
+	 1
+	-
+	 2
+	 3
+	 4
+	-5
+	EOF
+	test_cmp expect actual
+'
+
+test_expect_success 'combine --ignore-blank-lines with --function-context 2' '
+	test_write_lines    a b c "" function 1 2 3 4 5 "" 6 7 8 9 >a &&
+	test_write_lines "" a b c "" function 1 2 3 4 5    6 7 8   >b &&
+	test_must_fail git diff --no-index \
+		--ignore-blank-lines --function-context a b >actual.raw &&
+	sed -n "/@@/,\$p" <actual.raw >actual &&
+	cat <<-\EOF >expect &&
+	@@ -5,11 +6,9 @@ c
+	 function
+	 1
+	 2
+	 3
+	 4
+	 5
+	-
+	 6
+	 7
+	 8
+	-9
+	EOF
+	test_cmp expect actual
 '
 
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t4018/dts-labels 1.2.3+git2.25.1-1/git/t/t4018/dts-labels
--- 1.2.1+git2.18.0-1/git/t/t4018/dts-labels	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t4018/dts-labels	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,9 @@
+/ {
+	label_1: node1@ff00 {
+		label2: RIGHT {
+			vendor,some-property;
+
+			ChangeMe = <0x45-30>;
+		};
+	};
+};
diff -pruN 1.2.1+git2.18.0-1/git/t/t4018/dts-nodes 1.2.3+git2.25.1-1/git/t/t4018/dts-nodes
--- 1.2.1+git2.18.0-1/git/t/t4018/dts-nodes	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t4018/dts-nodes	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,8 @@
+/ {
+	label_1: node1@ff00 {
+		RIGHT@deadf00,4000 {
+			#size-cells = <1>;
+			ChangeMe = <0xffeedd00>;
+		};
+	};
+};
diff -pruN 1.2.1+git2.18.0-1/git/t/t4018/dts-nodes-boolean-prop 1.2.3+git2.25.1-1/git/t/t4018/dts-nodes-boolean-prop
--- 1.2.1+git2.18.0-1/git/t/t4018/dts-nodes-boolean-prop	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t4018/dts-nodes-boolean-prop	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,9 @@
+/ {
+	label_1: node1@ff00 {
+		RIGHT@deadf00,4000 {
+			boolean-prop1;
+
+			ChangeMe;
+		};
+	};
+};
diff -pruN 1.2.1+git2.18.0-1/git/t/t4018/dts-nodes-comment1 1.2.3+git2.25.1-1/git/t/t4018/dts-nodes-comment1
--- 1.2.1+git2.18.0-1/git/t/t4018/dts-nodes-comment1	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t4018/dts-nodes-comment1	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,8 @@
+/ {
+	label_1: node1@ff00 {
+		RIGHT@deadf00,4000 /* &a comment */ {
+			#size-cells = <1>;
+			ChangeMe = <0xffeedd00>;
+		};
+	};
+};
diff -pruN 1.2.1+git2.18.0-1/git/t/t4018/dts-nodes-comment2 1.2.3+git2.25.1-1/git/t/t4018/dts-nodes-comment2
--- 1.2.1+git2.18.0-1/git/t/t4018/dts-nodes-comment2	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t4018/dts-nodes-comment2	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,8 @@
+/ {
+	label_1: node1@ff00 {
+		RIGHT@deadf00,4000 { /* a trailing comment */ 
+			#size-cells = <1>;
+			ChangeMe = <0xffeedd00>;
+		};
+	};
+};
diff -pruN 1.2.1+git2.18.0-1/git/t/t4018/dts-nodes-multiline-prop 1.2.3+git2.25.1-1/git/t/t4018/dts-nodes-multiline-prop
--- 1.2.1+git2.18.0-1/git/t/t4018/dts-nodes-multiline-prop	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t4018/dts-nodes-multiline-prop	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,13 @@
+/ {
+	label_1: node1@ff00 {
+		RIGHT@deadf00,4000 {
+			multilineprop = <3>,
+					<4>,
+					<5>,
+					<6>,
+					<7>;
+
+			ChangeMe = <0xffeedd00>;
+		};
+	};
+};
diff -pruN 1.2.1+git2.18.0-1/git/t/t4018/dts-node-unitless 1.2.3+git2.25.1-1/git/t/t4018/dts-node-unitless
--- 1.2.1+git2.18.0-1/git/t/t4018/dts-node-unitless	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t4018/dts-node-unitless	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,8 @@
+/ {
+	label_1: node1 {
+		RIGHT {
+			prop-array = <1>, <4>;
+			ChangeMe = <0xffeedd00>;
+		};
+	};
+};
diff -pruN 1.2.1+git2.18.0-1/git/t/t4018/dts-reference 1.2.3+git2.25.1-1/git/t/t4018/dts-reference
--- 1.2.1+git2.18.0-1/git/t/t4018/dts-reference	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t4018/dts-reference	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,9 @@
+&label_1 {
+	TEST = <455>;
+};
+
+&RIGHT {
+	vendor,some-property;
+
+	ChangeMe = <0x45-30>;
+};
diff -pruN 1.2.1+git2.18.0-1/git/t/t4018/dts-root 1.2.3+git2.25.1-1/git/t/t4018/dts-root
--- 1.2.1+git2.18.0-1/git/t/t4018/dts-root	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t4018/dts-root	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,5 @@
+/ { RIGHT /* Technically just supposed to be a slash and brace */
+	#size-cells = <1>;
+
+	ChangeMe = <0xffeedd00>;
+};
diff -pruN 1.2.1+git2.18.0-1/git/t/t4018/dts-root-comment 1.2.3+git2.25.1-1/git/t/t4018/dts-root-comment
--- 1.2.1+git2.18.0-1/git/t/t4018/dts-root-comment	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t4018/dts-root-comment	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,8 @@
+/ { RIGHT /* Technically just supposed to be a slash and brace */
+	#size-cells = <1>;
+
+	/* This comment should be ignored */
+
+	some-property = <40+2>;
+	ChangeMe = <0xffeedd00>;
+};
diff -pruN 1.2.1+git2.18.0-1/git/t/t4018/elixir-do-not-pick-end 1.2.3+git2.25.1-1/git/t/t4018/elixir-do-not-pick-end
--- 1.2.1+git2.18.0-1/git/t/t4018/elixir-do-not-pick-end	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t4018/elixir-do-not-pick-end	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,5 @@
+defmodule RIGHT do
+end
+#
+#
+# ChangeMe; do not pick up 'end' line
diff -pruN 1.2.1+git2.18.0-1/git/t/t4018/elixir-ex-unit-test 1.2.3+git2.25.1-1/git/t/t4018/elixir-ex-unit-test
--- 1.2.1+git2.18.0-1/git/t/t4018/elixir-ex-unit-test	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t4018/elixir-ex-unit-test	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,6 @@
+defmodule Test do
+  test "RIGHT" do
+    assert true == true
+    assert ChangeMe
+  end
+end
diff -pruN 1.2.1+git2.18.0-1/git/t/t4018/elixir-function 1.2.3+git2.25.1-1/git/t/t4018/elixir-function
--- 1.2.1+git2.18.0-1/git/t/t4018/elixir-function	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t4018/elixir-function	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,5 @@
+def function(RIGHT, arg) do
+  # comment
+  # comment
+  ChangeMe
+end
diff -pruN 1.2.1+git2.18.0-1/git/t/t4018/elixir-macro 1.2.3+git2.25.1-1/git/t/t4018/elixir-macro
--- 1.2.1+git2.18.0-1/git/t/t4018/elixir-macro	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t4018/elixir-macro	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,5 @@
+defmacro foo(RIGHT) do
+  # Code
+  # Code
+  ChangeMe
+end
diff -pruN 1.2.1+git2.18.0-1/git/t/t4018/elixir-module 1.2.3+git2.25.1-1/git/t/t4018/elixir-module
--- 1.2.1+git2.18.0-1/git/t/t4018/elixir-module	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t4018/elixir-module	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,9 @@
+defmodule RIGHT do
+  @moduledoc """
+  Foo bar
+  """
+
+  def ChangeMe(a) where is_map(a) do
+    a
+  end
+end
diff -pruN 1.2.1+git2.18.0-1/git/t/t4018/elixir-module-func 1.2.3+git2.25.1-1/git/t/t4018/elixir-module-func
--- 1.2.1+git2.18.0-1/git/t/t4018/elixir-module-func	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t4018/elixir-module-func	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,8 @@
+defmodule Foo do
+  def fun(RIGHT) do
+     # Code
+     # Code
+     # Code
+     ChangeMe
+  end
+end
diff -pruN 1.2.1+git2.18.0-1/git/t/t4018/elixir-nested-module 1.2.3+git2.25.1-1/git/t/t4018/elixir-nested-module
--- 1.2.1+git2.18.0-1/git/t/t4018/elixir-nested-module	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t4018/elixir-nested-module	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,9 @@
+defmodule MyApp.RIGHT do
+  @moduledoc """
+  Foo bar
+  """
+
+  def ChangeMe(a) where is_map(a) do
+    a
+  end
+end
diff -pruN 1.2.1+git2.18.0-1/git/t/t4018/elixir-private-function 1.2.3+git2.25.1-1/git/t/t4018/elixir-private-function
--- 1.2.1+git2.18.0-1/git/t/t4018/elixir-private-function	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t4018/elixir-private-function	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,5 @@
+defp function(RIGHT, arg) do
+  # comment
+  # comment
+  ChangeMe
+end
diff -pruN 1.2.1+git2.18.0-1/git/t/t4018/elixir-protocol 1.2.3+git2.25.1-1/git/t/t4018/elixir-protocol
--- 1.2.1+git2.18.0-1/git/t/t4018/elixir-protocol	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t4018/elixir-protocol	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,6 @@
+defprotocol RIGHT do
+  @doc """
+  Calculates the size (and not the length!) of a data structure
+  """
+  def size(data, ChangeMe)
+end
diff -pruN 1.2.1+git2.18.0-1/git/t/t4018/elixir-protocol-implementation 1.2.3+git2.25.1-1/git/t/t4018/elixir-protocol-implementation
--- 1.2.1+git2.18.0-1/git/t/t4018/elixir-protocol-implementation	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t4018/elixir-protocol-implementation	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,5 @@
+defimpl RIGHT do
+  # Docs
+  # Docs
+  def foo(ChangeMe), do: :ok
+end
diff -pruN 1.2.1+git2.18.0-1/git/t/t4018/matlab-class-definition 1.2.3+git2.25.1-1/git/t/t4018/matlab-class-definition
--- 1.2.1+git2.18.0-1/git/t/t4018/matlab-class-definition	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t4018/matlab-class-definition	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,5 @@
+classdef RIGHT
+    properties
+        ChangeMe
+    end
+end
diff -pruN 1.2.1+git2.18.0-1/git/t/t4018/matlab-function 1.2.3+git2.25.1-1/git/t/t4018/matlab-function
--- 1.2.1+git2.18.0-1/git/t/t4018/matlab-function	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t4018/matlab-function	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,4 @@
+function y = RIGHT()
+x = 5;
+y = ChangeMe + x;
+end
diff -pruN 1.2.1+git2.18.0-1/git/t/t4018/matlab-octave-section-1 1.2.3+git2.25.1-1/git/t/t4018/matlab-octave-section-1
--- 1.2.1+git2.18.0-1/git/t/t4018/matlab-octave-section-1	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t4018/matlab-octave-section-1	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,3 @@
+%%% RIGHT section
+# this is octave script
+ChangeMe = 1;
diff -pruN 1.2.1+git2.18.0-1/git/t/t4018/matlab-octave-section-2 1.2.3+git2.25.1-1/git/t/t4018/matlab-octave-section-2
--- 1.2.1+git2.18.0-1/git/t/t4018/matlab-octave-section-2	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t4018/matlab-octave-section-2	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,3 @@
+## RIGHT section
+# this is octave script
+ChangeMe = 1;
diff -pruN 1.2.1+git2.18.0-1/git/t/t4018/matlab-section 1.2.3+git2.25.1-1/git/t/t4018/matlab-section
--- 1.2.1+git2.18.0-1/git/t/t4018/matlab-section	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t4018/matlab-section	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,3 @@
+%% RIGHT section
+% this is understood by both matlab and octave
+ChangeMe = 1;
diff -pruN 1.2.1+git2.18.0-1/git/t/t4018/php-abstract-class 1.2.3+git2.25.1-1/git/t/t4018/php-abstract-class
--- 1.2.1+git2.18.0-1/git/t/t4018/php-abstract-class	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t4018/php-abstract-class	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,4 @@
+abstract class RIGHT
+{
+    const FOO = 'ChangeMe';
+}
diff -pruN 1.2.1+git2.18.0-1/git/t/t4018/php-class 1.2.3+git2.25.1-1/git/t/t4018/php-class
--- 1.2.1+git2.18.0-1/git/t/t4018/php-class	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t4018/php-class	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,4 @@
+class RIGHT
+{
+    const FOO = 'ChangeMe';
+}
diff -pruN 1.2.1+git2.18.0-1/git/t/t4018/php-final-class 1.2.3+git2.25.1-1/git/t/t4018/php-final-class
--- 1.2.1+git2.18.0-1/git/t/t4018/php-final-class	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t4018/php-final-class	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,4 @@
+final class RIGHT
+{
+    const FOO = 'ChangeMe';
+}
diff -pruN 1.2.1+git2.18.0-1/git/t/t4018/php-function 1.2.3+git2.25.1-1/git/t/t4018/php-function
--- 1.2.1+git2.18.0-1/git/t/t4018/php-function	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t4018/php-function	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,4 @@
+function RIGHT()
+{
+    return 'ChangeMe';
+}
diff -pruN 1.2.1+git2.18.0-1/git/t/t4018/php-interface 1.2.3+git2.25.1-1/git/t/t4018/php-interface
--- 1.2.1+git2.18.0-1/git/t/t4018/php-interface	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t4018/php-interface	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,4 @@
+interface RIGHT
+{
+    public function foo($ChangeMe);
+}
diff -pruN 1.2.1+git2.18.0-1/git/t/t4018/php-method 1.2.3+git2.25.1-1/git/t/t4018/php-method
--- 1.2.1+git2.18.0-1/git/t/t4018/php-method	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t4018/php-method	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,7 @@
+class Klass
+{
+    public static function RIGHT()
+    {
+        return 'ChangeMe';
+    }
+}
diff -pruN 1.2.1+git2.18.0-1/git/t/t4018/php-trait 1.2.3+git2.25.1-1/git/t/t4018/php-trait
--- 1.2.1+git2.18.0-1/git/t/t4018/php-trait	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t4018/php-trait	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,7 @@
+trait RIGHT
+{
+    public function foo($ChangeMe)
+    {
+        return 'foo';
+    }
+}
diff -pruN 1.2.1+git2.18.0-1/git/t/t4018/python-async-def 1.2.3+git2.25.1-1/git/t/t4018/python-async-def
--- 1.2.1+git2.18.0-1/git/t/t4018/python-async-def	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t4018/python-async-def	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,4 @@
+async def RIGHT(pi: int = 3.14):
+    while True:
+        break
+    return ChangeMe()
diff -pruN 1.2.1+git2.18.0-1/git/t/t4018/python-class 1.2.3+git2.25.1-1/git/t/t4018/python-class
--- 1.2.1+git2.18.0-1/git/t/t4018/python-class	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t4018/python-class	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,4 @@
+class RIGHT(int, str):
+    # comment
+    # another comment
+    # ChangeMe
diff -pruN 1.2.1+git2.18.0-1/git/t/t4018/python-def 1.2.3+git2.25.1-1/git/t/t4018/python-def
--- 1.2.1+git2.18.0-1/git/t/t4018/python-def	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t4018/python-def	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,4 @@
+def RIGHT(pi: int = 3.14):
+    while True:
+        break
+    return ChangeMe()
diff -pruN 1.2.1+git2.18.0-1/git/t/t4018/python-indented-async-def 1.2.3+git2.25.1-1/git/t/t4018/python-indented-async-def
--- 1.2.1+git2.18.0-1/git/t/t4018/python-indented-async-def	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t4018/python-indented-async-def	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,7 @@
+class Foo:
+    async def RIGHT(self, x: int):
+        return [
+            1,
+            2,
+            ChangeMe,
+        ]
diff -pruN 1.2.1+git2.18.0-1/git/t/t4018/python-indented-class 1.2.3+git2.25.1-1/git/t/t4018/python-indented-class
--- 1.2.1+git2.18.0-1/git/t/t4018/python-indented-class	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t4018/python-indented-class	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,5 @@
+if TYPE_CHECKING:
+    class RIGHT:
+        # comment
+        # another comment
+        # ChangeMe
diff -pruN 1.2.1+git2.18.0-1/git/t/t4018/python-indented-def 1.2.3+git2.25.1-1/git/t/t4018/python-indented-def
--- 1.2.1+git2.18.0-1/git/t/t4018/python-indented-def	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t4018/python-indented-def	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,7 @@
+class Foo:
+    def RIGHT(self, x: int):
+        return [
+            1,
+            2,
+            ChangeMe,
+        ]
diff -pruN 1.2.1+git2.18.0-1/git/t/t4018/rust-fn 1.2.3+git2.25.1-1/git/t/t4018/rust-fn
--- 1.2.1+git2.18.0-1/git/t/t4018/rust-fn	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t4018/rust-fn	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,5 @@
+pub(self) fn RIGHT<T>(x: &[T]) where T: Debug {
+    let _ = x;
+    // a comment
+    let a = ChangeMe;
+}
diff -pruN 1.2.1+git2.18.0-1/git/t/t4018/rust-impl 1.2.3+git2.25.1-1/git/t/t4018/rust-impl
--- 1.2.1+git2.18.0-1/git/t/t4018/rust-impl	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t4018/rust-impl	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,5 @@
+impl<'a, T: AsRef<[u8]>>  std::RIGHT for Git<'a> {
+
+    pub fn ChangeMe(&self) -> () {
+    }
+}
diff -pruN 1.2.1+git2.18.0-1/git/t/t4018/rust-struct 1.2.3+git2.25.1-1/git/t/t4018/rust-struct
--- 1.2.1+git2.18.0-1/git/t/t4018/rust-struct	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t4018/rust-struct	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,5 @@
+#[derive(Debug)]
+pub(super) struct RIGHT<'a> {
+    name: &'a str,
+    age: ChangeMe,
+}
diff -pruN 1.2.1+git2.18.0-1/git/t/t4018/rust-trait 1.2.3+git2.25.1-1/git/t/t4018/rust-trait
--- 1.2.1+git2.18.0-1/git/t/t4018/rust-trait	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t4018/rust-trait	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,5 @@
+unsafe trait RIGHT<T> {
+    fn len(&self) -> u32;
+    fn ChangeMe(&self, n: u32) -> T;
+    fn iter<F>(&self, f: F) where F: Fn(T);
+}
diff -pruN 1.2.1+git2.18.0-1/git/t/t4018-diff-funcname.sh 1.2.3+git2.25.1-1/git/t/t4018-diff-funcname.sh
--- 1.2.1+git2.18.0-1/git/t/t4018-diff-funcname.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t4018-diff-funcname.sh	2020-02-17 04:47:35.000000000 +0000
@@ -31,6 +31,8 @@ diffpatterns="
 	cpp
 	csharp
 	css
+	dts
+	elixir
 	fortran
 	fountain
 	golang
@@ -43,6 +45,7 @@ diffpatterns="
 	php
 	python
 	ruby
+	rust
 	tex
 	custom1
 	custom2
@@ -103,7 +106,6 @@ do
 		result=success
 	fi
 	test_expect_$result "hunk header: $i" "
-		test_when_finished 'cat actual' &&	# for debugging only
 		git diff -U1 $i >actual &&
 		grep '@@ .* @@.*RIGHT' actual
 	"
diff -pruN 1.2.1+git2.18.0-1/git/t/t4019-diff-wserror.sh 1.2.3+git2.25.1-1/git/t/t4019-diff-wserror.sh
--- 1.2.1+git2.18.0-1/git/t/t4019-diff-wserror.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t4019-diff-wserror.sh	2020-02-17 04:47:35.000000000 +0000
@@ -260,7 +260,7 @@ test_expect_success 'trailing empty line
 
 	echo "F -whitespace" >.gitattributes &&
 	git diff --check >output &&
-	! test -s output
+	test_must_be_empty output
 
 '
 
diff -pruN 1.2.1+git2.18.0-1/git/t/t4024-diff-optimize-common.sh 1.2.3+git2.25.1-1/git/t/t4024-diff-optimize-common.sh
--- 1.2.1+git2.18.0-1/git/t/t4024-diff-optimize-common.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t4024-diff-optimize-common.sh	2020-02-17 04:47:35.000000000 +0000
@@ -127,17 +127,17 @@ test_expect_success setup '
 
 	for n in $sample
 	do
-		( zs $n ; echo a ) >file-a$n &&
-		( echo b; zs $n; echo ) >file-b$n &&
-		( printf c; zs $n ) >file-c$n &&
-		( echo d; zs $n ) >file-d$n &&
+		( zs $n && echo a ) >file-a$n &&
+		( echo b && zs $n && echo ) >file-b$n &&
+		( printf c && zs $n ) >file-c$n &&
+		( echo d && zs $n ) >file-d$n &&
 
 		git add file-a$n file-b$n file-c$n file-d$n &&
 
-		( zs $n ; echo A ) >file-a$n &&
-		( echo B; zs $n; echo ) >file-b$n &&
-		( printf C; zs $n ) >file-c$n &&
-		( echo D; zs $n ) >file-d$n &&
+		( zs $n && echo A ) >file-a$n &&
+		( echo B && zs $n && echo ) >file-b$n &&
+		( printf C && zs $n ) >file-c$n &&
+		( echo D && zs $n ) >file-d$n &&
 
 		expect_pattern $n || return 1
 
diff -pruN 1.2.1+git2.18.0-1/git/t/t4025-hunk-header.sh 1.2.3+git2.25.1-1/git/t/t4025-hunk-header.sh
--- 1.2.1+git2.18.0-1/git/t/t4025-hunk-header.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t4025-hunk-header.sh	2020-02-17 04:47:35.000000000 +0000
@@ -12,12 +12,12 @@ NS="$N$N$N$N$N$N$N$N$N$N$N$N$N"
 test_expect_success setup '
 
 	(
-		echo "A $NS"
+		echo "A $NS" &&
 		for c in B C D E F G H I J K
 		do
 			echo "  $c"
-		done
-		echo "L  $NS"
+		done &&
+		echo "L  $NS" &&
 		for c in M N O P Q R S T U V
 		do
 			echo "  $c"
@@ -34,10 +34,10 @@ test_expect_success 'hunk header truncat
 
 	git diff | sed -n -e "s/^.*@@//p" >actual &&
 	(
-		echo " A $N$N$N$N$N$N$N$N$N2"
+		echo " A $N$N$N$N$N$N$N$N$N2" &&
 		echo " L  $N$N$N$N$N$N$N$N$N1"
 	) >expected &&
-	test_cmp actual expected
+	test_cmp expected actual
 
 '
 
diff -pruN 1.2.1+git2.18.0-1/git/t/t4027-diff-submodule.sh 1.2.3+git2.25.1-1/git/t/t4027-diff-submodule.sh
--- 1.2.1+git2.18.0-1/git/t/t4027-diff-submodule.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t4027-diff-submodule.sh	2020-02-17 04:47:35.000000000 +0000
@@ -6,6 +6,7 @@ test_description='difference in submodul
 . "$TEST_DIRECTORY"/diff-lib.sh
 
 test_expect_success setup '
+	test_oid_init &&
 	test_tick &&
 	test_create_repo sub &&
 	(
@@ -36,7 +37,8 @@ test_expect_success setup '
 '
 
 test_expect_success 'git diff --raw HEAD' '
-	git diff --raw --abbrev=40 HEAD >actual &&
+	hexsz=$(test_oid hexsz) &&
+	git diff --raw --abbrev=$hexsz HEAD >actual &&
 	test_cmp expect actual
 '
 
@@ -104,19 +106,19 @@ test_expect_success 'git diff HEAD with
 	expect_from_to >expect.body $subprev $subprev-dirty &&
 	test_cmp expect.body actual.body &&
 	git diff --ignore-submodules HEAD >actual2 &&
-	! test -s actual2 &&
+	test_must_be_empty actual2 &&
 	git diff --ignore-submodules=untracked HEAD >actual3 &&
 	sed -e "1,/^@@/d" actual3 >actual3.body &&
 	expect_from_to >expect.body $subprev $subprev-dirty &&
 	test_cmp expect.body actual3.body &&
 	git diff --ignore-submodules=dirty HEAD >actual4 &&
-	! test -s actual4
+	test_must_be_empty actual4
 '
 
 test_expect_success 'git diff HEAD with dirty submodule (work tree, refs match) [.gitmodules]' '
 	git config diff.ignoreSubmodules dirty &&
 	git diff HEAD >actual &&
-	! test -s actual &&
+	test_must_be_empty actual &&
 	git config --add -f .gitmodules submodule.subname.ignore none &&
 	git config --add -f .gitmodules submodule.subname.path sub &&
 	git diff HEAD >actual &&
@@ -126,7 +128,7 @@ test_expect_success 'git diff HEAD with
 	git config -f .gitmodules submodule.subname.ignore all &&
 	git config -f .gitmodules submodule.subname.path sub &&
 	git diff HEAD >actual2 &&
-	! test -s actual2 &&
+	test_must_be_empty actual2 &&
 	git config -f .gitmodules submodule.subname.ignore untracked &&
 	git diff HEAD >actual3 &&
 	sed -e "1,/^@@/d" actual3 >actual3.body &&
@@ -134,7 +136,7 @@ test_expect_success 'git diff HEAD with
 	test_cmp expect.body actual3.body &&
 	git config -f .gitmodules submodule.subname.ignore dirty &&
 	git diff HEAD >actual4 &&
-	! test -s actual4 &&
+	test_must_be_empty actual4 &&
 	git config submodule.subname.ignore none &&
 	git config submodule.subname.path sub &&
 	git diff HEAD >actual &&
@@ -172,24 +174,24 @@ test_expect_success 'git diff HEAD with
 	expect_from_to >expect.body $subprev $subprev-dirty &&
 	test_cmp expect.body actual.body &&
 	git diff --ignore-submodules=all HEAD >actual2 &&
-	! test -s actual2 &&
+	test_must_be_empty actual2 &&
 	git diff --ignore-submodules=untracked HEAD >actual3 &&
-	! test -s actual3 &&
+	test_must_be_empty actual3 &&
 	git diff --ignore-submodules=dirty HEAD >actual4 &&
-	! test -s actual4
+	test_must_be_empty actual4
 '
 
 test_expect_success 'git diff HEAD with dirty submodule (untracked, refs match) [.gitmodules]' '
 	git config --add -f .gitmodules submodule.subname.ignore all &&
 	git config --add -f .gitmodules submodule.subname.path sub &&
 	git diff HEAD >actual2 &&
-	! test -s actual2 &&
+	test_must_be_empty actual2 &&
 	git config -f .gitmodules submodule.subname.ignore untracked &&
 	git diff HEAD >actual3 &&
-	! test -s actual3 &&
+	test_must_be_empty actual3 &&
 	git config -f .gitmodules submodule.subname.ignore dirty &&
 	git diff HEAD >actual4 &&
-	! test -s actual4 &&
+	test_must_be_empty actual4 &&
 	git config submodule.subname.ignore none &&
 	git config submodule.subname.path sub &&
 	git diff HEAD >actual &&
@@ -211,7 +213,7 @@ test_expect_success 'git diff between su
 	expect_from_to >expect.body $subtip $subprev &&
 	test_cmp expect.body actual.body &&
 	git diff --ignore-submodules HEAD^..HEAD >actual &&
-	! test -s actual
+	test_must_be_empty actual
 '
 
 test_expect_success 'git diff between submodule commits [.gitmodules]' '
@@ -227,7 +229,7 @@ test_expect_success 'git diff between su
 	test_cmp expect.body actual.body &&
 	git config -f .gitmodules submodule.subname.ignore all &&
 	git diff HEAD^..HEAD >actual &&
-	! test -s actual &&
+	test_must_be_empty actual &&
 	git config submodule.subname.ignore dirty &&
 	git config submodule.subname.path sub &&
 	git diff  HEAD^..HEAD >actual &&
@@ -239,30 +241,27 @@ test_expect_success 'git diff between su
 '
 
 test_expect_success 'git diff (empty submodule dir)' '
-	: >empty &&
 	rm -rf sub/* sub/.git &&
 	git diff > actual.empty &&
-	test_cmp empty actual.empty
+	test_must_be_empty actual.empty
 '
 
 test_expect_success 'conflicted submodule setup' '
-
-	# 39 efs
-	c=fffffffffffffffffffffffffffffffffffffff &&
+	c=$(test_oid ff_1) &&
 	(
 		echo "000000 $ZERO_OID 0	sub" &&
 		echo "160000 1$c 1	sub" &&
 		echo "160000 2$c 2	sub" &&
 		echo "160000 3$c 3	sub"
 	) | git update-index --index-info &&
-	echo >expect.nosub '\''diff --cc sub
+	echo >expect.nosub "diff --cc sub
 index 2ffffff,3ffffff..0000000
 --- a/sub
 +++ b/sub
 @@@ -1,1 -1,1 +1,1 @@@
-- Subproject commit 2fffffffffffffffffffffffffffffffffffffff
- -Subproject commit 3fffffffffffffffffffffffffffffffffffffff
-++Subproject commit 0000000000000000000000000000000000000000'\'' &&
+- Subproject commit 2$c
+ -Subproject commit 3$c
+++Subproject commit $ZERO_OID" &&
 
 	hh=$(git rev-parse HEAD) &&
 	sed -e "s/$ZERO_OID/$hh/" expect.nosub >expect.withsub
diff -pruN 1.2.1+git2.18.0-1/git/t/t4034/dts/expect 1.2.3+git2.25.1-1/git/t/t4034/dts/expect
--- 1.2.1+git2.18.0-1/git/t/t4034/dts/expect	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t4034/dts/expect	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,37 @@
+<BOLD>diff --git a/pre b/post<RESET>
+<BOLD>index b6a9051..7803aee 100644<RESET>
+<BOLD>--- a/pre<RESET>
+<BOLD>+++ b/post<RESET>
+<CYAN>@@ -1,32 +1,32 @@<RESET>
+/ {<RESET>
+	<RED>this_handle<RESET><GREEN>HANDLE_2<RESET>: <RED>node<RESET><GREEN>new-node<RESET>@<RED>f00<RESET><GREEN>eeda<RESET> {
+		compatible = "<RED>mydev<RESET><GREEN>vendor,compat<RESET>";
+		string-prop = <RED>start<RESET><GREEN>end<RESET>: "hello <RED>world!<RESET><GREEN>world?<RESET>" <RED>end<RESET><GREEN>start<RESET>: ;
+		<RED>#size-cells<RESET><GREEN>#address-cells<RESET> = <<RED>0+0<RESET><GREEN>0+40<RESET>>;
+		reg = <<RED>0xf00<RESET><GREEN>0xeeda<RESET>>;
+		prop = <<GREEN>(<RESET>1<GREEN>)<RESET>>;
+		prop = <<GREEN>(<RESET>-1e10<GREEN>)<RESET>>;
+		prop = <(!<RED>3<RESET><GREEN>1<RESET>)>;
+		prop = <(~<RED>3<RESET><GREEN>1<RESET>)>;
+		prop = <(<RED>3<RESET><GREEN>1<RESET>*<RED>4<RESET><GREEN>2<RESET>)>;
+		prop = <(<RED>3<RESET><GREEN>1<RESET>&<RED>4<RESET><GREEN>2<RESET>)>;
+		prop = <(<RED>3<RESET><GREEN>1<RESET>*<RED>4<RESET><GREEN>2<RESET>)>;
+		prop = <(<RED>3<RESET><GREEN>1<RESET>/<RED>4<RESET><GREEN>2<RESET>)>;
+		prop = <(<RED>3<RESET><GREEN>1<RESET>%<RED>4<RESET><GREEN>2<RESET>)>;
+		prop = <(<RED>3+4<RESET><GREEN>1+2<RESET>)>;
+		prop = <(<RED>3-4<RESET><GREEN>1-2<RESET>)>;
+		prop = /bits/ <RED>64<RESET><GREEN>32<RESET> <(<RED>3<RESET><GREEN>1<RESET><<<RED>4<RESET><GREEN>2<RESET>)>;
+		prop = <(<RED>3<RESET><GREEN>1<RESET>>><RED>4<RESET><GREEN>2<RESET>)>;
+		prop = <(<RED>3<RESET><GREEN>1<RESET>&<RED>4<RESET><GREEN>2<RESET>)>;
+		prop = <(<RED>3<RESET><GREEN>1<RESET>^<RED>4<RESET><GREEN>2<RESET>)>;
+		prop = <(<RED>3<RESET><GREEN>1<RESET>|<RED>4<RESET><GREEN>2<RESET>)>;
+		prop = <(<RED>3<RESET><GREEN>1<RESET>&&<RED>4<RESET><GREEN>2<RESET>)>;
+		prop = <(<RED>3<RESET><GREEN>1<RESET>||<RED>4<RESET><GREEN>2<RESET>)>;
+		prop = <(<RED>4?5<RESET><GREEN>1?2<RESET>:3)>;
+		list = <&<RED>this_handle<RESET><GREEN>HANDLE_2<RESET>>, <0 0 0 <RED>0<RESET><GREEN>1<RESET>>;
+	};<RESET>
+
+	&<RED>phandle<RESET><GREEN>phandle2<RESET> {
+		<RED>pre-phandle<RESET><GREEN>prop_handle<RESET> = <&<RED>this_handle<RESET><GREEN>HANDLE_2<RESET>>;
+	};<RESET>
+};<RESET>
diff -pruN 1.2.1+git2.18.0-1/git/t/t4034/dts/post 1.2.3+git2.25.1-1/git/t/t4034/dts/post
--- 1.2.1+git2.18.0-1/git/t/t4034/dts/post	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t4034/dts/post	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,32 @@
+/ {
+	HANDLE_2: new-node@eeda {
+		compatible = "vendor,compat";
+		string-prop = end: "hello world?" start: ;
+		#address-cells = <0+40>;
+		reg = <0xeeda>;
+		prop = <(1)>;
+		prop = <(-1e10)>;
+		prop = <(!1)>;
+		prop = <(~1)>;
+		prop = <(1*2)>;
+		prop = <(1&2)>;
+		prop = <(1*2)>;
+		prop = <(1/2)>;
+		prop = <(1%2)>;
+		prop = <(1+2)>;
+		prop = <(1-2)>;
+		prop = /bits/ 32 <(1<<2)>;
+		prop = <(1>>2)>;
+		prop = <(1&2)>;
+		prop = <(1^2)>;
+		prop = <(1|2)>;
+		prop = <(1&&2)>;
+		prop = <(1||2)>;
+		prop = <(1?2:3)>;
+		list = <&HANDLE_2>, <0 0 0 1>;
+	};
+
+	&phandle2 {
+		prop_handle = <&HANDLE_2>;
+	};
+};
diff -pruN 1.2.1+git2.18.0-1/git/t/t4034/dts/pre 1.2.3+git2.25.1-1/git/t/t4034/dts/pre
--- 1.2.1+git2.18.0-1/git/t/t4034/dts/pre	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t4034/dts/pre	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,32 @@
+/ {
+	this_handle: node@f00 {
+		compatible = "mydev";
+		string-prop = start: "hello world!" end: ;
+		#size-cells = <0+0>;
+		reg = <0xf00>;
+		prop = <1>;
+		prop = <-1e10>;
+		prop = <(!3)>;
+		prop = <(~3)>;
+		prop = <(3*4)>;
+		prop = <(3&4)>;
+		prop = <(3*4)>;
+		prop = <(3/4)>;
+		prop = <(3%4)>;
+		prop = <(3+4)>;
+		prop = <(3-4)>;
+		prop = /bits/ 64 <(3<<4)>;
+		prop = <(3>>4)>;
+		prop = <(3&4)>;
+		prop = <(3^4)>;
+		prop = <(3|4)>;
+		prop = <(3&&4)>;
+		prop = <(3||4)>;
+		prop = <(4?5:3)>;
+		list = <&this_handle>, <0 0 0 0>;
+	};
+
+	&phandle {
+		pre-phandle = <&this_handle>;
+	};
+};
diff -pruN 1.2.1+git2.18.0-1/git/t/t4034-diff-words.sh 1.2.3+git2.25.1-1/git/t/t4034-diff-words.sh
--- 1.2.1+git2.18.0-1/git/t/t4034-diff-words.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t4034-diff-words.sh	2020-02-17 04:47:35.000000000 +0000
@@ -19,9 +19,11 @@ cat >post.simple <<-\EOF
 
 	aeff = aeff * ( aaa )
 EOF
-cat >expect.letter-runs-are-words <<-\EOF
+pre=$(git rev-parse --short $(git hash-object pre.simple))
+post=$(git rev-parse --short $(git hash-object post.simple))
+cat >expect.letter-runs-are-words <<-EOF
 	<BOLD>diff --git a/pre b/post<RESET>
-	<BOLD>index 330b04f..5ed8eff 100644<RESET>
+	<BOLD>index $pre..$post 100644<RESET>
 	<BOLD>--- a/pre<RESET>
 	<BOLD>+++ b/post<RESET>
 	<CYAN>@@ -1,3 +1,7 @@<RESET>
@@ -33,9 +35,9 @@ cat >expect.letter-runs-are-words <<-\EO
 
 	<GREEN>aeff = aeff * ( aaa<RESET> )
 EOF
-cat >expect.non-whitespace-is-word <<-\EOF
+cat >expect.non-whitespace-is-word <<-EOF
 	<BOLD>diff --git a/pre b/post<RESET>
-	<BOLD>index 330b04f..5ed8eff 100644<RESET>
+	<BOLD>index $pre..$post 100644<RESET>
 	<BOLD>--- a/pre<RESET>
 	<BOLD>+++ b/post<RESET>
 	<CYAN>@@ -1,3 +1,7 @@<RESET>
@@ -49,9 +51,12 @@ cat >expect.non-whitespace-is-word <<-\E
 EOF
 
 word_diff () {
+	pre=$(git rev-parse --short $(git hash-object pre)) &&
+	post=$(git rev-parse --short $(git hash-object post)) &&
 	test_must_fail git diff --no-index "$@" pre post >output &&
 	test_decode_color <output >output.decrypted &&
-	test_cmp expect output.decrypted
+	sed -e "2s/index [^ ]*/index $pre..$post/" expect >expected
+	test_cmp expected output.decrypted
 }
 
 test_language_driver () {
@@ -77,9 +82,9 @@ test_expect_success 'set up pre and post
 '
 
 test_expect_success 'word diff with runs of whitespace' '
-	cat >expect <<-\EOF &&
+	cat >expect <<-EOF &&
 		<BOLD>diff --git a/pre b/post<RESET>
-		<BOLD>index 330b04f..5ed8eff 100644<RESET>
+		<BOLD>index $pre..$post 100644<RESET>
 		<BOLD>--- a/pre<RESET>
 		<BOLD>+++ b/post<RESET>
 		<CYAN>@@ -1,3 +1,7 @@<RESET>
@@ -97,9 +102,9 @@ test_expect_success 'word diff with runs
 '
 
 test_expect_success '--word-diff=porcelain' '
-	sed 's/#.*$//' >expect <<-\EOF &&
+	sed 's/#.*$//' >expect <<-EOF &&
 		diff --git a/pre b/post
-		index 330b04f..5ed8eff 100644
+		index $pre..$post 100644
 		--- a/pre
 		+++ b/post
 		@@ -1,3 +1,7 @@
@@ -121,9 +126,9 @@ test_expect_success '--word-diff=porcela
 '
 
 test_expect_success '--word-diff=plain' '
-	cat >expect <<-\EOF &&
+	cat >expect <<-EOF &&
 		diff --git a/pre b/post
-		index 330b04f..5ed8eff 100644
+		index $pre..$post 100644
 		--- a/pre
 		+++ b/post
 		@@ -1,3 +1,7 @@
@@ -140,9 +145,9 @@ test_expect_success '--word-diff=plain'
 '
 
 test_expect_success '--word-diff=plain --color' '
-	cat >expect <<-\EOF &&
+	cat >expect <<-EOF &&
 		<BOLD>diff --git a/pre b/post<RESET>
-		<BOLD>index 330b04f..5ed8eff 100644<RESET>
+		<BOLD>index $pre..$post 100644<RESET>
 		<BOLD>--- a/pre<RESET>
 		<BOLD>+++ b/post<RESET>
 		<CYAN>@@ -1,3 +1,7 @@<RESET>
@@ -158,9 +163,9 @@ test_expect_success '--word-diff=plain -
 '
 
 test_expect_success 'word diff without context' '
-	cat >expect <<-\EOF &&
+	cat >expect <<-EOF &&
 		<BOLD>diff --git a/pre b/post<RESET>
-		<BOLD>index 330b04f..5ed8eff 100644<RESET>
+		<BOLD>index $pre..$post 100644<RESET>
 		<BOLD>--- a/pre<RESET>
 		<BOLD>+++ b/post<RESET>
 		<CYAN>@@ -1 +1 @@<RESET>
@@ -207,9 +212,9 @@ test_expect_success 'command-line overri
 '
 
 test_expect_success 'command-line overrides config: --word-diff-regex' '
-	cat >expect <<-\EOF &&
+	cat >expect <<-EOF &&
 		<BOLD>diff --git a/pre b/post<RESET>
-		<BOLD>index 330b04f..5ed8eff 100644<RESET>
+		<BOLD>index $pre..$post 100644<RESET>
 		<BOLD>--- a/pre<RESET>
 		<BOLD>+++ b/post<RESET>
 		<CYAN>@@ -1,3 +1,7 @@<RESET>
@@ -234,9 +239,9 @@ test_expect_success 'setup: remove diff
 '
 
 test_expect_success 'use configured regex' '
-	cat >expect <<-\EOF &&
+	cat >expect <<-EOF &&
 		<BOLD>diff --git a/pre b/post<RESET>
-		<BOLD>index 330b04f..5ed8eff 100644<RESET>
+		<BOLD>index $pre..$post 100644<RESET>
 		<BOLD>--- a/pre<RESET>
 		<BOLD>+++ b/post<RESET>
 		<CYAN>@@ -1,3 +1,7 @@<RESET>
@@ -254,9 +259,11 @@ test_expect_success 'use configured rege
 test_expect_success 'test parsing words for newline' '
 	echo "aaa (aaa)" >pre &&
 	echo "aaa (aaa) aaa" >post &&
-	cat >expect <<-\EOF &&
+	pre=$(git rev-parse --short $(git hash-object pre)) &&
+	post=$(git rev-parse --short $(git hash-object post)) &&
+	cat >expect <<-EOF &&
 		<BOLD>diff --git a/pre b/post<RESET>
-		<BOLD>index c29453b..be22f37 100644<RESET>
+		<BOLD>index $pre..$post 100644<RESET>
 		<BOLD>--- a/pre<RESET>
 		<BOLD>+++ b/post<RESET>
 		<CYAN>@@ -1 +1 @@<RESET>
@@ -268,9 +275,11 @@ test_expect_success 'test parsing words
 test_expect_success 'test when words are only removed at the end' '
 	echo "(:" >pre &&
 	echo "(" >post &&
-	cat >expect <<-\EOF &&
+	pre=$(git rev-parse --short $(git hash-object pre)) &&
+	post=$(git rev-parse --short $(git hash-object post)) &&
+	cat >expect <<-EOF &&
 		<BOLD>diff --git a/pre b/post<RESET>
-		<BOLD>index 289cb9d..2d06f37 100644<RESET>
+		<BOLD>index $pre..$post 100644<RESET>
 		<BOLD>--- a/pre<RESET>
 		<BOLD>+++ b/post<RESET>
 		<CYAN>@@ -1 +1 @@<RESET>
@@ -282,9 +291,11 @@ test_expect_success 'test when words are
 test_expect_success '--word-diff=none' '
 	echo "(:" >pre &&
 	echo "(" >post &&
-	cat >expect <<-\EOF &&
+	pre=$(git rev-parse --short $(git hash-object pre)) &&
+	post=$(git rev-parse --short $(git hash-object post)) &&
+	cat >expect <<-EOF &&
 		diff --git a/pre b/post
-		index 289cb9d..2d06f37 100644
+		index $pre..$post 100644
 		--- a/pre
 		+++ b/post
 		@@ -1 +1 @@
@@ -303,6 +314,7 @@ test_language_driver bibtex
 test_language_driver cpp
 test_language_driver csharp
 test_language_driver css
+test_language_driver dts
 test_language_driver fortran
 test_language_driver html
 test_language_driver java
@@ -316,16 +328,6 @@ test_language_driver ruby
 test_language_driver tex
 
 test_expect_success 'word-diff with diff.sbe' '
-	cat >expect <<-\EOF &&
-	diff --git a/pre b/post
-	index a1a53b5..bc8fe6d 100644
-	--- a/pre
-	+++ b/post
-	@@ -1,3 +1,3 @@
-	a
-
-	[-b-]{+c+}
-	EOF
 	cat >pre <<-\EOF &&
 	a
 
@@ -336,21 +338,35 @@ test_expect_success 'word-diff with diff
 
 	c
 	EOF
+	pre=$(git rev-parse --short $(git hash-object pre)) &&
+	post=$(git rev-parse --short $(git hash-object post)) &&
+	cat >expect <<-EOF &&
+	diff --git a/pre b/post
+	index $pre..$post 100644
+	--- a/pre
+	+++ b/post
+	@@ -1,3 +1,3 @@
+	a
+
+	[-b-]{+c+}
+	EOF
 	test_config diff.suppress-blank-empty true &&
 	word_diff --word-diff=plain
 '
 
 test_expect_success 'word-diff with no newline at EOF' '
-	cat >expect <<-\EOF &&
+	printf "%s" "a a a a a" >pre &&
+	printf "%s" "a a ab a a" >post &&
+	pre=$(git rev-parse --short $(git hash-object pre)) &&
+	post=$(git rev-parse --short $(git hash-object post)) &&
+	cat >expect <<-EOF &&
 	diff --git a/pre b/post
-	index 7bf316e..3dd0303 100644
+	index $pre..$post 100644
 	--- a/pre
 	+++ b/post
 	@@ -1 +1 @@
 	a a [-a-]{+ab+} a a
 	EOF
-	printf "%s" "a a a a a" >pre &&
-	printf "%s" "a a ab a a" >post &&
 	word_diff --word-diff=plain
 '
 
diff -pruN 1.2.1+git2.18.0-1/git/t/t4038-diff-combined.sh 1.2.3+git2.25.1-1/git/t/t4038-diff-combined.sh
--- 1.2.1+git2.18.0-1/git/t/t4038-diff-combined.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t4038-diff-combined.sh	2020-02-17 04:47:35.000000000 +0000
@@ -354,7 +354,7 @@ test_expect_failure 'combine diff coales
 '
 
 # Test for a bug reported at
-# https://public-inbox.org/git/20130515143508.GO25742@login.drsnuggles.stderr.nl/
+# https://lore.kernel.org/git/20130515143508.GO25742@login.drsnuggles.stderr.nl/
 # where a delete lines were missing from combined diff output when they
 # occurred exactly before the context lines of a later change.
 test_expect_success 'combine diff missing delete bug' '
@@ -435,4 +435,99 @@ test_expect_success 'combine diff gets t
 	test_cmp expect actual
 '
 
+test_expect_success 'setup for --combined-all-paths' '
+	git branch side1c &&
+	git branch side2c &&
+	git checkout side1c &&
+	test_seq 1 10 >filename-side1c &&
+	side1cf=$(git hash-object filename-side1c) &&
+	git add filename-side1c &&
+	git commit -m with &&
+	git checkout side2c &&
+	test_seq 1 9 >filename-side2c &&
+	echo ten >>filename-side2c &&
+	side2cf=$(git hash-object filename-side2c) &&
+	git add filename-side2c &&
+	git commit -m iam &&
+	git checkout -b mergery side1c &&
+	git merge --no-commit side2c &&
+	git rm filename-side1c &&
+	echo eleven >>filename-side2c &&
+	git mv filename-side2c filename-merged &&
+	mergedf=$(git hash-object filename-merged) &&
+	git add filename-merged &&
+	git commit
+'
+
+test_expect_success '--combined-all-paths and --raw' '
+	cat <<-EOF >expect &&
+	::100644 100644 100644 $side1cf $side2cf $mergedf RR	filename-side1c	filename-side2c	filename-merged
+	EOF
+	git diff-tree -c -M --raw --combined-all-paths HEAD >actual.tmp &&
+	sed 1d <actual.tmp >actual &&
+	test_cmp expect actual
+'
+
+test_expect_success '--combined-all-paths and --cc' '
+	cat <<-\EOF >expect &&
+	--- a/filename-side1c
+	--- a/filename-side2c
+	+++ b/filename-merged
+	EOF
+	git diff-tree --cc -M --combined-all-paths HEAD >actual.tmp &&
+	grep ^[-+][-+][-+] <actual.tmp >actual &&
+	test_cmp expect actual
+'
+
+test_expect_success FUNNYNAMES 'setup for --combined-all-paths with funny names' '
+	git branch side1d &&
+	git branch side2d &&
+	git checkout side1d &&
+	test_seq 1 10 >"$(printf "file\twith\ttabs")" &&
+	git add file* &&
+	side1df=$(git hash-object *tabs) &&
+	git commit -m with &&
+	git checkout side2d &&
+	test_seq 1 9 >"$(printf "i\tam\ttabbed")" &&
+	echo ten >>"$(printf "i\tam\ttabbed")" &&
+	git add *tabbed &&
+	side2df=$(git hash-object *tabbed) &&
+	git commit -m iam &&
+	git checkout -b funny-names-mergery side1d &&
+	git merge --no-commit side2d &&
+	git rm *tabs &&
+	echo eleven >>"$(printf "i\tam\ttabbed")" &&
+	git mv "$(printf "i\tam\ttabbed")" "$(printf "fickle\tnaming")" &&
+	git add fickle* &&
+	headf=$(git hash-object fickle*) &&
+	git commit &&
+	head=$(git rev-parse HEAD)
+'
+
+test_expect_success FUNNYNAMES '--combined-all-paths and --raw and funny names' '
+	cat <<-EOF >expect &&
+	::100644 100644 100644 $side1df $side2df $headf RR	"file\twith\ttabs"	"i\tam\ttabbed"	"fickle\tnaming"
+	EOF
+	git diff-tree -c -M --raw --combined-all-paths HEAD >actual.tmp &&
+	sed 1d <actual.tmp >actual &&
+	test_cmp expect actual
+'
+
+test_expect_success FUNNYNAMES '--combined-all-paths and --raw -and -z and funny names' '
+	printf "$head\0::100644 100644 100644 $side1df $side2df $headf RR\0file\twith\ttabs\0i\tam\ttabbed\0fickle\tnaming\0" >expect &&
+	git diff-tree -c -M --raw --combined-all-paths -z HEAD >actual &&
+	test_cmp expect actual
+'
+
+test_expect_success FUNNYNAMES '--combined-all-paths and --cc and funny names' '
+	cat <<-\EOF >expect &&
+	--- "a/file\twith\ttabs"
+	--- "a/i\tam\ttabbed"
+	+++ "b/fickle\tnaming"
+	EOF
+	git diff-tree --cc -M --combined-all-paths HEAD >actual.tmp &&
+	grep ^[-+][-+][-+] <actual.tmp >actual &&
+	test_cmp expect actual
+'
+
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t4039-diff-assume-unchanged.sh 1.2.3+git2.25.1-1/git/t/t4039-diff-assume-unchanged.sh
--- 1.2.1+git2.18.0-1/git/t/t4039-diff-assume-unchanged.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t4039-diff-assume-unchanged.sh	2020-02-17 04:47:35.000000000 +0000
@@ -12,6 +12,7 @@ test_expect_success 'setup' '
 	git commit -m zero &&
 	echo one > one &&
 	echo two > two &&
+	blob=$(git hash-object one) &&
 	git add one two &&
 	git commit -m onetwo &&
 	git update-index --assume-unchanged one &&
@@ -20,7 +21,7 @@ test_expect_success 'setup' '
 '
 
 test_expect_success 'diff-index does not examine assume-unchanged entries' '
-	git diff-index HEAD^ -- one | grep -q 5626abf0f72e58d7a153368ba57db4c673c0e171
+	git diff-index HEAD^ -- one | grep -q $blob
 '
 
 test_expect_success 'diff-files does not examine assume-unchanged entries' '
@@ -34,9 +35,8 @@ test_expect_success POSIXPERM 'find-copi
 	git add exec &&
 	git commit -m exec &&
 	git update-index --assume-unchanged exec &&
-	>expect &&
 	git diff-files --find-copies-harder -- exec >actual &&
-	test_cmp expect actual
+	test_must_be_empty actual
 '
 
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t4041-diff-submodule-option.sh 1.2.3+git2.25.1-1/git/t/t4041-diff-submodule-option.sh
--- 1.2.1+git2.18.0-1/git/t/t4041-diff-submodule-option.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t4041-diff-submodule-option.sh	2020-02-17 04:47:35.000000000 +0000
@@ -257,9 +257,7 @@ test_expect_success 'typechanged submodu
 commit_file sm1 &&
 test_expect_success 'submodule is up to date' '
 	git diff-index -p --submodule=log HEAD >actual &&
-	cat >expected <<-EOF &&
-	EOF
-	test_cmp expected actual
+	test_must_be_empty actual
 '
 
 test_expect_success 'submodule contains untracked content' '
@@ -273,20 +271,20 @@ test_expect_success 'submodule contains
 
 test_expect_success 'submodule contains untracked content (untracked ignored)' '
 	git diff-index -p --ignore-submodules=untracked --submodule=log HEAD >actual &&
-	! test -s actual
+	test_must_be_empty actual
 '
 
 test_expect_success 'submodule contains untracked content (dirty ignored)' '
 	git diff-index -p --ignore-submodules=dirty --submodule=log HEAD >actual &&
-	! test -s actual
+	test_must_be_empty actual
 '
 
 test_expect_success 'submodule contains untracked content (all ignored)' '
 	git diff-index -p --ignore-submodules=all --submodule=log HEAD >actual &&
-	! test -s actual
+	test_must_be_empty actual
 '
 
-test_expect_success 'submodule contains untracked and modifed content' '
+test_expect_success 'submodule contains untracked and modified content' '
 	echo new > sm1/foo6 &&
 	git diff-index -p --submodule=log HEAD >actual &&
 	cat >expected <<-EOF &&
@@ -296,7 +294,7 @@ test_expect_success 'submodule contains
 	test_cmp expected actual
 '
 
-test_expect_success 'submodule contains untracked and modifed content (untracked ignored)' '
+test_expect_success 'submodule contains untracked and modified content (untracked ignored)' '
 	echo new > sm1/foo6 &&
 	git diff-index -p --ignore-submodules=untracked --submodule=log HEAD >actual &&
 	cat >expected <<-EOF &&
@@ -305,19 +303,19 @@ test_expect_success 'submodule contains
 	test_cmp expected actual
 '
 
-test_expect_success 'submodule contains untracked and modifed content (dirty ignored)' '
+test_expect_success 'submodule contains untracked and modified content (dirty ignored)' '
 	echo new > sm1/foo6 &&
 	git diff-index -p --ignore-submodules=dirty --submodule=log HEAD >actual &&
-	! test -s actual
+	test_must_be_empty actual
 '
 
-test_expect_success 'submodule contains untracked and modifed content (all ignored)' '
+test_expect_success 'submodule contains untracked and modified content (all ignored)' '
 	echo new > sm1/foo6 &&
 	git diff-index -p --ignore-submodules --submodule=log HEAD >actual &&
-	! test -s actual
+	test_must_be_empty actual
 '
 
-test_expect_success 'submodule contains modifed content' '
+test_expect_success 'submodule contains modified content' '
 	rm -f sm1/new-file &&
 	git diff-index -p --submodule=log HEAD >actual &&
 	cat >expected <<-EOF &&
@@ -368,10 +366,10 @@ test_expect_success 'modified submodule
 
 test_expect_success 'modified submodule contains untracked content (all ignored)' '
 	git diff-index -p --ignore-submodules=all --submodule=log HEAD >actual &&
-	! test -s actual
+	test_must_be_empty actual
 '
 
-test_expect_success 'modified submodule contains untracked and modifed content' '
+test_expect_success 'modified submodule contains untracked and modified content' '
 	echo modification >> sm1/foo6 &&
 	git diff-index -p --submodule=log HEAD >actual &&
 	cat >expected <<-EOF &&
@@ -383,7 +381,7 @@ test_expect_success 'modified submodule
 	test_cmp expected actual
 '
 
-test_expect_success 'modified submodule contains untracked and modifed content (untracked ignored)' '
+test_expect_success 'modified submodule contains untracked and modified content (untracked ignored)' '
 	echo modification >> sm1/foo6 &&
 	git diff-index -p --ignore-submodules=untracked --submodule=log HEAD >actual &&
 	cat >expected <<-EOF &&
@@ -394,7 +392,7 @@ test_expect_success 'modified submodule
 	test_cmp expected actual
 '
 
-test_expect_success 'modified submodule contains untracked and modifed content (dirty ignored)' '
+test_expect_success 'modified submodule contains untracked and modified content (dirty ignored)' '
 	echo modification >> sm1/foo6 &&
 	git diff-index -p --ignore-submodules=dirty --submodule=log HEAD >actual &&
 	cat >expected <<-EOF &&
@@ -404,13 +402,13 @@ test_expect_success 'modified submodule
 	test_cmp expected actual
 '
 
-test_expect_success 'modified submodule contains untracked and modifed content (all ignored)' '
+test_expect_success 'modified submodule contains untracked and modified content (all ignored)' '
 	echo modification >> sm1/foo6 &&
 	git diff-index -p --ignore-submodules --submodule=log HEAD >actual &&
-	! test -s actual
+	test_must_be_empty actual
 '
 
-test_expect_success 'modified submodule contains modifed content' '
+test_expect_success 'modified submodule contains modified content' '
 	rm -f sm1/new-file &&
 	git diff-index -p --submodule=log HEAD >actual &&
 	cat >expected <<-EOF &&
@@ -498,7 +496,7 @@ test_expect_success 'given commit --subm
 test_expect_success 'setup .git file for sm2' '
 	(cd sm2 &&
 	 REAL="$(pwd)/../.real" &&
-	 mv .git "$REAL"
+	 mv .git "$REAL" &&
 	 echo "gitdir: $REAL" >.git)
 '
 
@@ -527,7 +525,7 @@ test_expect_success 'diff --submodule wi
 		git commit -m "sub a"
 	) &&
 	(cd sub_alt &&
-		sha1_before=$(git rev-parse --short HEAD)
+		sha1_before=$(git rev-parse --short HEAD) &&
 		echo b >b &&
 		git add b &&
 		git commit -m b &&
diff -pruN 1.2.1+git2.18.0-1/git/t/t4044-diff-index-unique-abbrev.sh 1.2.3+git2.25.1-1/git/t/t4044-diff-index-unique-abbrev.sh
--- 1.2.1+git2.18.0-1/git/t/t4044-diff-index-unique-abbrev.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t4044-diff-index-unique-abbrev.sh	2020-02-17 04:47:35.000000000 +0000
@@ -3,34 +3,48 @@
 test_description='test unique sha1 abbreviation on "index from..to" line'
 . ./test-lib.sh
 
-if ! test_have_prereq SHA1
-then
-       skip_all='not using SHA-1 for objects'
-       test_done
-fi
+test_expect_success 'setup' '
+	test_oid_cache <<-EOF &&
+	val1 sha1:4827
+	val1 sha256:5664
 
-cat >expect_initial <<EOF
-100644 blob 51d2738463ea4ca66f8691c91e33ce64b7d41bb1	foo
-EOF
+	val2 sha1:11742
+	val2 sha256:10625
 
-cat >expect_update <<EOF
-100644 blob 51d2738efb4ad8a1e40bed839ab8e116f0a15e47	foo
-EOF
+	hash1 sha1:51d2738463ea4ca66f8691c91e33ce64b7d41bb1
+	hash1 sha256:ae31dfff0af93b2c62b0098a039b38569c43b0a7e97b873000ca42d128f27350
 
-test_expect_success 'setup' '
-	echo 4827 > foo &&
+	hasht1 sha1:51d27384
+	hasht1 sha256:ae31dfff
+
+	hash2 sha1:51d2738efb4ad8a1e40bed839ab8e116f0a15e47
+	hash2 sha256:ae31dffada88a46fd5f53c7ed5aa25a7a8951f1d5e88456c317c8d5484d263e5
+
+	hasht2 sha1:51d2738e
+	hasht2 sha256:ae31dffa
+	EOF
+
+	cat >expect_initial <<-EOF &&
+	100644 blob $(test_oid hash1)	foo
+	EOF
+
+	cat >expect_update <<-EOF &&
+	100644 blob $(test_oid hash2)	foo
+	EOF
+
+	echo "$(test_oid val1)" > foo &&
 	git add foo &&
 	git commit -m "initial" &&
 	git cat-file -p HEAD: > actual &&
 	test_cmp expect_initial actual &&
-	echo 11742 > foo &&
+	echo "$(test_oid val2)" > foo &&
 	git commit -a -m "update" &&
 	git cat-file -p HEAD: > actual &&
 	test_cmp expect_update actual
 '
 
 cat >expect <<EOF
-index 51d27384..51d2738e 100644
+index $(test_oid hasht1)..$(test_oid hasht2) 100644
 EOF
 
 test_expect_success 'diff does not produce ambiguous index line' '
diff -pruN 1.2.1+git2.18.0-1/git/t/t4045-diff-relative.sh 1.2.3+git2.25.1-1/git/t/t4045-diff-relative.sh
--- 1.2.1+git2.18.0-1/git/t/t4045-diff-relative.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t4045-diff-relative.sh	2020-02-17 04:47:35.000000000 +0000
@@ -70,7 +70,7 @@ check_raw () {
 	expect=$1
 	shift
 	cat >expected <<-EOF
-	:000000 100644 0000000000000000000000000000000000000000 $blob A	$expect
+	:000000 100644 $ZERO_OID $blob A	$expect
 	EOF
 	test_expect_success "--raw $*" "
 		git -C '$dir' diff --no-abbrev --raw $* HEAD^ >actual &&
diff -pruN 1.2.1+git2.18.0-1/git/t/t4047-diff-dirstat.sh 1.2.3+git2.25.1-1/git/t/t4047-diff-dirstat.sh
--- 1.2.1+git2.18.0-1/git/t/t4047-diff-dirstat.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t4047-diff-dirstat.sh	2020-02-17 04:47:35.000000000 +0000
@@ -940,7 +940,7 @@ test_expect_success 'diff.dirstat=0,line
 test_expect_success '--dirstat=future_param,lines,0 should fail loudly' '
 	test_must_fail git diff --dirstat=future_param,lines,0 HEAD^..HEAD >actual_diff_dirstat 2>actual_error &&
 	test_debug "cat actual_error" &&
-	test_cmp /dev/null actual_diff_dirstat &&
+	test_must_be_empty actual_diff_dirstat &&
 	test_i18ngrep -q "future_param" actual_error &&
 	test_i18ngrep -q "\--dirstat" actual_error
 '
@@ -948,7 +948,7 @@ test_expect_success '--dirstat=future_pa
 test_expect_success '--dirstat=dummy1,cumulative,2dummy should report both unrecognized parameters' '
 	test_must_fail git diff --dirstat=dummy1,cumulative,2dummy HEAD^..HEAD >actual_diff_dirstat 2>actual_error &&
 	test_debug "cat actual_error" &&
-	test_cmp /dev/null actual_diff_dirstat &&
+	test_must_be_empty actual_diff_dirstat &&
 	test_i18ngrep -q "dummy1" actual_error &&
 	test_i18ngrep -q "2dummy" actual_error &&
 	test_i18ngrep -q "\--dirstat" actual_error
diff -pruN 1.2.1+git2.18.0-1/git/t/t4048-diff-combined-binary.sh 1.2.3+git2.25.1-1/git/t/t4048-diff-combined-binary.sh
--- 1.2.1+git2.18.0-1/git/t/t4048-diff-combined-binary.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t4048-diff-combined-binary.sh	2020-02-17 04:47:35.000000000 +0000
@@ -9,24 +9,27 @@ test_expect_success 'setup binary merge
 	git commit -m one &&
 	echo twoQ2 | q_to_nul >binary &&
 	git commit -a -m two &&
+	two=$(git rev-parse --short HEAD:binary) &&
 	git checkout -b branch-binary HEAD^ &&
 	echo threeQ3 | q_to_nul >binary &&
 	git commit -a -m three &&
+	three=$(git rev-parse --short HEAD:binary) &&
 	test_must_fail git merge master &&
 	echo resolvedQhooray | q_to_nul >binary &&
-	git commit -a -m resolved
+	git commit -a -m resolved &&
+	res=$(git rev-parse --short HEAD:binary)
 '
 
-cat >expect <<'EOF'
+cat >expect <<EOF
 resolved
 
 diff --git a/binary b/binary
-index 7ea6ded..9563691 100644
+index $three..$res 100644
 Binary files a/binary and b/binary differ
 resolved
 
 diff --git a/binary b/binary
-index 6197570..9563691 100644
+index $two..$res 100644
 Binary files a/binary and b/binary differ
 EOF
 test_expect_success 'diff -m indicates binary-ness' '
@@ -34,11 +37,11 @@ test_expect_success 'diff -m indicates b
 	test_cmp expect actual
 '
 
-cat >expect <<'EOF'
+cat >expect <<EOF
 resolved
 
 diff --combined binary
-index 7ea6ded,6197570..9563691
+index $three,$two..$res
 Binary files differ
 EOF
 test_expect_success 'diff -c indicates binary-ness' '
@@ -46,11 +49,11 @@ test_expect_success 'diff -c indicates b
 	test_cmp expect actual
 '
 
-cat >expect <<'EOF'
+cat >expect <<EOF
 resolved
 
 diff --cc binary
-index 7ea6ded,6197570..9563691
+index $three,$two..$res
 Binary files differ
 EOF
 test_expect_success 'diff --cc indicates binary-ness' '
@@ -62,23 +65,26 @@ test_expect_success 'setup non-binary wi
 	git checkout master &&
 	test_commit one text &&
 	test_commit two text &&
+	two=$(git rev-parse --short HEAD:text) &&
 	git checkout -b branch-text HEAD^ &&
 	test_commit three text &&
+	three=$(git rev-parse --short HEAD:text) &&
 	test_must_fail git merge master &&
 	test_commit resolved text &&
+	res=$(git rev-parse --short HEAD:text) &&
 	echo text -diff >.gitattributes
 '
 
-cat >expect <<'EOF'
+cat >expect <<EOF
 resolved
 
 diff --git a/text b/text
-index 2bdf67a..2ab19ae 100644
+index $three..$res 100644
 Binary files a/text and b/text differ
 resolved
 
 diff --git a/text b/text
-index f719efd..2ab19ae 100644
+index $two..$res 100644
 Binary files a/text and b/text differ
 EOF
 test_expect_success 'diff -m respects binary attribute' '
@@ -86,11 +92,11 @@ test_expect_success 'diff -m respects bi
 	test_cmp expect actual
 '
 
-cat >expect <<'EOF'
+cat >expect <<EOF
 resolved
 
 diff --combined text
-index 2bdf67a,f719efd..2ab19ae
+index $three,$two..$res
 Binary files differ
 EOF
 test_expect_success 'diff -c respects binary attribute' '
@@ -98,11 +104,11 @@ test_expect_success 'diff -c respects bi
 	test_cmp expect actual
 '
 
-cat >expect <<'EOF'
+cat >expect <<EOF
 resolved
 
 diff --cc text
-index 2bdf67a,f719efd..2ab19ae
+index $three,$two..$res
 Binary files differ
 EOF
 test_expect_success 'diff --cc respects binary attribute' '
@@ -115,11 +121,11 @@ test_expect_success 'setup textconv attr
 	git config diff.upcase.textconv "tr a-z A-Z <"
 '
 
-cat >expect <<'EOF'
+cat >expect <<EOF
 resolved
 
 diff --git a/text b/text
-index 2bdf67a..2ab19ae 100644
+index $three..$res 100644
 --- a/text
 +++ b/text
 @@ -1 +1 @@
@@ -128,7 +134,7 @@ index 2bdf67a..2ab19ae 100644
 resolved
 
 diff --git a/text b/text
-index f719efd..2ab19ae 100644
+index $two..$res 100644
 --- a/text
 +++ b/text
 @@ -1 +1 @@
@@ -140,11 +146,11 @@ test_expect_success 'diff -m respects te
 	test_cmp expect actual
 '
 
-cat >expect <<'EOF'
+cat >expect <<EOF
 resolved
 
 diff --combined text
-index 2bdf67a,f719efd..2ab19ae
+index $three,$two..$res
 --- a/text
 +++ b/text
 @@@ -1,1 -1,1 +1,1 @@@
@@ -157,11 +163,11 @@ test_expect_success 'diff -c respects te
 	test_cmp expect actual
 '
 
-cat >expect <<'EOF'
+cat >expect <<EOF
 resolved
 
 diff --cc text
-index 2bdf67a,f719efd..2ab19ae
+index $three,$two..$res
 --- a/text
 +++ b/text
 @@@ -1,1 -1,1 +1,1 @@@
@@ -174,9 +180,9 @@ test_expect_success 'diff --cc respects
 	test_cmp expect actual
 '
 
-cat >expect <<'EOF'
+cat >expect <<EOF
 diff --combined text
-index 2bdf67a,f719efd..2ab19ae
+index $three,$two..$res
 --- a/text
 +++ b/text
 @@@ -1,1 -1,1 +1,1 @@@
@@ -190,9 +196,9 @@ test_expect_success 'diff-tree plumbing
 	test_cmp expect actual
 '
 
-cat >expect <<'EOF'
+cat >expect <<EOF
 diff --cc text
-index 2bdf67a,f719efd..0000000
+index $three,$two..0000000
 --- a/text
 +++ b/text
 @@@ -1,1 -1,1 +1,5 @@@
diff -pruN 1.2.1+git2.18.0-1/git/t/t4051-diff-function-context.sh 1.2.3+git2.25.1-1/git/t/t4051-diff-function-context.sh
--- 1.2.1+git2.18.0-1/git/t/t4051-diff-function-context.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t4051-diff-function-context.sh	2020-02-17 04:47:35.000000000 +0000
@@ -174,7 +174,7 @@ test_expect_success ' context does not i
 '
 
 test_expect_success ' context does not include preceding empty lines' '
-	test "$(first_context_line <long_common_tail.diff.diff)" != " "
+	test "$(first_context_line <long_common_tail.diff)" != " "
 '
 
 check_diff changed_hello_appended 'changed function plus appended function'
diff -pruN 1.2.1+git2.18.0-1/git/t/t4052-stat-output.sh 1.2.3+git2.25.1-1/git/t/t4052-stat-output.sh
--- 1.2.1+git2.18.0-1/git/t/t4052-stat-output.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t4052-stat-output.sh	2020-02-17 04:47:35.000000000 +0000
@@ -44,42 +44,50 @@ show --stat
 log -1 --stat
 EOF
 
-while read cmd args
+cat >expect.60 <<-'EOF'
+ ...aaaaaaaaaaaaaaaaaaaaaaaaaaaaa | 1 +
+EOF
+cat >expect.6030 <<-'EOF'
+ ...aaaaaaaaaaaaaaaaaaaaaaaaaaa | 1 +
+EOF
+cat >expect2.60 <<-'EOF'
+ ...aaaaaaaaaaaaaaaaaaaaaaaaaaaaa | 1 +
+ ...aaaaaaaaaaaaaaaaaaaaaaaaaaaaa | 1 +
+EOF
+cat >expect2.6030 <<-'EOF'
+ ...aaaaaaaaaaaaaaaaaaaaaaaaaaa | 1 +
+ ...aaaaaaaaaaaaaaaaaaaaaaaaaaa | 1 +
+EOF
+while read expect cmd args
 do
-	cat >expect <<-'EOF'
-	 ...aaaaaaaaaaaaaaaaaaaaaaaaaaaaa | 1 +
-	EOF
 	test_expect_success "$cmd --stat=width: a long name is given more room when the bar is short" '
 		git $cmd $args --stat=40 >output &&
 		grep " | " output >actual &&
-		test_cmp expect actual
+		test_cmp $expect.60 actual
 	'
 
 	test_expect_success "$cmd --stat-width=width with long name" '
 		git $cmd $args --stat-width=40 >output &&
 		grep " | " output >actual &&
-		test_cmp expect actual
+		test_cmp $expect.60 actual
 	'
 
-	cat >expect <<-'EOF'
-	 ...aaaaaaaaaaaaaaaaaaaaaaaaaaa | 1 +
-	EOF
 	test_expect_success "$cmd --stat=...,name-width with long name" '
 		git $cmd $args --stat=60,30 >output &&
 		grep " | " output >actual &&
-		test_cmp expect actual
+		test_cmp $expect.6030 actual
 	'
 
 	test_expect_success "$cmd --stat-name-width with long name" '
 		git $cmd $args --stat-name-width=30 >output &&
 		grep " | " output >actual &&
-		test_cmp expect actual
+		test_cmp $expect.6030 actual
 	'
 done <<\EOF
-format-patch -1 --stdout
-diff HEAD^ HEAD --stat
-show --stat
-log -1 --stat
+expect2 format-patch --cover-letter -1 --stdout
+expect diff HEAD^ HEAD --stat
+expect show --stat
+expect log -1 --stat
 EOF
 
 
@@ -96,6 +104,16 @@ test_expect_success 'preparation for big
 '
 
 cat >expect72 <<'EOF'
+ abcd | 1000 ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
+ abcd | 1000 ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
+EOF
+test_expect_success "format-patch --cover-letter ignores COLUMNS (big change)" '
+	COLUMNS=200 git format-patch -1 --stdout --cover-letter >output &&
+	grep " | " output >actual &&
+	test_cmp expect72 actual
+'
+
+cat >expect72 <<'EOF'
  abcd | 1000 ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
 EOF
 cat >expect72-graph <<'EOF'
diff -pruN 1.2.1+git2.18.0-1/git/t/t4053-diff-no-index.sh 1.2.3+git2.25.1-1/git/t/t4053-diff-no-index.sh
--- 1.2.1+git2.18.0-1/git/t/t4053-diff-no-index.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t4053-diff-no-index.sh	2020-02-17 04:47:35.000000000 +0000
@@ -50,8 +50,7 @@ test_expect_success 'git diff --no-index
 		export GIT_CEILING_DIRECTORIES &&
 		cd non/git &&
 		test_must_fail git diff --no-index a 2>actual.err &&
-		echo "usage: git diff --no-index <path> <path>" >expect.err &&
-		test_cmp expect.err actual.err
+		test_i18ngrep "usage: git diff --no-index" actual.err
 	)
 '
 
@@ -127,4 +126,22 @@ test_expect_success 'diff --no-index fro
 	test_cmp expect actual.head
 '
 
+test_expect_success 'diff --no-index from repo subdir with absolute paths' '
+	cat <<-EOF >expect &&
+	1	1	$(pwd)/non/git/{a => b}
+	EOF
+	test_expect_code 1 \
+		git -C repo/sub diff --numstat \
+		"$(pwd)/non/git/a" "$(pwd)/non/git/b" >actual &&
+	test_cmp expect actual
+'
+
+test_expect_success 'diff --no-index allows external diff' '
+	test_expect_code 1 \
+		env GIT_EXTERNAL_DIFF="echo external ;:" \
+		git diff --no-index non/git/a non/git/b >actual &&
+	echo external >expect &&
+	test_cmp expect actual
+'
+
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t4057-diff-combined-paths.sh 1.2.3+git2.25.1-1/git/t/t4057-diff-combined-paths.sh
--- 1.2.1+git2.18.0-1/git/t/t4057-diff-combined-paths.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t4057-diff-combined-paths.sh	2020-02-17 04:47:35.000000000 +0000
@@ -33,7 +33,7 @@ test_expect_success 'trivial merge - com
 '
 
 
-test_expect_success 'only one trully conflicting path' '
+test_expect_success 'only one truly conflicting path' '
 	git checkout side &&
 	for i in $(test_seq 2 9)
 	do
diff -pruN 1.2.1+git2.18.0-1/git/t/t4060-diff-submodule-option-diff-format.sh 1.2.3+git2.25.1-1/git/t/t4060-diff-submodule-option-diff-format.sh
--- 1.2.1+git2.18.0-1/git/t/t4060-diff-submodule-option-diff-format.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t4060-diff-submodule-option-diff-format.sh	2020-02-17 04:47:35.000000000 +0000
@@ -392,9 +392,7 @@ test_expect_success 'typechanged submodu
 commit_file sm1 &&
 test_expect_success 'submodule is up to date' '
 	git diff-index -p --submodule=diff HEAD >actual &&
-	cat >expected <<-EOF &&
-	EOF
-	test_cmp expected actual
+	test_must_be_empty actual
 '
 
 test_expect_success 'submodule contains untracked content' '
@@ -408,17 +406,17 @@ test_expect_success 'submodule contains
 
 test_expect_success 'submodule contains untracked content (untracked ignored)' '
 	git diff-index -p --ignore-submodules=untracked --submodule=diff HEAD >actual &&
-	! test -s actual
+	test_must_be_empty actual
 '
 
 test_expect_success 'submodule contains untracked content (dirty ignored)' '
 	git diff-index -p --ignore-submodules=dirty --submodule=diff HEAD >actual &&
-	! test -s actual
+	test_must_be_empty actual
 '
 
 test_expect_success 'submodule contains untracked content (all ignored)' '
 	git diff-index -p --ignore-submodules=all --submodule=diff HEAD >actual &&
-	! test -s actual
+	test_must_be_empty actual
 '
 
 test_expect_success 'submodule contains untracked and modified content' '
@@ -458,13 +456,13 @@ test_expect_success 'submodule contains
 test_expect_success 'submodule contains untracked and modified content (dirty ignored)' '
 	echo new > sm1/foo6 &&
 	git diff-index -p --ignore-submodules=dirty --submodule=diff HEAD >actual &&
-	! test -s actual
+	test_must_be_empty actual
 '
 
 test_expect_success 'submodule contains untracked and modified content (all ignored)' '
 	echo new > sm1/foo6 &&
 	git diff-index -p --ignore-submodules --submodule=diff HEAD >actual &&
-	! test -s actual
+	test_must_be_empty actual
 '
 
 test_expect_success 'submodule contains modified content' '
@@ -549,7 +547,7 @@ test_expect_success 'modified submodule
 
 test_expect_success 'modified submodule contains untracked content (all ignored)' '
 	git diff-index -p --ignore-submodules=all --submodule=diff HEAD >actual &&
-	! test -s actual
+	test_must_be_empty actual
 '
 
 test_expect_success 'modified submodule contains untracked and modified content' '
@@ -609,7 +607,7 @@ test_expect_success 'modified submodule
 test_expect_success 'modified submodule contains untracked and modified content (all ignored)' '
 	echo modification >> sm1/foo6 &&
 	git diff-index -p --ignore-submodules --submodule=diff HEAD >actual &&
-	! test -s actual
+	test_must_be_empty actual
 '
 
 # NOT OK
@@ -721,7 +719,7 @@ test_expect_success 'given commit' '
 test_expect_success 'setup .git file for sm2' '
 	(cd sm2 &&
 	 REAL="$(pwd)/../.real" &&
-	 mv .git "$REAL"
+	 mv .git "$REAL" &&
 	 echo "gitdir: $REAL" >.git)
 '
 
diff -pruN 1.2.1+git2.18.0-1/git/t/t4066-diff-emit-delay.sh 1.2.3+git2.25.1-1/git/t/t4066-diff-emit-delay.sh
--- 1.2.1+git2.18.0-1/git/t/t4066-diff-emit-delay.sh	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t4066-diff-emit-delay.sh	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,79 @@
+#!/bin/sh
+
+test_description='test combined/stat/moved interaction'
+. ./test-lib.sh
+
+# This test covers a weird 3-way interaction between "--cc -p", which will run
+# the combined diff code, along with "--stat", which will be computed as a
+# first-parent stat during the combined diff, and "--color-moved", which
+# enables the emitted_symbols list to store the diff in memory.
+
+test_expect_success 'set up history with a merge' '
+	test_commit A &&
+	test_commit B &&
+	git checkout -b side HEAD^ &&
+	test_commit C &&
+	git merge -m M master &&
+	test_commit D
+'
+
+test_expect_success 'log --cc -p --stat --color-moved' '
+	cat >expect <<-\EOF &&
+	commit D
+	---
+	 D.t | 1 +
+	 1 file changed, 1 insertion(+)
+
+	diff --git a/D.t b/D.t
+	new file mode 100644
+	index 0000000..1784810
+	--- /dev/null
+	+++ b/D.t
+	@@ -0,0 +1 @@
+	+D
+	commit M
+
+	 B.t | 1 +
+	 1 file changed, 1 insertion(+)
+	commit C
+	---
+	 C.t | 1 +
+	 1 file changed, 1 insertion(+)
+
+	diff --git a/C.t b/C.t
+	new file mode 100644
+	index 0000000..3cc58df
+	--- /dev/null
+	+++ b/C.t
+	@@ -0,0 +1 @@
+	+C
+	commit B
+	---
+	 B.t | 1 +
+	 1 file changed, 1 insertion(+)
+
+	diff --git a/B.t b/B.t
+	new file mode 100644
+	index 0000000..223b783
+	--- /dev/null
+	+++ b/B.t
+	@@ -0,0 +1 @@
+	+B
+	commit A
+	---
+	 A.t | 1 +
+	 1 file changed, 1 insertion(+)
+
+	diff --git a/A.t b/A.t
+	new file mode 100644
+	index 0000000..f70f10e
+	--- /dev/null
+	+++ b/A.t
+	@@ -0,0 +1 @@
+	+A
+	EOF
+	git log --format="commit %s" --cc -p --stat --color-moved >actual &&
+	test_cmp expect actual
+'
+
+test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t4067-diff-partial-clone.sh 1.2.3+git2.25.1-1/git/t/t4067-diff-partial-clone.sh
--- 1.2.1+git2.18.0-1/git/t/t4067-diff-partial-clone.sh	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t4067-diff-partial-clone.sh	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,134 @@
+#!/bin/sh
+
+test_description='behavior of diff when reading objects in a partial clone'
+
+. ./test-lib.sh
+
+test_expect_success 'git show batches blobs' '
+	test_when_finished "rm -rf server client trace" &&
+
+	test_create_repo server &&
+	echo a >server/a &&
+	echo b >server/b &&
+	git -C server add a b &&
+	git -C server commit -m x &&
+
+	test_config -C server uploadpack.allowfilter 1 &&
+	test_config -C server uploadpack.allowanysha1inwant 1 &&
+	git clone --bare --filter=blob:limit=0 "file://$(pwd)/server" client &&
+
+	# Ensure that there is exactly 1 negotiation by checking that there is
+	# only 1 "done" line sent. ("done" marks the end of negotiation.)
+	GIT_TRACE_PACKET="$(pwd)/trace" git -C client show HEAD &&
+	grep "git> done" trace >done_lines &&
+	test_line_count = 1 done_lines
+'
+
+test_expect_success 'diff batches blobs' '
+	test_when_finished "rm -rf server client trace" &&
+
+	test_create_repo server &&
+	echo a >server/a &&
+	echo b >server/b &&
+	git -C server add a b &&
+	git -C server commit -m x &&
+	echo c >server/c &&
+	echo d >server/d &&
+	git -C server add c d &&
+	git -C server commit -m x &&
+
+	test_config -C server uploadpack.allowfilter 1 &&
+	test_config -C server uploadpack.allowanysha1inwant 1 &&
+	git clone --bare --filter=blob:limit=0 "file://$(pwd)/server" client &&
+
+	# Ensure that there is exactly 1 negotiation by checking that there is
+	# only 1 "done" line sent. ("done" marks the end of negotiation.)
+	GIT_TRACE_PACKET="$(pwd)/trace" git -C client diff HEAD^ HEAD &&
+	grep "git> done" trace >done_lines &&
+	test_line_count = 1 done_lines
+'
+
+test_expect_success 'diff skips same-OID blobs' '
+	test_when_finished "rm -rf server client trace" &&
+
+	test_create_repo server &&
+	echo a >server/a &&
+	echo b >server/b &&
+	git -C server add a b &&
+	git -C server commit -m x &&
+	echo another-a >server/a &&
+	git -C server add a &&
+	git -C server commit -m x &&
+
+	test_config -C server uploadpack.allowfilter 1 &&
+	test_config -C server uploadpack.allowanysha1inwant 1 &&
+	git clone --bare --filter=blob:limit=0 "file://$(pwd)/server" client &&
+
+	echo a | git hash-object --stdin >hash-old-a &&
+	echo another-a | git hash-object --stdin >hash-new-a &&
+	echo b | git hash-object --stdin >hash-b &&
+
+	# Ensure that only a and another-a are fetched.
+	GIT_TRACE_PACKET="$(pwd)/trace" git -C client diff HEAD^ HEAD &&
+	grep "want $(cat hash-old-a)" trace &&
+	grep "want $(cat hash-new-a)" trace &&
+	! grep "want $(cat hash-b)" trace
+'
+
+test_expect_success 'when fetching missing objects, diff skips GITLINKs' '
+	test_when_finished "rm -rf sub server client trace" &&
+
+	test_create_repo sub &&
+	test_commit -C sub first &&
+
+	test_create_repo server &&
+	echo a >server/a &&
+	git -C server add a &&
+	git -C server submodule add "file://$(pwd)/sub" &&
+	git -C server commit -m x &&
+
+	test_commit -C server/sub second &&
+	echo another-a >server/a &&
+	git -C server add a sub &&
+	git -C server commit -m x &&
+
+	test_config -C server uploadpack.allowfilter 1 &&
+	test_config -C server uploadpack.allowanysha1inwant 1 &&
+	git clone --bare --filter=blob:limit=0 "file://$(pwd)/server" client &&
+
+	echo a | git hash-object --stdin >hash-old-a &&
+	echo another-a | git hash-object --stdin >hash-new-a &&
+
+	# Ensure that a and another-a are fetched, and check (by successful
+	# execution of the diff) that no invalid OIDs are sent.
+	GIT_TRACE_PACKET="$(pwd)/trace" git -C client diff HEAD^ HEAD &&
+	grep "want $(cat hash-old-a)" trace &&
+	grep "want $(cat hash-new-a)" trace
+'
+
+test_expect_success 'diff with rename detection batches blobs' '
+	test_when_finished "rm -rf server client trace" &&
+
+	test_create_repo server &&
+	echo a >server/a &&
+	printf "b\nb\nb\nb\nb\n" >server/b &&
+	git -C server add a b &&
+	git -C server commit -m x &&
+	rm server/b &&
+	printf "b\nb\nb\nb\nbX\n" >server/c &&
+	git -C server add c &&
+	git -C server commit -a -m x &&
+
+	test_config -C server uploadpack.allowfilter 1 &&
+	test_config -C server uploadpack.allowanysha1inwant 1 &&
+	git clone --bare --filter=blob:limit=0 "file://$(pwd)/server" client &&
+
+	# Ensure that there is exactly 1 negotiation by checking that there is
+	# only 1 "done" line sent. ("done" marks the end of negotiation.)
+	GIT_TRACE_PACKET="$(pwd)/trace" git -C client diff -M HEAD^ HEAD >out &&
+	grep "similarity index" out &&
+	grep "git> done" trace >done_lines &&
+	test_line_count = 1 done_lines
+'
+
+test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t4100/t-apply-1.patch 1.2.3+git2.25.1-1/git/t/t4100/t-apply-1.patch
--- 1.2.1+git2.18.0-1/git/t/t4100/t-apply-1.patch	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t4100/t-apply-1.patch	2020-02-17 04:47:35.000000000 +0000
@@ -75,8 +75,8 @@ diff --git a/Documentation/git.txt b/Doc
 +link:git-ssh-pull.html[git-ssh-pull]::
  	Pulls from a remote repository over ssh connection
  
- Interogators:
-@@ -156,8 +156,8 @@ Interogators:
+ Interrogators:
+@@ -156,8 +156,8 @@ Interrogators:
  link:git-diff-helper.html[git-diff-helper]::
  	Generates patch format output for git-diff-*
  
diff -pruN 1.2.1+git2.18.0-1/git/t/t4100/t-apply-3.patch 1.2.3+git2.25.1-1/git/t/t4100/t-apply-3.patch
--- 1.2.1+git2.18.0-1/git/t/t4100/t-apply-3.patch	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t4100/t-apply-3.patch	2020-02-17 04:47:35.000000000 +0000
@@ -211,7 +211,7 @@ dissimilarity index 82%
 -
 -		/* If this is an exact directory match, we may have
 -		 * directory files following this path. Match on them.
--		 * Otherwise, we're at a pach subcomponent, and we need
+-		 * Otherwise, we're at a patch subcomponent, and we need
 -		 * to try to match again.
 -		 */
 -		if (mtype == 0)
diff -pruN 1.2.1+git2.18.0-1/git/t/t4100/t-apply-5.patch 1.2.3+git2.25.1-1/git/t/t4100/t-apply-5.patch
--- 1.2.1+git2.18.0-1/git/t/t4100/t-apply-5.patch	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t4100/t-apply-5.patch	2020-02-17 04:47:35.000000000 +0000
@@ -185,8 +185,8 @@ diff a/Documentation/git.txt b/Documenta
 +link:git-ssh-pull.html[git-ssh-pull]::
  	Pulls from a remote repository over ssh connection
  
- Interogators:
-@@ -156,8 +156,8 @@ Interogators:
+ Interrogators:
+@@ -156,8 +156,8 @@ Interrogators:
  link:git-diff-helper.html[git-diff-helper]::
  	Generates patch format output for git-diff-*
  
diff -pruN 1.2.1+git2.18.0-1/git/t/t4100/t-apply-7.patch 1.2.3+git2.25.1-1/git/t/t4100/t-apply-7.patch
--- 1.2.1+git2.18.0-1/git/t/t4100/t-apply-7.patch	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t4100/t-apply-7.patch	2020-02-17 04:47:35.000000000 +0000
@@ -335,7 +335,7 @@ diff a/ls-tree.c b/ls-tree.c
  
 -		/* If this is an exact directory match, we may have
 -		 * directory files following this path. Match on them.
--		 * Otherwise, we're at a pach subcomponent, and we need
+-		 * Otherwise, we're at a patch subcomponent, and we need
 -		 * to try to match again.
 +	if (e->directory) {
 +		/* If this is a directory, we have the following cases:
diff -pruN 1.2.1+git2.18.0-1/git/t/t4108-apply-threeway.sh 1.2.3+git2.25.1-1/git/t/t4108-apply-threeway.sh
--- 1.2.1+git2.18.0-1/git/t/t4108-apply-threeway.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t4108-apply-threeway.sh	2020-02-17 04:47:35.000000000 +0000
@@ -4,23 +4,17 @@ test_description='git apply --3way'
 
 . ./test-lib.sh
 
-create_file () {
-	for i
-	do
-		echo "$i"
-	done
-}
-
-sanitize_conflicted_diff () {
+print_sanitized_conflicted_diff () {
+	git diff HEAD >diff.raw &&
 	sed -e '
 		/^index /d
-		s/^\(+[<>][<>][<>][<>]*\) .*/\1/
-	'
+		s/^\(+[<>|][<>|][<>|][<>|]*\) .*/\1/
+	' diff.raw
 }
 
 test_expect_success setup '
 	test_tick &&
-	create_file >one 1 2 3 4 5 6 7 &&
+	test_write_lines 1 2 3 4 5 6 7 >one &&
 	cat one >two &&
 	git add one two &&
 	git commit -m initial &&
@@ -28,13 +22,13 @@ test_expect_success setup '
 	git branch side &&
 
 	test_tick &&
-	create_file >one 1 two 3 4 5 six 7 &&
-	create_file >two 1 two 3 4 5 6 7 &&
+	test_write_lines 1 two 3 4 5 six 7 >one &&
+	test_write_lines 1 two 3 4 5 6 7 >two &&
 	git commit -a -m master &&
 
 	git checkout side &&
-	create_file >one 1 2 3 4 five 6 7 &&
-	create_file >two 1 2 3 4 five 6 7 &&
+	test_write_lines 1 2 3 4 five 6 7 >one &&
+	test_write_lines 1 2 3 4 five 6 7 >two &&
 	git commit -a -m side &&
 
 	git checkout master
@@ -52,7 +46,7 @@ test_expect_success 'apply without --3wa
 	git diff-index --exit-code --cached HEAD
 '
 
-test_expect_success 'apply with --3way' '
+test_apply_with_3way () {
 	# Merging side should be similar to applying this patch
 	git diff ...side >P.diff &&
 
@@ -61,22 +55,31 @@ test_expect_success 'apply with --3way'
 	git checkout master^0 &&
 	test_must_fail git merge --no-commit side &&
 	git ls-files -s >expect.ls &&
-	git diff HEAD | sanitize_conflicted_diff >expect.diff &&
+	print_sanitized_conflicted_diff >expect.diff &&
 
 	# should fail to apply
 	git reset --hard &&
 	git checkout master^0 &&
 	test_must_fail git apply --index --3way P.diff &&
 	git ls-files -s >actual.ls &&
-	git diff HEAD | sanitize_conflicted_diff >actual.diff &&
+	print_sanitized_conflicted_diff >actual.diff &&
 
 	# The result should resemble the corresponding merge
 	test_cmp expect.ls actual.ls &&
 	test_cmp expect.diff actual.diff
+}
+
+test_expect_success 'apply with --3way' '
+	test_apply_with_3way
+'
+
+test_expect_success 'apply with --3way with merge.conflictStyle = diff3' '
+	test_config merge.conflictStyle diff3 &&
+	test_apply_with_3way
 '
 
 test_expect_success 'apply with --3way with rerere enabled' '
-	git config rerere.enabled true &&
+	test_config rerere.enabled true &&
 
 	# Merging side should be similar to applying this patch
 	git diff ...side >P.diff &&
@@ -87,7 +90,7 @@ test_expect_success 'apply with --3way w
 	test_must_fail git merge --no-commit side &&
 
 	# Manually resolve and record the resolution
-	create_file 1 two 3 4 five six 7 >one &&
+	test_write_lines 1 two 3 4 five six 7 >one &&
 	git rerere &&
 	cat one >expect &&
 
@@ -104,14 +107,14 @@ test_expect_success 'apply -3 with add/a
 	git reset --hard &&
 
 	git checkout -b adder &&
-	create_file 1 2 3 4 5 6 7 >three &&
-	create_file 1 2 3 4 5 6 7 >four &&
+	test_write_lines 1 2 3 4 5 6 7 >three &&
+	test_write_lines 1 2 3 4 5 6 7 >four &&
 	git add three four &&
 	git commit -m "add three and four" &&
 
 	git checkout -b another adder^ &&
-	create_file 1 2 3 4 5 6 7 >three &&
-	create_file 1 2 3 four 5 6 7 >four &&
+	test_write_lines 1 2 3 4 5 6 7 >three &&
+	test_write_lines 1 2 3 four 5 6 7 >four &&
 	git add three four &&
 	git commit -m "add three and four" &&
 
@@ -121,7 +124,7 @@ test_expect_success 'apply -3 with add/a
 	git checkout adder^0 &&
 	test_must_fail git merge --no-commit another &&
 	git ls-files -s >expect.ls &&
-	git diff HEAD | sanitize_conflicted_diff >expect.diff
+	print_sanitized_conflicted_diff >expect.diff
 '
 
 test_expect_success 'apply -3 with add/add conflict' '
@@ -131,7 +134,7 @@ test_expect_success 'apply -3 with add/a
 	test_must_fail git apply --index --3way P.diff &&
 	# ... and leave conflicts in the index and in the working tree
 	git ls-files -s >actual.ls &&
-	git diff HEAD | sanitize_conflicted_diff >actual.diff &&
+	print_sanitized_conflicted_diff >actual.diff &&
 
 	# The result should resemble the corresponding merge
 	test_cmp expect.ls actual.ls &&
diff -pruN 1.2.1+git2.18.0-1/git/t/t4116-apply-reverse.sh 1.2.3+git2.25.1-1/git/t/t4116-apply-reverse.sh
--- 1.2.1+git2.18.0-1/git/t/t4116-apply-reverse.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t4116-apply-reverse.sh	2020-02-17 04:47:35.000000000 +0000
@@ -42,7 +42,7 @@ test_expect_success 'apply in reverse' '
 	git reset --hard second &&
 	git apply --reverse --binary --index patch &&
 	git diff >diff &&
-	test_cmp /dev/null diff
+	test_must_be_empty diff
 
 '
 
diff -pruN 1.2.1+git2.18.0-1/git/t/t4117-apply-reject.sh 1.2.3+git2.25.1-1/git/t/t4117-apply-reject.sh
--- 1.2.1+git2.18.0-1/git/t/t4117-apply-reject.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t4117-apply-reject.sh	2020-02-17 04:47:35.000000000 +0000
@@ -72,7 +72,7 @@ test_expect_success 'apply with --reject
 	rm -f file1.rej file2.rej &&
 
 	test_must_fail git apply --reject patch.1 &&
-	test_cmp file1 expected &&
+	test_cmp expected file1 &&
 
 	cat file1.rej &&
 	test_path_is_missing file2.rej
@@ -85,7 +85,7 @@ test_expect_success 'apply with --reject
 
 	test_must_fail git apply --reject patch.2 >rejects &&
 	test_path_is_missing file1 &&
-	test_cmp file2 expected &&
+	test_cmp expected file2 &&
 
 	cat file2.rej &&
 	test_path_is_missing file1.rej
@@ -99,7 +99,7 @@ test_expect_success 'the same test with
 
 	test_must_fail git apply --reject --verbose patch.2 >rejects &&
 	test_path_is_missing file1 &&
-	test_cmp file2 expected &&
+	test_cmp expected file2 &&
 
 	cat file2.rej &&
 	test_path_is_missing file1.rej
diff -pruN 1.2.1+git2.18.0-1/git/t/t4121-apply-diffs.sh 1.2.3+git2.25.1-1/git/t/t4121-apply-diffs.sh
--- 1.2.1+git2.18.0-1/git/t/t4121-apply-diffs.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t4121-apply-diffs.sh	2020-02-17 04:47:35.000000000 +0000
@@ -27,6 +27,6 @@ test_expect_success 'setup' \
 
 test_expect_success \
 	'check if contextually independent diffs for the same file apply' \
-	'( git diff test~2 test~1; git diff test~1 test~0 )| git apply'
+	'( git diff test~2 test~1 && git diff test~1 test~0 )| git apply'
 
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t4124-apply-ws-rule.sh 1.2.3+git2.25.1-1/git/t/t4124-apply-ws-rule.sh
--- 1.2.1+git2.18.0-1/git/t/t4124-apply-ws-rule.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t4124-apply-ws-rule.sh	2020-02-17 04:47:35.000000000 +0000
@@ -100,7 +100,7 @@ test_expect_success 'whitespace=warn, de
 test_expect_success 'whitespace=error-all, default rule' '
 
 	test_must_fail apply_patch --whitespace=error-all &&
-	! test -s target
+	test_must_be_empty target
 
 '
 
@@ -313,9 +313,9 @@ test_expect_success 'applying beyond EOF
 	{ echo a; echo; } >one &&
 	cp one expect &&
 	test_must_fail git apply --whitespace=fix patch &&
-	test_cmp one expect &&
+	test_cmp expect one &&
 	test_must_fail git apply --ignore-space-change --whitespace=fix patch &&
-	test_cmp one expect
+	test_cmp expect one
 '
 
 test_expect_success 'tons of blanks at EOF should not apply' '
@@ -342,10 +342,10 @@ test_expect_success 'missing blank line
 	cp one saved-one &&
 	test_must_fail git apply patch &&
 	git apply --whitespace=fix patch &&
-	test_cmp one expect &&
+	test_cmp expect one &&
 	mv saved-one one &&
 	git apply --ignore-space-change --whitespace=fix patch &&
-	test_cmp one expect
+	test_cmp expect one
 '
 
 test_expect_success 'two missing blank lines at end with --whitespace=fix' '
@@ -360,11 +360,11 @@ test_expect_success 'two missing blank l
 	cp no-blank-lines one &&
 	test_must_fail git apply patch &&
 	git apply --whitespace=fix patch &&
-	test_cmp one expect &&
+	test_cmp expect one &&
 	mv no-blank-lines one &&
 	test_must_fail git apply patch &&
 	git apply --ignore-space-change --whitespace=fix patch &&
-	test_cmp one expect
+	test_cmp expect one
 '
 
 test_expect_success 'missing blank line at end, insert before end, --whitespace=fix' '
@@ -376,7 +376,7 @@ test_expect_success 'missing blank line
 	echo a >one &&
 	test_must_fail git apply patch &&
 	git apply --whitespace=fix patch &&
-	test_cmp one expect
+	test_cmp expect one
 '
 
 test_expect_success 'shrink file with tons of missing blanks at end of file' '
@@ -392,10 +392,10 @@ test_expect_success 'shrink file with to
 	cp no-blank-lines one &&
 	test_must_fail git apply patch &&
 	git apply --whitespace=fix patch &&
-	test_cmp one expect &&
+	test_cmp expect one &&
 	mv no-blank-lines one &&
 	git apply --ignore-space-change --whitespace=fix patch &&
-	test_cmp one expect
+	test_cmp expect one
 '
 
 test_expect_success 'missing blanks at EOF must only match blank lines' '
@@ -427,7 +427,7 @@ test_expect_success 'missing blank line
 	git add one &&
 
 	git apply --whitespace=fix patch &&
-	test_cmp one expect
+	test_cmp expect one
 '
 
 sed -e's/Z//' >one <<EOF
@@ -447,7 +447,7 @@ test_expect_success 'same, but with the
 
 	git checkout-index -f one &&
 	git apply --ignore-space-change --whitespace=fix patch &&
-	test_cmp one expect
+	test_cmp expect one
 '
 
 test_expect_success 'same, but with CR-LF line endings && cr-at-eol set' '
@@ -464,7 +464,7 @@ test_expect_success 'same, but with CR-L
 	mv save-one one &&
 
 	git apply --ignore-space-change --whitespace=fix patch &&
-	test_cmp one expect
+	test_cmp expect one
 '
 
 test_expect_success 'CR-LF line endings && add line && text=auto' '
@@ -478,7 +478,7 @@ test_expect_success 'CR-LF line endings
 	mv save-one one &&
 	echo "one text=auto" >.gitattributes &&
 	git apply patch &&
-	test_cmp one expect
+	test_cmp expect one
 '
 
 test_expect_success 'CR-LF line endings && change line && text=auto' '
@@ -491,7 +491,7 @@ test_expect_success 'CR-LF line endings
 	mv save-one one &&
 	echo "one text=auto" >.gitattributes &&
 	git apply patch &&
-	test_cmp one expect
+	test_cmp expect one
 '
 
 test_expect_success 'LF in repo, CRLF in worktree && change line && text=auto' '
@@ -503,7 +503,7 @@ test_expect_success 'LF in repo, CRLF in
 	echo "one text=auto" >.gitattributes &&
 	git -c core.eol=CRLF apply patch &&
 	printf "b\r\n" >expect &&
-	test_cmp one expect
+	test_cmp expect one
 '
 
 test_expect_success 'whitespace=fix to expand' '
diff -pruN 1.2.1+git2.18.0-1/git/t/t4132-apply-removal.sh 1.2.3+git2.25.1-1/git/t/t4132-apply-removal.sh
--- 1.2.1+git2.18.0-1/git/t/t4132-apply-removal.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t4132-apply-removal.sh	2020-02-17 04:47:35.000000000 +0000
@@ -49,8 +49,7 @@ test_expect_success setup '
 	sed -e "s/TS0/$timeGMT/" -e "s/TS1/$epocGMT/" <d >removeGMT.patch &&
 	sed -e "s/TS0/$timeWest/" -e "s/TS1/$epocWest2/" <d >removeWest2.patch &&
 
-	echo something >something &&
-	>empty
+	echo something >something
 '
 
 for patch in *.patch
@@ -81,7 +80,7 @@ do
 			git add file &&
 			git apply --index $patch &&
 			test -f file &&
-			test_cmp empty file
+			test_must_be_empty file
 			;;
 		remove*)
 			# must remove the file
diff -pruN 1.2.1+git2.18.0-1/git/t/t4135-apply-weird-filenames.sh 1.2.3+git2.25.1-1/git/t/t4135-apply-weird-filenames.sh
--- 1.2.1+git2.18.0-1/git/t/t4135-apply-weird-filenames.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t4135-apply-weird-filenames.sh	2020-02-17 04:47:35.000000000 +0000
@@ -15,15 +15,7 @@ test_expect_success 'setup' '
 		git checkout -f preimage^0 &&
 		git read-tree -u --reset HEAD &&
 		git update-index --refresh
-	} &&
-
-	test_when_finished "rm -f \"tab	embedded.txt\"" &&
-	test_when_finished "rm -f '\''\"quoteembedded\".txt'\''" &&
-	if test_have_prereq !MINGW &&
-		touch -- "tab	embedded.txt" '\''"quoteembedded".txt'\''
-	then
-		test_set_prereq FUNNYNAMES
-	fi
+	}
 '
 
 try_filename() {
diff -pruN 1.2.1+git2.18.0-1/git/t/t4136-apply-check.sh 1.2.3+git2.25.1-1/git/t/t4136-apply-check.sh
--- 1.2.1+git2.18.0-1/git/t/t4136-apply-check.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t4136-apply-check.sh	2020-02-17 04:47:35.000000000 +0000
@@ -29,6 +29,18 @@ test_expect_success 'apply exits non-zer
 	test_must_fail git apply --check input
 '
 
+test_expect_success '`apply --recount` allows no-op patch' '
+	echo 1 >1 &&
+	git apply --recount --check <<-\EOF
+	diff --get a/1 b/1
+	index 6696ea4..606eddd 100644
+	--- a/1
+	+++ b/1
+	@@ -1,1 +1,1 @@
+	 1
+	EOF
+'
+
 test_expect_success 'invalid combination: create and copy' '
 	test_must_fail git apply --check - <<-\EOF
 	diff --git a/1 b/2
diff -pruN 1.2.1+git2.18.0-1/git/t/t4138-apply-ws-expansion.sh 1.2.3+git2.25.1-1/git/t/t4138-apply-ws-expansion.sh
--- 1.2.1+git2.18.0-1/git/t/t4138-apply-ws-expansion.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t4138-apply-ws-expansion.sh	2020-02-17 04:47:35.000000000 +0000
@@ -17,8 +17,8 @@ test_expect_success setup '
 	printf "\t%s\n" 1 2 3 >after &&
 	printf "%64s\n" a b c >>after &&
 	printf "\t%s\n" 4 5 6 >>after &&
-	git diff --no-index before after |
-		sed -e "s/before/test-1/" -e "s/after/test-1/" >patch1.patch &&
+	test_expect_code 1 git diff --no-index before after >patch1.patch.raw &&
+	sed -e "s/before/test-1/" -e "s/after/test-1/" patch1.patch.raw >patch1.patch &&
 	printf "%64s\n" 1 2 3 4 5 6 >test-1 &&
 	printf "%64s\n" 1 2 3 a b c 4 5 6 >expect-1 &&
 
@@ -33,8 +33,8 @@ test_expect_success setup '
 		x=$(( $x + 1 ))
 	done &&
 	printf "\t%s\n" d e f >>after &&
-	git diff --no-index before after |
-		sed -e "s/before/test-2/" -e "s/after/test-2/" >patch2.patch &&
+	test_expect_code 1 git diff --no-index before after >patch2.patch.raw &&
+	sed -e "s/before/test-2/" -e "s/after/test-2/" patch2.patch.raw >patch2.patch &&
 	printf "%64s\n" a b c d e f >test-2 &&
 	printf "%64s\n" a b c >expect-2 &&
 	x=1 &&
@@ -56,8 +56,8 @@ test_expect_success setup '
 		x=$(( $x + 1 ))
 	done &&
 	printf "\t%s\n" d e f >>after &&
-	git diff --no-index before after |
-	sed -e "s/before/test-3/" -e "s/after/test-3/" >patch3.patch &&
+	test_expect_code 1 git diff --no-index before after >patch3.patch.raw &&
+	sed -e "s/before/test-3/" -e "s/after/test-3/" patch3.patch.raw >patch3.patch &&
 	printf "%64s\n" a b c d e f >test-3 &&
 	printf "%64s\n" a b c >expect-3 &&
 	x=0 &&
@@ -84,8 +84,8 @@ test_expect_success setup '
 		printf "\t%02d\n" $x >>after
 		x=$(( $x + 1 ))
 	done &&
-	git diff --no-index before after |
-	sed -e "s/before/test-4/" -e "s/after/test-4/" >patch4.patch &&
+	test_expect_code 1 git diff --no-index before after >patch4.patch.raw &&
+	sed -e "s/before/test-4/" -e "s/after/test-4/" patch4.patch.raw >patch4.patch &&
 	>test-4 &&
 	x=0 &&
 	while test $x -lt 50
@@ -114,7 +114,7 @@ for t in 1 2 3 4
 do
 	test_expect_success 'apply with ws expansion (t=$t)' '
 		git apply patch$t.patch &&
-		test_cmp test-$t expect-$t
+		test_cmp expect-$t test-$t
 	'
 done
 
diff -pruN 1.2.1+git2.18.0-1/git/t/t4150-am.sh 1.2.3+git2.25.1-1/git/t/t4150-am.sh
--- 1.2.1+git2.18.0-1/git/t/t4150-am.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t4150-am.sh	2020-02-17 04:47:35.000000000 +0000
@@ -69,20 +69,20 @@ test_expect_success 'setup: messages' '
 
 	EOF
 
-	cat >scissors-msg <<-\EOF &&
-	Test git-am with scissors line
+	cat >msg-without-scissors-line <<-\EOF &&
+	Test that git-am --scissors cuts at the scissors line
 
 	This line should be included in the commit message.
 	EOF
 
-	cat - scissors-msg >no-scissors-msg <<-\EOF &&
+	printf "Subject: " >subject-prefix &&
+
+	cat - subject-prefix msg-without-scissors-line >msg-with-scissors-line <<-\EOF
 	This line should not be included in the commit message with --scissors enabled.
 
 	 - - >8 - - remove everything above this line - - >8 - -
 
 	EOF
-
-	signoff="Signed-off-by: $GIT_COMMITTER_NAME <$GIT_COMMITTER_EMAIL>"
 '
 
 test_expect_success setup '
@@ -148,18 +148,17 @@ test_expect_success setup '
 	} >patch1-hg.eml &&
 
 
-	echo scissors-file >scissors-file &&
-	git add scissors-file &&
-	git commit -F scissors-msg &&
-	git tag scissors &&
-	git format-patch --stdout scissors^ >scissors-patch.eml &&
+	echo file >file &&
+	git add file &&
+	git commit -F msg-without-scissors-line &&
+	git tag expected-for-scissors &&
 	git reset --hard HEAD^ &&
 
-	echo no-scissors-file >no-scissors-file &&
-	git add no-scissors-file &&
-	git commit -F no-scissors-msg &&
-	git tag no-scissors &&
-	git format-patch --stdout no-scissors^ >no-scissors-patch.eml &&
+	echo file >file &&
+	git add file &&
+	git commit -F msg-with-scissors-line &&
+	git tag expected-for-no-scissors &&
+	git format-patch --stdout expected-for-no-scissors^ >patch-with-scissors-line.eml &&
 	git reset --hard HEAD^ &&
 
 	sed -n -e "3,\$p" msg >file &&
@@ -416,10 +415,10 @@ test_expect_success 'am --scissors cuts
 	rm -fr .git/rebase-apply &&
 	git reset --hard &&
 	git checkout second &&
-	git am --scissors scissors-patch.eml &&
+	git am --scissors patch-with-scissors-line.eml &&
 	test_path_is_missing .git/rebase-apply &&
-	git diff --exit-code scissors &&
-	test_cmp_rev scissors HEAD
+	git diff --exit-code expected-for-scissors &&
+	test_cmp_rev expected-for-scissors HEAD
 '
 
 test_expect_success 'am --no-scissors overrides mailinfo.scissors' '
@@ -427,10 +426,10 @@ test_expect_success 'am --no-scissors ov
 	git reset --hard &&
 	git checkout second &&
 	test_config mailinfo.scissors true &&
-	git am --no-scissors no-scissors-patch.eml &&
+	git am --no-scissors patch-with-scissors-line.eml &&
 	test_path_is_missing .git/rebase-apply &&
-	git diff --exit-code no-scissors &&
-	test_cmp_rev no-scissors HEAD
+	git diff --exit-code expected-for-no-scissors &&
+	test_cmp_rev expected-for-no-scissors HEAD
 '
 
 test_expect_success 'setup: new author and committer' '
@@ -651,7 +650,7 @@ test_expect_success 'am -3 -q is quiet'
 	git checkout -f lorem2 &&
 	git reset base3way --hard &&
 	git am -3 -q lorem-move.patch >output.out 2>&1 &&
-	! test -s output.out
+	test_must_be_empty output.out
 '
 
 test_expect_success 'am pauses on conflict' '
@@ -874,7 +873,7 @@ test_expect_success 'am -q is quiet' '
 	git checkout first &&
 	test_tick &&
 	git am -q <patch1 >output.out 2>&1 &&
-	! test -s output.out
+	test_must_be_empty output.out
 '
 
 test_expect_success 'am empty-file does not infloop' '
@@ -1062,4 +1061,56 @@ test_expect_success 'am --quit keeps HEA
 	test_cmp expected actual
 '
 
+test_expect_success 'am and .gitattibutes' '
+	test_create_repo attributes &&
+	(
+		cd attributes &&
+		test_commit init &&
+		git config filter.test.clean "sed -e '\''s/smudged/clean/g'\''" &&
+		git config filter.test.smudge "sed -e '\''s/clean/smudged/g'\''" &&
+
+		test_commit second &&
+		git checkout -b test HEAD^ &&
+
+		echo "*.txt filter=test conflict-marker-size=10" >.gitattributes &&
+		git add .gitattributes &&
+		test_commit third &&
+
+		echo "This text is smudged." >a.txt &&
+		git add a.txt &&
+		test_commit fourth &&
+
+		git checkout -b removal HEAD^ &&
+		git rm .gitattributes &&
+		git add -u &&
+		test_commit fifth &&
+		git cherry-pick test &&
+
+		git checkout -b conflict third &&
+		echo "This text is different." >a.txt &&
+		git add a.txt &&
+		test_commit sixth &&
+
+		git checkout test &&
+		git format-patch --stdout master..HEAD >patches &&
+		git reset --hard master &&
+		git am patches &&
+		grep "smudged" a.txt &&
+
+		git checkout removal &&
+		git reset --hard &&
+		git format-patch --stdout master..HEAD >patches &&
+		git reset --hard master &&
+		git am patches &&
+		grep "clean" a.txt &&
+
+		git checkout conflict &&
+		git reset --hard &&
+		git format-patch --stdout master..HEAD >patches &&
+		git reset --hard fourth &&
+		test_must_fail git am -3 patches &&
+		grep "<<<<<<<<<<" a.txt
+	)
+'
+
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t4200-rerere.sh 1.2.3+git2.25.1-1/git/t/t4200-rerere.sh
--- 1.2.1+git2.18.0-1/git/t/t4200-rerere.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t4200-rerere.sh	2020-02-17 04:47:35.000000000 +0000
@@ -267,8 +267,7 @@ rerere_gc_custom_expiry_test () {
 		git -c "gc.rerereresolved=$right_now" \
 		    -c "gc.rerereunresolved=$right_now" rerere gc &&
 		find .git/rr-cache -type f | sort >actual &&
-		>expect &&
-		test_cmp expect actual
+		test_must_be_empty actual
 	'
 }
 
@@ -536,9 +535,8 @@ test_expect_success 'multiple identical
 
 	# We resolved file1 and file2
 	git rerere &&
-	>expect &&
 	git rerere remaining >actual &&
-	test_cmp expect actual &&
+	test_must_be_empty actual &&
 
 	# We must have recorded both of them
 	count_pre_post 2 2 &&
@@ -548,9 +546,8 @@ test_expect_success 'multiple identical
 	test_must_fail git merge six.1 &&
 	git rerere &&
 
-	>expect &&
 	git rerere remaining >actual &&
-	test_cmp expect actual &&
+	test_must_be_empty actual &&
 
 	concat_insert short 6.1 6.2 >file1.expect &&
 	concat_insert long 6.1 6.2 >file2.expect &&
@@ -580,4 +577,98 @@ test_expect_success 'multiple identical
 	count_pre_post 0 0
 '
 
+test_expect_success 'rerere with unexpected conflict markers does not crash' '
+	git reset --hard &&
+
+	git checkout -b branch-1 master &&
+	echo "bar" >test &&
+	git add test &&
+	git commit -q -m two &&
+
+	git reset --hard &&
+	git checkout -b branch-2 master &&
+	echo "foo" >test &&
+	git add test &&
+	git commit -q -a -m one &&
+
+	test_must_fail git merge branch-1 &&
+	echo "<<<<<<< a" >test &&
+	git rerere &&
+
+	git rerere clear
+'
+
+test_expect_success 'rerere with inner conflict markers' '
+	git reset --hard &&
+
+	git checkout -b A master &&
+	echo "bar" >test &&
+	git add test &&
+	git commit -q -m two &&
+	echo "baz" >test &&
+	git add test &&
+	git commit -q -m three &&
+
+	git reset --hard &&
+	git checkout -b B master &&
+	echo "foo" >test &&
+	git add test &&
+	git commit -q -a -m one &&
+
+	test_must_fail git merge A~ &&
+	git add test &&
+	git commit -q -m "will solve conflicts later" &&
+	test_must_fail git merge A &&
+
+	echo "resolved" >test &&
+	git add test &&
+	git commit -q -m "solved conflict" &&
+
+	echo "resolved" >expect &&
+
+	git reset --hard HEAD~~ &&
+	test_must_fail git merge A~ &&
+	git add test &&
+	git commit -q -m "will solve conflicts later" &&
+	test_must_fail git merge A &&
+	cat test >actual &&
+	test_cmp expect actual &&
+
+	git add test &&
+	git commit -m "rerere solved conflict" &&
+	git reset --hard HEAD~ &&
+	test_must_fail git merge A &&
+	cat test >actual &&
+	test_cmp expect actual
+'
+
+test_expect_success 'setup simple stage 1 handling' '
+	test_create_repo stage_1_handling &&
+	(
+		cd stage_1_handling &&
+
+		test_seq 1 10 >original &&
+		git add original &&
+		git commit -m original &&
+
+		git checkout -b A master &&
+		git mv original A &&
+		git commit -m "rename to A" &&
+
+		git checkout -b B master &&
+		git mv original B &&
+		git commit -m "rename to B"
+	)
+'
+
+test_expect_success 'test simple stage 1 handling' '
+	(
+		cd stage_1_handling &&
+
+		git config rerere.enabled true &&
+		git checkout A^0 &&
+		test_must_fail git merge B^0
+	)
+'
+
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t4201-shortlog.sh 1.2.3+git2.25.1-1/git/t/t4201-shortlog.sh
--- 1.2.1+git2.18.0-1/git/t/t4201-shortlog.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t4201-shortlog.sh	2020-02-17 04:47:35.000000000 +0000
@@ -192,7 +192,7 @@ test_expect_success 'shortlog with revis
 
 test_expect_success 'shortlog with --output=<file>' '
 	git shortlog --output=shortlog -1 master >output &&
-	test ! -s output &&
+	test_must_be_empty output &&
 	test_line_count = 3 shortlog
 '
 
diff -pruN 1.2.1+git2.18.0-1/git/t/t4202-log.sh 1.2.3+git2.25.1-1/git/t/t4202-log.sh
--- 1.2.1+git2.18.0-1/git/t/t4202-log.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t4202-log.sh	2020-02-17 04:47:35.000000000 +0000
@@ -340,10 +340,9 @@ test_expect_success PCRE 'log -F -E --pe
 '
 
 test_expect_success 'log with grep.patternType configuration' '
-	>expect &&
 	git -c grep.patterntype=fixed \
 	log -1 --pretty=tformat:%s --grep=s.c.nd >actual &&
-	test_cmp expect actual
+	test_must_be_empty actual
 '
 
 test_expect_success 'log with grep.patternType configuration and command line' '
@@ -353,7 +352,7 @@ test_expect_success 'log with grep.patte
 	test_cmp expect actual
 '
 
-test_expect_success 'log with various grep.patternType configurations & command-lines' '
+test_expect_success !FAIL_PREREQS 'log with various grep.patternType configurations & command-lines' '
 	git init pattern-type &&
 	(
 		cd pattern-type &&
@@ -668,7 +667,7 @@ cat > expect <<\EOF
 * | | fifth
 * | | fourth
 |/ /
-* | third
+* / third
 |/
 * second
 * initial
@@ -838,6 +837,21 @@ test_expect_success 'decorate-refs and d
 	test_cmp expect.decorate actual
 '
 
+test_expect_success 'decorate-refs-exclude and simplify-by-decoration' '
+	cat >expect.decorate <<-\EOF &&
+	Merge-tag-reach (HEAD -> master)
+	reach (tag: reach, reach)
+	seventh (tag: seventh)
+	Merge-branch-tangle
+	Merge-branch-side-early-part-into-tangle (tangle)
+	tangle-a (tag: tangle-a)
+	EOF
+	git log -n6 --decorate=short --pretty="tformat:%f%d" \
+		--decorate-refs-exclude="*octopus*" \
+		--simplify-by-decoration >actual &&
+	test_cmp expect.decorate actual
+'
+
 test_expect_success 'log.decorate config parsing' '
 	git log --oneline --decorate=full >expect.full &&
 	git log --oneline --decorate=short >expect.short &&
@@ -1556,12 +1570,48 @@ test_expect_success GPG 'setup signed br
 	git commit -S -m signed_commit
 '
 
+test_expect_success GPG 'setup signed branch with subkey' '
+	test_when_finished "git reset --hard && git checkout master" &&
+	git checkout -b signed-subkey master &&
+	echo foo >foo &&
+	git add foo &&
+	git commit -SB7227189 -m signed_commit
+'
+
+test_expect_success GPGSM 'setup signed branch x509' '
+	test_when_finished "git reset --hard && git checkout master" &&
+	git checkout -b signed-x509 master &&
+	echo foo >foo &&
+	git add foo &&
+	test_config gpg.format x509 &&
+	test_config user.signingkey $GIT_COMMITTER_EMAIL &&
+	git commit -S -m signed_commit
+'
+
+test_expect_success GPGSM 'log x509 fingerprint' '
+	echo "F8BF62E0693D0694816377099909C779FA23FD65 | " >expect &&
+	git log -n1 --format="%GF | %GP" signed-x509 >actual &&
+	test_cmp expect actual
+'
+
+test_expect_success GPGSM 'log OpenPGP fingerprint' '
+	echo "D4BE22311AD3131E5EDA29A461092E85B7227189" > expect &&
+	git log -n1 --format="%GP" signed-subkey >actual &&
+	test_cmp expect actual
+'
+
 test_expect_success GPG 'log --graph --show-signature' '
 	git log --graph --show-signature -n1 signed >actual &&
 	grep "^| gpg: Signature made" actual &&
 	grep "^| gpg: Good signature" actual
 '
 
+test_expect_success GPGSM 'log --graph --show-signature x509' '
+	git log --graph --show-signature -n1 signed-x509 >actual &&
+	grep "^| gpgsm: Signature made" actual &&
+	grep "^| gpgsm: Good signature" actual
+'
+
 test_expect_success GPG 'log --graph --show-signature for merged tag' '
 	test_when_finished "git reset --hard && git checkout master" &&
 	git checkout -b plain master &&
@@ -1581,6 +1631,27 @@ test_expect_success GPG 'log --graph --s
 	grep "^| | gpg: Good signature" actual
 '
 
+test_expect_success GPGSM 'log --graph --show-signature for merged tag x509' '
+	test_when_finished "git reset --hard && git checkout master" &&
+	test_config gpg.format x509 &&
+	test_config user.signingkey $GIT_COMMITTER_EMAIL &&
+	git checkout -b plain-x509 master &&
+	echo aaa >bar &&
+	git add bar &&
+	git commit -m bar_commit &&
+	git checkout -b tagged-x509 master &&
+	echo bbb >baz &&
+	git add baz &&
+	git commit -m baz_commit &&
+	git tag -s -m signed_tag_msg signed_tag_x509 &&
+	git checkout plain-x509 &&
+	git merge --no-ff -m msg signed_tag_x509 &&
+	git log --graph --show-signature -n1 plain-x509 >actual &&
+	grep "^|\\\  merged tag" actual &&
+	grep "^| | gpgsm: Signature made" actual &&
+	grep "^| | gpgsm: Good signature" actual
+'
+
 test_expect_success GPG '--no-show-signature overrides --show-signature' '
 	git log -1 --show-signature --no-show-signature signed >actual &&
 	! grep "^gpg:" actual
@@ -1625,9 +1696,8 @@ test_expect_success 'log diagnoses bogus
 '
 
 test_expect_success 'log does not default to HEAD when rev input is given' '
-	>expect &&
 	git log --branches=does-not-exist >actual &&
-	test_cmp expect actual
+	test_must_be_empty actual
 '
 
 test_expect_success 'set up --source tests' '
@@ -1668,4 +1738,15 @@ test_expect_success 'log --source paints
 	test_cmp expect actual
 '
 
+test_expect_success '--exclude-promisor-objects does not BUG-crash' '
+	test_must_fail git log --exclude-promisor-objects source-a
+'
+
+test_expect_success 'log --end-of-options' '
+       git update-ref refs/heads/--source HEAD &&
+       git log --end-of-options --source >actual &&
+       git log >expect &&
+       test_cmp expect actual
+'
+
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t4203-mailmap.sh 1.2.3+git2.25.1-1/git/t/t4203-mailmap.sh
--- 1.2.1+git2.18.0-1/git/t/t4203-mailmap.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t4203-mailmap.sh	2020-02-17 04:47:35.000000000 +0000
@@ -13,8 +13,8 @@ fuzz_blame () {
 }
 
 test_expect_success setup '
-	cat >contacts <<-\EOF &&
-	A U Thor <author@example.com>
+	cat >contacts <<- EOF &&
+	$GIT_AUTHOR_NAME <$GIT_AUTHOR_EMAIL>
 	nick1 <bugs@company.xx>
 	EOF
 
@@ -33,19 +33,19 @@ test_expect_success 'check-mailmap no ar
 '
 
 test_expect_success 'check-mailmap arguments' '
-	cat >expect <<-\EOF &&
-	A U Thor <author@example.com>
+	cat >expect <<- EOF &&
+	$GIT_AUTHOR_NAME <$GIT_AUTHOR_EMAIL>
 	nick1 <bugs@company.xx>
 	EOF
 	git check-mailmap \
-		"A U Thor <author@example.com>" \
+		"$GIT_AUTHOR_NAME <$GIT_AUTHOR_EMAIL>" \
 		"nick1 <bugs@company.xx>" >actual &&
 	test_cmp expect actual
 '
 
 test_expect_success 'check-mailmap --stdin' '
-	cat >expect <<-\EOF &&
-	A U Thor <author@example.com>
+	cat >expect <<- EOF &&
+	$GIT_AUTHOR_NAME <$GIT_AUTHOR_EMAIL>
 	nick1 <bugs@company.xx>
 	EOF
 	git check-mailmap --stdin <contacts >actual &&
@@ -66,8 +66,8 @@ test_expect_success 'check-mailmap bogus
 	test_must_fail git check-mailmap bogus
 '
 
-cat >expect <<\EOF
-A U Thor (1):
+cat >expect << EOF
+$GIT_AUTHOR_NAME (1):
       initial
 
 nick1 (1):
@@ -90,7 +90,7 @@ nick1 (1):
 EOF
 
 test_expect_success 'default .mailmap' '
-	echo "Repo Guy <author@example.com>" > .mailmap &&
+	echo "Repo Guy <$GIT_AUTHOR_EMAIL>" > .mailmap &&
 	git shortlog HEAD >actual &&
 	test_cmp expect actual
 '
@@ -122,7 +122,7 @@ Internal Guy (1):
 
 EOF
 test_expect_success 'mailmap.file override' '
-	echo "External Guy <author@example.com>" >> internal_mailmap/.mailmap &&
+	echo "External Guy <$GIT_AUTHOR_EMAIL>" >> internal_mailmap/.mailmap &&
 	git config mailmap.file internal_mailmap/.mailmap &&
 	git shortlog HEAD >actual &&
 	test_cmp expect actual
@@ -178,8 +178,8 @@ test_expect_success 'name entry after em
 	test_cmp expect actual
 '
 
-cat >expect <<\EOF
-A U Thor (1):
+cat >expect << EOF
+$GIT_AUTHOR_NAME (1):
       initial
 
 nick1 (1):
@@ -195,18 +195,18 @@ test_expect_success 'No mailmap files, b
 test_expect_success 'setup mailmap blob tests' '
 	git checkout -b map &&
 	test_when_finished "git checkout master" &&
-	cat >just-bugs <<-\EOF &&
+	cat >just-bugs <<- EOF &&
 	Blob Guy <bugs@company.xx>
 	EOF
-	cat >both <<-\EOF &&
-	Blob Guy <author@example.com>
+	cat >both <<- EOF &&
+	Blob Guy <$GIT_AUTHOR_EMAIL>
 	Blob Guy <bugs@company.xx>
 	EOF
-	printf "Tricky Guy <author@example.com>" >no-newline &&
+	printf "Tricky Guy <$GIT_AUTHOR_EMAIL>" >no-newline &&
 	git add just-bugs both no-newline &&
 	git commit -m "my mailmaps" &&
-	echo "Repo Guy <author@example.com>" >.mailmap &&
-	echo "Internal Guy <author@example.com>" >internal.map
+	echo "Repo Guy <$GIT_AUTHOR_EMAIL>" >.mailmap &&
+	echo "Internal Guy <$GIT_AUTHOR_EMAIL>" >internal.map
 '
 
 test_expect_success 'mailmap.blob set' '
@@ -266,12 +266,12 @@ test_expect_success 'mailmap.blob defaul
 	git init non-bare &&
 	(
 		cd non-bare &&
-		test_commit one .mailmap "Fake Name <author@example.com>" &&
+		test_commit one .mailmap "Fake Name <$GIT_AUTHOR_EMAIL>" &&
 		echo "     1	Fake Name" >expect &&
 		git shortlog -ns HEAD >actual &&
 		test_cmp expect actual &&
 		rm .mailmap &&
-		echo "     1	A U Thor" >expect &&
+		echo "     1	$GIT_AUTHOR_NAME" >expect &&
 		git shortlog -ns HEAD >actual &&
 		test_cmp expect actual
 	)
@@ -305,26 +305,26 @@ test_expect_success 'cleanup after mailm
 '
 
 test_expect_success 'single-character name' '
-	echo "     1	A <author@example.com>" >expect &&
+	echo "     1	A <$GIT_AUTHOR_EMAIL>" >expect &&
 	echo "     1	nick1 <bugs@company.xx>" >>expect &&
-	echo "A <author@example.com>" >.mailmap &&
+	echo "A <$GIT_AUTHOR_EMAIL>" >.mailmap &&
 	test_when_finished "rm .mailmap" &&
 	git shortlog -es HEAD >actual &&
 	test_cmp expect actual
 '
 
 test_expect_success 'preserve canonical email case' '
-	echo "     1	A U Thor <AUTHOR@example.com>" >expect &&
+	echo "     1	$GIT_AUTHOR_NAME <AUTHOR@example.com>" >expect &&
 	echo "     1	nick1 <bugs@company.xx>" >>expect &&
-	echo "<AUTHOR@example.com> <author@example.com>" >.mailmap &&
+	echo "<AUTHOR@example.com> <$GIT_AUTHOR_EMAIL>" >.mailmap &&
 	test_when_finished "rm .mailmap" &&
 	git shortlog -es HEAD >actual &&
 	test_cmp expect actual
 '
 
 # Extended mailmap configurations should give us the following output for shortlog
-cat >expect <<\EOF
-A U Thor <author@example.com> (1):
+cat >expect << EOF
+$GIT_AUTHOR_NAME <$GIT_AUTHOR_EMAIL> (1):
       initial
 
 CTO <cto@company.xx> (1):
@@ -370,7 +370,7 @@ test_expect_success 'Shortlog output (co
 	git commit --author "CTO <cto@coompany.xx>" -m seventh &&
 
 	mkdir -p internal_mailmap &&
-	echo "Committed <committer@example.com>" > internal_mailmap/.mailmap &&
+	echo "Committed <$GIT_COMMITTER_EMAIL>" > internal_mailmap/.mailmap &&
 	echo "<cto@company.xx>                       <cto@coompany.xx>" >> internal_mailmap/.mailmap &&
 	echo "Some Dude <some@dude.xx>         nick1 <bugs@company.xx>" >> internal_mailmap/.mailmap &&
 	echo "Other Author <other@author.xx>   nick2 <bugs@company.xx>" >> internal_mailmap/.mailmap &&
@@ -384,27 +384,27 @@ test_expect_success 'Shortlog output (co
 '
 
 # git log with --pretty format which uses the name and email mailmap placemarkers
-cat >expect <<\EOF
+cat >expect << EOF
 Author CTO <cto@coompany.xx> maps to CTO <cto@company.xx>
-Committer C O Mitter <committer@example.com> maps to Committed <committer@example.com>
+Committer $GIT_COMMITTER_NAME <$GIT_COMMITTER_EMAIL> maps to Committed <$GIT_COMMITTER_EMAIL>
 
 Author claus <me@company.xx> maps to Santa Claus <santa.claus@northpole.xx>
-Committer C O Mitter <committer@example.com> maps to Committed <committer@example.com>
+Committer $GIT_COMMITTER_NAME <$GIT_COMMITTER_EMAIL> maps to Committed <$GIT_COMMITTER_EMAIL>
 
 Author santa <me@company.xx> maps to Santa Claus <santa.claus@northpole.xx>
-Committer C O Mitter <committer@example.com> maps to Committed <committer@example.com>
+Committer $GIT_COMMITTER_NAME <$GIT_COMMITTER_EMAIL> maps to Committed <$GIT_COMMITTER_EMAIL>
 
 Author nick2 <nick2@company.xx> maps to Other Author <other@author.xx>
-Committer C O Mitter <committer@example.com> maps to Committed <committer@example.com>
+Committer $GIT_COMMITTER_NAME <$GIT_COMMITTER_EMAIL> maps to Committed <$GIT_COMMITTER_EMAIL>
 
 Author nick2 <bugs@company.xx> maps to Other Author <other@author.xx>
-Committer C O Mitter <committer@example.com> maps to Committed <committer@example.com>
+Committer $GIT_COMMITTER_NAME <$GIT_COMMITTER_EMAIL> maps to Committed <$GIT_COMMITTER_EMAIL>
 
 Author nick1 <bugs@company.xx> maps to Some Dude <some@dude.xx>
-Committer C O Mitter <committer@example.com> maps to Committed <committer@example.com>
+Committer $GIT_COMMITTER_NAME <$GIT_COMMITTER_EMAIL> maps to Committed <$GIT_COMMITTER_EMAIL>
 
-Author A U Thor <author@example.com> maps to A U Thor <author@example.com>
-Committer C O Mitter <committer@example.com> maps to Committed <committer@example.com>
+Author $GIT_AUTHOR_NAME <$GIT_AUTHOR_EMAIL> maps to $GIT_AUTHOR_NAME <$GIT_AUTHOR_EMAIL>
+Committer $GIT_COMMITTER_NAME <$GIT_COMMITTER_EMAIL> maps to Committed <$GIT_COMMITTER_EMAIL>
 EOF
 
 test_expect_success 'Log output (complex mapping)' '
@@ -412,14 +412,42 @@ test_expect_success 'Log output (complex
 	test_cmp expect actual
 '
 
-cat >expect <<\EOF
+cat >expect << EOF
+Author email cto@coompany.xx has local-part cto
+Committer email $GIT_COMMITTER_EMAIL has local-part $TEST_COMMITTER_LOCALNAME
+
+Author email me@company.xx has local-part me
+Committer email $GIT_COMMITTER_EMAIL has local-part $TEST_COMMITTER_LOCALNAME
+
+Author email me@company.xx has local-part me
+Committer email $GIT_COMMITTER_EMAIL has local-part $TEST_COMMITTER_LOCALNAME
+
+Author email nick2@company.xx has local-part nick2
+Committer email $GIT_COMMITTER_EMAIL has local-part $TEST_COMMITTER_LOCALNAME
+
+Author email bugs@company.xx has local-part bugs
+Committer email $GIT_COMMITTER_EMAIL has local-part $TEST_COMMITTER_LOCALNAME
+
+Author email bugs@company.xx has local-part bugs
+Committer email $GIT_COMMITTER_EMAIL has local-part $TEST_COMMITTER_LOCALNAME
+
+Author email author@example.com has local-part author
+Committer email $GIT_COMMITTER_EMAIL has local-part $TEST_COMMITTER_LOCALNAME
+EOF
+
+test_expect_success 'Log output (local-part email address)' '
+	git log --pretty=format:"Author email %ae has local-part %al%nCommitter email %ce has local-part %cl%n" >actual &&
+	test_cmp expect actual
+'
+
+cat >expect << EOF
 Author: CTO <cto@company.xx>
 Author: Santa Claus <santa.claus@northpole.xx>
 Author: Santa Claus <santa.claus@northpole.xx>
 Author: Other Author <other@author.xx>
 Author: Other Author <other@author.xx>
 Author: Some Dude <some@dude.xx>
-Author: A U Thor <author@example.com>
+Author: $GIT_AUTHOR_NAME <$GIT_AUTHOR_EMAIL>
 EOF
 
 test_expect_success 'Log output with --use-mailmap' '
@@ -427,14 +455,14 @@ test_expect_success 'Log output with --u
 	test_cmp expect actual
 '
 
-cat >expect <<\EOF
+cat >expect << EOF
 Author: CTO <cto@company.xx>
 Author: Santa Claus <santa.claus@northpole.xx>
 Author: Santa Claus <santa.claus@northpole.xx>
 Author: Other Author <other@author.xx>
 Author: Other Author <other@author.xx>
 Author: Some Dude <some@dude.xx>
-Author: A U Thor <author@example.com>
+Author: $GIT_AUTHOR_NAME <$GIT_AUTHOR_EMAIL>
 EOF
 
 test_expect_success 'Log output with log.mailmap' '
@@ -442,6 +470,34 @@ test_expect_success 'Log output with log
 	test_cmp expect actual
 '
 
+test_expect_success 'log.mailmap=false disables mailmap' '
+	cat >expect <<- EOF &&
+	Author: CTO <cto@coompany.xx>
+	Author: claus <me@company.xx>
+	Author: santa <me@company.xx>
+	Author: nick2 <nick2@company.xx>
+	Author: nick2 <bugs@company.xx>
+	Author: nick1 <bugs@company.xx>
+	Author: $GIT_AUTHOR_NAME <$GIT_AUTHOR_EMAIL>
+	EOF
+	git -c log.mailmap=False log | grep Author > actual &&
+	test_cmp expect actual
+'
+
+test_expect_success '--no-use-mailmap disables mailmap' '
+	cat >expect <<- EOF &&
+	Author: CTO <cto@coompany.xx>
+	Author: claus <me@company.xx>
+	Author: santa <me@company.xx>
+	Author: nick2 <nick2@company.xx>
+	Author: nick2 <bugs@company.xx>
+	Author: nick1 <bugs@company.xx>
+	Author: $GIT_AUTHOR_NAME <$GIT_AUTHOR_EMAIL>
+	EOF
+	git log --no-use-mailmap | grep Author > actual &&
+	test_cmp expect actual
+'
+
 cat >expect <<\EOF
 Author: Santa Claus <santa.claus@northpole.xx>
 Author: Santa Claus <santa.claus@northpole.xx>
@@ -461,16 +517,19 @@ test_expect_success 'Grep author with lo
 	test_cmp expect actual
 '
 
->expect
+test_expect_success 'log.mailmap is true by default these days' '
+	git log --author Santa | grep Author >actual &&
+	test_cmp expect actual
+'
 
 test_expect_success 'Only grep replaced author with --use-mailmap' '
 	git log --use-mailmap --author "<cto@coompany.xx>" >actual &&
-	test_cmp expect actual
+	test_must_be_empty actual
 '
 
 # git blame
-cat >expect <<\EOF
-^OBJI (A U Thor     DATE 1) one
+cat >expect <<EOF
+^OBJI ($GIT_AUTHOR_NAME     DATE 1) one
 OBJID (Some Dude    DATE 2) two
 OBJID (Other Author DATE 3) three
 OBJID (Other Author DATE 4) four
diff -pruN 1.2.1+git2.18.0-1/git/t/t4205-log-pretty-formats.sh 1.2.3+git2.25.1-1/git/t/t4205-log-pretty-formats.sh
--- 1.2.1+git2.18.0-1/git/t/t4205-log-pretty-formats.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t4205-log-pretty-formats.sh	2020-02-17 04:47:35.000000000 +0000
@@ -134,6 +134,36 @@ test_expect_failure C_LOCALE_OUTPUT 'NUL
 	test_cmp expected actual
 '
 
+for p in short medium full fuller email raw
+do
+	test_expect_success "NUL termination with --reflog --pretty=$p" '
+		revs="$(git rev-list --reflog)" &&
+		for r in $revs
+		do
+			git show -s "$r" --pretty="$p" &&
+			printf "\0" || return 1
+		done >expect &&
+		{
+			git log -z --reflog --pretty="$p" &&
+			printf "\0"
+		} >actual &&
+		test_cmp expect actual
+	'
+done
+
+test_expect_success 'NUL termination with --reflog --pretty=oneline' '
+	revs="$(git rev-list --reflog)" &&
+	for r in $revs
+	do
+		git show -s --pretty=oneline "$r" >raw &&
+		cat raw | lf_to_nul || exit 1
+	done >expect &&
+	# the trailing NUL is already produced so we do not need to
+	# output another one
+	git log -z --pretty=oneline --reflog >actual &&
+	test_cmp expect actual
+'
+
 test_expect_success 'setup more commits' '
 	test_commit "message one" one one message-one &&
 	test_commit "message two" two two message-two &&
@@ -503,6 +533,12 @@ test_expect_success 'ISO and ISO-strict
 	test_cmp expected actual
 '
 
+test_expect_success 'short date' '
+	git log --format=%ad%n%cd --date=short >expected &&
+	git log --format=%as%n%cs >actual &&
+	test_cmp expected actual
+'
+
 # get new digests (with no abbreviations)
 test_expect_success 'set up log decoration tests' '
 	head1=$(git rev-parse --verify HEAD~0) &&
@@ -578,6 +614,24 @@ test_expect_success '%(trailers:only) sh
 	test_cmp expect actual
 '
 
+test_expect_success '%(trailers:only=yes) shows only "key: value" trailers' '
+	git log --no-walk --pretty=format:"%(trailers:only=yes)" >actual &&
+	grep -v patch.description <trailers >expect &&
+	test_cmp expect actual
+'
+
+test_expect_success '%(trailers:only=no) shows all trailers' '
+	git log --no-walk --pretty=format:"%(trailers:only=no)" >actual &&
+	cat trailers >expect &&
+	test_cmp expect actual
+'
+
+test_expect_success '%(trailers:only=no,only=true) shows only "key: value" trailers' '
+	git log --no-walk --pretty=format:"%(trailers:only=yes)" >actual &&
+	grep -v patch.description <trailers >expect &&
+	test_cmp expect actual
+'
+
 test_expect_success '%(trailers:unfold) unfolds trailers' '
 	git log --no-walk --pretty="%(trailers:unfold)" >actual &&
 	{
@@ -598,4 +652,219 @@ test_expect_success ':only and :unfold w
 	test_cmp expect actual
 '
 
+test_expect_success 'pretty format %(trailers:key=foo) shows that trailer' '
+	git log --no-walk --pretty="format:%(trailers:key=Acked-by)" >actual &&
+	echo "Acked-by: A U Thor <author@example.com>" >expect &&
+	test_cmp expect actual
+'
+
+test_expect_success 'pretty format %(trailers:key=foo) is case insensitive' '
+	git log --no-walk --pretty="format:%(trailers:key=AcKed-bY)" >actual &&
+	echo "Acked-by: A U Thor <author@example.com>" >expect &&
+	test_cmp expect actual
+'
+
+test_expect_success 'pretty format %(trailers:key=foo:) trailing colon also works' '
+	git log --no-walk --pretty="format:%(trailers:key=Acked-by:)" >actual &&
+	echo "Acked-by: A U Thor <author@example.com>" >expect &&
+	test_cmp expect actual
+'
+
+test_expect_success 'pretty format %(trailers:key=foo) multiple keys' '
+	git log --no-walk --pretty="format:%(trailers:key=Acked-by:,key=Signed-off-By)" >actual &&
+	grep -v patch.description <trailers >expect &&
+	test_cmp expect actual
+'
+
+test_expect_success '%(trailers:key=nonexistent) becomes empty' '
+	git log --no-walk --pretty="x%(trailers:key=Nacked-by)x" >actual &&
+	echo "xx" >expect &&
+	test_cmp expect actual
+'
+
+test_expect_success '%(trailers:key=foo) handles multiple lines even if folded' '
+	git log --no-walk --pretty="format:%(trailers:key=Signed-Off-by)" >actual &&
+	grep -v patch.description <trailers | grep -v Acked-by >expect &&
+	test_cmp expect actual
+'
+
+test_expect_success '%(trailers:key=foo,unfold) properly unfolds' '
+	git log --no-walk --pretty="format:%(trailers:key=Signed-Off-by,unfold)" >actual &&
+	unfold <trailers | grep Signed-off-by >expect &&
+	test_cmp expect actual
+'
+
+test_expect_success 'pretty format %(trailers:key=foo,only=no) also includes nontrailer lines' '
+	git log --no-walk --pretty="format:%(trailers:key=Acked-by,only=no)" >actual &&
+	{
+		echo "Acked-by: A U Thor <author@example.com>" &&
+		grep patch.description <trailers
+	} >expect &&
+	test_cmp expect actual
+'
+
+test_expect_success '%(trailers:key) without value is error' '
+	git log --no-walk --pretty="tformat:%(trailers:key)" >actual &&
+	echo "%(trailers:key)" >expect &&
+	test_cmp expect actual
+'
+
+test_expect_success '%(trailers:key=foo,valueonly) shows only value' '
+	git log --no-walk --pretty="format:%(trailers:key=Acked-by,valueonly)" >actual &&
+	echo "A U Thor <author@example.com>" >expect &&
+	test_cmp expect actual
+'
+
+test_expect_success 'pretty format %(trailers:separator) changes separator' '
+	git log --no-walk --pretty=format:"X%(trailers:separator=%x00,unfold)X" >actual &&
+	printf "XSigned-off-by: A U Thor <author@example.com>\0Acked-by: A U Thor <author@example.com>\0[ v2 updated patch description ]\0Signed-off-by: A U Thor <author@example.com>X" >expect &&
+	test_cmp expect actual
+'
+
+test_expect_success 'pretty format %(trailers) combining separator/key/valueonly' '
+	git commit --allow-empty -F - <<-\EOF &&
+	Important fix
+
+	The fix is explained here
+
+	Closes: #1234
+	EOF
+
+	git commit --allow-empty -F - <<-\EOF &&
+	Another fix
+
+	The fix is explained here
+
+	Closes: #567
+	Closes: #890
+	EOF
+
+	git commit --allow-empty -F - <<-\EOF &&
+	Does not close any tickets
+	EOF
+
+	git log --pretty="%s% (trailers:separator=%x2c%x20,key=Closes,valueonly)" HEAD~3.. >actual &&
+	test_write_lines \
+		"Does not close any tickets" \
+		"Another fix #567, #890" \
+		"Important fix #1234" >expect &&
+	test_cmp expect actual
+'
+
+test_expect_success 'trailer parsing not fooled by --- line' '
+	git commit --allow-empty -F - <<-\EOF &&
+	this is the subject
+
+	This is the body. The message has a "---" line which would confuse a
+	message+patch parser. But here we know we have only a commit message,
+	so we get it right.
+
+	trailer: wrong
+	---
+	This is more body.
+
+	trailer: right
+	EOF
+
+	{
+		echo "trailer: right" &&
+		echo
+	} >expect &&
+	git log --no-walk --format="%(trailers)" >actual &&
+	test_cmp expect actual
+'
+
+test_expect_success 'set up %S tests' '
+	git checkout --orphan source-a &&
+	test_commit one &&
+	test_commit two &&
+	git checkout -b source-b HEAD^ &&
+	test_commit three
+'
+
+test_expect_success 'log --format=%S paints branch names' '
+	cat >expect <<-\EOF &&
+	source-b
+	source-a
+	source-b
+	EOF
+	git log --format=%S source-a source-b >actual &&
+	test_cmp expect actual
+'
+
+test_expect_success 'log --format=%S paints tag names' '
+	git tag -m tagged source-tag &&
+	cat >expect <<-\EOF &&
+	source-tag
+	source-a
+	source-tag
+	EOF
+	git log --format=%S source-tag source-a >actual &&
+	test_cmp expect actual
+'
+
+test_expect_success 'log --format=%S paints symmetric ranges' '
+	cat >expect <<-\EOF &&
+	source-b
+	source-a
+	EOF
+	git log --format=%S source-a...source-b >actual &&
+	test_cmp expect actual
+'
+
+test_expect_success '%S in git log --format works with other placeholders (part 1)' '
+	git log --format="source-b %h" source-b >expect &&
+	git log --format="%S %h" source-b >actual &&
+	test_cmp expect actual
+'
+
+test_expect_success '%S in git log --format works with other placeholders (part 2)' '
+	git log --format="%h source-b" source-b >expect &&
+	git log --format="%h %S" source-b >actual &&
+	test_cmp expect actual
+'
+
+test_expect_success 'log --pretty=reference' '
+	git log --pretty="tformat:%h (%s, %as)" >expect &&
+	git log --pretty=reference >actual &&
+	test_cmp expect actual
+'
+
+test_expect_success 'log --pretty=reference with log.date is overridden by short date' '
+	git log --pretty="tformat:%h (%s, %as)" >expect &&
+	test_config log.date rfc &&
+	git log --pretty=reference >actual &&
+	test_cmp expect actual
+'
+
+test_expect_success 'log --pretty=reference with explicit date overrides short date' '
+	git log --date=rfc --pretty="tformat:%h (%s, %ad)" >expect &&
+	git log --date=rfc --pretty=reference >actual &&
+	test_cmp expect actual
+'
+
+test_expect_success 'log --pretty=reference is never unabbreviated' '
+	git log --pretty="tformat:%h (%s, %as)" >expect &&
+	git log --no-abbrev-commit --pretty=reference >actual &&
+	test_cmp expect actual
+'
+
+test_expect_success 'log --pretty=reference is never decorated' '
+	git log --pretty="tformat:%h (%s, %as)" >expect &&
+	git log --decorate=short --pretty=reference >actual &&
+	test_cmp expect actual
+'
+
+test_expect_success 'log --pretty=reference does not output reflog info' '
+	git log --walk-reflogs --pretty="tformat:%h (%s, %as)" >expect &&
+	git log --walk-reflogs --pretty=reference >actual &&
+	test_cmp expect actual
+'
+
+test_expect_success 'log --pretty=reference is colored appropriately' '
+	git log --color=always --pretty="tformat:%C(auto)%h (%s, %as)" >expect &&
+	git log --color=always --pretty=reference >actual &&
+	test_cmp expect actual
+'
+
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t4208-log-magic-pathspec.sh 1.2.3+git2.25.1-1/git/t/t4208-log-magic-pathspec.sh
--- 1.2.1+git2.18.0-1/git/t/t4208-log-magic-pathspec.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t4208-log-magic-pathspec.sh	2020-02-17 04:47:35.000000000 +0000
@@ -25,6 +25,32 @@ test_expect_success '"git log :/a -- " s
 	git log :/a --
 '
 
+test_expect_success '"git log :/detached -- " should find a commit only in HEAD' '
+	test_when_finished "git checkout master" &&
+	git checkout --detach &&
+	# Must manually call `test_tick` instead of using `test_commit`,
+	# because the latter additionally creates a tag, which would make
+	# the commit reachable not only via HEAD.
+	test_tick &&
+	git commit --allow-empty -m detached &&
+	test_tick &&
+	git commit --allow-empty -m something-else &&
+	git log :/detached --
+'
+
+test_expect_success '"git log :/detached -- " should not find an orphaned commit' '
+	test_must_fail git log :/detached --
+'
+
+test_expect_success '"git log :/detached -- " should find HEAD only of own worktree' '
+	git worktree add other-tree HEAD &&
+	git -C other-tree checkout --detach &&
+	test_tick &&
+	git -C other-tree commit --allow-empty -m other-detached &&
+	git -C other-tree log :/other-detached -- &&
+	test_must_fail git log :/other-detached --
+'
+
 test_expect_success '"git log -- :/a" should not be ambiguous' '
 	git log -- :/a
 '
diff -pruN 1.2.1+git2.18.0-1/git/t/t4209-log-pickaxe.sh 1.2.3+git2.25.1-1/git/t/t4209-log-pickaxe.sh
--- 1.2.1+git2.18.0-1/git/t/t4209-log-pickaxe.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t4209-log-pickaxe.sh	2020-02-17 04:47:35.000000000 +0000
@@ -106,4 +106,39 @@ test_expect_success 'log -S --no-textcon
 	rm .gitattributes
 '
 
+test_expect_success 'setup log -[GS] binary & --text' '
+	git checkout --orphan GS-binary-and-text &&
+	git read-tree --empty &&
+	printf "a\na\0a\n" >data.bin &&
+	git add data.bin &&
+	git commit -m "create binary file" data.bin &&
+	printf "a\na\0a\n" >>data.bin &&
+	git commit -m "modify binary file" data.bin &&
+	git rm data.bin &&
+	git commit -m "delete binary file" data.bin &&
+	git log >full-log
+'
+
+test_expect_success 'log -G ignores binary files' '
+	git log -Ga >log &&
+	test_must_be_empty log
+'
+
+test_expect_success 'log -G looks into binary files with -a' '
+	git log -a -Ga >log &&
+	test_cmp log full-log
+'
+
+test_expect_success 'log -G looks into binary files with textconv filter' '
+	test_when_finished "rm .gitattributes" &&
+	echo "* diff=bin" >.gitattributes &&
+	git -c diff.bin.textconv=cat log -Ga >log &&
+	test_cmp log full-log
+'
+
+test_expect_success 'log -S looks into binary files' '
+	git log -Sa >log &&
+	test_cmp log full-log
+'
+
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t4210-log-i18n.sh 1.2.3+git2.25.1-1/git/t/t4210-log-i18n.sh
--- 1.2.1+git2.18.0-1/git/t/t4210-log-i18n.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t4210-log-i18n.sh	2020-02-17 04:47:35.000000000 +0000
@@ -1,12 +1,15 @@
 #!/bin/sh
 
 test_description='test log with i18n features'
-. ./test-lib.sh
+. ./lib-gettext.sh
 
 # two forms of é
 utf8_e=$(printf '\303\251')
 latin1_e=$(printf '\351')
 
+# invalid UTF-8
+invalid_e=$(printf '\303\50)') # ")" at end to close opening "("
+
 test_expect_success 'create commits in different encodings' '
 	test_tick &&
 	cat >msg <<-EOF &&
@@ -44,15 +47,47 @@ test_expect_success !MINGW 'log --grep s
 '
 
 test_expect_success !MINGW 'log --grep does not find non-reencoded values (utf8)' '
-	>expect &&
 	git log --encoding=utf8 --format=%s --grep=$latin1_e >actual &&
-	test_cmp expect actual
+	test_must_be_empty actual
 '
 
-test_expect_success 'log --grep does not find non-reencoded values (latin1)' '
-	>expect &&
+test_expect_success !MINGW 'log --grep does not find non-reencoded values (latin1)' '
 	git log --encoding=ISO-8859-1 --format=%s --grep=$utf8_e >actual &&
-	test_cmp expect actual
+	test_must_be_empty actual
 '
 
+for engine in fixed basic extended perl
+do
+	prereq=
+	if test $engine = "perl"
+	then
+		prereq="PCRE"
+	else
+		prereq=""
+	fi
+	force_regex=
+	if test $engine != "fixed"
+	then
+	    force_regex=.*
+	fi
+	test_expect_success !MINGW,!REGEX_ILLSEQ,GETTEXT_LOCALE,$prereq "-c grep.patternType=$engine log --grep does not find non-reencoded values (latin1 + locale)" "
+		cat >expect <<-\EOF &&
+		latin1
+		utf8
+		EOF
+		LC_ALL=\"$is_IS_locale\" git -c grep.patternType=$engine log --encoding=ISO-8859-1 --format=%s --grep=\"$force_regex$latin1_e\" >actual &&
+		test_cmp expect actual
+	"
+
+	test_expect_success !MINGW,GETTEXT_LOCALE,$prereq "-c grep.patternType=$engine log --grep does not find non-reencoded values (latin1 + locale)" "
+		LC_ALL=\"$is_IS_locale\" git -c grep.patternType=$engine log --encoding=ISO-8859-1 --format=%s --grep=\"$force_regex$utf8_e\" >actual &&
+		test_must_be_empty actual
+	"
+
+	test_expect_success !MINGW,!REGEX_ILLSEQ,GETTEXT_LOCALE,$prereq "-c grep.patternType=$engine log --grep does not die on invalid UTF-8 value (latin1 + locale + invalid needle)" "
+		LC_ALL=\"$is_IS_locale\" git -c grep.patternType=$engine log --encoding=ISO-8859-1 --format=%s --grep=\"$force_regex$invalid_e\" >actual &&
+		test_must_be_empty actual
+	"
+done
+
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t4211-line-log.sh 1.2.3+git2.25.1-1/git/t/t4211-line-log.sh
--- 1.2.1+git2.18.0-1/git/t/t4211-line-log.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t4211-line-log.sh	2020-02-17 04:47:35.000000000 +0000
@@ -25,7 +25,7 @@ canned_test_failure () {
 test_bad_opts () {
 	test_expect_success "invalid args: $1" "
 		test_must_fail git log $1 2>errors &&
-		grep '$2' errors
+		test_i18ngrep '$2' errors
 	"
 }
 
@@ -60,7 +60,6 @@ test_bad_opts "-L 1:nonexistent" "There
 test_bad_opts "-L 1:simple" "There is no path"
 test_bad_opts "-L '/foo:b.c'" "argument not .start,end:file"
 test_bad_opts "-L 1000:b.c" "has only.*lines"
-test_bad_opts "-L 1,1000:b.c" "has only.*lines"
 test_bad_opts "-L :b.c" "argument not .start,end:file"
 test_bad_opts "-L :foo:b.c" "no match"
 
@@ -86,12 +85,12 @@ test_expect_success '-L ,Y (Y == nlines)
 
 test_expect_success '-L ,Y (Y == nlines + 1)' '
 	n=$(expr $(wc -l <b.c) + 1) &&
-	test_must_fail git log -L ,$n:b.c
+	git log -L ,$n:b.c
 '
 
 test_expect_success '-L ,Y (Y == nlines + 2)' '
 	n=$(expr $(wc -l <b.c) + 2) &&
-	test_must_fail git log -L ,$n:b.c
+	git log -L ,$n:b.c
 '
 
 test_expect_success '-L with --first-parent and a merge' '
@@ -102,7 +101,7 @@ test_expect_success '-L with --first-par
 test_expect_success '-L with --output' '
 	git checkout parallel-change &&
 	git log --output=log -L :main:b.c >output &&
-	test ! -s output &&
+	test_must_be_empty output &&
 	test_line_count = 70 log
 '
 
@@ -116,4 +115,103 @@ test_expect_success 'range_set_union' '
 	git log $(for x in $(test_seq 200); do echo -L $((2*x)),+1:c.c; done)
 '
 
+test_expect_success '-s shows only line-log commits' '
+	git log --format="commit %s" -L1,24:b.c >expect.raw &&
+	grep ^commit expect.raw >expect &&
+	git log --format="commit %s" -L1,24:b.c -s >actual &&
+	test_cmp expect actual
+'
+
+test_expect_success '-p shows the default patch output' '
+	git log -L1,24:b.c >expect &&
+	git log -L1,24:b.c -p >actual &&
+	test_cmp expect actual
+'
+
+test_expect_success '--raw is forbidden' '
+	test_must_fail git log -L1,24:b.c --raw
+'
+
+test_expect_success 'setup for checking fancy rename following' '
+	git checkout --orphan moves-start &&
+	git reset --hard &&
+
+	printf "%s\n"    12 13 14 15      b c d e   >file-1 &&
+	printf "%s\n"    22 23 24 25      B C D E   >file-2 &&
+	git add file-1 file-2 &&
+	test_tick &&
+	git commit -m "Add file-1 and file-2" &&
+	oid_add_f1_f2=$(git rev-parse --short HEAD) &&
+
+	git checkout -b moves-main &&
+	printf "%s\n" 11 12 13 14 15      b c d e   >file-1 &&
+	git commit -a -m "Modify file-1 on main" &&
+	oid_mod_f1_main=$(git rev-parse --short HEAD) &&
+
+	printf "%s\n" 21 22 23 24 25      B C D E   >file-2 &&
+	git commit -a -m "Modify file-2 on main #1" &&
+	oid_mod_f2_main_1=$(git rev-parse --short HEAD) &&
+
+	git mv file-1 renamed-1 &&
+	git commit -m "Rename file-1 to renamed-1 on main" &&
+
+	printf "%s\n" 11 12 13 14 15      b c d e f >renamed-1 &&
+	git commit -a -m "Modify renamed-1 on main" &&
+	oid_mod_r1_main=$(git rev-parse --short HEAD) &&
+
+	printf "%s\n" 21 22 23 24 25      B C D E F >file-2 &&
+	git commit -a -m "Modify file-2 on main #2" &&
+	oid_mod_f2_main_2=$(git rev-parse --short HEAD) &&
+
+	git checkout -b moves-side moves-start &&
+	printf "%s\n"    12 13 14 15 16   b c d e   >file-1 &&
+	git commit -a -m "Modify file-1 on side #1" &&
+	oid_mod_f1_side_1=$(git rev-parse --short HEAD) &&
+
+	printf "%s\n"    22 23 24 25 26   B C D E   >file-2 &&
+	git commit -a -m "Modify file-2 on side" &&
+	oid_mod_f2_side=$(git rev-parse --short HEAD) &&
+
+	git mv file-2 renamed-2 &&
+	git commit -m "Rename file-2 to renamed-2 on side" &&
+
+	printf "%s\n"    12 13 14 15 16 a b c d e   >file-1 &&
+	git commit -a -m "Modify file-1 on side #2" &&
+	oid_mod_f1_side_2=$(git rev-parse --short HEAD) &&
+
+	printf "%s\n"    22 23 24 25 26 A B C D E   >renamed-2 &&
+	git commit -a -m "Modify renamed-2 on side" &&
+	oid_mod_r2_side=$(git rev-parse --short HEAD) &&
+
+	git checkout moves-main &&
+	git merge moves-side &&
+	oid_merge=$(git rev-parse --short HEAD)
+'
+
+test_expect_success 'fancy rename following #1' '
+	cat >expect <<-EOF &&
+	$oid_merge Merge branch '\''moves-side'\'' into moves-main
+	$oid_mod_f1_side_2 Modify file-1 on side #2
+	$oid_mod_f1_side_1 Modify file-1 on side #1
+	$oid_mod_r1_main Modify renamed-1 on main
+	$oid_mod_f1_main Modify file-1 on main
+	$oid_add_f1_f2 Add file-1 and file-2
+	EOF
+	git log -L1:renamed-1 --oneline --no-patch >actual &&
+	test_cmp expect actual
+'
+
+test_expect_success 'fancy rename following #2' '
+	cat >expect <<-EOF &&
+	$oid_merge Merge branch '\''moves-side'\'' into moves-main
+	$oid_mod_r2_side Modify renamed-2 on side
+	$oid_mod_f2_side Modify file-2 on side
+	$oid_mod_f2_main_2 Modify file-2 on main #2
+	$oid_mod_f2_main_1 Modify file-2 on main #1
+	$oid_add_f1_f2 Add file-1 and file-2
+	EOF
+	git log -L1:renamed-2 --oneline --no-patch >actual &&
+	test_cmp expect actual
+'
+
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t4212-log-corrupt.sh 1.2.3+git2.25.1-1/git/t/t4212-log-corrupt.sh
--- 1.2.1+git2.18.0-1/git/t/t4212-log-corrupt.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t4212-log-corrupt.sh	2020-02-17 04:47:35.000000000 +0000
@@ -26,22 +26,20 @@ test_expect_success 'git log with broken
 		echo
 		echo "    foo"
 	} >expect.out &&
-	: >expect.err &&
 
 	git log broken_email >actual.out 2>actual.err &&
 
 	test_cmp expect.out actual.out &&
-	test_cmp expect.err actual.err
+	test_must_be_empty actual.err
 '
 
 test_expect_success 'git log --format with broken author email' '
 	echo "A U Thor+author@example.com+Thu Apr 7 15:13:13 2005 -0700" >expect.out &&
-	: >expect.err &&
 
 	git log --format="%an+%ae+%ad" broken_email >actual.out 2>actual.err &&
 
 	test_cmp expect.out actual.out &&
-	test_cmp expect.err actual.err
+	test_must_be_empty actual.err
 '
 
 munge_author_date () {
diff -pruN 1.2.1+git2.18.0-1/git/t/t4213-log-tabexpand.sh 1.2.3+git2.25.1-1/git/t/t4213-log-tabexpand.sh
--- 1.2.1+git2.18.0-1/git/t/t4213-log-tabexpand.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t4213-log-tabexpand.sh	2020-02-17 04:47:35.000000000 +0000
@@ -36,7 +36,7 @@ count_expand ()
 	esac
 
 	# Prefix the output with the command line arguments, and
-	# replace SP with a dot both in the expecte and actual output
+	# replace SP with a dot both in the expected and actual output
 	# so that test_cmp would show the difference together with the
 	# breakage in a way easier to consume by the debugging user.
 	{
diff -pruN 1.2.1+git2.18.0-1/git/t/t4214-log-graph-octopus.sh 1.2.3+git2.25.1-1/git/t/t4214-log-graph-octopus.sh
--- 1.2.1+git2.18.0-1/git/t/t4214-log-graph-octopus.sh	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t4214-log-graph-octopus.sh	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,377 @@
+#!/bin/sh
+
+test_description='git log --graph of skewed left octopus merge.'
+
+. ./test-lib.sh
+
+test_expect_success 'set up merge history' '
+	test_commit initial &&
+	for i in 1 2 3 4 ; do
+		git checkout master -b $i || return $?
+		# Make tag name different from branch name, to avoid
+		# ambiguity error when calling checkout.
+		test_commit $i $i $i tag$i || return $?
+	done &&
+	git checkout 1 -b merge &&
+	test_merge octopus-merge 1 2 3 4 &&
+	test_commit after-merge &&
+	git checkout 1 -b L &&
+	test_commit left &&
+	git checkout 4 -b crossover &&
+	test_commit after-4 &&
+	git checkout initial -b more-L &&
+	test_commit after-initial
+'
+
+test_expect_success 'log --graph with tricky octopus merge, no color' '
+	cat >expect.uncolored <<-\EOF &&
+	* left
+	| *-.   octopus-merge
+	|/|\ \
+	| | | * 4
+	| | * | 3
+	| | |/
+	| * / 2
+	| |/
+	* / 1
+	|/
+	* initial
+	EOF
+	git log --color=never --graph --date-order --pretty=tformat:%s left octopus-merge >actual.raw &&
+	sed "s/ *\$//" actual.raw >actual &&
+	test_cmp expect.uncolored actual
+'
+
+test_expect_success 'log --graph with tricky octopus merge with colors' '
+	test_config log.graphColors red,green,yellow,blue,magenta,cyan &&
+	cat >expect.colors <<-\EOF &&
+	* left
+	<RED>|<RESET> *<MAGENTA>-<RESET><MAGENTA>.<RESET>   octopus-merge
+	<RED>|<RESET><RED>/<RESET><YELLOW>|<RESET><BLUE>\<RESET> <MAGENTA>\<RESET>
+	<RED>|<RESET> <YELLOW>|<RESET> <BLUE>|<RESET> * 4
+	<RED>|<RESET> <YELLOW>|<RESET> * <MAGENTA>|<RESET> 3
+	<RED>|<RESET> <YELLOW>|<RESET> <MAGENTA>|<RESET><MAGENTA>/<RESET>
+	<RED>|<RESET> * <MAGENTA>/<RESET> 2
+	<RED>|<RESET> <MAGENTA>|<RESET><MAGENTA>/<RESET>
+	* <MAGENTA>/<RESET> 1
+	<MAGENTA>|<RESET><MAGENTA>/<RESET>
+	* initial
+	EOF
+	git log --color=always --graph --date-order --pretty=tformat:%s left octopus-merge >actual.colors.raw &&
+	test_decode_color <actual.colors.raw | sed "s/ *\$//" >actual.colors &&
+	test_cmp expect.colors actual.colors
+'
+
+# Repeat the previous two tests with "normal" octopus merge (i.e.,
+# without the first parent skewing to the "left" branch column).
+
+test_expect_success 'log --graph with normal octopus merge, no color' '
+	cat >expect.uncolored <<-\EOF &&
+	*---.   octopus-merge
+	|\ \ \
+	| | | * 4
+	| | * | 3
+	| | |/
+	| * / 2
+	| |/
+	* / 1
+	|/
+	* initial
+	EOF
+	git log --color=never --graph --date-order --pretty=tformat:%s octopus-merge >actual.raw &&
+	sed "s/ *\$//" actual.raw >actual &&
+	test_cmp expect.uncolored actual
+'
+
+test_expect_success 'log --graph with normal octopus merge with colors' '
+	cat >expect.colors <<-\EOF &&
+	*<YELLOW>-<RESET><YELLOW>-<RESET><BLUE>-<RESET><BLUE>.<RESET>   octopus-merge
+	<RED>|<RESET><GREEN>\<RESET> <YELLOW>\<RESET> <BLUE>\<RESET>
+	<RED>|<RESET> <GREEN>|<RESET> <YELLOW>|<RESET> * 4
+	<RED>|<RESET> <GREEN>|<RESET> * <BLUE>|<RESET> 3
+	<RED>|<RESET> <GREEN>|<RESET> <BLUE>|<RESET><BLUE>/<RESET>
+	<RED>|<RESET> * <BLUE>/<RESET> 2
+	<RED>|<RESET> <BLUE>|<RESET><BLUE>/<RESET>
+	* <BLUE>/<RESET> 1
+	<BLUE>|<RESET><BLUE>/<RESET>
+	* initial
+	EOF
+	test_config log.graphColors red,green,yellow,blue,magenta,cyan &&
+	git log --color=always --graph --date-order --pretty=tformat:%s octopus-merge >actual.colors.raw &&
+	test_decode_color <actual.colors.raw | sed "s/ *\$//" >actual.colors &&
+	test_cmp expect.colors actual.colors
+'
+
+test_expect_success 'log --graph with normal octopus merge and child, no color' '
+	cat >expect.uncolored <<-\EOF &&
+	* after-merge
+	*---.   octopus-merge
+	|\ \ \
+	| | | * 4
+	| | * | 3
+	| | |/
+	| * / 2
+	| |/
+	* / 1
+	|/
+	* initial
+	EOF
+	git log --color=never --graph --date-order --pretty=tformat:%s after-merge >actual.raw &&
+	sed "s/ *\$//" actual.raw >actual &&
+	test_cmp expect.uncolored actual
+'
+
+test_expect_success 'log --graph with normal octopus and child merge with colors' '
+	cat >expect.colors <<-\EOF &&
+	* after-merge
+	*<BLUE>-<RESET><BLUE>-<RESET><MAGENTA>-<RESET><MAGENTA>.<RESET>   octopus-merge
+	<GREEN>|<RESET><YELLOW>\<RESET> <BLUE>\<RESET> <MAGENTA>\<RESET>
+	<GREEN>|<RESET> <YELLOW>|<RESET> <BLUE>|<RESET> * 4
+	<GREEN>|<RESET> <YELLOW>|<RESET> * <MAGENTA>|<RESET> 3
+	<GREEN>|<RESET> <YELLOW>|<RESET> <MAGENTA>|<RESET><MAGENTA>/<RESET>
+	<GREEN>|<RESET> * <MAGENTA>/<RESET> 2
+	<GREEN>|<RESET> <MAGENTA>|<RESET><MAGENTA>/<RESET>
+	* <MAGENTA>/<RESET> 1
+	<MAGENTA>|<RESET><MAGENTA>/<RESET>
+	* initial
+	EOF
+	test_config log.graphColors red,green,yellow,blue,magenta,cyan &&
+	git log --color=always --graph --date-order --pretty=tformat:%s after-merge >actual.colors.raw &&
+	test_decode_color <actual.colors.raw | sed "s/ *\$//" >actual.colors &&
+	test_cmp expect.colors actual.colors
+'
+
+test_expect_success 'log --graph with tricky octopus merge and its child, no color' '
+	cat >expect.uncolored <<-\EOF &&
+	* left
+	| * after-merge
+	| *-.   octopus-merge
+	|/|\ \
+	| | | * 4
+	| | * | 3
+	| | |/
+	| * / 2
+	| |/
+	* / 1
+	|/
+	* initial
+	EOF
+	git log --color=never --graph --date-order --pretty=tformat:%s left after-merge >actual.raw &&
+	sed "s/ *\$//" actual.raw >actual &&
+	test_cmp expect.uncolored actual
+'
+
+test_expect_success 'log --graph with tricky octopus merge and its child with colors' '
+	test_config log.graphColors red,green,yellow,blue,magenta,cyan &&
+	cat >expect.colors <<-\EOF &&
+	* left
+	<RED>|<RESET> * after-merge
+	<RED>|<RESET> *<CYAN>-<RESET><CYAN>.<RESET>   octopus-merge
+	<RED>|<RESET><RED>/<RESET><BLUE>|<RESET><MAGENTA>\<RESET> <CYAN>\<RESET>
+	<RED>|<RESET> <BLUE>|<RESET> <MAGENTA>|<RESET> * 4
+	<RED>|<RESET> <BLUE>|<RESET> * <CYAN>|<RESET> 3
+	<RED>|<RESET> <BLUE>|<RESET> <CYAN>|<RESET><CYAN>/<RESET>
+	<RED>|<RESET> * <CYAN>/<RESET> 2
+	<RED>|<RESET> <CYAN>|<RESET><CYAN>/<RESET>
+	* <CYAN>/<RESET> 1
+	<CYAN>|<RESET><CYAN>/<RESET>
+	* initial
+	EOF
+	git log --color=always --graph --date-order --pretty=tformat:%s left after-merge >actual.colors.raw &&
+	test_decode_color <actual.colors.raw | sed "s/ *\$//" >actual.colors &&
+	test_cmp expect.colors actual.colors
+'
+
+test_expect_success 'log --graph with crossover in octopus merge, no color' '
+	cat >expect.uncolored <<-\EOF &&
+	* after-4
+	| *---.   octopus-merge
+	| |\ \ \
+	| |_|_|/
+	|/| | |
+	* | | | 4
+	| | | * 3
+	| |_|/
+	|/| |
+	| | * 2
+	| |/
+	|/|
+	| * 1
+	|/
+	* initial
+	EOF
+	git log --color=never --graph --date-order --pretty=tformat:%s after-4 octopus-merge >actual.raw &&
+	sed "s/ *\$//" actual.raw >actual &&
+	test_cmp expect.uncolored actual
+'
+
+test_expect_success 'log --graph with crossover in octopus merge with colors' '
+	test_config log.graphColors red,green,yellow,blue,magenta,cyan &&
+	cat >expect.colors <<-\EOF &&
+	* after-4
+	<RED>|<RESET> *<BLUE>-<RESET><BLUE>-<RESET><RED>-<RESET><RED>.<RESET>   octopus-merge
+	<RED>|<RESET> <GREEN>|<RESET><YELLOW>\<RESET> <BLUE>\<RESET> <RED>\<RESET>
+	<RED>|<RESET> <GREEN>|<RESET><RED>_<RESET><YELLOW>|<RESET><RED>_<RESET><BLUE>|<RESET><RED>/<RESET>
+	<RED>|<RESET><RED>/<RESET><GREEN>|<RESET> <YELLOW>|<RESET> <BLUE>|<RESET>
+	* <GREEN>|<RESET> <YELLOW>|<RESET> <BLUE>|<RESET> 4
+	<MAGENTA>|<RESET> <GREEN>|<RESET> <YELLOW>|<RESET> * 3
+	<MAGENTA>|<RESET> <GREEN>|<RESET><MAGENTA>_<RESET><YELLOW>|<RESET><MAGENTA>/<RESET>
+	<MAGENTA>|<RESET><MAGENTA>/<RESET><GREEN>|<RESET> <YELLOW>|<RESET>
+	<MAGENTA>|<RESET> <GREEN>|<RESET> * 2
+	<MAGENTA>|<RESET> <GREEN>|<RESET><MAGENTA>/<RESET>
+	<MAGENTA>|<RESET><MAGENTA>/<RESET><GREEN>|<RESET>
+	<MAGENTA>|<RESET> * 1
+	<MAGENTA>|<RESET><MAGENTA>/<RESET>
+	* initial
+	EOF
+	git log --color=always --graph --date-order --pretty=tformat:%s after-4 octopus-merge >actual.colors.raw &&
+	test_decode_color <actual.colors.raw | sed "s/ *\$//" >actual.colors &&
+	test_cmp expect.colors actual.colors
+'
+
+test_expect_success 'log --graph with crossover in octopus merge and its child, no color' '
+	cat >expect.uncolored <<-\EOF &&
+	* after-4
+	| * after-merge
+	| *---.   octopus-merge
+	| |\ \ \
+	| |_|_|/
+	|/| | |
+	* | | | 4
+	| | | * 3
+	| |_|/
+	|/| |
+	| | * 2
+	| |/
+	|/|
+	| * 1
+	|/
+	* initial
+	EOF
+	git log --color=never --graph --date-order --pretty=tformat:%s after-4 after-merge >actual.raw &&
+	sed "s/ *\$//" actual.raw >actual &&
+	test_cmp expect.uncolored actual
+'
+
+test_expect_success 'log --graph with crossover in octopus merge and its child with colors' '
+	test_config log.graphColors red,green,yellow,blue,magenta,cyan &&
+	cat >expect.colors <<-\EOF &&
+	* after-4
+	<RED>|<RESET> * after-merge
+	<RED>|<RESET> *<MAGENTA>-<RESET><MAGENTA>-<RESET><RED>-<RESET><RED>.<RESET>   octopus-merge
+	<RED>|<RESET> <YELLOW>|<RESET><BLUE>\<RESET> <MAGENTA>\<RESET> <RED>\<RESET>
+	<RED>|<RESET> <YELLOW>|<RESET><RED>_<RESET><BLUE>|<RESET><RED>_<RESET><MAGENTA>|<RESET><RED>/<RESET>
+	<RED>|<RESET><RED>/<RESET><YELLOW>|<RESET> <BLUE>|<RESET> <MAGENTA>|<RESET>
+	* <YELLOW>|<RESET> <BLUE>|<RESET> <MAGENTA>|<RESET> 4
+	<CYAN>|<RESET> <YELLOW>|<RESET> <BLUE>|<RESET> * 3
+	<CYAN>|<RESET> <YELLOW>|<RESET><CYAN>_<RESET><BLUE>|<RESET><CYAN>/<RESET>
+	<CYAN>|<RESET><CYAN>/<RESET><YELLOW>|<RESET> <BLUE>|<RESET>
+	<CYAN>|<RESET> <YELLOW>|<RESET> * 2
+	<CYAN>|<RESET> <YELLOW>|<RESET><CYAN>/<RESET>
+	<CYAN>|<RESET><CYAN>/<RESET><YELLOW>|<RESET>
+	<CYAN>|<RESET> * 1
+	<CYAN>|<RESET><CYAN>/<RESET>
+	* initial
+	EOF
+	git log --color=always --graph --date-order --pretty=tformat:%s after-4 after-merge >actual.colors.raw &&
+	test_decode_color <actual.colors.raw | sed "s/ *\$//" >actual.colors &&
+	test_cmp expect.colors actual.colors
+'
+
+test_expect_success 'log --graph with unrelated commit and octopus tip, no color' '
+	cat >expect.uncolored <<-\EOF &&
+	* after-initial
+	| *---.   octopus-merge
+	| |\ \ \
+	| | | | * 4
+	| |_|_|/
+	|/| | |
+	| | | * 3
+	| |_|/
+	|/| |
+	| | * 2
+	| |/
+	|/|
+	| * 1
+	|/
+	* initial
+	EOF
+	git log --color=never --graph --date-order --pretty=tformat:%s after-initial octopus-merge >actual.raw &&
+	sed "s/ *\$//" actual.raw >actual &&
+	test_cmp expect.uncolored actual
+'
+
+test_expect_success 'log --graph with unrelated commit and octopus tip with colors' '
+	test_config log.graphColors red,green,yellow,blue,magenta,cyan &&
+	cat >expect.colors <<-\EOF &&
+	* after-initial
+	<RED>|<RESET> *<BLUE>-<RESET><BLUE>-<RESET><MAGENTA>-<RESET><MAGENTA>.<RESET>   octopus-merge
+	<RED>|<RESET> <GREEN>|<RESET><YELLOW>\<RESET> <BLUE>\<RESET> <MAGENTA>\<RESET>
+	<RED>|<RESET> <GREEN>|<RESET> <YELLOW>|<RESET> <BLUE>|<RESET> * 4
+	<RED>|<RESET> <GREEN>|<RESET><RED>_<RESET><YELLOW>|<RESET><RED>_<RESET><BLUE>|<RESET><RED>/<RESET>
+	<RED>|<RESET><RED>/<RESET><GREEN>|<RESET> <YELLOW>|<RESET> <BLUE>|<RESET>
+	<RED>|<RESET> <GREEN>|<RESET> <YELLOW>|<RESET> * 3
+	<RED>|<RESET> <GREEN>|<RESET><RED>_<RESET><YELLOW>|<RESET><RED>/<RESET>
+	<RED>|<RESET><RED>/<RESET><GREEN>|<RESET> <YELLOW>|<RESET>
+	<RED>|<RESET> <GREEN>|<RESET> * 2
+	<RED>|<RESET> <GREEN>|<RESET><RED>/<RESET>
+	<RED>|<RESET><RED>/<RESET><GREEN>|<RESET>
+	<RED>|<RESET> * 1
+	<RED>|<RESET><RED>/<RESET>
+	* initial
+	EOF
+	git log --color=always --graph --date-order --pretty=tformat:%s after-initial octopus-merge >actual.colors.raw &&
+	test_decode_color <actual.colors.raw | sed "s/ *\$//" >actual.colors &&
+	test_cmp expect.colors actual.colors
+'
+
+test_expect_success 'log --graph with unrelated commit and octopus child, no color' '
+	cat >expect.uncolored <<-\EOF &&
+	* after-initial
+	| * after-merge
+	| *---.   octopus-merge
+	| |\ \ \
+	| | | | * 4
+	| |_|_|/
+	|/| | |
+	| | | * 3
+	| |_|/
+	|/| |
+	| | * 2
+	| |/
+	|/|
+	| * 1
+	|/
+	* initial
+	EOF
+	git log --color=never --graph --date-order --pretty=tformat:%s after-initial after-merge >actual.raw &&
+	sed "s/ *\$//" actual.raw >actual &&
+	test_cmp expect.uncolored actual
+'
+
+test_expect_success 'log --graph with unrelated commit and octopus child with colors' '
+	test_config log.graphColors red,green,yellow,blue,magenta,cyan &&
+	cat >expect.colors <<-\EOF &&
+	* after-initial
+	<RED>|<RESET> * after-merge
+	<RED>|<RESET> *<MAGENTA>-<RESET><MAGENTA>-<RESET><CYAN>-<RESET><CYAN>.<RESET>   octopus-merge
+	<RED>|<RESET> <YELLOW>|<RESET><BLUE>\<RESET> <MAGENTA>\<RESET> <CYAN>\<RESET>
+	<RED>|<RESET> <YELLOW>|<RESET> <BLUE>|<RESET> <MAGENTA>|<RESET> * 4
+	<RED>|<RESET> <YELLOW>|<RESET><RED>_<RESET><BLUE>|<RESET><RED>_<RESET><MAGENTA>|<RESET><RED>/<RESET>
+	<RED>|<RESET><RED>/<RESET><YELLOW>|<RESET> <BLUE>|<RESET> <MAGENTA>|<RESET>
+	<RED>|<RESET> <YELLOW>|<RESET> <BLUE>|<RESET> * 3
+	<RED>|<RESET> <YELLOW>|<RESET><RED>_<RESET><BLUE>|<RESET><RED>/<RESET>
+	<RED>|<RESET><RED>/<RESET><YELLOW>|<RESET> <BLUE>|<RESET>
+	<RED>|<RESET> <YELLOW>|<RESET> * 2
+	<RED>|<RESET> <YELLOW>|<RESET><RED>/<RESET>
+	<RED>|<RESET><RED>/<RESET><YELLOW>|<RESET>
+	<RED>|<RESET> * 1
+	<RED>|<RESET><RED>/<RESET>
+	* initial
+	EOF
+	git log --color=always --graph --date-order --pretty=tformat:%s after-initial after-merge >actual.colors.raw &&
+	test_decode_color <actual.colors.raw | sed "s/ *\$//" >actual.colors &&
+	test_cmp expect.colors actual.colors
+'
+
+test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t4215-log-skewed-merges.sh 1.2.3+git2.25.1-1/git/t/t4215-log-skewed-merges.sh
--- 1.2.1+git2.18.0-1/git/t/t4215-log-skewed-merges.sh	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t4215-log-skewed-merges.sh	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,314 @@
+#!/bin/sh
+
+test_description='git log --graph of skewed merges'
+
+. ./test-lib.sh
+
+check_graph () {
+	cat >expect &&
+	git log --graph --pretty=tformat:%s "$@" >actual.raw &&
+	sed "s/ *$//" actual.raw >actual &&
+	test_cmp expect actual
+}
+
+test_expect_success 'log --graph with merge fusing with its left and right neighbors' '
+	git checkout --orphan _p &&
+	test_commit A &&
+	test_commit B &&
+	git checkout -b _q @^ && test_commit C &&
+	git checkout -b _r @^ && test_commit D &&
+	git checkout _p && git merge --no-ff _q _r -m E &&
+	git checkout _r && test_commit F &&
+	git checkout _p && git merge --no-ff _r -m G &&
+	git checkout @^^ && git merge --no-ff _p -m H &&
+
+	check_graph <<-\EOF
+	*   H
+	|\
+	| *   G
+	| |\
+	| | * F
+	| * | E
+	|/|\|
+	| | * D
+	| * | C
+	| |/
+	* / B
+	|/
+	* A
+	EOF
+'
+
+test_expect_success 'log --graph with left-skewed merge' '
+	git checkout --orphan 0_p && test_commit 0_A &&
+	git checkout -b 0_q 0_p && test_commit 0_B &&
+	git checkout -b 0_r 0_p &&
+	test_commit 0_C &&
+	test_commit 0_D &&
+	git checkout -b 0_s 0_p && test_commit 0_E &&
+	git checkout -b 0_t 0_p && git merge --no-ff 0_r^ 0_s -m 0_F &&
+	git checkout 0_p && git merge --no-ff 0_s -m 0_G &&
+	git checkout @^ && git merge --no-ff 0_q 0_r 0_t 0_p -m 0_H &&
+
+	check_graph <<-\EOF
+	*-----.   0_H
+	|\ \ \ \
+	| | | | * 0_G
+	| |_|_|/|
+	|/| | | |
+	| | | * | 0_F
+	| |_|/|\|
+	|/| | | |
+	| | | | * 0_E
+	| |_|_|/
+	|/| | |
+	| | * | 0_D
+	| | |/
+	| | * 0_C
+	| |/
+	|/|
+	| * 0_B
+	|/
+	* 0_A
+	EOF
+'
+
+test_expect_success 'log --graph with nested left-skewed merge' '
+	git checkout --orphan 1_p &&
+	test_commit 1_A &&
+	test_commit 1_B &&
+	test_commit 1_C &&
+	git checkout -b 1_q @^ && test_commit 1_D &&
+	git checkout 1_p && git merge --no-ff 1_q -m 1_E &&
+	git checkout -b 1_r @~3 && test_commit 1_F &&
+	git checkout 1_p && git merge --no-ff 1_r -m 1_G &&
+	git checkout @^^ && git merge --no-ff 1_p -m 1_H &&
+
+	check_graph <<-\EOF
+	*   1_H
+	|\
+	| *   1_G
+	| |\
+	| | * 1_F
+	| * | 1_E
+	|/| |
+	| * | 1_D
+	* | | 1_C
+	|/ /
+	* / 1_B
+	|/
+	* 1_A
+	EOF
+'
+
+test_expect_success 'log --graph with nested left-skewed merge following normal merge' '
+	git checkout --orphan 2_p &&
+	test_commit 2_A &&
+	test_commit 2_B &&
+	test_commit 2_C &&
+	git checkout -b 2_q @^^ &&
+	test_commit 2_D &&
+	test_commit 2_E &&
+	git checkout -b 2_r @^ && test_commit 2_F &&
+	git checkout 2_q &&
+	git merge --no-ff 2_r -m 2_G &&
+	git merge --no-ff 2_p^ -m 2_H &&
+	git checkout -b 2_s @^^ && git merge --no-ff 2_q -m 2_J &&
+	git checkout 2_p && git merge --no-ff 2_s -m 2_K &&
+
+	check_graph <<-\EOF
+	*   2_K
+	|\
+	| *   2_J
+	| |\
+	| | *   2_H
+	| | |\
+	| | * | 2_G
+	| |/| |
+	| | * | 2_F
+	| * | | 2_E
+	| |/ /
+	| * | 2_D
+	* | | 2_C
+	| |/
+	|/|
+	* | 2_B
+	|/
+	* 2_A
+	EOF
+'
+
+test_expect_success 'log --graph with nested right-skewed merge following left-skewed merge' '
+	git checkout --orphan 3_p &&
+	test_commit 3_A &&
+	git checkout -b 3_q &&
+	test_commit 3_B &&
+	test_commit 3_C &&
+	git checkout -b 3_r @^ &&
+	test_commit 3_D &&
+	git checkout 3_q && git merge --no-ff 3_r -m 3_E &&
+	git checkout 3_p && git merge --no-ff 3_q -m 3_F &&
+	git checkout 3_r && test_commit 3_G &&
+	git checkout 3_p && git merge --no-ff 3_r -m 3_H &&
+	git checkout @^^ && git merge --no-ff 3_p -m 3_J &&
+
+	check_graph <<-\EOF
+	*   3_J
+	|\
+	| *   3_H
+	| |\
+	| | * 3_G
+	| * | 3_F
+	|/| |
+	| * | 3_E
+	| |\|
+	| | * 3_D
+	| * | 3_C
+	| |/
+	| * 3_B
+	|/
+	* 3_A
+	EOF
+'
+
+test_expect_success 'log --graph with right-skewed merge following a left-skewed one' '
+	git checkout --orphan 4_p &&
+	test_commit 4_A &&
+	test_commit 4_B &&
+	test_commit 4_C &&
+	git checkout -b 4_q @^^ && test_commit 4_D &&
+	git checkout -b 4_r 4_p^ && git merge --no-ff 4_q -m 4_E &&
+	git checkout -b 4_s 4_p^^ &&
+	git merge --no-ff 4_r -m 4_F &&
+	git merge --no-ff 4_p -m 4_G &&
+	git checkout @^^ && git merge --no-ff 4_s -m 4_H &&
+
+	check_graph --date-order <<-\EOF
+	*   4_H
+	|\
+	| *   4_G
+	| |\
+	| * | 4_F
+	|/| |
+	| * |   4_E
+	| |\ \
+	| | * | 4_D
+	| |/ /
+	|/| |
+	| | * 4_C
+	| |/
+	| * 4_B
+	|/
+	* 4_A
+	EOF
+'
+
+test_expect_success 'log --graph with octopus merge with column joining its penultimate parent' '
+	git checkout --orphan 5_p &&
+	test_commit 5_A &&
+	git branch 5_q &&
+	git branch 5_r &&
+	test_commit 5_B &&
+	git checkout 5_q && test_commit 5_C &&
+	git checkout 5_r && test_commit 5_D &&
+	git checkout 5_p &&
+	git merge --no-ff 5_q 5_r -m 5_E &&
+	git checkout 5_q && test_commit 5_F &&
+	git checkout -b 5_s 5_p^ &&
+	git merge --no-ff 5_p 5_q -m 5_G &&
+	git checkout 5_r &&
+	git merge --no-ff 5_s -m 5_H &&
+
+	check_graph <<-\EOF
+	*   5_H
+	|\
+	| *-.   5_G
+	| |\ \
+	| | | * 5_F
+	| | * |   5_E
+	| |/|\ \
+	| |_|/ /
+	|/| | /
+	| | |/
+	* | | 5_D
+	| | * 5_C
+	| |/
+	|/|
+	| * 5_B
+	|/
+	* 5_A
+	EOF
+'
+
+test_expect_success 'log --graph with multiple tips' '
+	git checkout --orphan 6_1 &&
+	test_commit 6_A &&
+	git branch 6_2 &&
+	git branch 6_4 &&
+	test_commit 6_B &&
+	git branch 6_3 &&
+	test_commit 6_C &&
+	git checkout 6_2 && test_commit 6_D &&
+	git checkout 6_3 && test_commit 6_E &&
+	git checkout -b 6_5 6_1 &&
+	git merge --no-ff 6_2 -m 6_F &&
+	git checkout 6_4 && test_commit 6_G &&
+	git checkout 6_3 &&
+	git merge --no-ff 6_4 -m 6_H &&
+	git checkout 6_1 &&
+	git merge --no-ff 6_2 -m 6_I &&
+
+	check_graph 6_1 6_3 6_5 <<-\EOF
+	*   6_I
+	|\
+	| | *   6_H
+	| | |\
+	| | | * 6_G
+	| | * | 6_E
+	| | | | * 6_F
+	| |_|_|/|
+	|/| | |/
+	| | |/|
+	| |/| |
+	| * | | 6_D
+	| | |/
+	| |/|
+	* | | 6_C
+	| |/
+	|/|
+	* | 6_B
+	|/
+	* 6_A
+	EOF
+'
+
+test_expect_success 'log --graph with multiple tips and colors' '
+	test_config log.graphColors red,green,yellow,blue,magenta,cyan &&
+	cat >expect.colors <<-\EOF &&
+	*   6_I
+	<RED>|<RESET><GREEN>\<RESET>
+	<RED>|<RESET> <GREEN>|<RESET> *   6_H
+	<RED>|<RESET> <GREEN>|<RESET> <YELLOW>|<RESET><BLUE>\<RESET>
+	<RED>|<RESET> <GREEN>|<RESET> <YELLOW>|<RESET> * 6_G
+	<RED>|<RESET> <GREEN>|<RESET> <YELLOW>|<RESET> <BLUE>|<RESET> * 6_F
+	<RED>|<RESET> <GREEN>|<RESET><RED>_<RESET><YELLOW>|<RESET><RED>_<RESET><BLUE>|<RESET><RED>/<RESET><GREEN>|<RESET>
+	<RED>|<RESET><RED>/<RESET><GREEN>|<RESET> <YELLOW>|<RESET> <BLUE>|<RESET><GREEN>/<RESET>
+	<RED>|<RESET> <GREEN>|<RESET> <YELLOW>|<RESET><GREEN>/<RESET><BLUE>|<RESET>
+	<RED>|<RESET> <GREEN>|<RESET><GREEN>/<RESET><YELLOW>|<RESET> <BLUE>|<RESET>
+	<RED>|<RESET> <GREEN>|<RESET> * <BLUE>|<RESET> 6_E
+	<RED>|<RESET> * <CYAN>|<RESET> <BLUE>|<RESET> 6_D
+	<RED>|<RESET> <BLUE>|<RESET> <CYAN>|<RESET><BLUE>/<RESET>
+	<RED>|<RESET> <BLUE>|<RESET><BLUE>/<RESET><CYAN>|<RESET>
+	* <BLUE>|<RESET> <CYAN>|<RESET> 6_C
+	<CYAN>|<RESET> <BLUE>|<RESET><CYAN>/<RESET>
+	<CYAN>|<RESET><CYAN>/<RESET><BLUE>|<RESET>
+	* <BLUE>|<RESET> 6_B
+	<BLUE>|<RESET><BLUE>/<RESET>
+	* 6_A
+	EOF
+	git log --color=always --graph --date-order --pretty=tformat:%s 6_1 6_3 6_5 >actual.colors.raw &&
+	test_decode_color <actual.colors.raw | sed "s/ *\$//" >actual.colors &&
+	test_cmp expect.colors actual.colors
+'
+
+test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t4253-am-keep-cr-dos.sh 1.2.3+git2.25.1-1/git/t/t4253-am-keep-cr-dos.sh
--- 1.2.1+git2.18.0-1/git/t/t4253-am-keep-cr-dos.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t4253-am-keep-cr-dos.sh	2020-02-17 04:47:35.000000000 +0000
@@ -51,14 +51,16 @@ test_expect_success 'am with dos files w
 
 test_expect_success 'am with dos files with --keep-cr' '
 	git checkout -b dosfiles-keep-cr initial &&
-	git format-patch -k --stdout initial..master | git am --keep-cr -k -3 &&
+	git format-patch -k --stdout initial..master >output &&
+	git am --keep-cr -k -3 output &&
 	git diff --exit-code master
 '
 
 test_expect_success 'am with dos files config am.keepcr' '
 	git config am.keepcr 1 &&
 	git checkout -b dosfiles-conf-keepcr initial &&
-	git format-patch -k --stdout initial..master | git am -k -3 &&
+	git format-patch -k --stdout initial..master >output &&
+	git am -k -3 output &&
 	git diff --exit-code master
 '
 
diff -pruN 1.2.1+git2.18.0-1/git/t/t4254-am-corrupt.sh 1.2.3+git2.25.1-1/git/t/t4254-am-corrupt.sh
--- 1.2.1+git2.18.0-1/git/t/t4254-am-corrupt.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t4254-am-corrupt.sh	2020-02-17 04:47:35.000000000 +0000
@@ -25,7 +25,7 @@ test_expect_success setup '
 #   fatal: unable to write file '(null)' mode 100644: Bad address
 # Also, it had the unwanted side-effect of deleting f.
 test_expect_success 'try to apply corrupted patch' '
-	test_must_fail git am bad-patch.diff 2>actual
+	test_must_fail git -c advice.amWorkDir=false am bad-patch.diff 2>actual
 '
 
 test_expect_success 'compare diagnostic; ensure file is still here' '
diff -pruN 1.2.1+git2.18.0-1/git/t/t4256/1/mailinfo.c 1.2.3+git2.25.1-1/git/t/t4256/1/mailinfo.c
--- 1.2.1+git2.18.0-1/git/t/t4256/1/mailinfo.c	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t4256/1/mailinfo.c	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,1245 @@
+#include "cache.h"
+#include "config.h"
+#include "utf8.h"
+#include "strbuf.h"
+#include "mailinfo.h"
+
+static void cleanup_space(struct strbuf *sb)
+{
+	size_t pos, cnt;
+	for (pos = 0; pos < sb->len; pos++) {
+		if (isspace(sb->buf[pos])) {
+			sb->buf[pos] = ' ';
+			for (cnt = 0; isspace(sb->buf[pos + cnt + 1]); cnt++);
+			strbuf_remove(sb, pos + 1, cnt);
+		}
+	}
+}
+
+static void get_sane_name(struct strbuf *out, struct strbuf *name, struct strbuf *email)
+{
+	struct strbuf *src = name;
+	if (name->len < 3 || 60 < name->len || strchr(name->buf, '@') ||
+		strchr(name->buf, '<') || strchr(name->buf, '>'))
+		src = email;
+	else if (name == out)
+		return;
+	strbuf_reset(out);
+	strbuf_addbuf(out, src);
+}
+
+static void parse_bogus_from(struct mailinfo *mi, const struct strbuf *line)
+{
+	/* John Doe <johndoe> */
+
+	char *bra, *ket;
+	/* This is fallback, so do not bother if we already have an
+	 * e-mail address.
+	 */
+	if (mi->email.len)
+		return;
+
+	bra = strchr(line->buf, '<');
+	if (!bra)
+		return;
+	ket = strchr(bra, '>');
+	if (!ket)
+		return;
+
+	strbuf_reset(&mi->email);
+	strbuf_add(&mi->email, bra + 1, ket - bra - 1);
+
+	strbuf_reset(&mi->name);
+	strbuf_add(&mi->name, line->buf, bra - line->buf);
+	strbuf_trim(&mi->name);
+	get_sane_name(&mi->name, &mi->name, &mi->email);
+}
+
+static const char *unquote_comment(struct strbuf *outbuf, const char *in)
+{
+	int c;
+	int take_next_literally = 0;
+
+	strbuf_addch(outbuf, '(');
+
+	while ((c = *in++) != 0) {
+		if (take_next_literally == 1) {
+			take_next_literally = 0;
+		} else {
+			switch (c) {
+			case '\\':
+				take_next_literally = 1;
+				continue;
+			case '(':
+				in = unquote_comment(outbuf, in);
+				continue;
+			case ')':
+				strbuf_addch(outbuf, ')');
+				return in;
+			}
+		}
+
+		strbuf_addch(outbuf, c);
+	}
+
+	return in;
+}
+
+static const char *unquote_quoted_string(struct strbuf *outbuf, const char *in)
+{
+	int c;
+	int take_next_literally = 0;
+
+	while ((c = *in++) != 0) {
+		if (take_next_literally == 1) {
+			take_next_literally = 0;
+		} else {
+			switch (c) {
+			case '\\':
+				take_next_literally = 1;
+				continue;
+			case '"':
+				return in;
+			}
+		}
+
+		strbuf_addch(outbuf, c);
+	}
+
+	return in;
+}
+
+static void unquote_quoted_pair(struct strbuf *line)
+{
+	struct strbuf outbuf;
+	const char *in = line->buf;
+	int c;
+
+	strbuf_init(&outbuf, line->len);
+
+	while ((c = *in++) != 0) {
+		switch (c) {
+		case '"':
+			in = unquote_quoted_string(&outbuf, in);
+			continue;
+		case '(':
+			in = unquote_comment(&outbuf, in);
+			continue;
+		}
+
+		strbuf_addch(&outbuf, c);
+	}
+
+	strbuf_swap(&outbuf, line);
+	strbuf_release(&outbuf);
+
+}
+
+static void handle_from(struct mailinfo *mi, const struct strbuf *from)
+{
+	char *at;
+	size_t el;
+	struct strbuf f;
+
+	strbuf_init(&f, from->len);
+	strbuf_addbuf(&f, from);
+
+	unquote_quoted_pair(&f);
+
+	at = strchr(f.buf, '@');
+	if (!at) {
+		parse_bogus_from(mi, from);
+		goto out;
+	}
+
+	/*
+	 * If we already have one email, don't take any confusing lines
+	 */
+	if (mi->email.len && strchr(at + 1, '@'))
+		goto out;
+
+	/* Pick up the string around '@', possibly delimited with <>
+	 * pair; that is the email part.
+	 */
+	while (at > f.buf) {
+		char c = at[-1];
+		if (isspace(c))
+			break;
+		if (c == '<') {
+			at[-1] = ' ';
+			break;
+		}
+		at--;
+	}
+	el = strcspn(at, " \n\t\r\v\f>");
+	strbuf_reset(&mi->email);
+	strbuf_add(&mi->email, at, el);
+	strbuf_remove(&f, at - f.buf, el + (at[el] ? 1 : 0));
+
+	/* The remainder is name.  It could be
+	 *
+	 * - "John Doe <john.doe@xz>"			(a), or
+	 * - "john.doe@xz (John Doe)"			(b), or
+	 * - "John (zzz) Doe <john.doe@xz> (Comment)"	(c)
+	 *
+	 * but we have removed the email part, so
+	 *
+	 * - remove extra spaces which could stay after email (case 'c'), and
+	 * - trim from both ends, possibly removing the () pair at the end
+	 *   (cases 'a' and 'b').
+	 */
+	cleanup_space(&f);
+	strbuf_trim(&f);
+	if (f.buf[0] == '(' && f.len && f.buf[f.len - 1] == ')') {
+		strbuf_remove(&f, 0, 1);
+		strbuf_setlen(&f, f.len - 1);
+	}
+
+	get_sane_name(&mi->name, &f, &mi->email);
+out:
+	strbuf_release(&f);
+}
+
+static void handle_header(struct strbuf **out, const struct strbuf *line)
+{
+	if (!*out) {
+		*out = xmalloc(sizeof(struct strbuf));
+		strbuf_init(*out, line->len);
+	} else
+		strbuf_reset(*out);
+
+	strbuf_addbuf(*out, line);
+}
+
+/* NOTE NOTE NOTE.  We do not claim we do full MIME.  We just attempt
+ * to have enough heuristics to grok MIME encoded patches often found
+ * on our mailing lists.  For example, we do not even treat header lines
+ * case insensitively.
+ */
+
+static int slurp_attr(const char *line, const char *name, struct strbuf *attr)
+{
+	const char *ends, *ap = strcasestr(line, name);
+	size_t sz;
+
+	strbuf_setlen(attr, 0);
+	if (!ap)
+		return 0;
+	ap += strlen(name);
+	if (*ap == '"') {
+		ap++;
+		ends = "\"";
+	}
+	else
+		ends = "; \t";
+	sz = strcspn(ap, ends);
+	strbuf_add(attr, ap, sz);
+	return 1;
+}
+
+static int has_attr_value(const char *line, const char *name, const char *value)
+{
+	struct strbuf sb = STRBUF_INIT;
+	int rc = slurp_attr(line, name, &sb) && !strcasecmp(sb.buf, value);
+	strbuf_release(&sb);
+	return rc;
+}
+
+static void handle_content_type(struct mailinfo *mi, struct strbuf *line)
+{
+	struct strbuf *boundary = xmalloc(sizeof(struct strbuf));
+	strbuf_init(boundary, line->len);
+
+	mi->format_flowed = has_attr_value(line->buf, "format=", "flowed");
+	mi->delsp = has_attr_value(line->buf, "delsp=", "yes");
+
+	if (slurp_attr(line->buf, "boundary=", boundary)) {
+		strbuf_insert(boundary, 0, "--", 2);
+		if (++mi->content_top >= &mi->content[MAX_BOUNDARIES]) {
+			error("Too many boundaries to handle");
+			mi->input_error = -1;
+			mi->content_top = &mi->content[MAX_BOUNDARIES] - 1;
+			return;
+		}
+		*(mi->content_top) = boundary;
+		boundary = NULL;
+	}
+	slurp_attr(line->buf, "charset=", &mi->charset);
+
+	if (boundary) {
+		strbuf_release(boundary);
+		free(boundary);
+	}
+}
+
+static void handle_content_transfer_encoding(struct mailinfo *mi,
+					     const struct strbuf *line)
+{
+	if (strcasestr(line->buf, "base64"))
+		mi->transfer_encoding = TE_BASE64;
+	else if (strcasestr(line->buf, "quoted-printable"))
+		mi->transfer_encoding = TE_QP;
+	else
+		mi->transfer_encoding = TE_DONTCARE;
+}
+
+static int is_multipart_boundary(struct mailinfo *mi, const struct strbuf *line)
+{
+	struct strbuf *content_top = *(mi->content_top);
+
+	return ((content_top->len <= line->len) &&
+		!memcmp(line->buf, content_top->buf, content_top->len));
+}
+
+static void cleanup_subject(struct mailinfo *mi, struct strbuf *subject)
+{
+	size_t at = 0;
+
+	while (at < subject->len) {
+		char *pos;
+		size_t remove;
+
+		switch (subject->buf[at]) {
+		case 'r': case 'R':
+			if (subject->len <= at + 3)
+				break;
+			if ((subject->buf[at + 1] == 'e' ||
+			     subject->buf[at + 1] == 'E') &&
+			    subject->buf[at + 2] == ':') {
+				strbuf_remove(subject, at, 3);
+				continue;
+			}
+			at++;
+			break;
+		case ' ': case '\t': case ':':
+			strbuf_remove(subject, at, 1);
+			continue;
+		case '[':
+			pos = strchr(subject->buf + at, ']');
+			if (!pos)
+				break;
+			remove = pos - subject->buf + at + 1;
+			if (!mi->keep_non_patch_brackets_in_subject ||
+			    (7 <= remove &&
+			     memmem(subject->buf + at, remove, "PATCH", 5)))
+				strbuf_remove(subject, at, remove);
+			else {
+				at += remove;
+				/*
+				 * If the input had a space after the ], keep
+				 * it.  We don't bother with finding the end of
+				 * the space, since we later normalize it
+				 * anyway.
+				 */
+				if (isspace(subject->buf[at]))
+					at += 1;
+			}
+			continue;
+		}
+		break;
+	}
+	strbuf_trim(subject);
+}
+
+#define MAX_HDR_PARSED 10
+static const char *header[MAX_HDR_PARSED] = {
+	"From","Subject","Date",
+};
+
+static inline int cmp_header(const struct strbuf *line, const char *hdr)
+{
+	int len = strlen(hdr);
+	return !strncasecmp(line->buf, hdr, len) && line->len > len &&
+			line->buf[len] == ':' && isspace(line->buf[len + 1]);
+}
+
+static int is_format_patch_separator(const char *line, int len)
+{
+	static const char SAMPLE[] =
+		"From e6807f3efca28b30decfecb1732a56c7db1137ee Mon Sep 17 00:00:00 2001\n";
+	const char *cp;
+
+	if (len != strlen(SAMPLE))
+		return 0;
+	if (!skip_prefix(line, "From ", &cp))
+		return 0;
+	if (strspn(cp, "0123456789abcdef") != 40)
+		return 0;
+	cp += 40;
+	return !memcmp(SAMPLE + (cp - line), cp, strlen(SAMPLE) - (cp - line));
+}
+
+static struct strbuf *decode_q_segment(const struct strbuf *q_seg, int rfc2047)
+{
+	const char *in = q_seg->buf;
+	int c;
+	struct strbuf *out = xmalloc(sizeof(struct strbuf));
+	strbuf_init(out, q_seg->len);
+
+	while ((c = *in++) != 0) {
+		if (c == '=') {
+			int ch, d = *in;
+			if (d == '\n' || !d)
+				break; /* drop trailing newline */
+			ch = hex2chr(in);
+			if (ch >= 0) {
+				strbuf_addch(out, ch);
+				in += 2;
+				continue;
+			}
+			/* garbage -- fall through */
+		}
+		if (rfc2047 && c == '_') /* rfc2047 4.2 (2) */
+			c = 0x20;
+		strbuf_addch(out, c);
+	}
+	return out;
+}
+
+static struct strbuf *decode_b_segment(const struct strbuf *b_seg)
+{
+	/* Decode in..ep, possibly in-place to ot */
+	int c, pos = 0, acc = 0;
+	const char *in = b_seg->buf;
+	struct strbuf *out = xmalloc(sizeof(struct strbuf));
+	strbuf_init(out, b_seg->len);
+
+	while ((c = *in++) != 0) {
+		if (c == '+')
+			c = 62;
+		else if (c == '/')
+			c = 63;
+		else if ('A' <= c && c <= 'Z')
+			c -= 'A';
+		else if ('a' <= c && c <= 'z')
+			c -= 'a' - 26;
+		else if ('0' <= c && c <= '9')
+			c -= '0' - 52;
+		else
+			continue; /* garbage */
+		switch (pos++) {
+		case 0:
+			acc = (c << 2);
+			break;
+		case 1:
+			strbuf_addch(out, (acc | (c >> 4)));
+			acc = (c & 15) << 4;
+			break;
+		case 2:
+			strbuf_addch(out, (acc | (c >> 2)));
+			acc = (c & 3) << 6;
+			break;
+		case 3:
+			strbuf_addch(out, (acc | c));
+			acc = pos = 0;
+			break;
+		}
+	}
+	return out;
+}
+
+static int convert_to_utf8(struct mailinfo *mi,
+			   struct strbuf *line, const char *charset)
+{
+	char *out;
+
+	if (!mi->metainfo_charset || !charset || !*charset)
+		return 0;
+
+	if (same_encoding(mi->metainfo_charset, charset))
+		return 0;
+	out = reencode_string(line->buf, mi->metainfo_charset, charset);
+	if (!out) {
+		mi->input_error = -1;
+		return error("cannot convert from %s to %s",
+			     charset, mi->metainfo_charset);
+	}
+	strbuf_attach(line, out, strlen(out), strlen(out));
+	return 0;
+}
+
+static void decode_header(struct mailinfo *mi, struct strbuf *it)
+{
+	char *in, *ep, *cp;
+	struct strbuf outbuf = STRBUF_INIT, *dec;
+	struct strbuf charset_q = STRBUF_INIT, piecebuf = STRBUF_INIT;
+	int found_error = 1; /* pessimism */
+
+	in = it->buf;
+	while (in - it->buf <= it->len && (ep = strstr(in, "=?")) != NULL) {
+		int encoding;
+		strbuf_reset(&charset_q);
+		strbuf_reset(&piecebuf);
+
+		if (in != ep) {
+			/*
+			 * We are about to process an encoded-word
+			 * that begins at ep, but there is something
+			 * before the encoded word.
+			 */
+			char *scan;
+			for (scan = in; scan < ep; scan++)
+				if (!isspace(*scan))
+					break;
+
+			if (scan != ep || in == it->buf) {
+				/*
+				 * We should not lose that "something",
+				 * unless we have just processed an
+				 * encoded-word, and there is only LWS
+				 * before the one we are about to process.
+				 */
+				strbuf_add(&outbuf, in, ep - in);
+			}
+		}
+		/* E.g.
+		 * ep : "=?iso-2022-jp?B?GyR...?= foo"
+		 * ep : "=?ISO-8859-1?Q?Foo=FCbar?= baz"
+		 */
+		ep += 2;
+
+		if (ep - it->buf >= it->len || !(cp = strchr(ep, '?')))
+			goto release_return;
+
+		if (cp + 3 - it->buf > it->len)
+			goto release_return;
+		strbuf_add(&charset_q, ep, cp - ep);
+
+		encoding = cp[1];
+		if (!encoding || cp[2] != '?')
+			goto release_return;
+		ep = strstr(cp + 3, "?=");
+		if (!ep)
+			goto release_return;
+		strbuf_add(&piecebuf, cp + 3, ep - cp - 3);
+		switch (tolower(encoding)) {
+		default:
+			goto release_return;
+		case 'b':
+			dec = decode_b_segment(&piecebuf);
+			break;
+		case 'q':
+			dec = decode_q_segment(&piecebuf, 1);
+			break;
+		}
+		if (convert_to_utf8(mi, dec, charset_q.buf))
+			goto release_return;
+
+		strbuf_addbuf(&outbuf, dec);
+		strbuf_release(dec);
+		free(dec);
+		in = ep + 2;
+	}
+	strbuf_addstr(&outbuf, in);
+	strbuf_reset(it);
+	strbuf_addbuf(it, &outbuf);
+	found_error = 0;
+release_return:
+	strbuf_release(&outbuf);
+	strbuf_release(&charset_q);
+	strbuf_release(&piecebuf);
+
+	if (found_error)
+		mi->input_error = -1;
+}
+
+static int check_header(struct mailinfo *mi,
+			const struct strbuf *line,
+			struct strbuf *hdr_data[], int overwrite)
+{
+	int i, ret = 0, len;
+	struct strbuf sb = STRBUF_INIT;
+
+	/* search for the interesting parts */
+	for (i = 0; header[i]; i++) {
+		int len = strlen(header[i]);
+		if ((!hdr_data[i] || overwrite) && cmp_header(line, header[i])) {
+			/* Unwrap inline B and Q encoding, and optionally
+			 * normalize the meta information to utf8.
+			 */
+			strbuf_add(&sb, line->buf + len + 2, line->len - len - 2);
+			decode_header(mi, &sb);
+			handle_header(&hdr_data[i], &sb);
+			ret = 1;
+			goto check_header_out;
+		}
+	}
+
+	/* Content stuff */
+	if (cmp_header(line, "Content-Type")) {
+		len = strlen("Content-Type: ");
+		strbuf_add(&sb, line->buf + len, line->len - len);
+		decode_header(mi, &sb);
+		strbuf_insert(&sb, 0, "Content-Type: ", len);
+		handle_content_type(mi, &sb);
+		ret = 1;
+		goto check_header_out;
+	}
+	if (cmp_header(line, "Content-Transfer-Encoding")) {
+		len = strlen("Content-Transfer-Encoding: ");
+		strbuf_add(&sb, line->buf + len, line->len - len);
+		decode_header(mi, &sb);
+		handle_content_transfer_encoding(mi, &sb);
+		ret = 1;
+		goto check_header_out;
+	}
+	if (cmp_header(line, "Message-Id")) {
+		len = strlen("Message-Id: ");
+		strbuf_add(&sb, line->buf + len, line->len - len);
+		decode_header(mi, &sb);
+		if (mi->add_message_id)
+			mi->message_id = strbuf_detach(&sb, NULL);
+		ret = 1;
+		goto check_header_out;
+	}
+
+check_header_out:
+	strbuf_release(&sb);
+	return ret;
+}
+
+/*
+ * Returns 1 if the given line or any line beginning with the given line is an
+ * in-body header (that is, check_header will succeed when passed
+ * mi->s_hdr_data).
+ */
+static int is_inbody_header(const struct mailinfo *mi,
+			    const struct strbuf *line)
+{
+	int i;
+	for (i = 0; header[i]; i++)
+		if (!mi->s_hdr_data[i] && cmp_header(line, header[i]))
+			return 1;
+	return 0;
+}
+
+static void decode_transfer_encoding(struct mailinfo *mi, struct strbuf *line)
+{
+	struct strbuf *ret;
+
+	switch (mi->transfer_encoding) {
+	case TE_QP:
+		ret = decode_q_segment(line, 0);
+		break;
+	case TE_BASE64:
+		ret = decode_b_segment(line);
+		break;
+	case TE_DONTCARE:
+	default:
+		return;
+	}
+	strbuf_reset(line);
+	strbuf_addbuf(line, ret);
+	strbuf_release(ret);
+	free(ret);
+}
+
+static inline int patchbreak(const struct strbuf *line)
+{
+	size_t i;
+
+	/* Beginning of a "diff -" header? */
+	if (starts_with(line->buf, "diff -"))
+		return 1;
+
+	/* CVS "Index: " line? */
+	if (starts_with(line->buf, "Index: "))
+		return 1;
+
+	/*
+	 * "--- <filename>" starts patches without headers
+	 * "---<sp>*" is a manual separator
+	 */
+	if (line->len < 4)
+		return 0;
+
+	if (starts_with(line->buf, "---")) {
+		/* space followed by a filename? */
+		if (line->buf[3] == ' ' && !isspace(line->buf[4]))
+			return 1;
+		/* Just whitespace? */
+		for (i = 3; i < line->len; i++) {
+			unsigned char c = line->buf[i];
+			if (c == '\n')
+				return 1;
+			if (!isspace(c))
+				break;
+		}
+		return 0;
+	}
+	return 0;
+}
+
+static int is_scissors_line(const char *line)
+{
+	const char *c;
+	int scissors = 0, gap = 0;
+	const char *first_nonblank = NULL, *last_nonblank = NULL;
+	int visible, perforation = 0, in_perforation = 0;
+
+	for (c = line; *c; c++) {
+		if (isspace(*c)) {
+			if (in_perforation) {
+				perforation++;
+				gap++;
+			}
+			continue;
+		}
+		last_nonblank = c;
+		if (first_nonblank == NULL)
+			first_nonblank = c;
+		if (*c == '-') {
+			in_perforation = 1;
+			perforation++;
+			continue;
+		}
+		if ((!memcmp(c, ">8", 2) || !memcmp(c, "8<", 2) ||
+		     !memcmp(c, ">%", 2) || !memcmp(c, "%<", 2))) {
+			in_perforation = 1;
+			perforation += 2;
+			scissors += 2;
+			c++;
+			continue;
+		}
+		in_perforation = 0;
+	}
+
+	/*
+	 * The mark must be at least 8 bytes long (e.g. "-- >8 --").
+	 * Even though there can be arbitrary cruft on the same line
+	 * (e.g. "cut here"), in order to avoid misidentification, the
+	 * perforation must occupy more than a third of the visible
+	 * width of the line, and dashes and scissors must occupy more
+	 * than half of the perforation.
+	 */
+
+	if (first_nonblank && last_nonblank)
+		visible = last_nonblank - first_nonblank + 1;
+	else
+		visible = 0;
+	return (scissors && 8 <= visible &&
+		visible < perforation * 3 &&
+		gap * 2 < perforation);
+}
+
+static void flush_inbody_header_accum(struct mailinfo *mi)
+{
+	if (!mi->inbody_header_accum.len)
+		return;
+	if (!check_header(mi, &mi->inbody_header_accum, mi->s_hdr_data, 0))
+		BUG("inbody_header_accum, if not empty, must always contain a valid in-body header");
+	strbuf_reset(&mi->inbody_header_accum);
+}
+
+static int check_inbody_header(struct mailinfo *mi, const struct strbuf *line)
+{
+	if (mi->inbody_header_accum.len &&
+	    (line->buf[0] == ' ' || line->buf[0] == '\t')) {
+		if (mi->use_scissors && is_scissors_line(line->buf)) {
+			/*
+			 * This is a scissors line; do not consider this line
+			 * as a header continuation line.
+			 */
+			flush_inbody_header_accum(mi);
+			return 0;
+		}
+		strbuf_strip_suffix(&mi->inbody_header_accum, "\n");
+		strbuf_addbuf(&mi->inbody_header_accum, line);
+		return 1;
+	}
+
+	flush_inbody_header_accum(mi);
+
+	if (starts_with(line->buf, ">From") && isspace(line->buf[5]))
+		return is_format_patch_separator(line->buf + 1, line->len - 1);
+	if (starts_with(line->buf, "[PATCH]") && isspace(line->buf[7])) {
+		int i;
+		for (i = 0; header[i]; i++)
+			if (!strcmp("Subject", header[i])) {
+				handle_header(&mi->s_hdr_data[i], line);
+				return 1;
+			}
+		return 0;
+	}
+	if (is_inbody_header(mi, line)) {
+		strbuf_addbuf(&mi->inbody_header_accum, line);
+		return 1;
+	}
+	return 0;
+}
+
+static int handle_commit_msg(struct mailinfo *mi, struct strbuf *line)
+{
+	assert(!mi->filter_stage);
+
+	if (mi->header_stage) {
+		if (!line->len || (line->len == 1 && line->buf[0] == '\n')) {
+			if (mi->inbody_header_accum.len) {
+				flush_inbody_header_accum(mi);
+				mi->header_stage = 0;
+			}
+			return 0;
+		}
+	}
+
+	if (mi->use_inbody_headers && mi->header_stage) {
+		mi->header_stage = check_inbody_header(mi, line);
+		if (mi->header_stage)
+			return 0;
+	} else
+		/* Only trim the first (blank) line of the commit message
+		 * when ignoring in-body headers.
+		 */
+		mi->header_stage = 0;
+
+	/* normalize the log message to UTF-8. */
+	if (convert_to_utf8(mi, line, mi->charset.buf))
+		return 0; /* mi->input_error already set */
+
+	if (mi->use_scissors && is_scissors_line(line->buf)) {
+		int i;
+
+		strbuf_setlen(&mi->log_message, 0);
+		mi->header_stage = 1;
+
+		/*
+		 * We may have already read "secondary headers"; purge
+		 * them to give ourselves a clean restart.
+		 */
+		for (i = 0; header[i]; i++) {
+			if (mi->s_hdr_data[i])
+				strbuf_release(mi->s_hdr_data[i]);
+			mi->s_hdr_data[i] = NULL;
+		}
+		return 0;
+	}
+
+	if (patchbreak(line)) {
+		if (mi->message_id)
+			strbuf_addf(&mi->log_message,
+				    "Message-Id: %s\n", mi->message_id);
+		return 1;
+	}
+
+	strbuf_addbuf(&mi->log_message, line);
+	return 0;
+}
+
+static void handle_patch(struct mailinfo *mi, const struct strbuf *line)
+{
+	fwrite(line->buf, 1, line->len, mi->patchfile);
+	mi->patch_lines++;
+}
+
+static void handle_filter(struct mailinfo *mi, struct strbuf *line)
+{
+	switch (mi->filter_stage) {
+	case 0:
+		if (!handle_commit_msg(mi, line))
+			break;
+		mi->filter_stage++;
+		/* fallthrough */
+	case 1:
+		handle_patch(mi, line);
+		break;
+	}
+}
+
+static int is_rfc2822_header(const struct strbuf *line)
+{
+	/*
+	 * The section that defines the loosest possible
+	 * field name is "3.6.8 Optional fields".
+	 *
+	 * optional-field = field-name ":" unstructured CRLF
+	 * field-name = 1*ftext
+	 * ftext = %d33-57 / %59-126
+	 */
+	int ch;
+	char *cp = line->buf;
+
+	/* Count mbox From headers as headers */
+	if (starts_with(cp, "From ") || starts_with(cp, ">From "))
+		return 1;
+
+	while ((ch = *cp++)) {
+		if (ch == ':')
+			return 1;
+		if ((33 <= ch && ch <= 57) ||
+		    (59 <= ch && ch <= 126))
+			continue;
+		break;
+	}
+	return 0;
+}
+
+static int read_one_header_line(struct strbuf *line, FILE *in)
+{
+	struct strbuf continuation = STRBUF_INIT;
+
+	/* Get the first part of the line. */
+	if (strbuf_getline_lf(line, in))
+		return 0;
+
+	/*
+	 * Is it an empty line or not a valid rfc2822 header?
+	 * If so, stop here, and return false ("not a header")
+	 */
+	strbuf_rtrim(line);
+	if (!line->len || !is_rfc2822_header(line)) {
+		/* Re-add the newline */
+		strbuf_addch(line, '\n');
+		return 0;
+	}
+
+	/*
+	 * Now we need to eat all the continuation lines..
+	 * Yuck, 2822 header "folding"
+	 */
+	for (;;) {
+		int peek;
+
+		peek = fgetc(in);
+		if (peek == EOF)
+			break;
+		ungetc(peek, in);
+		if (peek != ' ' && peek != '\t')
+			break;
+		if (strbuf_getline_lf(&continuation, in))
+			break;
+		continuation.buf[0] = ' ';
+		strbuf_rtrim(&continuation);
+		strbuf_addbuf(line, &continuation);
+	}
+	strbuf_release(&continuation);
+
+	return 1;
+}
+
+static int find_boundary(struct mailinfo *mi, struct strbuf *line)
+{
+	while (!strbuf_getline_lf(line, mi->input)) {
+		if (*(mi->content_top) && is_multipart_boundary(mi, line))
+			return 1;
+	}
+	return 0;
+}
+
+static int handle_boundary(struct mailinfo *mi, struct strbuf *line)
+{
+	struct strbuf newline = STRBUF_INIT;
+
+	strbuf_addch(&newline, '\n');
+again:
+	if (line->len >= (*(mi->content_top))->len + 2 &&
+	    !memcmp(line->buf + (*(mi->content_top))->len, "--", 2)) {
+		/* we hit an end boundary */
+		/* pop the current boundary off the stack */
+		strbuf_release(*(mi->content_top));
+		FREE_AND_NULL(*(mi->content_top));
+
+		/* technically won't happen as is_multipart_boundary()
+		   will fail first.  But just in case..
+		 */
+		if (--mi->content_top < mi->content) {
+			error("Detected mismatched boundaries, can't recover");
+			mi->input_error = -1;
+			mi->content_top = mi->content;
+			strbuf_release(&newline);
+			return 0;
+		}
+		handle_filter(mi, &newline);
+		strbuf_release(&newline);
+		if (mi->input_error)
+			return 0;
+
+		/* skip to the next boundary */
+		if (!find_boundary(mi, line))
+			return 0;
+		goto again;
+	}
+
+	/* set some defaults */
+	mi->transfer_encoding = TE_DONTCARE;
+	strbuf_reset(&mi->charset);
+
+	/* slurp in this section's info */
+	while (read_one_header_line(line, mi->input))
+		check_header(mi, line, mi->p_hdr_data, 0);
+
+	strbuf_release(&newline);
+	/* replenish line */
+	if (strbuf_getline_lf(line, mi->input))
+		return 0;
+	strbuf_addch(line, '\n');
+	return 1;
+}
+
+static void handle_filter_flowed(struct mailinfo *mi, struct strbuf *line,
+				 struct strbuf *prev)
+{
+	size_t len = line->len;
+	const char *rest;
+
+	if (!mi->format_flowed) {
+		handle_filter(mi, line);
+		return;
+	}
+
+	if (line->buf[len - 1] == '\n') {
+		len--;
+		if (len && line->buf[len - 1] == '\r')
+			len--;
+	}
+
+	/* Keep signature separator as-is. */
+	if (skip_prefix(line->buf, "-- ", &rest) && rest - line->buf == len) {
+		if (prev->len) {
+			handle_filter(mi, prev);
+			strbuf_reset(prev);
+		}
+		handle_filter(mi, line);
+		return;
+	}
+
+	/* Unstuff space-stuffed line. */
+	if (len && line->buf[0] == ' ') {
+		strbuf_remove(line, 0, 1);
+		len--;
+	}
+
+	/* Save flowed line for later, but without the soft line break. */
+	if (len && line->buf[len - 1] == ' ') {
+		strbuf_add(prev, line->buf, len - !!mi->delsp);
+		return;
+	}
+
+	/* Prepend any previous partial lines */
+	strbuf_insert(line, 0, prev->buf, prev->len);
+	strbuf_reset(prev);
+
+	handle_filter(mi, line);
+}
+
+static void handle_body(struct mailinfo *mi, struct strbuf *line)
+{
+	struct strbuf prev = STRBUF_INIT;
+
+	/* Skip up to the first boundary */
+	if (*(mi->content_top)) {
+		if (!find_boundary(mi, line))
+			goto handle_body_out;
+	}
+
+	do {
+		/* process any boundary lines */
+		if (*(mi->content_top) && is_multipart_boundary(mi, line)) {
+			/* flush any leftover */
+			if (prev.len) {
+				handle_filter(mi, &prev);
+				strbuf_reset(&prev);
+			}
+			if (!handle_boundary(mi, line))
+				goto handle_body_out;
+		}
+
+		/* Unwrap transfer encoding */
+		decode_transfer_encoding(mi, line);
+
+		switch (mi->transfer_encoding) {
+		case TE_BASE64:
+		case TE_QP:
+		{
+			struct strbuf **lines, **it, *sb;
+
+			/* Prepend any previous partial lines */
+			strbuf_insert(line, 0, prev.buf, prev.len);
+			strbuf_reset(&prev);
+
+			/*
+			 * This is a decoded line that may contain
+			 * multiple new lines.  Pass only one chunk
+			 * at a time to handle_filter()
+			 */
+			lines = strbuf_split(line, '\n');
+			for (it = lines; (sb = *it); it++) {
+				if (*(it + 1) == NULL) /* The last line */
+					if (sb->buf[sb->len - 1] != '\n') {
+						/* Partial line, save it for later. */
+						strbuf_addbuf(&prev, sb);
+						break;
+					}
+				handle_filter_flowed(mi, sb, &prev);
+			}
+			/*
+			 * The partial chunk is saved in "prev" and will be
+			 * appended by the next iteration of read_line_with_nul().
+			 */
+			strbuf_list_free(lines);
+			break;
+		}
+		default:
+			handle_filter_flowed(mi, line, &prev);
+		}
+
+		if (mi->input_error)
+			break;
+	} while (!strbuf_getwholeline(line, mi->input, '\n'));
+
+	if (prev.len)
+		handle_filter(mi, &prev);
+
+	flush_inbody_header_accum(mi);
+
+handle_body_out:
+	strbuf_release(&prev);
+}
+
+static void output_header_lines(FILE *fout, const char *hdr, const struct strbuf *data)
+{
+	const char *sp = data->buf;
+	while (1) {
+		char *ep = strchr(sp, '\n');
+		int len;
+		if (!ep)
+			len = strlen(sp);
+		else
+			len = ep - sp;
+		fprintf(fout, "%s: %.*s\n", hdr, len, sp);
+		if (!ep)
+			break;
+		sp = ep + 1;
+	}
+}
+
+static void handle_info(struct mailinfo *mi)
+{
+	struct strbuf *hdr;
+	int i;
+
+	for (i = 0; header[i]; i++) {
+		/* only print inbody headers if we output a patch file */
+		if (mi->patch_lines && mi->s_hdr_data[i])
+			hdr = mi->s_hdr_data[i];
+		else if (mi->p_hdr_data[i])
+			hdr = mi->p_hdr_data[i];
+		else
+			continue;
+
+		if (!strcmp(header[i], "Subject")) {
+			if (!mi->keep_subject) {
+				cleanup_subject(mi, hdr);
+				cleanup_space(hdr);
+			}
+			output_header_lines(mi->output, "Subject", hdr);
+		} else if (!strcmp(header[i], "From")) {
+			cleanup_space(hdr);
+			handle_from(mi, hdr);
+			fprintf(mi->output, "Author: %s\n", mi->name.buf);
+			fprintf(mi->output, "Email: %s\n", mi->email.buf);
+		} else {
+			cleanup_space(hdr);
+			fprintf(mi->output, "%s: %s\n", header[i], hdr->buf);
+		}
+	}
+	fprintf(mi->output, "\n");
+}
+
+int mailinfo(struct mailinfo *mi, const char *msg, const char *patch)
+{
+	FILE *cmitmsg;
+	int peek;
+	struct strbuf line = STRBUF_INIT;
+
+	cmitmsg = fopen(msg, "w");
+	if (!cmitmsg) {
+		perror(msg);
+		return -1;
+	}
+	mi->patchfile = fopen(patch, "w");
+	if (!mi->patchfile) {
+		perror(patch);
+		fclose(cmitmsg);
+		return -1;
+	}
+
+	mi->p_hdr_data = xcalloc(MAX_HDR_PARSED, sizeof(*(mi->p_hdr_data)));
+	mi->s_hdr_data = xcalloc(MAX_HDR_PARSED, sizeof(*(mi->s_hdr_data)));
+
+	do {
+		peek = fgetc(mi->input);
+		if (peek == EOF) {
+			fclose(cmitmsg);
+			return error("empty patch: '%s'", patch);
+		}
+	} while (isspace(peek));
+	ungetc(peek, mi->input);
+
+	/* process the email header */
+	while (read_one_header_line(&line, mi->input))
+		check_header(mi, &line, mi->p_hdr_data, 1);
+
+	handle_body(mi, &line);
+	fwrite(mi->log_message.buf, 1, mi->log_message.len, cmitmsg);
+	fclose(cmitmsg);
+	fclose(mi->patchfile);
+
+	handle_info(mi);
+	strbuf_release(&line);
+	return mi->input_error;
+}
+
+static int git_mailinfo_config(const char *var, const char *value, void *mi_)
+{
+	struct mailinfo *mi = mi_;
+
+	if (!starts_with(var, "mailinfo."))
+		return git_default_config(var, value, NULL);
+	if (!strcmp(var, "mailinfo.scissors")) {
+		mi->use_scissors = git_config_bool(var, value);
+		return 0;
+	}
+	/* perhaps others here */
+	return 0;
+}
+
+void setup_mailinfo(struct mailinfo *mi)
+{
+	memset(mi, 0, sizeof(*mi));
+	strbuf_init(&mi->name, 0);
+	strbuf_init(&mi->email, 0);
+	strbuf_init(&mi->charset, 0);
+	strbuf_init(&mi->log_message, 0);
+	strbuf_init(&mi->inbody_header_accum, 0);
+	mi->header_stage = 1;
+	mi->use_inbody_headers = 1;
+	mi->content_top = mi->content;
+	git_config(git_mailinfo_config, mi);
+}
+
+void clear_mailinfo(struct mailinfo *mi)
+{
+	int i;
+
+	strbuf_release(&mi->name);
+	strbuf_release(&mi->email);
+	strbuf_release(&mi->charset);
+	strbuf_release(&mi->inbody_header_accum);
+	free(mi->message_id);
+
+	if (mi->p_hdr_data)
+		for (i = 0; mi->p_hdr_data[i]; i++)
+			strbuf_release(mi->p_hdr_data[i]);
+	free(mi->p_hdr_data);
+	if (mi->s_hdr_data)
+		for (i = 0; mi->s_hdr_data[i]; i++)
+			strbuf_release(mi->s_hdr_data[i]);
+	free(mi->s_hdr_data);
+
+	while (mi->content < mi->content_top) {
+		free(*(mi->content_top));
+		mi->content_top--;
+	}
+
+	strbuf_release(&mi->log_message);
+}
diff -pruN 1.2.1+git2.18.0-1/git/t/t4256/1/mailinfo.c.orig 1.2.3+git2.25.1-1/git/t/t4256/1/mailinfo.c.orig
--- 1.2.1+git2.18.0-1/git/t/t4256/1/mailinfo.c.orig	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t4256/1/mailinfo.c.orig	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,1185 @@
+#include "cache.h"
+#include "config.h"
+#include "utf8.h"
+#include "strbuf.h"
+#include "mailinfo.h"
+
+static void cleanup_space(struct strbuf *sb)
+{
+	size_t pos, cnt;
+	for (pos = 0; pos < sb->len; pos++) {
+		if (isspace(sb->buf[pos])) {
+			sb->buf[pos] = ' ';
+			for (cnt = 0; isspace(sb->buf[pos + cnt + 1]); cnt++);
+			strbuf_remove(sb, pos + 1, cnt);
+		}
+	}
+}
+
+static void get_sane_name(struct strbuf *out, struct strbuf *name, struct strbuf *email)
+{
+	struct strbuf *src = name;
+	if (name->len < 3 || 60 < name->len || strchr(name->buf, '@') ||
+		strchr(name->buf, '<') || strchr(name->buf, '>'))
+		src = email;
+	else if (name == out)
+		return;
+	strbuf_reset(out);
+	strbuf_addbuf(out, src);
+}
+
+static void parse_bogus_from(struct mailinfo *mi, const struct strbuf *line)
+{
+	/* John Doe <johndoe> */
+
+	char *bra, *ket;
+	/* This is fallback, so do not bother if we already have an
+	 * e-mail address.
+	 */
+	if (mi->email.len)
+		return;
+
+	bra = strchr(line->buf, '<');
+	if (!bra)
+		return;
+	ket = strchr(bra, '>');
+	if (!ket)
+		return;
+
+	strbuf_reset(&mi->email);
+	strbuf_add(&mi->email, bra + 1, ket - bra - 1);
+
+	strbuf_reset(&mi->name);
+	strbuf_add(&mi->name, line->buf, bra - line->buf);
+	strbuf_trim(&mi->name);
+	get_sane_name(&mi->name, &mi->name, &mi->email);
+}
+
+static const char *unquote_comment(struct strbuf *outbuf, const char *in)
+{
+	int c;
+	int take_next_literally = 0;
+
+	strbuf_addch(outbuf, '(');
+
+	while ((c = *in++) != 0) {
+		if (take_next_literally == 1) {
+			take_next_literally = 0;
+		} else {
+			switch (c) {
+			case '\\':
+				take_next_literally = 1;
+				continue;
+			case '(':
+				in = unquote_comment(outbuf, in);
+				continue;
+			case ')':
+				strbuf_addch(outbuf, ')');
+				return in;
+			}
+		}
+
+		strbuf_addch(outbuf, c);
+	}
+
+	return in;
+}
+
+static const char *unquote_quoted_string(struct strbuf *outbuf, const char *in)
+{
+	int c;
+	int take_next_literally = 0;
+
+	while ((c = *in++) != 0) {
+		if (take_next_literally == 1) {
+			take_next_literally = 0;
+		} else {
+			switch (c) {
+			case '\\':
+				take_next_literally = 1;
+				continue;
+			case '"':
+				return in;
+			}
+		}
+
+		strbuf_addch(outbuf, c);
+	}
+
+	return in;
+}
+
+static void unquote_quoted_pair(struct strbuf *line)
+{
+	struct strbuf outbuf;
+	const char *in = line->buf;
+	int c;
+
+	strbuf_init(&outbuf, line->len);
+
+	while ((c = *in++) != 0) {
+		switch (c) {
+		case '"':
+			in = unquote_quoted_string(&outbuf, in);
+			continue;
+		case '(':
+			in = unquote_comment(&outbuf, in);
+			continue;
+		}
+
+		strbuf_addch(&outbuf, c);
+	}
+
+	strbuf_swap(&outbuf, line);
+	strbuf_release(&outbuf);
+
+}
+
+static void handle_from(struct mailinfo *mi, const struct strbuf *from)
+{
+	char *at;
+	size_t el;
+	struct strbuf f;
+
+	strbuf_init(&f, from->len);
+	strbuf_addbuf(&f, from);
+
+	unquote_quoted_pair(&f);
+
+	at = strchr(f.buf, '@');
+	if (!at) {
+		parse_bogus_from(mi, from);
+		goto out;
+	}
+
+	/*
+	 * If we already have one email, don't take any confusing lines
+	 */
+	if (mi->email.len && strchr(at + 1, '@'))
+		goto out;
+
+	/* Pick up the string around '@', possibly delimited with <>
+	 * pair; that is the email part.
+	 */
+	while (at > f.buf) {
+		char c = at[-1];
+		if (isspace(c))
+			break;
+		if (c == '<') {
+			at[-1] = ' ';
+			break;
+		}
+		at--;
+	}
+	el = strcspn(at, " \n\t\r\v\f>");
+	strbuf_reset(&mi->email);
+	strbuf_add(&mi->email, at, el);
+	strbuf_remove(&f, at - f.buf, el + (at[el] ? 1 : 0));
+
+	/* The remainder is name.  It could be
+	 *
+	 * - "John Doe <john.doe@xz>"			(a), or
+	 * - "john.doe@xz (John Doe)"			(b), or
+	 * - "John (zzz) Doe <john.doe@xz> (Comment)"	(c)
+	 *
+	 * but we have removed the email part, so
+	 *
+	 * - remove extra spaces which could stay after email (case 'c'), and
+	 * - trim from both ends, possibly removing the () pair at the end
+	 *   (cases 'a' and 'b').
+	 */
+	cleanup_space(&f);
+	strbuf_trim(&f);
+	if (f.buf[0] == '(' && f.len && f.buf[f.len - 1] == ')') {
+		strbuf_remove(&f, 0, 1);
+		strbuf_setlen(&f, f.len - 1);
+	}
+
+	get_sane_name(&mi->name, &f, &mi->email);
+out:
+	strbuf_release(&f);
+}
+
+static void handle_header(struct strbuf **out, const struct strbuf *line)
+{
+	if (!*out) {
+		*out = xmalloc(sizeof(struct strbuf));
+		strbuf_init(*out, line->len);
+	} else
+		strbuf_reset(*out);
+
+	strbuf_addbuf(*out, line);
+}
+
+/* NOTE NOTE NOTE.  We do not claim we do full MIME.  We just attempt
+ * to have enough heuristics to grok MIME encoded patches often found
+ * on our mailing lists.  For example, we do not even treat header lines
+ * case insensitively.
+ */
+
+static int slurp_attr(const char *line, const char *name, struct strbuf *attr)
+{
+	const char *ends, *ap = strcasestr(line, name);
+	size_t sz;
+
+	strbuf_setlen(attr, 0);
+	if (!ap)
+		return 0;
+	ap += strlen(name);
+	if (*ap == '"') {
+		ap++;
+		ends = "\"";
+	}
+	else
+		ends = "; \t";
+	sz = strcspn(ap, ends);
+	strbuf_add(attr, ap, sz);
+	return 1;
+}
+
+static void handle_content_type(struct mailinfo *mi, struct strbuf *line)
+{
+	struct strbuf *boundary = xmalloc(sizeof(struct strbuf));
+	strbuf_init(boundary, line->len);
+
+	if (slurp_attr(line->buf, "boundary=", boundary)) {
+		strbuf_insert(boundary, 0, "--", 2);
+		if (++mi->content_top >= &mi->content[MAX_BOUNDARIES]) {
+			error("Too many boundaries to handle");
+			mi->input_error = -1;
+			mi->content_top = &mi->content[MAX_BOUNDARIES] - 1;
+			return;
+		}
+		*(mi->content_top) = boundary;
+		boundary = NULL;
+	}
+	slurp_attr(line->buf, "charset=", &mi->charset);
+
+	if (boundary) {
+		strbuf_release(boundary);
+		free(boundary);
+	}
+}
+
+static void handle_content_transfer_encoding(struct mailinfo *mi,
+					     const struct strbuf *line)
+{
+	if (strcasestr(line->buf, "base64"))
+		mi->transfer_encoding = TE_BASE64;
+	else if (strcasestr(line->buf, "quoted-printable"))
+		mi->transfer_encoding = TE_QP;
+	else
+		mi->transfer_encoding = TE_DONTCARE;
+}
+
+static int is_multipart_boundary(struct mailinfo *mi, const struct strbuf *line)
+{
+	struct strbuf *content_top = *(mi->content_top);
+
+	return ((content_top->len <= line->len) &&
+		!memcmp(line->buf, content_top->buf, content_top->len));
+}
+
+static void cleanup_subject(struct mailinfo *mi, struct strbuf *subject)
+{
+	size_t at = 0;
+
+	while (at < subject->len) {
+		char *pos;
+		size_t remove;
+
+		switch (subject->buf[at]) {
+		case 'r': case 'R':
+			if (subject->len <= at + 3)
+				break;
+			if ((subject->buf[at + 1] == 'e' ||
+			     subject->buf[at + 1] == 'E') &&
+			    subject->buf[at + 2] == ':') {
+				strbuf_remove(subject, at, 3);
+				continue;
+			}
+			at++;
+			break;
+		case ' ': case '\t': case ':':
+			strbuf_remove(subject, at, 1);
+			continue;
+		case '[':
+			pos = strchr(subject->buf + at, ']');
+			if (!pos)
+				break;
+			remove = pos - subject->buf + at + 1;
+			if (!mi->keep_non_patch_brackets_in_subject ||
+			    (7 <= remove &&
+			     memmem(subject->buf + at, remove, "PATCH", 5)))
+				strbuf_remove(subject, at, remove);
+			else {
+				at += remove;
+				/*
+				 * If the input had a space after the ], keep
+				 * it.  We don't bother with finding the end of
+				 * the space, since we later normalize it
+				 * anyway.
+				 */
+				if (isspace(subject->buf[at]))
+					at += 1;
+			}
+			continue;
+		}
+		break;
+	}
+	strbuf_trim(subject);
+}
+
+#define MAX_HDR_PARSED 10
+static const char *header[MAX_HDR_PARSED] = {
+	"From","Subject","Date",
+};
+
+static inline int cmp_header(const struct strbuf *line, const char *hdr)
+{
+	int len = strlen(hdr);
+	return !strncasecmp(line->buf, hdr, len) && line->len > len &&
+			line->buf[len] == ':' && isspace(line->buf[len + 1]);
+}
+
+static int is_format_patch_separator(const char *line, int len)
+{
+	static const char SAMPLE[] =
+		"From e6807f3efca28b30decfecb1732a56c7db1137ee Mon Sep 17 00:00:00 2001\n";
+	const char *cp;
+
+	if (len != strlen(SAMPLE))
+		return 0;
+	if (!skip_prefix(line, "From ", &cp))
+		return 0;
+	if (strspn(cp, "0123456789abcdef") != 40)
+		return 0;
+	cp += 40;
+	return !memcmp(SAMPLE + (cp - line), cp, strlen(SAMPLE) - (cp - line));
+}
+
+static struct strbuf *decode_q_segment(const struct strbuf *q_seg, int rfc2047)
+{
+	const char *in = q_seg->buf;
+	int c;
+	struct strbuf *out = xmalloc(sizeof(struct strbuf));
+	strbuf_init(out, q_seg->len);
+
+	while ((c = *in++) != 0) {
+		if (c == '=') {
+			int ch, d = *in;
+			if (d == '\n' || !d)
+				break; /* drop trailing newline */
+			ch = hex2chr(in);
+			if (ch >= 0) {
+				strbuf_addch(out, ch);
+				in += 2;
+				continue;
+			}
+			/* garbage -- fall through */
+		}
+		if (rfc2047 && c == '_') /* rfc2047 4.2 (2) */
+			c = 0x20;
+		strbuf_addch(out, c);
+	}
+	return out;
+}
+
+static struct strbuf *decode_b_segment(const struct strbuf *b_seg)
+{
+	/* Decode in..ep, possibly in-place to ot */
+	int c, pos = 0, acc = 0;
+	const char *in = b_seg->buf;
+	struct strbuf *out = xmalloc(sizeof(struct strbuf));
+	strbuf_init(out, b_seg->len);
+
+	while ((c = *in++) != 0) {
+		if (c == '+')
+			c = 62;
+		else if (c == '/')
+			c = 63;
+		else if ('A' <= c && c <= 'Z')
+			c -= 'A';
+		else if ('a' <= c && c <= 'z')
+			c -= 'a' - 26;
+		else if ('0' <= c && c <= '9')
+			c -= '0' - 52;
+		else
+			continue; /* garbage */
+		switch (pos++) {
+		case 0:
+			acc = (c << 2);
+			break;
+		case 1:
+			strbuf_addch(out, (acc | (c >> 4)));
+			acc = (c & 15) << 4;
+			break;
+		case 2:
+			strbuf_addch(out, (acc | (c >> 2)));
+			acc = (c & 3) << 6;
+			break;
+		case 3:
+			strbuf_addch(out, (acc | c));
+			acc = pos = 0;
+			break;
+		}
+	}
+	return out;
+}
+
+static int convert_to_utf8(struct mailinfo *mi,
+			   struct strbuf *line, const char *charset)
+{
+	char *out;
+
+	if (!mi->metainfo_charset || !charset || !*charset)
+		return 0;
+
+	if (same_encoding(mi->metainfo_charset, charset))
+		return 0;
+	out = reencode_string(line->buf, mi->metainfo_charset, charset);
+	if (!out) {
+		mi->input_error = -1;
+		return error("cannot convert from %s to %s",
+			     charset, mi->metainfo_charset);
+	}
+	strbuf_attach(line, out, strlen(out), strlen(out));
+	return 0;
+}
+
+static void decode_header(struct mailinfo *mi, struct strbuf *it)
+{
+	char *in, *ep, *cp;
+	struct strbuf outbuf = STRBUF_INIT, *dec;
+	struct strbuf charset_q = STRBUF_INIT, piecebuf = STRBUF_INIT;
+	int found_error = 1; /* pessimism */
+
+	in = it->buf;
+	while (in - it->buf <= it->len && (ep = strstr(in, "=?")) != NULL) {
+		int encoding;
+		strbuf_reset(&charset_q);
+		strbuf_reset(&piecebuf);
+
+		if (in != ep) {
+			/*
+			 * We are about to process an encoded-word
+			 * that begins at ep, but there is something
+			 * before the encoded word.
+			 */
+			char *scan;
+			for (scan = in; scan < ep; scan++)
+				if (!isspace(*scan))
+					break;
+
+			if (scan != ep || in == it->buf) {
+				/*
+				 * We should not lose that "something",
+				 * unless we have just processed an
+				 * encoded-word, and there is only LWS
+				 * before the one we are about to process.
+				 */
+				strbuf_add(&outbuf, in, ep - in);
+			}
+		}
+		/* E.g.
+		 * ep : "=?iso-2022-jp?B?GyR...?= foo"
+		 * ep : "=?ISO-8859-1?Q?Foo=FCbar?= baz"
+		 */
+		ep += 2;
+
+		if (ep - it->buf >= it->len || !(cp = strchr(ep, '?')))
+			goto release_return;
+
+		if (cp + 3 - it->buf > it->len)
+			goto release_return;
+		strbuf_add(&charset_q, ep, cp - ep);
+
+		encoding = cp[1];
+		if (!encoding || cp[2] != '?')
+			goto release_return;
+		ep = strstr(cp + 3, "?=");
+		if (!ep)
+			goto release_return;
+		strbuf_add(&piecebuf, cp + 3, ep - cp - 3);
+		switch (tolower(encoding)) {
+		default:
+			goto release_return;
+		case 'b':
+			dec = decode_b_segment(&piecebuf);
+			break;
+		case 'q':
+			dec = decode_q_segment(&piecebuf, 1);
+			break;
+		}
+		if (convert_to_utf8(mi, dec, charset_q.buf))
+			goto release_return;
+
+		strbuf_addbuf(&outbuf, dec);
+		strbuf_release(dec);
+		free(dec);
+		in = ep + 2;
+	}
+	strbuf_addstr(&outbuf, in);
+	strbuf_reset(it);
+	strbuf_addbuf(it, &outbuf);
+	found_error = 0;
+release_return:
+	strbuf_release(&outbuf);
+	strbuf_release(&charset_q);
+	strbuf_release(&piecebuf);
+
+	if (found_error)
+		mi->input_error = -1;
+}
+
+static int check_header(struct mailinfo *mi,
+			const struct strbuf *line,
+			struct strbuf *hdr_data[], int overwrite)
+{
+	int i, ret = 0, len;
+	struct strbuf sb = STRBUF_INIT;
+
+	/* search for the interesting parts */
+	for (i = 0; header[i]; i++) {
+		int len = strlen(header[i]);
+		if ((!hdr_data[i] || overwrite) && cmp_header(line, header[i])) {
+			/* Unwrap inline B and Q encoding, and optionally
+			 * normalize the meta information to utf8.
+			 */
+			strbuf_add(&sb, line->buf + len + 2, line->len - len - 2);
+			decode_header(mi, &sb);
+			handle_header(&hdr_data[i], &sb);
+			ret = 1;
+			goto check_header_out;
+		}
+	}
+
+	/* Content stuff */
+	if (cmp_header(line, "Content-Type")) {
+		len = strlen("Content-Type: ");
+		strbuf_add(&sb, line->buf + len, line->len - len);
+		decode_header(mi, &sb);
+		strbuf_insert(&sb, 0, "Content-Type: ", len);
+		handle_content_type(mi, &sb);
+		ret = 1;
+		goto check_header_out;
+	}
+	if (cmp_header(line, "Content-Transfer-Encoding")) {
+		len = strlen("Content-Transfer-Encoding: ");
+		strbuf_add(&sb, line->buf + len, line->len - len);
+		decode_header(mi, &sb);
+		handle_content_transfer_encoding(mi, &sb);
+		ret = 1;
+		goto check_header_out;
+	}
+	if (cmp_header(line, "Message-Id")) {
+		len = strlen("Message-Id: ");
+		strbuf_add(&sb, line->buf + len, line->len - len);
+		decode_header(mi, &sb);
+		if (mi->add_message_id)
+			mi->message_id = strbuf_detach(&sb, NULL);
+		ret = 1;
+		goto check_header_out;
+	}
+
+check_header_out:
+	strbuf_release(&sb);
+	return ret;
+}
+
+/*
+ * Returns 1 if the given line or any line beginning with the given line is an
+ * in-body header (that is, check_header will succeed when passed
+ * mi->s_hdr_data).
+ */
+static int is_inbody_header(const struct mailinfo *mi,
+			    const struct strbuf *line)
+{
+	int i;
+	for (i = 0; header[i]; i++)
+		if (!mi->s_hdr_data[i] && cmp_header(line, header[i]))
+			return 1;
+	return 0;
+}
+
+static void decode_transfer_encoding(struct mailinfo *mi, struct strbuf *line)
+{
+	struct strbuf *ret;
+
+	switch (mi->transfer_encoding) {
+	case TE_QP:
+		ret = decode_q_segment(line, 0);
+		break;
+	case TE_BASE64:
+		ret = decode_b_segment(line);
+		break;
+	case TE_DONTCARE:
+	default:
+		return;
+	}
+	strbuf_reset(line);
+	strbuf_addbuf(line, ret);
+	strbuf_release(ret);
+	free(ret);
+}
+
+static inline int patchbreak(const struct strbuf *line)
+{
+	size_t i;
+
+	/* Beginning of a "diff -" header? */
+	if (starts_with(line->buf, "diff -"))
+		return 1;
+
+	/* CVS "Index: " line? */
+	if (starts_with(line->buf, "Index: "))
+		return 1;
+
+	/*
+	 * "--- <filename>" starts patches without headers
+	 * "---<sp>*" is a manual separator
+	 */
+	if (line->len < 4)
+		return 0;
+
+	if (starts_with(line->buf, "---")) {
+		/* space followed by a filename? */
+		if (line->buf[3] == ' ' && !isspace(line->buf[4]))
+			return 1;
+		/* Just whitespace? */
+		for (i = 3; i < line->len; i++) {
+			unsigned char c = line->buf[i];
+			if (c == '\n')
+				return 1;
+			if (!isspace(c))
+				break;
+		}
+		return 0;
+	}
+	return 0;
+}
+
+static int is_scissors_line(const char *line)
+{
+	const char *c;
+	int scissors = 0, gap = 0;
+	const char *first_nonblank = NULL, *last_nonblank = NULL;
+	int visible, perforation = 0, in_perforation = 0;
+
+	for (c = line; *c; c++) {
+		if (isspace(*c)) {
+			if (in_perforation) {
+				perforation++;
+				gap++;
+			}
+			continue;
+		}
+		last_nonblank = c;
+		if (first_nonblank == NULL)
+			first_nonblank = c;
+		if (*c == '-') {
+			in_perforation = 1;
+			perforation++;
+			continue;
+		}
+		if ((!memcmp(c, ">8", 2) || !memcmp(c, "8<", 2) ||
+		     !memcmp(c, ">%", 2) || !memcmp(c, "%<", 2))) {
+			in_perforation = 1;
+			perforation += 2;
+			scissors += 2;
+			c++;
+			continue;
+		}
+		in_perforation = 0;
+	}
+
+	/*
+	 * The mark must be at least 8 bytes long (e.g. "-- >8 --").
+	 * Even though there can be arbitrary cruft on the same line
+	 * (e.g. "cut here"), in order to avoid misidentification, the
+	 * perforation must occupy more than a third of the visible
+	 * width of the line, and dashes and scissors must occupy more
+	 * than half of the perforation.
+	 */
+
+	if (first_nonblank && last_nonblank)
+		visible = last_nonblank - first_nonblank + 1;
+	else
+		visible = 0;
+	return (scissors && 8 <= visible &&
+		visible < perforation * 3 &&
+		gap * 2 < perforation);
+}
+
+static void flush_inbody_header_accum(struct mailinfo *mi)
+{
+	if (!mi->inbody_header_accum.len)
+		return;
+	if (!check_header(mi, &mi->inbody_header_accum, mi->s_hdr_data, 0))
+		BUG("inbody_header_accum, if not empty, must always contain a valid in-body header");
+	strbuf_reset(&mi->inbody_header_accum);
+}
+
+static int check_inbody_header(struct mailinfo *mi, const struct strbuf *line)
+{
+	if (mi->inbody_header_accum.len &&
+	    (line->buf[0] == ' ' || line->buf[0] == '\t')) {
+		if (mi->use_scissors && is_scissors_line(line->buf)) {
+			/*
+			 * This is a scissors line; do not consider this line
+			 * as a header continuation line.
+			 */
+			flush_inbody_header_accum(mi);
+			return 0;
+		}
+		strbuf_strip_suffix(&mi->inbody_header_accum, "\n");
+		strbuf_addbuf(&mi->inbody_header_accum, line);
+		return 1;
+	}
+
+	flush_inbody_header_accum(mi);
+
+	if (starts_with(line->buf, ">From") && isspace(line->buf[5]))
+		return is_format_patch_separator(line->buf + 1, line->len - 1);
+	if (starts_with(line->buf, "[PATCH]") && isspace(line->buf[7])) {
+		int i;
+		for (i = 0; header[i]; i++)
+			if (!strcmp("Subject", header[i])) {
+				handle_header(&mi->s_hdr_data[i], line);
+				return 1;
+			}
+		return 0;
+	}
+	if (is_inbody_header(mi, line)) {
+		strbuf_addbuf(&mi->inbody_header_accum, line);
+		return 1;
+	}
+	return 0;
+}
+
+static int handle_commit_msg(struct mailinfo *mi, struct strbuf *line)
+{
+	assert(!mi->filter_stage);
+
+	if (mi->header_stage) {
+		if (!line->len || (line->len == 1 && line->buf[0] == '\n')) {
+			if (mi->inbody_header_accum.len) {
+				flush_inbody_header_accum(mi);
+				mi->header_stage = 0;
+			}
+			return 0;
+		}
+	}
+
+	if (mi->use_inbody_headers && mi->header_stage) {
+		mi->header_stage = check_inbody_header(mi, line);
+		if (mi->header_stage)
+			return 0;
+	} else
+		/* Only trim the first (blank) line of the commit message
+		 * when ignoring in-body headers.
+		 */
+		mi->header_stage = 0;
+
+	/* normalize the log message to UTF-8. */
+	if (convert_to_utf8(mi, line, mi->charset.buf))
+		return 0; /* mi->input_error already set */
+
+	if (mi->use_scissors && is_scissors_line(line->buf)) {
+		int i;
+
+		strbuf_setlen(&mi->log_message, 0);
+		mi->header_stage = 1;
+
+		/*
+		 * We may have already read "secondary headers"; purge
+		 * them to give ourselves a clean restart.
+		 */
+		for (i = 0; header[i]; i++) {
+			if (mi->s_hdr_data[i])
+				strbuf_release(mi->s_hdr_data[i]);
+			mi->s_hdr_data[i] = NULL;
+		}
+		return 0;
+	}
+
+	if (patchbreak(line)) {
+		if (mi->message_id)
+			strbuf_addf(&mi->log_message,
+				    "Message-Id: %s\n", mi->message_id);
+		return 1;
+	}
+
+	strbuf_addbuf(&mi->log_message, line);
+	return 0;
+}
+
+static void handle_patch(struct mailinfo *mi, const struct strbuf *line)
+{
+	fwrite(line->buf, 1, line->len, mi->patchfile);
+	mi->patch_lines++;
+}
+
+static void handle_filter(struct mailinfo *mi, struct strbuf *line)
+{
+	switch (mi->filter_stage) {
+	case 0:
+		if (!handle_commit_msg(mi, line))
+			break;
+		mi->filter_stage++;
+		/* fallthrough */
+	case 1:
+		handle_patch(mi, line);
+		break;
+	}
+}
+
+static int is_rfc2822_header(const struct strbuf *line)
+{
+	/*
+	 * The section that defines the loosest possible
+	 * field name is "3.6.8 Optional fields".
+	 *
+	 * optional-field = field-name ":" unstructured CRLF
+	 * field-name = 1*ftext
+	 * ftext = %d33-57 / %59-126
+	 */
+	int ch;
+	char *cp = line->buf;
+
+	/* Count mbox From headers as headers */
+	if (starts_with(cp, "From ") || starts_with(cp, ">From "))
+		return 1;
+
+	while ((ch = *cp++)) {
+		if (ch == ':')
+			return 1;
+		if ((33 <= ch && ch <= 57) ||
+		    (59 <= ch && ch <= 126))
+			continue;
+		break;
+	}
+	return 0;
+}
+
+static int read_one_header_line(struct strbuf *line, FILE *in)
+{
+	struct strbuf continuation = STRBUF_INIT;
+
+	/* Get the first part of the line. */
+	if (strbuf_getline_lf(line, in))
+		return 0;
+
+	/*
+	 * Is it an empty line or not a valid rfc2822 header?
+	 * If so, stop here, and return false ("not a header")
+	 */
+	strbuf_rtrim(line);
+	if (!line->len || !is_rfc2822_header(line)) {
+		/* Re-add the newline */
+		strbuf_addch(line, '\n');
+		return 0;
+	}
+
+	/*
+	 * Now we need to eat all the continuation lines..
+	 * Yuck, 2822 header "folding"
+	 */
+	for (;;) {
+		int peek;
+
+		peek = fgetc(in);
+		if (peek == EOF)
+			break;
+		ungetc(peek, in);
+		if (peek != ' ' && peek != '\t')
+			break;
+		if (strbuf_getline_lf(&continuation, in))
+			break;
+		continuation.buf[0] = ' ';
+		strbuf_rtrim(&continuation);
+		strbuf_addbuf(line, &continuation);
+	}
+	strbuf_release(&continuation);
+
+	return 1;
+}
+
+static int find_boundary(struct mailinfo *mi, struct strbuf *line)
+{
+	while (!strbuf_getline_lf(line, mi->input)) {
+		if (*(mi->content_top) && is_multipart_boundary(mi, line))
+			return 1;
+	}
+	return 0;
+}
+
+static int handle_boundary(struct mailinfo *mi, struct strbuf *line)
+{
+	struct strbuf newline = STRBUF_INIT;
+
+	strbuf_addch(&newline, '\n');
+again:
+	if (line->len >= (*(mi->content_top))->len + 2 &&
+	    !memcmp(line->buf + (*(mi->content_top))->len, "--", 2)) {
+		/* we hit an end boundary */
+		/* pop the current boundary off the stack */
+		strbuf_release(*(mi->content_top));
+		FREE_AND_NULL(*(mi->content_top));
+
+		/* technically won't happen as is_multipart_boundary()
+		   will fail first.  But just in case..
+		 */
+		if (--mi->content_top < mi->content) {
+			error("Detected mismatched boundaries, can't recover");
+			mi->input_error = -1;
+			mi->content_top = mi->content;
+			strbuf_release(&newline);
+			return 0;
+		}
+		handle_filter(mi, &newline);
+		strbuf_release(&newline);
+		if (mi->input_error)
+			return 0;
+
+		/* skip to the next boundary */
+		if (!find_boundary(mi, line))
+			return 0;
+		goto again;
+	}
+
+	/* set some defaults */
+	mi->transfer_encoding = TE_DONTCARE;
+	strbuf_reset(&mi->charset);
+
+	/* slurp in this section's info */
+	while (read_one_header_line(line, mi->input))
+		check_header(mi, line, mi->p_hdr_data, 0);
+
+	strbuf_release(&newline);
+	/* replenish line */
+	if (strbuf_getline_lf(line, mi->input))
+		return 0;
+	strbuf_addch(line, '\n');
+	return 1;
+}
+
+static void handle_body(struct mailinfo *mi, struct strbuf *line)
+{
+	struct strbuf prev = STRBUF_INIT;
+
+	/* Skip up to the first boundary */
+	if (*(mi->content_top)) {
+		if (!find_boundary(mi, line))
+			goto handle_body_out;
+	}
+
+	do {
+		/* process any boundary lines */
+		if (*(mi->content_top) && is_multipart_boundary(mi, line)) {
+			/* flush any leftover */
+			if (prev.len) {
+				handle_filter(mi, &prev);
+				strbuf_reset(&prev);
+			}
+			if (!handle_boundary(mi, line))
+				goto handle_body_out;
+		}
+
+		/* Unwrap transfer encoding */
+		decode_transfer_encoding(mi, line);
+
+		switch (mi->transfer_encoding) {
+		case TE_BASE64:
+		case TE_QP:
+		{
+			struct strbuf **lines, **it, *sb;
+
+			/* Prepend any previous partial lines */
+			strbuf_insert(line, 0, prev.buf, prev.len);
+			strbuf_reset(&prev);
+
+			/*
+			 * This is a decoded line that may contain
+			 * multiple new lines.  Pass only one chunk
+			 * at a time to handle_filter()
+			 */
+			lines = strbuf_split(line, '\n');
+			for (it = lines; (sb = *it); it++) {
+				if (*(it + 1) == NULL) /* The last line */
+					if (sb->buf[sb->len - 1] != '\n') {
+						/* Partial line, save it for later. */
+						strbuf_addbuf(&prev, sb);
+						break;
+					}
+				handle_filter(mi, sb);
+			}
+			/*
+			 * The partial chunk is saved in "prev" and will be
+			 * appended by the next iteration of read_line_with_nul().
+			 */
+			strbuf_list_free(lines);
+			break;
+		}
+		default:
+			handle_filter(mi, line);
+		}
+
+		if (mi->input_error)
+			break;
+	} while (!strbuf_getwholeline(line, mi->input, '\n'));
+
+	flush_inbody_header_accum(mi);
+
+handle_body_out:
+	strbuf_release(&prev);
+}
+
+static void output_header_lines(FILE *fout, const char *hdr, const struct strbuf *data)
+{
+	const char *sp = data->buf;
+	while (1) {
+		char *ep = strchr(sp, '\n');
+		int len;
+		if (!ep)
+			len = strlen(sp);
+		else
+			len = ep - sp;
+		fprintf(fout, "%s: %.*s\n", hdr, len, sp);
+		if (!ep)
+			break;
+		sp = ep + 1;
+	}
+}
+
+static void handle_info(struct mailinfo *mi)
+{
+	struct strbuf *hdr;
+	int i;
+
+	for (i = 0; header[i]; i++) {
+		/* only print inbody headers if we output a patch file */
+		if (mi->patch_lines && mi->s_hdr_data[i])
+			hdr = mi->s_hdr_data[i];
+		else if (mi->p_hdr_data[i])
+			hdr = mi->p_hdr_data[i];
+		else
+			continue;
+
+		if (!strcmp(header[i], "Subject")) {
+			if (!mi->keep_subject) {
+				cleanup_subject(mi, hdr);
+				cleanup_space(hdr);
+			}
+			output_header_lines(mi->output, "Subject", hdr);
+		} else if (!strcmp(header[i], "From")) {
+			cleanup_space(hdr);
+			handle_from(mi, hdr);
+			fprintf(mi->output, "Author: %s\n", mi->name.buf);
+			fprintf(mi->output, "Email: %s\n", mi->email.buf);
+		} else {
+			cleanup_space(hdr);
+			fprintf(mi->output, "%s: %s\n", header[i], hdr->buf);
+		}
+	}
+	fprintf(mi->output, "\n");
+}
+
+int mailinfo(struct mailinfo *mi, const char *msg, const char *patch)
+{
+	FILE *cmitmsg;
+	int peek;
+	struct strbuf line = STRBUF_INIT;
+
+	cmitmsg = fopen(msg, "w");
+	if (!cmitmsg) {
+		perror(msg);
+		return -1;
+	}
+	mi->patchfile = fopen(patch, "w");
+	if (!mi->patchfile) {
+		perror(patch);
+		fclose(cmitmsg);
+		return -1;
+	}
+
+	mi->p_hdr_data = xcalloc(MAX_HDR_PARSED, sizeof(*(mi->p_hdr_data)));
+	mi->s_hdr_data = xcalloc(MAX_HDR_PARSED, sizeof(*(mi->s_hdr_data)));
+
+	do {
+		peek = fgetc(mi->input);
+		if (peek == EOF) {
+			fclose(cmitmsg);
+			return error("empty patch: '%s'", patch);
+		}
+	} while (isspace(peek));
+	ungetc(peek, mi->input);
+
+	/* process the email header */
+	while (read_one_header_line(&line, mi->input))
+		check_header(mi, &line, mi->p_hdr_data, 1);
+
+	handle_body(mi, &line);
+	fwrite(mi->log_message.buf, 1, mi->log_message.len, cmitmsg);
+	fclose(cmitmsg);
+	fclose(mi->patchfile);
+
+	handle_info(mi);
+	strbuf_release(&line);
+	return mi->input_error;
+}
+
+static int git_mailinfo_config(const char *var, const char *value, void *mi_)
+{
+	struct mailinfo *mi = mi_;
+
+	if (!starts_with(var, "mailinfo."))
+		return git_default_config(var, value, NULL);
+	if (!strcmp(var, "mailinfo.scissors")) {
+		mi->use_scissors = git_config_bool(var, value);
+		return 0;
+	}
+	/* perhaps others here */
+	return 0;
+}
+
+void setup_mailinfo(struct mailinfo *mi)
+{
+	memset(mi, 0, sizeof(*mi));
+	strbuf_init(&mi->name, 0);
+	strbuf_init(&mi->email, 0);
+	strbuf_init(&mi->charset, 0);
+	strbuf_init(&mi->log_message, 0);
+	strbuf_init(&mi->inbody_header_accum, 0);
+	mi->header_stage = 1;
+	mi->use_inbody_headers = 1;
+	mi->content_top = mi->content;
+	git_config(git_mailinfo_config, mi);
+}
+
+void clear_mailinfo(struct mailinfo *mi)
+{
+	int i;
+
+	strbuf_release(&mi->name);
+	strbuf_release(&mi->email);
+	strbuf_release(&mi->charset);
+	strbuf_release(&mi->inbody_header_accum);
+	free(mi->message_id);
+
+	if (mi->p_hdr_data)
+		for (i = 0; mi->p_hdr_data[i]; i++)
+			strbuf_release(mi->p_hdr_data[i]);
+	free(mi->p_hdr_data);
+	if (mi->s_hdr_data)
+		for (i = 0; mi->s_hdr_data[i]; i++)
+			strbuf_release(mi->s_hdr_data[i]);
+	free(mi->s_hdr_data);
+
+	while (mi->content < mi->content_top) {
+		free(*(mi->content_top));
+		mi->content_top--;
+	}
+
+	strbuf_release(&mi->log_message);
+}
diff -pruN 1.2.1+git2.18.0-1/git/t/t4256/1/patch 1.2.3+git2.25.1-1/git/t/t4256/1/patch
--- 1.2.1+git2.18.0-1/git/t/t4256/1/patch	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t4256/1/patch	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,129 @@
+From: A <author@example.com>
+Subject: [PATCH] mailinfo: support format=flowed
+Message-ID: <aaaaaaaa-aaaa-aaaa-aaaa-aaaaaaaaaaaa@example.com>
+Date: Sat, 25 Aug 2018 22:04:50 +0200
+User-Agent: Mozilla/5.0 (Windows NT 10.0; WOW64; rv:60.0) Gecko/20100101
+ Thunderbird/60.0
+MIME-Version: 1.0
+Content-Type: text/plain; charset=utf-8; format=flowed
+Content-Language: en-US
+Content-Transfer-Encoding: 7bit
+
+---
+  mailinfo.c | 64 ++++++++++++++++++++++++++++++++++++++++++++++++++++--
+  1 file changed, 62 insertions(+), 2 deletions(-)
+
+diff --git a/mailinfo.c b/mailinfo.c
+index 3281a37d51..b395adbdf2 100644
+--- a/mailinfo.c
++++ b/mailinfo.c
+@@ -237,11 +237,22 @@ static int slurp_attr(const char *line, const char 
+*name, struct strbuf *attr)
+  	return 1;
+  }
+
++static int has_attr_value(const char *line, const char *name, const 
+char *value)
++{
++	struct strbuf sb = STRBUF_INIT;
++	int rc = slurp_attr(line, name, &sb) && !strcasecmp(sb.buf, value);
++	strbuf_release(&sb);
++	return rc;
++}
++
+  static void handle_content_type(struct mailinfo *mi, struct strbuf *line)
+  {
+  	struct strbuf *boundary = xmalloc(sizeof(struct strbuf));
+  	strbuf_init(boundary, line->len);
+
++	mi->format_flowed = has_attr_value(line->buf, "format=", "flowed");
++	mi->delsp = has_attr_value(line->buf, "delsp=", "yes");
++
+  	if (slurp_attr(line->buf, "boundary=", boundary)) {
+  		strbuf_insert(boundary, 0, "--", 2);
+  		if (++mi->content_top >= &mi->content[MAX_BOUNDARIES]) {
+@@ -964,6 +975,52 @@ static int handle_boundary(struct mailinfo *mi, 
+struct strbuf *line)
+  	return 1;
+  }
+
++static void handle_filter_flowed(struct mailinfo *mi, struct strbuf *line,
++				 struct strbuf *prev)
++{
++	size_t len = line->len;
++	const char *rest;
++
++	if (!mi->format_flowed) {
++		handle_filter(mi, line);
++		return;
++	}
++
++	if (line->buf[len - 1] == '\n') {
++		len--;
++		if (len && line->buf[len - 1] == '\r')
++			len--;
++	}
++
++	/* Keep signature separator as-is. */
++	if (skip_prefix(line->buf, "-- ", &rest) && rest - line->buf == len) {
++		if (prev->len) {
++			handle_filter(mi, prev);
++			strbuf_reset(prev);
++		}
++		handle_filter(mi, line);
++		return;
++	}
++
++	/* Unstuff space-stuffed line. */
++	if (len && line->buf[0] == ' ') {
++		strbuf_remove(line, 0, 1);
++		len--;
++	}
++
++	/* Save flowed line for later, but without the soft line break. */
++	if (len && line->buf[len - 1] == ' ') {
++		strbuf_add(prev, line->buf, len - !!mi->delsp);
++		return;
++	}
++
++	/* Prepend any previous partial lines */
++	strbuf_insert(line, 0, prev->buf, prev->len);
++	strbuf_reset(prev);
++
++	handle_filter(mi, line);
++}
++
+  static void handle_body(struct mailinfo *mi, struct strbuf *line)
+  {
+  	struct strbuf prev = STRBUF_INIT;
+@@ -1012,7 +1069,7 @@ static void handle_body(struct mailinfo *mi, 
+struct strbuf *line)
+  						strbuf_addbuf(&prev, sb);
+  						break;
+  					}
+-				handle_filter(mi, sb);
++				handle_filter_flowed(mi, sb, &prev);
+  			}
+  			/*
+  			 * The partial chunk is saved in "prev" and will be
+@@ -1022,13 +1079,16 @@ static void handle_body(struct mailinfo *mi, 
+struct strbuf *line)
+  			break;
+  		}
+  		default:
+-			handle_filter(mi, line);
++			handle_filter_flowed(mi, line, &prev);
+  		}
+
+  		if (mi->input_error)
+  			break;
+  	} while (!strbuf_getwholeline(line, mi->input, '\n'));
+
++	if (prev.len)
++		handle_filter(mi, &prev);
++
+  	flush_inbody_header_accum(mi);
+
+  handle_body_out:
+-- 
+2.18.0
diff -pruN 1.2.1+git2.18.0-1/git/t/t4256-am-format-flowed.sh 1.2.3+git2.25.1-1/git/t/t4256-am-format-flowed.sh
--- 1.2.1+git2.18.0-1/git/t/t4256-am-format-flowed.sh	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t4256-am-format-flowed.sh	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,19 @@
+#!/bin/sh
+
+test_description='test format=flowed support of git am'
+
+. ./test-lib.sh
+
+test_expect_success 'setup' '
+	cp "$TEST_DIRECTORY/t4256/1/mailinfo.c.orig" mailinfo.c &&
+	git add mailinfo.c &&
+	git commit -m initial
+'
+
+test_expect_success 'am with format=flowed' '
+	git am <"$TEST_DIRECTORY/t4256/1/patch" 2>stderr &&
+	test_i18ngrep "warning: Patch sent with format=flowed" stderr &&
+	test_cmp "$TEST_DIRECTORY/t4256/1/mailinfo.c" mailinfo.c
+'
+
+test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t4257-am-interactive.sh 1.2.3+git2.25.1-1/git/t/t4257-am-interactive.sh
--- 1.2.1+git2.18.0-1/git/t/t4257-am-interactive.sh	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t4257-am-interactive.sh	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,52 @@
+#!/bin/sh
+
+test_description='am --interactive tests'
+. ./test-lib.sh
+
+test_expect_success 'set up patches to apply' '
+	test_commit unrelated &&
+	test_commit no-conflict &&
+	test_commit conflict-patch file patch &&
+	git format-patch --stdout -2 >mbox &&
+
+	git reset --hard unrelated &&
+	test_commit conflict-master file master base
+'
+
+# Sanity check our setup.
+test_expect_success 'applying all patches generates conflict' '
+	test_must_fail git am mbox &&
+	echo resolved >file &&
+	git add -u &&
+	git am --resolved
+'
+
+test_expect_success 'interactive am can apply a single patch' '
+	git reset --hard base &&
+	# apply the first, but not the second
+	test_write_lines y n | git am -i mbox &&
+
+	echo no-conflict >expect &&
+	git log -1 --format=%s >actual &&
+	test_cmp expect actual
+'
+
+test_expect_success 'interactive am can resolve conflict' '
+	git reset --hard base &&
+	# apply both; the second one will conflict
+	test_write_lines y y | test_must_fail git am -i mbox &&
+	echo resolved >file &&
+	git add -u &&
+	# interactive "--resolved" will ask us if we want to apply the result
+	echo y | git am -i --resolved &&
+
+	echo conflict-patch >expect &&
+	git log -1 --format=%s >actual &&
+	test_cmp expect actual &&
+
+	echo resolved >expect &&
+	git cat-file blob HEAD:file >actual &&
+	test_cmp expect actual
+'
+
+test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t4300-merge-tree.sh 1.2.3+git2.25.1-1/git/t/t4300-merge-tree.sh
--- 1.2.1+git2.18.0-1/git/t/t4300-merge-tree.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t4300-merge-tree.sh	2020-02-17 04:47:35.000000000 +0000
@@ -25,25 +25,19 @@ EXPECTED
 '
 
 test_expect_success 'file add !A, B' '
-	cat >expected <<\EXPECTED &&
-EXPECTED
-
 	git reset --hard initial &&
 	test_commit "add-not-a-b" "ONE" "AAA" &&
 	git merge-tree initial add-not-a-b initial >actual &&
-	test_cmp expected actual
+	test_must_be_empty actual
 '
 
 test_expect_success 'file add A, B (same)' '
-	cat >expected <<\EXPECTED &&
-EXPECTED
-
 	git reset --hard initial &&
 	test_commit "add-a-b-same-A" "ONE" "AAA" &&
 	git reset --hard initial &&
 	test_commit "add-a-b-same-B" "ONE" "AAA" &&
 	git merge-tree initial add-a-b-same-A add-a-b-same-B >actual &&
-	test_cmp expected actual
+	test_must_be_empty actual
 '
 
 test_expect_success 'file add A, B (different)' '
@@ -68,13 +62,10 @@ EXPECTED
 '
 
 test_expect_success 'file change A, !B' '
-	cat >expected <<\EXPECTED &&
-EXPECTED
-
 	git reset --hard initial &&
 	test_commit "change-a-not-b" "initial-file" "BBB" &&
 	git merge-tree initial change-a-not-b initial >actual &&
-	test_cmp expected actual
+	test_must_be_empty actual
 '
 
 test_expect_success 'file change !A, B' '
@@ -94,15 +85,12 @@ EXPECTED
 '
 
 test_expect_success 'file change A, B (same)' '
-	cat >expected <<\EXPECTED &&
-EXPECTED
-
 	git reset --hard initial &&
 	test_commit "change-a-b-same-A" "initial-file" "AAA" &&
 	git reset --hard initial &&
 	test_commit "change-a-b-same-B" "initial-file" "AAA" &&
 	git merge-tree initial change-a-b-same-A change-a-b-same-B >actual &&
-	test_cmp expected actual
+	test_must_be_empty actual
 '
 
 test_expect_success 'file change A, B (different)' '
@@ -175,16 +163,13 @@ AAA" &&
 '
 
 test_expect_success 'file remove A, !B' '
-	cat >expected <<\EXPECTED &&
-EXPECTED
-
 	git reset --hard initial &&
 	test_commit "rm-a-not-b-base" "ONE" "AAA" &&
 	git rm ONE &&
 	git commit -m "rm-a-not-b" &&
 	git tag "rm-a-not-b" &&
 	git merge-tree rm-a-not-b-base rm-a-not-b rm-a-not-b-base >actual &&
-	test_cmp expected actual
+	test_must_be_empty actual
 '
 
 test_expect_success 'file remove !A, B' '
@@ -206,16 +191,13 @@ EXPECTED
 '
 
 test_expect_success 'file remove A, B (same)' '
-	cat >expected <<\EXPECTED &&
-EXPECTED
-
 	git reset --hard initial &&
 	test_commit "rm-a-b-base" "ONE" "AAA" &&
 	git rm ONE &&
 	git commit -m "rm-a-b" &&
 	git tag "rm-a-b" &&
 	git merge-tree rm-a-b-base rm-a-b rm-a-b >actual &&
-	test_cmp expected actual
+	test_must_be_empty actual
 '
 
 test_expect_success 'file change A, remove B' '
@@ -260,13 +242,11 @@ EXPECTED
 '
 
 test_expect_success 'tree add A, B (same)' '
-	cat >expect <<-\EOF &&
-	EOF
 	git reset --hard initial &&
 	mkdir sub &&
 	test_commit "add sub/file" "sub/file" "file" add-tree-A &&
 	git merge-tree initial add-tree-A add-tree-A >actual &&
-	test_cmp expect actual
+	test_must_be_empty actual
 '
 
 test_expect_success 'tree add A, B (different)' '
Binary files 1.2.1+git2.18.0-1/git/t/t5000/19f9c8273ec45a8938e6999cb59b3ff66739902a and 1.2.3+git2.25.1-1/git/t/t5000/19f9c8273ec45a8938e6999cb59b3ff66739902a differ
Binary files 1.2.1+git2.18.0-1/git/t/t5000/huge-object and 1.2.3+git2.25.1-1/git/t/t5000/huge-object differ
diff -pruN 1.2.1+git2.18.0-1/git/t/t5000-tar-tree.sh 1.2.3+git2.25.1-1/git/t/t5000-tar-tree.sh
--- 1.2.1+git2.18.0-1/git/t/t5000-tar-tree.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t5000-tar-tree.sh	2020-02-17 04:47:35.000000000 +0000
@@ -94,6 +94,13 @@ check_tar() {
 	'
 }
 
+test_expect_success 'setup' '
+	test_oid_cache <<-EOF
+	obj sha1:19f9c8273ec45a8938e6999cb59b3ff66739902a
+	obj sha256:3c666f798798601571f5cec0adb57ce4aba8546875e7693177e0535f34d2c49b
+	EOF
+'
+
 test_expect_success \
     'populate workdir' \
     'mkdir a &&
@@ -206,6 +213,12 @@ test_expect_success 'git archive with --
 	test_cmp_bin b.tar d4.zip
 '
 
+test_expect_success GZIP 'git archive with --output and --remote creates .tgz' '
+	git archive --output=d5.tgz --remote=. HEAD &&
+	gzip -d -c <d5.tgz >d5.tar &&
+	test_cmp_bin b.tar d5.tar
+'
+
 test_expect_success 'git archive --list outside of a git repo' '
 	nongit git archive --list
 '
@@ -363,11 +376,10 @@ test_lazy_prereq TAR_HUGE '
 '
 
 test_expect_success LONG_IS_64BIT 'set up repository with huge blob' '
-	obj_d=19 &&
-	obj_f=f9c8273ec45a8938e6999cb59b3ff66739902a &&
-	obj=${obj_d}${obj_f} &&
-	mkdir -p .git/objects/$obj_d &&
-	cp "$TEST_DIRECTORY"/t5000/$obj .git/objects/$obj_d/$obj_f &&
+	obj=$(test_oid obj) &&
+	path=$(test_oid_to_path $obj) &&
+	mkdir -p .git/objects/$(dirname $path) &&
+	cp "$TEST_DIRECTORY"/t5000/huge-object .git/objects/$path &&
 	rm -f .git/index &&
 	git update-index --add --cacheinfo 100644,$obj,huge &&
 	git commit -m huge
diff -pruN 1.2.1+git2.18.0-1/git/t/t5003-archive-zip.sh 1.2.3+git2.25.1-1/git/t/t5003-archive-zip.sh
--- 1.2.1+git2.18.0-1/git/t/t5003-archive-zip.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t5003-archive-zip.sh	2020-02-17 04:47:35.000000000 +0000
@@ -158,11 +158,16 @@ test_expect_success 'git archive --forma
     'git archive --format=zip --output=d2.zip HEAD &&
     test_cmp_bin d.zip d2.zip'
 
-test_expect_success 'git archive with --output, inferring format' '
+test_expect_success 'git archive with --output, inferring format (local)' '
 	git archive --output=d3.zip HEAD &&
 	test_cmp_bin d.zip d3.zip
 '
 
+test_expect_success 'git archive with --output, inferring format (remote)' '
+	git archive --remote=. --output=d4.zip HEAD &&
+	test_cmp_bin d.zip d4.zip
+'
+
 test_expect_success \
     'git archive --format=zip with prefix' \
     'git archive --format=zip --prefix=prefix/ HEAD >e.zip'
diff -pruN 1.2.1+git2.18.0-1/git/t/t5004-archive-corner-cases.sh 1.2.3+git2.25.1-1/git/t/t5004-archive-corner-cases.sh
--- 1.2.1+git2.18.0-1/git/t/t5004-archive-corner-cases.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t5004-archive-corner-cases.sh	2020-02-17 04:47:35.000000000 +0000
@@ -3,8 +3,12 @@
 test_description='test corner cases of git-archive'
 . ./test-lib.sh
 
-test_expect_success 'create commit with empty tree' '
-	git commit --allow-empty -m foo
+# the 10knuls.tar file is used to test for an empty git generated tar
+# without having to invoke tar because an otherwise valid empty GNU tar
+# will be considered broken by {Open,Net}BSD tar
+test_expect_success 'create commit with empty tree and fake empty tar' '
+	git commit --allow-empty -m foo &&
+	perl -e "print \"\\0\" x 10240" >10knuls.tar
 '
 
 # Make a dir and clean it up afterwards
@@ -47,7 +51,6 @@ test_expect_success HEADER_ONLY_TAR_OK '
 
 test_expect_success 'tar archive of empty tree is empty' '
 	git archive --format=tar HEAD: >empty.tar &&
-	perl -e "print \"\\0\" x 10240" >10knuls.tar &&
 	test_cmp_bin 10knuls.tar empty.tar
 '
 
@@ -106,16 +109,12 @@ test_expect_success 'create a commit wit
 
 test_expect_success 'archive empty subtree with no pathspec' '
 	git archive --format=tar $root_tree >subtree-all.tar &&
-	make_dir extract &&
-	"$TAR" xf subtree-all.tar -C extract &&
-	check_dir extract
+	test_cmp_bin 10knuls.tar subtree-all.tar
 '
 
 test_expect_success 'archive empty subtree by direct pathspec' '
 	git archive --format=tar $root_tree -- sub >subtree-path.tar &&
-	make_dir extract &&
-	"$TAR" xf subtree-path.tar -C extract &&
-	check_dir extract
+	test_cmp_bin 10knuls.tar subtree-path.tar
 '
 
 ZIPINFO=zipinfo
@@ -205,4 +204,23 @@ test_expect_success EXPENSIVE,LONG_IS_64
 	grep $size big.lst
 '
 
+build_tree() {
+	perl -e '
+		my $hash = $ARGV[0];
+		foreach my $order (2..6) {
+			$first = 10 ** $order;
+			foreach my $i (-13..-9) {
+				my $name = "a" x ($first + $i);
+				print "100644 blob $hash\t$name\n"
+			}
+		}
+	' "$1"
+}
+
+test_expect_success 'tar archive with long paths' '
+	blob=$(echo foo | git hash-object -w --stdin) &&
+	tree=$(build_tree $blob | git mktree) &&
+	git archive -o long_paths.tar $tree
+'
+
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t5150-request-pull.sh 1.2.3+git2.25.1-1/git/t/t5150-request-pull.sh
--- 1.2.1+git2.18.0-1/git/t/t5150-request-pull.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t5150-request-pull.sh	2020-02-17 04:47:35.000000000 +0000
@@ -4,6 +4,12 @@ test_description='Test workflows involvi
 
 . ./test-lib.sh
 
+if ! test_have_prereq PERL
+then
+	skip_all='skipping request-pull tests, perl not available'
+	test_done
+fi
+
 test_expect_success 'setup' '
 
 	git init --bare upstream.git &&
@@ -246,4 +252,57 @@ test_expect_success 'request-pull ignore
 
 '
 
+test_expect_success 'request-pull quotes regex metacharacters properly' '
+
+	rm -fr downstream.git &&
+	git init --bare downstream.git &&
+	(
+		cd local &&
+		git checkout initial &&
+		git merge --ff-only master &&
+		git tag -mrelease v2.0 &&
+		git push origin refs/tags/v2.0:refs/tags/v2-0 &&
+		test_must_fail git request-pull initial "$downstream_url" tags/v2.0 \
+			2>../err
+	) &&
+	grep "No match for commit .*" err &&
+	grep "Are you sure you pushed" err
+
+'
+
+test_expect_success 'pull request with mismatched object' '
+
+	rm -fr downstream.git &&
+	git init --bare downstream.git &&
+	(
+		cd local &&
+		git checkout initial &&
+		git merge --ff-only master &&
+		git push origin HEAD:refs/tags/full &&
+		test_must_fail git request-pull initial "$downstream_url" tags/full \
+			2>../err
+	) &&
+	grep "points to a different object" err &&
+	grep "Are you sure you pushed" err
+
+'
+
+test_expect_success 'pull request with stale object' '
+
+	rm -fr downstream.git &&
+	git init --bare downstream.git &&
+	(
+		cd local &&
+		git checkout initial &&
+		git merge --ff-only master &&
+		git push origin refs/tags/full &&
+		git tag -f -m"Thirty-one days" full &&
+		test_must_fail git request-pull initial "$downstream_url" tags/full \
+			2>../err
+	) &&
+	grep "points to a different object" err &&
+	grep "Are you sure you pushed" err
+
+'
+
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t5200-update-server-info.sh 1.2.3+git2.25.1-1/git/t/t5200-update-server-info.sh
--- 1.2.1+git2.18.0-1/git/t/t5200-update-server-info.sh	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t5200-update-server-info.sh	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,41 @@
+#!/bin/sh
+
+test_description='Test git update-server-info'
+
+. ./test-lib.sh
+
+test_expect_success 'setup' 'test_commit file'
+
+test_expect_success 'create info/refs' '
+	git update-server-info &&
+	test_path_is_file .git/info/refs
+'
+
+test_expect_success 'modify and store mtime' '
+	test-tool chmtime =0 .git/info/refs &&
+	test-tool chmtime --get .git/info/refs >a
+'
+
+test_expect_success 'info/refs is not needlessly overwritten' '
+	git update-server-info &&
+	test-tool chmtime --get .git/info/refs >b &&
+	test_cmp a b
+'
+
+test_expect_success 'info/refs can be forced to update' '
+	git update-server-info -f &&
+	test-tool chmtime --get .git/info/refs >b &&
+	! test_cmp a b
+'
+
+test_expect_success 'info/refs updates when changes are made' '
+	test-tool chmtime =0 .git/info/refs &&
+	test-tool chmtime --get .git/info/refs >b &&
+	test_cmp a b &&
+	git update-ref refs/heads/foo HEAD &&
+	git update-server-info &&
+	test-tool chmtime --get .git/info/refs >b &&
+	! test_cmp a b
+'
+
+test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t5300-pack-object.sh 1.2.3+git2.25.1-1/git/t/t5300-pack-object.sh
--- 1.2.1+git2.18.0-1/git/t/t5300-pack-object.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t5300-pack-object.sh	2020-02-17 04:47:35.000000000 +0000
@@ -191,7 +191,7 @@ test_expect_success 'survive missing obj
 		mkdir missing-pack &&
 		cd missing-pack &&
 		git init &&
-		GOP=.git/objects/pack
+		GOP=.git/objects/pack &&
 		rm -fr $GOP &&
 		git index-pack --stdin --keep=test <../test-3-${packname_3}.pack &&
 		test -f $GOP/pack-${packname_3}.pack &&
@@ -468,29 +468,32 @@ test_expect_success 'pack-objects in too
 	git fsck
 '
 
-#
-# WARNING!
-#
-# The following test is destructive.  Please keep the next
-# two tests at the end of this file.
-#
-
-test_expect_success \
-    'fake a SHA1 hash collision' \
-    'long_a=$(git hash-object a | sed -e "s!^..!&/!") &&
-     long_b=$(git hash-object b | sed -e "s!^..!&/!") &&
-     test -f	.git/objects/$long_b &&
-     cp -f	.git/objects/$long_a \
-		.git/objects/$long_b'
+test_expect_success 'setup: fake a SHA1 hash collision' '
+	git init corrupt &&
+	(
+		cd corrupt &&
+		long_a=$(git hash-object -w ../a | sed -e "s!^..!&/!") &&
+		long_b=$(git hash-object -w ../b | sed -e "s!^..!&/!") &&
+		test -f	.git/objects/$long_b &&
+		cp -f	.git/objects/$long_a \
+			.git/objects/$long_b
+	)
+'
 
-test_expect_success \
-    'make sure index-pack detects the SHA1 collision' \
-    'test_must_fail git index-pack -o bad.idx test-3.pack 2>msg &&
-     test_i18ngrep "SHA1 COLLISION FOUND" msg'
+test_expect_success 'make sure index-pack detects the SHA1 collision' '
+	(
+		cd corrupt &&
+		test_must_fail git index-pack -o ../bad.idx ../test-3.pack 2>msg &&
+		test_i18ngrep "SHA1 COLLISION FOUND" msg
+	)
+'
 
-test_expect_success \
-    'make sure index-pack detects the SHA1 collision (large blobs)' \
-    'test_must_fail git -c core.bigfilethreshold=1 index-pack -o bad.idx test-3.pack 2>msg &&
-     test_i18ngrep "SHA1 COLLISION FOUND" msg'
+test_expect_success 'make sure index-pack detects the SHA1 collision (large blobs)' '
+	(
+		cd corrupt &&
+		test_must_fail git -c core.bigfilethreshold=1 index-pack -o ../bad.idx ../test-3.pack 2>msg &&
+		test_i18ngrep "SHA1 COLLISION FOUND" msg
+	)
+'
 
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t5302-pack-index.sh 1.2.3+git2.25.1-1/git/t/t5302-pack-index.sh
--- 1.2.1+git2.18.0-1/git/t/t5302-pack-index.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t5302-pack-index.sh	2020-02-17 04:47:35.000000000 +0000
@@ -237,7 +237,7 @@ test_expect_success 'running index-pack
     rm -f .git/objects/pack/* &&
     cp test-1-${pack1}.pack .git/objects/pack/pack-${pack1}.pack &&
     (
-	cd .git/objects/pack
+	cd .git/objects/pack &&
 	git index-pack pack-${pack1}.pack
     ) &&
     test -f .git/objects/pack/pack-${pack1}.idx
diff -pruN 1.2.1+git2.18.0-1/git/t/t5303-pack-corruption-resilience.sh 1.2.3+git2.25.1-1/git/t/t5303-pack-corruption-resilience.sh
--- 1.2.1+git2.18.0-1/git/t/t5303-pack-corruption-resilience.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t5303-pack-corruption-resilience.sh	2020-02-17 04:47:35.000000000 +0000
@@ -311,4 +311,93 @@ test_expect_success \
      test_must_fail git cat-file blob $blob_2 > /dev/null &&
      test_must_fail git cat-file blob $blob_3 > /dev/null'
 
+# \0 - empty base
+# \1 - one byte in result
+# \1 - one literal byte (X)
+test_expect_success \
+    'apply good minimal delta' \
+    'printf "\0\1\1X" > minimal_delta &&
+     test-tool delta -p /dev/null minimal_delta /dev/null'
+
+# \0 - empty base
+# \1 - 1 byte in result
+# \2 - two literal bytes (one too many)
+test_expect_success \
+    'apply delta with too many literal bytes' \
+    'printf "\0\1\2XX" > too_big_literal &&
+     test_must_fail test-tool delta -p /dev/null too_big_literal /dev/null'
+
+# \4 - four bytes in base
+# \1 - one byte in result
+# \221 - copy, one byte offset, one byte size
+#   \0 - copy from offset 0
+#   \2 - copy two bytes (one too many)
+test_expect_success \
+    'apply delta with too many copied bytes' \
+    'printf "\4\1\221\0\2" > too_big_copy &&
+     printf base >base &&
+     test_must_fail test-tool delta -p base too_big_copy /dev/null'
+
+# \0 - empty base
+# \2 - two bytes in result
+# \2 - two literal bytes (we are short one)
+test_expect_success \
+    'apply delta with too few literal bytes' \
+    'printf "\0\2\2X" > truncated_delta &&
+     test_must_fail test-tool delta -p /dev/null truncated_delta /dev/null'
+
+# \0 - empty base
+# \1 - one byte in result
+# \221 - copy, one byte offset, one byte size
+#   \0 - copy from offset 0
+#   \1 - copy one byte (we are short one)
+test_expect_success \
+    'apply delta with too few bytes in base' \
+    'printf "\0\1\221\0\1" > truncated_base &&
+     test_must_fail test-tool delta -p /dev/null truncated_base /dev/null'
+
+# \4 - four bytes in base
+# \2 - two bytes in result
+# \1 - one literal byte (X)
+# \221 - copy, one byte offset, one byte size
+#        (offset/size missing)
+#
+# Note that the literal byte is necessary to get past the uninteresting minimum
+# delta size check.
+test_expect_success \
+    'apply delta with truncated copy parameters' \
+    'printf "\4\2\1X\221" > truncated_copy_delta &&
+     printf base >base &&
+     test_must_fail test-tool delta -p base truncated_copy_delta /dev/null'
+
+# \0 - empty base
+# \1 - one byte in result
+# \1 - one literal byte (X)
+# \1 - trailing garbage command
+test_expect_success \
+    'apply delta with trailing garbage literal' \
+    'printf "\0\1\1X\1" > tail_garbage_literal &&
+     test_must_fail test-tool delta -p /dev/null tail_garbage_literal /dev/null'
+
+# \4 - four bytes in base
+# \1 - one byte in result
+# \1 - one literal byte (X)
+# \221 - copy, one byte offset, one byte size
+#   \0 - copy from offset 0
+#   \1 - copy 1 byte
+test_expect_success \
+    'apply delta with trailing garbage copy' \
+    'printf "\4\1\1X\221\0\1" > tail_garbage_copy &&
+     printf base >base &&
+     test_must_fail test-tool delta -p /dev/null tail_garbage_copy /dev/null'
+
+# \0 - empty base
+# \1 - one byte in result
+# \1 - one literal byte (X)
+# \0 - bogus opcode
+test_expect_success \
+    'apply delta with trailing garbage opcode' \
+    'printf "\0\1\1X\0" > tail_garbage_opcode &&
+     test_must_fail test-tool delta -p /dev/null tail_garbage_opcode /dev/null'
+
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t5304-prune.sh 1.2.3+git2.25.1-1/git/t/t5304-prune.sh
--- 1.2.1+git2.18.0-1/git/t/t5304-prune.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t5304-prune.sh	2020-02-17 04:47:35.000000000 +0000
@@ -112,17 +112,16 @@ test_expect_success 'prune: do not prune
 	# (should be removed and disabled by previous test)
 	test_path_is_missing .git/logs &&
 	git prune -n >prune_actual &&
-	: >prune_expected &&
-	test_cmp prune_actual prune_expected
+	test_must_be_empty prune_actual
 
 '
 
 test_expect_success 'prune: prune former HEAD after checking out branch' '
 
-	head_sha1=$(git rev-parse HEAD) &&
+	head_oid=$(git rev-parse HEAD) &&
 	git checkout --quiet master &&
 	git prune -v >prune_actual &&
-	grep "$head_sha1" prune_actual
+	grep "$head_oid" prune_actual
 
 '
 
@@ -266,15 +265,27 @@ EOF
 '
 
 test_expect_success 'prune .git/shallow' '
-	SHA1=$(echo hi|git commit-tree HEAD^{tree}) &&
-	echo $SHA1 >.git/shallow &&
+	oid=$(echo hi|git commit-tree HEAD^{tree}) &&
+	echo $oid >.git/shallow &&
 	git prune --dry-run >out &&
-	grep $SHA1 .git/shallow &&
-	grep $SHA1 out &&
+	grep $oid .git/shallow &&
+	grep $oid out &&
 	git prune &&
 	test_path_is_missing .git/shallow
 '
 
+test_expect_success 'prune .git/shallow when there are no loose objects' '
+	oid=$(echo hi|git commit-tree HEAD^{tree}) &&
+	echo $oid >.git/shallow &&
+	git update-ref refs/heads/shallow-tip $oid &&
+	git repack -ad &&
+	# verify assumption that all loose objects are gone
+	git count-objects | grep ^0 &&
+	git prune &&
+	echo $oid >expect &&
+	test_cmp expect .git/shallow
+'
+
 test_expect_success 'prune: handle alternate object database' '
 	test_create_repo A &&
 	git -C A commit --allow-empty -m "initial commit" &&
@@ -315,8 +326,8 @@ test_expect_success 'prune: handle HEAD
 		git reset --hard HEAD^
 	) &&
 	git prune --expire=now &&
-	SHA1=`git hash-object expected` &&
-	git -C third-worktree show "$SHA1" >actual &&
+	oid=`git hash-object expected` &&
+	git -C third-worktree show "$oid" >actual &&
 	test_cmp expected actual
 '
 
@@ -330,4 +341,12 @@ test_expect_success 'prune: handle expir
 	git prune --no-expire
 '
 
+test_expect_success 'trivial prune with bitmaps enabled' '
+	git repack -adb &&
+	blob=$(echo bitmap-unreachable-blob | git hash-object -w --stdin) &&
+	git prune --expire=now &&
+	git cat-file -e HEAD &&
+	test_must_fail git cat-file -e $blob
+'
+
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t5307-pack-missing-commit.sh 1.2.3+git2.25.1-1/git/t/t5307-pack-missing-commit.sh
--- 1.2.1+git2.18.0-1/git/t/t5307-pack-missing-commit.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t5307-pack-missing-commit.sh	2020-02-17 04:47:35.000000000 +0000
@@ -24,11 +24,11 @@ test_expect_success 'check corruption' '
 '
 
 test_expect_success 'rev-list notices corruption (1)' '
-	test_must_fail git rev-list HEAD
+	test_must_fail env GIT_TEST_COMMIT_GRAPH=0 git -c core.commitGraph=false rev-list HEAD
 '
 
 test_expect_success 'rev-list notices corruption (2)' '
-	test_must_fail git rev-list --objects HEAD
+	test_must_fail env GIT_TEST_COMMIT_GRAPH=0 git -c core.commitGraph=false rev-list --objects HEAD
 '
 
 test_expect_success 'pack-objects notices corruption' '
diff -pruN 1.2.1+git2.18.0-1/git/t/t5310-pack-bitmaps.sh 1.2.3+git2.25.1-1/git/t/t5310-pack-bitmaps.sh
--- 1.2.1+git2.18.0-1/git/t/t5310-pack-bitmaps.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t5310-pack-bitmaps.sh	2020-02-17 04:47:35.000000000 +0000
@@ -9,7 +9,8 @@ objpath () {
 
 # show objects present in pack ($1 should be associated *.idx)
 list_packed_objects () {
-	git show-index <"$1" | cut -d' ' -f2
+	git show-index <"$1" >object-list &&
+	cut -d' ' -f2 object-list
 }
 
 # has_any pattern-file content-file
@@ -20,21 +21,14 @@ has_any () {
 }
 
 test_expect_success 'setup repo with moderate-sized history' '
-	for i in $(test_seq 1 10)
-	do
-		test_commit $i
-	done &&
+	test_commit_bulk --id=file 100 &&
 	git checkout -b other HEAD~5 &&
-	for i in $(test_seq 1 10)
-	do
-		test_commit side-$i
-	done &&
+	test_commit_bulk --id=side 10 &&
 	git checkout master &&
 	bitmaptip=$(git rev-parse master) &&
 	blob=$(echo tagged-blob | git hash-object -w --stdin) &&
 	git tag tagged-blob $blob &&
-	git config repack.writebitmaps true &&
-	git config pack.writebitmaphashcache true
+	git config repack.writebitmaps true
 '
 
 test_expect_success 'full repack creates bitmaps' '
@@ -106,10 +100,7 @@ test_expect_success 'clone from bitmappe
 '
 
 test_expect_success 'setup further non-bitmapped commits' '
-	for i in $(test_seq 1 10)
-	do
-		test_commit further-$i
-	done
+	test_commit_bulk --id=further 10
 '
 
 rev_list_tests 'partial bitmap'
@@ -190,6 +181,7 @@ test_expect_success 'pack-objects respec
 
 test_expect_success 'pack-objects respects --local (non-local bitmapped pack)' '
 	mv .git/objects/pack/$packbitmap.* alt.git/objects/pack/ &&
+	rm -f .git/objects/pack/multi-pack-index &&
 	test_when_finished "mv alt.git/objects/pack/$packbitmap.* .git/objects/pack/" &&
 	echo HEAD | git pack-objects --local --stdout --revs >3b.pack &&
 	git index-pack 3b.pack &&
@@ -204,8 +196,8 @@ test_expect_success 'pack-objects to fil
 	# verify equivalent packs are generated with/without using bitmap index
 	packasha1=$(git pack-objects --no-use-bitmap-index --all packa </dev/null) &&
 	packbsha1=$(git pack-objects --use-bitmap-index --all packb </dev/null) &&
-	list_packed_objects <packa-$packasha1.idx >packa.objects &&
-	list_packed_objects <packb-$packbsha1.idx >packb.objects &&
+	list_packed_objects packa-$packasha1.idx >packa.objects &&
+	list_packed_objects packb-$packbsha1.idx >packb.objects &&
 	test_cmp packa.objects packb.objects
 '
 
@@ -267,7 +259,7 @@ test_expect_success JGIT 'we can read jg
 	git clone --bare . compat-jgit.git &&
 	(
 		cd compat-jgit.git &&
-		rm -f .git/objects/pack/*.bitmap &&
+		rm -f objects/pack/*.bitmap &&
 		jgit gc &&
 		git rev-list --test-bitmap HEAD
 	)
@@ -309,9 +301,8 @@ test_expect_success 'pack reuse respects
 	done &&
 	reusable_pack --honor-pack-keep >empty.pack &&
 	git index-pack empty.pack &&
-	>expect &&
 	git show-index <empty.idx >actual &&
-	test_cmp expect actual
+	test_must_be_empty actual
 '
 
 test_expect_success 'pack reuse respects --local' '
@@ -319,17 +310,15 @@ test_expect_success 'pack reuse respects
 	test_when_finished "mv alt.git/objects/pack/* .git/objects/pack/" &&
 	reusable_pack --local >empty.pack &&
 	git index-pack empty.pack &&
-	>expect &&
 	git show-index <empty.idx >actual &&
-	test_cmp expect actual
+	test_must_be_empty actual
 '
 
 test_expect_success 'pack reuse respects --incremental' '
 	reusable_pack --incremental >empty.pack &&
 	git index-pack empty.pack &&
-	>expect &&
 	git show-index <empty.idx >actual &&
-	test_cmp expect actual
+	test_must_be_empty actual
 '
 
 test_expect_success 'truncated bitmap fails gracefully' '
@@ -337,11 +326,104 @@ test_expect_success 'truncated bitmap fa
 	git rev-list --use-bitmap-index --count --all >expect &&
 	bitmap=$(ls .git/objects/pack/*.bitmap) &&
 	test_when_finished "rm -f $bitmap" &&
-	head -c 512 <$bitmap >$bitmap.tmp &&
+	test_copy_bytes 512 <$bitmap >$bitmap.tmp &&
 	mv -f $bitmap.tmp $bitmap &&
 	git rev-list --use-bitmap-index --count --all >actual 2>stderr &&
 	test_cmp expect actual &&
 	test_i18ngrep corrupt stderr
 '
 
+# have_delta <obj> <expected_base>
+#
+# Note that because this relies on cat-file, it might find _any_ copy of an
+# object in the repository. The caller is responsible for making sure
+# there's only one (e.g., via "repack -ad", or having just fetched a copy).
+have_delta () {
+	echo $2 >expect &&
+	echo $1 | git cat-file --batch-check="%(deltabase)" >actual &&
+	test_cmp expect actual
+}
+
+# Create a state of history with these properties:
+#
+#  - refs that allow a client to fetch some new history, while sharing some old
+#    history with the server; we use branches delta-reuse-old and
+#    delta-reuse-new here
+#
+#  - the new history contains an object that is stored on the server as a delta
+#    against a base that is in the old history
+#
+#  - the base object is not immediately reachable from the tip of the old
+#    history; finding it would involve digging down through history we know the
+#    other side has
+#
+# This should result in a state where fetching from old->new would not
+# traditionally reuse the on-disk delta (because we'd have to dig to realize
+# that the client has it), but we will do so if bitmaps can tell us cheaply
+# that the other side has it.
+test_expect_success 'set up thin delta-reuse parent' '
+	# This first commit contains the buried base object.
+	test-tool genrandom delta 16384 >file &&
+	git add file &&
+	git commit -m "delta base" &&
+	base=$(git rev-parse --verify HEAD:file) &&
+
+	# These intermediate commits bury the base back in history.
+	# This becomes the "old" state.
+	for i in 1 2 3 4 5
+	do
+		echo $i >file &&
+		git commit -am "intermediate $i" || return 1
+	done &&
+	git branch delta-reuse-old &&
+
+	# And now our new history has a delta against the buried base. Note
+	# that this must be smaller than the original file, since pack-objects
+	# prefers to create deltas from smaller objects to larger.
+	test-tool genrandom delta 16300 >file &&
+	git commit -am "delta result" &&
+	delta=$(git rev-parse --verify HEAD:file) &&
+	git branch delta-reuse-new &&
+
+	# Repack with bitmaps and double check that we have the expected delta
+	# relationship.
+	git repack -adb &&
+	have_delta $delta $base
+'
+
+# Now we can sanity-check the non-bitmap behavior (that the server is not able
+# to reuse the delta). This isn't strictly something we care about, so this
+# test could be scrapped in the future. But it makes sure that the next test is
+# actually triggering the feature we want.
+#
+# Note that our tools for working with on-the-wire "thin" packs are limited. So
+# we actually perform the fetch, retain the resulting pack, and inspect the
+# result.
+test_expect_success 'fetch without bitmaps ignores delta against old base' '
+	test_config pack.usebitmaps false &&
+	test_when_finished "rm -rf client.git" &&
+	git init --bare client.git &&
+	(
+		cd client.git &&
+		git config transfer.unpackLimit 1 &&
+		git fetch .. delta-reuse-old:delta-reuse-old &&
+		git fetch .. delta-reuse-new:delta-reuse-new &&
+		have_delta $delta $ZERO_OID
+	)
+'
+
+# And do the same for the bitmap case, where we do expect to find the delta.
+test_expect_success 'fetch with bitmaps can reuse old base' '
+	test_config pack.usebitmaps true &&
+	test_when_finished "rm -rf client.git" &&
+	git init --bare client.git &&
+	(
+		cd client.git &&
+		git config transfer.unpackLimit 1 &&
+		git fetch .. delta-reuse-old:delta-reuse-old &&
+		git fetch .. delta-reuse-new:delta-reuse-new &&
+		have_delta $delta $base
+	)
+'
+
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t5313-pack-bounds-checks.sh 1.2.3+git2.25.1-1/git/t/t5313-pack-bounds-checks.sh
--- 1.2.1+git2.18.0-1/git/t/t5313-pack-bounds-checks.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t5313-pack-bounds-checks.sh	2020-02-17 04:47:35.000000000 +0000
@@ -90,9 +90,8 @@ test_expect_success 'matched bogus objec
 
 	# Unlike above, we should notice early that the .idx is totally
 	# bogus, and not even enumerate its contents.
-	>expect &&
 	git cat-file --batch-all-objects --batch-check >actual &&
-	test_cmp expect actual &&
+	test_must_be_empty actual &&
 
 	# But as before, we can do the same object-access checks.
 	test_must_fail git cat-file blob $object &&
diff -pruN 1.2.1+git2.18.0-1/git/t/t5314-pack-cycle-detection.sh 1.2.3+git2.25.1-1/git/t/t5314-pack-cycle-detection.sh
--- 1.2.1+git2.18.0-1/git/t/t5314-pack-cycle-detection.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t5314-pack-cycle-detection.sh	2020-02-17 04:47:35.000000000 +0000
@@ -53,7 +53,7 @@ immediately after the lookup for "dummy"
 
 
 
-# Create a pack containing the the tree $1 and blob $1:file, with
+# Create a pack containing the tree $1 and blob $1:file, with
 # the latter stored as a delta against $2:file.
 #
 # We convince pack-objects to make the delta in the direction of our choosing
@@ -98,9 +98,8 @@ test_expect_success 'repack' '
 	# We first want to check that we do not have any internal errors,
 	# and also that we do not hit the last-ditch cycle-breaking code
 	# in write_object(), which will issue a warning to stderr.
-	>expect &&
 	git repack -ad 2>stderr &&
-	test_cmp expect stderr &&
+	test_must_be_empty stderr &&
 
 	# And then double-check that the resulting pack is usable (i.e.,
 	# we did not fail to notice any cycles). We know we are accessing
diff -pruN 1.2.1+git2.18.0-1/git/t/t5315-pack-objects-compression.sh 1.2.3+git2.25.1-1/git/t/t5315-pack-objects-compression.sh
--- 1.2.1+git2.18.0-1/git/t/t5315-pack-objects-compression.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t5315-pack-objects-compression.sh	2020-02-17 04:47:35.000000000 +0000
@@ -7,7 +7,7 @@ test_description='pack-object compressio
 # This should be moved to test-lib.sh together with the
 # copy in t0021 after both topics have graduated to 'master'.
 file_size () {
-	perl -e 'print -s $ARGV[0]' "$1"
+	test-tool path-utils file-size "$1"
 }
 
 test_expect_success setup '
diff -pruN 1.2.1+git2.18.0-1/git/t/t5317-pack-objects-filter-objects.sh 1.2.3+git2.25.1-1/git/t/t5317-pack-objects-filter-objects.sh
--- 1.2.1+git2.18.0-1/git/t/t5317-pack-objects-filter-objects.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t5317-pack-objects-filter-objects.sh	2020-02-17 04:47:35.000000000 +0000
@@ -21,42 +21,87 @@ test_expect_success 'setup r1' '
 
 test_expect_success 'verify blob count in normal packfile' '
 	git -C r1 ls-files -s file.1 file.2 file.3 file.4 file.5 \
-		| awk -f print_2.awk \
-		| sort >expected &&
-	git -C r1 pack-objects --rev --stdout >all.pack <<-EOF &&
+		>ls_files_result &&
+	awk -f print_2.awk ls_files_result |
+	sort >expected &&
+
+	git -C r1 pack-objects --revs --stdout >all.pack <<-EOF &&
 	HEAD
 	EOF
 	git -C r1 index-pack ../all.pack &&
-	git -C r1 verify-pack -v ../all.pack \
-		| grep blob \
-		| awk -f print_1.awk \
-		| sort >observed &&
-	test_cmp observed expected
+
+	git -C r1 verify-pack -v ../all.pack >verify_result &&
+	grep blob verify_result |
+	awk -f print_1.awk |
+	sort >observed &&
+
+	test_cmp expected observed
 '
 
 test_expect_success 'verify blob:none packfile has no blobs' '
-	git -C r1 pack-objects --rev --stdout --filter=blob:none >filter.pack <<-EOF &&
+	git -C r1 pack-objects --revs --stdout --filter=blob:none >filter.pack <<-EOF &&
 	HEAD
 	EOF
 	git -C r1 index-pack ../filter.pack &&
-	git -C r1 verify-pack -v ../filter.pack \
-		| grep blob \
-		| awk -f print_1.awk \
-		| sort >observed &&
-	nr=$(wc -l <observed) &&
-	test 0 -eq $nr
+
+	git -C r1 verify-pack -v ../filter.pack >verify_result &&
+	! grep blob verify_result
 '
 
 test_expect_success 'verify normal and blob:none packfiles have same commits/trees' '
-	git -C r1 verify-pack -v ../all.pack \
-		| grep -E "commit|tree" \
-		| awk -f print_1.awk \
-		| sort >expected &&
-	git -C r1 verify-pack -v ../filter.pack \
-		| grep -E "commit|tree" \
-		| awk -f print_1.awk \
-		| sort >observed &&
-	test_cmp observed expected
+	git -C r1 verify-pack -v ../all.pack >verify_result &&
+	grep -E "commit|tree" verify_result |
+	awk -f print_1.awk |
+	sort >expected &&
+
+	git -C r1 verify-pack -v ../filter.pack >verify_result &&
+	grep -E "commit|tree" verify_result |
+	awk -f print_1.awk |
+	sort >observed &&
+
+	test_cmp expected observed
+'
+
+test_expect_success 'get an error for missing tree object' '
+	git init r5 &&
+	echo foo >r5/foo &&
+	git -C r5 add foo &&
+	git -C r5 commit -m "foo" &&
+	git -C r5 rev-parse HEAD^{tree} >tree &&
+	del=$(sed "s|..|&/|" tree) &&
+	rm r5/.git/objects/$del &&
+	test_must_fail git -C r5 pack-objects --revs --stdout 2>bad_tree <<-EOF &&
+	HEAD
+	EOF
+	grep "bad tree object" bad_tree
+'
+
+test_expect_success 'setup for tests of tree:0' '
+	mkdir r1/subtree &&
+	echo "This is a file in a subtree" >r1/subtree/file &&
+	git -C r1 add subtree/file &&
+	git -C r1 commit -m subtree
+'
+
+test_expect_success 'verify tree:0 packfile has no blobs or trees' '
+	git -C r1 pack-objects --revs --stdout --filter=tree:0 >commitsonly.pack <<-EOF &&
+	HEAD
+	EOF
+	git -C r1 index-pack ../commitsonly.pack &&
+	git -C r1 verify-pack -v ../commitsonly.pack >objs &&
+	! grep -E "tree|blob" objs
+'
+
+test_expect_success 'grab tree directly when using tree:0' '
+	# We should get the tree specified directly but not its blobs or subtrees.
+	git -C r1 pack-objects --revs --stdout --filter=tree:0 >commitsonly.pack <<-EOF &&
+	HEAD:
+	EOF
+	git -C r1 index-pack ../commitsonly.pack &&
+	git -C r1 verify-pack -v ../commitsonly.pack >objs &&
+	awk "/tree|blob/{print \$1}" objs >trees_and_blobs &&
+	git -C r1 rev-parse HEAD: >expected &&
+	test_cmp expected trees_and_blobs
 '
 
 # Test blob:limit=<n>[kmg] filter.
@@ -75,119 +120,152 @@ test_expect_success 'setup r2' '
 '
 
 test_expect_success 'verify blob count in normal packfile' '
-	git -C r2 ls-files -s large.1000 large.10000 \
-		| awk -f print_2.awk \
-		| sort >expected &&
-	git -C r2 pack-objects --rev --stdout >all.pack <<-EOF &&
+	git -C r2 ls-files -s large.1000 large.10000 >ls_files_result &&
+	awk -f print_2.awk ls_files_result |
+	sort >expected &&
+
+	git -C r2 pack-objects --revs --stdout >all.pack <<-EOF &&
 	HEAD
 	EOF
 	git -C r2 index-pack ../all.pack &&
-	git -C r2 verify-pack -v ../all.pack \
-		| grep blob \
-		| awk -f print_1.awk \
-		| sort >observed &&
-	test_cmp observed expected
+
+	git -C r2 verify-pack -v ../all.pack >verify_result &&
+	grep blob verify_result |
+	awk -f print_1.awk |
+	sort >observed &&
+
+	test_cmp expected observed
 '
 
 test_expect_success 'verify blob:limit=500 omits all blobs' '
-	git -C r2 pack-objects --rev --stdout --filter=blob:limit=500 >filter.pack <<-EOF &&
+	git -C r2 pack-objects --revs --stdout --filter=blob:limit=500 >filter.pack <<-EOF &&
 	HEAD
 	EOF
 	git -C r2 index-pack ../filter.pack &&
-	git -C r2 verify-pack -v ../filter.pack \
-		| grep blob \
-		| awk -f print_1.awk \
-		| sort >observed &&
-	nr=$(wc -l <observed) &&
-	test 0 -eq $nr
+
+	git -C r2 verify-pack -v ../filter.pack >verify_result &&
+	! grep blob verify_result
 '
 
 test_expect_success 'verify blob:limit=1000' '
-	git -C r2 pack-objects --rev --stdout --filter=blob:limit=1000 >filter.pack <<-EOF &&
+	git -C r2 pack-objects --revs --stdout --filter=blob:limit=1000 >filter.pack <<-EOF &&
 	HEAD
 	EOF
 	git -C r2 index-pack ../filter.pack &&
-	git -C r2 verify-pack -v ../filter.pack \
-		| grep blob \
-		| awk -f print_1.awk \
-		| sort >observed &&
-	nr=$(wc -l <observed) &&
-	test 0 -eq $nr
+
+	git -C r2 verify-pack -v ../filter.pack >verify_result &&
+	! grep blob verify_result
 '
 
 test_expect_success 'verify blob:limit=1001' '
-	git -C r2 ls-files -s large.1000 \
-		| awk -f print_2.awk \
-		| sort >expected &&
-	git -C r2 pack-objects --rev --stdout --filter=blob:limit=1001 >filter.pack <<-EOF &&
+	git -C r2 ls-files -s large.1000 >ls_files_result &&
+	awk -f print_2.awk ls_files_result |
+	sort >expected &&
+
+	git -C r2 pack-objects --revs --stdout --filter=blob:limit=1001 >filter.pack <<-EOF &&
 	HEAD
 	EOF
 	git -C r2 index-pack ../filter.pack &&
-	git -C r2 verify-pack -v ../filter.pack \
-		| grep blob \
-		| awk -f print_1.awk \
-		| sort >observed &&
-	test_cmp observed expected
+
+	git -C r2 verify-pack -v ../filter.pack >verify_result &&
+	grep blob verify_result |
+	awk -f print_1.awk |
+	sort >observed &&
+
+	test_cmp expected observed
 '
 
 test_expect_success 'verify blob:limit=10001' '
-	git -C r2 ls-files -s large.1000 large.10000 \
-		| awk -f print_2.awk \
-		| sort >expected &&
-	git -C r2 pack-objects --rev --stdout --filter=blob:limit=10001 >filter.pack <<-EOF &&
+	git -C r2 ls-files -s large.1000 large.10000 >ls_files_result &&
+	awk -f print_2.awk ls_files_result |
+	sort >expected &&
+
+	git -C r2 pack-objects --revs --stdout --filter=blob:limit=10001 >filter.pack <<-EOF &&
 	HEAD
 	EOF
 	git -C r2 index-pack ../filter.pack &&
-	git -C r2 verify-pack -v ../filter.pack \
-		| grep blob \
-		| awk -f print_1.awk \
-		| sort >observed &&
-	test_cmp observed expected
+
+	git -C r2 verify-pack -v ../filter.pack >verify_result &&
+	grep blob verify_result |
+	awk -f print_1.awk |
+	sort >observed &&
+
+	test_cmp expected observed
 '
 
 test_expect_success 'verify blob:limit=1k' '
-	git -C r2 ls-files -s large.1000 \
-		| awk -f print_2.awk \
-		| sort >expected &&
-	git -C r2 pack-objects --rev --stdout --filter=blob:limit=1k >filter.pack <<-EOF &&
+	git -C r2 ls-files -s large.1000 >ls_files_result &&
+	awk -f print_2.awk ls_files_result |
+	sort >expected &&
+
+	git -C r2 pack-objects --revs --stdout --filter=blob:limit=1k >filter.pack <<-EOF &&
 	HEAD
 	EOF
 	git -C r2 index-pack ../filter.pack &&
-	git -C r2 verify-pack -v ../filter.pack \
-		| grep blob \
-		| awk -f print_1.awk \
-		| sort >observed &&
-	test_cmp observed expected
+
+	git -C r2 verify-pack -v ../filter.pack >verify_result &&
+	grep blob verify_result |
+	awk -f print_1.awk |
+	sort >observed &&
+
+	test_cmp expected observed
+'
+
+test_expect_success 'verify explicitly specifying oversized blob in input' '
+	git -C r2 ls-files -s large.1000 large.10000 >ls_files_result &&
+	awk -f print_2.awk ls_files_result |
+	sort >expected &&
+
+	echo HEAD >objects &&
+	git -C r2 rev-parse HEAD:large.10000 >>objects &&
+	git -C r2 pack-objects --revs --stdout --filter=blob:limit=1k <objects >filter.pack &&
+	git -C r2 index-pack ../filter.pack &&
+
+	git -C r2 verify-pack -v ../filter.pack >verify_result &&
+	grep blob verify_result |
+	awk -f print_1.awk |
+	sort >observed &&
+
+	test_cmp expected observed
 '
 
 test_expect_success 'verify blob:limit=1m' '
-	git -C r2 ls-files -s large.1000 large.10000 \
-		| awk -f print_2.awk \
-		| sort >expected &&
-	git -C r2 pack-objects --rev --stdout --filter=blob:limit=1m >filter.pack <<-EOF &&
+	git -C r2 ls-files -s large.1000 large.10000 >ls_files_result &&
+	awk -f print_2.awk ls_files_result |
+	sort >expected &&
+
+	git -C r2 pack-objects --revs --stdout --filter=blob:limit=1m >filter.pack <<-EOF &&
 	HEAD
 	EOF
 	git -C r2 index-pack ../filter.pack &&
-	git -C r2 verify-pack -v ../filter.pack \
-		| grep blob \
-		| awk -f print_1.awk \
-		| sort >observed &&
-	test_cmp observed expected
+
+	git -C r2 verify-pack -v ../filter.pack >verify_result &&
+	grep blob verify_result |
+	awk -f print_1.awk |
+	sort >observed &&
+
+	test_cmp expected observed
 '
 
 test_expect_success 'verify normal and blob:limit packfiles have same commits/trees' '
-	git -C r2 verify-pack -v ../all.pack \
-		| grep -E "commit|tree" \
-		| awk -f print_1.awk \
-		| sort >expected &&
-	git -C r2 verify-pack -v ../filter.pack \
-		| grep -E "commit|tree" \
-		| awk -f print_1.awk \
-		| sort >observed &&
-	test_cmp observed expected
+	git -C r2 verify-pack -v ../all.pack >verify_result &&
+	grep -E "commit|tree" verify_result |
+	awk -f print_1.awk |
+	sort >expected &&
+
+	git -C r2 verify-pack -v ../filter.pack >verify_result &&
+	grep -E "commit|tree" verify_result |
+	awk -f print_1.awk |
+	sort >observed &&
+
+	test_cmp expected observed
 '
 
 # Test sparse:path=<path> filter.
+# !!!!
+# NOTE: sparse:path filter support has been dropped for security reasons,
+# so the tests have been changed to make sure that using it fails.
+# !!!!
 # Use a local file containing a sparse-checkout specification to filter
 # out blobs not required for the corresponding sparse-checkout.  We do not
 # require sparse-checkout to actually be enabled.
@@ -209,76 +287,41 @@ test_expect_success 'setup r3' '
 
 test_expect_success 'verify blob count in normal packfile' '
 	git -C r3 ls-files -s sparse1 sparse2 dir1/sparse1 dir1/sparse2 \
-		| awk -f print_2.awk \
-		| sort >expected &&
-	git -C r3 pack-objects --rev --stdout >all.pack <<-EOF &&
+		>ls_files_result &&
+	awk -f print_2.awk ls_files_result |
+	sort >expected &&
+
+	git -C r3 pack-objects --revs --stdout >all.pack <<-EOF &&
 	HEAD
 	EOF
 	git -C r3 index-pack ../all.pack &&
-	git -C r3 verify-pack -v ../all.pack \
-		| grep blob \
-		| awk -f print_1.awk \
-		| sort >observed &&
-	test_cmp observed expected
-'
-
-test_expect_success 'verify sparse:path=pattern1' '
-	git -C r3 ls-files -s dir1/sparse1 dir1/sparse2 \
-		| awk -f print_2.awk \
-		| sort >expected &&
-	git -C r3 pack-objects --rev --stdout --filter=sparse:path=../pattern1 >filter.pack <<-EOF &&
-	HEAD
-	EOF
-	git -C r3 index-pack ../filter.pack &&
-	git -C r3 verify-pack -v ../filter.pack \
-		| grep blob \
-		| awk -f print_1.awk \
-		| sort >observed &&
-	test_cmp observed expected
-'
-
-test_expect_success 'verify normal and sparse:path=pattern1 packfiles have same commits/trees' '
-	git -C r3 verify-pack -v ../all.pack \
-		| grep -E "commit|tree" \
-		| awk -f print_1.awk \
-		| sort >expected &&
-	git -C r3 verify-pack -v ../filter.pack \
-		| grep -E "commit|tree" \
-		| awk -f print_1.awk \
-		| sort >observed &&
-	test_cmp observed expected
-'
-
-test_expect_success 'verify sparse:path=pattern2' '
-	git -C r3 ls-files -s sparse1 dir1/sparse1 \
-		| awk -f print_2.awk \
-		| sort >expected &&
-	git -C r3 pack-objects --rev --stdout --filter=sparse:path=../pattern2 >filter.pack <<-EOF &&
-	HEAD
-	EOF
-	git -C r3 index-pack ../filter.pack &&
-	git -C r3 verify-pack -v ../filter.pack \
-		| grep blob \
-		| awk -f print_1.awk \
-		| sort >observed &&
-	test_cmp observed expected
-'
-
-test_expect_success 'verify normal and sparse:path=pattern2 packfiles have same commits/trees' '
-	git -C r3 verify-pack -v ../all.pack \
-		| grep -E "commit|tree" \
-		| awk -f print_1.awk \
-		| sort >expected &&
-	git -C r3 verify-pack -v ../filter.pack \
-		| grep -E "commit|tree" \
-		| awk -f print_1.awk \
-		| sort >observed &&
-	test_cmp observed expected
+
+	git -C r3 verify-pack -v ../all.pack >verify_result &&
+	grep blob verify_result |
+	awk -f print_1.awk |
+	sort >observed &&
+
+	test_cmp expected observed
+'
+
+test_expect_success 'verify sparse:path=pattern1 fails' '
+	test_must_fail git -C r3 pack-objects --revs --stdout \
+		--filter=sparse:path=../pattern1 <<-EOF
+	HEAD
+	EOF
+'
+
+test_expect_success 'verify sparse:path=pattern2 fails' '
+	test_must_fail git -C r3 pack-objects --revs --stdout \
+		--filter=sparse:path=../pattern2 <<-EOF
+	HEAD
+	EOF
 '
 
 # Test sparse:oid=<oid-ish> filter.
-# Like sparse:path, but we get the sparse-checkout specification from
-# a blob rather than a file on disk.
+# Use a blob containing a sparse-checkout specification to filter
+# out blobs not required for the corresponding sparse-checkout.  We do not
+# require sparse-checkout to actually be enabled.
 
 test_expect_success 'setup r4' '
 	git init r4 &&
@@ -297,48 +340,59 @@ test_expect_success 'setup r4' '
 
 test_expect_success 'verify blob count in normal packfile' '
 	git -C r4 ls-files -s pattern sparse1 sparse2 dir1/sparse1 dir1/sparse2 \
-		| awk -f print_2.awk \
-		| sort >expected &&
-	git -C r4 pack-objects --rev --stdout >all.pack <<-EOF &&
+		>ls_files_result &&
+	awk -f print_2.awk ls_files_result |
+	sort >expected &&
+
+	git -C r4 pack-objects --revs --stdout >all.pack <<-EOF &&
 	HEAD
 	EOF
 	git -C r4 index-pack ../all.pack &&
-	git -C r4 verify-pack -v ../all.pack \
-		| grep blob \
-		| awk -f print_1.awk \
-		| sort >observed &&
-	test_cmp observed expected
+
+	git -C r4 verify-pack -v ../all.pack >verify_result &&
+	grep blob verify_result |
+	awk -f print_1.awk |
+	sort >observed &&
+
+	test_cmp expected observed
 '
 
 test_expect_success 'verify sparse:oid=OID' '
-	git -C r4 ls-files -s dir1/sparse1 dir1/sparse2 \
-		| awk -f print_2.awk \
-		| sort >expected &&
-	oid=$(git -C r4 ls-files -s pattern | awk -f print_2.awk) &&
-	git -C r4 pack-objects --rev --stdout --filter=sparse:oid=$oid >filter.pack <<-EOF &&
+	git -C r4 ls-files -s dir1/sparse1 dir1/sparse2 >ls_files_result &&
+	awk -f print_2.awk ls_files_result |
+	sort >expected &&
+
+	git -C r4 ls-files -s pattern >staged &&
+	oid=$(awk -f print_2.awk staged) &&
+	git -C r4 pack-objects --revs --stdout --filter=sparse:oid=$oid >filter.pack <<-EOF &&
 	HEAD
 	EOF
 	git -C r4 index-pack ../filter.pack &&
-	git -C r4 verify-pack -v ../filter.pack \
-		| grep blob \
-		| awk -f print_1.awk \
-		| sort >observed &&
-	test_cmp observed expected
+
+	git -C r4 verify-pack -v ../filter.pack >verify_result &&
+	grep blob verify_result |
+	awk -f print_1.awk |
+	sort >observed &&
+
+	test_cmp expected observed
 '
 
 test_expect_success 'verify sparse:oid=oid-ish' '
-	git -C r4 ls-files -s dir1/sparse1 dir1/sparse2 \
-		| awk -f print_2.awk \
-		| sort >expected &&
-	git -C r4 pack-objects --rev --stdout --filter=sparse:oid=master:pattern >filter.pack <<-EOF &&
+	git -C r4 ls-files -s dir1/sparse1 dir1/sparse2 >ls_files_result &&
+	awk -f print_2.awk ls_files_result |
+	sort >expected &&
+
+	git -C r4 pack-objects --revs --stdout --filter=sparse:oid=master:pattern >filter.pack <<-EOF &&
 	HEAD
 	EOF
 	git -C r4 index-pack ../filter.pack &&
-	git -C r4 verify-pack -v ../filter.pack \
-		| grep blob \
-		| awk -f print_1.awk \
-		| sort >observed &&
-	test_cmp observed expected
+
+	git -C r4 verify-pack -v ../filter.pack >verify_result &&
+	grep blob verify_result |
+	awk -f print_1.awk |
+	sort >observed &&
+
+	test_cmp expected observed
 '
 
 # Delete some loose objects and use pack-objects, but WITHOUT any filtering.
@@ -346,8 +400,10 @@ test_expect_success 'verify sparse:oid=o
 
 test_expect_success 'setup r1 - delete loose blobs' '
 	git -C r1 ls-files -s file.1 file.2 file.3 file.4 file.5 \
-		| awk -f print_2.awk \
-		| sort >expected &&
+		>ls_files_result &&
+	awk -f print_2.awk ls_files_result |
+	sort >expected &&
+
 	for id in `cat expected | sed "s|..|&/|"`
 	do
 		rm r1/.git/objects/$id
@@ -355,19 +411,19 @@ test_expect_success 'setup r1 - delete l
 '
 
 test_expect_success 'verify pack-objects fails w/ missing objects' '
-	test_must_fail git -C r1 pack-objects --rev --stdout >miss.pack <<-EOF
+	test_must_fail git -C r1 pack-objects --revs --stdout >miss.pack <<-EOF
 	HEAD
 	EOF
 '
 
 test_expect_success 'verify pack-objects fails w/ --missing=error' '
-	test_must_fail git -C r1 pack-objects --rev --stdout --missing=error >miss.pack <<-EOF
+	test_must_fail git -C r1 pack-objects --revs --stdout --missing=error >miss.pack <<-EOF
 	HEAD
 	EOF
 '
 
 test_expect_success 'verify pack-objects w/ --missing=allow-any' '
-	git -C r1 pack-objects --rev --stdout --missing=allow-any >miss.pack <<-EOF
+	git -C r1 pack-objects --revs --stdout --missing=allow-any >miss.pack <<-EOF
 	HEAD
 	EOF
 '
diff -pruN 1.2.1+git2.18.0-1/git/t/t5318-commit-graph.sh 1.2.3+git2.25.1-1/git/t/t5318-commit-graph.sh
--- 1.2.1+git2.18.0-1/git/t/t5318-commit-graph.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t5318-commit-graph.sh	2020-02-17 04:47:35.000000000 +0000
@@ -8,13 +8,26 @@ test_expect_success 'setup full repo' '
 	cd "$TRASH_DIRECTORY/full" &&
 	git init &&
 	git config core.commitGraph true &&
-	objdir=".git/objects"
+	objdir=".git/objects" &&
+	test_oid_init
+'
+
+test_expect_success 'verify graph with no graph file' '
+	cd "$TRASH_DIRECTORY/full" &&
+	git commit-graph verify
 '
 
 test_expect_success 'write graph with no packs' '
 	cd "$TRASH_DIRECTORY/full" &&
 	git commit-graph write --object-dir . &&
-	test_path_is_file info/commit-graph
+	test_path_is_missing info/commit-graph
+'
+
+test_expect_success 'exit with correct error on bad input to --stdin-packs' '
+	cd "$TRASH_DIRECTORY/full" &&
+	echo doesnotexist >in &&
+	test_expect_code 1 git commit-graph write --stdin-packs <in 2>stderr &&
+	test_i18ngrep "error adding pack" stderr
 '
 
 test_expect_success 'create commits and repack' '
@@ -27,10 +40,19 @@ test_expect_success 'create commits and
 	git repack
 '
 
+test_expect_success 'exit with correct error on bad input to --stdin-commits' '
+	cd "$TRASH_DIRECTORY/full" &&
+	echo HEAD | test_expect_code 1 git commit-graph write --stdin-commits 2>stderr &&
+	test_i18ngrep "invalid commit object id" stderr &&
+	# valid tree OID, but not a commit OID
+	git rev-parse HEAD^{tree} | test_expect_code 1 git commit-graph write --stdin-commits 2>stderr &&
+	test_i18ngrep "invalid commit object id" stderr
+'
+
 graph_git_two_modes() {
-	git -c core.graph=true $1 >output
-	git -c core.graph=false $1 >expect
-	test_cmp output expect
+	git -c core.commitGraph=true $1 >output
+	git -c core.commitGraph=false $1 >expect
+	test_cmp expect output
 }
 
 graph_git_behavior() {
@@ -63,13 +85,13 @@ graph_read_expect() {
 	num_commits: $1
 	chunks: oid_fanout oid_lookup commit_metadata$OPTIONAL
 	EOF
-	git commit-graph read >output &&
+	test-tool read-graph >output &&
 	test_cmp expect output
 }
 
 test_expect_success 'write graph' '
 	cd "$TRASH_DIRECTORY/full" &&
-	graph1=$(git commit-graph write) &&
+	git commit-graph write &&
 	test_path_is_file $objdir/info/commit-graph &&
 	graph_read_expect "3"
 '
@@ -102,6 +124,42 @@ test_expect_success 'Add more commits' '
 	git repack
 '
 
+test_expect_success 'commit-graph write progress off for redirected stderr' '
+	cd "$TRASH_DIRECTORY/full" &&
+	git commit-graph write 2>err &&
+	test_line_count = 0 err
+'
+
+test_expect_success 'commit-graph write force progress on for stderr' '
+	cd "$TRASH_DIRECTORY/full" &&
+	GIT_PROGRESS_DELAY=0 git commit-graph write --progress 2>err &&
+	test_file_not_empty err
+'
+
+test_expect_success 'commit-graph write with the --no-progress option' '
+	cd "$TRASH_DIRECTORY/full" &&
+	git commit-graph write --no-progress 2>err &&
+	test_line_count = 0 err
+'
+
+test_expect_success 'commit-graph verify progress off for redirected stderr' '
+	cd "$TRASH_DIRECTORY/full" &&
+	git commit-graph verify 2>err &&
+	test_line_count = 0 err
+'
+
+test_expect_success 'commit-graph verify force progress on for stderr' '
+	cd "$TRASH_DIRECTORY/full" &&
+	GIT_PROGRESS_DELAY=0 git commit-graph verify --progress 2>err &&
+	test_file_not_empty err
+'
+
+test_expect_success 'commit-graph verify with the --no-progress option' '
+	cd "$TRASH_DIRECTORY/full" &&
+	git commit-graph verify --no-progress 2>err &&
+	test_line_count = 0 err
+'
+
 # Current graph structure:
 #
 #   __M3___
@@ -116,7 +174,7 @@ test_expect_success 'write graph with me
 	cd "$TRASH_DIRECTORY/full" &&
 	git commit-graph write &&
 	test_path_is_file $objdir/info/commit-graph &&
-	graph_read_expect "10" "large_edges"
+	graph_read_expect "10" "extra_edges"
 '
 
 graph_git_behavior 'merge 1 vs 2' full merge/1 merge/2
@@ -129,7 +187,7 @@ test_expect_success 'Add one more commit
 	git branch commits/8 &&
 	ls $objdir/pack | grep idx >existing-idx &&
 	git repack &&
-	ls $objdir/pack| grep idx | grep -v --file=existing-idx >new-idx
+	ls $objdir/pack| grep idx | grep -v -f existing-idx >new-idx
 '
 
 # Current graph structure:
@@ -151,7 +209,7 @@ test_expect_success 'write graph with ne
 	cd "$TRASH_DIRECTORY/full" &&
 	git commit-graph write &&
 	test_path_is_file $objdir/info/commit-graph &&
-	graph_read_expect "11" "large_edges"
+	graph_read_expect "11" "extra_edges"
 '
 
 graph_git_behavior 'full graph, commit 8 vs merge 1' full commits/8 merge/1
@@ -161,7 +219,7 @@ test_expect_success 'write graph with no
 	cd "$TRASH_DIRECTORY/full" &&
 	git commit-graph write &&
 	test_path_is_file $objdir/info/commit-graph &&
-	graph_read_expect "11" "large_edges"
+	graph_read_expect "11" "extra_edges"
 '
 
 graph_git_behavior 'cleared graph, commit 8 vs merge 1' full commits/8 merge/1
@@ -171,7 +229,7 @@ test_expect_success 'build graph from la
 	cd "$TRASH_DIRECTORY/full" &&
 	cat new-idx | git commit-graph write --stdin-packs &&
 	test_path_is_file $objdir/info/commit-graph &&
-	graph_read_expect "9" "large_edges"
+	graph_read_expect "9" "extra_edges"
 '
 
 graph_git_behavior 'graph from pack, commit 8 vs merge 1' full commits/8 merge/1
@@ -194,7 +252,17 @@ test_expect_success 'build graph from co
 	cd "$TRASH_DIRECTORY/full" &&
 	git rev-parse merge/3 | git commit-graph write --stdin-commits --append &&
 	test_path_is_file $objdir/info/commit-graph &&
-	graph_read_expect "10" "large_edges"
+	graph_read_expect "10" "extra_edges"
+'
+
+graph_git_behavior 'append graph, commit 8 vs merge 1' full commits/8 merge/1
+graph_git_behavior 'append graph, commit 8 vs merge 2' full commits/8 merge/2
+
+test_expect_success 'build graph using --reachable' '
+	cd "$TRASH_DIRECTORY/full" &&
+	git commit-graph write --reachable &&
+	test_path_is_file $objdir/info/commit-graph &&
+	graph_read_expect "11" "extra_edges"
 '
 
 graph_git_behavior 'append graph, commit 8 vs merge 1' full commits/8 merge/1
@@ -215,10 +283,385 @@ test_expect_success 'write graph in bare
 	cd "$TRASH_DIRECTORY/bare" &&
 	git commit-graph write &&
 	test_path_is_file $baredir/info/commit-graph &&
-	graph_read_expect "11" "large_edges"
+	graph_read_expect "11" "extra_edges"
 '
 
 graph_git_behavior 'bare repo with graph, commit 8 vs merge 1' bare commits/8 merge/1
 graph_git_behavior 'bare repo with graph, commit 8 vs merge 2' bare commits/8 merge/2
 
+test_expect_success 'perform fast-forward merge in full repo' '
+	cd "$TRASH_DIRECTORY/full" &&
+	git checkout -b merge-5-to-8 commits/5 &&
+	git merge commits/8 &&
+	git show-ref -s merge-5-to-8 >output &&
+	git show-ref -s commits/8 >expect &&
+	test_cmp expect output
+'
+
+test_expect_success 'check that gc computes commit-graph' '
+	cd "$TRASH_DIRECTORY/full" &&
+	git commit --allow-empty -m "blank" &&
+	git commit-graph write --reachable &&
+	cp $objdir/info/commit-graph commit-graph-before-gc &&
+	git reset --hard HEAD~1 &&
+	git config gc.writeCommitGraph true &&
+	git gc &&
+	cp $objdir/info/commit-graph commit-graph-after-gc &&
+	! test_cmp_bin commit-graph-before-gc commit-graph-after-gc &&
+	git commit-graph write --reachable &&
+	test_cmp_bin commit-graph-after-gc $objdir/info/commit-graph
+'
+
+test_expect_success 'replace-objects invalidates commit-graph' '
+	cd "$TRASH_DIRECTORY" &&
+	test_when_finished rm -rf replace &&
+	git clone full replace &&
+	(
+		cd replace &&
+		git commit-graph write --reachable &&
+		test_path_is_file .git/objects/info/commit-graph &&
+		git replace HEAD~1 HEAD~2 &&
+		git -c core.commitGraph=false log >expect &&
+		git -c core.commitGraph=true log >actual &&
+		test_cmp expect actual &&
+		git commit-graph write --reachable &&
+		git -c core.commitGraph=false --no-replace-objects log >expect &&
+		git -c core.commitGraph=true --no-replace-objects log >actual &&
+		test_cmp expect actual &&
+		rm -rf .git/objects/info/commit-graph &&
+		git commit-graph write --reachable &&
+		test_path_is_file .git/objects/info/commit-graph
+	)
+'
+
+test_expect_success 'commit grafts invalidate commit-graph' '
+	cd "$TRASH_DIRECTORY" &&
+	test_when_finished rm -rf graft &&
+	git clone full graft &&
+	(
+		cd graft &&
+		git commit-graph write --reachable &&
+		test_path_is_file .git/objects/info/commit-graph &&
+		H1=$(git rev-parse --verify HEAD~1) &&
+		H3=$(git rev-parse --verify HEAD~3) &&
+		echo "$H1 $H3" >.git/info/grafts &&
+		git -c core.commitGraph=false log >expect &&
+		git -c core.commitGraph=true log >actual &&
+		test_cmp expect actual &&
+		git commit-graph write --reachable &&
+		git -c core.commitGraph=false --no-replace-objects log >expect &&
+		git -c core.commitGraph=true --no-replace-objects log >actual &&
+		test_cmp expect actual &&
+		rm -rf .git/objects/info/commit-graph &&
+		git commit-graph write --reachable &&
+		test_path_is_missing .git/objects/info/commit-graph
+	)
+'
+
+test_expect_success 'replace-objects invalidates commit-graph' '
+	cd "$TRASH_DIRECTORY" &&
+	test_when_finished rm -rf shallow &&
+	git clone --depth 2 "file://$TRASH_DIRECTORY/full" shallow &&
+	(
+		cd shallow &&
+		git commit-graph write --reachable &&
+		test_path_is_missing .git/objects/info/commit-graph &&
+		git fetch origin --unshallow &&
+		git commit-graph write --reachable &&
+		test_path_is_file .git/objects/info/commit-graph
+	)
+'
+
+# the verify tests below expect the commit-graph to contain
+# exactly the commits reachable from the commits/8 branch.
+# If the file changes the set of commits in the list, then the
+# offsets into the binary file will result in different edits
+# and the tests will likely break.
+
+test_expect_success 'git commit-graph verify' '
+	cd "$TRASH_DIRECTORY/full" &&
+	git rev-parse commits/8 | git commit-graph write --stdin-commits &&
+	git commit-graph verify >output
+'
+
+NUM_COMMITS=9
+NUM_OCTOPUS_EDGES=2
+HASH_LEN="$(test_oid rawsz)"
+GRAPH_BYTE_VERSION=4
+GRAPH_BYTE_HASH=5
+GRAPH_BYTE_CHUNK_COUNT=6
+GRAPH_CHUNK_LOOKUP_OFFSET=8
+GRAPH_CHUNK_LOOKUP_WIDTH=12
+GRAPH_CHUNK_LOOKUP_ROWS=5
+GRAPH_BYTE_OID_FANOUT_ID=$GRAPH_CHUNK_LOOKUP_OFFSET
+GRAPH_BYTE_OID_LOOKUP_ID=$(($GRAPH_CHUNK_LOOKUP_OFFSET + \
+			    1 * $GRAPH_CHUNK_LOOKUP_WIDTH))
+GRAPH_BYTE_COMMIT_DATA_ID=$(($GRAPH_CHUNK_LOOKUP_OFFSET + \
+			     2 * $GRAPH_CHUNK_LOOKUP_WIDTH))
+GRAPH_FANOUT_OFFSET=$(($GRAPH_CHUNK_LOOKUP_OFFSET + \
+		       $GRAPH_CHUNK_LOOKUP_WIDTH * $GRAPH_CHUNK_LOOKUP_ROWS))
+GRAPH_BYTE_FANOUT1=$(($GRAPH_FANOUT_OFFSET + 4 * 4))
+GRAPH_BYTE_FANOUT2=$(($GRAPH_FANOUT_OFFSET + 4 * 255))
+GRAPH_OID_LOOKUP_OFFSET=$(($GRAPH_FANOUT_OFFSET + 4 * 256))
+GRAPH_BYTE_OID_LOOKUP_ORDER=$(($GRAPH_OID_LOOKUP_OFFSET + $HASH_LEN * 8))
+GRAPH_BYTE_OID_LOOKUP_MISSING=$(($GRAPH_OID_LOOKUP_OFFSET + $HASH_LEN * 4 + 10))
+GRAPH_COMMIT_DATA_OFFSET=$(($GRAPH_OID_LOOKUP_OFFSET + $HASH_LEN * $NUM_COMMITS))
+GRAPH_BYTE_COMMIT_TREE=$GRAPH_COMMIT_DATA_OFFSET
+GRAPH_BYTE_COMMIT_PARENT=$(($GRAPH_COMMIT_DATA_OFFSET + $HASH_LEN))
+GRAPH_BYTE_COMMIT_EXTRA_PARENT=$(($GRAPH_COMMIT_DATA_OFFSET + $HASH_LEN + 4))
+GRAPH_BYTE_COMMIT_WRONG_PARENT=$(($GRAPH_COMMIT_DATA_OFFSET + $HASH_LEN + 3))
+GRAPH_BYTE_COMMIT_GENERATION=$(($GRAPH_COMMIT_DATA_OFFSET + $HASH_LEN + 11))
+GRAPH_BYTE_COMMIT_DATE=$(($GRAPH_COMMIT_DATA_OFFSET + $HASH_LEN + 12))
+GRAPH_COMMIT_DATA_WIDTH=$(($HASH_LEN + 16))
+GRAPH_OCTOPUS_DATA_OFFSET=$(($GRAPH_COMMIT_DATA_OFFSET + \
+			     $GRAPH_COMMIT_DATA_WIDTH * $NUM_COMMITS))
+GRAPH_BYTE_OCTOPUS=$(($GRAPH_OCTOPUS_DATA_OFFSET + 4))
+GRAPH_BYTE_FOOTER=$(($GRAPH_OCTOPUS_DATA_OFFSET + 4 * $NUM_OCTOPUS_EDGES))
+
+corrupt_graph_setup() {
+	cd "$TRASH_DIRECTORY/full" &&
+	test_when_finished mv commit-graph-backup $objdir/info/commit-graph &&
+	cp $objdir/info/commit-graph commit-graph-backup
+}
+
+corrupt_graph_verify() {
+	grepstr=$1
+	test_must_fail git commit-graph verify 2>test_err &&
+	grep -v "^+" test_err >err &&
+	test_i18ngrep "$grepstr" err &&
+	if test "$2" != "no-copy"
+	then
+		cp $objdir/info/commit-graph commit-graph-pre-write-test
+	fi &&
+	git status --short &&
+	GIT_TEST_COMMIT_GRAPH_DIE_ON_LOAD=true git commit-graph write &&
+	git commit-graph verify
+}
+
+# usage: corrupt_graph_and_verify <position> <data> <string> [<zero_pos>]
+# Manipulates the commit-graph file at the position
+# by inserting the data, optionally zeroing the file
+# starting at <zero_pos>, then runs 'git commit-graph verify'
+# and places the output in the file 'err'. Test 'err' for
+# the given string.
+corrupt_graph_and_verify() {
+	pos=$1
+	data="${2:-\0}"
+	grepstr=$3
+	corrupt_graph_setup &&
+	orig_size=$(wc -c < $objdir/info/commit-graph) &&
+	zero_pos=${4:-${orig_size}} &&
+	printf "$data" | dd of="$objdir/info/commit-graph" bs=1 seek="$pos" conv=notrunc &&
+	dd of="$objdir/info/commit-graph" bs=1 seek="$zero_pos" if=/dev/null &&
+	generate_zero_bytes $(($orig_size - $zero_pos)) >>"$objdir/info/commit-graph" &&
+	corrupt_graph_verify "$grepstr"
+
+}
+
+test_expect_success POSIXPERM,SANITY 'detect permission problem' '
+	corrupt_graph_setup &&
+	chmod 000 $objdir/info/commit-graph &&
+	corrupt_graph_verify "Could not open" "no-copy"
+'
+
+test_expect_success 'detect too small' '
+	corrupt_graph_setup &&
+	echo "a small graph" >$objdir/info/commit-graph &&
+	corrupt_graph_verify "too small"
+'
+
+test_expect_success 'detect bad signature' '
+	corrupt_graph_and_verify 0 "\0" \
+		"graph signature"
+'
+
+test_expect_success 'detect bad version' '
+	corrupt_graph_and_verify $GRAPH_BYTE_VERSION "\02" \
+		"graph version"
+'
+
+test_expect_success 'detect bad hash version' '
+	corrupt_graph_and_verify $GRAPH_BYTE_HASH "\02" \
+		"hash version"
+'
+
+test_expect_success 'detect low chunk count' '
+	corrupt_graph_and_verify $GRAPH_BYTE_CHUNK_COUNT "\02" \
+		"missing the .* chunk"
+'
+
+test_expect_success 'detect missing OID fanout chunk' '
+	corrupt_graph_and_verify $GRAPH_BYTE_OID_FANOUT_ID "\0" \
+		"missing the OID Fanout chunk"
+'
+
+test_expect_success 'detect missing OID lookup chunk' '
+	corrupt_graph_and_verify $GRAPH_BYTE_OID_LOOKUP_ID "\0" \
+		"missing the OID Lookup chunk"
+'
+
+test_expect_success 'detect missing commit data chunk' '
+	corrupt_graph_and_verify $GRAPH_BYTE_COMMIT_DATA_ID "\0" \
+		"missing the Commit Data chunk"
+'
+
+test_expect_success 'detect incorrect fanout' '
+	corrupt_graph_and_verify $GRAPH_BYTE_FANOUT1 "\01" \
+		"fanout value"
+'
+
+test_expect_success 'detect incorrect fanout final value' '
+	corrupt_graph_and_verify $GRAPH_BYTE_FANOUT2 "\01" \
+		"fanout value"
+'
+
+test_expect_success 'detect incorrect OID order' '
+	corrupt_graph_and_verify $GRAPH_BYTE_OID_LOOKUP_ORDER "\01" \
+		"incorrect OID order"
+'
+
+test_expect_success 'detect OID not in object database' '
+	corrupt_graph_and_verify $GRAPH_BYTE_OID_LOOKUP_MISSING "\01" \
+		"from object database"
+'
+
+test_expect_success 'detect incorrect tree OID' '
+	corrupt_graph_and_verify $GRAPH_BYTE_COMMIT_TREE "\01" \
+		"root tree OID for commit"
+'
+
+test_expect_success 'detect incorrect parent int-id' '
+	corrupt_graph_and_verify $GRAPH_BYTE_COMMIT_PARENT "\01" \
+		"invalid parent"
+'
+
+test_expect_success 'detect extra parent int-id' '
+	corrupt_graph_and_verify $GRAPH_BYTE_COMMIT_EXTRA_PARENT "\00" \
+		"is too long"
+'
+
+test_expect_success 'detect wrong parent' '
+	corrupt_graph_and_verify $GRAPH_BYTE_COMMIT_WRONG_PARENT "\01" \
+		"commit-graph parent for"
+'
+
+test_expect_success 'detect incorrect generation number' '
+	corrupt_graph_and_verify $GRAPH_BYTE_COMMIT_GENERATION "\070" \
+		"generation for commit"
+'
+
+test_expect_success 'detect incorrect generation number' '
+	corrupt_graph_and_verify $GRAPH_BYTE_COMMIT_GENERATION "\01" \
+		"non-zero generation number"
+'
+
+test_expect_success 'detect incorrect commit date' '
+	corrupt_graph_and_verify $GRAPH_BYTE_COMMIT_DATE "\01" \
+		"commit date"
+'
+
+test_expect_success 'detect incorrect parent for octopus merge' '
+	corrupt_graph_and_verify $GRAPH_BYTE_OCTOPUS "\01" \
+		"invalid parent"
+'
+
+test_expect_success 'detect invalid checksum hash' '
+	corrupt_graph_and_verify $GRAPH_BYTE_FOOTER "\00" \
+		"incorrect checksum"
+'
+
+test_expect_success 'detect incorrect chunk count' '
+	corrupt_graph_and_verify $GRAPH_BYTE_CHUNK_COUNT "\377" \
+		"chunk lookup table entry missing" $GRAPH_CHUNK_LOOKUP_OFFSET
+'
+
+test_expect_success 'git fsck (checks commit-graph)' '
+	cd "$TRASH_DIRECTORY/full" &&
+	git fsck &&
+	corrupt_graph_and_verify $GRAPH_BYTE_FOOTER "\00" \
+		"incorrect checksum" &&
+	cp commit-graph-pre-write-test $objdir/info/commit-graph &&
+	test_must_fail git fsck
+'
+
+test_expect_success 'setup non-the_repository tests' '
+	rm -rf repo &&
+	git init repo &&
+	test_commit -C repo one &&
+	test_commit -C repo two &&
+	git -C repo config core.commitGraph true &&
+	git -C repo rev-parse two | \
+		git -C repo commit-graph write --stdin-commits
+'
+
+test_expect_success 'parse_commit_in_graph works for non-the_repository' '
+	test-tool repository parse_commit_in_graph \
+		repo/.git repo "$(git -C repo rev-parse two)" >actual &&
+	{
+		git -C repo log --pretty=format:"%ct " -1 &&
+		git -C repo rev-parse one
+	} >expect &&
+	test_cmp expect actual &&
+
+	test-tool repository parse_commit_in_graph \
+		repo/.git repo "$(git -C repo rev-parse one)" >actual &&
+	git -C repo log --pretty="%ct" -1 one >expect &&
+	test_cmp expect actual
+'
+
+test_expect_success 'get_commit_tree_in_graph works for non-the_repository' '
+	test-tool repository get_commit_tree_in_graph \
+		repo/.git repo "$(git -C repo rev-parse two)" >actual &&
+	git -C repo rev-parse two^{tree} >expect &&
+	test_cmp expect actual &&
+
+	test-tool repository get_commit_tree_in_graph \
+		repo/.git repo "$(git -C repo rev-parse one)" >actual &&
+	git -C repo rev-parse one^{tree} >expect &&
+	test_cmp expect actual
+'
+
+test_expect_success 'corrupt commit-graph write (broken parent)' '
+	rm -rf repo &&
+	git init repo &&
+	(
+		cd repo &&
+		empty="$(git mktree </dev/null)" &&
+		cat >broken <<-EOF &&
+		tree $empty
+		parent 0000000000000000000000000000000000000000
+		author whatever <whatever@example.com> 1234 -0000
+		committer whatever <whatever@example.com> 1234 -0000
+
+		broken commit
+		EOF
+		broken="$(git hash-object -w -t commit --literally broken)" &&
+		git commit-tree -p "$broken" -m "good commit" "$empty" >good &&
+		test_must_fail git commit-graph write --stdin-commits \
+			<good 2>test_err &&
+		test_i18ngrep "unable to parse commit" test_err
+	)
+'
+
+test_expect_success 'corrupt commit-graph write (missing tree)' '
+	rm -rf repo &&
+	git init repo &&
+	(
+		cd repo &&
+		tree="$(git mktree </dev/null)" &&
+		cat >broken <<-EOF &&
+		parent 0000000000000000000000000000000000000000
+		author whatever <whatever@example.com> 1234 -0000
+		committer whatever <whatever@example.com> 1234 -0000
+
+		broken commit
+		EOF
+		broken="$(git hash-object -w -t commit --literally broken)" &&
+		git commit-tree -p "$broken" -m "good" "$tree" >good &&
+		test_must_fail git commit-graph write --stdin-commits \
+			<good 2>test_err &&
+		test_i18ngrep "unable to parse commit" test_err
+	)
+'
+
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t5319-multi-pack-index.sh 1.2.3+git2.25.1-1/git/t/t5319-multi-pack-index.sh
--- 1.2.1+git2.18.0-1/git/t/t5319-multi-pack-index.sh	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t5319-multi-pack-index.sh	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,619 @@
+#!/bin/sh
+
+test_description='multi-pack-indexes'
+. ./test-lib.sh
+
+objdir=.git/objects
+
+midx_read_expect () {
+	NUM_PACKS=$1
+	NUM_OBJECTS=$2
+	NUM_CHUNKS=$3
+	OBJECT_DIR=$4
+	EXTRA_CHUNKS="$5"
+	{
+		cat <<-EOF &&
+		header: 4d494458 1 $NUM_CHUNKS $NUM_PACKS
+		chunks: pack-names oid-fanout oid-lookup object-offsets$EXTRA_CHUNKS
+		num_objects: $NUM_OBJECTS
+		packs:
+		EOF
+		if test $NUM_PACKS -ge 1
+		then
+			ls $OBJECT_DIR/pack/ | grep idx | sort
+		fi &&
+		printf "object-dir: $OBJECT_DIR\n"
+	} >expect &&
+	test-tool read-midx $OBJECT_DIR >actual &&
+	test_cmp expect actual
+}
+
+test_expect_success 'write midx with no packs' '
+	test_when_finished rm -f pack/multi-pack-index &&
+	git multi-pack-index --object-dir=. write &&
+	midx_read_expect 0 0 4 .
+'
+
+generate_objects () {
+	i=$1
+	iii=$(printf '%03i' $i)
+	{
+		test-tool genrandom "bar" 200 &&
+		test-tool genrandom "baz $iii" 50
+	} >wide_delta_$iii &&
+	{
+		test-tool genrandom "foo"$i 100 &&
+		test-tool genrandom "foo"$(( $i + 1 )) 100 &&
+		test-tool genrandom "foo"$(( $i + 2 )) 100
+	} >deep_delta_$iii &&
+	{
+		echo $iii &&
+		test-tool genrandom "$iii" 8192
+	} >file_$iii &&
+	git update-index --add file_$iii deep_delta_$iii wide_delta_$iii
+}
+
+commit_and_list_objects () {
+	{
+		echo 101 &&
+		test-tool genrandom 100 8192;
+	} >file_101 &&
+	git update-index --add file_101 &&
+	tree=$(git write-tree) &&
+	commit=$(git commit-tree $tree -p HEAD</dev/null) &&
+	{
+		echo $tree &&
+		git ls-tree $tree | sed -e "s/.* \\([0-9a-f]*\\)	.*/\\1/"
+	} >obj-list &&
+	git reset --hard $commit
+}
+
+test_expect_success 'create objects' '
+	test_commit initial &&
+	for i in $(test_seq 1 5)
+	do
+		generate_objects $i
+	done &&
+	commit_and_list_objects
+'
+
+test_expect_success 'write midx with one v1 pack' '
+	pack=$(git pack-objects --index-version=1 $objdir/pack/test <obj-list) &&
+	test_when_finished rm $objdir/pack/test-$pack.pack \
+		$objdir/pack/test-$pack.idx $objdir/pack/multi-pack-index &&
+	git multi-pack-index --object-dir=$objdir write &&
+	midx_read_expect 1 18 4 $objdir
+'
+
+midx_git_two_modes () {
+	git -c core.multiPackIndex=false $1 >expect &&
+	git -c core.multiPackIndex=true $1 >actual &&
+	if [ "$2" = "sorted" ]
+	then
+		sort <expect >expect.sorted &&
+		mv expect.sorted expect &&
+		sort <actual >actual.sorted &&
+		mv actual.sorted actual
+	fi &&
+	test_cmp expect actual
+}
+
+compare_results_with_midx () {
+	MSG=$1
+	test_expect_success "check normal git operations: $MSG" '
+		midx_git_two_modes "rev-list --objects --all" &&
+		midx_git_two_modes "log --raw" &&
+		midx_git_two_modes "count-objects --verbose" &&
+		midx_git_two_modes "cat-file --batch-all-objects --batch-check" &&
+		midx_git_two_modes "cat-file --batch-all-objects --batch-check --unordered" sorted
+	'
+}
+
+test_expect_success 'write midx with one v2 pack' '
+	git pack-objects --index-version=2,0x40 $objdir/pack/test <obj-list &&
+	git multi-pack-index --object-dir=$objdir write &&
+	midx_read_expect 1 18 4 $objdir
+'
+
+compare_results_with_midx "one v2 pack"
+
+test_expect_success 'corrupt idx not opened' '
+	idx=$(test-tool read-midx $objdir | grep "\.idx\$") &&
+	mv $objdir/pack/$idx backup-$idx &&
+	test_when_finished "mv backup-\$idx \$objdir/pack/\$idx" &&
+
+	# This is the minimum size for a sha-1 based .idx; this lets
+	# us pass perfunctory tests, but anything that actually opens and reads
+	# the idx file will complain.
+	test_copy_bytes 1064 <backup-$idx >$objdir/pack/$idx &&
+
+	git -c core.multiPackIndex=true rev-list --objects --all 2>err &&
+	test_must_be_empty err
+'
+
+test_expect_success 'add more objects' '
+	for i in $(test_seq 6 10)
+	do
+		generate_objects $i
+	done &&
+	commit_and_list_objects
+'
+
+test_expect_success 'write midx with two packs' '
+	git pack-objects --index-version=1 $objdir/pack/test-2 <obj-list &&
+	git multi-pack-index --object-dir=$objdir write &&
+	midx_read_expect 2 34 4 $objdir
+'
+
+compare_results_with_midx "two packs"
+
+test_expect_success 'write progress off for redirected stderr' '
+	git multi-pack-index --object-dir=$objdir write 2>err &&
+	test_line_count = 0 err
+'
+
+test_expect_success 'write force progress on for stderr' '
+	git multi-pack-index --object-dir=$objdir --progress write 2>err &&
+	test_file_not_empty err
+'
+
+test_expect_success 'write with the --no-progress option' '
+	git multi-pack-index --object-dir=$objdir --no-progress write 2>err &&
+	test_line_count = 0 err
+'
+
+test_expect_success 'add more packs' '
+	for j in $(test_seq 11 20)
+	do
+		generate_objects $j &&
+		commit_and_list_objects &&
+		git pack-objects --index-version=2 $objdir/pack/test-pack <obj-list
+	done
+'
+
+compare_results_with_midx "mixed mode (two packs + extra)"
+
+test_expect_success 'write midx with twelve packs' '
+	git multi-pack-index --object-dir=$objdir write &&
+	midx_read_expect 12 74 4 $objdir
+'
+
+compare_results_with_midx "twelve packs"
+
+test_expect_success 'verify multi-pack-index success' '
+	git multi-pack-index verify --object-dir=$objdir
+'
+
+test_expect_success 'verify progress off for redirected stderr' '
+	git multi-pack-index verify --object-dir=$objdir 2>err &&
+	test_line_count = 0 err
+'
+
+test_expect_success 'verify force progress on for stderr' '
+	git multi-pack-index verify --object-dir=$objdir --progress 2>err &&
+	test_file_not_empty err
+'
+
+test_expect_success 'verify with the --no-progress option' '
+	git multi-pack-index verify --object-dir=$objdir --no-progress 2>err &&
+	test_line_count = 0 err
+'
+
+# usage: corrupt_midx_and_verify <pos> <data> <objdir> <string>
+corrupt_midx_and_verify() {
+	POS=$1 &&
+	DATA="${2:-\0}" &&
+	OBJDIR=$3 &&
+	GREPSTR="$4" &&
+	COMMAND="$5" &&
+	if test -z "$COMMAND"
+	then
+		COMMAND="git multi-pack-index verify --object-dir=$OBJDIR"
+	fi &&
+	FILE=$OBJDIR/pack/multi-pack-index &&
+	chmod a+w $FILE &&
+	test_when_finished mv midx-backup $FILE &&
+	cp $FILE midx-backup &&
+	printf "$DATA" | dd of="$FILE" bs=1 seek="$POS" conv=notrunc &&
+	test_must_fail $COMMAND 2>test_err &&
+	grep -v "^+" test_err >err &&
+	test_i18ngrep "$GREPSTR" err
+}
+
+test_expect_success 'verify bad signature' '
+	corrupt_midx_and_verify 0 "\00" $objdir \
+		"multi-pack-index signature"
+'
+
+HASH_LEN=20
+NUM_OBJECTS=74
+MIDX_BYTE_VERSION=4
+MIDX_BYTE_OID_VERSION=5
+MIDX_BYTE_CHUNK_COUNT=6
+MIDX_HEADER_SIZE=12
+MIDX_BYTE_CHUNK_ID=$MIDX_HEADER_SIZE
+MIDX_BYTE_CHUNK_OFFSET=$(($MIDX_HEADER_SIZE + 4))
+MIDX_NUM_CHUNKS=5
+MIDX_CHUNK_LOOKUP_WIDTH=12
+MIDX_OFFSET_PACKNAMES=$(($MIDX_HEADER_SIZE + \
+			 $MIDX_NUM_CHUNKS * $MIDX_CHUNK_LOOKUP_WIDTH))
+MIDX_BYTE_PACKNAME_ORDER=$(($MIDX_OFFSET_PACKNAMES + 2))
+MIDX_OFFSET_OID_FANOUT=$(($MIDX_OFFSET_PACKNAMES + 652))
+MIDX_OID_FANOUT_WIDTH=4
+MIDX_BYTE_OID_FANOUT_ORDER=$((MIDX_OFFSET_OID_FANOUT + 250 * $MIDX_OID_FANOUT_WIDTH + 1))
+MIDX_OFFSET_OID_LOOKUP=$(($MIDX_OFFSET_OID_FANOUT + 256 * $MIDX_OID_FANOUT_WIDTH))
+MIDX_BYTE_OID_LOOKUP=$(($MIDX_OFFSET_OID_LOOKUP + 16 * $HASH_LEN))
+MIDX_OFFSET_OBJECT_OFFSETS=$(($MIDX_OFFSET_OID_LOOKUP + $NUM_OBJECTS * $HASH_LEN))
+MIDX_OFFSET_WIDTH=8
+MIDX_BYTE_PACK_INT_ID=$(($MIDX_OFFSET_OBJECT_OFFSETS + 16 * $MIDX_OFFSET_WIDTH + 2))
+MIDX_BYTE_OFFSET=$(($MIDX_OFFSET_OBJECT_OFFSETS + 16 * $MIDX_OFFSET_WIDTH + 6))
+
+test_expect_success 'verify bad version' '
+	corrupt_midx_and_verify $MIDX_BYTE_VERSION "\00" $objdir \
+		"multi-pack-index version"
+'
+
+test_expect_success 'verify bad OID version' '
+	corrupt_midx_and_verify $MIDX_BYTE_OID_VERSION "\02" $objdir \
+		"hash version"
+'
+
+test_expect_success 'verify truncated chunk count' '
+	corrupt_midx_and_verify $MIDX_BYTE_CHUNK_COUNT "\01" $objdir \
+		"missing required"
+'
+
+test_expect_success 'verify extended chunk count' '
+	corrupt_midx_and_verify $MIDX_BYTE_CHUNK_COUNT "\07" $objdir \
+		"terminating multi-pack-index chunk id appears earlier than expected"
+'
+
+test_expect_success 'verify missing required chunk' '
+	corrupt_midx_and_verify $MIDX_BYTE_CHUNK_ID "\01" $objdir \
+		"missing required"
+'
+
+test_expect_success 'verify invalid chunk offset' '
+	corrupt_midx_and_verify $MIDX_BYTE_CHUNK_OFFSET "\01" $objdir \
+		"invalid chunk offset (too large)"
+'
+
+test_expect_success 'verify packnames out of order' '
+	corrupt_midx_and_verify $MIDX_BYTE_PACKNAME_ORDER "z" $objdir \
+		"pack names out of order"
+'
+
+test_expect_success 'verify packnames out of order' '
+	corrupt_midx_and_verify $MIDX_BYTE_PACKNAME_ORDER "a" $objdir \
+		"failed to load pack"
+'
+
+test_expect_success 'verify oid fanout out of order' '
+	corrupt_midx_and_verify $MIDX_BYTE_OID_FANOUT_ORDER "\01" $objdir \
+		"oid fanout out of order"
+'
+
+test_expect_success 'verify oid lookup out of order' '
+	corrupt_midx_and_verify $MIDX_BYTE_OID_LOOKUP "\00" $objdir \
+		"oid lookup out of order"
+'
+
+test_expect_success 'verify incorrect pack-int-id' '
+	corrupt_midx_and_verify $MIDX_BYTE_PACK_INT_ID "\07" $objdir \
+		"bad pack-int-id"
+'
+
+test_expect_success 'verify incorrect offset' '
+	corrupt_midx_and_verify $MIDX_BYTE_OFFSET "\07" $objdir \
+		"incorrect object offset"
+'
+
+test_expect_success 'git-fsck incorrect offset' '
+	corrupt_midx_and_verify $MIDX_BYTE_OFFSET "\07" $objdir \
+		"incorrect object offset" \
+		"git -c core.multipackindex=true fsck"
+'
+
+test_expect_success 'repack progress off for redirected stderr' '
+	git multi-pack-index --object-dir=$objdir repack 2>err &&
+	test_line_count = 0 err
+'
+
+test_expect_success 'repack force progress on for stderr' '
+	git multi-pack-index --object-dir=$objdir --progress repack 2>err &&
+	test_file_not_empty err
+'
+
+test_expect_success 'repack with the --no-progress option' '
+	git multi-pack-index --object-dir=$objdir --no-progress repack 2>err &&
+	test_line_count = 0 err
+'
+
+test_expect_success 'repack removes multi-pack-index' '
+	test_path_is_file $objdir/pack/multi-pack-index &&
+	GIT_TEST_MULTI_PACK_INDEX=0 git repack -adf &&
+	test_path_is_missing $objdir/pack/multi-pack-index
+'
+
+compare_results_with_midx "after repack"
+
+test_expect_success 'multi-pack-index and pack-bitmap' '
+	git -c repack.writeBitmaps=true repack -ad &&
+	git multi-pack-index write &&
+	git rev-list --test-bitmap HEAD
+'
+
+test_expect_success 'multi-pack-index and alternates' '
+	git init --bare alt.git &&
+	echo $(pwd)/alt.git/objects >.git/objects/info/alternates &&
+	echo content1 >file1 &&
+	altblob=$(GIT_DIR=alt.git git hash-object -w file1) &&
+	git cat-file blob $altblob &&
+	git rev-list --all
+'
+
+compare_results_with_midx "with alternate (local midx)"
+
+test_expect_success 'multi-pack-index in an alternate' '
+	mv .git/objects/pack/* alt.git/objects/pack &&
+	test_commit add_local_objects &&
+	git repack --local &&
+	git multi-pack-index write &&
+	midx_read_expect 1 3 4 $objdir &&
+	git reset --hard HEAD~1 &&
+	rm -f .git/objects/pack/*
+'
+
+compare_results_with_midx "with alternate (remote midx)"
+
+# usage: corrupt_data <file> <pos> [<data>]
+corrupt_data () {
+	file=$1
+	pos=$2
+	data="${3:-\0}"
+	printf "$data" | dd of="$file" bs=1 seek="$pos" conv=notrunc
+}
+
+# Force 64-bit offsets by manipulating the idx file.
+# This makes the IDX file _incorrect_ so be careful to clean up after!
+test_expect_success 'force some 64-bit offsets with pack-objects' '
+	mkdir objects64 &&
+	mkdir objects64/pack &&
+	for i in $(test_seq 1 11)
+	do
+		generate_objects 11
+	done &&
+	commit_and_list_objects &&
+	pack64=$(git pack-objects --index-version=2,0x40 objects64/pack/test-64 <obj-list) &&
+	idx64=objects64/pack/test-64-$pack64.idx &&
+	chmod u+w $idx64 &&
+	corrupt_data $idx64 2999 "\02" &&
+	midx64=$(git multi-pack-index --object-dir=objects64 write) &&
+	midx_read_expect 1 63 5 objects64 " large-offsets"
+'
+
+test_expect_success 'verify multi-pack-index with 64-bit offsets' '
+	git multi-pack-index verify --object-dir=objects64
+'
+
+NUM_OBJECTS=63
+MIDX_OFFSET_OID_FANOUT=$((MIDX_OFFSET_PACKNAMES + 54))
+MIDX_OFFSET_OID_LOOKUP=$((MIDX_OFFSET_OID_FANOUT + 256 * $MIDX_OID_FANOUT_WIDTH))
+MIDX_OFFSET_OBJECT_OFFSETS=$(($MIDX_OFFSET_OID_LOOKUP + $NUM_OBJECTS * $HASH_LEN))
+MIDX_OFFSET_LARGE_OFFSETS=$(($MIDX_OFFSET_OBJECT_OFFSETS + $NUM_OBJECTS * $MIDX_OFFSET_WIDTH))
+MIDX_BYTE_LARGE_OFFSET=$(($MIDX_OFFSET_LARGE_OFFSETS + 3))
+
+test_expect_success 'verify incorrect 64-bit offset' '
+	corrupt_midx_and_verify $MIDX_BYTE_LARGE_OFFSET "\07" objects64 \
+		"incorrect object offset"
+'
+
+test_expect_success 'setup expire tests' '
+	mkdir dup &&
+	(
+		cd dup &&
+		git init &&
+		test-tool genrandom "data" 4096 >large_file.txt &&
+		git update-index --add large_file.txt &&
+		for i in $(test_seq 1 20)
+		do
+			test_commit $i
+		done &&
+		git branch A HEAD &&
+		git branch B HEAD~8 &&
+		git branch C HEAD~13 &&
+		git branch D HEAD~16 &&
+		git branch E HEAD~18 &&
+		git pack-objects --revs .git/objects/pack/pack-A <<-EOF &&
+		refs/heads/A
+		^refs/heads/B
+		EOF
+		git pack-objects --revs .git/objects/pack/pack-B <<-EOF &&
+		refs/heads/B
+		^refs/heads/C
+		EOF
+		git pack-objects --revs .git/objects/pack/pack-C <<-EOF &&
+		refs/heads/C
+		^refs/heads/D
+		EOF
+		git pack-objects --revs .git/objects/pack/pack-D <<-EOF &&
+		refs/heads/D
+		^refs/heads/E
+		EOF
+		git pack-objects --revs .git/objects/pack/pack-E <<-EOF &&
+		refs/heads/E
+		EOF
+		git multi-pack-index write &&
+		cp -r .git/objects/pack .git/objects/pack-backup
+	)
+'
+
+test_expect_success 'expire does not remove any packs' '
+	(
+		cd dup &&
+		ls .git/objects/pack >expect &&
+		git multi-pack-index expire &&
+		ls .git/objects/pack >actual &&
+		test_cmp expect actual
+	)
+'
+
+test_expect_success 'expire progress off for redirected stderr' '
+	(
+		cd dup &&
+		git multi-pack-index expire 2>err &&
+		test_line_count = 0 err
+	)
+'
+
+test_expect_success 'expire force progress on for stderr' '
+	(
+		cd dup &&
+		git multi-pack-index --progress expire 2>err &&
+		test_file_not_empty err
+	)
+'
+
+test_expect_success 'expire with the --no-progress option' '
+	(
+		cd dup &&
+		git multi-pack-index --no-progress expire 2>err &&
+		test_line_count = 0 err
+	)
+'
+
+test_expect_success 'expire removes unreferenced packs' '
+	(
+		cd dup &&
+		git pack-objects --revs .git/objects/pack/pack-combined <<-EOF &&
+		refs/heads/A
+		^refs/heads/C
+		EOF
+		git multi-pack-index write &&
+		ls .git/objects/pack | grep -v -e pack-[AB] >expect &&
+		git multi-pack-index expire &&
+		ls .git/objects/pack >actual &&
+		test_cmp expect actual &&
+		ls .git/objects/pack/ | grep idx >expect-idx &&
+		test-tool read-midx .git/objects | grep idx >actual-midx &&
+		test_cmp expect-idx actual-midx &&
+		git multi-pack-index verify &&
+		git fsck
+	)
+'
+
+test_expect_success 'repack with minimum size does not alter existing packs' '
+	(
+		cd dup &&
+		rm -rf .git/objects/pack &&
+		mv .git/objects/pack-backup .git/objects/pack &&
+		touch -m -t 201901010000 .git/objects/pack/pack-D* &&
+		touch -m -t 201901010001 .git/objects/pack/pack-C* &&
+		touch -m -t 201901010002 .git/objects/pack/pack-B* &&
+		touch -m -t 201901010003 .git/objects/pack/pack-A* &&
+		ls .git/objects/pack >expect &&
+		MINSIZE=$(test-tool path-utils file-size .git/objects/pack/*pack | sort -n | head -n 1) &&
+		git multi-pack-index repack --batch-size=$MINSIZE &&
+		ls .git/objects/pack >actual &&
+		test_cmp expect actual
+	)
+'
+
+test_expect_success 'repack creates a new pack' '
+	(
+		cd dup &&
+		ls .git/objects/pack/*idx >idx-list &&
+		test_line_count = 5 idx-list &&
+		THIRD_SMALLEST_SIZE=$(test-tool path-utils file-size .git/objects/pack/*pack | sort -n | head -n 3 | tail -n 1) &&
+		BATCH_SIZE=$(($THIRD_SMALLEST_SIZE + 1)) &&
+		git multi-pack-index repack --batch-size=$BATCH_SIZE &&
+		ls .git/objects/pack/*idx >idx-list &&
+		test_line_count = 6 idx-list &&
+		test-tool read-midx .git/objects | grep idx >midx-list &&
+		test_line_count = 6 midx-list
+	)
+'
+
+test_expect_success 'expire removes repacked packs' '
+	(
+		cd dup &&
+		ls -al .git/objects/pack/*pack &&
+		ls -S .git/objects/pack/*pack | head -n 4 >expect &&
+		git multi-pack-index expire &&
+		ls -S .git/objects/pack/*pack >actual &&
+		test_cmp expect actual &&
+		test-tool read-midx .git/objects | grep idx >midx-list &&
+		test_line_count = 4 midx-list
+	)
+'
+
+test_expect_success 'expire works when adding new packs' '
+	(
+		cd dup &&
+		git pack-objects --revs .git/objects/pack/pack-combined <<-EOF &&
+		refs/heads/A
+		^refs/heads/B
+		EOF
+		git pack-objects --revs .git/objects/pack/pack-combined <<-EOF &&
+		refs/heads/B
+		^refs/heads/C
+		EOF
+		git pack-objects --revs .git/objects/pack/pack-combined <<-EOF &&
+		refs/heads/C
+		^refs/heads/D
+		EOF
+		git multi-pack-index write &&
+		git pack-objects --revs .git/objects/pack/a-pack <<-EOF &&
+		refs/heads/D
+		^refs/heads/E
+		EOF
+		git multi-pack-index write &&
+		git pack-objects --revs .git/objects/pack/z-pack <<-EOF &&
+		refs/heads/E
+		EOF
+		git multi-pack-index expire &&
+		ls .git/objects/pack/ | grep idx >expect &&
+		test-tool read-midx .git/objects | grep idx >actual &&
+		test_cmp expect actual &&
+		git multi-pack-index verify
+	)
+'
+
+test_expect_success 'expire respects .keep files' '
+	(
+		cd dup &&
+		git pack-objects --revs .git/objects/pack/pack-all <<-EOF &&
+		refs/heads/A
+		EOF
+		git multi-pack-index write &&
+		PACKA=$(ls .git/objects/pack/a-pack*\.pack | sed s/\.pack\$//) &&
+		touch $PACKA.keep &&
+		git multi-pack-index expire &&
+		ls -S .git/objects/pack/a-pack* | grep $PACKA >a-pack-files &&
+		test_line_count = 3 a-pack-files &&
+		test-tool read-midx .git/objects | grep idx >midx-list &&
+		test_line_count = 2 midx-list
+	)
+'
+
+test_expect_success 'repack --batch-size=0 repacks everything' '
+	(
+		cd dup &&
+		rm .git/objects/pack/*.keep &&
+		ls .git/objects/pack/*idx >idx-list &&
+		test_line_count = 2 idx-list &&
+		git multi-pack-index repack --batch-size=0 &&
+		ls .git/objects/pack/*idx >idx-list &&
+		test_line_count = 3 idx-list &&
+		test-tool read-midx .git/objects | grep idx >midx-list &&
+		test_line_count = 3 midx-list &&
+		git multi-pack-index expire &&
+		ls -al .git/objects/pack/*idx >idx-list &&
+		test_line_count = 1 idx-list &&
+		git multi-pack-index repack --batch-size=0 &&
+		ls -al .git/objects/pack/*idx >new-idx-list &&
+		test_cmp idx-list new-idx-list
+	)
+'
+
+test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t5320-delta-islands.sh 1.2.3+git2.25.1-1/git/t/t5320-delta-islands.sh
--- 1.2.1+git2.18.0-1/git/t/t5320-delta-islands.sh	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t5320-delta-islands.sh	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,143 @@
+#!/bin/sh
+
+test_description='exercise delta islands'
+. ./test-lib.sh
+
+# returns true iff $1 is a delta based on $2
+is_delta_base () {
+	delta_base=$(echo "$1" | git cat-file --batch-check='%(deltabase)') &&
+	echo >&2 "$1 has base $delta_base" &&
+	test "$delta_base" = "$2"
+}
+
+# generate a commit on branch $1 with a single file, "file", whose
+# content is mostly based on the seed $2, but with a unique bit
+# of content $3 appended. This should allow us to see whether
+# blobs of different refs delta against each other.
+commit() {
+	blob=$({ test-tool genrandom "$2" 10240 && echo "$3"; } |
+	       git hash-object -w --stdin) &&
+	tree=$(printf '100644 blob %s\tfile\n' "$blob" | git mktree) &&
+	commit=$(echo "$2-$3" | git commit-tree "$tree" ${4:+-p "$4"}) &&
+	git update-ref "refs/heads/$1" "$commit" &&
+	eval "$1"'=$(git rev-parse $1:file)' &&
+	eval "echo >&2 $1=\$$1"
+}
+
+test_expect_success 'setup commits' '
+	commit one seed 1 &&
+	commit two seed 12
+'
+
+# Note: This is heavily dependent on the "prefer larger objects as base"
+# heuristic.
+test_expect_success 'vanilla repack deltas one against two' '
+	git repack -adf &&
+	is_delta_base $one $two
+'
+
+test_expect_success 'island repack with no island definition is vanilla' '
+	git repack -adfi &&
+	is_delta_base $one $two
+'
+
+test_expect_success 'island repack with no matches is vanilla' '
+	git -c "pack.island=refs/foo" repack -adfi &&
+	is_delta_base $one $two
+'
+
+test_expect_success 'separate islands disallows delta' '
+	git -c "pack.island=refs/heads/(.*)" repack -adfi &&
+	! is_delta_base $one $two &&
+	! is_delta_base $two $one
+'
+
+test_expect_success 'same island allows delta' '
+	git -c "pack.island=refs/heads" repack -adfi &&
+	is_delta_base $one $two
+'
+
+test_expect_success 'coalesce same-named islands' '
+	git \
+		-c "pack.island=refs/(.*)/one" \
+		-c "pack.island=refs/(.*)/two" \
+		repack -adfi &&
+	is_delta_base $one $two
+'
+
+test_expect_success 'island restrictions drop reused deltas' '
+	git repack -adfi &&
+	is_delta_base $one $two &&
+	git -c "pack.island=refs/heads/(.*)" repack -adi &&
+	! is_delta_base $one $two &&
+	! is_delta_base $two $one
+'
+
+test_expect_success 'island regexes are left-anchored' '
+	git -c "pack.island=heads/(.*)" repack -adfi &&
+	is_delta_base $one $two
+'
+
+test_expect_success 'island regexes follow last-one-wins scheme' '
+	git \
+		-c "pack.island=refs/heads/(.*)" \
+		-c "pack.island=refs/heads/" \
+		repack -adfi &&
+	is_delta_base $one $two
+'
+
+test_expect_success 'setup shared history' '
+	commit root shared root &&
+	commit one shared 1 root &&
+	commit two shared 12-long root
+'
+
+# We know that $two will be preferred as a base from $one,
+# because we can transform it with a pure deletion.
+#
+# We also expect $root as a delta against $two by the "longest is base" rule.
+test_expect_success 'vanilla delta goes between branches' '
+	git repack -adf &&
+	is_delta_base $one $two &&
+	is_delta_base $root $two
+'
+
+# Here we should allow $one to base itself on $root; even though
+# they are in different islands, the objects in $root are in a superset
+# of islands compared to those in $one.
+#
+# Similarly, $two can delta against $root by our rules. And unlike $one,
+# in which we are just allowing it, the island rules actually put $root
+# as a possible base for $two, which it would not otherwise be (due to the size
+# sorting).
+test_expect_success 'deltas allowed against superset islands' '
+	git -c "pack.island=refs/heads/(.*)" repack -adfi &&
+	is_delta_base $one $root &&
+	is_delta_base $two $root
+'
+
+# We are going to test the packfile order here, so we again have to make some
+# assumptions. We assume that "$root", as part of our core "one", must come
+# before "$two". This should be guaranteed by the island code. However, for
+# this test to fail without islands, we are also assuming that it would not
+# otherwise do so. This is true by the current write order, which will put
+# commits (and their contents) before their parents.
+test_expect_success 'island core places core objects first' '
+	cat >expect <<-EOF &&
+	$root
+	$two
+	EOF
+	git -c "pack.island=refs/heads/(.*)" \
+	    -c "pack.islandcore=one" \
+	    repack -adfi &&
+	git verify-pack -v .git/objects/pack/*.pack |
+	cut -d" " -f1 |
+	egrep "$root|$two" >actual &&
+	test_cmp expect actual
+'
+
+test_expect_success 'unmatched island core is not fatal' '
+	git -c "pack.islandcore=one" repack -adfi
+'
+
+test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t5321-pack-large-objects.sh 1.2.3+git2.25.1-1/git/t/t5321-pack-large-objects.sh
--- 1.2.1+git2.18.0-1/git/t/t5321-pack-large-objects.sh	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t5321-pack-large-objects.sh	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,32 @@
+#!/bin/sh
+#
+# Copyright (c) 2018 Johannes Schindelin
+#
+
+test_description='git pack-object with "large" deltas
+
+'
+. ./test-lib.sh
+. "$TEST_DIRECTORY"/lib-pack.sh
+
+# Two similar-ish objects that we have computed deltas between.
+A=01d7713666f4de822776c7622c10f1b07de280dc
+B=e68fe8129b546b101aee9510c5328e7f21ca1d18
+
+test_expect_success 'setup' '
+	clear_packs &&
+	{
+		pack_header 2 &&
+		pack_obj $A $B &&
+		pack_obj $B
+	} >ab.pack &&
+	pack_trailer ab.pack &&
+	git index-pack --stdin <ab.pack
+'
+
+test_expect_success 'repack large deltas' '
+	printf "%s\\n" $A $B |
+	GIT_TEST_OE_DELTA_SIZE=2 git pack-objects tmp-pack
+'
+
+test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t5322-pack-objects-sparse.sh 1.2.3+git2.25.1-1/git/t/t5322-pack-objects-sparse.sh
--- 1.2.1+git2.18.0-1/git/t/t5322-pack-objects-sparse.sh	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t5322-pack-objects-sparse.sh	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,136 @@
+#!/bin/sh
+
+test_description='pack-objects object selection using sparse algorithm'
+. ./test-lib.sh
+
+test_expect_success 'setup repo' '
+	test_commit initial &&
+	for i in $(test_seq 1 3)
+	do
+		mkdir f$i &&
+		for j in $(test_seq 1 3)
+		do
+			mkdir f$i/f$j &&
+			echo $j >f$i/f$j/data.txt
+		done
+	done &&
+	git add . &&
+	git commit -m "Initialized trees" &&
+	for i in $(test_seq 1 3)
+	do
+		git checkout -b topic$i master &&
+		echo change-$i >f$i/f$i/data.txt &&
+		git commit -a -m "Changed f$i/f$i/data.txt"
+	done &&
+	cat >packinput.txt <<-EOF &&
+	topic1
+	^topic2
+	^topic3
+	EOF
+	git rev-parse			\
+		topic1			\
+		topic1^{tree}		\
+		topic1:f1		\
+		topic1:f1/f1		\
+		topic1:f1/f1/data.txt | sort >expect_objects.txt
+'
+
+test_expect_success 'non-sparse pack-objects' '
+	git pack-objects --stdout --revs --no-sparse <packinput.txt >nonsparse.pack &&
+	git index-pack -o nonsparse.idx nonsparse.pack &&
+	git show-index <nonsparse.idx | awk "{print \$2}" >nonsparse_objects.txt &&
+	test_cmp expect_objects.txt nonsparse_objects.txt
+'
+
+test_expect_success 'sparse pack-objects' '
+	git pack-objects --stdout --revs --sparse <packinput.txt >sparse.pack &&
+	git index-pack -o sparse.idx sparse.pack &&
+	git show-index <sparse.idx | awk "{print \$2}" >sparse_objects.txt &&
+	test_cmp expect_objects.txt sparse_objects.txt
+'
+
+test_expect_success 'duplicate a folder from f3 and commit to topic1' '
+	git checkout topic1 &&
+	echo change-3 >f3/f3/data.txt &&
+	git commit -a -m "Changed f3/f3/data.txt" &&
+	git rev-parse			\
+		topic1~1		\
+		topic1~1^{tree}		\
+		topic1^{tree}		\
+		topic1			\
+		topic1:f1		\
+		topic1:f1/f1		\
+		topic1:f1/f1/data.txt | sort >required_objects.txt
+'
+
+test_expect_success 'non-sparse pack-objects' '
+	git pack-objects --stdout --revs --no-sparse <packinput.txt >nonsparse.pack &&
+	git index-pack -o nonsparse.idx nonsparse.pack &&
+	git show-index <nonsparse.idx | awk "{print \$2}" >nonsparse_objects.txt &&
+	comm -1 -2 required_objects.txt nonsparse_objects.txt >nonsparse_required_objects.txt &&
+	test_cmp required_objects.txt nonsparse_required_objects.txt
+'
+
+test_expect_success 'sparse pack-objects' '
+	git pack-objects --stdout --revs --sparse <packinput.txt >sparse.pack &&
+	git index-pack -o sparse.idx sparse.pack &&
+	git show-index <sparse.idx | awk "{print \$2}" >sparse_objects.txt &&
+	comm -1 -2 required_objects.txt sparse_objects.txt >sparse_required_objects.txt &&
+	test_cmp required_objects.txt sparse_required_objects.txt
+'
+
+# Demonstrate that the algorithms differ when we copy a tree wholesale
+# from one folder to another.
+
+test_expect_success 'duplicate a folder from f1 into f3' '
+	mkdir f3/f4 &&
+	cp -r f1/f1/* f3/f4 &&
+	git add f3/f4 &&
+	git commit -m "Copied f1/f1 to f3/f4" &&
+	cat >packinput.txt <<-EOF &&
+	topic1
+	^topic1~1
+	EOF
+	git rev-parse		\
+		topic1		\
+		topic1^{tree}   \
+		topic1:f3 | sort >required_objects.txt
+'
+
+test_expect_success 'non-sparse pack-objects' '
+	git pack-objects --stdout --revs --no-sparse <packinput.txt >nonsparse.pack &&
+	git index-pack -o nonsparse.idx nonsparse.pack &&
+	git show-index <nonsparse.idx | awk "{print \$2}" >nonsparse_objects.txt &&
+	comm -1 -2 required_objects.txt nonsparse_objects.txt >nonsparse_required_objects.txt &&
+	test_cmp required_objects.txt nonsparse_required_objects.txt
+'
+
+test_expect_success 'sparse pack-objects' '
+	git rev-parse			\
+		topic1			\
+		topic1^{tree}		\
+		topic1:f3		\
+		topic1:f3/f4		\
+		topic1:f3/f4/data.txt | sort >expect_sparse_objects.txt &&
+	git pack-objects --stdout --revs --sparse <packinput.txt >sparse.pack &&
+	git index-pack -o sparse.idx sparse.pack &&
+	git show-index <sparse.idx | awk "{print \$2}" >sparse_objects.txt &&
+	test_cmp expect_sparse_objects.txt sparse_objects.txt
+'
+
+test_expect_success 'pack.useSparse enables algorithm' '
+	git config pack.useSparse true &&
+	git pack-objects --stdout --revs <packinput.txt >sparse.pack &&
+	git index-pack -o sparse.idx sparse.pack &&
+	git show-index <sparse.idx | awk "{print \$2}" >sparse_objects.txt &&
+	test_cmp expect_sparse_objects.txt sparse_objects.txt
+'
+
+test_expect_success 'pack.useSparse overridden' '
+	git pack-objects --stdout --revs --no-sparse <packinput.txt >sparse.pack &&
+	git index-pack -o sparse.idx sparse.pack &&
+	git show-index <sparse.idx | awk "{print \$2}" >sparse_objects.txt &&
+	test_cmp required_objects.txt sparse_objects.txt
+'
+
+test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t5323-pack-redundant.sh 1.2.3+git2.25.1-1/git/t/t5323-pack-redundant.sh
--- 1.2.1+git2.18.0-1/git/t/t5323-pack-redundant.sh	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t5323-pack-redundant.sh	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,467 @@
+#!/bin/sh
+#
+# Copyright (c) 2018 Jiang Xin
+#
+
+test_description='Test git pack-redundant
+
+In order to test git-pack-redundant, we will create a number of objects and
+packs in the repository `master.git`. The relationship between packs (P1-P8)
+and objects (T, A-R) is showed in the following chart. Objects of a pack will
+be marked with letter x, while objects of redundant packs will be marked with
+exclamation point, and redundant pack itself will be marked with asterisk.
+
+	| T A B C D E F G H I J K L M N O P Q R
+    ----+--------------------------------------
+    P1  | x x x x x x x                       x
+    P2* |     ! ! ! !   ! ! !
+    P3  |             x     x x x x x
+    P4* |                     ! ! ! !     !
+    P5  |               x x           x x
+    P6* |                             ! !   !
+    P7  |                                 x x
+    P8* |   !
+    ----+--------------------------------------
+    ALL | x x x x x x x x x x x x x x x x x x x
+
+Another repository `shared.git` has unique objects (X-Z), while other objects
+(marked with letter s) are shared through alt-odb (of `master.git`). The
+relationship between packs and objects is as follows:
+
+	| T A B C D E F G H I J K L M N O P Q R   X Y Z
+    ----+----------------------------------------------
+    Px1 |   s s s                                 x x x
+    Px2 |         s s s                           x x x
+'
+
+. ./test-lib.sh
+
+master_repo=master.git
+shared_repo=shared.git
+
+# Create commits in <repo> and assign each commit's oid to shell variables
+# given in the arguments (A, B, and C). E.g.:
+#
+#     create_commits_in <repo> A B C
+#
+# NOTE: Avoid calling this function from a subshell since variable
+# assignments will disappear when subshell exits.
+create_commits_in () {
+	repo="$1" &&
+	if ! parent=$(git -C "$repo" rev-parse HEAD^{} 2>/dev/null)
+	then
+		parent=
+	fi &&
+	T=$(git -C "$repo" write-tree) &&
+	shift &&
+	while test $# -gt 0
+	do
+		name=$1 &&
+		test_tick &&
+		if test -z "$parent"
+		then
+			oid=$(echo $name | git -C "$repo" commit-tree $T)
+		else
+			oid=$(echo $name | git -C "$repo" commit-tree -p $parent $T)
+		fi &&
+		eval $name=$oid &&
+		parent=$oid &&
+		shift ||
+		return 1
+	done &&
+	git -C "$repo" update-ref refs/heads/master $oid
+}
+
+# Create pack in <repo> and assign pack id to variable given in the 2nd argument
+# (<name>). Commits in the pack will be read from stdin. E.g.:
+#
+#     create_pack_in <repo> <name> <<-EOF
+#         ...
+#         EOF
+#
+# NOTE: commits from stdin should be given using heredoc, not using pipe, and
+# avoid calling this function from a subshell since variable assignments will
+# disappear when subshell exits.
+create_pack_in () {
+	repo="$1" &&
+	name="$2" &&
+	pack=$(git -C "$repo/objects/pack" pack-objects -q pack) &&
+	eval $name=$pack &&
+	eval P$pack=$name:$pack
+}
+
+format_packfiles () {
+	sed \
+		-e "s#.*/pack-\(.*\)\.idx#\1#" \
+		-e "s#.*/pack-\(.*\)\.pack#\1#" |
+	sort -u |
+	while read p
+	do
+		if test -z "$(eval echo \${P$p})"
+		then
+			echo $p
+		else
+			eval echo "\${P$p}"
+		fi
+	done |
+	sort
+}
+
+test_expect_success 'setup master repo' '
+	git init --bare "$master_repo" &&
+	create_commits_in "$master_repo" A B C D E F G H I J K L M N O P Q R
+'
+
+#############################################################################
+# Chart of packs and objects for this test case
+#
+#         | T A B C D E F G H I J K L M N O P Q R
+#     ----+--------------------------------------
+#     P1  | x x x x x x x                       x
+#     P2  |     x x x x   x x x
+#     P3  |             x     x x x x x
+#     ----+--------------------------------------
+#     ALL | x x x x x x x x x x x x x x         x
+#
+#############################################################################
+test_expect_success 'master: no redundant for pack 1, 2, 3' '
+	create_pack_in "$master_repo" P1 <<-EOF &&
+		$T
+		$A
+		$B
+		$C
+		$D
+		$E
+		$F
+		$R
+		EOF
+	create_pack_in "$master_repo" P2 <<-EOF &&
+		$B
+		$C
+		$D
+		$E
+		$G
+		$H
+		$I
+		EOF
+	create_pack_in "$master_repo" P3 <<-EOF &&
+		$F
+		$I
+		$J
+		$K
+		$L
+		$M
+		EOF
+	(
+		cd "$master_repo" &&
+		git pack-redundant --all >out &&
+		test_must_be_empty out
+	)
+'
+
+#############################################################################
+# Chart of packs and objects for this test case
+#
+#         | T A B C D E F G H I J K L M N O P Q R
+#     ----+--------------------------------------
+#     P1  | x x x x x x x                       x
+#     P2  |     x x x x   x x x
+#     P3* |             !     ! ! ! ! !
+#     P4  |                     x x x x     x
+#     P5  |               x x           x x
+#     ----+--------------------------------------
+#     ALL | x x x x x x x x x x x x x x x x x   x
+#
+#############################################################################
+test_expect_success 'master: one of pack-2/pack-3 is redundant' '
+	create_pack_in "$master_repo" P4 <<-EOF &&
+		$J
+		$K
+		$L
+		$M
+		$P
+		EOF
+	create_pack_in "$master_repo" P5 <<-EOF &&
+		$G
+		$H
+		$N
+		$O
+		EOF
+	(
+		cd "$master_repo" &&
+		cat >expect <<-EOF &&
+			P3:$P3
+			EOF
+		git pack-redundant --all >out &&
+		format_packfiles <out >actual &&
+		test_cmp expect actual
+	)
+'
+
+#############################################################################
+# Chart of packs and objects for this test case
+#
+#         | T A B C D E F G H I J K L M N O P Q R
+#     ----+--------------------------------------
+#     P1  | x x x x x x x                       x
+#     P2* |     ! ! ! !   ! ! !
+#     P3  |             x     x x x x x
+#     P4* |                     ! ! ! !     !
+#     P5  |               x x           x x
+#     P6* |                             ! !   !
+#     P7  |                                 x x
+#     ----+--------------------------------------
+#     ALL | x x x x x x x x x x x x x x x x x x x
+#
+#############################################################################
+test_expect_success 'master: pack 2, 4, and 6 are redundant' '
+	create_pack_in "$master_repo" P6 <<-EOF &&
+		$N
+		$O
+		$Q
+		EOF
+	create_pack_in "$master_repo" P7 <<-EOF &&
+		$P
+		$Q
+		EOF
+	(
+		cd "$master_repo" &&
+		cat >expect <<-EOF &&
+			P2:$P2
+			P4:$P4
+			P6:$P6
+			EOF
+		git pack-redundant --all >out &&
+		format_packfiles <out >actual &&
+		test_cmp expect actual
+	)
+'
+
+#############################################################################
+# Chart of packs and objects for this test case
+#
+#         | T A B C D E F G H I J K L M N O P Q R
+#     ----+--------------------------------------
+#     P1  | x x x x x x x                       x
+#     P2* |     ! ! ! !   ! ! !
+#     P3  |             x     x x x x x
+#     P4* |                     ! ! ! !     !
+#     P5  |               x x           x x
+#     P6* |                             ! !   !
+#     P7  |                                 x x
+#     P8* |   !
+#     ----+--------------------------------------
+#     ALL | x x x x x x x x x x x x x x x x x x x
+#
+#############################################################################
+test_expect_success 'master: pack-8 (subset of pack-1) is also redundant' '
+	create_pack_in "$master_repo" P8 <<-EOF &&
+		$A
+		EOF
+	(
+		cd "$master_repo" &&
+		cat >expect <<-EOF &&
+			P2:$P2
+			P4:$P4
+			P6:$P6
+			P8:$P8
+			EOF
+		git pack-redundant --all >out &&
+		format_packfiles <out >actual &&
+		test_cmp expect actual
+	)
+'
+
+test_expect_success 'master: clean loose objects' '
+	(
+		cd "$master_repo" &&
+		git prune-packed &&
+		find objects -type f | sed -e "/objects\/pack\//d" >out &&
+		test_must_be_empty out
+	)
+'
+
+test_expect_success 'master: remove redundant packs and pass fsck' '
+	(
+		cd "$master_repo" &&
+		git pack-redundant --all | xargs rm &&
+		git fsck &&
+		git pack-redundant --all >out &&
+		test_must_be_empty out
+	)
+'
+
+# The following test cases will execute inside `shared.git`, instead of
+# inside `master.git`.
+test_expect_success 'setup shared.git' '
+	git clone --mirror "$master_repo" "$shared_repo" &&
+	(
+		cd "$shared_repo" &&
+		printf "../../$master_repo/objects\n" >objects/info/alternates
+	)
+'
+
+test_expect_success 'shared: all packs are redundant, but no output without --alt-odb' '
+	(
+		cd "$shared_repo" &&
+		git pack-redundant --all >out &&
+		test_must_be_empty out
+	)
+'
+
+#############################################################################
+# Chart of packs and objects for this test case
+#
+#     ================ master.git ===============
+#         | T A B C D E F G H I J K L M N O P Q R  <----------+
+#     ----+--------------------------------------             |
+#     P1  | x x x x x x x                       x             |
+#     P3  |             x     x x x x x                       |
+#     P5  |               x x           x x                   |
+#     P7  |                                 x x               |
+#     ----+--------------------------------------             |
+#     ALL | x x x x x x x x x x x x x x x x x x x             |
+#                                                             |
+#                                                             |
+#     ================ shared.git ===============             |
+#         | T A B C D E F G H I J K L M N O P Q R  <objects/info/alternates>
+#     ----+--------------------------------------
+#     P1* | s s s s s s s                       s
+#     P3* |             s     s s s s s
+#     P5* |               s s           s s
+#     P7* |                                 s s
+#     ----+--------------------------------------
+#     ALL | x x x x x x x x x x x x x x x x x x x
+#
+#############################################################################
+test_expect_success 'shared: show redundant packs in stderr for verbose mode' '
+	(
+		cd "$shared_repo" &&
+		cat >expect <<-EOF &&
+			P1:$P1
+			P3:$P3
+			P5:$P5
+			P7:$P7
+			EOF
+		git pack-redundant --all --verbose >out 2>out.err &&
+		test_must_be_empty out &&
+		grep "pack$" out.err | format_packfiles >actual &&
+		test_cmp expect actual
+	)
+'
+
+test_expect_success 'shared: remove redundant packs, no packs left' '
+	(
+		cd "$shared_repo" &&
+		cat >expect <<-EOF &&
+			fatal: Zero packs found!
+			EOF
+		git pack-redundant --all --alt-odb | xargs rm &&
+		git fsck &&
+		test_must_fail git pack-redundant --all --alt-odb >actual 2>&1 &&
+		test_cmp expect actual
+	)
+'
+
+test_expect_success 'shared: create new objects and packs' '
+	create_commits_in "$shared_repo" X Y Z &&
+	create_pack_in "$shared_repo" Px1 <<-EOF &&
+		$X
+		$Y
+		$Z
+		$A
+		$B
+		$C
+		EOF
+	create_pack_in "$shared_repo" Px2 <<-EOF
+		$X
+		$Y
+		$Z
+		$D
+		$E
+		$F
+		EOF
+'
+
+test_expect_success 'shared: no redundant without --alt-odb' '
+	(
+		cd "$shared_repo" &&
+		git pack-redundant --all >out &&
+		test_must_be_empty out
+	)
+'
+
+#############################################################################
+# Chart of packs and objects for this test case
+#
+#     ================ master.git ===============
+#         | T A B C D E F G H I J K L M N O P Q R  <----------------+
+#     ----+--------------------------------------                   |
+#     P1  | x x x x x x x                       x                   |
+#     P3  |             x     x x x x x                             |
+#     P5  |               x x           x x                         |
+#     P7  |                                 x x                     |
+#     ----+--------------------------------------                   |
+#     ALL | x x x x x x x x x x x x x x x x x x x                   |
+#                                                                   |
+#                                                                   |
+#     ================ shared.git =======================           |
+#         | T A B C D E F G H I J K L M N O P Q R   X Y Z <objects/info/alternates>
+#     ----+----------------------------------------------
+#     Px1 |   s s s                                 x x x
+#     Px2*|         s s s                           ! ! !
+#     ----+----------------------------------------------
+#     ALL | s s s s s s s s s s s s s s s s s s s   x x x
+#
+#############################################################################
+test_expect_success 'shared: one pack is redundant with --alt-odb' '
+	(
+		cd "$shared_repo" &&
+		git pack-redundant --all --alt-odb >out &&
+		format_packfiles <out >actual &&
+		test_line_count = 1 actual
+	)
+'
+
+#############################################################################
+# Chart of packs and objects for this test case
+#
+#     ================ master.git ===============
+#         | T A B C D E F G H I J K L M N O P Q R  <----------------+
+#     ----+--------------------------------------                   |
+#     P1  | x x x x x x x                       x                   |
+#     P3  |             x     x x x x x                             |
+#     P5  |               x x           x x                         |
+#     P7  |                                 x x                     |
+#     ----+--------------------------------------                   |
+#     ALL | x x x x x x x x x x x x x x x x x x x                   |
+#                                                                   |
+#                                                                   |
+#     ================ shared.git =======================           |
+#         | T A B C D E F G H I J K L M N O P Q R   X Y Z <objects/info/alternates>
+#     ----+----------------------------------------------
+#     Px1*|   s s s                                 i i i
+#     Px2*|         s s s                           i i i
+#     ----+----------------------------------------------
+#     ALL | s s s s s s s s s s s s s s s s s s s   i i i
+#                                                  (ignored objects, marked with i)
+#
+#############################################################################
+test_expect_success 'shared: ignore unique objects and all two packs are redundant' '
+	(
+		cd "$shared_repo" &&
+		cat >expect <<-EOF &&
+			Px1:$Px1
+			Px2:$Px2
+			EOF
+		git pack-redundant --all --alt-odb >out <<-EOF &&
+			$X
+			$Y
+			$Z
+			EOF
+		format_packfiles <out >actual &&
+		test_cmp expect actual
+	)
+'
+
+test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t5324-split-commit-graph.sh 1.2.3+git2.25.1-1/git/t/t5324-split-commit-graph.sh
--- 1.2.1+git2.18.0-1/git/t/t5324-split-commit-graph.sh	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t5324-split-commit-graph.sh	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,347 @@
+#!/bin/sh
+
+test_description='split commit graph'
+. ./test-lib.sh
+
+GIT_TEST_COMMIT_GRAPH=0
+
+test_expect_success 'setup repo' '
+	git init &&
+	git config core.commitGraph true &&
+	git config gc.writeCommitGraph false &&
+	infodir=".git/objects/info" &&
+	graphdir="$infodir/commit-graphs" &&
+	test_oid_init
+'
+
+graph_read_expect() {
+	NUM_BASE=0
+	if test ! -z $2
+	then
+		NUM_BASE=$2
+	fi
+	cat >expect <<- EOF
+	header: 43475048 1 1 3 $NUM_BASE
+	num_commits: $1
+	chunks: oid_fanout oid_lookup commit_metadata
+	EOF
+	test-tool read-graph >output &&
+	test_cmp expect output
+}
+
+test_expect_success 'create commits and write commit-graph' '
+	for i in $(test_seq 3)
+	do
+		test_commit $i &&
+		git branch commits/$i || return 1
+	done &&
+	git commit-graph write --reachable &&
+	test_path_is_file $infodir/commit-graph &&
+	graph_read_expect 3
+'
+
+graph_git_two_modes() {
+	git -c core.commitGraph=true $1 >output
+	git -c core.commitGraph=false $1 >expect
+	test_cmp expect output
+}
+
+graph_git_behavior() {
+	MSG=$1
+	BRANCH=$2
+	COMPARE=$3
+	test_expect_success "check normal git operations: $MSG" '
+		graph_git_two_modes "log --oneline $BRANCH" &&
+		graph_git_two_modes "log --topo-order $BRANCH" &&
+		graph_git_two_modes "log --graph $COMPARE..$BRANCH" &&
+		graph_git_two_modes "branch -vv" &&
+		graph_git_two_modes "merge-base -a $BRANCH $COMPARE"
+	'
+}
+
+graph_git_behavior 'graph exists' commits/3 commits/1
+
+verify_chain_files_exist() {
+	for hash in $(cat $1/commit-graph-chain)
+	do
+		test_path_is_file $1/graph-$hash.graph || return 1
+	done
+}
+
+test_expect_success 'add more commits, and write a new base graph' '
+	git reset --hard commits/1 &&
+	for i in $(test_seq 4 5)
+	do
+		test_commit $i &&
+		git branch commits/$i || return 1
+	done &&
+	git reset --hard commits/2 &&
+	for i in $(test_seq 6 10)
+	do
+		test_commit $i &&
+		git branch commits/$i || return 1
+	done &&
+	git reset --hard commits/2 &&
+	git merge commits/4 &&
+	git branch merge/1 &&
+	git reset --hard commits/4 &&
+	git merge commits/6 &&
+	git branch merge/2 &&
+	git commit-graph write --reachable &&
+	graph_read_expect 12
+'
+
+test_expect_success 'fork and fail to base a chain on a commit-graph file' '
+	test_when_finished rm -rf fork &&
+	git clone . fork &&
+	(
+		cd fork &&
+		rm .git/objects/info/commit-graph &&
+		echo "$(pwd)/../.git/objects" >.git/objects/info/alternates &&
+		test_commit new-commit &&
+		git commit-graph write --reachable --split &&
+		test_path_is_file $graphdir/commit-graph-chain &&
+		test_line_count = 1 $graphdir/commit-graph-chain &&
+		verify_chain_files_exist $graphdir
+	)
+'
+
+test_expect_success 'add three more commits, write a tip graph' '
+	git reset --hard commits/3 &&
+	git merge merge/1 &&
+	git merge commits/5 &&
+	git merge merge/2 &&
+	git branch merge/3 &&
+	git commit-graph write --reachable --split &&
+	test_path_is_missing $infodir/commit-graph &&
+	test_path_is_file $graphdir/commit-graph-chain &&
+	ls $graphdir/graph-*.graph >graph-files &&
+	test_line_count = 2 graph-files &&
+	verify_chain_files_exist $graphdir
+'
+
+graph_git_behavior 'split commit-graph: merge 3 vs 2' merge/3 merge/2
+
+test_expect_success 'add one commit, write a tip graph' '
+	test_commit 11 &&
+	git branch commits/11 &&
+	git commit-graph write --reachable --split &&
+	test_path_is_missing $infodir/commit-graph &&
+	test_path_is_file $graphdir/commit-graph-chain &&
+	ls $graphdir/graph-*.graph >graph-files &&
+	test_line_count = 3 graph-files &&
+	verify_chain_files_exist $graphdir
+'
+
+graph_git_behavior 'three-layer commit-graph: commit 11 vs 6' commits/11 commits/6
+
+test_expect_success 'add one commit, write a merged graph' '
+	test_commit 12 &&
+	git branch commits/12 &&
+	git commit-graph write --reachable --split &&
+	test_path_is_file $graphdir/commit-graph-chain &&
+	test_line_count = 2 $graphdir/commit-graph-chain &&
+	ls $graphdir/graph-*.graph >graph-files &&
+	test_line_count = 2 graph-files &&
+	verify_chain_files_exist $graphdir
+'
+
+graph_git_behavior 'merged commit-graph: commit 12 vs 6' commits/12 commits/6
+
+test_expect_success 'create fork and chain across alternate' '
+	git clone . fork &&
+	(
+		cd fork &&
+		git config core.commitGraph true &&
+		rm -rf $graphdir &&
+		echo "$(pwd)/../.git/objects" >.git/objects/info/alternates &&
+		test_commit 13 &&
+		git branch commits/13 &&
+		git commit-graph write --reachable --split &&
+		test_path_is_file $graphdir/commit-graph-chain &&
+		test_line_count = 3 $graphdir/commit-graph-chain &&
+		ls $graphdir/graph-*.graph >graph-files &&
+		test_line_count = 1 graph-files &&
+		git -c core.commitGraph=true  rev-list HEAD >expect &&
+		git -c core.commitGraph=false rev-list HEAD >actual &&
+		test_cmp expect actual &&
+		test_commit 14 &&
+		git commit-graph write --reachable --split --object-dir=.git/objects/ &&
+		test_line_count = 3 $graphdir/commit-graph-chain &&
+		ls $graphdir/graph-*.graph >graph-files &&
+		test_line_count = 1 graph-files
+	)
+'
+
+graph_git_behavior 'alternate: commit 13 vs 6' commits/13 commits/6
+
+test_expect_success 'test merge stragety constants' '
+	git clone . merge-2 &&
+	(
+		cd merge-2 &&
+		git config core.commitGraph true &&
+		test_line_count = 2 $graphdir/commit-graph-chain &&
+		test_commit 14 &&
+		git commit-graph write --reachable --split --size-multiple=2 &&
+		test_line_count = 3 $graphdir/commit-graph-chain
+
+	) &&
+	git clone . merge-10 &&
+	(
+		cd merge-10 &&
+		git config core.commitGraph true &&
+		test_line_count = 2 $graphdir/commit-graph-chain &&
+		test_commit 14 &&
+		git commit-graph write --reachable --split --size-multiple=10 &&
+		test_line_count = 1 $graphdir/commit-graph-chain &&
+		ls $graphdir/graph-*.graph >graph-files &&
+		test_line_count = 1 graph-files
+	) &&
+	git clone . merge-10-expire &&
+	(
+		cd merge-10-expire &&
+		git config core.commitGraph true &&
+		test_line_count = 2 $graphdir/commit-graph-chain &&
+		test_commit 15 &&
+		git commit-graph write --reachable --split --size-multiple=10 --expire-time=1980-01-01 &&
+		test_line_count = 1 $graphdir/commit-graph-chain &&
+		ls $graphdir/graph-*.graph >graph-files &&
+		test_line_count = 3 graph-files
+	) &&
+	git clone --no-hardlinks . max-commits &&
+	(
+		cd max-commits &&
+		git config core.commitGraph true &&
+		test_line_count = 2 $graphdir/commit-graph-chain &&
+		test_commit 16 &&
+		test_commit 17 &&
+		git commit-graph write --reachable --split --max-commits=1 &&
+		test_line_count = 1 $graphdir/commit-graph-chain &&
+		ls $graphdir/graph-*.graph >graph-files &&
+		test_line_count = 1 graph-files
+	)
+'
+
+test_expect_success 'remove commit-graph-chain file after flattening' '
+	git clone . flatten &&
+	(
+		cd flatten &&
+		test_line_count = 2 $graphdir/commit-graph-chain &&
+		git commit-graph write --reachable &&
+		test_path_is_missing $graphdir/commit-graph-chain &&
+		ls $graphdir >graph-files &&
+		test_line_count = 0 graph-files
+	)
+'
+
+corrupt_file() {
+	file=$1
+	pos=$2
+	data="${3:-\0}"
+	chmod a+w "$file" &&
+	printf "$data" | dd of="$file" bs=1 seek="$pos" conv=notrunc
+}
+
+test_expect_success 'verify hashes along chain, even in shallow' '
+	git clone --no-hardlinks . verify &&
+	(
+		cd verify &&
+		git commit-graph verify &&
+		base_file=$graphdir/graph-$(head -n 1 $graphdir/commit-graph-chain).graph &&
+		corrupt_file "$base_file" 1760 "\01" &&
+		test_must_fail git commit-graph verify --shallow 2>test_err &&
+		grep -v "^+" test_err >err &&
+		test_i18ngrep "incorrect checksum" err
+	)
+'
+
+test_expect_success 'verify --shallow does not check base contents' '
+	git clone --no-hardlinks . verify-shallow &&
+	(
+		cd verify-shallow &&
+		git commit-graph verify &&
+		base_file=$graphdir/graph-$(head -n 1 $graphdir/commit-graph-chain).graph &&
+		corrupt_file "$base_file" 1000 "\01" &&
+		git commit-graph verify --shallow &&
+		test_must_fail git commit-graph verify 2>test_err &&
+		grep -v "^+" test_err >err &&
+		test_i18ngrep "incorrect checksum" err
+	)
+'
+
+test_expect_success 'warn on base graph chunk incorrect' '
+	git clone --no-hardlinks . base-chunk &&
+	(
+		cd base-chunk &&
+		git commit-graph verify &&
+		base_file=$graphdir/graph-$(tail -n 1 $graphdir/commit-graph-chain).graph &&
+		corrupt_file "$base_file" 1376 "\01" &&
+		git commit-graph verify --shallow 2>test_err &&
+		grep -v "^+" test_err >err &&
+		test_i18ngrep "commit-graph chain does not match" err
+	)
+'
+
+test_expect_success 'verify after commit-graph-chain corruption' '
+	git clone --no-hardlinks . verify-chain &&
+	(
+		cd verify-chain &&
+		corrupt_file "$graphdir/commit-graph-chain" 60 "G" &&
+		git commit-graph verify 2>test_err &&
+		grep -v "^+" test_err >err &&
+		test_i18ngrep "invalid commit-graph chain" err &&
+		corrupt_file "$graphdir/commit-graph-chain" 60 "A" &&
+		git commit-graph verify 2>test_err &&
+		grep -v "^+" test_err >err &&
+		test_i18ngrep "unable to find all commit-graph files" err
+	)
+'
+
+test_expect_success 'verify across alternates' '
+	git clone --no-hardlinks . verify-alt &&
+	(
+		cd verify-alt &&
+		rm -rf $graphdir &&
+		altdir="$(pwd)/../.git/objects" &&
+		echo "$altdir" >.git/objects/info/alternates &&
+		git commit-graph verify --object-dir="$altdir/" &&
+		test_commit extra &&
+		git commit-graph write --reachable --split &&
+		tip_file=$graphdir/graph-$(tail -n 1 $graphdir/commit-graph-chain).graph &&
+		corrupt_file "$tip_file" 100 "\01" &&
+		test_must_fail git commit-graph verify --shallow 2>test_err &&
+		grep -v "^+" test_err >err &&
+		test_i18ngrep "commit-graph has incorrect fanout value" err
+	)
+'
+
+test_expect_success 'add octopus merge' '
+	git reset --hard commits/10 &&
+	git merge commits/3 commits/4 &&
+	git branch merge/octopus &&
+	git commit-graph write --reachable --split &&
+	git commit-graph verify --progress 2>err &&
+	test_line_count = 3 err &&
+	test_i18ngrep ! warning err &&
+	test_line_count = 3 $graphdir/commit-graph-chain
+'
+
+graph_git_behavior 'graph exists' merge/octopus commits/12
+
+test_expect_success 'split across alternate where alternate is not split' '
+	git commit-graph write --reachable &&
+	test_path_is_file .git/objects/info/commit-graph &&
+	cp .git/objects/info/commit-graph . &&
+	git clone --no-hardlinks . alt-split &&
+	(
+		cd alt-split &&
+		rm -f .git/objects/info/commit-graph &&
+		echo "$(pwd)"/../.git/objects >.git/objects/info/alternates &&
+		test_commit 18 &&
+		git commit-graph write --reachable --split &&
+		test_line_count = 1 $graphdir/commit-graph-chain
+	) &&
+	test_cmp commit-graph .git/objects/info/commit-graph
+'
+
+test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t5400-send-pack.sh 1.2.3+git2.25.1-1/git/t/t5400-send-pack.sh
--- 1.2.1+git2.18.0-1/git/t/t5400-send-pack.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t5400-send-pack.sh	2020-02-17 04:47:35.000000000 +0000
@@ -86,7 +86,7 @@ test_expect_success 'push can be used to
 test_expect_success 'refuse deleting push with denyDeletes' '
 	(
 	    cd victim &&
-	    ( git branch -D extra || : ) &&
+	    test_might_fail git branch -D extra &&
 	    git config receive.denyDeletes true &&
 	    git branch extra master
 	) &&
@@ -119,7 +119,7 @@ test_expect_success 'override denyDelete
 test_expect_success 'denyNonFastforwards trumps --force' '
 	(
 	    cd victim &&
-	    ( git branch -D extra || : ) &&
+	    test_might_fail git branch -D extra &&
 	    git config receive.denyNonFastforwards true
 	) &&
 	victim_orig=$(cd victim && git rev-parse --verify master) &&
@@ -288,7 +288,7 @@ test_expect_success 'receive-pack de-dup
 	$shared .have
 	EOF
 
-	GIT_TRACE_PACKET=$(pwd)/trace \
+	GIT_TRACE_PACKET=$(pwd)/trace GIT_TEST_PROTOCOL_VERSION= \
 	    git push \
 		--receive-pack="unset GIT_TRACE_PACKET; git-receive-pack" \
 		fork HEAD:foo &&
diff -pruN 1.2.1+git2.18.0-1/git/t/t5401-update-hooks.sh 1.2.3+git2.25.1-1/git/t/t5401-update-hooks.sh
--- 1.2.1+git2.18.0-1/git/t/t5401-update-hooks.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t5401-update-hooks.sh	2020-02-17 04:47:35.000000000 +0000
@@ -82,13 +82,13 @@ test_expect_success 'hooks ran' '
 '
 
 test_expect_success 'pre-receive hook input' '
-	(echo $commit0 $commit1 refs/heads/master;
+	(echo $commit0 $commit1 refs/heads/master &&
 	 echo $commit1 $commit0 refs/heads/tofail
 	) | test_cmp - victim.git/pre-receive.stdin
 '
 
 test_expect_success 'update hook arguments' '
-	(echo refs/heads/master $commit0 $commit1;
+	(echo refs/heads/master $commit0 $commit1 &&
 	 echo refs/heads/tofail $commit1 $commit0
 	) | test_cmp - victim.git/update.args
 '
@@ -104,17 +104,17 @@ test_expect_success 'post-update hook ar
 '
 
 test_expect_success 'all hook stdin is /dev/null' '
-	! test -s victim.git/update.stdin &&
-	! test -s victim.git/post-update.stdin
+	test_must_be_empty victim.git/update.stdin &&
+	test_must_be_empty victim.git/post-update.stdin
 '
 
 test_expect_success 'all *-receive hook args are empty' '
-	! test -s victim.git/pre-receive.args &&
-	! test -s victim.git/post-receive.args
+	test_must_be_empty victim.git/pre-receive.args &&
+	test_must_be_empty victim.git/post-receive.args
 '
 
 test_expect_success 'send-pack produced no output' '
-	! test -s send.out
+	test_must_be_empty send.out
 '
 
 cat <<EOF >expect
diff -pruN 1.2.1+git2.18.0-1/git/t/t5403-post-checkout-hook.sh 1.2.3+git2.25.1-1/git/t/t5403-post-checkout-hook.sh
--- 1.2.1+git2.18.0-1/git/t/t5403-post-checkout-hook.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t5403-post-checkout-hook.sh	2020-02-17 04:47:35.000000000 +0000
@@ -7,82 +7,70 @@ test_description='Test the post-checkout
 . ./test-lib.sh
 
 test_expect_success setup '
-	echo Data for commit0. >a &&
-	echo Data for commit0. >b &&
-	git update-index --add a &&
-	git update-index --add b &&
-	tree0=$(git write-tree) &&
-	commit0=$(echo setup | git commit-tree $tree0) &&
-	git update-ref refs/heads/master $commit0 &&
-	git clone ./. clone1 &&
-	git clone ./. clone2 &&
-	GIT_DIR=clone2/.git git branch new2 &&
-	echo Data for commit1. >clone2/b &&
-	GIT_DIR=clone2/.git git add clone2/b &&
-	GIT_DIR=clone2/.git git commit -m new2
-'
-
-for clone in 1 2; do
-    cat >clone${clone}/.git/hooks/post-checkout <<'EOF'
-#!/bin/sh
-echo $@ > $GIT_DIR/post-checkout.args
-EOF
-    chmod u+x clone${clone}/.git/hooks/post-checkout
-done
-
-test_expect_success 'post-checkout runs as expected ' '
-	GIT_DIR=clone1/.git git checkout master &&
-	test -e clone1/.git/post-checkout.args
+	mkdir -p .git/hooks &&
+	write_script .git/hooks/post-checkout <<-\EOF &&
+	echo "$@" >.git/post-checkout.args
+	EOF
+	test_commit one &&
+	test_commit two &&
+	test_commit rebase-on-me &&
+	git reset --hard HEAD^ &&
+	test_commit three
 '
 
 test_expect_success 'post-checkout receives the right arguments with HEAD unchanged ' '
-	old=$(awk "{print \$1}" clone1/.git/post-checkout.args) &&
-	new=$(awk "{print \$2}" clone1/.git/post-checkout.args) &&
-	flag=$(awk "{print \$3}" clone1/.git/post-checkout.args) &&
+	test_when_finished "rm -f .git/post-checkout.args" &&
+	git checkout master &&
+	read old new flag <.git/post-checkout.args &&
 	test $old = $new && test $flag = 1
 '
 
-test_expect_success 'post-checkout runs as expected ' '
-	GIT_DIR=clone1/.git git checkout master &&
-	test -e clone1/.git/post-checkout.args
-'
-
 test_expect_success 'post-checkout args are correct with git checkout -b ' '
-	GIT_DIR=clone1/.git git checkout -b new1 &&
-	old=$(awk "{print \$1}" clone1/.git/post-checkout.args) &&
-	new=$(awk "{print \$2}" clone1/.git/post-checkout.args) &&
-	flag=$(awk "{print \$3}" clone1/.git/post-checkout.args) &&
+	test_when_finished "rm -f .git/post-checkout.args" &&
+	git checkout -b new1 &&
+	read old new flag <.git/post-checkout.args &&
 	test $old = $new && test $flag = 1
 '
 
 test_expect_success 'post-checkout receives the right args with HEAD changed ' '
-	GIT_DIR=clone2/.git git checkout new2 &&
-	old=$(awk "{print \$1}" clone2/.git/post-checkout.args) &&
-	new=$(awk "{print \$2}" clone2/.git/post-checkout.args) &&
-	flag=$(awk "{print \$3}" clone2/.git/post-checkout.args) &&
+	test_when_finished "rm -f .git/post-checkout.args" &&
+	git checkout two &&
+	read old new flag <.git/post-checkout.args &&
 	test $old != $new && test $flag = 1
 '
 
 test_expect_success 'post-checkout receives the right args when not switching branches ' '
-	GIT_DIR=clone2/.git git checkout master b &&
-	old=$(awk "{print \$1}" clone2/.git/post-checkout.args) &&
-	new=$(awk "{print \$2}" clone2/.git/post-checkout.args) &&
-	flag=$(awk "{print \$3}" clone2/.git/post-checkout.args) &&
+	test_when_finished "rm -f .git/post-checkout.args" &&
+	git checkout master -- three.t &&
+	read old new flag <.git/post-checkout.args &&
 	test $old = $new && test $flag = 0
 '
 
-if test "$(git config --bool core.filemode)" = true; then
-mkdir -p templates/hooks
-cat >templates/hooks/post-checkout <<'EOF'
-#!/bin/sh
-echo $@ > $GIT_DIR/post-checkout.args
-EOF
-chmod +x templates/hooks/post-checkout
+test_expect_success 'post-checkout is triggered on rebase' '
+	test_when_finished "rm -f .git/post-checkout.args" &&
+	git checkout -b rebase-test master &&
+	rm -f .git/post-checkout.args &&
+	git rebase rebase-on-me &&
+	read old new flag <.git/post-checkout.args &&
+	test $old != $new && test $flag = 1
+'
+
+test_expect_success 'post-checkout is triggered on rebase with fast-forward' '
+	test_when_finished "rm -f .git/post-checkout.args" &&
+	git checkout -b ff-rebase-test rebase-on-me^ &&
+	rm -f .git/post-checkout.args &&
+	git rebase rebase-on-me &&
+	read old new flag <.git/post-checkout.args &&
+	test $old != $new && test $flag = 1
+'
 
 test_expect_success 'post-checkout hook is triggered by clone' '
+	mkdir -p templates/hooks &&
+	write_script templates/hooks/post-checkout <<-\EOF &&
+	echo "$@" >"$GIT_DIR/post-checkout.args"
+	EOF
 	git clone --template=templates . clone3 &&
 	test -f clone3/.git/post-checkout.args
 '
-fi
 
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t5405-send-pack-rewind.sh 1.2.3+git2.25.1-1/git/t/t5405-send-pack-rewind.sh
--- 1.2.1+git2.18.0-1/git/t/t5405-send-pack-rewind.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t5405-send-pack-rewind.sh	2020-02-17 04:47:35.000000000 +0000
@@ -25,8 +25,7 @@ test_expect_success 'non forced push sho
 
 	(
 		cd another &&
-		git push .. master:master
-		test $? = 1
+		test_must_fail git push .. master:master
 	)
 
 '
diff -pruN 1.2.1+git2.18.0-1/git/t/t5406-remote-rejects.sh 1.2.3+git2.25.1-1/git/t/t5406-remote-rejects.sh
--- 1.2.1+git2.18.0-1/git/t/t5406-remote-rejects.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t5406-remote-rejects.sh	2020-02-17 04:47:35.000000000 +0000
@@ -6,8 +6,9 @@ test_description='remote push rejects ar
 
 test_expect_success 'setup' '
 	mkdir .git/hooks &&
-	(echo "#!/bin/sh" ; echo "exit 1") >.git/hooks/update &&
-	chmod +x .git/hooks/update &&
+	write_script .git/hooks/update <<-\EOF &&
+	exit 1
+	EOF
 	echo 1 >file &&
 	git add file &&
 	git commit -m 1 &&
diff -pruN 1.2.1+git2.18.0-1/git/t/t5407-post-rewrite-hook.sh 1.2.3+git2.25.1-1/git/t/t5407-post-rewrite-hook.sh
--- 1.2.1+git2.18.0-1/git/t/t5407-post-rewrite-hook.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t5407-post-rewrite-hook.sh	2020-02-17 04:47:35.000000000 +0000
@@ -78,6 +78,7 @@ test_expect_success 'git rebase --skip'
 	git rebase --continue &&
 	echo rebase >expected.args &&
 	cat >expected.data <<-EOF &&
+	$(git rev-parse C) $(git rev-parse HEAD^)
 	$(git rev-parse D) $(git rev-parse HEAD)
 	EOF
 	verify_hook_input
@@ -91,6 +92,7 @@ test_expect_success 'git rebase --skip t
 	echo rebase >expected.args &&
 	cat >expected.data <<-EOF &&
 	$(git rev-parse E) $(git rev-parse HEAD)
+	$(git rev-parse F) $(git rev-parse HEAD)
 	EOF
 	verify_hook_input
 '
@@ -113,13 +115,45 @@ test_expect_success 'git rebase -m' '
 test_expect_success 'git rebase -m --skip' '
 	git reset --hard D &&
 	clear_hook_input &&
-	test_must_fail git rebase --onto A B &&
+	test_must_fail git rebase -m --onto A B &&
+	test_must_fail git rebase --skip &&
+	echo D > foo &&
+	git add foo &&
+	git rebase --continue &&
+	echo rebase >expected.args &&
+	cat >expected.data <<-EOF &&
+	$(git rev-parse C) $(git rev-parse HEAD^)
+	$(git rev-parse D) $(git rev-parse HEAD)
+	EOF
+	verify_hook_input
+'
+
+test_expect_success 'git rebase with implicit use of interactive backend' '
+	git reset --hard D &&
+	clear_hook_input &&
+	test_must_fail git rebase --keep-empty --onto A B &&
+	echo C > foo &&
+	git add foo &&
+	git rebase --continue &&
+	echo rebase >expected.args &&
+	cat >expected.data <<-EOF &&
+	$(git rev-parse C) $(git rev-parse HEAD^)
+	$(git rev-parse D) $(git rev-parse HEAD)
+	EOF
+	verify_hook_input
+'
+
+test_expect_success 'git rebase --skip with implicit use of interactive backend' '
+	git reset --hard D &&
+	clear_hook_input &&
+	test_must_fail git rebase --keep-empty --onto A B &&
 	test_must_fail git rebase --skip &&
 	echo D > foo &&
 	git add foo &&
 	git rebase --continue &&
 	echo rebase >expected.args &&
 	cat >expected.data <<-EOF &&
+	$(git rev-parse C) $(git rev-parse HEAD^)
 	$(git rev-parse D) $(git rev-parse HEAD)
 	EOF
 	verify_hook_input
diff -pruN 1.2.1+git2.18.0-1/git/t/t5409-colorize-remote-messages.sh 1.2.3+git2.25.1-1/git/t/t5409-colorize-remote-messages.sh
--- 1.2.1+git2.18.0-1/git/t/t5409-colorize-remote-messages.sh	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t5409-colorize-remote-messages.sh	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,103 @@
+#!/bin/sh
+
+test_description='remote messages are colorized on the client'
+
+. ./test-lib.sh
+
+test_expect_success 'setup' '
+	mkdir .git/hooks &&
+	write_script .git/hooks/update <<-\EOF &&
+	echo error: error
+	echo ERROR: also highlighted
+	echo hint: hint
+	echo hinting: not highlighted
+	echo success: success
+	echo warning: warning
+	echo prefixerror: error
+	echo " " "error: leading space"
+	echo "    "
+	echo Err
+	echo SUCCESS
+	exit 0
+	EOF
+	echo 1 >file &&
+	git add file &&
+	git commit -m 1 &&
+	git clone . child &&
+	(
+		cd child &&
+		test_commit message2 file content2
+	)
+'
+
+test_expect_success 'keywords' '
+	git --git-dir child/.git -c color.remote=always push -f origin HEAD:refs/heads/keywords 2>output &&
+	test_decode_color <output >decoded &&
+	grep "<BOLD;RED>error<RESET>: error" decoded &&
+	grep "<YELLOW>hint<RESET>:" decoded &&
+	grep "<BOLD;GREEN>success<RESET>:" decoded &&
+	grep "<BOLD;GREEN>SUCCESS<RESET>" decoded &&
+	grep "<BOLD;YELLOW>warning<RESET>:" decoded
+'
+
+test_expect_success 'whole words at line start' '
+	git --git-dir child/.git -c color.remote=always push -f origin HEAD:refs/heads/whole-words 2>output &&
+	test_decode_color <output >decoded &&
+	grep "<YELLOW>hint<RESET>:" decoded &&
+	grep "hinting: not highlighted" decoded &&
+	grep "prefixerror: error" decoded
+'
+
+test_expect_success 'short line' '
+	git -C child -c color.remote=always push -f origin HEAD:short-line 2>output &&
+	test_decode_color <output >decoded &&
+	grep "remote: Err" decoded
+'
+
+test_expect_success 'case-insensitive' '
+	git --git-dir child/.git -c color.remote=always push -f origin HEAD:refs/heads/case-insensitive 2>output &&
+	cat output &&
+	test_decode_color <output >decoded &&
+	grep "<BOLD;RED>error<RESET>: error" decoded &&
+	grep "<BOLD;RED>ERROR<RESET>: also highlighted" decoded
+'
+
+test_expect_success 'leading space' '
+	git --git-dir child/.git -c color.remote=always push -f origin HEAD:refs/heads/leading-space 2>output &&        cat output &&
+	test_decode_color <output >decoded &&
+	grep "  <BOLD;RED>error<RESET>: leading space" decoded
+'
+
+test_expect_success 'spaces only' '
+	git -C child -c color.remote=always push -f origin HEAD:only-space 2>output &&
+	test_decode_color <output >decoded &&
+	grep "remote:     " decoded
+'
+
+test_expect_success 'no coloring for redirected output' '
+	git --git-dir child/.git push -f origin HEAD:refs/heads/redirected-output 2>output &&
+	test_decode_color <output >decoded &&
+	grep "error: error" decoded
+'
+
+test_expect_success 'push with customized color' '
+	git --git-dir child/.git -c color.remote=always -c color.remote.error=blue push -f origin HEAD:refs/heads/customized-color 2>output &&
+	test_decode_color <output >decoded &&
+	grep "<BLUE>error<RESET>:" decoded &&
+	grep "<BOLD;GREEN>success<RESET>:" decoded
+'
+
+
+test_expect_success 'error in customized color' '
+	git --git-dir child/.git -c color.remote=always -c color.remote.error=i-am-not-a-color push -f origin HEAD:refs/heads/error-customized-color 2>output &&
+	test_decode_color <output >decoded &&
+	grep "<BOLD;GREEN>success<RESET>:" decoded
+'
+
+test_expect_success 'fallback to color.ui' '
+	git --git-dir child/.git -c color.ui=always push -f origin HEAD:refs/heads/fallback-color-ui 2>output &&
+	test_decode_color <output >decoded &&
+	grep "<BOLD;RED>error<RESET>: error" decoded
+'
+
+test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t5410-receive-pack-alternates.sh 1.2.3+git2.25.1-1/git/t/t5410-receive-pack-alternates.sh
--- 1.2.1+git2.18.0-1/git/t/t5410-receive-pack-alternates.sh	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t5410-receive-pack-alternates.sh	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,41 @@
+#!/bin/sh
+
+test_description='git receive-pack with alternate ref filtering'
+
+. ./test-lib.sh
+
+test_expect_success 'setup' '
+	test_commit base &&
+	git clone -s --bare . fork &&
+	git checkout -b public/branch master &&
+	test_commit public &&
+	git checkout -b private/branch master &&
+	test_commit private
+'
+
+extract_haves () {
+	depacketize | perl -lne '/^(\S+) \.have/ and print $1'
+}
+
+test_expect_success 'with core.alternateRefsCommand' '
+	write_script fork/alternate-refs <<-\EOF &&
+		git --git-dir="$1" for-each-ref \
+			--format="%(objectname)" \
+			refs/heads/public/
+	EOF
+	test_config -C fork core.alternateRefsCommand ./alternate-refs &&
+	git rev-parse public/branch >expect &&
+	printf "0000" | git receive-pack fork >actual &&
+	extract_haves <actual >actual.haves &&
+	test_cmp expect actual.haves
+'
+
+test_expect_success 'with core.alternateRefsPrefixes' '
+	test_config -C fork core.alternateRefsPrefixes "refs/heads/private" &&
+	git rev-parse private/branch >expect &&
+	printf "0000" | git receive-pack fork >actual &&
+	extract_haves <actual >actual.haves &&
+	test_cmp expect actual.haves
+'
+
+test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t5500-fetch-pack.sh 1.2.3+git2.25.1-1/git/t/t5500-fetch-pack.sh
--- 1.2.1+git2.18.0-1/git/t/t5500-fetch-pack.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t5500-fetch-pack.sh	2020-02-17 04:47:35.000000000 +0000
@@ -50,8 +50,11 @@ pull_to_client () {
 			case "$heads" in *B*)
 			    git update-ref refs/heads/B "$BTIP";;
 			esac &&
-			git symbolic-ref HEAD refs/heads/$(echo $heads \
-				| sed -e "s/^\(.\).*$/\1/") &&
+
+			git symbolic-ref HEAD refs/heads/$(
+				echo $heads |
+				sed -e "s/^\(.\).*$/\1/"
+			) &&
 
 			git fsck --full &&
 
@@ -161,7 +164,7 @@ test_expect_success 'clone shallow objec
 test_expect_success 'clone shallow object count (part 2)' '
 	sed -e "/^in-pack:/d" -e "/^packs:/d" -e "/^size-pack:/d" \
 	    -e "/: 0$/d" count.shallow > count_output &&
-	! test -s count_output
+	test_must_be_empty count_output
 '
 
 test_expect_success 'fsck in shallow repo' '
@@ -259,7 +262,7 @@ test_expect_success 'clone shallow objec
 test_expect_success 'pull in shallow repo with missing merge base' '
 	(
 		cd shallow &&
-		git fetch --depth 4 .. A
+		git fetch --depth 4 .. A &&
 		test_must_fail git merge --allow-unrelated-histories FETCH_HEAD
 	)
 '
@@ -403,7 +406,7 @@ test_expect_success 'fetch creating new
 		git fetch --depth=1 --progress 2>actual &&
 		# This should fetch only the empty commit, no tree or
 		# blob objects
-		grep "remote: Total 1" actual
+		test_i18ngrep "remote: Total 1" actual
 	)
 '
 
@@ -436,15 +439,23 @@ test_expect_success 'setup tests for the
 	) >input.dup
 '
 
-test_expect_success 'fetch refs from cmdline' '
-	(
-		cd client &&
-		git fetch-pack --no-progress .. $(cat ../input)
-	) >output &&
-	cut -d " " -f 2 <output | sort >actual &&
-	test_cmp expect actual
+test_expect_success 'setup fetch refs from cmdline v[12]' '
+	cp -r client client1 &&
+	cp -r client client2
 '
 
+for version in '' 1 2
+do
+	test_expect_success "protocol.version=$version fetch refs from cmdline" "
+		(
+			cd client$version &&
+			GIT_TEST_PROTOCOL_VERSION=$version git fetch-pack --no-progress .. \$(cat ../input)
+		) >output &&
+		cut -d ' ' -f 2 <output | sort >actual &&
+		test_cmp expect actual
+	"
+done
+
 test_expect_success 'fetch refs from stdin' '
 	(
 		cd client &&
@@ -518,6 +529,54 @@ test_expect_success 'test --all, --depth
 	) >out-adt 2>error-adt
 '
 
+test_expect_success 'test --all with tag to non-tip' '
+	git commit --allow-empty -m non-tip &&
+	git commit --allow-empty -m tip &&
+	git tag -m "annotated" non-tip HEAD^ &&
+	(
+		cd client &&
+		git fetch-pack --all ..
+	)
+'
+
+test_expect_success 'test --all wrt tag to non-commits' '
+	# create tag-to-{blob,tree,commit,tag}, making sure all tagged objects
+	# are reachable only via created tag references.
+	blob=$(echo "hello blob" | git hash-object -t blob -w --stdin) &&
+	git tag -a -m "tag -> blob" tag-to-blob $blob &&
+
+	tree=$(printf "100644 blob $blob\tfile" | git mktree) &&
+	git tag -a -m "tag -> tree" tag-to-tree $tree &&
+
+	tree2=$(printf "100644 blob $blob\tfile2" | git mktree) &&
+	commit=$(git commit-tree -m "hello commit" $tree) &&
+	git tag -a -m "tag -> commit" tag-to-commit $commit &&
+
+	blob2=$(echo "hello blob2" | git hash-object -t blob -w --stdin) &&
+	tag=$(git mktag <<-EOF
+		object $blob2
+		type blob
+		tag tag-to-blob2
+		tagger author A U Thor <author@example.com> 0 +0000
+
+		hello tag
+	EOF
+	) &&
+	git tag -a -m "tag -> tag" tag-to-tag $tag &&
+
+	# `fetch-pack --all` should succeed fetching all those objects.
+	mkdir fetchall &&
+	(
+		cd fetchall &&
+		git init &&
+		git fetch-pack --all .. &&
+		git cat-file blob $blob >/dev/null &&
+		git cat-file tree $tree >/dev/null &&
+		git cat-file commit $commit >/dev/null &&
+		git cat-file tag $tag >/dev/null
+	)
+'
+
 test_expect_success 'shallow fetch with tags does not break the repository' '
 	mkdir repo1 &&
 	(
@@ -577,7 +636,9 @@ test_expect_success 'fetch-pack cannot f
 	test_commit -C server 6 &&
 
 	git init client &&
-	test_must_fail git -C client fetch-pack ../server \
+	# Some protocol versions (e.g. 2) support fetching
+	# unadvertised objects, so restrict this test to v0.
+	test_must_fail env GIT_TEST_PROTOCOL_VERSION= git -C client fetch-pack ../server \
 		$(git -C server rev-parse refs/heads/master^) 2>err &&
 	test_i18ngrep "Server does not allow request for unadvertised object" err
 '
@@ -647,13 +708,22 @@ do
 	# file with scheme
 	for p in file
 	do
-		test_expect_success "fetch-pack --diag-url $p://$h/$r" '
+		test_expect_success !MINGW "fetch-pack --diag-url $p://$h/$r" '
 			check_prot_path $p://$h/$r $p "/$r"
 		'
+		test_expect_success MINGW "fetch-pack --diag-url $p://$h/$r" '
+			check_prot_path $p://$h/$r $p "//$h/$r"
+		'
+		test_expect_success MINGW "fetch-pack --diag-url $p:///$r" '
+			check_prot_path $p:///$r $p "/$r"
+		'
 		# No "/~" -> "~" conversion for file
-		test_expect_success "fetch-pack --diag-url $p://$h/~$r" '
+		test_expect_success !MINGW "fetch-pack --diag-url $p://$h/~$r" '
 			check_prot_path $p://$h/~$r $p "/~$r"
 		'
+		test_expect_success MINGW "fetch-pack --diag-url $p://$h/~$r" '
+			check_prot_path $p://$h/~$r $p "//$h/~$r"
+		'
 	done
 	# file without scheme
 	for h in nohost nohost:12 [::1] [::1]:23 [ [:aa
@@ -711,6 +781,55 @@ test_expect_success 'fetch shallow since
 	test_cmp expected actual
 '
 
+test_expect_success 'clone shallow since selects no commits' '
+	test_create_repo shallow-since-the-future &&
+	(
+	cd shallow-since-the-future &&
+	GIT_COMMITTER_DATE="100000000 +0700" git commit --allow-empty -m one &&
+	GIT_COMMITTER_DATE="200000000 +0700" git commit --allow-empty -m two &&
+	GIT_COMMITTER_DATE="300000000 +0700" git commit --allow-empty -m three &&
+	test_must_fail git clone --shallow-since "900000000 +0700" "file://$(pwd)/." ../shallow111
+	)
+'
+
+# A few subtle things about the request in this test:
+#
+#  - the server must have commit-graphs present and enabled
+#
+#  - the history is such that our want/have share a common ancestor ("base"
+#    here)
+#
+#  - we send only a single have, which is fewer than a normal client would
+#    send. This ensures that we don't parse "base" up front with
+#    parse_object(), but rather traverse to it as a parent while deciding if we
+#    can stop the "have" negotiation, and call parse_commit(). The former
+#    sees the actual object data and so always loads the three oid, whereas the
+#    latter will try to load it lazily.
+#
+#  - we must use protocol v2, because it handles the "have" negotiation before
+#    processing the shallow directives
+#
+test_expect_success 'shallow since with commit graph and already-seen commit' '
+	test_create_repo shallow-since-graph &&
+	(
+	cd shallow-since-graph &&
+	test_commit base &&
+	test_commit master &&
+	git checkout -b other HEAD^ &&
+	test_commit other &&
+	git commit-graph write --reachable &&
+	git config core.commitGraph true &&
+
+	GIT_PROTOCOL=version=2 git upload-pack . <<-EOF >/dev/null
+	0012command=fetch
+	00010013deepen-since 1
+	0032want $(git rev-parse other)
+	0032have $(git rev-parse master)
+	0000
+	EOF
+	)
+'
+
 test_expect_success 'shallow clone exclude tag two' '
 	test_create_repo shallow-exclude &&
 	(
@@ -755,6 +874,39 @@ test_expect_success 'fetching deepen' '
 	)
 '
 
+test_expect_success 'use ref advertisement to prune "have" lines sent' '
+	rm -rf server client &&
+	git init server &&
+	test_commit -C server both_have_1 &&
+	git -C server tag -d both_have_1 &&
+	test_commit -C server both_have_2 &&
+
+	git clone server client &&
+	test_commit -C server server_has &&
+	test_commit -C client client_has &&
+
+	# In both protocol v0 and v2, ensure that the parent of both_have_2 is
+	# not sent as a "have" line. The client should know that the server has
+	# both_have_2, so it only needs to inform the server that it has
+	# both_have_2, and the server can infer the rest.
+
+	rm -f trace &&
+	cp -r client clientv0 &&
+	GIT_TRACE_PACKET="$(pwd)/trace" git -C clientv0 \
+		fetch origin server_has both_have_2 &&
+	grep "have $(git -C client rev-parse client_has)" trace &&
+	grep "have $(git -C client rev-parse both_have_2)" trace &&
+	! grep "have $(git -C client rev-parse both_have_2^)" trace &&
+
+	rm -f trace &&
+	cp -r client clientv2 &&
+	GIT_TRACE_PACKET="$(pwd)/trace" git -C clientv2 -c protocol.version=2 \
+		fetch origin server_has both_have_2 &&
+	grep "have $(git -C client rev-parse client_has)" trace &&
+	grep "have $(git -C client rev-parse both_have_2)" trace &&
+	! grep "have $(git -C client rev-parse both_have_2^)" trace
+'
+
 test_expect_success 'filtering by size' '
 	rm -rf server client &&
 	test_create_repo server &&
@@ -815,7 +967,7 @@ test_expect_success 'fetch with --filter
 	fetch_filter_blob_limit_zero "$HTTPD_DOCUMENT_ROOT_PATH/server" "$HTTPD_URL/smart/server"
 '
 
-stop_httpd
-
+# DO NOT add non-httpd-specific tests here, because the last part of this
+# test script is only executed when httpd is available and enabled.
 
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t5503-tagfollow.sh 1.2.3+git2.25.1-1/git/t/t5503-tagfollow.sh
--- 1.2.1+git2.18.0-1/git/t/t5503-tagfollow.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t5503-tagfollow.sh	2020-02-17 04:47:35.000000000 +0000
@@ -47,7 +47,7 @@ get_needs () {
 	test -s "$1" &&
 	perl -alne '
 		next unless $F[1] eq "upload-pack<";
-		last if $F[2] eq "0000";
+		next unless $F[2] eq "want";
 		print $F[2], " ", $F[3];
 	' "$1"
 }
diff -pruN 1.2.1+git2.18.0-1/git/t/t5504-fetch-receive-strict.sh 1.2.3+git2.25.1-1/git/t/t5504-fetch-receive-strict.sh
--- 1.2.1+git2.18.0-1/git/t/t5504-fetch-receive-strict.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t5504-fetch-receive-strict.sh	2020-02-17 04:47:35.000000000 +0000
@@ -3,13 +3,16 @@
 test_description='fetch/receive strict mode'
 . ./test-lib.sh
 
-test_expect_success setup '
+test_expect_success 'setup and inject "corrupt or missing" object' '
 	echo hello >greetings &&
 	git add greetings &&
 	git commit -m greetings &&
 
 	S=$(git rev-parse :greetings | sed -e "s|^..|&/|") &&
 	X=$(echo bye | git hash-object -w --stdin | sed -e "s|^..|&/|") &&
+	echo $S >S &&
+	echo $X >X &&
+	cp .git/objects/$S .git/objects/$S.back &&
 	mv -f .git/objects/$X .git/objects/$S &&
 
 	test_must_fail git fsck
@@ -115,6 +118,13 @@ test_expect_success 'push with transfer.
 	test_cmp exp act
 '
 
+test_expect_success 'repair the "corrupt or missing" object' '
+	mv -f .git/objects/$(cat S) .git/objects/$(cat X) &&
+	mv .git/objects/$(cat S).back .git/objects/$(cat S) &&
+	rm -rf .git/objects/$(cat X) &&
+	git fsck
+'
+
 cat >bogus-commit <<EOF
 tree $EMPTY_TREE
 author Bugs Bunny 1234567890 +0000
@@ -123,38 +133,199 @@ committer Bugs Bunny <bugs@bun.ni> 12345
 This commit object intentionally broken
 EOF
 
+test_expect_success 'setup bogus commit' '
+	commit="$(git hash-object -t commit -w --stdin <bogus-commit)"
+'
+
+test_expect_success 'fsck with no skipList input' '
+	test_must_fail git fsck 2>err &&
+	test_i18ngrep "missingEmail" err
+'
+
+test_expect_success 'setup sorted and unsorted skipLists' '
+	cat >SKIP.unsorted <<-EOF &&
+	0000000000000000000000000000000000000004
+	0000000000000000000000000000000000000002
+	$commit
+	0000000000000000000000000000000000000001
+	0000000000000000000000000000000000000003
+	EOF
+	sort SKIP.unsorted >SKIP.sorted
+'
+
+test_expect_success 'fsck with sorted skipList' '
+	git -c fsck.skipList=SKIP.sorted fsck
+'
+
+test_expect_success 'fsck with unsorted skipList' '
+	git -c fsck.skipList=SKIP.unsorted fsck
+'
+
+test_expect_success 'fsck with invalid or bogus skipList input' '
+	git -c fsck.skipList=/dev/null -c fsck.missingEmail=ignore fsck &&
+	test_must_fail git -c fsck.skipList=does-not-exist -c fsck.missingEmail=ignore fsck 2>err &&
+	test_i18ngrep "could not open.*: does-not-exist" err &&
+	test_must_fail git -c fsck.skipList=.git/config -c fsck.missingEmail=ignore fsck 2>err &&
+	test_i18ngrep "invalid object name: \[core\]" err
+'
+
+test_expect_success 'fsck with other accepted skipList input (comments & empty lines)' '
+	cat >SKIP.with-comment <<-EOF &&
+	# Some bad commit
+	0000000000000000000000000000000000000001
+	EOF
+	test_must_fail git -c fsck.skipList=SKIP.with-comment fsck 2>err-with-comment &&
+	test_i18ngrep "missingEmail" err-with-comment &&
+	cat >SKIP.with-empty-line <<-EOF &&
+	0000000000000000000000000000000000000001
+
+	0000000000000000000000000000000000000002
+	EOF
+	test_must_fail git -c fsck.skipList=SKIP.with-empty-line fsck 2>err-with-empty-line &&
+	test_i18ngrep "missingEmail" err-with-empty-line
+'
+
+test_expect_success 'fsck no garbage output from comments & empty lines errors' '
+	test_line_count = 1 err-with-comment &&
+	test_line_count = 1 err-with-empty-line
+'
+
+test_expect_success 'fsck with invalid abbreviated skipList input' '
+	echo $commit | test_copy_bytes 20 >SKIP.abbreviated &&
+	test_must_fail git -c fsck.skipList=SKIP.abbreviated fsck 2>err-abbreviated &&
+	test_i18ngrep "^fatal: invalid object name: " err-abbreviated
+'
+
+test_expect_success 'fsck with exhaustive accepted skipList input (various types of comments etc.)' '
+	>SKIP.exhaustive &&
+	echo "# A commented line" >>SKIP.exhaustive &&
+	echo "" >>SKIP.exhaustive &&
+	echo " " >>SKIP.exhaustive &&
+	echo " # Comment after whitespace" >>SKIP.exhaustive &&
+	echo "$commit # Our bad commit (with leading whitespace and trailing comment)" >>SKIP.exhaustive &&
+	echo "# Some bad commit (leading whitespace)" >>SKIP.exhaustive &&
+	echo "  0000000000000000000000000000000000000001" >>SKIP.exhaustive &&
+	git -c fsck.skipList=SKIP.exhaustive fsck 2>err &&
+	test_must_be_empty err
+'
+
 test_expect_success 'push with receive.fsck.skipList' '
-	commit="$(git hash-object -t commit -w --stdin <bogus-commit)" &&
 	git push . $commit:refs/heads/bogus &&
 	rm -rf dst &&
 	git init dst &&
 	git --git-dir=dst/.git config receive.fsckObjects true &&
 	test_must_fail git push --porcelain dst bogus &&
-	git --git-dir=dst/.git config receive.fsck.skipList SKIP &&
 	echo $commit >dst/.git/SKIP &&
+
+	# receive.fsck.* does not fall back on fsck.*
+	git --git-dir=dst/.git config fsck.skipList SKIP &&
+	test_must_fail git push --porcelain dst bogus &&
+
+	# Invalid and/or bogus skipList input
+	git --git-dir=dst/.git config receive.fsck.skipList /dev/null &&
+	test_must_fail git push --porcelain dst bogus &&
+	git --git-dir=dst/.git config receive.fsck.skipList does-not-exist &&
+	test_must_fail git push --porcelain dst bogus 2>err &&
+	test_i18ngrep "could not open.*: does-not-exist" err &&
+	git --git-dir=dst/.git config receive.fsck.skipList config &&
+	test_must_fail git push --porcelain dst bogus 2>err &&
+	test_i18ngrep "invalid object name: \[core\]" err &&
+
+	git --git-dir=dst/.git config receive.fsck.skipList SKIP &&
 	git push --porcelain dst bogus
 '
 
+test_expect_success 'fetch with fetch.fsck.skipList' '
+	refspec=refs/heads/bogus:refs/heads/bogus &&
+	git push . $commit:refs/heads/bogus &&
+	rm -rf dst &&
+	git init dst &&
+	git --git-dir=dst/.git config fetch.fsckObjects true &&
+	test_must_fail git --git-dir=dst/.git fetch "file://$(pwd)" $refspec &&
+	git --git-dir=dst/.git config fetch.fsck.skipList /dev/null &&
+	test_must_fail git --git-dir=dst/.git fetch "file://$(pwd)" $refspec &&
+	echo $commit >dst/.git/SKIP &&
+
+	# fetch.fsck.* does not fall back on fsck.*
+	git --git-dir=dst/.git config fsck.skipList dst/.git/SKIP &&
+	test_must_fail git --git-dir=dst/.git fetch "file://$(pwd)" $refspec &&
+
+	# Invalid and/or bogus skipList input
+	git --git-dir=dst/.git config fetch.fsck.skipList /dev/null &&
+	test_must_fail git --git-dir=dst/.git fetch "file://$(pwd)" $refspec &&
+	git --git-dir=dst/.git config fetch.fsck.skipList does-not-exist &&
+	test_must_fail git --git-dir=dst/.git fetch "file://$(pwd)" $refspec 2>err &&
+	test_i18ngrep "could not open.*: does-not-exist" err &&
+	git --git-dir=dst/.git config fetch.fsck.skipList dst/.git/config &&
+	test_must_fail git --git-dir=dst/.git fetch "file://$(pwd)" $refspec 2>err &&
+	test_i18ngrep "invalid object name: \[core\]" err &&
+
+	git --git-dir=dst/.git config fetch.fsck.skipList dst/.git/SKIP &&
+	git --git-dir=dst/.git fetch "file://$(pwd)" $refspec
+'
+
+test_expect_success 'fsck.<unknownmsg-id> dies' '
+	test_must_fail git -c fsck.whatEver=ignore fsck 2>err &&
+	test_i18ngrep "Unhandled message id: whatever" err
+'
+
 test_expect_success 'push with receive.fsck.missingEmail=warn' '
-	commit="$(git hash-object -t commit -w --stdin <bogus-commit)" &&
 	git push . $commit:refs/heads/bogus &&
 	rm -rf dst &&
 	git init dst &&
 	git --git-dir=dst/.git config receive.fsckobjects true &&
 	test_must_fail git push --porcelain dst bogus &&
+
+	# receive.fsck.<msg-id> does not fall back on fsck.<msg-id>
+	git --git-dir=dst/.git config fsck.missingEmail warn &&
+	test_must_fail git push --porcelain dst bogus &&
+
+	# receive.fsck.<unknownmsg-id> warns
+	git --git-dir=dst/.git config \
+		receive.fsck.whatEver error &&
+
 	git --git-dir=dst/.git config \
 		receive.fsck.missingEmail warn &&
 	git push --porcelain dst bogus >act 2>&1 &&
 	grep "missingEmail" act &&
+	test_i18ngrep "Skipping unknown msg id.*whatever" act &&
 	git --git-dir=dst/.git branch -D bogus &&
 	git --git-dir=dst/.git config --add \
 		receive.fsck.missingEmail ignore &&
-	git --git-dir=dst/.git config --add \
-		receive.fsck.badDate warn &&
 	git push --porcelain dst bogus >act 2>&1 &&
 	! grep "missingEmail" act
 '
 
+test_expect_success 'fetch with fetch.fsck.missingEmail=warn' '
+	refspec=refs/heads/bogus:refs/heads/bogus &&
+	git push . $commit:refs/heads/bogus &&
+	rm -rf dst &&
+	git init dst &&
+	git --git-dir=dst/.git config fetch.fsckobjects true &&
+	test_must_fail git --git-dir=dst/.git fetch "file://$(pwd)" $refspec &&
+
+	# fetch.fsck.<msg-id> does not fall back on fsck.<msg-id>
+	git --git-dir=dst/.git config fsck.missingEmail warn &&
+	test_must_fail git --git-dir=dst/.git fetch "file://$(pwd)" $refspec &&
+
+	# receive.fsck.<unknownmsg-id> warns
+	git --git-dir=dst/.git config \
+		fetch.fsck.whatEver error &&
+
+	git --git-dir=dst/.git config \
+		fetch.fsck.missingEmail warn &&
+	git --git-dir=dst/.git fetch "file://$(pwd)" $refspec >act 2>&1 &&
+	grep "missingEmail" act &&
+	test_i18ngrep "Skipping unknown msg id.*whatever" act &&
+	rm -rf dst &&
+	git init dst &&
+	git --git-dir=dst/.git config fetch.fsckobjects true &&
+	git --git-dir=dst/.git config \
+		fetch.fsck.missingEmail ignore &&
+	git --git-dir=dst/.git fetch "file://$(pwd)" $refspec >act 2>&1 &&
+	! grep "missingEmail" act
+'
+
 test_expect_success \
 	'receive.fsck.unterminatedHeader=warn triggers error' '
 	rm -rf dst &&
@@ -166,4 +337,15 @@ test_expect_success \
 	grep "Cannot demote unterminatedheader" act
 '
 
+test_expect_success \
+	'fetch.fsck.unterminatedHeader=warn triggers error' '
+	rm -rf dst &&
+	git init dst &&
+	git --git-dir=dst/.git config fetch.fsckobjects true &&
+	git --git-dir=dst/.git config \
+		fetch.fsck.unterminatedheader warn &&
+	test_must_fail git --git-dir=dst/.git fetch "file://$(pwd)" HEAD &&
+	grep "Cannot demote unterminatedheader" act
+'
+
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t5505-remote.sh 1.2.3+git2.25.1-1/git/t/t5505-remote.sh
--- 1.2.1+git2.18.0-1/git/t/t5505-remote.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t5505-remote.sh	2020-02-17 04:47:35.000000000 +0000
@@ -74,8 +74,7 @@ test_expect_success 'add another remote'
 		git for-each-ref "--format=%(refname)" refs/remotes |
 		sed -e "/^refs\/remotes\/origin\//d" \
 		    -e "/^refs\/remotes\/second\//d" >actual &&
-		>expect &&
-		test_cmp expect actual
+		test_must_be_empty actual
 	)
 '
 
@@ -112,8 +111,7 @@ test_expect_success C_LOCALE_OUTPUT 'rem
 		check_remote_track origin master side &&
 		git for-each-ref "--format=%(refname)" refs/remotes |
 		sed -e "/^refs\/remotes\/origin\//d" >actual &&
-		>expect &&
-		test_cmp expect actual
+		test_must_be_empty actual
 	)
 '
 
@@ -147,7 +145,7 @@ test_expect_success 'remove remote prote
 test_expect_success 'remove errors out early when deleting non-existent branch' '
 	(
 		cd test &&
-		echo "fatal: No such remote: foo" >expect &&
+		echo "fatal: No such remote: '\''foo'\''" >expect &&
 		test_must_fail git remote rm foo 2>actual &&
 		test_i18ncmp expect actual
 	)
@@ -175,7 +173,7 @@ test_expect_success 'remove remote with
 test_expect_success 'rename errors out early when deleting non-existent branch' '
 	(
 		cd test &&
-		echo "fatal: No such remote: foo" >expect &&
+		echo "fatal: No such remote: '\''foo'\''" >expect &&
 		test_must_fail git remote rename foo bar 2>actual &&
 		test_i18ncmp expect actual
 	)
@@ -348,17 +346,13 @@ URL: $(pwd)/one
 EOF
 
 test_expect_success 'prune --dry-run' '
-	(
-		cd one &&
-		git branch -m side2 side) &&
+	git -C one branch -m side2 side &&
+	test_when_finished "git -C one branch -m side side2" &&
 	(
 		cd test &&
 		git remote prune --dry-run origin >output &&
 		git rev-parse refs/remotes/origin/side2 &&
 		test_must_fail git rev-parse refs/remotes/origin/side &&
-	(
-		cd ../one &&
-		git branch -m side side2) &&
 		test_i18ncmp expect output
 	)
 '
@@ -848,7 +842,7 @@ test_expect_success 'migrate a remote fr
 		git remote rename origin origin &&
 		test_path_is_missing .git/branches/origin &&
 		test "$(git config remote.origin.url)" = "quux" &&
-		test "$(git config remote.origin.fetch)" = "refs/heads/foom:refs/heads/origin"
+		test "$(git config remote.origin.fetch)" = "refs/heads/foom:refs/heads/origin" &&
 		test "$(git config remote.origin.push)" = "HEAD:refs/heads/foom"
 	)
 '
@@ -876,7 +870,7 @@ test_expect_success 'remote prune to cau
 		cd eight &&
 		test_must_fail git branch nomore origin
 	) 2>err &&
-	grep "dangling symref" err
+	test_i18ngrep "dangling symref" err
 '
 
 test_expect_success 'show empty remote' '
@@ -1228,4 +1222,59 @@ test_expect_success 'add remote matching
 	git remote add backup xyz@example.com
 '
 
+test_expect_success 'unqualified <dst> refspec DWIM and advice' '
+	test_when_finished "(cd test && git tag -d some-tag)" &&
+	(
+		cd test &&
+		git tag -a -m "Some tag" some-tag master &&
+		exit_with=true &&
+		for type in commit tag tree blob
+		do
+			if test "$type" = "blob"
+			then
+				oid=$(git rev-parse some-tag:file)
+			else
+				oid=$(git rev-parse some-tag^{$type})
+			fi &&
+			test_must_fail git push origin $oid:dst 2>err &&
+			test_i18ngrep "error: The destination you" err &&
+			test_i18ngrep "hint: Did you mean" err &&
+			test_must_fail git -c advice.pushUnqualifiedRefName=false \
+				push origin $oid:dst 2>err &&
+			test_i18ngrep "error: The destination you" err &&
+			test_i18ngrep ! "hint: Did you mean" err ||
+			exit_with=false
+		done &&
+		$exit_with
+	)
+'
+
+test_expect_success 'refs/remotes/* <src> refspec and unqualified <dst> DWIM and advice' '
+	(
+		cd two &&
+		git tag -a -m "Some tag" my-tag master &&
+		git update-ref refs/trees/my-head-tree HEAD^{tree} &&
+		git update-ref refs/blobs/my-file-blob HEAD:file
+	) &&
+	(
+		cd test &&
+		git config --add remote.two.fetch "+refs/tags/*:refs/remotes/tags-from-two/*" &&
+		git config --add remote.two.fetch "+refs/trees/*:refs/remotes/trees-from-two/*" &&
+		git config --add remote.two.fetch "+refs/blobs/*:refs/remotes/blobs-from-two/*" &&
+		git fetch --no-tags two &&
+
+		test_must_fail git push origin refs/remotes/two/another:dst 2>err &&
+		test_i18ngrep "error: The destination you" err &&
+
+		test_must_fail git push origin refs/remotes/tags-from-two/my-tag:dst-tag 2>err &&
+		test_i18ngrep "error: The destination you" err &&
+
+		test_must_fail git push origin refs/remotes/trees-from-two/my-head-tree:dst-tree 2>err &&
+		test_i18ngrep "error: The destination you" err &&
+
+		test_must_fail git push origin refs/remotes/blobs-from-two/my-file-blob:dst-blob 2>err &&
+		test_i18ngrep "error: The destination you" err
+	)
+'
+
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t5509-fetch-push-namespaces.sh 1.2.3+git2.25.1-1/git/t/t5509-fetch-push-namespaces.sh
--- 1.2.1+git2.18.0-1/git/t/t5509-fetch-push-namespaces.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t5509-fetch-push-namespaces.sh	2020-02-17 04:47:35.000000000 +0000
@@ -44,7 +44,7 @@ test_expect_success 'pushing into a repo
 		test_cmp expected actual &&
 		# Try a namespace with no content
 		git ls-remote "ext::git --namespace=garbage %s ../pushee" >actual &&
-		test_cmp /dev/null actual &&
+		test_must_be_empty actual &&
 		git ls-remote pushee-unnamespaced >actual &&
 		sed -e "s|refs/|refs/namespaces/namespace/refs/|" expected >expected.unnamespaced &&
 		test_cmp expected.unnamespaced actual
@@ -124,4 +124,32 @@ test_expect_success 'try to update a hid
 	test_must_fail git -C original push pushee-namespaced master
 '
 
+test_expect_success 'set up ambiguous HEAD' '
+	git init ambiguous &&
+	(
+		cd ambiguous &&
+		git commit --allow-empty -m foo &&
+		git update-ref refs/namespaces/ns/refs/heads/one HEAD &&
+		git update-ref refs/namespaces/ns/refs/heads/two HEAD &&
+		git symbolic-ref refs/namespaces/ns/HEAD \
+			refs/namespaces/ns/refs/heads/two
+	)
+'
+
+test_expect_success 'clone chooses correct HEAD (v0)' '
+	GIT_NAMESPACE=ns git -c protocol.version=0 \
+		clone ambiguous ambiguous-v0 &&
+	echo refs/heads/two >expect &&
+	git -C ambiguous-v0 symbolic-ref HEAD >actual &&
+	test_cmp expect actual
+'
+
+test_expect_success 'clone chooses correct HEAD (v2)' '
+	GIT_NAMESPACE=ns git -c protocol.version=2 \
+		clone ambiguous ambiguous-v2 &&
+	echo refs/heads/two >expect &&
+	git -C ambiguous-v2 symbolic-ref HEAD >actual &&
+	test_cmp expect actual
+'
+
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t5510-fetch.sh 1.2.3+git2.25.1-1/git/t/t5510-fetch.sh
--- 1.2.1+git2.18.0-1/git/t/t5510-fetch.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t5510-fetch.sh	2020-02-17 04:47:35.000000000 +0000
@@ -174,6 +174,30 @@ test_expect_success 'fetch --prune --tag
 	git rev-parse sometag
 '
 
+test_expect_success '--refmap="" ignores configured refspec' '
+	cd "$TRASH_DIRECTORY" &&
+	git clone "$D" remote-refs &&
+	git -C remote-refs rev-parse remotes/origin/master >old &&
+	git -C remote-refs update-ref refs/remotes/origin/master master~1 &&
+	git -C remote-refs rev-parse remotes/origin/master >new &&
+	git -C remote-refs fetch --refmap= origin "+refs/heads/*:refs/hidden/origin/*" &&
+	git -C remote-refs rev-parse remotes/origin/master >actual &&
+	test_cmp new actual &&
+	git -C remote-refs fetch origin &&
+	git -C remote-refs rev-parse remotes/origin/master >actual &&
+	test_cmp old actual
+'
+
+test_expect_success '--refmap="" and --prune' '
+	git -C remote-refs update-ref refs/remotes/origin/foo/otherbranch master &&
+	git -C remote-refs update-ref refs/hidden/foo/otherbranch master &&
+	git -C remote-refs fetch --prune --refmap="" origin +refs/heads/*:refs/hidden/* &&
+	git -C remote-refs rev-parse remotes/origin/foo/otherbranch &&
+	test_must_fail git -C remote-refs rev-parse refs/hidden/foo/otherbranch &&
+	git -C remote-refs fetch --prune origin &&
+	test_must_fail git -C remote-refs rev-parse remotes/origin/foo/otherbranch
+'
+
 test_expect_success 'fetch tags when there is no tags' '
 
     cd "$D" &&
@@ -535,6 +559,70 @@ test_expect_success "should be able to f
 	)
 '
 
+test_expect_success 'LHS of refspec follows ref disambiguation rules' '
+	mkdir lhs-ambiguous &&
+	(
+		cd lhs-ambiguous &&
+		git init server &&
+		test_commit -C server unwanted &&
+		test_commit -C server wanted &&
+
+		git init client &&
+
+		# Check a name coming after "refs" alphabetically ...
+		git -C server update-ref refs/heads/s wanted &&
+		git -C server update-ref refs/heads/refs/heads/s unwanted &&
+		git -C client fetch ../server +refs/heads/s:refs/heads/checkthis &&
+		git -C server rev-parse wanted >expect &&
+		git -C client rev-parse checkthis >actual &&
+		test_cmp expect actual &&
+
+		# ... and one before.
+		git -C server update-ref refs/heads/q wanted &&
+		git -C server update-ref refs/heads/refs/heads/q unwanted &&
+		git -C client fetch ../server +refs/heads/q:refs/heads/checkthis &&
+		git -C server rev-parse wanted >expect &&
+		git -C client rev-parse checkthis >actual &&
+		test_cmp expect actual &&
+
+		# Tags are preferred over branches like refs/{heads,tags}/*
+		git -C server update-ref refs/tags/t wanted &&
+		git -C server update-ref refs/heads/t unwanted &&
+		git -C client fetch ../server +t:refs/heads/checkthis &&
+		git -C server rev-parse wanted >expect &&
+		git -C client rev-parse checkthis >actual
+	)
+'
+
+test_expect_success 'fetch.writeCommitGraph' '
+	git clone three write &&
+	(
+		cd three &&
+		test_commit new
+	) &&
+	(
+		cd write &&
+		git -c fetch.writeCommitGraph fetch origin &&
+		test_path_is_file .git/objects/info/commit-graphs/commit-graph-chain
+	)
+'
+
+test_expect_success 'fetch.writeCommitGraph with submodules' '
+	git clone dups super &&
+	(
+		cd super &&
+		git submodule add "file://$TRASH_DIRECTORY/three" &&
+		git commit -m "add submodule"
+	) &&
+	git clone "super" super-clone &&
+	(
+		cd super-clone &&
+		rm -rf .git/objects/info &&
+		git -c fetch.writeCommitGraph=true fetch origin &&
+		test_path_is_file .git/objects/info/commit-graphs/commit-graph-chain
+	)
+'
+
 # configured prune tests
 
 set_config_tristate () {
@@ -613,7 +701,7 @@ test_configured_prune_type () {
 			git rev-parse --verify refs/tags/newtag
 		) &&
 
-		# now remove it
+		# now remove them
 		git branch -d newbranch &&
 		git tag -d newtag &&
 
@@ -828,9 +916,11 @@ test_expect_success 'fetching with auto-
 	test_commit test2 &&
 	(
 		cd auto-gc &&
+		git config fetch.unpackLimit 1 &&
 		git config gc.autoPackLimit 1 &&
 		git config gc.autoDetach false &&
 		GIT_ASK_YESNO="$D/askyesno" git fetch >fetch.out 2>&1 &&
+		test_i18ngrep "Auto packing the repository" fetch.out &&
 		! grep "Should I try again" fetch.out
 	)
 '
@@ -865,4 +955,106 @@ test_expect_success C_LOCALE_OUTPUT 'fet
 	test_cmp expect actual
 '
 
+test_expect_success '--no-show-forced-updates' '
+	mkdir forced-updates &&
+	(
+		cd forced-updates &&
+		git init &&
+		test_commit 1 &&
+		test_commit 2
+	) &&
+	git clone forced-updates forced-update-clone &&
+	git clone forced-updates no-forced-update-clone &&
+	git -C forced-updates reset --hard HEAD~1 &&
+	(
+		cd forced-update-clone &&
+		git fetch --show-forced-updates origin 2>output &&
+		test_i18ngrep "(forced update)" output
+	) &&
+	(
+		cd no-forced-update-clone &&
+		git fetch --no-show-forced-updates origin 2>output &&
+		test_i18ngrep ! "(forced update)" output
+	)
+'
+
+setup_negotiation_tip () {
+	SERVER="$1"
+	URL="$2"
+	USE_PROTOCOL_V2="$3"
+
+	rm -rf "$SERVER" client trace &&
+	git init "$SERVER" &&
+	test_commit -C "$SERVER" alpha_1 &&
+	test_commit -C "$SERVER" alpha_2 &&
+	git -C "$SERVER" checkout --orphan beta &&
+	test_commit -C "$SERVER" beta_1 &&
+	test_commit -C "$SERVER" beta_2 &&
+
+	git clone "$URL" client &&
+
+	if test "$USE_PROTOCOL_V2" -eq 1
+	then
+		git -C "$SERVER" config protocol.version 2 &&
+		git -C client config protocol.version 2
+	fi &&
+
+	test_commit -C "$SERVER" beta_s &&
+	git -C "$SERVER" checkout master &&
+	test_commit -C "$SERVER" alpha_s &&
+	git -C "$SERVER" tag -d alpha_1 alpha_2 beta_1 beta_2
+}
+
+check_negotiation_tip () {
+	# Ensure that {alpha,beta}_1 are sent as "have", but not {alpha_beta}_2
+	ALPHA_1=$(git -C client rev-parse alpha_1) &&
+	grep "fetch> have $ALPHA_1" trace &&
+	BETA_1=$(git -C client rev-parse beta_1) &&
+	grep "fetch> have $BETA_1" trace &&
+	ALPHA_2=$(git -C client rev-parse alpha_2) &&
+	! grep "fetch> have $ALPHA_2" trace &&
+	BETA_2=$(git -C client rev-parse beta_2) &&
+	! grep "fetch> have $BETA_2" trace
+}
+
+test_expect_success '--negotiation-tip limits "have" lines sent' '
+	setup_negotiation_tip server server 0 &&
+	GIT_TRACE_PACKET="$(pwd)/trace" git -C client fetch \
+		--negotiation-tip=alpha_1 --negotiation-tip=beta_1 \
+		origin alpha_s beta_s &&
+	check_negotiation_tip
+'
+
+test_expect_success '--negotiation-tip understands globs' '
+	setup_negotiation_tip server server 0 &&
+	GIT_TRACE_PACKET="$(pwd)/trace" git -C client fetch \
+		--negotiation-tip=*_1 \
+		origin alpha_s beta_s &&
+	check_negotiation_tip
+'
+
+test_expect_success '--negotiation-tip understands abbreviated SHA-1' '
+	setup_negotiation_tip server server 0 &&
+	GIT_TRACE_PACKET="$(pwd)/trace" git -C client fetch \
+		--negotiation-tip=$(git -C client rev-parse --short alpha_1) \
+		--negotiation-tip=$(git -C client rev-parse --short beta_1) \
+		origin alpha_s beta_s &&
+	check_negotiation_tip
+'
+
+. "$TEST_DIRECTORY"/lib-httpd.sh
+start_httpd
+
+test_expect_success '--negotiation-tip limits "have" lines sent with HTTP protocol v2' '
+	setup_negotiation_tip "$HTTPD_DOCUMENT_ROOT_PATH/server" \
+		"$HTTPD_URL/smart/server" 1 &&
+	GIT_TRACE_PACKET="$(pwd)/trace" git -C client fetch \
+		--negotiation-tip=alpha_1 --negotiation-tip=beta_1 \
+		origin alpha_s beta_s &&
+	check_negotiation_tip
+'
+
+# DO NOT add non-httpd-specific tests here, because the last part of this
+# test script is only executed when httpd is available and enabled.
+
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t5512-ls-remote.sh 1.2.3+git2.25.1-1/git/t/t5512-ls-remote.sh
--- 1.2.1+git2.18.0-1/git/t/t5512-ls-remote.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t5512-ls-remote.sh	2020-02-17 04:47:35.000000000 +0000
@@ -15,7 +15,7 @@ test_expect_success setup '
 	git tag mark1.10 &&
 	git show-ref --tags -d | sed -e "s/ /	/" >expected.tag &&
 	(
-		echo "$(git rev-parse HEAD)	HEAD"
+		echo "$(git rev-parse HEAD)	HEAD" &&
 		git show-ref -d	| sed -e "s/ /	/"
 	) >expected.all &&
 
@@ -105,7 +105,7 @@ test_expect_success 'use branch.<name>.r
 	git clone . other.git &&
 	(
 		cd other.git &&
-		echo "$(git rev-parse HEAD)	HEAD"
+		echo "$(git rev-parse HEAD)	HEAD" &&
 		git show-ref	| sed -e "s/ /	/"
 	) >exp &&
 
@@ -155,14 +155,12 @@ test_expect_success 'die with non-2 for
 
 test_expect_success 'Report success even when nothing matches' '
 	git ls-remote other.git "refs/nsn/*" >actual &&
-	>expect &&
-	test_cmp expect actual
+	test_must_be_empty actual
 '
 
 test_expect_success 'Report no-match with --exit-code' '
 	test_expect_code 2 git ls-remote --exit-code other.git "refs/nsn/*" >actual &&
-	>expect &&
-	test_cmp expect actual
+	test_must_be_empty actual
 '
 
 test_expect_success 'Report match with --exit-code' '
@@ -206,6 +204,12 @@ test_expect_success 'overrides work betw
 	grep refs/tags/magic actual
 '
 
+test_expect_success 'protocol v2 supports hiderefs' '
+	test_config uploadpack.hiderefs refs/tags &&
+	git -c protocol.version=2 ls-remote . >actual &&
+	! grep refs/tags actual
+'
+
 test_expect_success 'ls-remote --symref' '
 	git fetch origin &&
 	cat >expect <<-EOF &&
@@ -219,7 +223,9 @@ test_expect_success 'ls-remote --symref'
 	$(git rev-parse refs/tags/mark1.10)	refs/tags/mark1.10
 	$(git rev-parse refs/tags/mark1.2)	refs/tags/mark1.2
 	EOF
-	git ls-remote --symref >actual &&
+	# Protocol v2 supports sending symrefs for refs other than HEAD, so use
+	# protocol v0 here.
+	GIT_TEST_PROTOCOL_VERSION= git ls-remote --symref >actual &&
 	test_cmp expect actual
 '
 
@@ -228,7 +234,9 @@ test_expect_success 'ls-remote with filt
 	ref: refs/heads/master	HEAD
 	1bd44cb9d13204b0fe1958db0082f5028a16eb3a	HEAD
 	EOF
-	git ls-remote --symref . HEAD >actual &&
+	# Protocol v2 supports sending symrefs for refs other than HEAD, so use
+	# protocol v0 here.
+	GIT_TEST_PROTOCOL_VERSION= git ls-remote --symref . HEAD >actual &&
 	test_cmp expect actual
 '
 
@@ -239,7 +247,9 @@ test_expect_failure 'ls-remote with filt
 	1bd44cb9d13204b0fe1958db0082f5028a16eb3a	refs/heads/foo
 	1bd44cb9d13204b0fe1958db0082f5028a16eb3a	refs/heads/master
 	EOF
-	git ls-remote --symref --heads . >actual &&
+	# Protocol v2 supports sending symrefs for refs other than HEAD, so use
+	# protocol v0 here.
+	GIT_TEST_PROTOCOL_VERSION= git ls-remote --symref --heads . >actual &&
 	test_cmp expect actual
 '
 
@@ -248,21 +258,22 @@ test_expect_success 'ls-remote --symref
 	1bd44cb9d13204b0fe1958db0082f5028a16eb3a	refs/heads/foo
 	1bd44cb9d13204b0fe1958db0082f5028a16eb3a	refs/heads/master
 	EOF
-	git ls-remote --symref --heads . >actual &&
+	# Protocol v2 supports sending symrefs for refs other than HEAD, so use
+	# protocol v0 here.
+	GIT_TEST_PROTOCOL_VERSION= git ls-remote --symref --heads . >actual &&
 	test_cmp expect actual &&
-	git ls-remote --symref . "refs/heads/*" >actual &&
+	GIT_TEST_PROTOCOL_VERSION= git ls-remote --symref . "refs/heads/*" >actual &&
 	test_cmp expect actual
 '
 
 test_lazy_prereq GIT_DAEMON '
-	test_tristate GIT_TEST_GIT_DAEMON &&
-	test "$GIT_TEST_GIT_DAEMON" != false
+	test_bool_env GIT_TEST_GIT_DAEMON true
 '
 
 # This test spawns a daemon, so run it only if the user would be OK with
 # testing with git-daemon.
 test_expect_success PIPE,JGIT,GIT_DAEMON 'indicate no refs in standards-compliant empty remote' '
-	JGIT_DAEMON_PORT=${JGIT_DAEMON_PORT-${this_test#t}} &&
+	test_set_port JGIT_DAEMON_PORT &&
 	JGIT_DAEMON_PID= &&
 	git init --bare empty.git &&
 	>empty.git/git-daemon-export-ok &&
@@ -304,4 +315,28 @@ test_expect_success 'ls-remote works out
 	nongit git ls-remote dst.git
 '
 
+test_expect_success 'ls-remote --sort fails gracefully outside repository' '
+	# Use a sort key that requires access to the referenced objects.
+	nongit test_must_fail git ls-remote --sort=authordate "$TRASH_DIRECTORY" 2>err &&
+	test_i18ngrep "^fatal: not a git repository, but the field '\''authordate'\'' requires access to object data" err
+'
+
+test_expect_success 'ls-remote patterns work with all protocol versions' '
+	git for-each-ref --format="%(objectname)	%(refname)" \
+		refs/heads/master refs/remotes/origin/master >expect &&
+	git -c protocol.version=1 ls-remote . master >actual.v1 &&
+	test_cmp expect actual.v1 &&
+	git -c protocol.version=2 ls-remote . master >actual.v2 &&
+	test_cmp expect actual.v2
+'
+
+test_expect_success 'ls-remote prefixes work with all protocol versions' '
+	git for-each-ref --format="%(objectname)	%(refname)" \
+		refs/heads/ refs/tags/ >expect &&
+	git -c protocol.version=1 ls-remote --heads --tags . >actual.v1 &&
+	test_cmp expect actual.v1 &&
+	git -c protocol.version=2 ls-remote --heads --tags . >actual.v2 &&
+	test_cmp expect actual.v2
+'
+
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t5514-fetch-multiple.sh 1.2.3+git2.25.1-1/git/t/t5514-fetch-multiple.sh
--- 1.2.1+git2.18.0-1/git/t/t5514-fetch-multiple.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t5514-fetch-multiple.sh	2020-02-17 04:47:35.000000000 +0000
@@ -105,9 +105,12 @@ test_expect_success 'git fetch --multipl
 	 git remote rm origin &&
 	 git remote add one ../one &&
 	 git remote add two ../two &&
-	 git fetch --multiple one two &&
+	 GIT_TRACE=1 git fetch --multiple one two 2>trace &&
 	 git branch -r > output &&
-	 test_cmp ../expect output)
+	 test_cmp ../expect output &&
+	 grep "built-in: git gc" trace >gc &&
+	 test_line_count = 1 gc
+	)
 '
 
 test_expect_success 'git fetch --multiple (bad remote names)' '
@@ -152,7 +155,6 @@ test_expect_success 'git fetch --multipl
 '
 
 test_expect_success 'git fetch --all --no-tags' '
-	>expect &&
 	git clone one test5 &&
 	git clone test5 test6 &&
 	(cd test5 && git tag test-tag) &&
@@ -161,7 +163,7 @@ test_expect_success 'git fetch --all --n
 		git fetch --all --no-tags &&
 		git tag >output
 	) &&
-	test_cmp expect test6/output
+	test_must_be_empty test6/output
 '
 
 test_expect_success 'git fetch --all --tags' '
@@ -181,4 +183,15 @@ test_expect_success 'git fetch --all --t
 	test_cmp expect test8/output
 '
 
+test_expect_success 'parallel' '
+	git remote add one ./bogus1 &&
+	git remote add two ./bogus2 &&
+
+	test_must_fail env GIT_TRACE="$PWD/trace" \
+		git fetch --jobs=2 --multiple one two 2>err &&
+	grep "preparing to run up to 2 tasks" trace &&
+	test_i18ngrep "could not fetch .one.*128" err &&
+	test_i18ngrep "could not fetch .two.*128" err
+'
+
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t5515-fetch-merge-logic.sh 1.2.3+git2.25.1-1/git/t/t5515-fetch-merge-logic.sh
--- 1.2.1+git2.18.0-1/git/t/t5515-fetch-merge-logic.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t5515-fetch-merge-logic.sh	2020-02-17 04:47:35.000000000 +0000
@@ -6,10 +6,11 @@
 
 test_description='Merge logic in fetch'
 
-. ./test-lib.sh
+# NEEDSWORK: If the overspecification of the expected result is reduced, we
+# might be able to run this test in all protocol versions.
+GIT_TEST_PROTOCOL_VERSION=
 
-LF='
-'
+. ./test-lib.sh
 
 test_expect_success setup '
 	GIT_AUTHOR_DATE="2006-06-26 00:00:00 +0000" &&
diff -pruN 1.2.1+git2.18.0-1/git/t/t5516-fetch-push.sh 1.2.3+git2.25.1-1/git/t/t5516-fetch-push.sh
--- 1.2.1+git2.18.0-1/git/t/t5516-fetch-push.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t5516-fetch-push.sh	2020-02-17 04:47:35.000000000 +0000
@@ -95,7 +95,7 @@ mk_child() {
 
 check_push_result () {
 	test $# -ge 3 ||
-	error "bug in the test script: check_push_result requires at least 3 parameters"
+	BUG "check_push_result requires at least 3 parameters"
 
 	repo_name="$1"
 	shift
@@ -923,7 +923,7 @@ test_expect_success 'push into aliased r
 	(
 		cd child1 &&
 		git branch foo &&
-		git symbolic-ref refs/heads/bar refs/heads/foo
+		git symbolic-ref refs/heads/bar refs/heads/foo &&
 		git config receive.denyCurrentBranch false
 	) &&
 	(
@@ -945,7 +945,7 @@ test_expect_success 'push into aliased r
 	(
 		cd child1 &&
 		git branch foo &&
-		git symbolic-ref refs/heads/bar refs/heads/foo
+		git symbolic-ref refs/heads/bar refs/heads/foo &&
 		git config receive.denyCurrentBranch false
 	) &&
 	(
@@ -965,26 +965,76 @@ test_expect_success 'push into aliased r
 	)
 '
 
-test_expect_success 'push requires --force to update lightweight tag' '
-	mk_test testrepo heads/master &&
-	mk_child testrepo child1 &&
-	mk_child testrepo child2 &&
-	(
-		cd child1 &&
-		git tag Tag &&
-		git push ../child2 Tag &&
-		git push ../child2 Tag &&
-		>file1 &&
-		git add file1 &&
-		git commit -m "file1" &&
-		git tag -f Tag &&
-		test_must_fail git push ../child2 Tag &&
-		git push --force ../child2 Tag &&
-		git tag -f Tag &&
-		test_must_fail git push ../child2 Tag HEAD~ &&
-		git push --force ../child2 Tag
-	)
-'
+test_force_push_tag () {
+	tag_type_description=$1
+	tag_args=$2
+
+	test_expect_success "force pushing required to update $tag_type_description" "
+		mk_test testrepo heads/master &&
+		mk_child testrepo child1 &&
+		mk_child testrepo child2 &&
+		(
+			cd child1 &&
+			git tag testTag &&
+			git push ../child2 testTag &&
+			>file1 &&
+			git add file1 &&
+			git commit -m 'file1' &&
+			git tag $tag_args testTag &&
+			test_must_fail git push ../child2 testTag &&
+			git push --force ../child2 testTag &&
+			git tag $tag_args testTag HEAD~ &&
+			test_must_fail git push ../child2 testTag &&
+			git push --force ../child2 testTag &&
+
+			# Clobbering without + in refspec needs --force
+			git tag -f testTag &&
+			test_must_fail git push ../child2 'refs/tags/*:refs/tags/*' &&
+			git push --force ../child2 'refs/tags/*:refs/tags/*' &&
+
+			# Clobbering with + in refspec does not need --force
+			git tag -f testTag HEAD~ &&
+			git push ../child2 '+refs/tags/*:refs/tags/*' &&
+
+			# Clobbering with --no-force still obeys + in refspec
+			git tag -f testTag &&
+			git push --no-force ../child2 '+refs/tags/*:refs/tags/*' &&
+
+			# Clobbering with/without --force and 'tag <name>' format
+			git tag -f testTag HEAD~ &&
+			test_must_fail git push ../child2 tag testTag &&
+			git push --force ../child2 tag testTag
+		)
+	"
+}
+
+test_force_push_tag "lightweight tag" "-f"
+test_force_push_tag "annotated tag" "-f -a -m'tag message'"
+
+test_force_fetch_tag () {
+	tag_type_description=$1
+	tag_args=$2
+
+	test_expect_success "fetch will not clobber an existing $tag_type_description without --force" "
+		mk_test testrepo heads/master &&
+		mk_child testrepo child1 &&
+		mk_child testrepo child2 &&
+		(
+			cd testrepo &&
+			git tag testTag &&
+			git -C ../child1 fetch origin tag testTag &&
+			>file1 &&
+			git add file1 &&
+			git commit -m 'file1' &&
+			git tag $tag_args testTag &&
+			test_must_fail git -C ../child1 fetch origin tag testTag &&
+			git -C ../child1 fetch origin '+refs/tags/*:refs/tags/*'
+		)
+	"
+}
+
+test_force_fetch_tag "lightweight tag" "-f"
+test_force_fetch_tag "annotated tag" "-f -a -m'tag message'"
 
 test_expect_success 'push --porcelain' '
 	mk_empty testrepo &&
@@ -1011,7 +1061,7 @@ test_expect_success 'push --porcelain re
 	mk_empty testrepo &&
 	git push testrepo refs/heads/master:refs/remotes/origin/master &&
 	(cd testrepo &&
-		git reset --hard origin/master^
+		git reset --hard origin/master^ &&
 		git config receive.denyCurrentBranch true) &&
 
 	echo >.git/foo  "To testrepo"  &&
@@ -1025,7 +1075,7 @@ test_expect_success 'push --porcelain --
 	mk_empty testrepo &&
 	git push testrepo refs/heads/master:refs/remotes/origin/master &&
 	(cd testrepo &&
-		git reset --hard origin/master
+		git reset --hard origin/master &&
 		git config receive.denyCurrentBranch true) &&
 
 	echo >.git/foo  "To testrepo"  &&
@@ -1097,8 +1147,12 @@ test_expect_success 'fetch exact SHA1' '
 		git prune &&
 		test_must_fail git cat-file -t $the_commit &&
 
+		# Some protocol versions (e.g. 2) support fetching
+		# unadvertised objects, so restrict this test to v0.
+
 		# fetching the hidden object should fail by default
-		test_must_fail git fetch -v ../testrepo $the_commit:refs/heads/copy 2>err &&
+		test_must_fail env GIT_TEST_PROTOCOL_VERSION= \
+			git fetch -v ../testrepo $the_commit:refs/heads/copy 2>err &&
 		test_i18ngrep "Server does not allow request for unadvertised object" err &&
 		test_must_fail git rev-parse --verify refs/heads/copy &&
 
@@ -1154,7 +1208,10 @@ do
 		mk_empty shallow &&
 		(
 			cd shallow &&
-			test_must_fail git fetch --depth=1 ../testrepo/.git $SHA1 &&
+			# Some protocol versions (e.g. 2) support fetching
+			# unadvertised objects, so restrict this test to v0.
+			test_must_fail env GIT_TEST_PROTOCOL_VERSION= \
+				git fetch --depth=1 ../testrepo/.git $SHA1 &&
 			git --git-dir=../testrepo/.git config uploadpack.allowreachablesha1inwant true &&
 			git fetch --depth=1 ../testrepo/.git $SHA1 &&
 			git cat-file commit $SHA1
@@ -1182,15 +1239,21 @@ do
 		mk_empty shallow &&
 		(
 			cd shallow &&
-			test_must_fail ok=sigpipe git fetch ../testrepo/.git $SHA1_3 &&
-			test_must_fail ok=sigpipe git fetch ../testrepo/.git $SHA1_1 &&
+			# Some protocol versions (e.g. 2) support fetching
+			# unadvertised objects, so restrict this test to v0.
+			test_must_fail env GIT_TEST_PROTOCOL_VERSION= \
+				git fetch ../testrepo/.git $SHA1_3 &&
+			test_must_fail env GIT_TEST_PROTOCOL_VERSION= \
+				git fetch ../testrepo/.git $SHA1_1 &&
 			git --git-dir=../testrepo/.git config uploadpack.allowreachablesha1inwant true &&
 			git fetch ../testrepo/.git $SHA1_1 &&
 			git cat-file commit $SHA1_1 &&
 			test_must_fail git cat-file commit $SHA1_2 &&
 			git fetch ../testrepo/.git $SHA1_2 &&
 			git cat-file commit $SHA1_2 &&
-			test_must_fail ok=sigpipe git fetch ../testrepo/.git $SHA1_3
+			test_must_fail env GIT_TEST_PROTOCOL_VERSION= \
+				git fetch ../testrepo/.git $SHA1_3 2>err &&
+			test_i18ngrep "remote error:.*not our ref.*$SHA1_3\$" err
 		)
 	'
 done
@@ -1222,6 +1285,17 @@ test_expect_success 'fetch follows tags
 	test_cmp expect actual
 '
 
+test_expect_success 'peeled advertisements are not considered ref tips' '
+	mk_empty testrepo &&
+	git -C testrepo commit --allow-empty -m one &&
+	git -C testrepo commit --allow-empty -m two &&
+	git -C testrepo tag -m foo mytag HEAD^ &&
+	oid=$(git -C testrepo rev-parse mytag^{commit}) &&
+	test_must_fail env GIT_TEST_PROTOCOL_VERSION= \
+		git fetch testrepo $oid 2>err &&
+	test_i18ngrep "Server does not allow request for unadvertised object" err
+'
+
 test_expect_success 'pushing a specific ref applies remote.$name.push as refmap' '
 	mk_test testrepo heads/master &&
 	rm -fr src dst &&
@@ -1320,7 +1394,7 @@ test_expect_success 'push does not follo
 	test_cmp expect actual
 '
 
-test_expect_success 'push --follow-tag only pushes relevant tags' '
+test_expect_success 'push --follow-tags only pushes relevant tags' '
 	mk_test testrepo heads/master &&
 	rm -fr src dst &&
 	git init src &&
@@ -1333,8 +1407,8 @@ test_expect_success 'push --follow-tag o
 		git commit --allow-empty -m "future commit" &&
 		git tag -m "future" future &&
 		git checkout master &&
-		git for-each-ref refs/heads/master refs/tags/tag >../expect
-		git push --follow-tag ../dst master
+		git for-each-ref refs/heads/master refs/tags/tag >../expect &&
+		git push --follow-tags ../dst master
 	) &&
 	(
 		cd dst &&
@@ -1527,7 +1601,13 @@ test_expect_success 'receive.denyCurrent
 		test $(git -C .. rev-parse master) = $(git rev-parse HEAD) &&
 		git diff --quiet &&
 		git diff --cached --quiet
-	)
+	) &&
+
+	# (6) updateInstead intervened by fast-forward check
+	test_must_fail git push void master^:master &&
+	test $(git -C void rev-parse HEAD) = $(git rev-parse master) &&
+	git -C void diff --quiet &&
+	git -C void diff --cached --quiet
 '
 
 test_expect_success 'updateInstead with push-to-checkout hook' '
diff -pruN 1.2.1+git2.18.0-1/git/t/t5517-push-mirror.sh 1.2.3+git2.25.1-1/git/t/t5517-push-mirror.sh
--- 1.2.1+git2.18.0-1/git/t/t5517-push-mirror.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t5517-push-mirror.sh	2020-02-17 04:47:35.000000000 +0000
@@ -71,7 +71,7 @@ test_expect_success 'push mirror force u
 		git push --mirror up &&
 		echo two >foo && git add foo && git commit -m two &&
 		git push --mirror up &&
-		git reset --hard HEAD^
+		git reset --hard HEAD^ &&
 		git push --mirror up
 	) &&
 	master_master=$(cd master && git show-ref -s --verify refs/heads/master) &&
@@ -88,7 +88,7 @@ test_expect_success 'push mirror removes
 		echo one >foo && git add foo && git commit -m one &&
 		git branch remove master &&
 		git push --mirror up &&
-		git branch -D remove
+		git branch -D remove &&
 		git push --mirror up
 	) &&
 	(
@@ -170,7 +170,7 @@ test_expect_success 'push mirror force u
 		echo two >foo && git add foo && git commit -m two &&
 		git tag -f tmaster master &&
 		git push --mirror up &&
-		git reset --hard HEAD^
+		git reset --hard HEAD^ &&
 		git tag -f tmaster master &&
 		git push --mirror up
 	) &&
@@ -188,7 +188,7 @@ test_expect_success 'push mirror removes
 		echo one >foo && git add foo && git commit -m one &&
 		git tag -f tremove master &&
 		git push --mirror up &&
-		git tag -d tremove
+		git tag -d tremove &&
 		git push --mirror up
 	) &&
 	(
@@ -235,7 +235,7 @@ test_expect_success 'remote.foo.mirror a
 		git branch keep master &&
 		git branch remove master &&
 		git push up &&
-		git branch -D remove
+		git branch -D remove &&
 		git push up
 	) &&
 	(
@@ -265,4 +265,14 @@ test_expect_success 'remote.foo.mirror=n
 
 '
 
+test_expect_success 'push to mirrored repository with refspec fails' '
+	mk_repo_pair &&
+	(
+		cd master &&
+		echo one >foo && git add foo && git commit -m one &&
+		git config --add remote.up.mirror true &&
+		test_must_fail git push up master
+	)
+'
+
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t5520-pull.sh 1.2.3+git2.25.1-1/git/t/t5520-pull.sh
--- 1.2.1+git2.18.0-1/git/t/t5520-pull.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t5520-pull.sh	2020-02-17 04:47:35.000000000 +0000
@@ -5,7 +5,7 @@ test_description='pulling into void'
 . ./test-lib.sh
 
 modify () {
-	sed -e "$1" <"$2" >"$2.x" &&
+	sed -e "$1" "$2" >"$2.x" &&
 	mv "$2.x" "$2"
 }
 
@@ -15,8 +15,10 @@ test_pull_autostash () {
 	git add new_file &&
 	git pull "$@" . copy &&
 	test_cmp_rev HEAD^ copy &&
-	test "$(cat new_file)" = dirty &&
-	test "$(cat file)" = "modified again"
+	echo dirty >expect &&
+	test_cmp expect new_file &&
+	echo "modified again" >expect &&
+	test_cmp expect file
 }
 
 test_pull_autostash_fail () {
@@ -39,8 +41,8 @@ test_expect_success 'pulling into void'
 		cd cloned &&
 		git pull ..
 	) &&
-	test -f file &&
-	test -f cloned/file &&
+	test_path_is_file file &&
+	test_path_is_file cloned/file &&
 	test_cmp file cloned/file
 '
 
@@ -50,8 +52,8 @@ test_expect_success 'pulling into void u
 		cd cloned-uho &&
 		git pull .. master:master
 	) &&
-	test -f file &&
-	test -f cloned-uho/file &&
+	test_path_is_file file &&
+	test_path_is_file cloned-uho/file &&
 	test_cmp file cloned-uho/file
 '
 
@@ -99,7 +101,7 @@ test_expect_success 'pulling into void m
 	(
 		cd cloned-octopus &&
 		test_must_fail git pull .. master master &&
-		! test -f file
+		test_path_is_missing file
 	)
 '
 
@@ -110,9 +112,11 @@ test_expect_success 'test . as a remote'
 	echo updated >file &&
 	git commit -a -m updated &&
 	git checkout copy &&
-	test "$(cat file)" = file &&
+	echo file >expect &&
+	test_cmp expect file &&
 	git pull &&
-	test "$(cat file)" = updated &&
+	echo updated >expect &&
+	test_cmp expect file &&
 	git reflog -1 >reflog.actual &&
 	sed "s/^[0-9a-f][0-9a-f]*/OBJID/" reflog.actual >reflog.fuzzy &&
 	echo "OBJID HEAD@{0}: pull: Fast-forward" >reflog.expected &&
@@ -125,9 +129,11 @@ test_expect_success 'the default remote
 	git commit -a -m modified &&
 	git checkout copy &&
 	git reset --hard HEAD^ &&
-	test "$(cat file)" = file &&
+	echo file >expect &&
+	test_cmp expect file &&
 	git pull . second &&
-	test "$(cat file)" = modified &&
+	echo modified >expect &&
+	test_cmp expect file &&
 	git reflog -1 >reflog.actual &&
 	sed "s/^[0-9a-f][0-9a-f]*/OBJID/" reflog.actual >reflog.fuzzy &&
 	echo "OBJID HEAD@{0}: pull . second: Fast-forward" >reflog.expected &&
@@ -137,10 +143,11 @@ test_expect_success 'the default remote
 test_expect_success 'fail if wildcard spec does not match any refs' '
 	git checkout -b test copy^ &&
 	test_when_finished "git checkout -f copy && git branch -D test" &&
-	test "$(cat file)" = file &&
+	echo file >expect &&
+	test_cmp expect file &&
 	test_must_fail git pull . "refs/nonexisting1/*:refs/nonexisting2/*" 2>err &&
 	test_i18ngrep "no candidates for merging" err &&
-	test "$(cat file)" = file
+	test_cmp expect file
 '
 
 test_expect_success 'fail if no branches specified with non-default remote' '
@@ -148,11 +155,12 @@ test_expect_success 'fail if no branches
 	test_when_finished "git remote remove test_remote" &&
 	git checkout -b test copy^ &&
 	test_when_finished "git checkout -f copy && git branch -D test" &&
-	test "$(cat file)" = file &&
+	echo file >expect &&
+	test_cmp expect file &&
 	test_config branch.test.remote origin &&
 	test_must_fail git pull test_remote 2>err &&
 	test_i18ngrep "specify a branch on the command line" err &&
-	test "$(cat file)" = file
+	test_cmp expect file
 '
 
 test_expect_success 'fail if not on a branch' '
@@ -160,10 +168,11 @@ test_expect_success 'fail if not on a br
 	test_when_finished "git remote remove origin" &&
 	git checkout HEAD^ &&
 	test_when_finished "git checkout -f copy" &&
-	test "$(cat file)" = file &&
+	echo file >expect &&
+	test_cmp expect file &&
 	test_must_fail git pull 2>err &&
 	test_i18ngrep "not currently on a branch" err &&
-	test "$(cat file)" = file
+	test_cmp expect file
 '
 
 test_expect_success 'fail if no configuration for current branch' '
@@ -172,10 +181,11 @@ test_expect_success 'fail if no configur
 	git checkout -b test copy^ &&
 	test_when_finished "git checkout -f copy && git branch -D test" &&
 	test_config branch.test.remote test_remote &&
-	test "$(cat file)" = file &&
+	echo file >expect &&
+	test_cmp expect file &&
 	test_must_fail git pull 2>err &&
 	test_i18ngrep "no tracking information" err &&
-	test "$(cat file)" = file
+	test_cmp expect file
 '
 
 test_expect_success 'pull --all: fail if no configuration for current branch' '
@@ -184,10 +194,11 @@ test_expect_success 'pull --all: fail if
 	git checkout -b test copy^ &&
 	test_when_finished "git checkout -f copy && git branch -D test" &&
 	test_config branch.test.remote test_remote &&
-	test "$(cat file)" = file &&
+	echo file >expect &&
+	test_cmp expect file &&
 	test_must_fail git pull --all 2>err &&
 	test_i18ngrep "There is no tracking information" err &&
-	test "$(cat file)" = file
+	test_cmp expect file
 '
 
 test_expect_success 'fail if upstream branch does not exist' '
@@ -195,26 +206,31 @@ test_expect_success 'fail if upstream br
 	test_when_finished "git checkout -f copy && git branch -D test" &&
 	test_config branch.test.remote . &&
 	test_config branch.test.merge refs/heads/nonexisting &&
-	test "$(cat file)" = file &&
+	echo file >expect &&
+	test_cmp expect file &&
 	test_must_fail git pull 2>err &&
 	test_i18ngrep "no such ref was fetched" err &&
-	test "$(cat file)" = file
+	test_cmp expect file
 '
 
 test_expect_success 'fail if the index has unresolved entries' '
 	git checkout -b third second^ &&
 	test_when_finished "git checkout -f copy && git branch -D third" &&
-	test "$(cat file)" = file &&
+	echo file >expect &&
+	test_cmp expect file &&
 	test_commit modified2 file &&
-	test -z "$(git ls-files -u)" &&
+	git ls-files -u >unmerged &&
+	test_must_be_empty unmerged &&
 	test_must_fail git pull . second &&
-	test -n "$(git ls-files -u)" &&
+	git ls-files -u >unmerged &&
+	test_file_not_empty unmerged &&
 	cp file expected &&
 	test_must_fail git pull . second 2>err &&
 	test_i18ngrep "Pulling is not possible because you have unmerged files." err &&
 	test_cmp expected file &&
 	git add file &&
-	test -z "$(git ls-files -u)" &&
+	git ls-files -u >unmerged &&
+	test_must_be_empty unmerged &&
 	test_must_fail git pull . second 2>err &&
 	test_i18ngrep "You have not concluded your merge" err &&
 	test_cmp expected file
@@ -223,36 +239,42 @@ test_expect_success 'fail if the index h
 test_expect_success 'fast-forwards working tree if branch head is updated' '
 	git checkout -b third second^ &&
 	test_when_finished "git checkout -f copy && git branch -D third" &&
-	test "$(cat file)" = file &&
+	echo file >expect &&
+	test_cmp expect file &&
 	git pull . second:third 2>err &&
 	test_i18ngrep "fetch updated the current branch head" err &&
-	test "$(cat file)" = modified &&
-	test "$(git rev-parse third)" = "$(git rev-parse second)"
+	echo modified >expect &&
+	test_cmp expect file &&
+	test_cmp_rev third second
 '
 
 test_expect_success 'fast-forward fails with conflicting work tree' '
 	git checkout -b third second^ &&
 	test_when_finished "git checkout -f copy && git branch -D third" &&
-	test "$(cat file)" = file &&
+	echo file >expect &&
+	test_cmp expect file &&
 	echo conflict >file &&
 	test_must_fail git pull . second:third 2>err &&
 	test_i18ngrep "Cannot fast-forward your working tree" err &&
-	test "$(cat file)" = conflict &&
-	test "$(git rev-parse third)" = "$(git rev-parse second)"
+	echo conflict >expect &&
+	test_cmp expect file &&
+	test_cmp_rev third second
 '
 
 test_expect_success '--rebase' '
 	git branch to-rebase &&
-	echo modified again > file &&
+	echo modified again >file &&
 	git commit -m file file &&
 	git checkout to-rebase &&
-	echo new > file2 &&
+	echo new >file2 &&
 	git add file2 &&
 	git commit -m "new file" &&
 	git tag before-rebase &&
 	git pull --rebase . copy &&
-	test "$(git rev-parse HEAD^)" = "$(git rev-parse copy)" &&
-	test new = "$(git show HEAD:file2)"
+	test_cmp_rev HEAD^ copy &&
+	echo new >expect &&
+	git show HEAD:file2 >actual &&
+	test_cmp expect actual
 '
 
 test_expect_success '--rebase fast forward' '
@@ -263,7 +285,7 @@ test_expect_success '--rebase fast forwa
 
 	git checkout to-rebase &&
 	git pull --rebase . ff &&
-	test "$(git rev-parse HEAD)" = "$(git rev-parse ff)" &&
+	test_cmp_rev HEAD ff &&
 
 	# The above only validates the result.  Did we actually bypass rebase?
 	git reflog -1 >reflog.actual &&
@@ -287,7 +309,7 @@ test_expect_success '--rebase --autostas
 	git checkout behind &&
 	echo dirty >file &&
 	git pull --rebase --autostash . to-rebase-ff &&
-	test "$(git rev-parse HEAD)" = "$(git rev-parse to-rebase-ff)"
+	test_cmp_rev HEAD to-rebase-ff
 '
 
 test_expect_success '--rebase with conflicts shows advice' '
@@ -325,9 +347,11 @@ test_expect_success 'failed --rebase sho
 test_expect_success '--rebase fails with multiple branches' '
 	git reset --hard before-rebase &&
 	test_must_fail git pull --rebase . copy master 2>err &&
-	test "$(git rev-parse HEAD)" = "$(git rev-parse before-rebase)" &&
+	test_cmp_rev HEAD before-rebase &&
 	test_i18ngrep "Cannot rebase onto multiple branches" err &&
-	test modified = "$(git show HEAD:file)"
+	echo modified >expect &&
+	git show HEAD:file >actual &&
+	test_cmp expect actual
 '
 
 test_expect_success 'pull --rebase succeeds with dirty working directory and rebase.autostash set' '
@@ -377,8 +401,10 @@ test_expect_success 'pull.rebase' '
 	git reset --hard before-rebase &&
 	test_config pull.rebase true &&
 	git pull . copy &&
-	test "$(git rev-parse HEAD^)" = "$(git rev-parse copy)" &&
-	test new = "$(git show HEAD:file2)"
+	test_cmp_rev HEAD^ copy &&
+	echo new >expect &&
+	git show HEAD:file2 >actual &&
+	test_cmp expect actual
 '
 
 test_expect_success 'pull --autostash & pull.rebase=true' '
@@ -395,8 +421,10 @@ test_expect_success 'branch.to-rebase.re
 	git reset --hard before-rebase &&
 	test_config branch.to-rebase.rebase true &&
 	git pull . copy &&
-	test "$(git rev-parse HEAD^)" = "$(git rev-parse copy)" &&
-	test new = "$(git show HEAD:file2)"
+	test_cmp_rev HEAD^ copy &&
+	echo new >expect &&
+	git show HEAD:file2 >actual &&
+	test_cmp expect actual
 '
 
 test_expect_success 'branch.to-rebase.rebase should override pull.rebase' '
@@ -404,23 +432,29 @@ test_expect_success 'branch.to-rebase.re
 	test_config pull.rebase true &&
 	test_config branch.to-rebase.rebase false &&
 	git pull . copy &&
-	test "$(git rev-parse HEAD^)" != "$(git rev-parse copy)" &&
-	test new = "$(git show HEAD:file2)"
+	test_cmp_rev ! HEAD^ copy &&
+	echo new >expect &&
+	git show HEAD:file2 >actual &&
+	test_cmp expect actual
 '
 
-test_expect_success "pull --rebase warns on --verify-signatures" '
+test_expect_success 'pull --rebase warns on --verify-signatures' '
 	git reset --hard before-rebase &&
 	git pull --rebase --verify-signatures . copy 2>err &&
-	test "$(git rev-parse HEAD^)" = "$(git rev-parse copy)" &&
-	test new = "$(git show HEAD:file2)" &&
+	test_cmp_rev HEAD^ copy &&
+	echo new >expect &&
+	git show HEAD:file2 >actual &&
+	test_cmp expect actual &&
 	test_i18ngrep "ignoring --verify-signatures for rebase" err
 '
 
-test_expect_success "pull --rebase does not warn on --no-verify-signatures" '
+test_expect_success 'pull --rebase does not warn on --no-verify-signatures' '
 	git reset --hard before-rebase &&
 	git pull --rebase --no-verify-signatures . copy 2>err &&
-	test "$(git rev-parse HEAD^)" = "$(git rev-parse copy)" &&
-	test new = "$(git show HEAD:file2)" &&
+	test_cmp_rev HEAD^ copy &&
+	echo new >expect &&
+	git show HEAD:file2 >actual &&
+	test_cmp expect actual &&
 	test_i18ngrep ! "verify-signatures" err
 '
 
@@ -440,33 +474,40 @@ test_expect_success 'pull.rebase=false c
 	git reset --hard before-preserve-rebase &&
 	test_config pull.rebase false &&
 	git pull . copy &&
-	test "$(git rev-parse HEAD^1)" = "$(git rev-parse before-preserve-rebase)" &&
-	test "$(git rev-parse HEAD^2)" = "$(git rev-parse copy)" &&
-	test file3 = "$(git show HEAD:file3.t)"
+	test_cmp_rev HEAD^1 before-preserve-rebase &&
+	test_cmp_rev HEAD^2 copy &&
+	echo file3 >expect &&
+	git show HEAD:file3.t >actual &&
+	test_cmp expect actual
 '
 
 test_expect_success 'pull.rebase=true flattens keep-merge' '
 	git reset --hard before-preserve-rebase &&
 	test_config pull.rebase true &&
 	git pull . copy &&
-	test "$(git rev-parse HEAD^^)" = "$(git rev-parse copy)" &&
-	test file3 = "$(git show HEAD:file3.t)"
+	test_cmp_rev HEAD^^ copy &&
+	echo file3 >expect &&
+	git show HEAD:file3.t >actual &&
+	test_cmp expect actual
 '
 
 test_expect_success 'pull.rebase=1 is treated as true and flattens keep-merge' '
 	git reset --hard before-preserve-rebase &&
 	test_config pull.rebase 1 &&
 	git pull . copy &&
-	test "$(git rev-parse HEAD^^)" = "$(git rev-parse copy)" &&
-	test file3 = "$(git show HEAD:file3.t)"
+	test_cmp_rev HEAD^^ copy &&
+	echo file3 >expect &&
+	git show HEAD:file3.t >actual &&
+	test_cmp expect actual
 '
 
-test_expect_success 'pull.rebase=preserve rebases and merges keep-merge' '
+test_expect_success REBASE_P \
+	'pull.rebase=preserve rebases and merges keep-merge' '
 	git reset --hard before-preserve-rebase &&
 	test_config pull.rebase preserve &&
 	git pull . copy &&
-	test "$(git rev-parse HEAD^^)" = "$(git rev-parse copy)" &&
-	test "$(git rev-parse HEAD^2)" = "$(git rev-parse keep-merge)"
+	test_cmp_rev HEAD^^ copy &&
+	test_cmp_rev HEAD^2 keep-merge
 '
 
 test_expect_success 'pull.rebase=interactive' '
@@ -475,89 +516,112 @@ test_expect_success 'pull.rebase=interac
 	false
 	EOF
 	test_set_editor "$TRASH_DIRECTORY/fake-editor" &&
+	test_when_finished "test_might_fail git rebase --abort" &&
 	test_must_fail git pull --rebase=interactive . copy &&
-	test "I was here" = "$(cat fake.out)"
+	echo "I was here" >expect &&
+	test_cmp expect fake.out
+'
+
+test_expect_success 'pull --rebase=i' '
+	write_script "$TRASH_DIRECTORY/fake-editor" <<-\EOF &&
+	echo I was here, too >fake.out &&
+	false
+	EOF
+	test_set_editor "$TRASH_DIRECTORY/fake-editor" &&
+	test_when_finished "test_might_fail git rebase --abort" &&
+	test_must_fail git pull --rebase=i . copy &&
+	echo "I was here, too" >expect &&
+	test_cmp expect fake.out
 '
 
 test_expect_success 'pull.rebase=invalid fails' '
 	git reset --hard before-preserve-rebase &&
 	test_config pull.rebase invalid &&
-	! git pull . copy
+	test_must_fail git pull . copy
 '
 
 test_expect_success '--rebase=false create a new merge commit' '
 	git reset --hard before-preserve-rebase &&
 	test_config pull.rebase true &&
 	git pull --rebase=false . copy &&
-	test "$(git rev-parse HEAD^1)" = "$(git rev-parse before-preserve-rebase)" &&
-	test "$(git rev-parse HEAD^2)" = "$(git rev-parse copy)" &&
-	test file3 = "$(git show HEAD:file3.t)"
+	test_cmp_rev HEAD^1 before-preserve-rebase &&
+	test_cmp_rev HEAD^2 copy &&
+	echo file3 >expect &&
+	git show HEAD:file3.t >actual &&
+	test_cmp expect actual
 '
 
 test_expect_success '--rebase=true rebases and flattens keep-merge' '
 	git reset --hard before-preserve-rebase &&
 	test_config pull.rebase preserve &&
 	git pull --rebase=true . copy &&
-	test "$(git rev-parse HEAD^^)" = "$(git rev-parse copy)" &&
-	test file3 = "$(git show HEAD:file3.t)"
+	test_cmp_rev HEAD^^ copy &&
+	echo file3 >expect &&
+	git show HEAD:file3.t >actual &&
+	test_cmp expect actual
 '
 
-test_expect_success '--rebase=preserve rebases and merges keep-merge' '
+test_expect_success REBASE_P \
+	'--rebase=preserve rebases and merges keep-merge' '
 	git reset --hard before-preserve-rebase &&
 	test_config pull.rebase true &&
 	git pull --rebase=preserve . copy &&
-	test "$(git rev-parse HEAD^^)" = "$(git rev-parse copy)" &&
-	test "$(git rev-parse HEAD^2)" = "$(git rev-parse keep-merge)"
+	test_cmp_rev HEAD^^ copy &&
+	test_cmp_rev HEAD^2 keep-merge
 '
 
 test_expect_success '--rebase=invalid fails' '
 	git reset --hard before-preserve-rebase &&
-	! git pull --rebase=invalid . copy
+	test_must_fail git pull --rebase=invalid . copy
 '
 
 test_expect_success '--rebase overrides pull.rebase=preserve and flattens keep-merge' '
 	git reset --hard before-preserve-rebase &&
 	test_config pull.rebase preserve &&
 	git pull --rebase . copy &&
-	test "$(git rev-parse HEAD^^)" = "$(git rev-parse copy)" &&
-	test file3 = "$(git show HEAD:file3.t)"
+	test_cmp_rev HEAD^^ copy &&
+	echo file3 >expect &&
+	git show HEAD:file3.t >actual &&
+	test_cmp expect actual
 '
 
 test_expect_success '--rebase with rebased upstream' '
-
 	git remote add -f me . &&
 	git checkout copy &&
 	git tag copy-orig &&
 	git reset --hard HEAD^ &&
-	echo conflicting modification > file &&
+	echo conflicting modification >file &&
 	git commit -m conflict file &&
 	git checkout to-rebase &&
-	echo file > file2 &&
+	echo file >file2 &&
 	git commit -m to-rebase file2 &&
 	git tag to-rebase-orig &&
 	git pull --rebase me copy &&
-	test "conflicting modification" = "$(cat file)" &&
-	test file = "$(cat file2)"
-
+	echo "conflicting modification" >expect &&
+	test_cmp expect file &&
+	echo file >expect &&
+	test_cmp expect file2
 '
 
 test_expect_success '--rebase -f with rebased upstream' '
 	test_when_finished "test_might_fail git rebase --abort" &&
 	git reset --hard to-rebase-orig &&
 	git pull --rebase -f me copy &&
-	test "conflicting modification" = "$(cat file)" &&
-	test file = "$(cat file2)"
+	echo "conflicting modification" >expect &&
+	test_cmp expect file &&
+	echo file >expect &&
+	test_cmp expect file2
 '
 
 test_expect_success '--rebase with rebased default upstream' '
-
 	git update-ref refs/remotes/me/copy copy-orig &&
 	git checkout --track -b to-rebase2 me/copy &&
 	git reset --hard to-rebase-orig &&
 	git pull --rebase &&
-	test "conflicting modification" = "$(cat file)" &&
-	test file = "$(cat file2)"
-
+	echo "conflicting modification" >expect &&
+	test_cmp expect file &&
+	echo file >expect &&
+	test_cmp expect file2
 '
 
 test_expect_success 'rebased upstream + fetch + pull --rebase' '
@@ -568,13 +632,14 @@ test_expect_success 'rebased upstream +
 	git reset --hard to-rebase-orig &&
 	git fetch &&
 	git pull --rebase &&
-	test "conflicting modification" = "$(cat file)" &&
-	test file = "$(cat file2)"
+	echo "conflicting modification" >expect &&
+	test_cmp expect file &&
+	echo file >expect &&
+	test_cmp expect file2
 
 '
 
 test_expect_success 'pull --rebase dies early with dirty working directory' '
-
 	git checkout to-rebase &&
 	git update-ref refs/remotes/me/copy copy^ &&
 	COPY="$(git rev-parse --verify me/copy)" &&
@@ -582,23 +647,23 @@ test_expect_success 'pull --rebase dies
 	test_config branch.to-rebase.remote me &&
 	test_config branch.to-rebase.merge refs/heads/copy &&
 	test_config branch.to-rebase.rebase true &&
-	echo dirty >> file &&
+	echo dirty >>file &&
 	git add file &&
 	test_must_fail git pull &&
-	test "$COPY" = "$(git rev-parse --verify me/copy)" &&
+	test_cmp_rev "$COPY" me/copy &&
 	git checkout HEAD -- file &&
 	git pull &&
-	test "$COPY" != "$(git rev-parse --verify me/copy)"
-
+	test_cmp_rev ! "$COPY" me/copy
 '
 
 test_expect_success 'pull --rebase works on branch yet to be born' '
 	git rev-parse master >expect &&
 	mkdir empty_repo &&
-	(cd empty_repo &&
-	 git init &&
-	 git pull --rebase .. master &&
-	 git rev-parse HEAD >../actual
+	(
+		cd empty_repo &&
+		git init &&
+		git pull --rebase .. master &&
+		git rev-parse HEAD >../actual
 	) &&
 	test_cmp expect actual
 '
@@ -610,76 +675,104 @@ test_expect_success 'pull --rebase fails
 		cd empty_repo2 &&
 		echo staged-file >staged-file &&
 		git add staged-file &&
-		test "$(git ls-files)" = staged-file &&
+		echo staged-file >expect &&
+		git ls-files >actual &&
+		test_cmp expect actual &&
 		test_must_fail git pull --rebase .. master 2>err &&
-		test "$(git ls-files)" = staged-file &&
-		test "$(git show :staged-file)" = staged-file &&
+		git ls-files >actual &&
+		test_cmp expect actual &&
+		git show :staged-file >actual &&
+		test_cmp expect actual &&
 		test_i18ngrep "unborn branch with changes added to the index" err
 	)
 '
 
+test_expect_success 'pull --rebase fails on corrupt HEAD' '
+	test_when_finished "rm -rf corrupt" &&
+	git init corrupt &&
+	(
+		cd corrupt &&
+		test_commit one &&
+		git rev-parse --verify HEAD >head &&
+		obj=$(sed "s#^..#&/#" head) &&
+		rm -f .git/objects/$obj &&
+		test_must_fail git pull --rebase
+	)
+'
+
 test_expect_success 'setup for detecting upstreamed changes' '
 	mkdir src &&
-	(cd src &&
-	 git init &&
-	 printf "1\n2\n3\n4\n5\n6\n7\n8\n9\n10\n" > stuff &&
-	 git add stuff &&
-	 git commit -m "Initial revision"
+	(
+		cd src &&
+		git init &&
+		printf "1\n2\n3\n4\n5\n6\n7\n8\n9\n10\n" > stuff &&
+		git add stuff &&
+		git commit -m "Initial revision"
 	) &&
 	git clone src dst &&
-	(cd src &&
-	 modify s/5/43/ stuff &&
-	 git commit -a -m "5->43" &&
-	 modify s/6/42/ stuff &&
-	 git commit -a -m "Make it bigger"
+	(
+		cd src &&
+		modify s/5/43/ stuff &&
+		git commit -a -m "5->43" &&
+		modify s/6/42/ stuff &&
+		git commit -a -m "Make it bigger"
 	) &&
-	(cd dst &&
-	 modify s/5/43/ stuff &&
-	 git commit -a -m "Independent discovery of 5->43"
+	(
+		cd dst &&
+		modify s/5/43/ stuff &&
+		git commit -a -m "Independent discovery of 5->43"
 	)
 '
 
 test_expect_success 'git pull --rebase detects upstreamed changes' '
-	(cd dst &&
-	 git pull --rebase &&
-	 test -z "$(git ls-files -u)"
+	(
+		cd dst &&
+		git pull --rebase &&
+		git ls-files -u >untracked &&
+		test_must_be_empty untracked
 	)
 '
 
 test_expect_success 'setup for avoiding reapplying old patches' '
-	(cd dst &&
-	 test_might_fail git rebase --abort &&
-	 git reset --hard origin/master
+	(
+		cd dst &&
+		test_might_fail git rebase --abort &&
+		git reset --hard origin/master
 	) &&
 	git clone --bare src src-replace.git &&
 	rm -rf src &&
 	mv src-replace.git src &&
-	(cd dst &&
-	 modify s/2/22/ stuff &&
-	 git commit -a -m "Change 2" &&
-	 modify s/3/33/ stuff &&
-	 git commit -a -m "Change 3" &&
-	 modify s/4/44/ stuff &&
-	 git commit -a -m "Change 4" &&
-	 git push &&
+	(
+		cd dst &&
+		modify s/2/22/ stuff &&
+		git commit -a -m "Change 2" &&
+		modify s/3/33/ stuff &&
+		git commit -a -m "Change 3" &&
+		modify s/4/44/ stuff &&
+		git commit -a -m "Change 4" &&
+		git push &&
 
-	 modify s/44/55/ stuff &&
-	 git commit --amend -a -m "Modified Change 4"
+		modify s/44/55/ stuff &&
+		git commit --amend -a -m "Modified Change 4"
 	)
 '
 
 test_expect_success 'git pull --rebase does not reapply old patches' '
-	(cd dst &&
-	 test_must_fail git pull --rebase &&
-	 test 1 = $(find .git/rebase-apply -name "000*" | wc -l)
+	(
+		cd dst &&
+		test_must_fail git pull --rebase &&
+		find .git/rebase-apply -name "000*" >patches &&
+		test_line_count = 1 patches
 	)
 '
 
 test_expect_success 'git pull --rebase against local branch' '
 	git checkout -b copy2 to-rebase-orig &&
 	git pull --rebase . to-rebase &&
-	test "conflicting modification" = "$(cat file)" &&
-	test file = "$(cat file2)"
+	echo "conflicting modification" >expect &&
+	test_cmp expect file &&
+	echo file >expect &&
+	test_cmp expect file2
 '
 
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t5521-pull-options.sh 1.2.3+git2.25.1-1/git/t/t5521-pull-options.sh
--- 1.2.1+git2.18.0-1/git/t/t5521-pull-options.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t5521-pull-options.sh	2020-02-17 04:47:35.000000000 +0000
@@ -77,6 +77,14 @@ test_expect_success 'git pull -q -v' '
 	test_must_be_empty out &&
 	test -s err)
 '
+test_expect_success 'git pull --cleanup errors early on invalid argument' '
+	mkdir clonedcleanup &&
+	(cd clonedcleanup && git init &&
+	test_must_fail git pull --cleanup invalid "../parent" >out 2>err &&
+	test_must_be_empty out &&
+	test -s err)
+'
+
 
 test_expect_success 'git pull --force' '
 	mkdir clonedoldstyle &&
diff -pruN 1.2.1+git2.18.0-1/git/t/t5523-push-upstream.sh 1.2.3+git2.25.1-1/git/t/t5523-push-upstream.sh
--- 1.2.1+git2.18.0-1/git/t/t5523-push-upstream.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t5523-push-upstream.sh	2020-02-17 04:47:35.000000000 +0000
@@ -113,7 +113,7 @@ test_expect_success TTY 'quiet push' '
 	ensure_fresh_upstream &&
 
 	test_terminal git push --quiet --no-progress upstream master 2>&1 | tee output &&
-	test_cmp /dev/null output
+	test_must_be_empty output
 '
 
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t5526-fetch-submodules.sh 1.2.3+git2.25.1-1/git/t/t5526-fetch-submodules.sh
--- 1.2.1+git2.18.0-1/git/t/t5526-fetch-submodules.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t5526-fetch-submodules.sh	2020-02-17 04:47:35.000000000 +0000
@@ -98,8 +98,8 @@ test_expect_success "fetch alone only fe
 		cd downstream &&
 		git fetch >../actual.out 2>../actual.err
 	) &&
-	! test -s actual.out &&
-	! test -s actual.err
+	test_must_be_empty actual.out &&
+	test_must_be_empty actual.err
 '
 
 test_expect_success "fetch --no-recurse-submodules only fetches superproject" '
@@ -107,8 +107,8 @@ test_expect_success "fetch --no-recurse-
 		cd downstream &&
 		git fetch --no-recurse-submodules >../actual.out 2>../actual.err
 	) &&
-	! test -s actual.out &&
-	! test -s actual.err
+	test_must_be_empty actual.out &&
+	test_must_be_empty actual.err
 '
 
 test_expect_success "using fetchRecurseSubmodules=true in .gitmodules recurses into submodules" '
@@ -127,8 +127,8 @@ test_expect_success "--no-recurse-submod
 		cd downstream &&
 		git fetch --no-recurse-submodules >../actual.out 2>../actual.err
 	) &&
-	! test -s actual.out &&
-	! test -s actual.err
+	test_must_be_empty actual.out &&
+	test_must_be_empty actual.err
 '
 
 test_expect_success "using fetchRecurseSubmodules=false in .git/config overrides setting in .gitmodules" '
@@ -137,8 +137,8 @@ test_expect_success "using fetchRecurseS
 		git config submodule.submodule.fetchRecurseSubmodules false &&
 		git fetch >../actual.out 2>../actual.err
 	) &&
-	! test -s actual.out &&
-	! test -s actual.err
+	test_must_be_empty actual.out &&
+	test_must_be_empty actual.err
 '
 
 test_expect_success "--recurse-submodules overrides fetchRecurseSubmodules setting from .git/config" '
@@ -157,8 +157,8 @@ test_expect_success "--quiet propagates
 		cd downstream &&
 		git fetch --recurse-submodules --quiet >../actual.out 2>../actual.err
 	) &&
-	! test -s actual.out &&
-	! test -s actual.err
+	test_must_be_empty actual.out &&
+	test_must_be_empty actual.err
 '
 
 test_expect_success "--quiet propagates to parallel submodules" '
@@ -166,8 +166,8 @@ test_expect_success "--quiet propagates
 		cd downstream &&
 		git fetch --recurse-submodules -j 2 --quiet  >../actual.out 2>../actual.err
 	) &&
-	! test -s actual.out &&
-	! test -s actual.err
+	test_must_be_empty actual.out &&
+	test_must_be_empty actual.err
 '
 
 test_expect_success "--dry-run propagates to submodules" '
@@ -221,8 +221,8 @@ test_expect_success "--no-recurse-submod
 		git config fetch.recurseSubmodules true &&
 		git fetch --no-recurse-submodules >../actual.out 2>../actual.err
 	) &&
-	! test -s actual.out &&
-	! test -s actual.err
+	test_must_be_empty actual.out &&
+	test_must_be_empty actual.err
 '
 
 test_expect_success "Recursion doesn't happen when no new commits are fetched in the superproject" '
@@ -235,8 +235,8 @@ test_expect_success "Recursion doesn't h
 		git config --unset fetch.recurseSubmodules &&
 		git fetch >../actual.out 2>../actual.err
 	) &&
-	! test -s actual.out &&
-	! test -s actual.err
+	test_must_be_empty actual.out &&
+	test_must_be_empty actual.err
 '
 
 test_expect_success "Recursion stops when no new submodule commits are fetched" '
@@ -268,7 +268,7 @@ test_expect_success "Recursion doesn't h
 		cd downstream &&
 		git fetch >../actual.out 2>../actual.err
 	) &&
-	! test -s actual.out &&
+	test_must_be_empty actual.out &&
 	test_i18ncmp expect.err.file actual.err
 '
 
@@ -357,8 +357,8 @@ test_expect_success "'--recurse-submodul
 		git fetch --recurse-submodules=on-demand >../actual.out 2>../actual.err &&
 		git config --unset fetch.recurseSubmodules
 	) &&
-	! test -s actual.out &&
-	! test -s actual.err
+	test_must_be_empty actual.out &&
+	test_must_be_empty actual.err
 '
 
 test_expect_success "'--recurse-submodules=on-demand' recurses as deep as necessary (and ignores config)" '
@@ -379,7 +379,7 @@ test_expect_success "'--recurse-submodul
 			git config -f .gitmodules submodule.subdir/deepsubmodule.fetchRecursive false
 		) &&
 		git fetch --recurse-submodules=on-demand >../actual.out 2>../actual.err &&
-		git config --unset fetch.recurseSubmodules
+		git config --unset fetch.recurseSubmodules &&
 		(
 			cd submodule &&
 			git config --unset -f .gitmodules submodule.subdir/deepsubmodule.fetchRecursive
@@ -402,7 +402,7 @@ test_expect_success "'--recurse-submodul
 		cd downstream &&
 		git fetch --recurse-submodules=on-demand >../actual.out 2>../actual.err
 	) &&
-	! test -s actual.out &&
+	test_must_be_empty actual.out &&
 	test_i18ncmp expect.err.file actual.err
 '
 
@@ -477,7 +477,7 @@ test_expect_success "don't fetch submodu
 		cd downstream &&
 		git fetch >../actual.out 2>../actual.err
 	) &&
-	! test -s actual.out &&
+	test_must_be_empty actual.out &&
 	test_i18ncmp expect.err actual.err &&
 	(
 		cd submodule &&
@@ -495,7 +495,6 @@ test_expect_success "'fetch.recurseSubmo
 	git add submodule &&
 	git rm .gitmodules &&
 	git commit -m "new submodule without .gitmodules" &&
-	printf "" >expect.out &&
 	head2=$(git rev-parse --short HEAD) &&
 	echo "From $pwd/." >expect.err.2 &&
 	echo "   $head1..$head2  master     -> origin/master" >>expect.err.2 &&
@@ -514,7 +513,7 @@ test_expect_success "'fetch.recurseSubmo
 		git config --unset fetch.recurseSubmodules &&
 		git reset --hard
 	) &&
-	test_i18ncmp expect.out actual.out &&
+	test_must_be_empty actual.out &&
 	test_i18ncmp expect.err.2 actual.err &&
 	git checkout HEAD^ -- .gitmodules &&
 	git add .gitmodules &&
@@ -525,6 +524,8 @@ test_expect_success 'fetching submodules
 	git config fetch.recurseSubmodules true &&
 	(
 		cd downstream &&
+		GIT_TRACE=$(pwd)/trace.out git fetch &&
+		grep "1 tasks" trace.out &&
 		GIT_TRACE=$(pwd)/trace.out git fetch --jobs 7 &&
 		grep "7 tasks" trace.out &&
 		git config submodule.fetchJobs 8 &&
@@ -574,11 +575,7 @@ test_expect_success "fetch new commits w
 	git clone . downstream_rename &&
 	(
 		cd downstream_rename &&
-		git submodule update --init &&
-# NEEDSWORK: we omitted --recursive for the submodule update here since
-# that does not work. See test 7001 for mv "moving nested submodules"
-# for details. Once that is fixed we should add the --recursive option
-# here.
+		git submodule update --init --recursive &&
 		git checkout -b rename &&
 		git mv submodule submodule_renamed &&
 		(
@@ -605,4 +602,121 @@ test_expect_success "fetch new commits w
 	test_cmp expect actual
 '
 
+test_expect_success "fetch new submodule commits on-demand outside standard refspec" '
+	# add a second submodule and ensure it is around in downstream first
+	git clone submodule sub1 &&
+	git submodule add ./sub1 &&
+	git commit -m "adding a second submodule" &&
+	git -C downstream pull &&
+	git -C downstream submodule update --init --recursive &&
+
+	git checkout --detach &&
+
+	C=$(git -C submodule commit-tree -m "new change outside refs/heads" HEAD^{tree}) &&
+	git -C submodule update-ref refs/changes/1 $C &&
+	git update-index --cacheinfo 160000 $C submodule &&
+	test_tick &&
+
+	D=$(git -C sub1 commit-tree -m "new change outside refs/heads" HEAD^{tree}) &&
+	git -C sub1 update-ref refs/changes/2 $D &&
+	git update-index --cacheinfo 160000 $D sub1 &&
+
+	git commit -m "updated submodules outside of refs/heads" &&
+	E=$(git rev-parse HEAD) &&
+	git update-ref refs/changes/3 $E &&
+	(
+		cd downstream &&
+		git fetch --recurse-submodules origin refs/changes/3:refs/heads/my_branch &&
+		git -C submodule cat-file -t $C &&
+		git -C sub1 cat-file -t $D &&
+		git checkout --recurse-submodules FETCH_HEAD
+	)
+'
+
+test_expect_success 'fetch new submodule commit on-demand in FETCH_HEAD' '
+	# depends on the previous test for setup
+
+	C=$(git -C submodule commit-tree -m "another change outside refs/heads" HEAD^{tree}) &&
+	git -C submodule update-ref refs/changes/4 $C &&
+	git update-index --cacheinfo 160000 $C submodule &&
+	test_tick &&
+
+	D=$(git -C sub1 commit-tree -m "another change outside refs/heads" HEAD^{tree}) &&
+	git -C sub1 update-ref refs/changes/5 $D &&
+	git update-index --cacheinfo 160000 $D sub1 &&
+
+	git commit -m "updated submodules outside of refs/heads" &&
+	E=$(git rev-parse HEAD) &&
+	git update-ref refs/changes/6 $E &&
+	(
+		cd downstream &&
+		git fetch --recurse-submodules origin refs/changes/6 &&
+		git -C submodule cat-file -t $C &&
+		git -C sub1 cat-file -t $D &&
+		git checkout --recurse-submodules FETCH_HEAD
+	)
+'
+
+test_expect_success 'fetch new submodule commits on-demand without .gitmodules entry' '
+	# depends on the previous test for setup
+
+	git config -f .gitmodules --remove-section submodule.sub1 &&
+	git add .gitmodules &&
+	git commit -m "delete gitmodules file" &&
+	git checkout -B master &&
+	git -C downstream fetch &&
+	git -C downstream checkout origin/master &&
+
+	C=$(git -C submodule commit-tree -m "yet another change outside refs/heads" HEAD^{tree}) &&
+	git -C submodule update-ref refs/changes/7 $C &&
+	git update-index --cacheinfo 160000 $C submodule &&
+	test_tick &&
+
+	D=$(git -C sub1 commit-tree -m "yet another change outside refs/heads" HEAD^{tree}) &&
+	git -C sub1 update-ref refs/changes/8 $D &&
+	git update-index --cacheinfo 160000 $D sub1 &&
+
+	git commit -m "updated submodules outside of refs/heads" &&
+	E=$(git rev-parse HEAD) &&
+	git update-ref refs/changes/9 $E &&
+	(
+		cd downstream &&
+		git fetch --recurse-submodules origin refs/changes/9 &&
+		git -C submodule cat-file -t $C &&
+		git -C sub1 cat-file -t $D &&
+		git checkout --recurse-submodules FETCH_HEAD
+	)
+'
+
+test_expect_success 'fetch new submodule commit intermittently referenced by superproject' '
+	# depends on the previous test for setup
+
+	D=$(git -C sub1 commit-tree -m "change 10 outside refs/heads" HEAD^{tree}) &&
+	E=$(git -C sub1 commit-tree -m "change 11 outside refs/heads" HEAD^{tree}) &&
+	F=$(git -C sub1 commit-tree -m "change 12 outside refs/heads" HEAD^{tree}) &&
+
+	git -C sub1 update-ref refs/changes/10 $D &&
+	git update-index --cacheinfo 160000 $D sub1 &&
+	git commit -m "updated submodules outside of refs/heads" &&
+
+	git -C sub1 update-ref refs/changes/11 $E &&
+	git update-index --cacheinfo 160000 $E sub1 &&
+	git commit -m "updated submodules outside of refs/heads" &&
+
+	git -C sub1 update-ref refs/changes/12 $F &&
+	git update-index --cacheinfo 160000 $F sub1 &&
+	git commit -m "updated submodules outside of refs/heads" &&
+
+	G=$(git rev-parse HEAD) &&
+	git update-ref refs/changes/13 $G &&
+	(
+		cd downstream &&
+		git fetch --recurse-submodules origin refs/changes/13 &&
+
+		git -C sub1 cat-file -t $D &&
+		git -C sub1 cat-file -t $E &&
+		git -C sub1 cat-file -t $F
+	)
+'
+
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t5528-push-default.sh 1.2.3+git2.25.1-1/git/t/t5528-push-default.sh
--- 1.2.1+git2.18.0-1/git/t/t5528-push-default.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t5528-push-default.sh	2020-02-17 04:47:35.000000000 +0000
@@ -163,7 +163,7 @@ test_pushdefault_workflow success curren
 # update parent1's foo (which is our upstream)
 test_pushdefault_workflow success upstream foo
 
-# upsream is foo which is not the name of the current branch
+# upstream is foo which is not the name of the current branch
 test_pushdefault_workflow failure simple master
 
 # master and foo are updated
diff -pruN 1.2.1+git2.18.0-1/git/t/t5530-upload-pack-error.sh 1.2.3+git2.25.1-1/git/t/t5530-upload-pack-error.sh
--- 1.2.1+git2.18.0-1/git/t/t5530-upload-pack-error.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t5530-upload-pack-error.sh	2020-02-17 04:47:35.000000000 +0000
@@ -57,13 +57,25 @@ test_expect_success 'upload-pack fails d
 	grep "bad tree object" output.err
 '
 
-test_expect_success 'upload-pack error message when bad ref requested' '
+test_expect_success 'upload-pack fails due to bad want (no object)' '
 
 	printf "0045want %s multi_ack_detailed\n00000009done\n0000" \
 		"deadbeefdeadbeefdeadbeefdeadbeefdeadbeef" >input &&
 	test_must_fail git upload-pack . <input >output 2>output.err &&
-	grep -q "not our ref" output.err &&
-	! grep -q multi_ack_detailed output.err
+	grep "not our ref" output.err &&
+	grep "ERR" output &&
+	! grep multi_ack_detailed output.err
+'
+
+test_expect_success 'upload-pack fails due to bad want (not tip)' '
+
+	oid=$(echo an object we have | git hash-object -w --stdin) &&
+	printf "0045want %s multi_ack_detailed\n00000009done\n0000" \
+		"$oid" >input &&
+	test_must_fail git upload-pack . <input >output 2>output.err &&
+	grep "not our ref" output.err &&
+	grep "ERR" output &&
+	! grep multi_ack_detailed output.err
 '
 
 test_expect_success 'upload-pack fails due to error in pack-objects enumeration' '
diff -pruN 1.2.1+git2.18.0-1/git/t/t5531-deep-submodule-push.sh 1.2.3+git2.25.1-1/git/t/t5531-deep-submodule-push.sh
--- 1.2.1+git2.18.0-1/git/t/t5531-deep-submodule-push.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t5531-deep-submodule-push.sh	2020-02-17 04:47:35.000000000 +0000
@@ -354,7 +354,7 @@ test_expect_success 'push succeeds if su
 	git clone a a1 &&
 	(
 		cd a1 &&
-		git init b
+		git init b &&
 		(
 			cd b &&
 			>junk &&
@@ -363,7 +363,7 @@ test_expect_success 'push succeeds if su
 		) &&
 		git add b &&
 		git commit -m "added submodule" &&
-		git push --recurse-submodule=check origin master
+		git push --recurse-submodules=check origin master
 	)
 '
 
diff -pruN 1.2.1+git2.18.0-1/git/t/t5533-push-cas.sh 1.2.3+git2.25.1-1/git/t/t5533-push-cas.sh
--- 1.2.1+git2.18.0-1/git/t/t5533-push-cas.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t5533-push-cas.sh	2020-02-17 04:47:35.000000000 +0000
@@ -142,9 +142,8 @@ test_expect_success 'push to delete (pro
 		cd dst &&
 		git push --force --force-with-lease=master:master^ origin :master
 	) &&
-	>expect &&
 	git ls-remote src refs/heads/master >actual &&
-	test_cmp expect actual
+	test_must_be_empty actual
 '
 
 test_expect_success 'push to delete (allowed)' '
@@ -154,9 +153,8 @@ test_expect_success 'push to delete (all
 		git push --force-with-lease=master origin :master 2>err &&
 		grep deleted err
 	) &&
-	>expect &&
 	git ls-remote src refs/heads/master >actual &&
-	test_cmp expect actual
+	test_must_be_empty actual
 '
 
 test_expect_success 'cover everything with default force-with-lease (protected)' '
diff -pruN 1.2.1+git2.18.0-1/git/t/t5534-push-signed.sh 1.2.3+git2.25.1-1/git/t/t5534-push-signed.sh
--- 1.2.1+git2.18.0-1/git/t/t5534-push-signed.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t5534-push-signed.sh	2020-02-17 04:47:35.000000000 +0000
@@ -194,10 +194,12 @@ test_expect_success GPG 'fail without ke
 
 	EOF
 
-	unset GIT_COMMITTER_EMAIL &&
-	git config user.email hasnokey@nowhere.com &&
-	test_must_fail git push --signed dst noop ff +noff &&
-	git config user.signingkey committer@example.com &&
+	test_config user.email hasnokey@nowhere.com &&
+	(
+		sane_unset GIT_COMMITTER_EMAIL &&
+		test_must_fail git push --signed dst noop ff +noff
+	) &&
+	test_config user.signingkey $GIT_COMMITTER_EMAIL &&
 	git push --signed dst noop ff +noff &&
 
 	(
@@ -212,6 +214,59 @@ test_expect_success GPG 'fail without ke
 
 	noop=$(git rev-parse noop) &&
 	ff=$(git rev-parse ff) &&
+	noff=$(git rev-parse noff) &&
+	grep "$noop $ff refs/heads/ff" dst/push-cert &&
+	grep "$noop $noff refs/heads/noff" dst/push-cert &&
+	test_cmp expect dst/push-cert-status
+'
+
+test_expect_success GPGSM 'fail without key and heed user.signingkey x509' '
+	test_config gpg.format x509 &&
+	prepare_dst &&
+	mkdir -p dst/.git/hooks &&
+	git -C dst config receive.certnonceseed sekrit &&
+	write_script dst/.git/hooks/post-receive <<-\EOF &&
+	# discard the update list
+	cat >/dev/null
+	# record the push certificate
+	if test -n "${GIT_PUSH_CERT-}"
+	then
+		git cat-file blob $GIT_PUSH_CERT >../push-cert
+	fi &&
+
+	cat >../push-cert-status <<E_O_F
+	SIGNER=${GIT_PUSH_CERT_SIGNER-nobody}
+	KEY=${GIT_PUSH_CERT_KEY-nokey}
+	STATUS=${GIT_PUSH_CERT_STATUS-nostatus}
+	NONCE_STATUS=${GIT_PUSH_CERT_NONCE_STATUS-nononcestatus}
+	NONCE=${GIT_PUSH_CERT_NONCE-nononce}
+	E_O_F
+
+	EOF
+
+	test_config user.email hasnokey@nowhere.com &&
+	test_config user.signingkey "" &&
+	(
+		sane_unset GIT_COMMITTER_EMAIL &&
+		test_must_fail git push --signed dst noop ff +noff
+	) &&
+	test_config user.signingkey $GIT_COMMITTER_EMAIL &&
+	git push --signed dst noop ff +noff &&
+
+	(
+		cat <<-\EOF &&
+		SIGNER=/CN=C O Mitter/O=Example/SN=C O/GN=Mitter
+		KEY=
+		STATUS=G
+		NONCE_STATUS=OK
+		EOF
+		sed -n -e "s/^nonce /NONCE=/p" -e "/^$/q" dst/push-cert
+	) >expect.in &&
+	key=$(cat "${GNUPGHOME}/trustlist.txt" | cut -d" " -f1 | tr -d ":") &&
+	sed -e "s/^KEY=/KEY=${key}/" expect.in >expect &&
+
+	noop=$(git rev-parse noop) &&
+	ff=$(git rev-parse ff) &&
 	noff=$(git rev-parse noff) &&
 	grep "$noop $ff refs/heads/ff" dst/push-cert &&
 	grep "$noop $noff refs/heads/noff" dst/push-cert &&
diff -pruN 1.2.1+git2.18.0-1/git/t/t5535-fetch-push-symref.sh 1.2.3+git2.25.1-1/git/t/t5535-fetch-push-symref.sh
--- 1.2.1+git2.18.0-1/git/t/t5535-fetch-push-symref.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t5535-fetch-push-symref.sh	2020-02-17 04:47:35.000000000 +0000
@@ -1,6 +1,6 @@
 #!/bin/sh
 
-test_description='avoiding conflicting update thru symref aliasing'
+test_description='avoiding conflicting update through symref aliasing'
 
 . ./test-lib.sh
 
diff -pruN 1.2.1+git2.18.0-1/git/t/t5537-fetch-shallow.sh 1.2.3+git2.25.1-1/git/t/t5537-fetch-shallow.sh
--- 1.2.1+git2.18.0-1/git/t/t5537-fetch-shallow.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t5537-fetch-shallow.sh	2020-02-17 04:47:35.000000000 +0000
@@ -175,8 +175,8 @@ EOF
 
 test_expect_success POSIXPERM,SANITY 'shallow fetch from a read-only repo' '
 	cp -R .git read-only.git &&
-	find read-only.git -print | xargs chmod -w &&
 	test_when_finished "find read-only.git -type d -print | xargs chmod +w" &&
+	find read-only.git -print | xargs chmod -w &&
 	git clone --no-local --depth=2 read-only.git from-read-only &&
 	git --git-dir=from-read-only/.git log --format=%s >actual &&
 	cat >expect <<EOF &&
@@ -186,4 +186,76 @@ EOF
 	test_cmp expect actual
 '
 
+test_expect_success '.git/shallow is edited by repack' '
+	git init shallow-server &&
+	test_commit -C shallow-server A &&
+	test_commit -C shallow-server B &&
+	git -C shallow-server checkout -b branch &&
+	test_commit -C shallow-server C &&
+	test_commit -C shallow-server E &&
+	test_commit -C shallow-server D &&
+	d="$(git -C shallow-server rev-parse --verify D^0)" &&
+	git -C shallow-server checkout master &&
+
+	git clone --depth=1 --no-tags --no-single-branch \
+		"file://$PWD/shallow-server" shallow-client &&
+
+	: now remove the branch and fetch with prune &&
+	git -C shallow-server branch -D branch &&
+	git -C shallow-client fetch --prune --depth=1 \
+		origin "+refs/heads/*:refs/remotes/origin/*" &&
+	git -C shallow-client repack -adfl &&
+	test_must_fail git -C shallow-client rev-parse --verify $d^0 &&
+	! grep $d shallow-client/.git/shallow &&
+
+	git -C shallow-server branch branch-orig $d &&
+	git -C shallow-client fetch --prune --depth=2 \
+		origin "+refs/heads/*:refs/remotes/origin/*"
+'
+
+. "$TEST_DIRECTORY"/lib-httpd.sh
+start_httpd
+
+REPO="$HTTPD_DOCUMENT_ROOT_PATH/repo"
+
+test_expect_success 'shallow fetches check connectivity before writing shallow file' '
+	rm -rf "$REPO" client &&
+
+	git init "$REPO" &&
+	test_commit -C "$REPO" one &&
+	test_commit -C "$REPO" two &&
+	test_commit -C "$REPO" three &&
+
+	git init client &&
+
+	# Use protocol v2 to ensure that shallow information is sent exactly
+	# once by the server, since we are planning to manipulate it.
+	git -C "$REPO" config protocol.version 2 &&
+	git -C client config protocol.version 2 &&
+
+	git -C client fetch --depth=2 "$HTTPD_URL/one_time_sed/repo" master:a_branch &&
+
+	# Craft a situation in which the server sends back an unshallow request
+	# with an empty packfile. This is done by refetching with a shorter
+	# depth (to ensure that the packfile is empty), and overwriting the
+	# shallow line in the response with the unshallow line we want.
+	printf "s/0034shallow %s/0036unshallow %s/" \
+	       "$(git -C "$REPO" rev-parse HEAD)" \
+	       "$(git -C "$REPO" rev-parse HEAD^)" \
+	       >"$HTTPD_ROOT_PATH/one-time-sed" &&
+	test_must_fail env GIT_TEST_SIDEBAND_ALL=0 git -C client \
+		fetch --depth=1 "$HTTPD_URL/one_time_sed/repo" \
+		master:a_branch &&
+
+	# Ensure that the one-time-sed script was used.
+	! test -e "$HTTPD_ROOT_PATH/one-time-sed" &&
+
+	# Ensure that the resulting repo is consistent, despite our failure to
+	# fetch.
+	git -C client fsck
+'
+
+# DO NOT add non-httpd-specific tests here, because the last part of this
+# test script is only executed when httpd is available and enabled.
+
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t5539-fetch-http-shallow.sh 1.2.3+git2.25.1-1/git/t/t5539-fetch-http-shallow.sh
--- 1.2.1+git2.18.0-1/git/t/t5539-fetch-http-shallow.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t5539-fetch-http-shallow.sh	2020-02-17 04:47:35.000000000 +0000
@@ -67,7 +67,10 @@ test_expect_success 'no shallow lines af
 		cd clone &&
 		git checkout --orphan newnew &&
 		test_commit new-too &&
-		GIT_TRACE_PACKET="$TRASH_DIRECTORY/trace" git fetch --depth=2 &&
+		# NEEDSWORK: If the overspecification of the expected result is reduced, we
+		# might be able to run this test in all protocol versions.
+		GIT_TRACE_PACKET="$TRASH_DIRECTORY/trace" GIT_TEST_PROTOCOL_VERSION= \
+			git fetch --depth=2 &&
 		grep "fetch-pack< ACK .* ready" ../trace &&
 		! grep "fetch-pack> done" ../trace
 	)
@@ -146,5 +149,4 @@ test_expect_success 'fetching deepen' '
 	)
 '
 
-stop_httpd
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t5540-http-push-webdav.sh 1.2.3+git2.25.1-1/git/t/t5540-http-push-webdav.sh
--- 1.2.1+git2.18.0-1/git/t/t5540-http-push-webdav.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t5540-http-push-webdav.sh	2020-02-17 04:47:35.000000000 +0000
@@ -176,6 +176,4 @@ test_expect_failure 'push to password-pr
 	test_cmp expect actual
 '
 
-stop_httpd
-
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t5541-http-push-smart.sh 1.2.3+git2.25.1-1/git/t/t5541-http-push-smart.sh
--- 1.2.1+git2.18.0-1/git/t/t5541-http-push-smart.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t5541-http-push-smart.sh	2020-02-17 04:47:35.000000000 +0000
@@ -38,25 +38,21 @@ GET  /smart/test_repo.git/info/refs?serv
 POST /smart/test_repo.git/git-upload-pack HTTP/1.1 200
 EOF
 test_expect_success 'no empty path components' '
+	# Clear the log, so that it does not affect the "used receive-pack
+	# service" test which reads the log too.
+	test_when_finished ">\"\$HTTPD_ROOT_PATH\"/access.log" &&
+
 	# In the URL, add a trailing slash, and see if git appends yet another
 	# slash.
 	cd "$ROOT_PATH" &&
 	git clone $HTTPD_URL/smart/test_repo.git/ test_repo_clone &&
 
-	sed -e "
-		s/^.* \"//
-		s/\"//
-		s/ [1-9][0-9]*\$//
-		s/^GET /GET  /
-	" >act <"$HTTPD_ROOT_PATH"/access.log &&
-
-	# Clear the log, so that it does not affect the "used receive-pack
-	# service" test which reads the log too.
-	#
-	# We do this before the actual comparison to ensure the log is cleared.
-	echo > "$HTTPD_ROOT_PATH"/access.log &&
-
-	test_cmp exp act
+	# NEEDSWORK: If the overspecification of the expected result is reduced, we
+	# might be able to run this test in all protocol versions.
+	if test -z "$GIT_TEST_PROTOCOL_VERSION"
+	then
+		check_access_log exp
+	fi
 '
 
 test_expect_success 'clone remote repository' '
@@ -124,7 +120,6 @@ test_expect_success 'rejected update pri
 rm -f "$HTTPD_DOCUMENT_ROOT_PATH/test_repo.git/hooks/update"
 
 cat >exp <<EOF
-
 GET  /smart/test_repo.git/info/refs?service=git-upload-pack HTTP/1.1 200
 POST /smart/test_repo.git/git-upload-pack HTTP/1.1 200
 GET  /smart/test_repo.git/info/refs?service=git-receive-pack HTTP/1.1 200
@@ -138,13 +133,12 @@ GET  /smart/test_repo.git/info/refs?serv
 POST /smart/test_repo.git/git-receive-pack HTTP/1.1 200
 EOF
 test_expect_success 'used receive-pack service' '
-	sed -e "
-		s/^.* \"//
-		s/\"//
-		s/ [1-9][0-9]*\$//
-		s/^GET /GET  /
-	" >act <"$HTTPD_ROOT_PATH"/access.log &&
-	test_cmp exp act
+	# NEEDSWORK: If the overspecification of the expected result is reduced, we
+	# might be able to run this test in all protocol versions.
+	if test -z "$GIT_TEST_PROTOCOL_VERSION"
+	then
+		check_access_log exp
+	fi
 '
 
 test_http_push_nonff "$HTTPD_DOCUMENT_ROOT_PATH"/test_repo.git \
@@ -183,6 +177,91 @@ test_expect_success 'push (chunked)' '
 	 test $HEAD = $(git rev-parse --verify HEAD))
 '
 
+test_expect_success 'push --atomic also prevents branch creation, reports collateral' '
+	# Setup upstream repo - empty for now
+	d=$HTTPD_DOCUMENT_ROOT_PATH/atomic-branches.git &&
+	git init --bare "$d" &&
+	test_config -C "$d" http.receivepack true &&
+	up="$HTTPD_URL"/smart/atomic-branches.git &&
+
+	# Tell "$up" about three branches for now
+	test_commit atomic1 &&
+	test_commit atomic2 &&
+	git branch collateral &&
+	git branch other &&
+	git push "$up" master collateral other &&
+
+	# collateral is a valid push, but should be failed by atomic push
+	git checkout collateral &&
+	test_commit collateral1 &&
+
+	# Make master incompatible with upstream to provoke atomic
+	git checkout master &&
+	git reset --hard HEAD^ &&
+
+	# Add a new branch which should be failed by atomic push. This is a
+	# regression case.
+	git branch atomic &&
+
+	# --atomic should cause entire push to be rejected
+	test_must_fail git push --atomic "$up" master atomic collateral 2>output &&
+
+	# the new branch should not have been created upstream
+	test_must_fail git -C "$d" show-ref --verify refs/heads/atomic &&
+
+	# upstream should still reflect atomic2, the last thing we pushed
+	# successfully
+	git rev-parse atomic2 >expected &&
+	# on master...
+	git -C "$d" rev-parse refs/heads/master >actual &&
+	test_cmp expected actual &&
+	# ...and collateral.
+	git -C "$d" rev-parse refs/heads/collateral >actual &&
+	test_cmp expected actual &&
+
+	# the failed refs should be indicated to the user
+	grep "^ ! .*rejected.* master -> master" output &&
+
+	# the collateral failure refs should be indicated to the user
+	grep "^ ! .*rejected.* atomic -> atomic .*atomic push failed" output &&
+	grep "^ ! .*rejected.* collateral -> collateral .*atomic push failed" output
+'
+
+test_expect_success 'push --atomic fails on server-side errors' '
+	# Use previously set up repository
+	d=$HTTPD_DOCUMENT_ROOT_PATH/atomic-branches.git &&
+	test_config -C "$d" http.receivepack true &&
+	up="$HTTPD_URL"/smart/atomic-branches.git &&
+
+	# break ref updates for other on the remote site
+	mkdir "$d/refs/heads/other.lock" &&
+
+	# add the new commit to other
+	git branch -f other collateral &&
+
+	# --atomic should cause entire push to be rejected
+	test_must_fail git push --atomic "$up" atomic other 2>output  &&
+
+	# the new branch should not have been created upstream
+	test_must_fail git -C "$d" show-ref --verify refs/heads/atomic &&
+
+	# upstream should still reflect atomic2, the last thing we pushed
+	# successfully
+	git rev-parse atomic2 >expected &&
+	# ...to other.
+	git -C "$d" rev-parse refs/heads/other >actual &&
+	test_cmp expected actual &&
+
+	# the new branch should not have been created upstream
+	test_must_fail git -C "$d" show-ref --verify refs/heads/atomic &&
+
+	# the failed refs should be indicated to the user
+	grep "^ ! .*rejected.* other -> other .*atomic transaction failed" output &&
+
+	# the collateral failure refs should be indicated to the user
+	grep "^ ! .*rejected.* atomic -> atomic .*atomic transaction failed" output
+'
+
 test_expect_success 'push --all can push to empty repo' '
 	d=$HTTPD_DOCUMENT_ROOT_PATH/empty-all.git &&
 	git init --bare "$d" &&
@@ -226,7 +305,7 @@ test_expect_success TTY 'push --quiet si
 	cd "$ROOT_PATH"/test_repo_clone &&
 	test_commit quiet &&
 	test_terminal git push --quiet >output 2>&1 &&
-	test_cmp /dev/null output
+	test_must_be_empty output
 '
 
 test_expect_success TTY 'push --no-progress silences progress but not status' '
@@ -389,5 +468,4 @@ test_expect_success 'colorize errors/hin
 	test_i18ngrep ! "^hint: " decoded
 '
 
-stop_httpd
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t5542-push-http-shallow.sh 1.2.3+git2.25.1-1/git/t/t5542-push-http-shallow.sh
--- 1.2.1+git2.18.0-1/git/t/t5542-push-http-shallow.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t5542-push-http-shallow.sh	2020-02-17 04:47:35.000000000 +0000
@@ -90,5 +90,4 @@ EOF
 	)
 '
 
-stop_httpd
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t5543-atomic-push.sh 1.2.3+git2.25.1-1/git/t/t5543-atomic-push.sh
--- 1.2.1+git2.18.0-1/git/t/t5543-atomic-push.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t5543-atomic-push.sh	2020-02-17 04:47:35.000000000 +0000
@@ -178,7 +178,7 @@ test_expect_success 'atomic push obeys u
 test_expect_success 'atomic push is not advertised if configured' '
 	mk_repo_pair &&
 	(
-		cd upstream
+		cd upstream &&
 		git config receive.advertiseatomic 0
 	) &&
 	(
diff -pruN 1.2.1+git2.18.0-1/git/t/t5545-push-options.sh 1.2.3+git2.25.1-1/git/t/t5545-push-options.sh
--- 1.2.1+git2.18.0-1/git/t/t5545-push-options.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t5545-push-options.sh	2020-02-17 04:47:35.000000000 +0000
@@ -115,7 +115,7 @@ test_expect_success 'push options and su
 
 	git -C parent submodule add ../upstream workbench &&
 	git -C parent/workbench remote add up ../../upstream &&
-	git -C parent commit -m "add submoule" &&
+	git -C parent commit -m "add submodule" &&
 
 	test_commit -C parent/workbench two &&
 	git -C parent add workbench &&
@@ -278,6 +278,7 @@ test_expect_success 'push options keep q
 	test_cmp expect "$HTTPD_DOCUMENT_ROOT_PATH"/upstream.git/hooks/pre-receive.push_options
 '
 
-stop_httpd
+# DO NOT add non-httpd-specific tests here, because the last part of this
+# test script is only executed when httpd is available and enabled.
 
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t5550-http-fetch-dumb.sh 1.2.3+git2.25.1-1/git/t/t5550-http-fetch-dumb.sh
--- 1.2.1+git2.18.0-1/git/t/t5550-http-fetch-dumb.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t5550-http-fetch-dumb.sh	2020-02-17 04:47:35.000000000 +0000
@@ -408,5 +408,20 @@ test_expect_success 'print HTTP error wh
 	test_i18ngrep "unable to access.*/redir-to/502" stderr
 '
 
-stop_httpd
+test_expect_success 'fetching via http alternates works' '
+	parent=$HTTPD_DOCUMENT_ROOT_PATH/alt-parent.git &&
+	git init --bare "$parent" &&
+	git -C "$parent" --work-tree=. commit --allow-empty -m foo &&
+	git -C "$parent" update-server-info &&
+	commit=$(git -C "$parent" rev-parse HEAD) &&
+
+	child=$HTTPD_DOCUMENT_ROOT_PATH/alt-child.git &&
+	git init --bare "$child" &&
+	echo "../../alt-parent.git/objects" >"$child/objects/info/alternates" &&
+	git -C "$child" update-ref HEAD $commit &&
+	git -C "$child" update-server-info &&
+
+	git -c http.followredirects=true clone "$HTTPD_URL/dumb/alt-child.git"
+'
+
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t5551-http-fetch-smart.sh 1.2.3+git2.25.1-1/git/t/t5551-http-fetch-smart.sh
--- 1.2.1+git2.18.0-1/git/t/t5551-http-fetch-smart.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t5551-http-fetch-smart.sh	2020-02-17 04:47:35.000000000 +0000
@@ -23,27 +23,28 @@ test_expect_success 'create http-accessi
 
 setup_askpass_helper
 
-cat >exp <<EOF
-> GET /smart/repo.git/info/refs?service=git-upload-pack HTTP/1.1
-> Accept: */*
-> Accept-Encoding: ENCODINGS
-> Pragma: no-cache
-< HTTP/1.1 200 OK
-< Pragma: no-cache
-< Cache-Control: no-cache, max-age=0, must-revalidate
-< Content-Type: application/x-git-upload-pack-advertisement
-> POST /smart/repo.git/git-upload-pack HTTP/1.1
-> Accept-Encoding: ENCODINGS
-> Content-Type: application/x-git-upload-pack-request
-> Accept: application/x-git-upload-pack-result
-> Content-Length: xxx
-< HTTP/1.1 200 OK
-< Pragma: no-cache
-< Cache-Control: no-cache, max-age=0, must-revalidate
-< Content-Type: application/x-git-upload-pack-result
-EOF
 test_expect_success 'clone http repository' '
-	GIT_TRACE_CURL=true git clone --quiet $HTTPD_URL/smart/repo.git clone 2>err &&
+	cat >exp <<-\EOF &&
+	> GET /smart/repo.git/info/refs?service=git-upload-pack HTTP/1.1
+	> Accept: */*
+	> Accept-Encoding: ENCODINGS
+	> Pragma: no-cache
+	< HTTP/1.1 200 OK
+	< Pragma: no-cache
+	< Cache-Control: no-cache, max-age=0, must-revalidate
+	< Content-Type: application/x-git-upload-pack-advertisement
+	> POST /smart/repo.git/git-upload-pack HTTP/1.1
+	> Accept-Encoding: ENCODINGS
+	> Content-Type: application/x-git-upload-pack-request
+	> Accept: application/x-git-upload-pack-result
+	> Content-Length: xxx
+	< HTTP/1.1 200 OK
+	< Pragma: no-cache
+	< Cache-Control: no-cache, max-age=0, must-revalidate
+	< Content-Type: application/x-git-upload-pack-result
+	EOF
+	GIT_TRACE_CURL=true GIT_TEST_PROTOCOL_VERSION= \
+		git clone --quiet $HTTPD_URL/smart/repo.git clone 2>err &&
 	test_cmp file clone/file &&
 	tr '\''\015'\'' Q <err |
 	sed -e "
@@ -80,12 +81,18 @@ test_expect_success 'clone http reposito
 		/^< Content-Length: /d
 		/^< Transfer-Encoding: /d
 	" >actual &&
-	sed -e "s/^> Accept-Encoding: .*/> Accept-Encoding: ENCODINGS/" \
-			actual >actual.smudged &&
-	test_cmp exp actual.smudged &&
 
-	grep "Accept-Encoding:.*gzip" actual >actual.gzip &&
-	test_line_count = 2 actual.gzip
+	# NEEDSWORK: If the overspecification of the expected result is reduced, we
+	# might be able to run this test in all protocol versions.
+	if test -z "$GIT_TEST_PROTOCOL_VERSION"
+	then
+		sed -e "s/^> Accept-Encoding: .*/> Accept-Encoding: ENCODINGS/" \
+				actual >actual.smudged &&
+		test_cmp exp actual.smudged &&
+
+		grep "Accept-Encoding:.*gzip" actual >actual.gzip &&
+		test_line_count = 2 actual.gzip
+	fi
 '
 
 test_expect_success 'fetch changes via http' '
@@ -96,20 +103,20 @@ test_expect_success 'fetch changes via h
 	test_cmp file clone/file
 '
 
-cat >exp <<EOF
-GET  /smart/repo.git/info/refs?service=git-upload-pack HTTP/1.1 200
-POST /smart/repo.git/git-upload-pack HTTP/1.1 200
-GET  /smart/repo.git/info/refs?service=git-upload-pack HTTP/1.1 200
-POST /smart/repo.git/git-upload-pack HTTP/1.1 200
-EOF
 test_expect_success 'used upload-pack service' '
-	sed -e "
-		s/^.* \"//
-		s/\"//
-		s/ [1-9][0-9]*\$//
-		s/^GET /GET  /
-	" >act <"$HTTPD_ROOT_PATH"/access.log &&
-	test_cmp exp act
+	cat >exp <<-\EOF &&
+	GET  /smart/repo.git/info/refs?service=git-upload-pack HTTP/1.1 200
+	POST /smart/repo.git/git-upload-pack HTTP/1.1 200
+	GET  /smart/repo.git/info/refs?service=git-upload-pack HTTP/1.1 200
+	POST /smart/repo.git/git-upload-pack HTTP/1.1 200
+	EOF
+
+	# NEEDSWORK: If the overspecification of the expected result is reduced, we
+	# might be able to run this test in all protocol versions.
+	if test -z "$GIT_TEST_PROTOCOL_VERSION"
+	then
+		check_access_log exp
+	fi
 '
 
 test_expect_success 'follow redirects (301)' '
@@ -157,7 +164,17 @@ test_expect_success 'clone from auth-onl
 
 test_expect_success 'no-op half-auth fetch does not require a password' '
 	set_askpass wrong &&
-	git --git-dir=half-auth fetch &&
+
+	# NEEDSWORK: When using HTTP(S), protocol v0 supports a "half-auth"
+	# configuration with authentication required only when downloading
+	# objects and not refs, by having the HTTP server only require
+	# authentication for the "git-upload-pack" path and not "info/refs".
+	# This is not possible with protocol v2, since both objects and refs
+	# are obtained from the "git-upload-pack" path. A solution to this is
+	# to teach the server and client to be able to inline ls-refs requests
+	# as an Extra Parameter (see pack-protocol.txt), so that "info/refs"
+	# can serve refs, just like it does in protocol v0.
+	GIT_TEST_PROTOCOL_VERSION=0 git --git-dir=half-auth fetch &&
 	expect_askpass none
 '
 
@@ -182,7 +199,7 @@ test_expect_success 'GIT_SMART_HTTP can
 
 test_expect_success 'invalid Content-Type rejected' '
 	test_must_fail git clone $HTTPD_URL/broken_smart/repo.git 2>actual &&
-	grep "not valid:" actual
+	test_i18ngrep "not valid:" actual
 '
 
 test_expect_success 'create namespaced refs' '
@@ -209,20 +226,26 @@ test_expect_success 'dumb clone via http
 	test_cmp expect actual
 '
 
-cat >cookies.txt <<EOF
-127.0.0.1	FALSE	/smart_cookies/	FALSE	0	othername	othervalue
-EOF
-cat >expect_cookies.txt <<EOF
-
-127.0.0.1	FALSE	/smart_cookies/	FALSE	0	othername	othervalue
-127.0.0.1	FALSE	/smart_cookies/repo.git/info/	FALSE	0	name	value
-EOF
 test_expect_success 'cookies stored in http.cookiefile when http.savecookies set' '
+	cat >cookies.txt <<-\EOF &&
+	127.0.0.1	FALSE	/smart_cookies/	FALSE	0	othername	othervalue
+	EOF
+	sort >expect_cookies.txt <<-\EOF &&
+
+	127.0.0.1	FALSE	/smart_cookies/	FALSE	0	othername	othervalue
+	127.0.0.1	FALSE	/smart_cookies/repo.git/info/	FALSE	0	name	value
+	EOF
 	git config http.cookiefile cookies.txt &&
 	git config http.savecookies true &&
 	git ls-remote $HTTPD_URL/smart_cookies/repo.git master &&
-	tail -3 cookies.txt >cookies_tail.txt &&
-	test_cmp expect_cookies.txt cookies_tail.txt
+
+	# NEEDSWORK: If the overspecification of the expected result is reduced, we
+	# might be able to run this test in all protocol versions.
+	if test -z "$GIT_TEST_PROTOCOL_VERSION"
+	then
+		tail -3 cookies.txt | sort >cookies_tail.txt &&
+		test_cmp expect_cookies.txt cookies_tail.txt
+	fi
 '
 
 test_expect_success 'transfer.hiderefs works over smart-http' '
@@ -278,11 +301,10 @@ test_expect_success CMDLINE_LIMIT \
 	)
 '
 
-test_expect_success 'large fetch-pack requests can be split across POSTs' '
+test_expect_success 'large fetch-pack requests can be sent using chunked encoding' '
 	GIT_TRACE_CURL=true git -c http.postbuffer=65536 \
 		clone --bare "$HTTPD_URL/smart/repo.git" split.git 2>err &&
-	grep "^=> Send header: POST" err >posts &&
-	test_line_count = 2 posts
+	grep "^=> Send header: Transfer-Encoding: chunked" err
 '
 
 test_expect_success 'test allowreachablesha1inwant' '
@@ -312,7 +334,10 @@ test_expect_success 'test allowreachable
 
 	git init --bare test_reachable.git &&
 	git -C test_reachable.git remote add origin "$HTTPD_URL/smart/repo.git" &&
-	test_must_fail git -C test_reachable.git fetch origin "$(git rev-parse HEAD)"
+	# Some protocol versions (e.g. 2) support fetching
+	# unadvertised objects, so restrict this test to v0.
+	test_must_fail env GIT_TEST_PROTOCOL_VERSION= \
+		git -C test_reachable.git fetch origin "$(git rev-parse HEAD)"
 '
 
 test_expect_success 'test allowanysha1inwant with unreachable' '
@@ -331,7 +356,10 @@ test_expect_success 'test allowanysha1in
 
 	git init --bare test_reachable.git &&
 	git -C test_reachable.git remote add origin "$HTTPD_URL/smart/repo.git" &&
-	test_must_fail git -C test_reachable.git fetch origin "$(git rev-parse HEAD)" &&
+	# Some protocol versions (e.g. 2) support fetching
+	# unadvertised objects, so restrict this test to v0.
+	test_must_fail env GIT_TEST_PROTOCOL_VERSION= \
+		git -C test_reachable.git fetch origin "$(git rev-parse HEAD)" &&
 
 	git -C "$server" config uploadpack.allowanysha1inwant 1 &&
 	git -C test_reachable.git fetch origin "$(git rev-parse HEAD)"
@@ -369,6 +397,39 @@ test_expect_success 'custom http headers
 		submodule update sub
 '
 
+test_expect_success 'using fetch command in remote-curl updates refs' '
+	SERVER="$HTTPD_DOCUMENT_ROOT_PATH/twobranch" &&
+	rm -rf "$SERVER" client &&
+
+	git init "$SERVER" &&
+	test_commit -C "$SERVER" foo &&
+	git -C "$SERVER" update-ref refs/heads/anotherbranch foo &&
+
+	git clone $HTTPD_URL/smart/twobranch client &&
+
+	test_commit -C "$SERVER" bar &&
+	git -C client -c protocol.version=0 fetch &&
+
+	git -C "$SERVER" rev-parse master >expect &&
+	git -C client rev-parse origin/master >actual &&
+	test_cmp expect actual
+'
+
+test_expect_success 'fetch by SHA-1 without tag following' '
+	SERVER="$HTTPD_DOCUMENT_ROOT_PATH/server" &&
+	rm -rf "$SERVER" client &&
+
+	git init "$SERVER" &&
+	test_commit -C "$SERVER" foo &&
+
+	git clone $HTTPD_URL/smart/server client &&
+
+	test_commit -C "$SERVER" bar &&
+	git -C "$SERVER" rev-parse bar >bar_hash &&
+	git -C client -c protocol.version=0 fetch \
+		--no-tags origin $(cat bar_hash)
+'
+
 test_expect_success 'GIT_REDACT_COOKIES redacts cookies' '
 	rm -rf clone &&
 	echo "Set-Cookie: Foo=1" >cookies &&
@@ -402,5 +463,9 @@ test_expect_success 'GIT_TRACE_CURL_NO_D
 	! grep "=> Send data" err
 '
 
-stop_httpd
+test_expect_success 'server-side error detected' '
+	test_must_fail git clone $HTTPD_URL/error_smart/repo.git 2>actual &&
+	test_i18ngrep "server-side error" actual
+'
+
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t5552-skipping-fetch-negotiator.sh 1.2.3+git2.25.1-1/git/t/t5552-skipping-fetch-negotiator.sh
--- 1.2.1+git2.18.0-1/git/t/t5552-skipping-fetch-negotiator.sh	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t5552-skipping-fetch-negotiator.sh	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,195 @@
+#!/bin/sh
+
+test_description='test skipping fetch negotiator'
+. ./test-lib.sh
+
+have_sent () {
+	while test "$#" -ne 0
+	do
+		grep "fetch> have $(git -C client rev-parse $1)" trace
+		if test $? -ne 0
+		then
+			echo "No have $(git -C client rev-parse $1) ($1)"
+			return 1
+		fi
+		shift
+	done
+}
+
+have_not_sent () {
+	while test "$#" -ne 0
+	do
+		grep "fetch> have $(git -C client rev-parse $1)" trace
+		if test $? -eq 0
+		then
+			return 1
+		fi
+		shift
+	done
+}
+
+# trace_fetch <client_dir> <server_dir> [args]
+#
+# Trace the packet output of fetch, but make sure we disable the variable
+# in the child upload-pack, so we don't combine the results in the same file.
+trace_fetch () {
+	client=$1; shift
+	server=$1; shift
+	GIT_TRACE_PACKET="$(pwd)/trace" \
+	git -C "$client" fetch \
+	  --upload-pack 'unset GIT_TRACE_PACKET; git-upload-pack' \
+	  "$server" "$@"
+}
+
+test_expect_success 'commits with no parents are sent regardless of skip distance' '
+	git init server &&
+	test_commit -C server to_fetch &&
+
+	git init client &&
+	for i in $(test_seq 7)
+	do
+		test_commit -C client c$i
+	done &&
+
+	# We send: "c7" (skip 1) "c5" (skip 2) "c2" (skip 4). After that, since
+	# "c1" has no parent, it is still sent as "have" even though it would
+	# normally be skipped.
+	test_config -C client fetch.negotiationalgorithm skipping &&
+	trace_fetch client "$(pwd)/server" &&
+	have_sent c7 c5 c2 c1 &&
+	have_not_sent c6 c4 c3
+'
+
+test_expect_success 'when two skips collide, favor the larger one' '
+	rm -rf server client trace &&
+	git init server &&
+	test_commit -C server to_fetch &&
+
+	git init client &&
+	for i in $(test_seq 11)
+	do
+		test_commit -C client c$i
+	done &&
+	git -C client checkout c5 &&
+	test_commit -C client c5side &&
+
+	# Before reaching c5, we send "c5side" (skip 1) and "c11" (skip 1) "c9"
+	# (skip 2) "c6" (skip 4). The larger skip (skip 4) takes precedence, so
+	# the next "have" sent will be "c1" (from "c6" skip 4) and not "c4"
+	# (from "c5side" skip 1).
+	test_config -C client fetch.negotiationalgorithm skipping &&
+	trace_fetch client "$(pwd)/server" &&
+	have_sent c5side c11 c9 c6 c1 &&
+	have_not_sent c10 c8 c7 c5 c4 c3 c2
+'
+
+test_expect_success 'use ref advertisement to filter out commits' '
+	rm -rf server client trace &&
+	git init server &&
+	test_commit -C server c1 &&
+	test_commit -C server c2 &&
+	test_commit -C server c3 &&
+	git -C server tag -d c1 c2 c3 &&
+
+	git clone server client &&
+	test_commit -C client c4 &&
+	test_commit -C client c5 &&
+	git -C client checkout c4^^ &&
+	test_commit -C client c2side &&
+
+	git -C server checkout --orphan anotherbranch &&
+	test_commit -C server to_fetch &&
+
+	# The server advertising "c3" (as "refs/heads/master") means that we do
+	# not need to send any ancestors of "c3", but we still need to send "c3"
+	# itself.
+	test_config -C client fetch.negotiationalgorithm skipping &&
+
+	# The ref advertisement itself is filtered when protocol v2 is used, so
+	# use v0.
+	GIT_TEST_PROTOCOL_VERSION= trace_fetch client origin to_fetch &&
+	have_sent c5 c4^ c2side &&
+	have_not_sent c4 c4^^ c4^^^
+'
+
+test_expect_success 'handle clock skew' '
+	rm -rf server client trace &&
+	git init server &&
+	test_commit -C server to_fetch &&
+
+	git init client &&
+
+	# 2 regular commits
+	test_tick=2000000000 &&
+	test_commit -C client c1 &&
+	test_commit -C client c2 &&
+
+	# 4 old commits
+	test_tick=1000000000 &&
+	git -C client checkout c1 &&
+	test_commit -C client old1 &&
+	test_commit -C client old2 &&
+	test_commit -C client old3 &&
+	test_commit -C client old4 &&
+
+	# "c2" and "c1" are popped first, then "old4" to "old1". "old1" would
+	# normally be skipped, but is treated as a commit without a parent here
+	# and sent, because (due to clock skew) its only parent has already been
+	# popped off the priority queue.
+	test_config -C client fetch.negotiationalgorithm skipping &&
+	trace_fetch client "$(pwd)/server" &&
+	have_sent c2 c1 old4 old2 old1 &&
+	have_not_sent old3
+'
+
+test_expect_success 'do not send "have" with ancestors of commits that server ACKed' '
+	rm -rf server client trace &&
+	git init server &&
+	test_commit -C server to_fetch &&
+
+	git init client &&
+	for i in $(test_seq 8)
+	do
+		git -C client checkout --orphan b$i &&
+		test_commit -C client b$i.c0
+	done &&
+	for j in $(test_seq 19)
+	do
+		for i in $(test_seq 8)
+		do
+			git -C client checkout b$i &&
+			test_commit -C client b$i.c$j
+		done
+	done &&
+
+	# Copy this branch over to the server and add a commit on it so that it
+	# is reachable but not advertised.
+	git -C server fetch --no-tags "$(pwd)/client" b1:refs/heads/b1 &&
+	git -C server checkout b1 &&
+	test_commit -C server commit-on-b1 &&
+
+	test_config -C client fetch.negotiationalgorithm skipping &&
+	trace_fetch client "$(pwd)/server" to_fetch &&
+	grep "  fetch" trace &&
+
+	# fetch-pack sends 2 requests each containing 16 "have" lines before
+	# processing the first response. In these 2 requests, 4 commits from
+	# each branch are sent. Just check the first branch.
+	have_sent b1.c19 b1.c17 b1.c14 b1.c9 &&
+	have_not_sent b1.c18 b1.c16 b1.c15 b1.c13 b1.c12 b1.c11 b1.c10 &&
+
+	# While fetch-pack is processing the first response, it should read that
+	# the server ACKs b1.c19 and b1.c17.
+	grep "fetch< ACK $(git -C client rev-parse b1.c19) common" trace &&
+	grep "fetch< ACK $(git -C client rev-parse b1.c17) common" trace &&
+
+	# fetch-pack should thus not send any more commits in the b1 branch, but
+	# should still send the others (in this test, just check b2).
+	for i in $(test_seq 0 8)
+	do
+		have_not_sent b1.c$i
+	done &&
+	have_sent b2.c1 b2.c0
+'
+
+test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t5553-set-upstream.sh 1.2.3+git2.25.1-1/git/t/t5553-set-upstream.sh
--- 1.2.1+git2.18.0-1/git/t/t5553-set-upstream.sh	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t5553-set-upstream.sh	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,178 @@
+#!/bin/sh
+
+test_description='"git fetch/pull --set-upstream" basic tests.'
+. ./test-lib.sh
+
+check_config () {
+	printf "%s\n" "$2" "$3" >"expect.$1" &&
+	{
+		git config "branch.$1.remote" && git config "branch.$1.merge"
+	} >"actual.$1" &&
+	test_cmp "expect.$1" "actual.$1"
+}
+
+check_config_missing () {
+	test_expect_code 1 git config "branch.$1.remote" &&
+	test_expect_code 1 git config "branch.$1.merge"
+}
+
+clear_config () {
+	for branch in "$@"; do
+		test_might_fail git config --unset-all "branch.$branch.remote"
+		test_might_fail git config --unset-all "branch.$branch.merge"
+	done
+}
+
+ensure_fresh_upstream () {
+	rm -rf parent && git init --bare parent
+}
+
+test_expect_success 'setup bare parent fetch' '
+	ensure_fresh_upstream &&
+	git remote add upstream parent
+'
+
+test_expect_success 'setup commit on master and other fetch' '
+	test_commit one &&
+	git push upstream master &&
+	git checkout -b other &&
+	test_commit two &&
+	git push upstream other
+'
+
+# tests for fetch --set-upstream
+
+test_expect_success 'fetch --set-upstream does not set upstream w/o branch' '
+	clear_config master other &&
+	git checkout master &&
+	git fetch --set-upstream upstream &&
+	check_config_missing master &&
+	check_config_missing other
+'
+
+test_expect_success 'fetch --set-upstream upstream master sets branch master but not other' '
+	clear_config master other &&
+	git fetch --set-upstream upstream master &&
+	check_config master upstream refs/heads/master &&
+	check_config_missing other
+'
+
+test_expect_success 'fetch --set-upstream upstream other sets branch other' '
+	clear_config master other &&
+	git fetch --set-upstream upstream other &&
+	check_config master upstream refs/heads/other &&
+	check_config_missing other
+'
+
+test_expect_success 'fetch --set-upstream master:other does not set the branch other2' '
+	clear_config other2 &&
+	git fetch --set-upstream upstream master:other2 &&
+	check_config_missing other2
+'
+
+test_expect_success 'fetch --set-upstream http://nosuchdomain.example.com fails with invalid url' '
+	# master explicitly not cleared, we check that it is not touched from previous value
+	clear_config other other2 &&
+	test_must_fail git fetch --set-upstream http://nosuchdomain.example.com &&
+	check_config master upstream refs/heads/other &&
+	check_config_missing other &&
+	check_config_missing other2
+'
+
+test_expect_success 'fetch --set-upstream with valid URL sets upstream to URL' '
+	clear_config other other2 &&
+	url="file://'"$PWD"'" &&
+	git fetch --set-upstream "$url" &&
+	check_config master "$url" HEAD &&
+	check_config_missing other &&
+	check_config_missing other2
+'
+
+# tests for pull --set-upstream
+
+test_expect_success 'setup bare parent pull' '
+	git remote rm upstream &&
+	ensure_fresh_upstream &&
+	git remote add upstream parent
+'
+
+test_expect_success 'setup commit on master and other pull' '
+	test_commit three &&
+	git push --tags upstream master &&
+	test_commit four &&
+	git push upstream other
+'
+
+test_expect_success 'pull --set-upstream upstream master sets branch master but not other' '
+	clear_config master other &&
+	git pull --set-upstream upstream master &&
+	check_config master upstream refs/heads/master &&
+	check_config_missing other
+'
+
+test_expect_success 'pull --set-upstream master:other2 does not set the branch other2' '
+	clear_config other2 &&
+	git pull --set-upstream upstream master:other2 &&
+	check_config_missing other2
+'
+
+test_expect_success 'pull --set-upstream upstream other sets branch master' '
+	clear_config master other &&
+	git pull --set-upstream upstream other &&
+	check_config master upstream refs/heads/other &&
+	check_config_missing other
+'
+
+test_expect_success 'pull --set-upstream upstream tag does not set the tag' '
+	clear_config three &&
+	git pull --tags --set-upstream upstream three &&
+	check_config_missing three
+'
+
+test_expect_success 'pull --set-upstream http://nosuchdomain.example.com fails with invalid url' '
+	# master explicitly not cleared, we check that it is not touched from previous value
+	clear_config other other2 three &&
+	test_must_fail git pull --set-upstream http://nosuchdomain.example.com &&
+	check_config master upstream refs/heads/other &&
+	check_config_missing other &&
+	check_config_missing other2 &&
+	check_config_missing three
+'
+
+test_expect_success 'pull --set-upstream upstream HEAD sets branch HEAD' '
+	clear_config master other &&
+	git pull --set-upstream upstream HEAD &&
+	check_config master upstream HEAD &&
+	git checkout other &&
+	git pull --set-upstream upstream HEAD &&
+	check_config other upstream HEAD
+'
+
+test_expect_success 'pull --set-upstream upstream with more than one branch does nothing' '
+	clear_config master three &&
+	git pull --set-upstream upstream master three &&
+	check_config_missing master &&
+	check_config_missing three
+'
+
+test_expect_success 'pull --set-upstream with valid URL sets upstream to URL' '
+	clear_config master other other2 &&
+	git checkout master &&
+	url="file://'"$PWD"'" &&
+	git pull --set-upstream "$url" &&
+	check_config master "$url" HEAD &&
+	check_config_missing other &&
+	check_config_missing other2
+'
+
+test_expect_success 'pull --set-upstream with valid URL and branch sets branch' '
+	clear_config master other other2 &&
+	git checkout master &&
+	url="file://'"$PWD"'" &&
+	git pull --set-upstream "$url" master &&
+	check_config master "$url" refs/heads/master &&
+	check_config_missing other &&
+	check_config_missing other2
+'
+
+test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t5561-http-backend.sh 1.2.3+git2.25.1-1/git/t/t5561-http-backend.sh
--- 1.2.1+git2.18.0-1/git/t/t5561-http-backend.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t5561-http-backend.sh	2020-02-17 04:47:35.000000000 +0000
@@ -129,14 +129,7 @@ GET  /smart/repo.git/info/refs?service=g
 POST /smart/repo.git/git-receive-pack HTTP/1.1 403 -
 EOF
 test_expect_success 'server request log matches test results' '
-	sed -e "
-		s/^.* \"//
-		s/\"//
-		s/ [1-9][0-9]*\$//
-		s/^GET /GET  /
-	" >act <"$HTTPD_ROOT_PATH"/access.log &&
-	test_cmp exp act
+	check_access_log exp
 '
 
-stop_httpd
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t5562/invoke-with-content-length.pl 1.2.3+git2.25.1-1/git/t/t5562/invoke-with-content-length.pl
--- 1.2.1+git2.18.0-1/git/t/t5562/invoke-with-content-length.pl	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t5562/invoke-with-content-length.pl	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,36 @@
+use 5.008;
+use strict;
+use warnings;
+
+my $body_filename = $ARGV[0];
+my @command = @ARGV[1 .. $#ARGV];
+
+# read data
+my $body_size = -s $body_filename;
+$ENV{"CONTENT_LENGTH"} = $body_size;
+open(my $body_fh, "<", $body_filename) or die "Cannot open $body_filename: $!";
+my $body_data;
+defined read($body_fh, $body_data, $body_size) or die "Cannot read $body_filename: $!";
+close($body_fh);
+
+my $exited = 0;
+$SIG{"CHLD"} = sub {
+        $exited = 1;
+};
+
+# write data
+my $pid = open(my $out, "|-", @command);
+{
+        # disable buffering at $out
+        my $old_selected = select;
+        select $out;
+        $| = 1;
+        select $old_selected;
+}
+print $out $body_data or die "Cannot write data: $!";
+
+sleep 60; # is interrupted by SIGCHLD
+if (!$exited) {
+        close($out);
+        die "Command did not exit after reading whole body";
+}
diff -pruN 1.2.1+git2.18.0-1/git/t/t5562-http-backend-content-length.sh 1.2.3+git2.25.1-1/git/t/t5562-http-backend-content-length.sh
--- 1.2.1+git2.18.0-1/git/t/t5562-http-backend-content-length.sh	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t5562-http-backend-content-length.sh	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,168 @@
+#!/bin/sh
+
+test_description='test git-http-backend respects CONTENT_LENGTH'
+. ./test-lib.sh
+
+test_lazy_prereq GZIP 'gzip --version'
+
+verify_http_result() {
+	# some fatal errors still produce status 200
+	# so check if there is the error message
+	if grep 'fatal:' act.err.$test_count
+	then
+		return 1
+	fi
+
+	if ! grep "Status" act.out.$test_count >act
+	then
+		printf "Status: 200 OK\r\n" >act
+	fi
+	printf "Status: $1\r\n" >exp &&
+	test_cmp exp act
+}
+
+test_http_env() {
+	handler_type="$1"
+	request_body="$2"
+	shift
+	env \
+		CONTENT_TYPE="application/x-git-$handler_type-pack-request" \
+		QUERY_STRING="/repo.git/git-$handler_type-pack" \
+		PATH_TRANSLATED="$PWD/.git/git-$handler_type-pack" \
+		GIT_HTTP_EXPORT_ALL=TRUE \
+		REQUEST_METHOD=POST \
+		"$PERL_PATH" \
+		"$TEST_DIRECTORY"/t5562/invoke-with-content-length.pl \
+		    "$request_body" git http-backend >act.out.$test_count 2>act.err.$test_count
+}
+
+ssize_b100dots() {
+	# hardcoded ((size_t) SSIZE_MAX) + 1
+	case "$(build_option sizeof-size_t)" in
+	8) echo 9223372036854775808;;
+	4) echo 2147483648;;
+	*) die "Unexpected ssize_t size: $(build_option sizeof-size_t)";;
+	esac
+}
+
+test_expect_success 'setup' '
+	HTTP_CONTENT_ENCODING="identity" &&
+	export HTTP_CONTENT_ENCODING &&
+	git config http.receivepack true &&
+	test_commit c0 &&
+	test_commit c1 &&
+	hash_head=$(git rev-parse HEAD) &&
+	hash_prev=$(git rev-parse HEAD~1) &&
+	printf "want %s" "$hash_head" | packetize >fetch_body &&
+	printf 0000 >>fetch_body &&
+	printf "have %s" "$hash_prev" | packetize >>fetch_body &&
+	printf done | packetize >>fetch_body &&
+	test_copy_bytes 10 <fetch_body >fetch_body.trunc &&
+	hash_next=$(git commit-tree -p HEAD -m next HEAD^{tree}) &&
+	printf "%s %s refs/heads/newbranch\\0report-status\\n" "$_z40" "$hash_next" | packetize >push_body &&
+	printf 0000 >>push_body &&
+	echo "$hash_next" | git pack-objects --stdout >>push_body &&
+	test_copy_bytes 10 <push_body >push_body.trunc &&
+	: >empty_body
+'
+
+test_expect_success GZIP 'setup, compression related' '
+	gzip -c fetch_body >fetch_body.gz &&
+	test_copy_bytes 10 <fetch_body.gz >fetch_body.gz.trunc &&
+	gzip -c push_body >push_body.gz &&
+	test_copy_bytes 10 <push_body.gz >push_body.gz.trunc
+'
+
+test_expect_success 'fetch plain' '
+	test_http_env upload fetch_body &&
+	verify_http_result "200 OK"
+'
+
+test_expect_success 'fetch plain truncated' '
+	test_http_env upload fetch_body.trunc &&
+	! verify_http_result "200 OK"
+'
+
+test_expect_success 'fetch plain empty' '
+	test_http_env upload empty_body &&
+	! verify_http_result "200 OK"
+'
+
+test_expect_success GZIP 'fetch gzipped' '
+	test_env HTTP_CONTENT_ENCODING="gzip" test_http_env upload fetch_body.gz &&
+	verify_http_result "200 OK"
+'
+
+test_expect_success GZIP 'fetch gzipped truncated' '
+	test_env HTTP_CONTENT_ENCODING="gzip" test_http_env upload fetch_body.gz.trunc &&
+	! verify_http_result "200 OK"
+'
+
+test_expect_success GZIP 'fetch gzipped empty' '
+	test_env HTTP_CONTENT_ENCODING="gzip" test_http_env upload empty_body &&
+	! verify_http_result "200 OK"
+'
+
+test_expect_success GZIP 'push plain' '
+	test_when_finished "git branch -D newbranch" &&
+	test_http_env receive push_body &&
+	verify_http_result "200 OK" &&
+	git rev-parse newbranch >act.head &&
+	echo "$hash_next" >exp.head &&
+	test_cmp act.head exp.head
+'
+
+test_expect_success 'push plain truncated' '
+	test_http_env receive push_body.trunc &&
+	! verify_http_result "200 OK"
+'
+
+test_expect_success 'push plain empty' '
+	test_http_env receive empty_body &&
+	! verify_http_result "200 OK"
+'
+
+test_expect_success GZIP 'push gzipped' '
+	test_when_finished "git branch -D newbranch" &&
+	test_env HTTP_CONTENT_ENCODING="gzip" test_http_env receive push_body.gz &&
+	verify_http_result "200 OK" &&
+	git rev-parse newbranch >act.head &&
+	echo "$hash_next" >exp.head &&
+	test_cmp act.head exp.head
+'
+
+test_expect_success GZIP 'push gzipped truncated' '
+	test_env HTTP_CONTENT_ENCODING="gzip" test_http_env receive push_body.gz.trunc &&
+	! verify_http_result "200 OK"
+'
+
+test_expect_success GZIP 'push gzipped empty' '
+	test_env HTTP_CONTENT_ENCODING="gzip" test_http_env receive empty_body &&
+	! verify_http_result "200 OK"
+'
+
+test_expect_success 'CONTENT_LENGTH overflow ssite_t' '
+	NOT_FIT_IN_SSIZE=$(ssize_b100dots) &&
+	env \
+		CONTENT_TYPE=application/x-git-upload-pack-request \
+		QUERY_STRING=/repo.git/git-upload-pack \
+		PATH_TRANSLATED="$PWD"/.git/git-upload-pack \
+		GIT_HTTP_EXPORT_ALL=TRUE \
+		REQUEST_METHOD=POST \
+		CONTENT_LENGTH="$NOT_FIT_IN_SSIZE" \
+		git http-backend </dev/null >/dev/null 2>err &&
+	grep "fatal:.*CONTENT_LENGTH" err
+'
+
+test_expect_success 'empty CONTENT_LENGTH' '
+	env \
+		QUERY_STRING="service=git-receive-pack" \
+		PATH_TRANSLATED="$PWD"/.git/info/refs \
+		GIT_HTTP_EXPORT_ALL=TRUE \
+		REQUEST_METHOD=GET \
+		CONTENT_LENGTH="" \
+		git http-backend <empty_body >act.out.$test_count 2>act.err.$test_count &&
+	verify_http_result "200 OK"
+'
+
+test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t5570-git-daemon.sh 1.2.3+git2.25.1-1/git/t/t5570-git-daemon.sh
--- 1.2.1+git2.18.0-1/git/t/t5570-git-daemon.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t5570-git-daemon.sh	2020-02-17 04:47:35.000000000 +0000
@@ -7,9 +7,9 @@ test_description='test fetching over git
 start_git_daemon
 
 check_verbose_connect () {
-	grep -F "Looking up 127.0.0.1 ..." stderr &&
-	grep -F "Connecting to 127.0.0.1 (port " stderr &&
-	grep -F "done." stderr
+	test_i18ngrep -F "Looking up 127.0.0.1 ..." stderr &&
+	test_i18ngrep -F "Connecting to 127.0.0.1 (port " stderr &&
+	test_i18ngrep -F "done." stderr
 }
 
 test_expect_success 'setup repository' '
@@ -51,7 +51,7 @@ test_expect_success 'no-op fetch -v stde
 
 test_expect_success 'no-op fetch without "-v" is quiet' '
 	(cd clone && git fetch 2>../stderr) &&
-	! test -s stderr
+	test_must_be_empty stderr
 '
 
 test_expect_success 'remote detects correct HEAD' '
@@ -90,6 +90,7 @@ test_expect_success 'fetch notices corru
 test_expect_success 'fetch notices corrupt idx' '
 	cp -R "$GIT_DAEMON_DOCUMENT_ROOT_PATH"/repo_pack.git "$GIT_DAEMON_DOCUMENT_ROOT_PATH"/repo_bad2.git &&
 	(cd "$GIT_DAEMON_DOCUMENT_ROOT_PATH"/repo_bad2.git &&
+	 rm -f objects/pack/multi-pack-index &&
 	 p=$(ls objects/pack/pack-*.idx) &&
 	 chmod u+w $p &&
 	 printf %0256d 0 | dd of=$p bs=256 count=1 seek=1 conv=notrunc
@@ -183,19 +184,6 @@ test_expect_success 'hostname cannot bre
 		git ls-remote "$GIT_DAEMON_URL/escape.git"
 '
 
-test_expect_success 'daemon log records all attributes' '
-	cat >expect <<-\EOF &&
-	Extended attribute "host": localhost
-	Extended attribute "protocol": version=1
-	EOF
-	>daemon.log &&
-	GIT_OVERRIDE_VIRTUAL_HOST=localhost \
-		git -c protocol.version=1 \
-			ls-remote "$GIT_DAEMON_URL/interp.git" &&
-	grep -i extended.attribute daemon.log | cut -d" " -f2- >actual &&
-	test_cmp expect actual
-'
-
 test_expect_success FAKENC 'hostname interpolation works after LF-stripping' '
 	{
 		printf "git-upload-pack /interp.git\n\0host=localhost" | packetize
@@ -211,5 +199,4 @@ test_expect_success FAKENC 'hostname int
 	test_cmp expect actual
 '
 
-stop_git_daemon
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t5573-pull-verify-signatures.sh 1.2.3+git2.25.1-1/git/t/t5573-pull-verify-signatures.sh
--- 1.2.1+git2.18.0-1/git/t/t5573-pull-verify-signatures.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t5573-pull-verify-signatures.sh	2020-02-17 04:47:35.000000000 +0000
@@ -29,7 +29,7 @@ test_expect_success GPG 'create reposito
 		echo 4 >d && git add d &&
 		test_tick && git commit -S -m "bad" &&
 		git cat-file commit HEAD >raw &&
-		sed -e "s/bad/forged bad/" raw >forged &&
+		sed -e "s/^bad/forged bad/" raw >forged &&
 		git hash-object -w -t commit forged >forged.commit &&
 		git checkout $(cat forged.commit)
 	) &&
@@ -78,4 +78,11 @@ test_expect_success GPG 'pull commit wit
 	git pull --ff-only --no-verify-signatures bad 2>pullerror
 '
 
+test_expect_success GPG 'pull unsigned commit into unborn branch' '
+	git init empty-repo &&
+	test_must_fail \
+		git -C empty-repo pull --verify-signatures ..  2>pullerror &&
+	test_i18ngrep "does not have a GPG signature" pullerror
+'
+
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t5580-clone-push-unc.sh 1.2.3+git2.25.1-1/git/t/t5580-clone-push-unc.sh
--- 1.2.1+git2.18.0-1/git/t/t5580-clone-push-unc.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t5580-clone-push-unc.sh	2020-02-17 04:47:35.000000000 +0000
@@ -40,6 +40,11 @@ test_expect_success clone '
 	git clone "file://$UNCPATH" clone
 '
 
+test_expect_success 'clone with backslashed path' '
+	BACKSLASHED="$(echo "$UNCPATH" | tr / \\\\)" &&
+	git clone "$BACKSLASHED" backslashed
+'
+
 test_expect_success push '
 	(
 		cd clone &&
@@ -53,8 +58,20 @@ test_expect_success push '
 
 test_expect_success MINGW 'remote nick cannot contain backslashes' '
 	BACKSLASHED="$(winpwd | tr / \\\\)" &&
-	git ls-remote "$BACKSLASHED" >out 2>err &&
+	git ls-remote "$BACKSLASHED" 2>err &&
 	test_i18ngrep ! "unable to access" err
 '
 
+test_expect_success 'unc alternates' '
+	tree="$(git rev-parse HEAD:)" &&
+	mkdir test-unc-alternate &&
+	(
+		cd test-unc-alternate &&
+		git init &&
+		test_must_fail git show $tree &&
+		echo "$UNCPATH/.git/objects" >.git/objects/info/alternates &&
+		git show $tree
+	)
+'
+
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t5581-http-curl-verbose.sh 1.2.3+git2.25.1-1/git/t/t5581-http-curl-verbose.sh
--- 1.2.1+git2.18.0-1/git/t/t5581-http-curl-verbose.sh	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t5581-http-curl-verbose.sh	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,26 @@
+#!/bin/sh
+
+test_description='test GIT_CURL_VERBOSE'
+. ./test-lib.sh
+. "$TEST_DIRECTORY"/lib-httpd.sh
+start_httpd
+
+test_expect_success 'setup repository' '
+	mkdir "$HTTPD_DOCUMENT_ROOT_PATH/repo.git" &&
+	git -C "$HTTPD_DOCUMENT_ROOT_PATH/repo.git" --bare init &&
+	git config push.default matching &&
+	echo content >file &&
+	git add file &&
+	git commit -m one &&
+	git remote add public "$HTTPD_DOCUMENT_ROOT_PATH/repo.git" &&
+	git push public master:master
+'
+
+test_expect_success 'failure in git-upload-pack is shown' '
+	test_might_fail env GIT_CURL_VERBOSE=1 \
+		git clone "$HTTPD_URL/error_git_upload_pack/smart/repo.git" \
+		2>curl_log &&
+	grep "< HTTP/1.1 500 Intentional Breakage" curl_log
+'
+
+test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t5601-clone.sh 1.2.3+git2.25.1-1/git/t/t5601-clone.sh
--- 1.2.1+git2.18.0-1/git/t/t5601-clone.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t5601-clone.sh	2020-02-17 04:47:35.000000000 +0000
@@ -345,7 +345,7 @@ expect_ssh () {
 }
 
 test_expect_success 'clone myhost:src uses ssh' '
-	git clone myhost:src ssh-clone &&
+	GIT_TEST_PROTOCOL_VERSION=0 git clone myhost:src ssh-clone &&
 	expect_ssh myhost src
 '
 
@@ -356,12 +356,12 @@ test_expect_success !MINGW,!CYGWIN 'clon
 '
 
 test_expect_success 'bracketed hostnames are still ssh' '
-	git clone "[myhost:123]:src" ssh-bracket-clone &&
+	GIT_TEST_PROTOCOL_VERSION=0 git clone "[myhost:123]:src" ssh-bracket-clone &&
 	expect_ssh "-p 123" myhost src
 '
 
 test_expect_success 'OpenSSH variant passes -4' '
-	git clone -4 "[myhost:123]:src" ssh-ipv4-clone &&
+	GIT_TEST_PROTOCOL_VERSION=0 git clone -4 "[myhost:123]:src" ssh-ipv4-clone &&
 	expect_ssh "-4 -p 123" myhost src
 '
 
@@ -405,7 +405,7 @@ test_expect_success 'OpenSSH-like uplink
 	test_when_finished "rm -f \"\$TRASH_DIRECTORY/uplink\"" &&
 	GIT_SSH="$TRASH_DIRECTORY/uplink" &&
 	test_when_finished "GIT_SSH=\"\$TRASH_DIRECTORY/ssh\$X\"" &&
-	git clone "[myhost:123]:src" ssh-bracket-clone-sshlike-uplink &&
+	GIT_TEST_PROTOCOL_VERSION=0 git clone "[myhost:123]:src" ssh-bracket-clone-sshlike-uplink &&
 	expect_ssh "-p 123" myhost src
 '
 
@@ -434,7 +434,6 @@ test_expect_success 'double quoted plink
 	expect_ssh "-v -P 123" myhost src
 '
 
-SQ="'"
 test_expect_success 'single quoted plink.exe in GIT_SSH_COMMAND' '
 	copy_ssh_wrapper_as "$TRASH_DIRECTORY/plink.exe" &&
 	GIT_SSH_COMMAND="$SQ$TRASH_DIRECTORY/plink.exe$SQ -v" \
@@ -444,14 +443,14 @@ test_expect_success 'single quoted plink
 
 test_expect_success 'GIT_SSH_VARIANT overrides plink detection' '
 	copy_ssh_wrapper_as "$TRASH_DIRECTORY/plink" &&
-	GIT_SSH_VARIANT=ssh \
-	git clone "[myhost:123]:src" ssh-bracket-clone-variant-1 &&
+	GIT_TEST_PROTOCOL_VERSION=0 GIT_SSH_VARIANT=ssh \
+		git clone "[myhost:123]:src" ssh-bracket-clone-variant-1 &&
 	expect_ssh "-p 123" myhost src
 '
 
 test_expect_success 'ssh.variant overrides plink detection' '
 	copy_ssh_wrapper_as "$TRASH_DIRECTORY/plink" &&
-	git -c ssh.variant=ssh \
+	GIT_TEST_PROTOCOL_VERSION=0 git -c ssh.variant=ssh \
 		clone "[myhost:123]:src" ssh-bracket-clone-variant-2 &&
 	expect_ssh "-p 123" myhost src
 '
@@ -482,12 +481,12 @@ counter=0
 # $3 path
 test_clone_url () {
 	counter=$(($counter + 1))
-	test_might_fail git clone "$1" tmp$counter &&
+	test_might_fail env GIT_TEST_PROTOCOL_VERSION=0 git clone "$1" tmp$counter &&
 	shift &&
 	expect_ssh "$@"
 }
 
-test_expect_success !MINGW 'clone c:temp is ssl' '
+test_expect_success !MINGW,!CYGWIN 'clone c:temp is ssl' '
 	test_clone_url c:temp c temp
 '
 
@@ -611,26 +610,27 @@ test_expect_success 'GIT_TRACE_PACKFILE
 	git -C replay.git index-pack -v --stdin <tmp.pack
 '
 
-hex2oct () {
-	perl -ne 'printf "\\%03o", hex for /../g'
-}
-
 test_expect_success 'clone on case-insensitive fs' '
 	git init icasefs &&
 	(
-		cd icasefs
+		cd icasefs &&
 		o=$(git hash-object -w --stdin </dev/null | hex2oct) &&
 		t=$(printf "100644 X\0${o}100644 x\0${o}" |
 			git hash-object -w -t tree --stdin) &&
 		c=$(git commit-tree -m bogus $t) &&
 		git update-ref refs/heads/bogus $c &&
-		git clone -b bogus . bogus
+		git clone -b bogus . bogus 2>warning
 	)
 '
 
-partial_clone () {
+test_expect_success CASE_INSENSITIVE_FS 'colliding file detection' '
+	grep X icasefs/warning &&
+	grep x icasefs/warning &&
+	test_i18ngrep "the following paths have collided" icasefs/warning
+'
+
+partial_clone_server () {
 	       SERVER="$1" &&
-	       URL="$2" &&
 
 	rm -rf "$SERVER" client &&
 	test_create_repo "$SERVER" &&
@@ -640,14 +640,21 @@ partial_clone () {
 	test_commit -C "$SERVER" two &&
 	HASH2=$(git hash-object "$SERVER/two.t") &&
 	test_config -C "$SERVER" uploadpack.allowfilter 1 &&
-	test_config -C "$SERVER" uploadpack.allowanysha1inwant 1 &&
+	test_config -C "$SERVER" uploadpack.allowanysha1inwant 1
+}
 
+partial_clone () {
+	       SERVER="$1" &&
+	       URL="$2" &&
+
+	partial_clone_server "${SERVER}" &&
 	git clone --filter=blob:limit=0 "$URL" client &&
 
 	git -C client fsck &&
 
 	# Ensure that unneeded blobs are not inadvertently fetched.
-	test_config -C client extensions.partialclone "not a remote" &&
+	test_config -C client remote.origin.promisor "false" &&
+	git -C client config --unset remote.origin.partialclonefilter &&
 	test_must_fail git -C client cat-file -e "$HASH1" &&
 
 	# But this blob was fetched, because clone performs an initial checkout
@@ -658,6 +665,11 @@ test_expect_success 'partial clone' '
 	partial_clone server "file://$(pwd)/server"
 '
 
+test_expect_success 'partial clone with -o' '
+	partial_clone_server server &&
+	git clone -o blah --filter=blob:limit=0 "file://$(pwd)/server" client
+'
+
 test_expect_success 'partial clone: warn if server does not support object filtering' '
 	rm -rf server client &&
 	test_create_repo server &&
@@ -727,6 +739,7 @@ test_expect_success 'partial clone using
 	partial_clone "$HTTPD_DOCUMENT_ROOT_PATH/server" "$HTTPD_URL/smart/server"
 '
 
-stop_httpd
+# DO NOT add non-httpd-specific tests here, because the last part of this
+# test script is only executed when httpd is available and enabled.
 
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t5604-clone-reference.sh 1.2.3+git2.25.1-1/git/t/t5604-clone-reference.sh
--- 1.2.1+git2.18.0-1/git/t/t5604-clone-reference.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t5604-clone-reference.sh	2020-02-17 04:47:35.000000000 +0000
@@ -221,4 +221,137 @@ test_expect_success 'clone, dissociate f
 	( cd C && git fsck )
 '
 
+test_expect_success 'setup repo with garbage in objects/*' '
+	git init S &&
+	(
+		cd S &&
+		test_commit A &&
+
+		cd .git/objects &&
+		>.some-hidden-file &&
+		>some-file &&
+		mkdir .some-hidden-dir &&
+		>.some-hidden-dir/some-file &&
+		>.some-hidden-dir/.some-dot-file &&
+		mkdir some-dir &&
+		>some-dir/some-file &&
+		>some-dir/.some-dot-file
+	)
+'
+
+test_expect_success 'clone a repo with garbage in objects/*' '
+	for option in --local --no-hardlinks --shared --dissociate
+	do
+		git clone $option S S$option || return 1 &&
+		git -C S$option fsck || return 1
+	done &&
+	find S-* -name "*some*" | sort >actual &&
+	cat >expected <<-EOF &&
+	S--dissociate/.git/objects/.some-hidden-dir
+	S--dissociate/.git/objects/.some-hidden-dir/.some-dot-file
+	S--dissociate/.git/objects/.some-hidden-dir/some-file
+	S--dissociate/.git/objects/.some-hidden-file
+	S--dissociate/.git/objects/some-dir
+	S--dissociate/.git/objects/some-dir/.some-dot-file
+	S--dissociate/.git/objects/some-dir/some-file
+	S--dissociate/.git/objects/some-file
+	S--local/.git/objects/.some-hidden-dir
+	S--local/.git/objects/.some-hidden-dir/.some-dot-file
+	S--local/.git/objects/.some-hidden-dir/some-file
+	S--local/.git/objects/.some-hidden-file
+	S--local/.git/objects/some-dir
+	S--local/.git/objects/some-dir/.some-dot-file
+	S--local/.git/objects/some-dir/some-file
+	S--local/.git/objects/some-file
+	S--no-hardlinks/.git/objects/.some-hidden-dir
+	S--no-hardlinks/.git/objects/.some-hidden-dir/.some-dot-file
+	S--no-hardlinks/.git/objects/.some-hidden-dir/some-file
+	S--no-hardlinks/.git/objects/.some-hidden-file
+	S--no-hardlinks/.git/objects/some-dir
+	S--no-hardlinks/.git/objects/some-dir/.some-dot-file
+	S--no-hardlinks/.git/objects/some-dir/some-file
+	S--no-hardlinks/.git/objects/some-file
+	EOF
+	test_cmp expected actual
+'
+
+test_expect_success SYMLINKS 'setup repo with manually symlinked or unknown files at objects/' '
+	git init T &&
+	(
+		cd T &&
+		git config gc.auto 0 &&
+		test_commit A &&
+		git gc &&
+		test_commit B &&
+
+		cd .git/objects &&
+		mv pack packs &&
+		ln -s packs pack &&
+		find ?? -type d >loose-dirs &&
+		last_loose=$(tail -n 1 loose-dirs) &&
+		mv $last_loose a-loose-dir &&
+		ln -s a-loose-dir $last_loose &&
+		first_loose=$(head -n 1 loose-dirs) &&
+		rm -f loose-dirs &&
+
+		cd $first_loose &&
+		obj=$(ls *) &&
+		mv $obj ../an-object &&
+		ln -s ../an-object $obj &&
+
+		cd ../ &&
+		find . -type f | sort >../../../T.objects-files.raw &&
+		find . -type l | sort >../../../T.objects-symlinks.raw &&
+		echo unknown_content >unknown_file
+	) &&
+	git -C T fsck &&
+	git -C T rev-list --all --objects >T.objects
+'
+
+
+test_expect_success SYMLINKS 'clone repo with symlinked or unknown files at objects/' '
+	for option in --local --no-hardlinks --shared --dissociate
+	do
+		git clone $option T T$option || return 1 &&
+		git -C T$option fsck || return 1 &&
+		git -C T$option rev-list --all --objects >T$option.objects &&
+		test_cmp T.objects T$option.objects &&
+		(
+			cd T$option/.git/objects &&
+			find . -type f | sort >../../../T$option.objects-files.raw &&
+			find . -type l | sort >../../../T$option.objects-symlinks.raw
+		)
+	done &&
+
+	for raw in $(ls T*.raw)
+	do
+		sed -e "s!/../!/Y/!; s![0-9a-f]\{38,\}!Z!" -e "/commit-graph/d" \
+		    -e "/multi-pack-index/d" <$raw >$raw.de-sha || return 1
+	done &&
+
+	cat >expected-files <<-EOF &&
+	./Y/Z
+	./Y/Z
+	./a-loose-dir/Z
+	./an-object
+	./Y/Z
+	./info/packs
+	./pack/pack-Z.idx
+	./pack/pack-Z.pack
+	./packs/pack-Z.idx
+	./packs/pack-Z.pack
+	./unknown_file
+	EOF
+
+	for option in --local --no-hardlinks --dissociate
+	do
+		test_cmp expected-files T$option.objects-files.raw.de-sha || return 1 &&
+		test_must_be_empty T$option.objects-symlinks.raw.de-sha || return 1
+	done &&
+
+	echo ./info/alternates >expected-files &&
+	test_cmp expected-files T--shared.objects-files.raw &&
+	test_must_be_empty T--shared.objects-symlinks.raw
+'
+
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t5605-clone-local.sh 1.2.3+git2.25.1-1/git/t/t5605-clone-local.sh
--- 1.2.1+git2.18.0-1/git/t/t5605-clone-local.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t5605-clone-local.sh	2020-02-17 04:47:35.000000000 +0000
@@ -94,7 +94,7 @@ test_expect_success 'clone empty reposit
 	 git config receive.denyCurrentBranch warn) &&
 	git clone empty empty-clone &&
 	test_tick &&
-	(cd empty-clone
+	(cd empty-clone &&
 	 echo "content" >> foo &&
 	 git add foo &&
 	 git commit -m "Initial commit" &&
diff -pruN 1.2.1+git2.18.0-1/git/t/t5607-clone-bundle.sh 1.2.3+git2.25.1-1/git/t/t5607-clone-bundle.sh
--- 1.2.1+git2.18.0-1/git/t/t5607-clone-bundle.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t5607-clone-bundle.sh	2020-02-17 04:47:35.000000000 +0000
@@ -14,6 +14,12 @@ test_expect_success 'setup' '
 	git tag -d third
 '
 
+test_expect_success '"verify" needs a worktree' '
+	git bundle create tip.bundle -1 master &&
+	test_must_fail nongit git bundle verify ../tip.bundle 2>err &&
+	test_i18ngrep "need a repository" err
+'
+
 test_expect_success 'annotated tags can be excluded by rev-list options' '
 	git bundle create bundle --all --since=7.Apr.2005.15:14:00.-0700 &&
 	git ls-remote bundle > output &&
@@ -71,4 +77,21 @@ test_expect_success 'prerequisites with
 	git bundle verify bundle
 '
 
+test_expect_success 'failed bundle creation does not leave cruft' '
+	# This fails because the bundle would be empty.
+	test_must_fail git bundle create fail.bundle master..master &&
+	test_path_is_missing fail.bundle.lock
+'
+
+test_expect_success 'fetch SHA-1 from bundle' '
+	test_create_repo foo &&
+	test_commit -C foo x &&
+	git -C foo bundle create tip.bundle -1 master &&
+	git -C foo rev-parse HEAD >hash &&
+
+	# Exercise to ensure that fetching a SHA-1 from a bundle works with no
+	# errors
+	git fetch --no-tags foo/tip.bundle "$(cat hash)"
+'
+
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t5608-clone-2gb.sh 1.2.3+git2.25.1-1/git/t/t5608-clone-2gb.sh
--- 1.2.1+git2.18.0-1/git/t/t5608-clone-2gb.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t5608-clone-2gb.sh	2020-02-17 04:47:35.000000000 +0000
@@ -3,7 +3,7 @@
 test_description='Test cloning a repository larger than 2 gigabyte'
 . ./test-lib.sh
 
-if test -z "$GIT_TEST_CLONE_2GB"
+if ! test_bool_env GIT_TEST_CLONE_2GB false
 then
 	say 'Skipping expensive 2GB clone test; enable it with GIT_TEST_CLONE_2GB=t'
 else
@@ -23,7 +23,7 @@ test_expect_success CLONE_2GB 'setup' '
 		printf "blob\nmark :$i\ndata $blobsize\n" &&
 		#test-tool genrandom $i $blobsize &&
 		printf "%-${blobsize}s" $i &&
-		echo "M 100644 :$i $i" >> commit
+		echo "M 100644 :$i $i" >> commit &&
 		i=$(($i+1)) ||
 		echo $? > exit-status
 	 done &&
diff -pruN 1.2.1+git2.18.0-1/git/t/t5611-clone-config.sh 1.2.3+git2.25.1-1/git/t/t5611-clone-config.sh
--- 1.2.1+git2.18.0-1/git/t/t5611-clone-config.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t5611-clone-config.sh	2020-02-17 04:47:35.000000000 +0000
@@ -45,6 +45,53 @@ test_expect_success 'clone -c config is
 	test_cmp expect child/file
 '
 
+test_expect_success 'clone -c remote.origin.fetch=<refspec> works' '
+	rm -rf child &&
+	git update-ref refs/grab/it refs/heads/master &&
+	git update-ref refs/leave/out refs/heads/master &&
+	git clone -c "remote.origin.fetch=+refs/grab/*:refs/grab/*" . child &&
+	git -C child for-each-ref --format="%(refname)" >actual &&
+
+	cat >expect <<-\EOF &&
+	refs/grab/it
+	refs/heads/master
+	refs/remotes/origin/HEAD
+	refs/remotes/origin/master
+	EOF
+	test_cmp expect actual
+'
+
+test_expect_success 'git -c remote.origin.fetch=<refspec> clone works' '
+	rm -rf child &&
+	git -c "remote.origin.fetch=+refs/grab/*:refs/grab/*" clone . child &&
+	git -C child for-each-ref --format="%(refname)" >actual &&
+
+	cat >expect <<-\EOF &&
+	refs/grab/it
+	refs/heads/master
+	refs/remotes/origin/HEAD
+	refs/remotes/origin/master
+	EOF
+	test_cmp expect actual
+'
+
+test_expect_success 'clone -c remote.<remote>.fetch=<refspec> --origin=<name>' '
+	rm -rf child &&
+	git clone --origin=upstream \
+		  -c "remote.upstream.fetch=+refs/grab/*:refs/grab/*" \
+		  -c "remote.origin.fetch=+refs/leave/*:refs/leave/*" \
+		  . child &&
+	git -C child for-each-ref --format="%(refname)" >actual &&
+
+	cat >expect <<-\EOF &&
+	refs/grab/it
+	refs/heads/master
+	refs/remotes/upstream/HEAD
+	refs/remotes/upstream/master
+	EOF
+	test_cmp expect actual
+'
+
 # Tests for the hidden file attribute on windows
 is_hidden () {
 	# Use the output of `attrib`, ignore the absolute path
diff -pruN 1.2.1+git2.18.0-1/git/t/t5612-clone-refspec.sh 1.2.3+git2.25.1-1/git/t/t5612-clone-refspec.sh
--- 1.2.1+git2.18.0-1/git/t/t5612-clone-refspec.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t5612-clone-refspec.sh	2020-02-17 04:47:35.000000000 +0000
@@ -97,14 +97,13 @@ test_expect_success 'clone with --no-tag
 		git fetch &&
 		git for-each-ref refs/tags >../actual
 	) &&
-	>expect &&
-	test_cmp expect actual
+	test_must_be_empty actual
 '
 
 test_expect_success '--single-branch while HEAD pointing at master' '
 	(
 		cd dir_master &&
-		git fetch &&
+		git fetch --force &&
 		git for-each-ref refs/remotes/origin |
 		sed -e "/HEAD$/d" \
 		    -e "s|/remotes/origin/|/heads/|" >../actual
@@ -115,7 +114,7 @@ test_expect_success '--single-branch whi
 	test_cmp expect actual &&
 	(
 		cd dir_master &&
-		git fetch --tags &&
+		git fetch --tags --force &&
 		git for-each-ref refs/tags >../actual
 	) &&
 	git for-each-ref refs/tags >expect &&
@@ -140,8 +139,7 @@ test_expect_success '--single-branch whi
 		git fetch &&
 		git for-each-ref refs/tags >../actual
 	) &&
-	>expect &&
-	test_cmp expect actual &&
+	test_must_be_empty actual &&
 	test_line_count = 0 actual &&
 	# get tags with --tags overrides tagOpt
 	(
@@ -230,8 +228,7 @@ test_expect_success '--single-branch wit
 		    -e "s|/remotes/origin/|/heads/|" >../actual
 	) &&
 	# nothing
-	>expect &&
-	test_cmp expect actual
+	test_must_be_empty actual
 '
 
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t5616-partial-clone.sh 1.2.3+git2.25.1-1/git/t/t5616-partial-clone.sh
--- 1.2.1+git2.18.0-1/git/t/t5616-partial-clone.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t5616-partial-clone.sh	2020-02-17 04:47:35.000000000 +0000
@@ -34,22 +34,32 @@ test_expect_success 'setup bare clone fo
 # confirm partial clone was registered in the local config.
 test_expect_success 'do partial clone 1' '
 	git clone --no-checkout --filter=blob:none "file://$(pwd)/srv.bare" pc1 &&
-	git -C pc1 rev-list HEAD --quiet --objects --missing=print \
-		| awk -f print_1.awk \
-		| sed "s/?//" \
-		| sort >observed.oids &&
+
+	git -C pc1 rev-list --quiet --objects --missing=print HEAD >revs &&
+	awk -f print_1.awk revs |
+	sed "s/?//" |
+	sort >observed.oids &&
+
 	test_cmp expect_1.oids observed.oids &&
 	test "$(git -C pc1 config --local core.repositoryformatversion)" = "1" &&
-	test "$(git -C pc1 config --local extensions.partialclone)" = "origin" &&
-	test "$(git -C pc1 config --local core.partialclonefilter)" = "blob:none"
+	test "$(git -C pc1 config --local remote.origin.promisor)" = "true" &&
+	test "$(git -C pc1 config --local remote.origin.partialclonefilter)" = "blob:none"
+'
+
+test_expect_success 'verify that .promisor file contains refs fetched' '
+	ls pc1/.git/objects/pack/pack-*.promisor >promisorlist &&
+	test_line_count = 1 promisorlist &&
+	git -C srv.bare rev-list HEAD >headhash &&
+	grep "$(cat headhash) HEAD" $(cat promisorlist) &&
+	grep "$(cat headhash) refs/heads/master" $(cat promisorlist)
 '
 
 # checkout master to force dynamic object fetch of blobs at HEAD.
 test_expect_success 'verify checkout with dynamic object fetch' '
-	git -C pc1 rev-list HEAD --quiet --objects --missing=print >observed &&
+	git -C pc1 rev-list --quiet --objects --missing=print HEAD >observed &&
 	test_line_count = 4 observed &&
 	git -C pc1 checkout master &&
-	git -C pc1 rev-list HEAD --quiet --objects --missing=print >observed &&
+	git -C pc1 rev-list --quiet --objects --missing=print HEAD >observed &&
 	test_line_count = 0 observed
 '
 
@@ -72,7 +82,8 @@ test_expect_success 'push new commits to
 # have the new blobs.
 test_expect_success 'partial fetch inherits filter settings' '
 	git -C pc1 fetch origin &&
-	git -C pc1 rev-list master..origin/master --quiet --objects --missing=print >observed &&
+	git -C pc1 rev-list --quiet --objects --missing=print \
+		master..origin/master >observed &&
 	test_line_count = 5 observed
 '
 
@@ -80,7 +91,8 @@ test_expect_success 'partial fetch inher
 # we should only get 1 new blob (for the file in origin/master).
 test_expect_success 'verify diff causes dynamic object fetch' '
 	git -C pc1 diff master..origin/master -- file.1.txt &&
-	git -C pc1 rev-list master..origin/master --quiet --objects --missing=print >observed &&
+	git -C pc1 rev-list --quiet --objects --missing=print \
+		 master..origin/master >observed &&
 	test_line_count = 4 observed
 '
 
@@ -89,7 +101,8 @@ test_expect_success 'verify diff causes
 test_expect_success 'verify blame causes dynamic object fetch' '
 	git -C pc1 blame origin/master -- file.1.txt >observed.blame &&
 	test_cmp expect.blame observed.blame &&
-	git -C pc1 rev-list master..origin/master --quiet --objects --missing=print >observed &&
+	git -C pc1 rev-list --quiet --objects --missing=print \
+		master..origin/master >observed &&
 	test_line_count = 0 observed
 '
 
@@ -109,7 +122,8 @@ test_expect_success 'push new commits to
 # Verify we have all the new blobs.
 test_expect_success 'override inherited filter-spec using --no-filter' '
 	git -C pc1 fetch --no-filter origin &&
-	git -C pc1 rev-list master..origin/master --quiet --objects --missing=print >observed &&
+	git -C pc1 rev-list --quiet --objects --missing=print \
+		master..origin/master >observed &&
 	test_line_count = 0 observed
 '
 
@@ -130,16 +144,22 @@ test_expect_success 'push new commits to
 # perhaps combined with a command in dry-run mode.
 test_expect_success 'manual prefetch of missing objects' '
 	git -C pc1 fetch --filter=blob:none origin &&
-	git -C pc1 rev-list master..origin/master --quiet --objects --missing=print \
-		| awk -f print_1.awk \
-		| sed "s/?//" \
-		| sort >observed.oids &&
+
+	git -C pc1 rev-list --quiet --objects --missing=print \
+		 master..origin/master >revs &&
+	awk -f print_1.awk revs |
+	sed "s/?//" |
+	sort >observed.oids &&
+
 	test_line_count = 6 observed.oids &&
 	git -C pc1 fetch-pack --stdin "file://$(pwd)/srv.bare" <observed.oids &&
-	git -C pc1 rev-list master..origin/master --quiet --objects --missing=print \
-		| awk -f print_1.awk \
-		| sed "s/?//" \
-		| sort >observed.oids &&
+
+	git -C pc1 rev-list --quiet --objects --missing=print \
+		master..origin/master >revs &&
+	awk -f print_1.awk revs |
+	sed "s/?//" |
+	sort >observed.oids &&
+
 	test_line_count = 0 observed.oids
 '
 
@@ -154,4 +174,393 @@ test_expect_success 'partial clone with
 	grep "git index-pack.*--fsck-objects" trace
 '
 
+test_expect_success 'use fsck before and after manually fetching a missing subtree' '
+	# push new commit so server has a subtree
+	mkdir src/dir &&
+	echo "in dir" >src/dir/file.txt &&
+	git -C src add dir/file.txt &&
+	git -C src commit -m "file in dir" &&
+	git -C src push -u srv master &&
+	SUBTREE=$(git -C src rev-parse HEAD:dir) &&
+
+	rm -rf dst &&
+	git clone --no-checkout --filter=tree:0 "file://$(pwd)/srv.bare" dst &&
+	git -C dst fsck &&
+
+	# Make sure we only have commits, and all trees and blobs are missing.
+	git -C dst rev-list --missing=allow-any --objects master \
+		>fetched_objects &&
+	awk -f print_1.awk fetched_objects |
+	xargs -n1 git -C dst cat-file -t >fetched_types &&
+
+	sort -u fetched_types >unique_types.observed &&
+	echo commit >unique_types.expected &&
+	test_cmp unique_types.expected unique_types.observed &&
+
+	# Auto-fetch a tree with cat-file.
+	git -C dst cat-file -p $SUBTREE >tree_contents &&
+	grep file.txt tree_contents &&
+
+	# fsck still works after an auto-fetch of a tree.
+	git -C dst fsck &&
+
+	# Auto-fetch all remaining trees and blobs with --missing=error
+	git -C dst rev-list --missing=error --objects master >fetched_objects &&
+	test_line_count = 70 fetched_objects &&
+
+	awk -f print_1.awk fetched_objects |
+	xargs -n1 git -C dst cat-file -t >fetched_types &&
+
+	sort -u fetched_types >unique_types.observed &&
+	test_write_lines blob commit tree >unique_types.expected &&
+	test_cmp unique_types.expected unique_types.observed
+'
+
+test_expect_success 'implicitly construct combine: filter with repeated flags' '
+	GIT_TRACE=$(pwd)/trace git clone --bare \
+		--filter=blob:none --filter=tree:1 \
+		"file://$(pwd)/srv.bare" pc2 &&
+	grep "trace:.* git pack-objects .*--filter=combine:blob:none+tree:1" \
+		trace &&
+	git -C pc2 rev-list --objects --missing=allow-any HEAD >objects &&
+
+	# We should have gotten some root trees.
+	grep " $" objects &&
+	# Should not have gotten any non-root trees or blobs.
+	! grep " ." objects &&
+
+	xargs -n 1 git -C pc2 cat-file -t <objects >types &&
+	sort -u types >unique_types.actual &&
+	test_write_lines commit tree >unique_types.expected &&
+	test_cmp unique_types.expected unique_types.actual
+'
+
+test_expect_success 'partial clone fetches blobs pointed to by refs even if normally filtered out' '
+	rm -rf src dst &&
+	git init src &&
+	test_commit -C src x &&
+	test_config -C src uploadpack.allowfilter 1 &&
+	test_config -C src uploadpack.allowanysha1inwant 1 &&
+
+	# Create a tag pointing to a blob.
+	BLOB=$(echo blob-contents | git -C src hash-object --stdin -w) &&
+	git -C src tag myblob "$BLOB" &&
+
+	git clone --filter="blob:none" "file://$(pwd)/src" dst 2>err &&
+	! grep "does not point to a valid object" err &&
+	git -C dst fsck
+'
+
+test_expect_success 'fetch what is specified on CLI even if already promised' '
+	rm -rf src dst.git &&
+	git init src &&
+	test_commit -C src foo &&
+	test_config -C src uploadpack.allowfilter 1 &&
+	test_config -C src uploadpack.allowanysha1inwant 1 &&
+
+	git hash-object --stdin <src/foo.t >blob &&
+
+	git clone --bare --filter=blob:none "file://$(pwd)/src" dst.git &&
+	git -C dst.git rev-list --objects --quiet --missing=print HEAD >missing_before &&
+	grep "?$(cat blob)" missing_before &&
+	git -C dst.git fetch origin $(cat blob) &&
+	git -C dst.git rev-list --objects --quiet --missing=print HEAD >missing_after &&
+	! grep "?$(cat blob)" missing_after
+'
+
+test_expect_success 'setup src repo for sparse filter' '
+	git init sparse-src &&
+	git -C sparse-src config --local uploadpack.allowfilter 1 &&
+	git -C sparse-src config --local uploadpack.allowanysha1inwant 1 &&
+	test_commit -C sparse-src one &&
+	test_commit -C sparse-src two &&
+	echo /one.t >sparse-src/only-one &&
+	git -C sparse-src add . &&
+	git -C sparse-src commit -m "add sparse checkout files"
+'
+
+test_expect_success 'partial clone with sparse filter succeeds' '
+	rm -rf dst.git &&
+	git clone --no-local --bare \
+		  --filter=sparse:oid=master:only-one \
+		  sparse-src dst.git &&
+	(
+		cd dst.git &&
+		git rev-list --objects --missing=print HEAD >out &&
+		grep "^$(git rev-parse HEAD:one.t)" out &&
+		grep "^?$(git rev-parse HEAD:two.t)" out
+	)
+'
+
+test_expect_success 'partial clone with unresolvable sparse filter fails cleanly' '
+	rm -rf dst.git &&
+	test_must_fail git clone --no-local --bare \
+				 --filter=sparse:oid=master:no-such-name \
+				 sparse-src dst.git 2>err &&
+	test_i18ngrep "unable to access sparse blob in .master:no-such-name" err &&
+	test_must_fail git clone --no-local --bare \
+				 --filter=sparse:oid=master \
+				 sparse-src dst.git 2>err &&
+	test_i18ngrep "unable to parse sparse filter data in" err
+'
+
+setup_triangle () {
+	rm -rf big-blob.txt server client promisor-remote &&
+
+	printf "line %d\n" $(test_seq 1 100) >big-blob.txt &&
+
+	# Create a server with 2 commits: a commit with a big tree and a child
+	# commit with an incremental change. Also, create a partial clone
+	# client that only contains the first commit.
+	git init server &&
+	git -C server config --local uploadpack.allowfilter 1 &&
+	for i in $(test_seq 1 100)
+	do
+		echo "make the tree big" >server/file$i &&
+		git -C server add file$i
+	done &&
+	git -C server commit -m "initial" &&
+	git clone --bare --filter=tree:0 "file://$(pwd)/server" client &&
+	echo another line >>server/file1 &&
+	git -C server commit -am "incremental change" &&
+
+	# Create a promisor remote that only contains the tree and blob from
+	# the first commit.
+	git init promisor-remote &&
+	git -C server config --local uploadpack.allowanysha1inwant 1 &&
+	TREE_HASH=$(git -C server rev-parse HEAD~1^{tree}) &&
+	git -C promisor-remote fetch --keep "file://$(pwd)/server" "$TREE_HASH" &&
+	git -C promisor-remote count-objects -v >object-count &&
+	test_i18ngrep "count: 0" object-count &&
+	test_i18ngrep "in-pack: 2" object-count &&
+
+	# Set it as the promisor remote of client. Thus, whenever
+	# the client lazy fetches, the lazy fetch will succeed only if it is
+	# for this tree or blob.
+	test_commit -C promisor-remote one && # so that ref advertisement is not empty
+	git -C promisor-remote config --local uploadpack.allowanysha1inwant 1 &&
+	git -C client remote set-url origin "file://$(pwd)/promisor-remote"
+}
+
+# NEEDSWORK: The tests beginning with "fetch lazy-fetches" below only
+# test that "fetch" avoid fetching trees and blobs, but not commits or
+# tags. Revisit this if Git is ever taught to support partial clones
+# with commits and/or tags filtered out.
+
+test_expect_success 'fetch lazy-fetches only to resolve deltas' '
+	setup_triangle &&
+
+	# Exercise to make sure it works. Git will not fetch anything from the
+	# promisor remote other than for the big tree (because it needs to
+	# resolve the delta).
+	GIT_TRACE_PACKET="$(pwd)/trace" git -C client \
+		fetch "file://$(pwd)/server" master &&
+
+	# Verify the assumption that the client needed to fetch the delta base
+	# to resolve the delta.
+	git -C server rev-parse HEAD~1^{tree} >hash &&
+	grep "want $(cat hash)" trace
+'
+
+test_expect_success 'fetch lazy-fetches only to resolve deltas, protocol v2' '
+	setup_triangle &&
+
+	git -C server config --local protocol.version 2 &&
+	git -C client config --local protocol.version 2 &&
+	git -C promisor-remote config --local protocol.version 2 &&
+
+	# Exercise to make sure it works. Git will not fetch anything from the
+	# promisor remote other than for the big blob (because it needs to
+	# resolve the delta).
+	GIT_TRACE_PACKET="$(pwd)/trace" git -C client \
+		fetch "file://$(pwd)/server" master &&
+
+	# Verify that protocol version 2 was used.
+	grep "fetch< version 2" trace &&
+
+	# Verify the assumption that the client needed to fetch the delta base
+	# to resolve the delta.
+	git -C server rev-parse HEAD~1^{tree} >hash &&
+	grep "want $(cat hash)" trace
+'
+
+. "$TEST_DIRECTORY"/lib-httpd.sh
+start_httpd
+
+# Converts bytes into their hexadecimal representation. For example,
+# "printf 'ab\r\n' | hex_unpack" results in '61620d0a'.
+hex_unpack () {
+	perl -e '$/ = undef; $input = <>; print unpack("H2" x length($input), $input)'
+}
+
+# Inserts $1 at the start of the string and every 2 characters thereafter.
+intersperse () {
+	sed 's/\(..\)/'$1'\1/g'
+}
+
+# Create a one-time-sed command to replace the existing packfile with $1.
+replace_packfile () {
+	# The protocol requires that the packfile be sent in sideband 1, hence
+	# the extra \x01 byte at the beginning.
+	printf "1,/packfile/!c %04x\\\\x01%s0000" \
+		"$(($(wc -c <$1) + 5))" \
+		"$(hex_unpack <$1 | intersperse '\\x')" \
+		>"$HTTPD_ROOT_PATH/one-time-sed"
+}
+
+test_expect_success 'upon cloning, check that all refs point to objects' '
+	SERVER="$HTTPD_DOCUMENT_ROOT_PATH/server" &&
+	rm -rf "$SERVER" repo &&
+	test_create_repo "$SERVER" &&
+	test_commit -C "$SERVER" foo &&
+	test_config -C "$SERVER" uploadpack.allowfilter 1 &&
+	test_config -C "$SERVER" uploadpack.allowanysha1inwant 1 &&
+
+	# Create a tag pointing to a blob.
+	BLOB=$(echo blob-contents | git -C "$SERVER" hash-object --stdin -w) &&
+	git -C "$SERVER" tag myblob "$BLOB" &&
+
+	# Craft a packfile not including that blob.
+	git -C "$SERVER" rev-parse HEAD |
+	git -C "$SERVER" pack-objects --stdout >incomplete.pack &&
+
+	# Replace the existing packfile with the crafted one. The protocol
+	# requires that the packfile be sent in sideband 1, hence the extra
+	# \x01 byte at the beginning.
+	replace_packfile incomplete.pack &&
+
+	# Use protocol v2 because the sed command looks for the "packfile"
+	# section header.
+	test_config -C "$SERVER" protocol.version 2 &&
+	test_must_fail git -c protocol.version=2 clone \
+		--filter=blob:none $HTTPD_URL/one_time_sed/server repo 2>err &&
+
+	test_i18ngrep "did not send all necessary objects" err &&
+
+	# Ensure that the one-time-sed script was used.
+	! test -e "$HTTPD_ROOT_PATH/one-time-sed"
+'
+
+test_expect_success 'when partial cloning, tolerate server not sending target of tag' '
+	SERVER="$HTTPD_DOCUMENT_ROOT_PATH/server" &&
+	rm -rf "$SERVER" repo &&
+	test_create_repo "$SERVER" &&
+	test_commit -C "$SERVER" foo &&
+	test_config -C "$SERVER" uploadpack.allowfilter 1 &&
+	test_config -C "$SERVER" uploadpack.allowanysha1inwant 1 &&
+
+	# Create an annotated tag pointing to a blob.
+	BLOB=$(echo blob-contents | git -C "$SERVER" hash-object --stdin -w) &&
+	git -C "$SERVER" tag -m message -a myblob "$BLOB" &&
+
+	# Craft a packfile including the tag, but not the blob it points to.
+	# Also, omit objects referenced from HEAD in order to force a second
+	# fetch (to fetch missing objects) upon the automatic checkout that
+	# happens after a clone.
+	printf "%s\n%s\n--not\n%s\n%s\n" \
+		$(git -C "$SERVER" rev-parse HEAD) \
+		$(git -C "$SERVER" rev-parse myblob) \
+		$(git -C "$SERVER" rev-parse HEAD^{tree}) \
+		$(git -C "$SERVER" rev-parse myblob^{blob}) |
+		git -C "$SERVER" pack-objects --thin --stdout >incomplete.pack &&
+
+	# Replace the existing packfile with the crafted one. The protocol
+	# requires that the packfile be sent in sideband 1, hence the extra
+	# \x01 byte at the beginning.
+	replace_packfile incomplete.pack &&
+
+	# Use protocol v2 because the sed command looks for the "packfile"
+	# section header.
+	test_config -C "$SERVER" protocol.version 2 &&
+
+	# Exercise to make sure it works.
+	git -c protocol.version=2 clone \
+		--filter=blob:none $HTTPD_URL/one_time_sed/server repo 2> err &&
+	! grep "missing object referenced by" err &&
+
+	# Ensure that the one-time-sed script was used.
+	! test -e "$HTTPD_ROOT_PATH/one-time-sed"
+'
+
+test_expect_success 'tolerate server sending REF_DELTA against missing promisor objects' '
+	SERVER="$HTTPD_DOCUMENT_ROOT_PATH/server" &&
+	rm -rf "$SERVER" repo &&
+	test_create_repo "$SERVER" &&
+	test_config -C "$SERVER" uploadpack.allowfilter 1 &&
+	test_config -C "$SERVER" uploadpack.allowanysha1inwant 1 &&
+
+	# Create a commit with 2 blobs to be used as delta bases.
+	for i in $(test_seq 10)
+	do
+		echo "this is a line" >>"$SERVER/foo.txt" &&
+		echo "this is another line" >>"$SERVER/have.txt"
+	done &&
+	git -C "$SERVER" add foo.txt have.txt &&
+	git -C "$SERVER" commit -m bar &&
+	git -C "$SERVER" rev-parse HEAD:foo.txt >deltabase_missing &&
+	git -C "$SERVER" rev-parse HEAD:have.txt >deltabase_have &&
+
+	# Clone. The client has deltabase_have but not deltabase_missing.
+	git -c protocol.version=2 clone --no-checkout \
+		--filter=blob:none $HTTPD_URL/one_time_sed/server repo &&
+	git -C repo hash-object -w -- "$SERVER/have.txt" &&
+
+	# Sanity check to ensure that the client does not have
+	# deltabase_missing.
+	git -C repo rev-list --objects --ignore-missing \
+		-- $(cat deltabase_missing) >objlist &&
+	test_line_count = 0 objlist &&
+
+	# Another commit. This commit will be fetched by the client.
+	echo "abcdefghijklmnopqrstuvwxyz" >>"$SERVER/foo.txt" &&
+	echo "abcdefghijklmnopqrstuvwxyz" >>"$SERVER/have.txt" &&
+	git -C "$SERVER" add foo.txt have.txt &&
+	git -C "$SERVER" commit -m baz &&
+
+	# Pack a thin pack containing, among other things, HEAD:foo.txt
+	# delta-ed against HEAD^:foo.txt and HEAD:have.txt delta-ed against
+	# HEAD^:have.txt.
+	printf "%s\n--not\n%s\n" \
+		$(git -C "$SERVER" rev-parse HEAD) \
+		$(git -C "$SERVER" rev-parse HEAD^) |
+		git -C "$SERVER" pack-objects --thin --stdout >thin.pack &&
+
+	# Ensure that the pack contains one delta against HEAD^:foo.txt. Since
+	# the delta contains at least 26 novel characters, the size cannot be
+	# contained in 4 bits, so the object header will take up 2 bytes. The
+	# most significant nybble of the first byte is 0b1111 (0b1 to indicate
+	# that the header continues, and 0b111 to indicate REF_DELTA), followed
+	# by any 3 nybbles, then the OID of the delta base.
+	printf "f.,..%s" $(intersperse "," <deltabase_missing) >want &&
+	hex_unpack <thin.pack | intersperse "," >have &&
+	grep $(cat want) have &&
+
+	# Ensure that the pack contains one delta against HEAD^:have.txt,
+	# similar to the above.
+	printf "f.,..%s" $(intersperse "," <deltabase_have) >want &&
+	hex_unpack <thin.pack | intersperse "," >have &&
+	grep $(cat want) have &&
+
+	replace_packfile thin.pack &&
+
+	# Use protocol v2 because the sed command looks for the "packfile"
+	# section header.
+	test_config -C "$SERVER" protocol.version 2 &&
+
+	# Fetch the thin pack and ensure that index-pack is able to handle the
+	# REF_DELTA object with a missing promisor delta base.
+	GIT_TRACE_PACKET="$(pwd)/trace" git -C repo -c protocol.version=2 fetch &&
+
+	# Ensure that the missing delta base was directly fetched, but not the
+	# one that the client has.
+	grep "want $(cat deltabase_missing)" trace &&
+	! grep "want $(cat deltabase_have)" trace &&
+
+	# Ensure that the one-time-sed script was used.
+	! test -e "$HTTPD_ROOT_PATH/one-time-sed"
+'
+
+# DO NOT add non-httpd-specific tests here, because the last part of this
+# test script is only executed when httpd is available and enabled.
+
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t5617-clone-submodules-remote.sh 1.2.3+git2.25.1-1/git/t/t5617-clone-submodules-remote.sh
--- 1.2.1+git2.18.0-1/git/t/t5617-clone-submodules-remote.sh	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t5617-clone-submodules-remote.sh	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,54 @@
+#!/bin/sh
+
+test_description='Test cloning repos with submodules using remote-tracking branches'
+
+. ./test-lib.sh
+
+pwd=$(pwd)
+
+test_expect_success 'setup' '
+	git checkout -b master &&
+	test_commit commit1 &&
+	mkdir sub &&
+	(
+		cd sub &&
+		git init &&
+		test_commit subcommit1 &&
+		git tag sub_when_added_to_super
+	) &&
+	git submodule add "file://$pwd/sub" sub &&
+	git commit -m "add submodule" &&
+	(
+		cd sub &&
+		test_commit subcommit2
+	)
+'
+
+test_expect_success 'clone with --no-remote-submodules' '
+	test_when_finished "rm -rf super_clone" &&
+	git clone --recurse-submodules --no-remote-submodules "file://$pwd/." super_clone &&
+	(
+		cd super_clone/sub &&
+		git diff --exit-code sub_when_added_to_super
+	)
+'
+
+test_expect_success 'clone with --remote-submodules' '
+	test_when_finished "rm -rf super_clone" &&
+	git clone --recurse-submodules --remote-submodules "file://$pwd/." super_clone &&
+	(
+		cd super_clone/sub &&
+		git diff --exit-code remotes/origin/master
+	)
+'
+
+test_expect_success 'check the default is --no-remote-submodules' '
+	test_when_finished "rm -rf super_clone" &&
+	git clone --recurse-submodules "file://$pwd/." super_clone &&
+	(
+		cd super_clone/sub &&
+		git diff --exit-code sub_when_added_to_super
+	)
+'
+
+test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t5618-alternate-refs.sh 1.2.3+git2.25.1-1/git/t/t5618-alternate-refs.sh
--- 1.2.1+git2.18.0-1/git/t/t5618-alternate-refs.sh	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t5618-alternate-refs.sh	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,60 @@
+#!/bin/sh
+
+test_description='test handling of --alternate-refs traversal'
+. ./test-lib.sh
+
+# Avoid test_commit because we want a specific and known set of refs:
+#
+#  base -- one
+#      \      \
+#       two -- merged
+#
+# where "one" and "two" are on separate refs, and "merged" is available only in
+# the dependent child repository.
+test_expect_success 'set up local refs' '
+	git checkout -b one &&
+	test_tick &&
+	git commit --allow-empty -m base &&
+	test_tick &&
+	git commit --allow-empty -m one &&
+	git checkout -b two HEAD^ &&
+	test_tick &&
+	git commit --allow-empty -m two
+'
+
+# We'll enter the child repository after it's set up since that's where
+# all of the subsequent tests will want to run (and it's easy to forget a
+# "-C child" and get nonsense results).
+test_expect_success 'set up shared clone' '
+	git clone -s . child &&
+	cd child &&
+	git merge origin/one
+'
+
+test_expect_success 'rev-list --alternate-refs' '
+	git rev-list --remotes=origin >expect &&
+	git rev-list --alternate-refs >actual &&
+	test_cmp expect actual
+'
+
+test_expect_success 'rev-list --not --alternate-refs' '
+	git rev-parse HEAD >expect &&
+	git rev-list HEAD --not --alternate-refs >actual &&
+	test_cmp expect actual
+'
+
+test_expect_success 'limiting with alternateRefsPrefixes' '
+	test_config core.alternateRefsPrefixes refs/heads/one &&
+	git rev-list origin/one >expect &&
+	git rev-list --alternate-refs >actual &&
+	test_cmp expect actual
+'
+
+test_expect_success 'log --source shows .alternate marker' '
+	git log --oneline --source --remotes=origin >expect.orig &&
+	sed "s/origin.* /.alternate /" <expect.orig >expect &&
+	git log --oneline --source --alternate-refs >actual &&
+	test_cmp expect actual
+'
+
+test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t5700-protocol-v1.sh 1.2.3+git2.25.1-1/git/t/t5700-protocol-v1.sh
--- 1.2.1+git2.18.0-1/git/t/t5700-protocol-v1.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t5700-protocol-v1.sh	2020-02-17 04:47:35.000000000 +0000
@@ -4,6 +4,9 @@ test_description='test git wire-protocol
 
 TEST_NO_CREATE_REPO=1
 
+# This is a protocol-specific test.
+GIT_TEST_PROTOCOL_VERSION=
+
 . ./test-lib.sh
 
 # Test protocol v1 with 'git://' transport
@@ -289,6 +292,7 @@ test_expect_success 'push with http:// u
 	grep "git< version 1" log
 '
 
-stop_httpd
+# DO NOT add non-httpd-specific tests here, because the last part of this
+# test script is only executed when httpd is available and enabled.
 
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t5701-git-serve.sh 1.2.3+git2.25.1-1/git/t/t5701-git-serve.sh
--- 1.2.1+git2.18.0-1/git/t/t5701-git-serve.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t5701-git-serve.sh	2020-02-17 04:47:35.000000000 +0000
@@ -1,6 +1,6 @@
 #!/bin/sh
 
-test_description='test git-serve and server commands'
+test_description='test protocol v2 server commands'
 
 . ./test-lib.sh
 
@@ -14,49 +14,50 @@ test_expect_success 'test capability adv
 	0000
 	EOF
 
-	git serve --advertise-capabilities >out &&
-	test-pkt-line unpack <out >actual &&
-	test_cmp actual expect
+	GIT_TEST_SIDEBAND_ALL=0 test-tool serve-v2 \
+		--advertise-capabilities >out &&
+	test-tool pkt-line unpack <out >actual &&
+	test_cmp expect actual
 '
 
 test_expect_success 'stateless-rpc flag does not list capabilities' '
 	# Empty request
-	test-pkt-line pack >in <<-EOF &&
+	test-tool pkt-line pack >in <<-EOF &&
 	0000
 	EOF
-	git serve --stateless-rpc >out <in &&
+	test-tool serve-v2 --stateless-rpc >out <in &&
 	test_must_be_empty out &&
 
 	# EOF
-	git serve --stateless-rpc >out &&
+	test-tool serve-v2 --stateless-rpc >out &&
 	test_must_be_empty out
 '
 
 test_expect_success 'request invalid capability' '
-	test-pkt-line pack >in <<-EOF &&
+	test-tool pkt-line pack >in <<-EOF &&
 	foobar
 	0000
 	EOF
-	test_must_fail git serve --stateless-rpc 2>err <in &&
+	test_must_fail test-tool serve-v2 --stateless-rpc 2>err <in &&
 	test_i18ngrep "unknown capability" err
 '
 
 test_expect_success 'request with no command' '
-	test-pkt-line pack >in <<-EOF &&
+	test-tool pkt-line pack >in <<-EOF &&
 	agent=git/test
 	0000
 	EOF
-	test_must_fail git serve --stateless-rpc 2>err <in &&
+	test_must_fail test-tool serve-v2 --stateless-rpc 2>err <in &&
 	test_i18ngrep "no command requested" err
 '
 
 test_expect_success 'request invalid command' '
-	test-pkt-line pack >in <<-EOF &&
+	test-tool pkt-line pack >in <<-EOF &&
 	command=foo
 	agent=git/test
 	0000
 	EOF
-	test_must_fail git serve --stateless-rpc 2>err <in &&
+	test_must_fail test-tool serve-v2 --stateless-rpc 2>err <in &&
 	test_i18ngrep "invalid command" err
 '
 
@@ -71,7 +72,7 @@ test_expect_success 'setup some refs and
 '
 
 test_expect_success 'basics of ls-refs' '
-	test-pkt-line pack >in <<-EOF &&
+	test-tool pkt-line pack >in <<-EOF &&
 	command=ls-refs
 	0000
 	EOF
@@ -87,13 +88,13 @@ test_expect_success 'basics of ls-refs'
 	0000
 	EOF
 
-	git serve --stateless-rpc <in >out &&
-	test-pkt-line unpack <out >actual &&
-	test_cmp actual expect
+	test-tool serve-v2 --stateless-rpc <in >out &&
+	test-tool pkt-line unpack <out >actual &&
+	test_cmp expect actual
 '
 
 test_expect_success 'basic ref-prefixes' '
-	test-pkt-line pack >in <<-EOF &&
+	test-tool pkt-line pack >in <<-EOF &&
 	command=ls-refs
 	0001
 	ref-prefix refs/heads/master
@@ -107,13 +108,13 @@ test_expect_success 'basic ref-prefixes'
 	0000
 	EOF
 
-	git serve --stateless-rpc <in >out &&
-	test-pkt-line unpack <out >actual &&
-	test_cmp actual expect
+	test-tool serve-v2 --stateless-rpc <in >out &&
+	test-tool pkt-line unpack <out >actual &&
+	test_cmp expect actual
 '
 
 test_expect_success 'refs/heads prefix' '
-	test-pkt-line pack >in <<-EOF &&
+	test-tool pkt-line pack >in <<-EOF &&
 	command=ls-refs
 	0001
 	ref-prefix refs/heads/
@@ -127,13 +128,13 @@ test_expect_success 'refs/heads prefix'
 	0000
 	EOF
 
-	git serve --stateless-rpc <in >out &&
-	test-pkt-line unpack <out >actual &&
-	test_cmp actual expect
+	test-tool serve-v2 --stateless-rpc <in >out &&
+	test-tool pkt-line unpack <out >actual &&
+	test_cmp expect actual
 '
 
 test_expect_success 'peel parameter' '
-	test-pkt-line pack >in <<-EOF &&
+	test-tool pkt-line pack >in <<-EOF &&
 	command=ls-refs
 	0001
 	peel
@@ -148,13 +149,13 @@ test_expect_success 'peel parameter' '
 	0000
 	EOF
 
-	git serve --stateless-rpc <in >out &&
-	test-pkt-line unpack <out >actual &&
-	test_cmp actual expect
+	test-tool serve-v2 --stateless-rpc <in >out &&
+	test-tool pkt-line unpack <out >actual &&
+	test_cmp expect actual
 '
 
 test_expect_success 'symrefs parameter' '
-	test-pkt-line pack >in <<-EOF &&
+	test-tool pkt-line pack >in <<-EOF &&
 	command=ls-refs
 	0001
 	symrefs
@@ -169,13 +170,13 @@ test_expect_success 'symrefs parameter'
 	0000
 	EOF
 
-	git serve --stateless-rpc <in >out &&
-	test-pkt-line unpack <out >actual &&
-	test_cmp actual expect
+	test-tool serve-v2 --stateless-rpc <in >out &&
+	test-tool pkt-line unpack <out >actual &&
+	test_cmp expect actual
 '
 
 test_expect_success 'sending server-options' '
-	test-pkt-line pack >in <<-EOF &&
+	test-tool pkt-line pack >in <<-EOF &&
 	command=ls-refs
 	server-option=hello
 	server-option=world
@@ -189,22 +190,25 @@ test_expect_success 'sending server-opti
 	0000
 	EOF
 
-	git serve --stateless-rpc <in >out &&
-	test-pkt-line unpack <out >actual &&
-	test_cmp actual expect
+	test-tool serve-v2 --stateless-rpc <in >out &&
+	test-tool pkt-line unpack <out >actual &&
+	test_cmp expect actual
 '
 
 test_expect_success 'unexpected lines are not allowed in fetch request' '
 	git init server &&
 
-	test-pkt-line pack >in <<-EOF &&
+	test-tool pkt-line pack >in <<-EOF &&
 	command=fetch
 	0001
 	this-is-not-a-command
 	0000
 	EOF
 
-	test_must_fail git -C server serve --stateless-rpc <in >/dev/null 2>err &&
+	(
+		cd server &&
+		test_must_fail test-tool serve-v2 --stateless-rpc
+	) <in >/dev/null 2>err &&
 	grep "unexpected line: .this-is-not-a-command." err
 '
 
diff -pruN 1.2.1+git2.18.0-1/git/t/t5702-protocol-v2.sh 1.2.3+git2.25.1-1/git/t/t5702-protocol-v2.sh
--- 1.2.1+git2.18.0-1/git/t/t5702-protocol-v2.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t5702-protocol-v2.sh	2020-02-17 04:47:35.000000000 +0000
@@ -29,10 +29,10 @@ test_expect_success 'list refs with git:
 	grep "git< version 2" log &&
 
 	git ls-remote --symref "$GIT_DAEMON_URL/parent" >expect &&
-	test_cmp actual expect
+	test_cmp expect actual
 '
 
-test_expect_success 'ref advertisment is filtered with ls-remote using protocol v2' '
+test_expect_success 'ref advertisement is filtered with ls-remote using protocol v2' '
 	test_when_finished "rm -f log" &&
 
 	GIT_TRACE_PACKET="$(pwd)/log" git -c protocol.version=2 \
@@ -42,7 +42,7 @@ test_expect_success 'ref advertisment is
 	$(git -C "$daemon_parent" rev-parse refs/heads/master)$(printf "\t")refs/heads/master
 	EOF
 
-	test_cmp actual expect
+	test_cmp expect actual
 '
 
 test_expect_success 'clone with git:// using protocol v2' '
@@ -79,6 +79,19 @@ test_expect_success 'fetch with git:// u
 	grep "fetch< version 2" log
 '
 
+test_expect_success 'fetch by hash without tag following with protocol v2 does not list refs' '
+	test_when_finished "rm -f log" &&
+
+	test_commit -C "$daemon_parent" two_a &&
+	git -C "$daemon_parent" rev-parse two_a >two_a_hash &&
+
+	GIT_TRACE_PACKET="$(pwd)/log" git -C daemon_child -c protocol.version=2 \
+		fetch --no-tags origin $(cat two_a_hash) &&
+
+	grep "fetch< version 2" log &&
+	! grep "fetch> command=ls-refs" log
+'
+
 test_expect_success 'pull with git:// using protocol v2' '
 	test_when_finished "rm -f log" &&
 
@@ -138,10 +151,10 @@ test_expect_success 'list refs with file
 	grep "git< version 2" log &&
 
 	git ls-remote --symref "file://$(pwd)/file_parent" >expect &&
-	test_cmp actual expect
+	test_cmp expect actual
 '
 
-test_expect_success 'ref advertisment is filtered with ls-remote using protocol v2' '
+test_expect_success 'ref advertisement is filtered with ls-remote using protocol v2' '
 	test_when_finished "rm -f log" &&
 
 	GIT_TRACE_PACKET="$(pwd)/log" git -c protocol.version=2 \
@@ -151,7 +164,7 @@ test_expect_success 'ref advertisment is
 	$(git -C file_parent rev-parse refs/heads/master)$(printf "\t")refs/heads/master
 	EOF
 
-	test_cmp actual expect
+	test_cmp expect actual
 '
 
 test_expect_success 'server-options are sent when using ls-remote' '
@@ -164,11 +177,18 @@ test_expect_success 'server-options are
 	$(git -C file_parent rev-parse refs/heads/master)$(printf "\t")refs/heads/master
 	EOF
 
-	test_cmp actual expect &&
+	test_cmp expect actual &&
 	grep "server-option=hello" log &&
 	grep "server-option=world" log
 '
 
+test_expect_success 'warn if using server-option with ls-remote with legacy protocol' '
+	test_must_fail env GIT_TEST_PROTOCOL_VERSION=0 git -c protocol.version=0 \
+		ls-remote -o hello -o world "file://$(pwd)/file_parent" master 2>err &&
+
+	test_i18ngrep "see protocol.version in" err &&
+	test_i18ngrep "server options require protocol version 2 or later" err
+'
 
 test_expect_success 'clone with file:// using protocol v2' '
 	test_when_finished "rm -f log" &&
@@ -181,7 +201,12 @@ test_expect_success 'clone with file://
 	test_cmp expect actual &&
 
 	# Server responded using protocol v2
-	grep "clone< version 2" log
+	grep "clone< version 2" log &&
+
+	# Client sent ref-prefixes to filter the ref-advertisement
+	grep "ref-prefix HEAD" log &&
+	grep "ref-prefix refs/heads/" log &&
+	grep "ref-prefix refs/tags/" log
 '
 
 test_expect_success 'fetch with file:// using protocol v2' '
@@ -200,10 +225,11 @@ test_expect_success 'fetch with file://
 	grep "fetch< version 2" log
 '
 
-test_expect_success 'ref advertisment is filtered during fetch using protocol v2' '
+test_expect_success 'ref advertisement is filtered during fetch using protocol v2' '
 	test_when_finished "rm -f log" &&
 
 	test_commit -C file_parent three &&
+	git -C file_parent branch unwanted-branch three &&
 
 	GIT_TRACE_PACKET="$(pwd)/log" git -C file_child -c protocol.version=2 \
 		fetch origin master &&
@@ -212,9 +238,8 @@ test_expect_success 'ref advertisment is
 	git -C file_parent log -1 --format=%s >expect &&
 	test_cmp expect actual &&
 
-	! grep "refs/tags/one" log &&
-	! grep "refs/tags/two" log &&
-	! grep "refs/tags/three" log
+	grep "refs/heads/master" log &&
+	! grep "refs/heads/unwanted-branch" log
 '
 
 test_expect_success 'server-options are sent when fetching' '
@@ -233,6 +258,40 @@ test_expect_success 'server-options are
 	grep "server-option=world" log
 '
 
+test_expect_success 'warn if using server-option with fetch with legacy protocol' '
+	test_when_finished "rm -rf temp_child" &&
+
+	git init temp_child &&
+
+	test_must_fail env GIT_TEST_PROTOCOL_VERSION=0 git -C temp_child -c protocol.version=0 \
+		fetch -o hello -o world "file://$(pwd)/file_parent" master 2>err &&
+
+	test_i18ngrep "see protocol.version in" err &&
+	test_i18ngrep "server options require protocol version 2 or later" err
+'
+
+test_expect_success 'server-options are sent when cloning' '
+	test_when_finished "rm -rf log myclone" &&
+
+	GIT_TRACE_PACKET="$(pwd)/log" git -c protocol.version=2 \
+		clone --server-option=hello --server-option=world \
+		"file://$(pwd)/file_parent" myclone &&
+
+	grep "server-option=hello" log &&
+	grep "server-option=world" log
+'
+
+test_expect_success 'warn if using server-option with clone with legacy protocol' '
+	test_when_finished "rm -rf myclone" &&
+
+	test_must_fail env GIT_TEST_PROTOCOL_VERSION=0 git -c protocol.version=0 \
+		clone --server-option=hello --server-option=world \
+		"file://$(pwd)/file_parent" myclone 2>err &&
+
+	test_i18ngrep "see protocol.version in" err &&
+	test_i18ngrep "server options require protocol version 2 or later" err
+'
+
 test_expect_success 'upload-pack respects config using protocol v2' '
 	git init server &&
 	write_script server/.git/hook <<-\EOF &&
@@ -266,7 +325,7 @@ test_expect_success 'partial clone' '
 	grep "version 2" trace &&
 
 	# Ensure that the old version of the file is missing
-	git -C client rev-list master --quiet --objects --missing=print \
+	git -C client rev-list --quiet --objects --missing=print master \
 		>observed.oids &&
 	grep "$(git -C server rev-parse message1:a.txt)" observed.oids &&
 
@@ -281,6 +340,10 @@ test_expect_success 'dynamically fetch m
 	grep "version 2" trace
 '
 
+test_expect_success 'when dynamically fetching missing object, do not list refs' '
+	! grep "git> command=ls-refs" trace
+'
+
 test_expect_success 'partial fetch' '
 	rm -rf client "$(pwd)/trace" &&
 	git init client &&
@@ -292,7 +355,7 @@ test_expect_success 'partial fetch' '
 	grep "version 2" trace &&
 
 	# Ensure that the old version of the file is missing
-	git -C client rev-list other --quiet --objects --missing=print \
+	git -C client rev-list --quiet --objects --missing=print other \
 		>observed.oids &&
 	grep "$(git -C server rev-parse message1:a.txt)" observed.oids &&
 
@@ -329,7 +392,7 @@ test_expect_success 'even with handcraft
 	git -C server config uploadpack.allowfilter 0 &&
 
 	# Custom request that tries to filter even though it is not advertised.
-	test-pkt-line pack >in <<-EOF &&
+	test-tool pkt-line pack >in <<-EOF &&
 	command=fetch
 	0001
 	want $(git -C server rev-parse master)
@@ -337,12 +400,13 @@ test_expect_success 'even with handcraft
 	0000
 	EOF
 
-	test_must_fail git -C server serve --stateless-rpc <in >/dev/null 2>err &&
+	test_must_fail test-tool -C server serve-v2 --stateless-rpc \
+		<in >/dev/null 2>err &&
 	grep "unexpected line: .filter blob:none." err &&
 
 	# Exercise to ensure that if advertised, filter works
 	git -C server config uploadpack.allowfilter 1 &&
-	git -C server serve --stateless-rpc <in >/dev/null
+	test-tool -C server serve-v2 --stateless-rpc <in >/dev/null
 '
 
 test_expect_success 'default refspec is used to filter ref when fetchcing' '
@@ -359,6 +423,140 @@ test_expect_success 'default refspec is
 	grep "ref-prefix refs/tags/" log
 '
 
+test_expect_success 'fetch supports various ways of have lines' '
+	rm -rf server client trace &&
+	git init server &&
+	test_commit -C server dwim &&
+	TREE=$(git -C server rev-parse HEAD^{tree}) &&
+	git -C server tag exact \
+		$(git -C server commit-tree -m a "$TREE") &&
+	git -C server tag dwim-unwanted \
+		$(git -C server commit-tree -m b "$TREE") &&
+	git -C server tag exact-unwanted \
+		$(git -C server commit-tree -m c "$TREE") &&
+	git -C server tag prefix1 \
+		$(git -C server commit-tree -m d "$TREE") &&
+	git -C server tag prefix2 \
+		$(git -C server commit-tree -m e "$TREE") &&
+	git -C server tag fetch-by-sha1 \
+		$(git -C server commit-tree -m f "$TREE") &&
+	git -C server tag completely-unrelated \
+		$(git -C server commit-tree -m g "$TREE") &&
+
+	git init client &&
+	GIT_TRACE_PACKET="$(pwd)/trace" git -C client -c protocol.version=2 \
+		fetch "file://$(pwd)/server" \
+		dwim \
+		refs/tags/exact \
+		refs/tags/prefix*:refs/tags/prefix* \
+		"$(git -C server rev-parse fetch-by-sha1)" &&
+
+	# Ensure that the appropriate prefixes are sent (using a sample)
+	grep "fetch> ref-prefix dwim" trace &&
+	grep "fetch> ref-prefix refs/heads/dwim" trace &&
+	grep "fetch> ref-prefix refs/tags/prefix" trace &&
+
+	# Ensure that the correct objects are returned
+	git -C client cat-file -e $(git -C server rev-parse dwim) &&
+	git -C client cat-file -e $(git -C server rev-parse exact) &&
+	git -C client cat-file -e $(git -C server rev-parse prefix1) &&
+	git -C client cat-file -e $(git -C server rev-parse prefix2) &&
+	git -C client cat-file -e $(git -C server rev-parse fetch-by-sha1) &&
+	test_must_fail git -C client cat-file -e \
+		$(git -C server rev-parse dwim-unwanted) &&
+	test_must_fail git -C client cat-file -e \
+		$(git -C server rev-parse exact-unwanted) &&
+	test_must_fail git -C client cat-file -e \
+		$(git -C server rev-parse completely-unrelated)
+'
+
+test_expect_success 'fetch supports include-tag and tag following' '
+	rm -rf server client trace &&
+	git init server &&
+
+	test_commit -C server to_fetch &&
+	git -C server tag -a annotated_tag -m message &&
+
+	git init client &&
+	GIT_TRACE_PACKET="$(pwd)/trace" git -C client -c protocol.version=2 \
+		fetch "$(pwd)/server" to_fetch:to_fetch &&
+
+	grep "fetch> ref-prefix to_fetch" trace &&
+	grep "fetch> ref-prefix refs/tags/" trace &&
+	grep "fetch> include-tag" trace &&
+
+	git -C client cat-file -e $(git -C client rev-parse annotated_tag)
+'
+
+test_expect_success 'upload-pack respects client shallows' '
+	rm -rf server client trace &&
+
+	git init server &&
+	test_commit -C server base &&
+	test_commit -C server client_has &&
+
+	git clone --depth=1 "file://$(pwd)/server" client &&
+
+	# Add extra commits to the client so that the whole fetch takes more
+	# than 1 request (due to negotiation)
+	test_commit_bulk -C client --id=c 32 &&
+
+	git -C server checkout -b newbranch base &&
+	test_commit -C server client_wants &&
+
+	GIT_TRACE_PACKET="$(pwd)/trace" git -C client -c protocol.version=2 \
+		fetch origin newbranch &&
+	# Ensure that protocol v2 is used
+	grep "fetch< version 2" trace
+'
+
+test_expect_success 'ensure that multiple fetches in same process from a shallow repo works' '
+	rm -rf server client trace &&
+
+	test_create_repo server &&
+	test_commit -C server one &&
+	test_commit -C server two &&
+	test_commit -C server three &&
+	git clone --shallow-exclude two "file://$(pwd)/server" client &&
+
+	git -C server tag -a -m "an annotated tag" twotag two &&
+
+	# Triggers tag following (thus, 2 fetches in one process)
+	GIT_TRACE_PACKET="$(pwd)/trace" git -C client -c protocol.version=2 \
+		fetch --shallow-exclude one origin &&
+	# Ensure that protocol v2 is used
+	grep "fetch< version 2" trace
+'
+
+test_expect_success 'deepen-relative' '
+	rm -rf server client trace &&
+
+	test_create_repo server &&
+	test_commit -C server one &&
+	test_commit -C server two &&
+	test_commit -C server three &&
+	git clone --depth 1 "file://$(pwd)/server" client &&
+	test_commit -C server four &&
+
+	# Sanity check that only "three" is downloaded
+	git -C client log --pretty=tformat:%s master >actual &&
+	echo three >expected &&
+	test_cmp expected actual &&
+
+	GIT_TRACE_PACKET="$(pwd)/trace" git -C client -c protocol.version=2 \
+		fetch --deepen=1 origin &&
+	# Ensure that protocol v2 is used
+	grep "fetch< version 2" trace &&
+
+	git -C client log --pretty=tformat:%s origin/master >actual &&
+	cat >expected <<-\EOF &&
+	four
+	three
+	two
+	EOF
+	test_cmp expected actual
+'
+
 # Test protocol v2 with 'http://' transport
 #
 . "$TEST_DIRECTORY"/lib-httpd.sh
@@ -383,7 +581,38 @@ test_expect_success 'clone with http://
 	# Client requested to use protocol v2
 	grep "Git-Protocol: version=2" log &&
 	# Server responded using protocol v2
-	grep "git< version 2" log
+	grep "git< version 2" log &&
+	# Verify that the chunked encoding sending codepath is NOT exercised
+	! grep "Send header: Transfer-Encoding: chunked" log
+'
+
+test_expect_success 'clone big repository with http:// using protocol v2' '
+	test_when_finished "rm -f log" &&
+
+	git init "$HTTPD_DOCUMENT_ROOT_PATH/big" &&
+	# Ensure that the list of wants is greater than http.postbuffer below
+	for i in $(test_seq 1 1500)
+	do
+		# do not use here-doc, because it requires a process
+		# per loop iteration
+		echo "commit refs/heads/too-many-refs-$i" &&
+		echo "committer git <git@example.com> $i +0000" &&
+		echo "data 0" &&
+		echo "M 644 inline bla.txt" &&
+		echo "data 4" &&
+		echo "bla"
+	done | git -C "$HTTPD_DOCUMENT_ROOT_PATH/big" fast-import &&
+
+	GIT_TRACE_PACKET="$(pwd)/log" GIT_TRACE_CURL="$(pwd)/log" git \
+		-c protocol.version=2 -c http.postbuffer=65536 \
+		clone "$HTTPD_URL/smart/big" big_child &&
+
+	# Client requested to use protocol v2
+	grep "Git-Protocol: version=2" log &&
+	# Server responded using protocol v2
+	grep "git< version 2" log &&
+	# Verify that the chunked encoding sending codepath is exercised
+	grep "Send header: Transfer-Encoding: chunked" log
 '
 
 test_expect_success 'fetch with http:// using protocol v2' '
@@ -402,6 +631,52 @@ test_expect_success 'fetch with http://
 	grep "git< version 2" log
 '
 
+test_expect_success 'fetch with http:// by hash without tag following with protocol v2 does not list refs' '
+	test_when_finished "rm -f log" &&
+
+	test_commit -C "$HTTPD_DOCUMENT_ROOT_PATH/http_parent" two_a &&
+	git -C "$HTTPD_DOCUMENT_ROOT_PATH/http_parent" rev-parse two_a >two_a_hash &&
+
+	GIT_TRACE_PACKET="$(pwd)/log" git -C http_child -c protocol.version=2 \
+		fetch --no-tags origin $(cat two_a_hash) &&
+
+	grep "fetch< version 2" log &&
+	! grep "fetch> command=ls-refs" log
+'
+
+test_expect_success 'fetch from namespaced repo respects namespaces' '
+	test_when_finished "rm -f log" &&
+
+	git init "$HTTPD_DOCUMENT_ROOT_PATH/nsrepo" &&
+	test_commit -C "$HTTPD_DOCUMENT_ROOT_PATH/nsrepo" one &&
+	test_commit -C "$HTTPD_DOCUMENT_ROOT_PATH/nsrepo" two &&
+	git -C "$HTTPD_DOCUMENT_ROOT_PATH/nsrepo" \
+		update-ref refs/namespaces/ns/refs/heads/master one &&
+
+	GIT_TRACE_PACKET="$(pwd)/log" git -C http_child -c protocol.version=2 \
+		fetch "$HTTPD_URL/smart_namespace/nsrepo" \
+		refs/heads/master:refs/heads/theirs &&
+
+	# Server responded using protocol v2
+	grep "fetch< version 2" log &&
+
+	git -C "$HTTPD_DOCUMENT_ROOT_PATH/nsrepo" rev-parse one >expect &&
+	git -C http_child rev-parse theirs >actual &&
+	test_cmp expect actual
+'
+
+test_expect_success 'ls-remote with v2 http sends only one POST' '
+	test_when_finished "rm -f log" &&
+
+	git ls-remote "$HTTPD_DOCUMENT_ROOT_PATH/http_parent" >expect &&
+	GIT_TRACE_CURL="$(pwd)/log" git -c protocol.version=2 \
+		ls-remote "$HTTPD_URL/smart/http_parent" >actual &&
+	test_cmp expect actual &&
+
+	grep "Send header: POST" log >posts &&
+	test_line_count = 1 posts
+'
+
 test_expect_success 'push with http:// and a config of v2 does not request v2' '
 	test_when_finished "rm -f log" &&
 	# Till v2 for push is designed, make sure that if a client has
@@ -419,13 +694,61 @@ test_expect_success 'push with http:// a
 	git -C "$HTTPD_DOCUMENT_ROOT_PATH/http_parent" log -1 --format=%s client_branch >expect &&
 	test_cmp expect actual &&
 
-	# Client didnt request to use protocol v2
+	# Client did not request to use protocol v2
 	! grep "Git-Protocol: version=2" log &&
-	# Server didnt respond using protocol v2
+	# Server did not respond using protocol v2
 	! grep "git< version 2" log
 '
 
+test_expect_success 'when server sends "ready", expect DELIM' '
+	rm -rf "$HTTPD_DOCUMENT_ROOT_PATH/http_parent" http_child &&
+
+	git init "$HTTPD_DOCUMENT_ROOT_PATH/http_parent" &&
+	test_commit -C "$HTTPD_DOCUMENT_ROOT_PATH/http_parent" one &&
+
+	git clone "$HTTPD_URL/smart/http_parent" http_child &&
+
+	test_commit -C "$HTTPD_DOCUMENT_ROOT_PATH/http_parent" two &&
+
+	# After "ready" in the acknowledgments section, pretend that a FLUSH
+	# (0000) was sent instead of a DELIM (0001).
+	printf "/ready/,$ s/0001/0000/" \
+		>"$HTTPD_ROOT_PATH/one-time-sed" &&
+
+	test_must_fail git -C http_child -c protocol.version=2 \
+		fetch "$HTTPD_URL/one_time_sed/http_parent" 2> err &&
+	test_i18ngrep "expected packfile to be sent after .ready." err
+'
+
+test_expect_success 'when server does not send "ready", expect FLUSH' '
+	rm -rf "$HTTPD_DOCUMENT_ROOT_PATH/http_parent" http_child log &&
+
+	git init "$HTTPD_DOCUMENT_ROOT_PATH/http_parent" &&
+	test_commit -C "$HTTPD_DOCUMENT_ROOT_PATH/http_parent" one &&
+
+	git clone "$HTTPD_URL/smart/http_parent" http_child &&
+
+	test_commit -C "$HTTPD_DOCUMENT_ROOT_PATH/http_parent" two &&
+
+	# Create many commits to extend the negotiation phase across multiple
+	# requests, so that the server does not send "ready" in the first
+	# request.
+	test_commit_bulk -C http_child --id=c 32 &&
+
+	# After the acknowledgments section, pretend that a DELIM
+	# (0001) was sent instead of a FLUSH (0000).
+	printf "/acknowledgments/,$ s/0000/0001/" \
+		>"$HTTPD_ROOT_PATH/one-time-sed" &&
+
+	test_must_fail env GIT_TRACE_PACKET="$(pwd)/log" git -C http_child \
+		-c protocol.version=2 \
+		fetch "$HTTPD_URL/one_time_sed/http_parent" 2> err &&
+	grep "fetch< .*acknowledgments" log &&
+	! grep "fetch< .*ready" log &&
+	test_i18ngrep "expected no other sections to be sent after no .ready." err
+'
 
-stop_httpd
+# DO NOT add non-httpd-specific tests here, because the last part of this
+# test script is only executed when httpd is available and enabled.
 
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t5703-upload-pack-ref-in-want.sh 1.2.3+git2.25.1-1/git/t/t5703-upload-pack-ref-in-want.sh
--- 1.2.1+git2.18.0-1/git/t/t5703-upload-pack-ref-in-want.sh	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t5703-upload-pack-ref-in-want.sh	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,390 @@
+#!/bin/sh
+
+test_description='upload-pack ref-in-want'
+
+. ./test-lib.sh
+
+get_actual_refs () {
+	sed -n -e '/wanted-refs/,/0001/{
+		/wanted-refs/d
+		/0001/d
+		p
+		}' <out | test-tool pkt-line unpack >actual_refs
+}
+
+get_actual_commits () {
+	sed -n -e '/packfile/,/0000/{
+		/packfile/d
+		p
+		}' <out | test-tool pkt-line unpack-sideband >o.pack &&
+	git index-pack o.pack &&
+	git verify-pack -v o.idx >objs &&
+	grep commit objs | cut -c-40 | sort >actual_commits
+}
+
+check_output () {
+	get_actual_refs &&
+	test_cmp expected_refs actual_refs &&
+	get_actual_commits &&
+	sort expected_commits >sorted_commits &&
+	test_cmp sorted_commits actual_commits
+}
+
+# c(o/foo) d(o/bar)
+#        \ /
+#         b   e(baz)  f(master)
+#          \__  |  __/
+#             \ | /
+#               a
+test_expect_success 'setup repository' '
+	test_commit a &&
+	git checkout -b o/foo &&
+	test_commit b &&
+	test_commit c &&
+	git checkout -b o/bar b &&
+	test_commit d &&
+	git checkout -b baz a &&
+	test_commit e &&
+	git checkout master &&
+	test_commit f
+'
+
+test_expect_success 'config controls ref-in-want advertisement' '
+	test-tool serve-v2 --advertise-capabilities >out &&
+	! grep -a ref-in-want out &&
+
+	git config uploadpack.allowRefInWant false &&
+	test-tool serve-v2 --advertise-capabilities >out &&
+	! grep -a ref-in-want out &&
+
+	git config uploadpack.allowRefInWant true &&
+	test-tool serve-v2 --advertise-capabilities >out &&
+	grep -a ref-in-want out
+'
+
+test_expect_success 'invalid want-ref line' '
+	test-tool pkt-line pack >in <<-EOF &&
+	command=fetch
+	0001
+	no-progress
+	want-ref refs/heads/non-existent
+	done
+	0000
+	EOF
+
+	test_must_fail test-tool serve-v2 --stateless-rpc 2>out <in &&
+	grep "unknown ref" out
+'
+
+test_expect_success 'basic want-ref' '
+	oid=$(git rev-parse f) &&
+	cat >expected_refs <<-EOF &&
+	$oid refs/heads/master
+	EOF
+	git rev-parse f >expected_commits &&
+
+	oid=$(git rev-parse a) &&
+	test-tool pkt-line pack >in <<-EOF &&
+	command=fetch
+	0001
+	no-progress
+	want-ref refs/heads/master
+	have $oid
+	done
+	0000
+	EOF
+
+	test-tool serve-v2 --stateless-rpc >out <in &&
+	check_output
+'
+
+test_expect_success 'multiple want-ref lines' '
+	oid_c=$(git rev-parse c) &&
+	oid_d=$(git rev-parse d) &&
+	cat >expected_refs <<-EOF &&
+	$oid_c refs/heads/o/foo
+	$oid_d refs/heads/o/bar
+	EOF
+	git rev-parse c d >expected_commits &&
+
+	oid=$(git rev-parse b) &&
+	test-tool pkt-line pack >in <<-EOF &&
+	command=fetch
+	0001
+	no-progress
+	want-ref refs/heads/o/foo
+	want-ref refs/heads/o/bar
+	have $oid
+	done
+	0000
+	EOF
+
+	test-tool serve-v2 --stateless-rpc >out <in &&
+	check_output
+'
+
+test_expect_success 'mix want and want-ref' '
+	oid=$(git rev-parse f) &&
+	cat >expected_refs <<-EOF &&
+	$oid refs/heads/master
+	EOF
+	git rev-parse e f >expected_commits &&
+
+	test-tool pkt-line pack >in <<-EOF &&
+	command=fetch
+	0001
+	no-progress
+	want-ref refs/heads/master
+	want $(git rev-parse e)
+	have $(git rev-parse a)
+	done
+	0000
+	EOF
+
+	test-tool serve-v2 --stateless-rpc >out <in &&
+	check_output
+'
+
+test_expect_success 'want-ref with ref we already have commit for' '
+	oid=$(git rev-parse c) &&
+	cat >expected_refs <<-EOF &&
+	$oid refs/heads/o/foo
+	EOF
+	>expected_commits &&
+
+	oid=$(git rev-parse c) &&
+	test-tool pkt-line pack >in <<-EOF &&
+	command=fetch
+	0001
+	no-progress
+	want-ref refs/heads/o/foo
+	have $oid
+	done
+	0000
+	EOF
+
+	test-tool serve-v2 --stateless-rpc >out <in &&
+	check_output
+'
+
+REPO="$(pwd)/repo"
+LOCAL_PRISTINE="$(pwd)/local_pristine"
+
+# $REPO
+# c(o/foo) d(o/bar)
+#        \ /
+#         b   e(baz)  f(master)
+#          \__  |  __/
+#             \ | /
+#               a
+#
+# $LOCAL_PRISTINE
+#		s32(side)
+#		|
+#		.
+#		.
+#		|
+#		a(master)
+test_expect_success 'setup repos for fetching with ref-in-want tests' '
+	(
+		git init "$REPO" &&
+		cd "$REPO" &&
+		test_commit a &&
+
+		# Local repo with many commits (so that negotiation will take
+		# more than 1 request/response pair)
+		rm -rf "$LOCAL_PRISTINE" &&
+		git clone "file://$REPO" "$LOCAL_PRISTINE" &&
+		cd "$LOCAL_PRISTINE" &&
+		git checkout -b side &&
+		test_commit_bulk --id=s 33 &&
+
+		# Add novel commits to upstream
+		git checkout master &&
+		cd "$REPO" &&
+		git checkout -b o/foo &&
+		test_commit b &&
+		test_commit c &&
+		git checkout -b o/bar b &&
+		test_commit d &&
+		git checkout -b baz a &&
+		test_commit e &&
+		git checkout master &&
+		test_commit f
+	) &&
+	git -C "$REPO" config uploadpack.allowRefInWant true &&
+	git -C "$LOCAL_PRISTINE" config protocol.version 2
+'
+
+test_expect_success 'fetching with exact OID' '
+	test_when_finished "rm -f log" &&
+
+	rm -rf local &&
+	cp -r "$LOCAL_PRISTINE" local &&
+	oid=$(git -C "$REPO" rev-parse d) &&
+	GIT_TRACE_PACKET="$(pwd)/log" git -C local fetch origin \
+		"$oid":refs/heads/actual &&
+
+	git -C "$REPO" rev-parse "d" >expected &&
+	git -C local rev-parse refs/heads/actual >actual &&
+	test_cmp expected actual &&
+	grep "want $oid" log
+'
+
+test_expect_success 'fetching multiple refs' '
+	test_when_finished "rm -f log" &&
+
+	rm -rf local &&
+	cp -r "$LOCAL_PRISTINE" local &&
+	GIT_TRACE_PACKET="$(pwd)/log" git -C local fetch origin master baz &&
+
+	git -C "$REPO" rev-parse "master" "baz" >expected &&
+	git -C local rev-parse refs/remotes/origin/master refs/remotes/origin/baz >actual &&
+	test_cmp expected actual &&
+	grep "want-ref refs/heads/master" log &&
+	grep "want-ref refs/heads/baz" log
+'
+
+test_expect_success 'fetching ref and exact OID' '
+	test_when_finished "rm -f log" &&
+
+	rm -rf local &&
+	cp -r "$LOCAL_PRISTINE" local &&
+	oid=$(git -C "$REPO" rev-parse b) &&
+	GIT_TRACE_PACKET="$(pwd)/log" git -C local fetch origin \
+		master "$oid":refs/heads/actual &&
+
+	git -C "$REPO" rev-parse "master" "b" >expected &&
+	git -C local rev-parse refs/remotes/origin/master refs/heads/actual >actual &&
+	test_cmp expected actual &&
+	grep "want $oid" log &&
+	grep "want-ref refs/heads/master" log
+'
+
+test_expect_success 'fetching with wildcard that does not match any refs' '
+	test_when_finished "rm -f log" &&
+
+	rm -rf local &&
+	cp -r "$LOCAL_PRISTINE" local &&
+	git -C local fetch origin refs/heads/none*:refs/heads/* >out &&
+	test_must_be_empty out
+'
+
+test_expect_success 'fetching with wildcard that matches multiple refs' '
+	test_when_finished "rm -f log" &&
+
+	rm -rf local &&
+	cp -r "$LOCAL_PRISTINE" local &&
+	GIT_TRACE_PACKET="$(pwd)/log" git -C local fetch origin refs/heads/o*:refs/heads/o* &&
+
+	git -C "$REPO" rev-parse "o/foo" "o/bar" >expected &&
+	git -C local rev-parse "o/foo" "o/bar" >actual &&
+	test_cmp expected actual &&
+	grep "want-ref refs/heads/o/foo" log &&
+	grep "want-ref refs/heads/o/bar" log
+'
+
+. "$TEST_DIRECTORY"/lib-httpd.sh
+start_httpd
+
+REPO="$HTTPD_DOCUMENT_ROOT_PATH/repo"
+LOCAL_PRISTINE="$(pwd)/local_pristine"
+
+test_expect_success 'setup repos for change-while-negotiating test' '
+	(
+		git init "$REPO" &&
+		cd "$REPO" &&
+		>.git/git-daemon-export-ok &&
+		test_commit m1 &&
+		git tag -d m1 &&
+
+		# Local repo with many commits (so that negotiation will take
+		# more than 1 request/response pair)
+		rm -rf "$LOCAL_PRISTINE" &&
+		git clone "http://127.0.0.1:$LIB_HTTPD_PORT/smart/repo" "$LOCAL_PRISTINE" &&
+		cd "$LOCAL_PRISTINE" &&
+		git checkout -b side &&
+		test_commit_bulk --id=s 33 &&
+
+		# Add novel commits to upstream
+		git checkout master &&
+		cd "$REPO" &&
+		test_commit m2 &&
+		test_commit m3 &&
+		git tag -d m2 m3
+	) &&
+	git -C "$LOCAL_PRISTINE" remote set-url origin "http://127.0.0.1:$LIB_HTTPD_PORT/one_time_sed/repo" &&
+	git -C "$LOCAL_PRISTINE" config protocol.version 2
+'
+
+inconsistency () {
+	# Simulate that the server initially reports $2 as the ref
+	# corresponding to $1, and after that, $1 as the ref corresponding to
+	# $1. This corresponds to the real-life situation where the server's
+	# repository appears to change during negotiation, for example, when
+	# different servers in a load-balancing arrangement serve (stateless)
+	# RPCs during a single negotiation.
+	oid1=$(git -C "$REPO" rev-parse $1) &&
+	oid2=$(git -C "$REPO" rev-parse $2) &&
+	echo "s/$oid1/$oid2/" >"$HTTPD_ROOT_PATH/one-time-sed"
+}
+
+test_expect_success 'server is initially ahead - no ref in want' '
+	git -C "$REPO" config uploadpack.allowRefInWant false &&
+	rm -rf local &&
+	cp -r "$LOCAL_PRISTINE" local &&
+	inconsistency master 1234567890123456789012345678901234567890 &&
+	test_must_fail git -C local fetch 2>err &&
+	test_i18ngrep "fatal: remote error: upload-pack: not our ref" err
+'
+
+test_expect_success 'server is initially ahead - ref in want' '
+	git -C "$REPO" config uploadpack.allowRefInWant true &&
+	rm -rf local &&
+	cp -r "$LOCAL_PRISTINE" local &&
+	inconsistency master 1234567890123456789012345678901234567890 &&
+	git -C local fetch &&
+
+	git -C "$REPO" rev-parse --verify master >expected &&
+	git -C local rev-parse --verify refs/remotes/origin/master >actual &&
+	test_cmp expected actual
+'
+
+test_expect_success 'server is initially behind - no ref in want' '
+	git -C "$REPO" config uploadpack.allowRefInWant false &&
+	rm -rf local &&
+	cp -r "$LOCAL_PRISTINE" local &&
+	inconsistency master "master^" &&
+	git -C local fetch &&
+
+	git -C "$REPO" rev-parse --verify "master^" >expected &&
+	git -C local rev-parse --verify refs/remotes/origin/master >actual &&
+	test_cmp expected actual
+'
+
+test_expect_success 'server is initially behind - ref in want' '
+	git -C "$REPO" config uploadpack.allowRefInWant true &&
+	rm -rf local &&
+	cp -r "$LOCAL_PRISTINE" local &&
+	inconsistency master "master^" &&
+	git -C local fetch &&
+
+	git -C "$REPO" rev-parse --verify "master" >expected &&
+	git -C local rev-parse --verify refs/remotes/origin/master >actual &&
+	test_cmp expected actual
+'
+
+test_expect_success 'server loses a ref - ref in want' '
+	git -C "$REPO" config uploadpack.allowRefInWant true &&
+	rm -rf local &&
+	cp -r "$LOCAL_PRISTINE" local &&
+	echo "s/master/raster/" >"$HTTPD_ROOT_PATH/one-time-sed" &&
+	test_must_fail git -C local fetch 2>err &&
+
+	test_i18ngrep "fatal: remote error: unknown ref refs/heads/raster" err
+'
+
+# DO NOT add non-httpd-specific tests here, because the last part of this
+# test script is only executed when httpd is available and enabled.
+
+test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t5801/git-remote-testgit 1.2.3+git2.25.1-1/git/t/t5801/git-remote-testgit
--- 1.2.1+git2.18.0-1/git/t/t5801/git-remote-testgit	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t5801/git-remote-testgit	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,151 @@
+#!/bin/sh
+# Copyright (c) 2012 Felipe Contreras
+
+# The first argument can be a url when the fetch/push command was a url
+# instead of a configured remote. In this case, use a generic alias.
+if test "$1" = "testgit::$2"; then
+	alias=_
+else
+	alias=$1
+fi
+url=$2
+
+dir="$GIT_DIR/testgit/$alias"
+
+h_refspec="refs/heads/*:refs/testgit/$alias/heads/*"
+t_refspec="refs/tags/*:refs/testgit/$alias/tags/*"
+
+if test -n "$GIT_REMOTE_TESTGIT_NOREFSPEC"
+then
+	h_refspec=""
+	t_refspec=""
+fi
+
+GIT_DIR="$url/.git"
+export GIT_DIR
+
+force=
+
+mkdir -p "$dir"
+
+if test -z "$GIT_REMOTE_TESTGIT_NO_MARKS"
+then
+	gitmarks="$dir/git.marks"
+	testgitmarks="$dir/testgit.marks"
+	test -e "$gitmarks" || >"$gitmarks"
+	test -e "$testgitmarks" || >"$testgitmarks"
+fi
+
+while read line
+do
+	case $line in
+	capabilities)
+		echo 'import'
+		echo 'export'
+		test -n "$h_refspec" && echo "refspec $h_refspec"
+		test -n "$t_refspec" && echo "refspec $t_refspec"
+		if test -n "$gitmarks"
+		then
+			echo "*import-marks $gitmarks"
+			echo "*export-marks $gitmarks"
+		fi
+		test -n "$GIT_REMOTE_TESTGIT_SIGNED_TAGS" && echo "signed-tags"
+		test -n "$GIT_REMOTE_TESTGIT_NO_PRIVATE_UPDATE" && echo "no-private-update"
+		echo 'option'
+		echo
+		;;
+	list)
+		git for-each-ref --format='? %(refname)' 'refs/heads/' 'refs/tags/'
+		head=$(git symbolic-ref HEAD)
+		echo "@$head HEAD"
+		echo
+		;;
+	import*)
+		# read all import lines
+		while true
+		do
+			ref="${line#* }"
+			refs="$refs $ref"
+			read line
+			test "${line%% *}" != "import" && break
+		done
+
+		if test -n "$gitmarks"
+		then
+			echo "feature import-marks=$gitmarks"
+			echo "feature export-marks=$gitmarks"
+		fi
+
+		if test -n "$GIT_REMOTE_TESTGIT_FAILURE"
+		then
+			echo "feature done"
+			exit 1
+		fi
+
+		echo "feature done"
+		git fast-export \
+			${h_refspec:+"--refspec=$h_refspec"} \
+			${t_refspec:+"--refspec=$t_refspec"} \
+			${testgitmarks:+"--import-marks=$testgitmarks"} \
+			${testgitmarks:+"--export-marks=$testgitmarks"} \
+			$refs
+		echo "done"
+		;;
+	export)
+		if test -n "$GIT_REMOTE_TESTGIT_FAILURE"
+		then
+			# consume input so fast-export doesn't get SIGPIPE;
+			# git would also notice that case, but we want
+			# to make sure we are exercising the later
+			# error checks
+			while read line; do
+				test "done" = "$line" && break
+			done
+			exit 1
+		fi
+
+		before=$(git for-each-ref --format=' %(refname) %(objectname) ')
+
+		git fast-import \
+			${force:+--force} \
+			${testgitmarks:+"--import-marks=$testgitmarks"} \
+			${testgitmarks:+"--export-marks=$testgitmarks"} \
+			--quiet
+
+		# figure out which refs were updated
+		git for-each-ref --format='%(refname) %(objectname)' |
+		while read ref a
+		do
+			case "$before" in
+			*" $ref $a "*)
+				continue ;;	# unchanged
+			esac
+			if test -z "$GIT_REMOTE_TESTGIT_PUSH_ERROR"
+			then
+				echo "ok $ref"
+			else
+				echo "error $ref $GIT_REMOTE_TESTGIT_PUSH_ERROR"
+			fi
+		done
+
+		echo
+		;;
+	option\ *)
+		read cmd opt val <<-EOF
+		$line
+		EOF
+		case $opt in
+		force)
+			test $val = "true" && force="true" || force=
+			echo "ok"
+			;;
+		*)
+			echo "unsupported"
+			;;
+		esac
+		;;
+	'')
+		exit
+		;;
+	esac
+done
diff -pruN 1.2.1+git2.18.0-1/git/t/t5801-remote-helpers.sh 1.2.3+git2.25.1-1/git/t/t5801-remote-helpers.sh
--- 1.2.1+git2.18.0-1/git/t/t5801-remote-helpers.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t5801-remote-helpers.sh	2020-02-17 04:47:35.000000000 +0000
@@ -8,6 +8,8 @@ test_description='Test remote-helper imp
 . ./test-lib.sh
 . "$TEST_DIRECTORY"/lib-gpg.sh
 
+PATH="$TEST_DIRECTORY/t5801:$PATH"
+
 compare_refs() {
 	git --git-dir="$1/.git" rev-parse --verify $2 >expect &&
 	git --git-dir="$3/.git" rev-parse --verify $4 >actual &&
@@ -96,7 +98,7 @@ test_expect_success 'push new branch wit
 
 test_expect_success 'push new branch with HEAD:new refspec' '
 	(cd local &&
-	 git checkout new-name
+	 git checkout new-name &&
 	 git push origin HEAD:new-refspec-2
 	) &&
 	compare_refs local HEAD server refs/heads/new-refspec-2
@@ -124,17 +126,17 @@ test_expect_success 'forced push' '
 '
 
 test_expect_success 'cloning without refspec' '
-	GIT_REMOTE_TESTGIT_REFSPEC="" \
+	GIT_REMOTE_TESTGIT_NOREFSPEC=1 \
 	git clone "testgit::${PWD}/server" local2 2>error &&
-	grep "This remote helper should implement refspec capability" error &&
+	test_i18ngrep "this remote helper should implement refspec capability" error &&
 	compare_refs local2 HEAD server HEAD
 '
 
 test_expect_success 'pulling without refspecs' '
 	(cd local2 &&
 	git reset --hard &&
-	GIT_REMOTE_TESTGIT_REFSPEC="" git pull 2>../error) &&
-	grep "This remote helper should implement refspec capability" error &&
+	GIT_REMOTE_TESTGIT_NOREFSPEC=1 git pull 2>../error) &&
+	test_i18ngrep "this remote helper should implement refspec capability" error &&
 	compare_refs local2 HEAD server HEAD
 '
 
@@ -143,10 +145,10 @@ test_expect_success 'pushing without ref
 	(cd local2 &&
 	echo content >>file &&
 	git commit -a -m ten &&
-	GIT_REMOTE_TESTGIT_REFSPEC="" &&
-	export GIT_REMOTE_TESTGIT_REFSPEC &&
+	GIT_REMOTE_TESTGIT_NOREFSPEC=1 &&
+	export GIT_REMOTE_TESTGIT_NOREFSPEC &&
 	test_must_fail git push 2>../error) &&
-	grep "remote-helper doesn.t support push; refspec needed" error
+	test_i18ngrep "remote-helper doesn.t support push; refspec needed" error
 '
 
 test_expect_success 'pulling without marks' '
@@ -245,8 +247,7 @@ clean_mark () {
 test_expect_success 'proper failure checks for fetching' '
 	(cd local &&
 	test_must_fail env GIT_REMOTE_TESTGIT_FAILURE=1 git fetch 2>error &&
-	cat error &&
-	grep -q "Error while running fast-import" error
+	test_i18ngrep -q "error while running fast-import" error
 	)
 '
 
@@ -301,4 +302,14 @@ test_expect_success 'fetch url' '
 	compare_refs server HEAD local FETCH_HEAD
 '
 
+test_expect_success 'fetch tag' '
+	(cd server &&
+	 git tag v1.0
+	) &&
+	(cd local &&
+	 git fetch
+	) &&
+	compare_refs local v1.0 server v1.0
+'
+
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t5812-proto-disable-http.sh 1.2.3+git2.25.1-1/git/t/t5812-proto-disable-http.sh
--- 1.2.1+git2.18.0-1/git/t/t5812-proto-disable-http.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t5812-proto-disable-http.sh	2020-02-17 04:47:35.000000000 +0000
@@ -34,5 +34,4 @@ test_expect_success 'http can be limited
 		clone "$HTTPD_URL/smart-redir-perm/repo.git" redir.git
 '
 
-stop_httpd
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t6000-rev-list-misc.sh 1.2.3+git2.25.1-1/git/t/t6000-rev-list-misc.sh
--- 1.2.1+git2.18.0-1/git/t/t6000-rev-list-misc.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t6000-rev-list-misc.sh	2020-02-17 04:47:35.000000000 +0000
@@ -48,6 +48,26 @@ test_expect_success 'rev-list --objects
 	! grep one output
 '
 
+test_expect_success 'rev-list --objects --no-object-names has no space/names' '
+	git rev-list --objects --no-object-names HEAD >output &&
+	! grep wanted_file output &&
+	! grep unwanted_file output &&
+	! grep " " output
+'
+
+test_expect_success 'rev-list --objects --no-object-names works with cat-file' '
+	git rev-list --objects --no-object-names --all >list-output &&
+	git cat-file --batch-check <list-output >cat-output &&
+	! grep missing cat-output
+'
+
+test_expect_success '--no-object-names and --object-names are last-one-wins' '
+	git rev-list --objects --no-object-names --object-names --all >output &&
+	grep wanted_file output &&
+	git rev-list --objects --object-names --no-object-names --all >output &&
+	! grep wanted_file output
+'
+
 test_expect_success 'rev-list A..B and rev-list ^A B are the same' '
 	git commit --allow-empty -m another &&
 	git tag -a -m "annotated" v1.0 &&
@@ -58,8 +78,7 @@ test_expect_success 'rev-list A..B and r
 
 test_expect_success 'propagate uninteresting flag down correctly' '
 	git rev-list --objects ^HEAD^{tree} HEAD^{tree} >actual &&
-	>expect &&
-	test_cmp expect actual
+	test_must_be_empty actual
 '
 
 test_expect_success 'symleft flag bit is propagated down from tag' '
@@ -91,11 +110,18 @@ test_expect_success 'rev-list can show i
 	9200b628cf9dc883a85a7abc8d6e6730baee589c two
 	EOF
 	echo only-in-index >only-in-index &&
+	test_when_finished "git reset --hard" &&
 	git add only-in-index &&
 	git rev-list --objects --indexed-objects >actual &&
 	test_cmp expect actual
 '
 
+test_expect_success 'rev-list can negate index objects' '
+	git rev-parse HEAD >expect &&
+	git rev-list -1 --objects HEAD --not --indexed-objects >actual &&
+	test_cmp expect actual
+'
+
 test_expect_success '--bisect and --first-parent can not be combined' '
 	test_must_fail git rev-list --bisect --first-parent HEAD
 '
@@ -114,4 +140,12 @@ test_expect_success '--header shows a NU
 	test_cmp expect actual
 '
 
+test_expect_success 'rev-list --end-of-options' '
+	git update-ref refs/heads/--output=yikes HEAD &&
+	git rev-list --end-of-options --output=yikes >actual &&
+	test_path_is_missing yikes &&
+	git rev-list HEAD >expect &&
+	test_cmp expect actual
+'
+
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t6006-rev-list-format.sh 1.2.3+git2.25.1-1/git/t/t6006-rev-list-format.sh
--- 1.2.1+git2.18.0-1/git/t/t6006-rev-list-format.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t6006-rev-list-format.sh	2020-02-17 04:47:35.000000000 +0000
@@ -109,31 +109,35 @@ commit $head1
 EOF
 
 # we don't test relative here
-test_format author %an%n%ae%n%ad%n%aD%n%at <<EOF
+test_format author %an%n%ae%n%al%n%ad%n%aD%n%at <<EOF
 commit $head2
-A U Thor
-author@example.com
+$GIT_AUTHOR_NAME
+$GIT_AUTHOR_EMAIL
+$TEST_AUTHOR_LOCALNAME
 Thu Apr 7 15:13:13 2005 -0700
 Thu, 7 Apr 2005 15:13:13 -0700
 1112911993
 commit $head1
-A U Thor
-author@example.com
+$GIT_AUTHOR_NAME
+$GIT_AUTHOR_EMAIL
+$TEST_AUTHOR_LOCALNAME
 Thu Apr 7 15:13:13 2005 -0700
 Thu, 7 Apr 2005 15:13:13 -0700
 1112911993
 EOF
 
-test_format committer %cn%n%ce%n%cd%n%cD%n%ct <<EOF
+test_format committer %cn%n%ce%n%cl%n%cd%n%cD%n%ct <<EOF
 commit $head2
-C O Mitter
-committer@example.com
+$GIT_COMMITTER_NAME
+$GIT_COMMITTER_EMAIL
+$TEST_COMMITTER_LOCALNAME
 Thu Apr 7 15:13:13 2005 -0700
 Thu, 7 Apr 2005 15:13:13 -0700
 1112911993
 commit $head1
-C O Mitter
-committer@example.com
+$GIT_COMMITTER_NAME
+$GIT_COMMITTER_EMAIL
+$TEST_COMMITTER_LOCALNAME
 Thu Apr 7 15:13:13 2005 -0700
 Thu, 7 Apr 2005 15:13:13 -0700
 1112911993
@@ -185,6 +189,10 @@ test_expect_success 'basic colors' '
 	test_cmp expect actual
 '
 
+test_expect_success '%S is not a placeholder for rev-list yet' '
+	git rev-list --format="%S" -1 master | grep "%S"
+'
+
 test_expect_success 'advanced colors' '
 	cat >expect <<-EOF &&
 	commit $head2
@@ -406,7 +414,7 @@ test_expect_success 'empty email' '
 	test_tick &&
 	C=$(GIT_AUTHOR_EMAIL= git commit-tree HEAD^{tree} </dev/null) &&
 	A=$(git show --pretty=format:%an,%ae,%ad%n -s $C) &&
-	verbose test "$A" = "A U Thor,,Thu Apr 7 15:14:13 2005 -0700"
+	verbose test "$A" = "$GIT_AUTHOR_NAME,,Thu Apr 7 15:14:13 2005 -0700"
 '
 
 test_expect_success 'del LF before empty (1)' '
@@ -491,15 +499,14 @@ test_expect_success '%gd shortens ref na
 '
 
 test_expect_success 'reflog identity' '
-	echo "C O Mitter:committer@example.com" >expect &&
+	echo "$GIT_COMMITTER_NAME:$GIT_COMMITTER_EMAIL" >expect &&
 	git log -g -1 --format="%gn:%ge" >actual &&
 	test_cmp expect actual
 '
 
 test_expect_success 'oneline with empty message' '
-	git commit -m "dummy" --allow-empty &&
-	git commit -m "dummy" --allow-empty &&
-	git filter-branch --msg-filter "sed -e s/dummy//" HEAD^^.. &&
+	git commit --allow-empty --cleanup=verbatim -m "$LF" &&
+	git commit --allow-empty --allow-empty-message &&
 	git rev-list --oneline HEAD >test.txt &&
 	test_line_count = 5 test.txt &&
 	git rev-list --oneline --graph HEAD >testg.txt &&
diff -pruN 1.2.1+git2.18.0-1/git/t/t6009-rev-list-parent.sh 1.2.3+git2.25.1-1/git/t/t6009-rev-list-parent.sh
--- 1.2.1+git2.18.0-1/git/t/t6009-rev-list-parent.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t6009-rev-list-parent.sh	2020-02-17 04:47:35.000000000 +0000
@@ -31,8 +31,7 @@ test_expect_success setup '
 test_expect_success 'one is ancestor of others and should not be shown' '
 
 	git rev-list one --not four >result &&
-	>expect &&
-	test_cmp expect result
+	test_must_be_empty result
 
 '
 
@@ -144,8 +143,7 @@ test_expect_success 'ancestors with the
 		test_commit t$i
 	done &&
 	git rev-list t1^! --not t$i >result &&
-	>expect &&
-	test_cmp expect result
+	test_must_be_empty result
 '
 
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t6010-merge-base.sh 1.2.3+git2.25.1-1/git/t/t6010-merge-base.sh
--- 1.2.1+git2.18.0-1/git/t/t6010-merge-base.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t6010-merge-base.sh	2020-02-17 04:47:35.000000000 +0000
@@ -245,7 +245,7 @@ test_expect_success 'using reflog to fin
 			git commit --allow-empty -m "Derived #$count" &&
 			git rev-parse HEAD >derived$count &&
 			git checkout -B base $E || exit 1
-		done
+		done &&
 
 		for count in 1 2 3
 		do
diff -pruN 1.2.1+git2.18.0-1/git/t/t6011-rev-list-with-bad-commit.sh 1.2.3+git2.25.1-1/git/t/t6011-rev-list-with-bad-commit.sh
--- 1.2.1+git2.18.0-1/git/t/t6011-rev-list-with-bad-commit.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t6011-rev-list-with-bad-commit.sh	2020-02-17 04:47:35.000000000 +0000
@@ -41,10 +41,9 @@ test_expect_success 'corrupt second comm
    test_must_fail git fsck --full
    '
 
-test_expect_success 'rev-list should fail' \
-   '
-   test_must_fail git rev-list --all > /dev/null
-   '
+test_expect_success 'rev-list should fail' '
+	test_must_fail env GIT_TEST_COMMIT_GRAPH=0 git -c core.commitGraph=false rev-list --all > /dev/null
+'
 
 test_expect_success 'git repack _MUST_ fail' \
    '
diff -pruN 1.2.1+git2.18.0-1/git/t/t6012-rev-list-simplify.sh 1.2.3+git2.25.1-1/git/t/t6012-rev-list-simplify.sh
--- 1.2.1+git2.18.0-1/git/t/t6012-rev-list-simplify.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t6012-rev-list-simplify.sh	2020-02-17 04:47:35.000000000 +0000
@@ -12,6 +12,22 @@ unnote () {
 	git name-rev --tags --stdin | sed -e "s|$OID_REGEX (tags/\([^)]*\)) |\1 |g"
 }
 
+#
+# Create a test repo with interesting commit graph:
+#
+# A--B----------G--H--I--K--L
+#  \  \           /     /
+#   \  \         /     /
+#    C------E---F     J
+#        \_/
+#
+# The commits are laid out from left-to-right starting with
+# the root commit A and terminating at the tip commit L.
+#
+# There are a few places where we adjust the commit date or
+# author date to make the --topo-order, --date-order, and
+# --author-date-order flags produce different output.
+
 test_expect_success setup '
 	echo "Hi there" >file &&
 	echo "initial" >lost &&
@@ -21,10 +37,18 @@ test_expect_success setup '
 
 	git branch other-branch &&
 
+	git symbolic-ref HEAD refs/heads/unrelated &&
+	git rm -f "*" &&
+	echo "Unrelated branch" >side &&
+	git add side &&
+	test_tick && git commit -m "Side root" &&
+	note J &&
+	git checkout master &&
+
 	echo "Hello" >file &&
 	echo "second" >lost &&
 	git add file lost &&
-	test_tick && git commit -m "Modified file and lost" &&
+	test_tick && GIT_AUTHOR_DATE=$(($test_tick + 120)) git commit -m "Modified file and lost" &&
 	note B &&
 
 	git checkout other-branch &&
@@ -63,13 +87,6 @@ test_expect_success setup '
 	test_tick && git commit -a -m "Final change" &&
 	note I &&
 
-	git symbolic-ref HEAD refs/heads/unrelated &&
-	git rm -f "*" &&
-	echo "Unrelated branch" >side &&
-	git add side &&
-	test_tick && git commit -m "Side root" &&
-	note J &&
-
 	git checkout master &&
 	test_tick && git merge --allow-unrelated-histories -m "Coolest" unrelated &&
 	note K &&
@@ -103,14 +120,24 @@ check_result () {
 	check_outcome success "$@"
 }
 
-check_result 'L K J I H G F E D C B A' --full-history
+check_result 'L K J I H F E D C G B A' --full-history --topo-order
+check_result 'L K I H G F E D C B J A' --full-history
+check_result 'L K I H G F E D C B J A' --full-history --date-order
+check_result 'L K I H G F E D B C J A' --full-history --author-date-order
 check_result 'K I H E C B A' --full-history -- file
 check_result 'K I H E C B A' --full-history --topo-order -- file
 check_result 'K I H E C B A' --full-history --date-order -- file
+check_result 'K I H E B C A' --full-history --author-date-order -- file
 check_result 'I E C B A' --simplify-merges -- file
+check_result 'I E C B A' --simplify-merges --topo-order -- file
+check_result 'I E C B A' --simplify-merges --date-order -- file
+check_result 'I E B C A' --simplify-merges --author-date-order -- file
 check_result 'I B A' -- file
 check_result 'I B A' --topo-order -- file
+check_result 'I B A' --date-order -- file
+check_result 'I B A' --author-date-order -- file
 check_result 'H' --first-parent -- another-file
+check_result 'H' --first-parent --topo-order -- another-file
 
 check_result 'E C B A' --full-history E -- lost
 test_expect_success 'full history simplification without parent' '
diff -pruN 1.2.1+git2.18.0-1/git/t/t6016-rev-list-graph-simplify-history.sh 1.2.3+git2.25.1-1/git/t/t6016-rev-list-graph-simplify-history.sh
--- 1.2.1+git2.18.0-1/git/t/t6016-rev-list-graph-simplify-history.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t6016-rev-list-graph-simplify-history.sh	2020-02-17 04:47:35.000000000 +0000
@@ -67,11 +67,10 @@ test_expect_success '--graph --all' '
 	echo "| * $C4" >> expected &&
 	echo "| * $C3" >> expected &&
 	echo "* | $A5" >> expected &&
-	echo "| |     " >> expected &&
-	echo "|  \\    " >> expected &&
-	echo "*-. \\   $A4" >> expected &&
-	echo "|\\ \\ \\  " >> expected &&
-	echo "| | |/  " >> expected &&
+	echo "| |   " >> expected &&
+	echo "|  \\  " >> expected &&
+	echo "*-. | $A4" >> expected &&
+	echo "|\\ \\| " >> expected &&
 	echo "| | * $C2" >> expected &&
 	echo "| | * $C1" >> expected &&
 	echo "| * | $B2" >> expected &&
@@ -97,11 +96,10 @@ test_expect_success '--graph --simplify-
 	echo "| * $C4" >> expected &&
 	echo "| * $C3" >> expected &&
 	echo "* | $A5" >> expected &&
-	echo "| |     " >> expected &&
-	echo "|  \\    " >> expected &&
-	echo "*-. \\   $A4" >> expected &&
-	echo "|\\ \\ \\  " >> expected &&
-	echo "| | |/  " >> expected &&
+	echo "| |   " >> expected &&
+	echo "|  \\  " >> expected &&
+	echo "*-. | $A4" >> expected &&
+	echo "|\\ \\| " >> expected &&
 	echo "| | * $C2" >> expected &&
 	echo "| | * $C1" >> expected &&
 	echo "| * | $B2" >> expected &&
@@ -131,9 +129,8 @@ test_expect_success '--graph --simplify-
 	echo "| * $C4" >> expected &&
 	echo "| * $C3" >> expected &&
 	echo "* | $A5" >> expected &&
-	echo "* |   $A4" >> expected &&
-	echo "|\\ \\  " >> expected &&
-	echo "| |/  " >> expected &&
+	echo "* | $A4" >> expected &&
+	echo "|\\| " >> expected &&
 	echo "| * $C2" >> expected &&
 	echo "| * $C1" >> expected &&
 	echo "* | $A3" >> expected &&
@@ -151,9 +148,8 @@ test_expect_success '--graph --full-hist
 	echo "|\\  " >> expected &&
 	echo "| * $C4" >> expected &&
 	echo "* | $A5" >> expected &&
-	echo "* |   $A4" >> expected &&
-	echo "|\\ \\  " >> expected &&
-	echo "| |/  " >> expected &&
+	echo "* | $A4" >> expected &&
+	echo "|\\| " >> expected &&
 	echo "* | $A3" >> expected &&
 	echo "|/  " >> expected &&
 	echo "* $A2" >> expected &&
@@ -255,7 +251,7 @@ test_expect_success '--graph --boundary
 	echo "* | | | $A3" >> expected &&
 	echo "o | | | $A2" >> expected &&
 	echo "|/ / /  " >> expected &&
-	echo "o | | $A1" >> expected &&
+	echo "o / / $A1" >> expected &&
 	echo " / /  " >> expected &&
 	echo "| o $C3" >> expected &&
 	echo "|/  " >> expected &&
diff -pruN 1.2.1+git2.18.0-1/git/t/t6018-rev-list-glob.sh 1.2.3+git2.25.1-1/git/t/t6018-rev-list-glob.sh
--- 1.2.1+git2.18.0-1/git/t/t6018-rev-list-glob.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t6018-rev-list-glob.sh	2020-02-17 04:47:35.000000000 +0000
@@ -36,7 +36,13 @@ test_expect_success 'setup' '
 	git tag foo/bar master &&
 	commit master3 &&
 	git update-ref refs/remotes/foo/baz master &&
-	commit master4
+	commit master4 &&
+	git update-ref refs/remotes/upstream/one subspace/one &&
+	git update-ref refs/remotes/upstream/two subspace/two &&
+	git update-ref refs/remotes/upstream/x subspace-x &&
+	git tag qux/one subspace/one &&
+	git tag qux/two subspace/two &&
+	git tag qux/x subspace-x
 '
 
 test_expect_success 'rev-parse --glob=refs/heads/subspace/*' '
@@ -141,6 +147,66 @@ test_expect_success 'rev-parse accumulat
 	compare rev-parse "--exclude=refs/remotes/* --exclude=refs/tags/* --all" --branches
 '
 
+test_expect_success 'rev-parse --branches clears --exclude' '
+	compare rev-parse "--exclude=* --branches --branches" "--branches"
+'
+
+test_expect_success 'rev-parse --tags clears --exclude' '
+	compare rev-parse "--exclude=* --tags --tags" "--tags"
+'
+
+test_expect_success 'rev-parse --all clears --exclude' '
+	compare rev-parse "--exclude=* --all --all" "--all"
+'
+
+test_expect_success 'rev-parse --exclude=glob with --branches=glob' '
+	compare rev-parse "--exclude=subspace-* --branches=sub*" "subspace/one subspace/two"
+'
+
+test_expect_success 'rev-parse --exclude=glob with --tags=glob' '
+	compare rev-parse "--exclude=qux/? --tags=qux/*" "qux/one qux/two"
+'
+
+test_expect_success 'rev-parse --exclude=glob with --remotes=glob' '
+	compare rev-parse "--exclude=upstream/? --remotes=upstream/*" "upstream/one upstream/two"
+'
+
+test_expect_success 'rev-parse --exclude=ref with --branches=glob' '
+	compare rev-parse "--exclude=subspace-x --branches=sub*" "subspace/one subspace/two"
+'
+
+test_expect_success 'rev-parse --exclude=ref with --tags=glob' '
+	compare rev-parse "--exclude=qux/x --tags=qux/*" "qux/one qux/two"
+'
+
+test_expect_success 'rev-parse --exclude=ref with --remotes=glob' '
+	compare rev-parse "--exclude=upstream/x --remotes=upstream/*" "upstream/one upstream/two"
+'
+
+test_expect_success 'rev-list --exclude=glob with --branches=glob' '
+	compare rev-list "--exclude=subspace-* --branches=sub*" "subspace/one subspace/two"
+'
+
+test_expect_success 'rev-list --exclude=glob with --tags=glob' '
+	compare rev-list "--exclude=qux/? --tags=qux/*" "qux/one qux/two"
+'
+
+test_expect_success 'rev-list --exclude=glob with --remotes=glob' '
+	compare rev-list "--exclude=upstream/? --remotes=upstream/*" "upstream/one upstream/two"
+'
+
+test_expect_success 'rev-list --exclude=ref with --branches=glob' '
+	compare rev-list "--exclude=subspace-x --branches=sub*" "subspace/one subspace/two"
+'
+
+test_expect_success 'rev-list --exclude=ref with --tags=glob' '
+	compare rev-list "--exclude=qux/x --tags=qux/*" "qux/one qux/two"
+'
+
+test_expect_success 'rev-list --exclude=ref with --remotes=glob' '
+	compare rev-list "--exclude=upstream/x --remotes=upstream/*" "upstream/one upstream/two"
+'
+
 test_expect_success 'rev-list --glob=refs/heads/subspace/*' '
 
 	compare rev-list "subspace/one subspace/two" "--glob=refs/heads/subspace/*"
@@ -233,7 +299,7 @@ test_expect_success 'rev-list --tags=foo
 
 test_expect_success 'rev-list --tags' '
 
-	compare rev-list "foo/bar" "--tags"
+	compare rev-list "foo/bar qux/x qux/two qux/one" "--tags"
 
 '
 
@@ -255,32 +321,28 @@ test_expect_success 'rev-list accumulate
 	compare rev-list "--exclude=refs/remotes/* --exclude=refs/tags/* --all" --branches
 '
 
-test_expect_failure 'rev-list should succeed with empty output on empty stdin' '
-	>expect &&
-	git rev-list --stdin <expect >actual &&
-	test_cmp expect actual
+test_expect_success 'rev-list should succeed with empty output on empty stdin' '
+	git rev-list --stdin </dev/null >actual &&
+	test_must_be_empty actual
 '
 
 test_expect_success 'rev-list should succeed with empty output with all refs excluded' '
-	>expect &&
 	git rev-list --exclude=* --all >actual &&
-	test_cmp expect actual
+	test_must_be_empty actual
 '
 
 test_expect_success 'rev-list should succeed with empty output with empty --all' '
 	(
 		test_create_repo empty &&
 		cd empty &&
-		>expect &&
 		git rev-list --all >actual &&
-		test_cmp expect actual
+		test_must_be_empty actual
 	)
 '
 
 test_expect_success 'rev-list should succeed with empty output with empty glob' '
-	>expect &&
 	git rev-list --glob=does-not-match-anything >actual &&
-	test_cmp expect actual
+	test_must_be_empty actual
 '
 
 test_expect_success 'shortlog accepts --glob/--tags/--remotes' '
@@ -296,7 +358,7 @@ test_expect_success 'shortlog accepts --
 	  "master other/three someref subspace-x subspace/one subspace/two" \
 	  "--glob=heads/*" &&
 	compare shortlog foo/bar --tags=foo &&
-	compare shortlog foo/bar --tags &&
+	compare shortlog "foo/bar qux/one qux/two qux/x" --tags &&
 	compare shortlog foo/baz --remotes=foo
 
 '
diff -pruN 1.2.1+git2.18.0-1/git/t/t6019-rev-list-ancestry-path.sh 1.2.3+git2.25.1-1/git/t/t6019-rev-list-ancestry-path.sh
--- 1.2.1+git2.18.0-1/git/t/t6019-rev-list-ancestry-path.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t6019-rev-list-ancestry-path.sh	2020-02-17 04:47:35.000000000 +0000
@@ -95,10 +95,9 @@ test_expect_success 'rev-list --ancestry
 
 # G.t is dropped in an "-s ours" merge
 test_expect_success 'rev-list G..M -- G.t' '
-	>expect &&
 	git rev-list --format=%s G..M -- G.t |
 	sed -e "/^commit /d" >actual &&
-	test_cmp expect actual
+	test_must_be_empty actual
 '
 
 test_expect_success 'rev-list --ancestry-path G..M -- G.t' '
@@ -144,14 +143,14 @@ test_expect_success 'setup criss-cross'
 test_expect_success 'criss-cross: rev-list --ancestry-path cb..bc' '
 	(cd criss-cross &&
 	 git rev-list --ancestry-path xcb..xbc > actual &&
-	 test -z "$(cat actual)")
+	 test_must_be_empty actual)
 '
 
 # no commits in repository descend from cb
 test_expect_success 'criss-cross: rev-list --ancestry-path --all ^cb' '
 	(cd criss-cross &&
 	 git rev-list --ancestry-path --all ^xcb > actual &&
-	 test -z "$(cat actual)")
+	 test_must_be_empty actual)
 '
 
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t6020-merge-df.sh 1.2.3+git2.25.1-1/git/t/t6020-merge-df.sh
--- 1.2.1+git2.18.0-1/git/t/t6020-merge-df.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t6020-merge-df.sh	2020-02-17 04:47:35.000000000 +0000
@@ -89,9 +89,6 @@ test_expect_success 'modify/delete + dir
 '
 
 test_expect_success 'modify/delete + directory/file conflict; other way' '
-	# Yes, we really need the double reset since "letters" appears as
-	# both a file and a directory.
-	git reset --hard &&
 	git reset --hard &&
 	git clean -f &&
 	git checkout modify^0 &&
diff -pruN 1.2.1+git2.18.0-1/git/t/t6021-merge-criss-cross.sh 1.2.3+git2.25.1-1/git/t/t6021-merge-criss-cross.sh
--- 1.2.1+git2.18.0-1/git/t/t6021-merge-criss-cross.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t6021-merge-criss-cross.sh	2020-02-17 04:47:35.000000000 +0000
@@ -3,7 +3,7 @@
 # Copyright (c) 2005 Fredrik Kuivinen
 #
 
-# See http://marc.info/?l=git&m=111463358500362&w=2 for a
+# See https://lore.kernel.org/git/Pine.LNX.4.44.0504271254120.4678-100000@wax.eds.org/ for a
 # nice description of what this is about.
 
 
diff -pruN 1.2.1+git2.18.0-1/git/t/t6022-merge-rename.sh 1.2.3+git2.25.1-1/git/t/t6022-merge-rename.sh
--- 1.2.1+git2.18.0-1/git/t/t6022-merge-rename.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t6022-merge-rename.sh	2020-02-17 04:47:35.000000000 +0000
@@ -893,8 +893,7 @@ test_expect_success 'do not follow renam
 	git mv empty1 empty2 &&
 	git commit -m rename &&
 	test_must_fail git merge empty-base &&
-	>expect &&
-	test_cmp expect empty2
+	test_must_be_empty empty2
 '
 
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t6023-merge-file.sh 1.2.3+git2.25.1-1/git/t/t6023-merge-file.sh
--- 1.2.1+git2.18.0-1/git/t/t6023-merge-file.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t6023-merge-file.sh	2020-02-17 04:47:35.000000000 +0000
@@ -99,7 +99,7 @@ EOF
 printf "propter nomen suum." >> expect.txt
 
 test_expect_success "merge does not add LF away of change" \
-	"test_cmp test3.txt expect.txt"
+	"test_cmp expect.txt test3.txt"
 
 cp test.txt backup.txt
 test_expect_success "merge with conflicts" \
@@ -122,7 +122,7 @@ non timebo mala, quoniam tu mecum es:
 virga tua et baculus tuus ipsa me consolata sunt.
 EOF
 
-test_expect_success "expected conflict markers" "test_cmp test.txt expect.txt"
+test_expect_success "expected conflict markers" "test_cmp expect.txt test.txt"
 
 cp backup.txt test.txt
 
@@ -138,7 +138,7 @@ non timebo mala, quoniam tu mecum es:
 virga tua et baculus tuus ipsa me consolata sunt.
 EOF
 test_expect_success "merge conflicting with --ours" \
-	"git merge-file --ours test.txt orig.txt new3.txt && test_cmp test.txt expect.txt"
+	"git merge-file --ours test.txt orig.txt new3.txt && test_cmp expect.txt test.txt"
 cp backup.txt test.txt
 
 cat > expect.txt << EOF
@@ -154,7 +154,7 @@ non timebo mala, quoniam tu mecum es:
 virga tua et baculus tuus ipsa me consolata sunt.
 EOF
 test_expect_success "merge conflicting with --theirs" \
-	"git merge-file --theirs test.txt orig.txt new3.txt && test_cmp test.txt expect.txt"
+	"git merge-file --theirs test.txt orig.txt new3.txt && test_cmp expect.txt test.txt"
 cp backup.txt test.txt
 
 cat > expect.txt << EOF
@@ -171,7 +171,7 @@ non timebo mala, quoniam tu mecum es:
 virga tua et baculus tuus ipsa me consolata sunt.
 EOF
 test_expect_success "merge conflicting with --union" \
-	"git merge-file --union test.txt orig.txt new3.txt && test_cmp test.txt expect.txt"
+	"git merge-file --union test.txt orig.txt new3.txt && test_cmp expect.txt test.txt"
 cp backup.txt test.txt
 
 test_expect_success "merge with conflicts, using -L" \
@@ -195,7 +195,7 @@ virga tua et baculus tuus ipsa me consol
 EOF
 
 test_expect_success "expected conflict markers, with -L" \
-	"test_cmp test.txt expect.txt"
+	"test_cmp expect.txt test.txt"
 
 sed "s/ tu / TU /" < new1.txt > new5.txt
 test_expect_success "conflict in removed tail" \
diff -pruN 1.2.1+git2.18.0-1/git/t/t6024-recursive-merge.sh 1.2.3+git2.25.1-1/git/t/t6024-recursive-merge.sh
--- 1.2.1+git2.18.0-1/git/t/t6024-recursive-merge.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t6024-recursive-merge.sh	2020-02-17 04:47:35.000000000 +0000
@@ -14,85 +14,90 @@ test_description='Test merge without com
 GIT_COMMITTER_DATE="2006-12-12 23:28:00 +0100"
 export GIT_COMMITTER_DATE
 
-test_expect_success "setup tests" '
-echo 1 > a1 &&
-git add a1 &&
-GIT_AUTHOR_DATE="2006-12-12 23:00:00" git commit -m 1 a1 &&
-
-git checkout -b A master &&
-echo A > a1 &&
-GIT_AUTHOR_DATE="2006-12-12 23:00:01" git commit -m A a1 &&
-
-git checkout -b B master &&
-echo B > a1 &&
-GIT_AUTHOR_DATE="2006-12-12 23:00:02" git commit -m B a1 &&
-
-git checkout -b D A &&
-git rev-parse B > .git/MERGE_HEAD &&
-echo D > a1 &&
-git update-index a1 &&
-GIT_AUTHOR_DATE="2006-12-12 23:00:03" git commit -m D &&
-
-git symbolic-ref HEAD refs/heads/other &&
-echo 2 > a1 &&
-GIT_AUTHOR_DATE="2006-12-12 23:00:04" git commit -m 2 a1 &&
-
-git checkout -b C &&
-echo C > a1 &&
-GIT_AUTHOR_DATE="2006-12-12 23:00:05" git commit -m C a1 &&
-
-git checkout -b E C &&
-git rev-parse B > .git/MERGE_HEAD &&
-echo E > a1 &&
-git update-index a1 &&
-GIT_AUTHOR_DATE="2006-12-12 23:00:06" git commit -m E &&
-
-git checkout -b G E &&
-git rev-parse A > .git/MERGE_HEAD &&
-echo G > a1 &&
-git update-index a1 &&
-GIT_AUTHOR_DATE="2006-12-12 23:00:07" git commit -m G &&
-
-git checkout -b F D &&
-git rev-parse C > .git/MERGE_HEAD &&
-echo F > a1 &&
-git update-index a1 &&
-GIT_AUTHOR_DATE="2006-12-12 23:00:08" git commit -m F
-'
-
-test_expect_success "combined merge conflicts" "
-	test_must_fail git merge -m final G
-"
-
-cat > expect << EOF
-<<<<<<< HEAD
-F
-=======
-G
->>>>>>> G
-EOF
-
-test_expect_success "result contains a conflict" "test_cmp expect a1"
-
-git ls-files --stage > out
-cat > expect << EOF
-100644 ec3fe2a791706733f2d8fa7ad45d9a9672031f5e 1	a1
-100644 cf84443e49e1b366fac938711ddf4be2d4d1d9e9 2	a1
-100644 fd7923529855d0b274795ae3349c5e0438333979 3	a1
-EOF
+test_expect_success 'setup tests' '
+	echo 1 >a1 &&
+	git add a1 &&
+	GIT_AUTHOR_DATE="2006-12-12 23:00:00" git commit -m 1 a1 &&
+
+	git checkout -b A master &&
+	echo A >a1 &&
+	GIT_AUTHOR_DATE="2006-12-12 23:00:01" git commit -m A a1 &&
+
+	git checkout -b B master &&
+	echo B >a1 &&
+	GIT_AUTHOR_DATE="2006-12-12 23:00:02" git commit -m B a1 &&
+
+	git checkout -b D A &&
+	git rev-parse B >.git/MERGE_HEAD &&
+	echo D >a1 &&
+	git update-index a1 &&
+	GIT_AUTHOR_DATE="2006-12-12 23:00:03" git commit -m D &&
+
+	git symbolic-ref HEAD refs/heads/other &&
+	echo 2 >a1 &&
+	GIT_AUTHOR_DATE="2006-12-12 23:00:04" git commit -m 2 a1 &&
+
+	git checkout -b C &&
+	echo C >a1 &&
+	GIT_AUTHOR_DATE="2006-12-12 23:00:05" git commit -m C a1 &&
+
+	git checkout -b E C &&
+	git rev-parse B >.git/MERGE_HEAD &&
+	echo E >a1 &&
+	git update-index a1 &&
+	GIT_AUTHOR_DATE="2006-12-12 23:00:06" git commit -m E &&
+
+	git checkout -b G E &&
+	git rev-parse A >.git/MERGE_HEAD &&
+	echo G >a1 &&
+	git update-index a1 &&
+	GIT_AUTHOR_DATE="2006-12-12 23:00:07" git commit -m G &&
+
+	git checkout -b F D &&
+	git rev-parse C >.git/MERGE_HEAD &&
+	echo F >a1 &&
+	git update-index a1 &&
+	GIT_AUTHOR_DATE="2006-12-12 23:00:08" git commit -m F
+'
+
+test_expect_success 'combined merge conflicts' '
+	test_must_fail env GIT_TEST_COMMIT_GRAPH=0 git merge -m final G
+'
+
+test_expect_success 'result contains a conflict' '
+	cat >expect <<-\EOF &&
+	<<<<<<< HEAD
+	F
+	=======
+	G
+	>>>>>>> G
+	EOF
+
+	test_cmp expect a1
+'
+
+test_expect_success 'virtual trees were processed' '
+	git ls-files --stage >out &&
 
-test_expect_success "virtual trees were processed" "test_cmp expect out"
+	cat >expect <<-\EOF &&
+	100644 ec3fe2a791706733f2d8fa7ad45d9a9672031f5e 1	a1
+	100644 cf84443e49e1b366fac938711ddf4be2d4d1d9e9 2	a1
+	100644 fd7923529855d0b274795ae3349c5e0438333979 3	a1
+	EOF
+
+	test_cmp expect out
+'
 
 test_expect_success 'refuse to merge binary files' '
 	git reset --hard &&
-	printf "\0" > binary-file &&
+	printf "\0" >binary-file &&
 	git add binary-file &&
 	git commit -m binary &&
 	git checkout G &&
-	printf "\0\0" > binary-file &&
+	printf "\0\0" >binary-file &&
 	git add binary-file &&
 	git commit -m binary2 &&
-	test_must_fail git merge F > merge.out 2> merge.err &&
+	test_must_fail git merge F >merge.out 2>merge.err &&
 	grep "Cannot merge binary files: binary-file (HEAD vs. F)" merge.err
 '
 
@@ -116,7 +121,6 @@ test_expect_success 'mark rename/delete
 	test 1 = $(git ls-files --unmerged | wc -l) &&
 	test_must_fail git rev-parse --verify :2:a2 &&
 	git rev-parse --verify :3:a2
-
 '
 
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t6027-merge-binary.sh 1.2.3+git2.25.1-1/git/t/t6027-merge-binary.sh
--- 1.2.1+git2.18.0-1/git/t/t6027-merge-binary.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t6027-merge-binary.sh	2020-02-17 04:47:35.000000000 +0000
@@ -45,7 +45,7 @@ test_expect_success resolve '
 		false
 	else
 		git ls-files -s >current
-		test_cmp current expect
+		test_cmp expect current
 	fi
 '
 
@@ -60,7 +60,7 @@ test_expect_success recursive '
 		false
 	else
 		git ls-files -s >current
-		test_cmp current expect
+		test_cmp expect current
 	fi
 '
 
diff -pruN 1.2.1+git2.18.0-1/git/t/t6029-merge-subtree.sh 1.2.3+git2.25.1-1/git/t/t6029-merge-subtree.sh
--- 1.2.1+git2.18.0-1/git/t/t6029-merge-subtree.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t6029-merge-subtree.sh	2020-02-17 04:47:35.000000000 +0000
@@ -29,6 +29,34 @@ test_expect_success 'subtree available a
 
 '
 
+test_expect_success 'setup branch sub' '
+	git checkout --orphan sub &&
+	git rm -rf . &&
+	test_commit foo
+'
+
+test_expect_success 'setup branch main' '
+	git checkout -b main master &&
+	git merge -s ours --no-commit --allow-unrelated-histories sub &&
+	git read-tree --prefix=dir/ -u sub &&
+	git commit -m "initial merge of sub into main" &&
+	test_path_is_file dir/foo.t &&
+	test_path_is_file hello
+'
+
+test_expect_success 'update branch sub' '
+	git checkout sub &&
+	test_commit bar
+'
+
+test_expect_success 'update branch main' '
+	git checkout main &&
+	git merge -s subtree sub -m "second merge of sub into main" &&
+	test_path_is_file dir/bar.t &&
+	test_path_is_file dir/foo.t &&
+	test_path_is_file hello
+'
+
 test_expect_success 'setup' '
 	mkdir git-gui &&
 	cd git-gui &&
@@ -55,7 +83,7 @@ test_expect_success 'initial merge' '
 	git checkout -b work &&
 	git ls-files -s >actual &&
 	(
-		echo "100644 $o1 0	git-gui/git-gui.sh"
+		echo "100644 $o1 0	git-gui/git-gui.sh" &&
 		echo "100644 $o2 0	git.c"
 	) >expected &&
 	test_cmp expected actual
@@ -72,7 +100,7 @@ test_expect_success 'merge update' '
 	git pull -s subtree gui master2 &&
 	git ls-files -s >actual &&
 	(
-		echo "100644 $o3 0	git-gui/git-gui.sh"
+		echo "100644 $o3 0	git-gui/git-gui.sh" &&
 		echo "100644 $o2 0	git.c"
 	) >expected &&
 	test_cmp expected actual
@@ -88,8 +116,8 @@ test_expect_success 'initial ambiguous s
 	git checkout -b work2 &&
 	git ls-files -s >actual &&
 	(
-		echo "100644 $o1 0	git-gui/git-gui.sh"
-		echo "100644 $o1 0	git-gui2/git-gui.sh"
+		echo "100644 $o1 0	git-gui/git-gui.sh" &&
+		echo "100644 $o1 0	git-gui2/git-gui.sh" &&
 		echo "100644 $o2 0	git.c"
 	) >expected &&
 	test_cmp expected actual
@@ -101,8 +129,8 @@ test_expect_success 'merge using explici
 	git pull -Xsubtree=git-gui gui master2 &&
 	git ls-files -s >actual &&
 	(
-		echo "100644 $o3 0	git-gui/git-gui.sh"
-		echo "100644 $o1 0	git-gui2/git-gui.sh"
+		echo "100644 $o3 0	git-gui/git-gui.sh" &&
+		echo "100644 $o1 0	git-gui2/git-gui.sh" &&
 		echo "100644 $o2 0	git.c"
 	) >expected &&
 	test_cmp expected actual
@@ -114,8 +142,8 @@ test_expect_success 'merge2 using explic
 	git pull -Xsubtree=git-gui2 gui master2 &&
 	git ls-files -s >actual &&
 	(
-		echo "100644 $o1 0	git-gui/git-gui.sh"
-		echo "100644 $o3 0	git-gui2/git-gui.sh"
+		echo "100644 $o1 0	git-gui/git-gui.sh" &&
+		echo "100644 $o3 0	git-gui2/git-gui.sh" &&
 		echo "100644 $o2 0	git.c"
 	) >expected &&
 	test_cmp expected actual
diff -pruN 1.2.1+git2.18.0-1/git/t/t6030-bisect-porcelain.sh 1.2.3+git2.25.1-1/git/t/t6030-bisect-porcelain.sh
--- 1.2.1+git2.18.0-1/git/t/t6030-bisect-porcelain.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t6030-bisect-porcelain.sh	2020-02-17 04:47:35.000000000 +0000
@@ -482,7 +482,7 @@ test_expect_success 'optimized merge bas
 	git bisect good > my_bisect_log2.txt &&
 	test -f ".git/BISECT_ANCESTORS_OK" &&
 	test "$HASH6" = $(git rev-parse --verify HEAD) &&
-	git bisect bad > my_bisect_log3.txt &&
+	git bisect bad &&
 	git bisect good "$A_HASH" > my_bisect_log4.txt &&
 	test_i18ngrep "merge base must be tested" my_bisect_log4.txt &&
 	test_must_fail test -f ".git/BISECT_ANCESTORS_OK"
@@ -615,6 +615,7 @@ test_expect_success 'broken branch creat
 	git add missing/MISSING &&
 	git commit -m "6(broken): Added file that will be deleted" &&
 	git tag BROKEN_HASH6 &&
+	deleted=$(git rev-parse --verify HEAD:missing) &&
 	add_line_into_file "7(broken): second line on a broken branch" hello2 &&
 	git tag BROKEN_HASH7 &&
 	add_line_into_file "8(broken): third line on a broken branch" hello2 &&
@@ -622,12 +623,12 @@ test_expect_success 'broken branch creat
 	git rm missing/MISSING &&
 	git commit -m "9(broken): Remove missing file" &&
 	git tag BROKEN_HASH9 &&
-	rm .git/objects/39/f7e61a724187ab767d2e08442d9b6b9dab587d
+	rm .git/objects/$(test_oid_to_path $deleted)
 '
 
 echo "" > expected.ok
 cat > expected.missing-tree.default <<EOF
-fatal: unable to read tree 39f7e61a724187ab767d2e08442d9b6b9dab587d
+fatal: unable to read tree $deleted
 EOF
 
 test_expect_success 'bisect fails if tree is broken on start commit' '
@@ -681,7 +682,7 @@ test_expect_success 'bisect: --no-checko
 	check_same BROKEN_HASH6 BISECT_HEAD &&
 	git bisect bad BISECT_HEAD &&
 	check_same BROKEN_HASH5 BISECT_HEAD &&
-	git bisect good BISECT_HEAD &&
+	test_must_fail git bisect good BISECT_HEAD &&
 	check_same BROKEN_HASH6 bisect/bad &&
 	git bisect reset
 '
@@ -692,7 +693,7 @@ test_expect_success 'bisect: --no-checko
 	check_same BROKEN_HASH6 BISECT_HEAD &&
 	git bisect good BISECT_HEAD &&
 	check_same BROKEN_HASH8 BISECT_HEAD &&
-	git bisect good BISECT_HEAD &&
+	test_must_fail git bisect good BISECT_HEAD &&
 	check_same BROKEN_HASH9 bisect/bad &&
 	git bisect reset
 '
@@ -701,7 +702,7 @@ test_expect_success 'bisect: demonstrate
 	git bisect reset &&
 	git checkout broken &&
 	git bisect start broken master --no-checkout &&
-	git bisect run \"\$SHELL_PATH\" -c '
+	test_must_fail git bisect run \"\$SHELL_PATH\" -c '
 		GOOD=\$(git for-each-ref \"--format=%(objectname)\" refs/bisect/good-*) &&
 		git rev-list --objects BISECT_HEAD --not \$GOOD >tmp.\$\$ &&
 		git pack-objects --stdout >/dev/null < tmp.\$\$
@@ -713,12 +714,12 @@ test_expect_success 'bisect: demonstrate
 "
 
 cat > expected.bisect-log <<EOF
-# bad: [32a594a3fdac2d57cf6d02987e30eec68511498c] Add <4: Ciao for now> into <hello>.
-# good: [7b7f204a749c3125d5224ed61ea2ae1187ad046f] Add <2: A new day for git> into <hello>.
-git bisect start '32a594a3fdac2d57cf6d02987e30eec68511498c' '7b7f204a749c3125d5224ed61ea2ae1187ad046f'
-# good: [3de952f2416b6084f557ec417709eac740c6818c] Add <3: Another new day for git> into <hello>.
-git bisect good 3de952f2416b6084f557ec417709eac740c6818c
-# first bad commit: [32a594a3fdac2d57cf6d02987e30eec68511498c] Add <4: Ciao for now> into <hello>.
+# bad: [$HASH4] Add <4: Ciao for now> into <hello>.
+# good: [$HASH2] Add <2: A new day for git> into <hello>.
+git bisect start '$HASH4' '$HASH2'
+# good: [$HASH3] Add <3: Another new day for git> into <hello>.
+git bisect good $HASH3
+# first bad commit: [$HASH4] Add <4: Ciao for now> into <hello>.
 EOF
 
 test_expect_success 'bisect log: successful result' '
@@ -731,14 +732,14 @@ test_expect_success 'bisect log: success
 '
 
 cat > expected.bisect-skip-log <<EOF
-# bad: [32a594a3fdac2d57cf6d02987e30eec68511498c] Add <4: Ciao for now> into <hello>.
-# good: [7b7f204a749c3125d5224ed61ea2ae1187ad046f] Add <2: A new day for git> into <hello>.
-git bisect start '32a594a3fdac2d57cf6d02987e30eec68511498c' '7b7f204a749c3125d5224ed61ea2ae1187ad046f'
-# skip: [3de952f2416b6084f557ec417709eac740c6818c] Add <3: Another new day for git> into <hello>.
-git bisect skip 3de952f2416b6084f557ec417709eac740c6818c
+# bad: [$HASH4] Add <4: Ciao for now> into <hello>.
+# good: [$HASH2] Add <2: A new day for git> into <hello>.
+git bisect start '$HASH4' '$HASH2'
+# skip: [$HASH3] Add <3: Another new day for git> into <hello>.
+git bisect skip $HASH3
 # only skipped commits left to test
-# possible first bad commit: [32a594a3fdac2d57cf6d02987e30eec68511498c] Add <4: Ciao for now> into <hello>.
-# possible first bad commit: [3de952f2416b6084f557ec417709eac740c6818c] Add <3: Another new day for git> into <hello>.
+# possible first bad commit: [$HASH4] Add <4: Ciao for now> into <hello>.
+# possible first bad commit: [$HASH3] Add <3: Another new day for git> into <hello>.
 EOF
 
 test_expect_success 'bisect log: only skip commits left' '
@@ -802,7 +803,7 @@ test_expect_success 'bisect terms needs
 	test_must_fail git bisect terms only-one &&
 	test_must_fail git bisect terms 1 2 &&
 	test_must_fail git bisect terms 2>actual &&
-	echo "no terms defined" >expected &&
+	echo "error: no terms defined" >expected &&
 	test_i18ncmp expected actual
 '
 
diff -pruN 1.2.1+git2.18.0-1/git/t/t6031-merge-filemode.sh 1.2.3+git2.25.1-1/git/t/t6031-merge-filemode.sh
--- 1.2.1+git2.18.0-1/git/t/t6031-merge-filemode.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t6031-merge-filemode.sh	2020-02-17 04:47:35.000000000 +0000
@@ -61,7 +61,7 @@ do_both_modes () {
 		git checkout -f a2 &&
 		test_must_fail git merge -s $strategy b2 &&
 		git ls-files -u >actual &&
-		test_cmp actual expect &&
+		test_cmp expect actual &&
 		git ls-files -s file2 | grep ^100755
 	'
 
diff -pruN 1.2.1+git2.18.0-1/git/t/t6036-recursive-corner-cases.sh 1.2.3+git2.25.1-1/git/t/t6036-recursive-corner-cases.sh
--- 1.2.1+git2.18.0-1/git/t/t6036-recursive-corner-cases.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t6036-recursive-corner-cases.sh	2020-02-17 04:47:35.000000000 +0000
@@ -4,12 +4,6 @@ test_description='recursive merge corner
 
 . ./test-lib.sh
 
-get_clean_checkout () {
-	git reset --hard &&
-	git clean -fdqx &&
-	git checkout "$1"
-}
-
 #
 #  L1  L2
 #   o---o
@@ -21,51 +15,63 @@ get_clean_checkout () {
 #
 
 test_expect_success 'setup basic criss-cross + rename with no modifications' '
-	ten="0 1 2 3 4 5 6 7 8 9" &&
-	for i in $ten
-	do
-		echo line $i in a sample file
-	done >one &&
-	for i in $ten
-	do
-		echo line $i in another sample file
-	done >two &&
-	git add one two &&
-	test_tick && git commit -m initial &&
-
-	git branch L1 &&
-	git checkout -b R1 &&
-	git mv one three &&
-	test_tick && git commit -m R1 &&
-
-	git checkout L1 &&
-	git mv two three &&
-	test_tick && git commit -m L1 &&
-
-	git checkout L1^0 &&
-	test_tick && git merge -s ours R1 &&
-	git tag L2 &&
-
-	git checkout R1^0 &&
-	test_tick && git merge -s ours L1 &&
-	git tag R2
+	test_create_repo basic-rename &&
+	(
+		cd basic-rename &&
+
+		ten="0 1 2 3 4 5 6 7 8 9" &&
+		for i in $ten
+		do
+			echo line $i in a sample file
+		done >one &&
+		for i in $ten
+		do
+			echo line $i in another sample file
+		done >two &&
+		git add one two &&
+		test_tick && git commit -m initial &&
+
+		git branch L1 &&
+		git checkout -b R1 &&
+		git mv one three &&
+		test_tick && git commit -m R1 &&
+
+		git checkout L1 &&
+		git mv two three &&
+		test_tick && git commit -m L1 &&
+
+		git checkout L1^0 &&
+		test_tick && git merge -s ours R1 &&
+		git tag L2 &&
+
+		git checkout R1^0 &&
+		test_tick && git merge -s ours L1 &&
+		git tag R2
+	)
 '
 
 test_expect_success 'merge simple rename+criss-cross with no modifications' '
-	git reset --hard &&
-	git checkout L2^0 &&
-
-	test_must_fail git merge -s recursive R2^0 &&
+	(
+		cd basic-rename &&
 
-	test 2 = $(git ls-files -s | wc -l) &&
-	test 2 = $(git ls-files -u | wc -l) &&
-	test 2 = $(git ls-files -o | wc -l) &&
+		git reset --hard &&
+		git checkout L2^0 &&
 
-	test $(git rev-parse :2:three) = $(git rev-parse L2:three) &&
-	test $(git rev-parse :3:three) = $(git rev-parse R2:three) &&
+		test_must_fail git merge -s recursive R2^0 &&
 
-	test $(git rev-parse L2:three) = $(git hash-object three~HEAD) &&
-	test $(git rev-parse R2:three) = $(git hash-object three~R2^0)
+		git ls-files -s >out &&
+		test_line_count = 2 out &&
+		git ls-files -u >out &&
+		test_line_count = 2 out &&
+		git ls-files -o >out &&
+		test_line_count = 1 out &&
+
+		git rev-parse >expect       \
+			L2:three   R2:three &&
+		git rev-parse   >actual     \
+			:2:three   :3:three &&
+		test_cmp expect actual
+	)
 '
 
 #
@@ -81,58 +87,64 @@ test_expect_success 'merge simple rename
 #
 
 test_expect_success 'setup criss-cross + rename merges with basic modification' '
-	git rm -rf . &&
-	git clean -fdqx &&
-	rm -rf .git &&
-	git init &&
-
-	ten="0 1 2 3 4 5 6 7 8 9" &&
-	for i in $ten
-	do
-		echo line $i in a sample file
-	done >one &&
-	for i in $ten
-	do
-		echo line $i in another sample file
-	done >two &&
-	git add one two &&
-	test_tick && git commit -m initial &&
-
-	git branch L1 &&
-	git checkout -b R1 &&
-	git mv one three &&
-	echo more >>two &&
-	git add two &&
-	test_tick && git commit -m R1 &&
-
-	git checkout L1 &&
-	git mv two three &&
-	test_tick && git commit -m L1 &&
-
-	git checkout L1^0 &&
-	test_tick && git merge -s ours R1 &&
-	git tag L2 &&
-
-	git checkout R1^0 &&
-	test_tick && git merge -s ours L1 &&
-	git tag R2
+	test_create_repo rename-modify &&
+	(
+		cd rename-modify &&
+
+		ten="0 1 2 3 4 5 6 7 8 9" &&
+		for i in $ten
+		do
+			echo line $i in a sample file
+		done >one &&
+		for i in $ten
+		do
+			echo line $i in another sample file
+		done >two &&
+		git add one two &&
+		test_tick && git commit -m initial &&
+
+		git branch L1 &&
+		git checkout -b R1 &&
+		git mv one three &&
+		echo more >>two &&
+		git add two &&
+		test_tick && git commit -m R1 &&
+
+		git checkout L1 &&
+		git mv two three &&
+		test_tick && git commit -m L1 &&
+
+		git checkout L1^0 &&
+		test_tick && git merge -s ours R1 &&
+		git tag L2 &&
+
+		git checkout R1^0 &&
+		test_tick && git merge -s ours L1 &&
+		git tag R2
+	)
 '
 
 test_expect_success 'merge criss-cross + rename merges with basic modification' '
-	git reset --hard &&
-	git checkout L2^0 &&
+	(
+		cd rename-modify &&
 
-	test_must_fail git merge -s recursive R2^0 &&
+		git checkout L2^0 &&
 
-	test 2 = $(git ls-files -s | wc -l) &&
-	test 2 = $(git ls-files -u | wc -l) &&
-	test 2 = $(git ls-files -o | wc -l) &&
+		test_must_fail git merge -s recursive R2^0 &&
 
-	test $(git rev-parse :2:three) = $(git rev-parse L2:three) &&
-	test $(git rev-parse :3:three) = $(git rev-parse R2:three) &&
-
-	test $(git rev-parse L2:three) = $(git hash-object three~HEAD) &&
-	test $(git rev-parse R2:three) = $(git hash-object three~R2^0)
+		git ls-files -s >out &&
+		test_line_count = 2 out &&
+		git ls-files -u >out &&
+		test_line_count = 2 out &&
+		git ls-files -o >out &&
+		test_line_count = 1 out &&
+
+		git rev-parse >expect       \
+			L2:three   R2:three &&
+		git rev-parse   >actual     \
+			:2:three   :3:three &&
+		test_cmp expect actual
+	)
 '
 
 #
@@ -156,64 +168,127 @@ test_expect_success 'merge criss-cross +
 #
 
 test_expect_success 'setup differently handled merges of rename/add conflict' '
-	git rm -rf . &&
-	git clean -fdqx &&
-	rm -rf .git &&
-	git init &&
-
-	printf "0\n1\n2\n3\n4\n5\n6\n7\n8\n9\n" >a &&
-	git add a &&
-	test_tick && git commit -m A &&
-
-	git branch B &&
-	git checkout -b C &&
-	echo 10 >>a &&
-	echo "other content" >>new_a &&
-	git add a new_a &&
-	test_tick && git commit -m C &&
-
-	git checkout B &&
-	git mv a new_a &&
-	test_tick && git commit -m B &&
-
-	git checkout B^0 &&
-	test_must_fail git merge C &&
-	git clean -f &&
-	test_tick && git commit -m D &&
-	git tag D &&
-
-	git checkout C^0 &&
-	test_must_fail git merge B &&
-	rm new_a~HEAD new_a &&
-	printf "Incorrectly merged content" >>new_a &&
-	git add -u &&
-	test_tick && git commit -m E &&
-	git tag E
+	test_create_repo rename-add &&
+	(
+		cd rename-add &&
+
+		printf "0\n1\n2\n3\n4\n5\n6\n7\n8\n9\n" >a &&
+		git add a &&
+		test_tick && git commit -m A &&
+
+		git branch B &&
+		git checkout -b C &&
+		echo 10 >>a &&
+		test_write_lines 0 1 2 3 4 5 6 7 foobar >new_a &&
+		git add a new_a &&
+		test_tick && git commit -m C &&
+
+		git checkout B &&
+		git mv a new_a &&
+		test_tick && git commit -m B &&
+
+		git checkout B^0 &&
+		test_must_fail git merge C &&
+		git show :2:new_a >new_a &&
+		git add new_a &&
+		test_tick && git commit -m D &&
+		git tag D &&
+
+		git checkout C^0 &&
+		test_must_fail git merge B &&
+		test_write_lines 0 1 2 3 4 5 6 7 bad_merge >new_a &&
+		git add -u &&
+		test_tick && git commit -m E &&
+		git tag E
+	)
 '
 
 test_expect_success 'git detects differently handled merges conflict' '
-	git reset --hard &&
-	git checkout D^0 &&
+	(
+		cd rename-add &&
+
+		git checkout D^0 &&
 
-	test_must_fail git merge -s recursive E^0 &&
+		test_must_fail git merge -s recursive E^0 &&
 
-	test 3 = $(git ls-files -s | wc -l) &&
-	test 3 = $(git ls-files -u | wc -l) &&
-	test 0 = $(git ls-files -o | wc -l) &&
-
-	test $(git rev-parse :2:new_a) = $(git rev-parse D:new_a) &&
-	test $(git rev-parse :3:new_a) = $(git rev-parse E:new_a) &&
-
-	git cat-file -p B:new_a >>merged &&
-	git cat-file -p C:new_a >>merge-me &&
-	>empty &&
-	test_must_fail git merge-file \
-		-L "Temporary merge branch 2" \
-		-L "" \
-		-L "Temporary merge branch 1" \
-		merged empty merge-me &&
-	sed -e "s/^\([<=>]\)/\1\1\1/" merged >merged-internal &&
-	test $(git rev-parse :1:new_a) = $(git hash-object merged-internal)
+		git ls-files -s >out &&
+		test_line_count = 3 out &&
+		git ls-files -u >out &&
+		test_line_count = 3 out &&
+		git ls-files -o >out &&
+		test_line_count = 1 out &&
+
+		git rev-parse >expect       \
+			C:new_a  D:new_a  E:new_a &&
+		git rev-parse   >actual     \
+			:1:new_a :2:new_a :3:new_a &&
+		test_cmp expect actual &&
+
+		# Test that the two-way merge in new_a is as expected
+		git cat-file -p D:new_a >ours &&
+		git cat-file -p E:new_a >theirs &&
+		>empty &&
+		test_must_fail git merge-file \
+			-L "HEAD" \
+			-L "" \
+			-L "E^0" \
+			ours empty theirs &&
+		sed -e "s/^\([<=>]\)/\1\1\1/" ours >expect &&
+		git hash-object new_a >actual &&
+		git hash-object ours  >expect &&
+		test_cmp expect actual
+	)
+'
+
+# Repeat the above testcase with precisely the same setup, other than with
+# the two merge bases having different orderings of commit timestamps so
+# that they are reversed in the order they are provided to merge-recursive,
+# so that we can improve code coverage.
+test_expect_success 'git detects differently handled merges conflict, swapped' '
+	(
+		cd rename-add &&
+
+		# Difference #1: Do cleanup from previous testrun
+		git reset --hard &&
+		git clean -fdqx &&
+
+		# Difference #2: Change commit timestamps
+		btime=$(git log --no-walk --date=raw --format=%cd B | awk "{print \$1}") &&
+		ctime=$(git log --no-walk --date=raw --format=%cd C | awk "{print \$1}") &&
+		newctime=$(($btime+1)) &&
+		git fast-export --no-data --all | sed -e s/$ctime/$newctime/ | git fast-import --force --quiet &&
+		# End of differences; rest is copy-paste of last test
+
+		git checkout D^0 &&
+		test_must_fail git merge -s recursive E^0 &&
+
+		git ls-files -s >out &&
+		test_line_count = 3 out &&
+		git ls-files -u >out &&
+		test_line_count = 3 out &&
+		git ls-files -o >out &&
+		test_line_count = 1 out &&
+
+		git rev-parse >expect       \
+			C:new_a  D:new_a  E:new_a &&
+		git rev-parse   >actual     \
+			:1:new_a :2:new_a :3:new_a &&
+		test_cmp expect actual &&
+
+		# Test that the two-way merge in new_a is as expected
+		git cat-file -p D:new_a >ours &&
+		git cat-file -p E:new_a >theirs &&
+		>empty &&
+		test_must_fail git merge-file \
+			-L "HEAD" \
+			-L "" \
+			-L "E^0" \
+			ours empty theirs &&
+		sed -e "s/^\([<=>]\)/\1\1\1/" ours >expect &&
+		git hash-object new_a >actual &&
+		git hash-object ours  >expect &&
+		test_cmp expect actual
+	)
 '
 
 #
@@ -236,220 +311,428 @@ test_expect_success 'git detects differe
 # Merging commits D & E should result in modify/delete conflict.
 
 test_expect_success 'setup criss-cross + modify/delete resolved differently' '
-	git rm -rf . &&
-	git clean -fdqx &&
-	rm -rf .git &&
-	git init &&
-
-	echo A >file &&
-	git add file &&
-	test_tick &&
-	git commit -m A &&
-
-	git branch B &&
-	git checkout -b C &&
-	git rm file &&
-	test_tick &&
-	git commit -m C &&
-
-	git checkout B &&
-	echo B >file &&
-	git add file &&
-	test_tick &&
-	git commit -m B &&
-
-	git checkout B^0 &&
-	test_must_fail git merge C &&
-	echo B >file &&
-	git add file &&
-	test_tick &&
-	git commit -m D &&
-	git tag D &&
-
-	git checkout C^0 &&
-	test_must_fail git merge B &&
-	git rm file &&
-	test_tick &&
-	git commit -m E &&
-	git tag E
+	test_create_repo modify-delete &&
+	(
+		cd modify-delete &&
+
+		echo A >file &&
+		git add file &&
+		test_tick &&
+		git commit -m A &&
+
+		git branch B &&
+		git checkout -b C &&
+		git rm file &&
+		test_tick &&
+		git commit -m C &&
+
+		git checkout B &&
+		echo B >file &&
+		git add file &&
+		test_tick &&
+		git commit -m B &&
+
+		git checkout B^0 &&
+		test_must_fail git merge C &&
+		echo B >file &&
+		git add file &&
+		test_tick &&
+		git commit -m D &&
+		git tag D &&
+
+		git checkout C^0 &&
+		test_must_fail git merge B &&
+		git rm file &&
+		test_tick &&
+		git commit -m E &&
+		git tag E
+	)
 '
 
 test_expect_success 'git detects conflict merging criss-cross+modify/delete' '
-	git checkout D^0 &&
+	(
+		cd modify-delete &&
 
-	test_must_fail git merge -s recursive E^0 &&
+		git checkout D^0 &&
 
-	test 2 -eq $(git ls-files -s | wc -l) &&
-	test 2 -eq $(git ls-files -u | wc -l) &&
+		test_must_fail git merge -s recursive E^0 &&
 
-	test $(git rev-parse :1:file) = $(git rev-parse master:file) &&
-	test $(git rev-parse :2:file) = $(git rev-parse B:file)
+		git ls-files -s >out &&
+		test_line_count = 2 out &&
+		git ls-files -u >out &&
+		test_line_count = 2 out &&
+
+		git rev-parse >expect       \
+			master:file  B:file &&
+		git rev-parse   >actual      \
+			:1:file      :2:file &&
+		test_cmp expect actual
+	)
 '
 
 test_expect_success 'git detects conflict merging criss-cross+modify/delete, reverse direction' '
-	git reset --hard &&
-	git checkout E^0 &&
+	(
+		cd modify-delete &&
 
-	test_must_fail git merge -s recursive D^0 &&
+		git reset --hard &&
+		git checkout E^0 &&
 
-	test 2 -eq $(git ls-files -s | wc -l) &&
-	test 2 -eq $(git ls-files -u | wc -l) &&
+		test_must_fail git merge -s recursive D^0 &&
 
-	test $(git rev-parse :1:file) = $(git rev-parse master:file) &&
-	test $(git rev-parse :3:file) = $(git rev-parse B:file)
+		git ls-files -s >out &&
+		test_line_count = 2 out &&
+		git ls-files -u >out &&
+		test_line_count = 2 out &&
+
+		git rev-parse >expect       \
+			master:file  B:file &&
+		git rev-parse   >actual      \
+			:1:file      :3:file &&
+		test_cmp expect actual
+	)
 '
 
+#      SORRY FOR THE SUPER LONG DESCRIPTION, BUT THIS NEXT ONE IS HAIRY
 #
 # criss-cross + d/f conflict via add/add:
 #   Commit A: Neither file 'a' nor directory 'a/' exists.
 #   Commit B: Introduce 'a'
 #   Commit C: Introduce 'a/file'
-#   Commit D: Merge B & C, keeping 'a' and deleting 'a/'
-#
-# Two different later cases:
+#   Commit D1: Merge B & C, keeping 'a'    and deleting 'a/'
 #   Commit E1: Merge B & C, deleting 'a' but keeping 'a/file'
-#   Commit E2: Merge B & C, deleting 'a' but keeping a slightly modified 'a/file'
 #
-#      B   D
+#      B   D1 or D2
 #      o---o
 #     / \ / \
 #  A o   X   ? F
 #     \ / \ /
 #      o---o
-#      C   E1 or E2
+#      C   E1 or E2 or E3
 #
-# Merging D & E1 requires we first create a virtual merge base X from
-# merging A & B in memory.  Now, if X could keep both 'a' and 'a/file' in
-# the index, then the merge of D & E1 could be resolved cleanly with both
-# 'a' and 'a/file' removed.  Since git does not currently allow creating
-# such a tree, the best we can do is have X contain both 'a~<unique>' and
-# 'a/file' resulting in the merge of D and E1 having a rename/delete
-# conflict for 'a'.  (Although this merge appears to be unsolvable with git
-# currently, git could do a lot better than it currently does with these
-# d/f conflicts, which is the purpose of this test.)
+# I'll describe D2, E2, & E3 (which are alternatives for D1 & E1) more below...
 #
-# Merge of D & E2 has similar issues for path 'a', but should always result
-# in a modify/delete conflict for path 'a/file'.
-#
-# We run each merge in both directions, to check for directional issues
-# with D/F conflict handling.
+# Merging D1 & E1 requires we first create a virtual merge base X from
+# merging A & B in memory.  There are several possibilities for the merge-base:
+#   1: Keep both 'a' and 'a/file' (assuming crazy filesystem allowing a tree
+#      with a directory and file at same path): results in merge of D1 & E1
+#      being clean with both files deleted.  Bad (no conflict detected).
+#   2: Keep 'a' but not 'a/file': Merging D1 & E1 is clean and matches E1.  Bad.
+#   3: Keep 'a/file' but not 'a': Merging D1 & E1 is clean and matches D1.  Bad.
+#   4: Keep neither file: Merging D1 & E1 reports the D/F add/add conflict.
+#
+# So 4 sounds good for this case, but if we were to merge D1 & E3, where E3
+# is defined as:
+#   Commit E3: Merge B & C, keeping modified a, and deleting a/
+# then we'd get an add/add conflict for 'a', which seems suboptimal.  A little
+# creativity leads us to an alternate choice:
+#   5: Keep 'a' as 'a~$UNIQUE' and a/file; results:
+#        Merge D1 & E1: rename/delete conflict for 'a'; a/file silently deleted
+#        Merge D1 & E3 is clean, as expected.
+#
+# So choice 5 at least provides some kind of conflict for the original case,
+# and can merge cleanly as expected with D1 and E3.  It also made things just
+# slightly funny for merging D1 and e$, where E4 is defined as:
+#   Commit E4: Merge B & C, modifying 'a' and renaming to 'a2', and deleting 'a/'
+# in this case, we'll get a rename/rename(1to2) conflict because a~$UNIQUE
+# gets renamed to 'a' in D1 and to 'a2' in E4.  But that's better than having
+# two files (both 'a' and 'a2') sitting around without the user being notified
+# that we could detect they were related and need to be merged.  Also, choice
+# 5 makes the handling of 'a/file' seem suboptimal.  What if we were to merge
+# D2 and E4, where D2 is:
+#   Commit D2: Merge B & C, renaming 'a'->'a2', keeping 'a/file'
+# This would result in a clean merge with 'a2' having three-way merged
+# contents (good), and deleting 'a/' (bad) -- it doesn't detect the
+# conflict in how the different sides treated a/file differently.
+# Continuing down the creative route:
+#   6: Keep 'a' as 'a~$UNIQUE1' and keep 'a/' as 'a~$UNIQUE2/'; results:
+#        Merge D1 & E1: rename/delete conflict for 'a' and each path under 'a/'.
+#        Merge D1 & E3: clean, as expected.
+#        Merge D1 & E4: rename/rename(1to2) conflict on 'a' vs 'a2'.
+#        Merge D2 & E4: clean for 'a2', rename/delete for a/file
+#
+# Choice 6 could cause rename detection to take longer (providing more targets
+# that need to be searched).  Also, the conflict message for each path under
+# 'a/' might be annoying unless we can detect it at the directory level, print
+# it once, and then suppress it for individual filepaths underneath.
+#
+#
+# As of time of writing, git uses choice 5.  Directory rename detection and
+# rename detection performance improvements might make choice 6 a desirable
+# improvement.  But we can at least document where we fall short for now...
+#
+#
+# Historically, this testcase also used:
+#   Commit E2: Merge B & C, deleting 'a' but keeping slightly modified 'a/file'
+# The merge of D1 & E2 is very similar to D1 & E1 -- it has similar issues for
+# path 'a', but should always result in a modify/delete conflict for path
+# 'a/file'.  These tests ran the two merges
+#   D1 & E1
+#   D1 & E2
+# in both directions, to check for directional issues with D/F conflict
+# handling. Later we added
+#   D1 & E3
+#   D1 & E4
+#   D2 & E4
+# for good measure, though we only ran those one way because we had pretty
+# good confidence in merge-recursive's directional handling of D/F issues.
+#
+# Just to summarize all the intermediate merge commits:
+#   Commit D1: Merge B & C, keeping a    and deleting a/
+#   Commit D2: Merge B & C, renaming a->a2, keeping a/file
+#   Commit E1: Merge B & C, deleting a but keeping a/file
+#   Commit E2: Merge B & C, deleting a but keeping slightly modified a/file
+#   Commit E3: Merge B & C, keeping modified a, and deleting a/
+#   Commit E4: Merge B & C, modifying 'a' and renaming to 'a2', and deleting 'a/'
 #
 
 test_expect_success 'setup differently handled merges of directory/file conflict' '
-	git rm -rf . &&
-	git clean -fdqx &&
-	rm -rf .git &&
-	git init &&
-
-	>ignore-me &&
-	git add ignore-me &&
-	test_tick &&
-	git commit -m A &&
-	git tag A &&
-
-	git branch B &&
-	git checkout -b C &&
-	mkdir a &&
-	echo 10 >a/file &&
-	git add a/file &&
-	test_tick &&
-	git commit -m C &&
-
-	git checkout B &&
-	echo 5 >a &&
-	git add a &&
-	test_tick &&
-	git commit -m B &&
-
-	git checkout B^0 &&
-	test_must_fail git merge C &&
-	git clean -f &&
-	rm -rf a/ &&
-	echo 5 >a &&
-	git add a &&
-	test_tick &&
-	git commit -m D &&
-	git tag D &&
-
-	git checkout C^0 &&
-	test_must_fail git merge B &&
-	git clean -f &&
-	git rm --cached a &&
-	echo 10 >a/file &&
-	git add a/file &&
-	test_tick &&
-	git commit -m E1 &&
-	git tag E1 &&
-
-	git checkout C^0 &&
-	test_must_fail git merge B &&
-	git clean -f &&
-	git rm --cached a &&
-	printf "10\n11\n" >a/file &&
-	git add a/file &&
-	test_tick &&
-	git commit -m E2 &&
-	git tag E2
-'
-
-test_expect_success 'merge of D & E1 fails but has appropriate contents' '
-	get_clean_checkout D^0 &&
-
-	test_must_fail git merge -s recursive E1^0 &&
-
-	test 2 -eq $(git ls-files -s | wc -l) &&
-	test 1 -eq $(git ls-files -u | wc -l) &&
-	test 0 -eq $(git ls-files -o | wc -l) &&
-
-	test $(git rev-parse :0:ignore-me) = $(git rev-parse A:ignore-me) &&
-	test $(git rev-parse :2:a) = $(git rev-parse B:a)
-'
-
-test_expect_success 'merge of E1 & D fails but has appropriate contents' '
-	get_clean_checkout E1^0 &&
-
-	test_must_fail git merge -s recursive D^0 &&
-
-	test 2 -eq $(git ls-files -s | wc -l) &&
-	test 1 -eq $(git ls-files -u | wc -l) &&
-	test 0 -eq $(git ls-files -o | wc -l) &&
-
-	test $(git rev-parse :0:ignore-me) = $(git rev-parse A:ignore-me) &&
-	test $(git rev-parse :3:a) = $(git rev-parse B:a)
-'
-
-test_expect_success 'merge of D & E2 fails but has appropriate contents' '
-	get_clean_checkout D^0 &&
-
-	test_must_fail git merge -s recursive E2^0 &&
-
-	test 4 -eq $(git ls-files -s | wc -l) &&
-	test 3 -eq $(git ls-files -u | wc -l) &&
-	test 1 -eq $(git ls-files -o | wc -l) &&
-
-	test $(git rev-parse :2:a) = $(git rev-parse B:a) &&
-	test $(git rev-parse :3:a/file) = $(git rev-parse E2:a/file) &&
-	test $(git rev-parse :1:a/file) = $(git rev-parse C:a/file) &&
-	test $(git rev-parse :0:ignore-me) = $(git rev-parse A:ignore-me) &&
-
-	test -f a~HEAD
-'
-
-test_expect_success 'merge of E2 & D fails but has appropriate contents' '
-	get_clean_checkout E2^0 &&
-
-	test_must_fail git merge -s recursive D^0 &&
-
-	test 4 -eq $(git ls-files -s | wc -l) &&
-	test 3 -eq $(git ls-files -u | wc -l) &&
-	test 1 -eq $(git ls-files -o | wc -l) &&
-
-	test $(git rev-parse :3:a) = $(git rev-parse B:a) &&
-	test $(git rev-parse :2:a/file) = $(git rev-parse E2:a/file) &&
-	test $(git rev-parse :1:a/file) = $(git rev-parse C:a/file) &&
-	test $(git rev-parse :0:ignore-me) = $(git rev-parse A:ignore-me) &&
+	test_create_repo directory-file &&
+	(
+		cd directory-file &&
+
+		>ignore-me &&
+		git add ignore-me &&
+		test_tick &&
+		git commit -m A &&
+		git tag A &&
+
+		git branch B &&
+		git checkout -b C &&
+		mkdir a &&
+		test_write_lines a b c d e f g >a/file &&
+		git add a/file &&
+		test_tick &&
+		git commit -m C &&
+
+		git checkout B &&
+		test_write_lines 1 2 3 4 5 6 7 >a &&
+		git add a &&
+		test_tick &&
+		git commit -m B &&
+
+		git checkout B^0 &&
+		git merge -s ours -m D1 C^0 &&
+		git tag D1 &&
+
+		git checkout B^0 &&
+		test_must_fail git merge C^0 &&
+		git clean -fd &&
+		git rm -rf a/ &&
+		git rm a &&
+		git cat-file -p B:a >a2 &&
+		git add a2 &&
+		git commit -m D2 &&
+		git tag D2 &&
+
+		git checkout C^0 &&
+		git merge -s ours -m E1 B^0 &&
+		git tag E1 &&
+
+		git checkout C^0 &&
+		git merge -s ours -m E2 B^0 &&
+		test_write_lines a b c d e f g h >a/file &&
+		git add a/file &&
+		git commit --amend -C HEAD &&
+		git tag E2 &&
+
+		git checkout C^0 &&
+		test_must_fail git merge B^0 &&
+		git clean -fd &&
+		git rm -rf a/ &&
+		test_write_lines 1 2 3 4 5 6 7 8 >a &&
+		git add a &&
+		git commit -m E3 &&
+		git tag E3 &&
+
+		git checkout C^0 &&
+		test_must_fail git merge B^0 &&
+		git clean -fd &&
+		git rm -rf a/ &&
+		git rm a &&
+		test_write_lines 1 2 3 4 5 6 7 8 >a2 &&
+		git add a2 &&
+		git commit -m E4 &&
+		git tag E4
+	)
+'
+
+test_expect_success 'merge of D1 & E1 fails but has appropriate contents' '
+	test_when_finished "git -C directory-file reset --hard" &&
+	test_when_finished "git -C directory-file clean -fdqx" &&
+	(
+		cd directory-file &&
+
+		git checkout D1^0 &&
+
+		test_must_fail git merge -s recursive E1^0 &&
+
+		git ls-files -s >out &&
+		test_line_count = 2 out &&
+		git ls-files -u >out &&
+		test_line_count = 1 out &&
+		git ls-files -o >out &&
+		test_line_count = 1 out &&
+
+		git rev-parse >expect    \
+			A:ignore-me  B:a &&
+		git rev-parse   >actual   \
+			:0:ignore-me :2:a &&
+		test_cmp expect actual
+	)
+'
+
+test_expect_success 'merge of E1 & D1 fails but has appropriate contents' '
+	test_when_finished "git -C directory-file reset --hard" &&
+	test_when_finished "git -C directory-file clean -fdqx" &&
+	(
+		cd directory-file &&
+
+		git checkout E1^0 &&
+
+		test_must_fail git merge -s recursive D1^0 &&
+
+		git ls-files -s >out &&
+		test_line_count = 2 out &&
+		git ls-files -u >out &&
+		test_line_count = 1 out &&
+		git ls-files -o >out &&
+		test_line_count = 1 out &&
+
+		git rev-parse >expect    \
+			A:ignore-me  B:a &&
+		git rev-parse   >actual   \
+			:0:ignore-me :3:a &&
+		test_cmp expect actual
+	)
+'
+
+test_expect_success 'merge of D1 & E2 fails but has appropriate contents' '
+	test_when_finished "git -C directory-file reset --hard" &&
+	test_when_finished "git -C directory-file clean -fdqx" &&
+	(
+		cd directory-file &&
+
+		git checkout D1^0 &&
+
+		test_must_fail git merge -s recursive E2^0 &&
+
+		git ls-files -s >out &&
+		test_line_count = 4 out &&
+		git ls-files -u >out &&
+		test_line_count = 3 out &&
+		git ls-files -o >out &&
+		test_line_count = 2 out &&
+
+		git rev-parse >expect    \
+			B:a   E2:a/file  C:a/file   A:ignore-me &&
+		git rev-parse   >actual   \
+			:2:a  :3:a/file  :1:a/file  :0:ignore-me &&
+		test_cmp expect actual &&
 
-	test -f a~D^0
+		test_path_is_file a~HEAD
+	)
+'
+
+test_expect_success 'merge of E2 & D1 fails but has appropriate contents' '
+	test_when_finished "git -C directory-file reset --hard" &&
+	test_when_finished "git -C directory-file clean -fdqx" &&
+	(
+		cd directory-file &&
+
+		git checkout E2^0 &&
+
+		test_must_fail git merge -s recursive D1^0 &&
+
+		git ls-files -s >out &&
+		test_line_count = 4 out &&
+		git ls-files -u >out &&
+		test_line_count = 3 out &&
+		git ls-files -o >out &&
+		test_line_count = 2 out &&
+
+		git rev-parse >expect    \
+			B:a   E2:a/file  C:a/file   A:ignore-me &&
+		git rev-parse   >actual   \
+			:3:a  :2:a/file  :1:a/file  :0:ignore-me &&
+		test_cmp expect actual &&
+
+		test_path_is_file a~D1^0
+	)
+'
+
+test_expect_success 'merge of D1 & E3 succeeds' '
+	test_when_finished "git -C directory-file reset --hard" &&
+	test_when_finished "git -C directory-file clean -fdqx" &&
+	(
+		cd directory-file &&
+
+		git checkout D1^0 &&
+
+		git merge -s recursive E3^0 &&
+
+		git ls-files -s >out &&
+		test_line_count = 2 out &&
+		git ls-files -u >out &&
+		test_line_count = 0 out &&
+		git ls-files -o >out &&
+		test_line_count = 1 out &&
+
+		git rev-parse >expect    \
+			A:ignore-me  E3:a &&
+		git rev-parse   >actual   \
+			:0:ignore-me :0:a &&
+		test_cmp expect actual
+	)
+'
+
+test_expect_success 'merge of D1 & E4 notifies user a and a2 are related' '
+	test_when_finished "git -C directory-file reset --hard" &&
+	test_when_finished "git -C directory-file clean -fdqx" &&
+	(
+		cd directory-file &&
+
+		git checkout D1^0 &&
+
+		test_must_fail git merge -s recursive E4^0 &&
+
+		git ls-files -s >out &&
+		test_line_count = 4 out &&
+		git ls-files -u >out &&
+		test_line_count = 3 out &&
+		git ls-files -o >out &&
+		test_line_count = 1 out &&
+
+		git rev-parse >expect                  \
+			A:ignore-me  B:a   D1:a  E4:a2 &&
+		git rev-parse   >actual                \
+			:0:ignore-me :1:a~Temporary\ merge\ branch\ 2  :2:a  :3:a2 &&
+		test_cmp expect actual
+	)
+'
+
+test_expect_failure 'merge of D2 & E4 merges a2s & reports conflict for a/file' '
+	test_when_finished "git -C directory-file reset --hard" &&
+	test_when_finished "git -C directory-file clean -fdqx" &&
+	(
+		cd directory-file &&
+
+		git checkout D2^0 &&
+
+		test_must_fail git merge -s recursive E4^0 &&
+
+		git ls-files -s >out &&
+		test_line_count = 3 out &&
+		git ls-files -u >out &&
+		test_line_count = 1 out &&
+		git ls-files -o >out &&
+		test_line_count = 1 out &&
+
+		git rev-parse >expect                 \
+			A:ignore-me  E4:a2  D2:a/file &&
+		git rev-parse   >actual               \
+			:0:ignore-me :0:a2  :2:a/file &&
+		test_cmp expect actual
+	)
 '
 
 #
@@ -492,52 +775,58 @@ test_expect_success 'merge of E2 & D fai
 # but that may cancel out at the final merge stage".
 
 test_expect_success 'setup rename/rename(1to2)/modify followed by what looks like rename/rename(2to1)/modify' '
-	git reset --hard &&
-	git rm -rf . &&
-	git clean -fdqx &&
-	rm -rf .git &&
-	git init &&
-
-	printf "1\n2\n3\n4\n5\n6\n" >a &&
-	git add a &&
-	git commit -m A &&
-	git tag A &&
-
-	git checkout -b B A &&
-	git mv a b &&
-	echo 7 >>b &&
-	git add -u &&
-	git commit -m B &&
-
-	git checkout -b C A &&
-	git mv a c &&
-	git commit -m C &&
-
-	git checkout -q B^0 &&
-	git merge --no-commit -s ours C^0 &&
-	git mv b newname &&
-	git commit -m "Merge commit C^0 into HEAD" &&
-	git tag D &&
-
-	git checkout -q C^0 &&
-	git merge --no-commit -s ours B^0 &&
-	git mv c newname &&
-	printf "7\n8\n" >>newname &&
-	git add -u &&
-	git commit -m "Merge commit B^0 into HEAD" &&
-	git tag E
+	test_create_repo rename-squared-squared &&
+	(
+		cd rename-squared-squared &&
+
+		printf "1\n2\n3\n4\n5\n6\n" >a &&
+		git add a &&
+		git commit -m A &&
+		git tag A &&
+
+		git checkout -b B A &&
+		git mv a b &&
+		echo 7 >>b &&
+		git add -u &&
+		git commit -m B &&
+
+		git checkout -b C A &&
+		git mv a c &&
+		git commit -m C &&
+
+		git checkout -q B^0 &&
+		git merge --no-commit -s ours C^0 &&
+		git mv b newname &&
+		git commit -m "Merge commit C^0 into HEAD" &&
+		git tag D &&
+
+		git checkout -q C^0 &&
+		git merge --no-commit -s ours B^0 &&
+		git mv c newname &&
+		printf "7\n8\n" >>newname &&
+		git add -u &&
+		git commit -m "Merge commit B^0 into HEAD" &&
+		git tag E
+	)
 '
 
 test_expect_success 'handle rename/rename(1to2)/modify followed by what looks like rename/rename(2to1)/modify' '
-	git checkout D^0 &&
+	(
+		cd rename-squared-squared &&
+
+		git checkout D^0 &&
 
-	git merge -s recursive E^0 &&
+		git merge -s recursive E^0 &&
 
-	test 1 -eq $(git ls-files -s | wc -l) &&
-	test 0 -eq $(git ls-files -u | wc -l) &&
-	test 0 -eq $(git ls-files -o | wc -l) &&
+		git ls-files -s >out &&
+		test_line_count = 1 out &&
+		git ls-files -u >out &&
+		test_line_count = 0 out &&
+		git ls-files -o >out &&
+		test_line_count = 1 out &&
 
-	test $(git rev-parse HEAD:newname) = $(git rev-parse E:newname)
+		test $(git rev-parse HEAD:newname) = $(git rev-parse E:newname)
+	)
 '
 
 #
@@ -562,59 +851,72 @@ test_expect_success 'handle rename/renam
 # renaming carefully (both in the virtual merge base and later), and getting
 # content merge handled.
 
-test_expect_success 'setup criss-cross + rename/rename/add + modify/modify' '
-	git rm -rf . &&
-	git clean -fdqx &&
-	rm -rf .git &&
-	git init &&
-
-	printf "lots\nof\nwords\nand\ncontent\n" >a &&
-	git add a &&
-	git commit -m A &&
-	git tag A &&
-
-	git checkout -b B A &&
-	git mv a b &&
-	git commit -m B &&
-
-	git checkout -b C A &&
-	git mv a c &&
-	printf "2\n3\n4\n5\n6\n7\n" >a &&
-	git add a &&
-	git commit -m C &&
-
-	git checkout B^0 &&
-	git merge --no-commit -s ours C^0 &&
-	git checkout C -- a c &&
-	mv a old_a &&
-	echo 1 >a &&
-	cat old_a >>a &&
-	rm old_a &&
-	git add -u &&
-	git commit -m "Merge commit C^0 into HEAD" &&
-	git tag D &&
-
-	git checkout C^0 &&
-	git merge --no-commit -s ours B^0 &&
-	git checkout B -- b &&
-	echo 8 >>a &&
-	git add -u &&
-	git commit -m "Merge commit B^0 into HEAD" &&
-	git tag E
+test_expect_success 'setup criss-cross + rename/rename/add-source + modify/modify' '
+	test_create_repo rename-rename-add-source &&
+	(
+		cd rename-rename-add-source &&
+
+		printf "lots\nof\nwords\nand\ncontent\n" >a &&
+		git add a &&
+		git commit -m A &&
+		git tag A &&
+
+		git checkout -b B A &&
+		git mv a b &&
+		git commit -m B &&
+
+		git checkout -b C A &&
+		git mv a c &&
+		printf "2\n3\n4\n5\n6\n7\n" >a &&
+		git add a &&
+		git commit -m C &&
+
+		git checkout B^0 &&
+		git merge --no-commit -s ours C^0 &&
+		git checkout C -- a c &&
+		mv a old_a &&
+		echo 1 >a &&
+		cat old_a >>a &&
+		rm old_a &&
+		git add -u &&
+		git commit -m "Merge commit C^0 into HEAD" &&
+		git tag D &&
+
+		git checkout C^0 &&
+		git merge --no-commit -s ours B^0 &&
+		git checkout B -- b &&
+		echo 8 >>a &&
+		git add -u &&
+		git commit -m "Merge commit B^0 into HEAD" &&
+		git tag E
+	)
 '
 
 test_expect_failure 'detect rename/rename/add-source for virtual merge-base' '
-	git checkout D^0 &&
+	(
+		cd rename-rename-add-source &&
 
-	git merge -s recursive E^0 &&
+		git checkout D^0 &&
 
-	test 3 -eq $(git ls-files -s | wc -l) &&
-	test 0 -eq $(git ls-files -u | wc -l) &&
-	test 0 -eq $(git ls-files -o | wc -l) &&
+		git merge -s recursive E^0 &&
 
-	test $(git rev-parse HEAD:b) = $(git rev-parse A:a) &&
-	test $(git rev-parse HEAD:c) = $(git rev-parse A:a) &&
-	test "$(cat a)" = "$(printf "1\n2\n3\n4\n5\n6\n7\n8\n")"
+		git ls-files -s >out &&
+		test_line_count = 3 out &&
+		git ls-files -u >out &&
+		test_line_count = 0 out &&
+		git ls-files -o >out &&
+		test_line_count = 1 out &&
+
+		printf "1\n2\n3\n4\n5\n6\n7\n8\n" >correct &&
+		git rev-parse >expect \
+			A:a   A:a     \
+			correct       &&
+		git rev-parse   >actual  \
+			:0:b  :0:c       &&
+		git hash-object >>actual \
+			a                &&
+		test_cmp expect actual
+	)
 '
 
 #
@@ -638,52 +940,860 @@ test_expect_failure 'detect rename/renam
 # base of B & C needs to not delete B:c for that to work, though...
 
 test_expect_success 'setup criss-cross+rename/rename/add-dest + simple modify' '
-	git rm -rf . &&
-	git clean -fdqx &&
-	rm -rf .git &&
-	git init &&
-
-	>a &&
-	git add a &&
-	git commit -m A &&
-	git tag A &&
-
-	git checkout -b B A &&
-	git mv a b &&
-	printf "1\n2\n3\n4\n5\n6\n7\n" >c &&
-	git add c &&
-	git commit -m B &&
-
-	git checkout -b C A &&
-	git mv a c &&
-	git commit -m C &&
-
-	git checkout B^0 &&
-	git merge --no-commit -s ours C^0 &&
-	git mv b a &&
-	git commit -m "D is like B but renames b back to a" &&
-	git tag D &&
-
-	git checkout B^0 &&
-	git merge --no-commit -s ours C^0 &&
-	git mv b a &&
-	echo 8 >>c &&
-	git add c &&
-	git commit -m "E like D but has mod in c" &&
-	git tag E
+	test_create_repo rename-rename-add-dest &&
+	(
+		cd rename-rename-add-dest &&
+
+		>a &&
+		git add a &&
+		git commit -m A &&
+		git tag A &&
+
+		git checkout -b B A &&
+		git mv a b &&
+		printf "1\n2\n3\n4\n5\n6\n7\n" >c &&
+		git add c &&
+		git commit -m B &&
+
+		git checkout -b C A &&
+		git mv a c &&
+		git commit -m C &&
+
+		git checkout B^0 &&
+		git merge --no-commit -s ours C^0 &&
+		git mv b a &&
+		git commit -m "D is like B but renames b back to a" &&
+		git tag D &&
+
+		git checkout B^0 &&
+		git merge --no-commit -s ours C^0 &&
+		git mv b a &&
+		echo 8 >>c &&
+		git add c &&
+		git commit -m "E like D but has mod in c" &&
+		git tag E
+	)
 '
 
 test_expect_success 'virtual merge base handles rename/rename(1to2)/add-dest' '
-	git checkout D^0 &&
+	(
+		cd rename-rename-add-dest &&
 
-	git merge -s recursive E^0 &&
+		git checkout D^0 &&
 
-	test 2 -eq $(git ls-files -s | wc -l) &&
-	test 0 -eq $(git ls-files -u | wc -l) &&
-	test 0 -eq $(git ls-files -o | wc -l) &&
+		git merge -s recursive E^0 &&
+
+		git ls-files -s >out &&
+		test_line_count = 2 out &&
+		git ls-files -u >out &&
+		test_line_count = 0 out &&
+		git ls-files -o >out &&
+		test_line_count = 1 out &&
+
+		git rev-parse >expect \
+			A:a   E:c     &&
+		git rev-parse   >actual \
+			:0:a  :0:c      &&
+		test_cmp expect actual
+	)
+'
+
+#
+# criss-cross with modify/modify on a symlink:
+#
+#      B   D
+#      o---o
+#     / \ / \
+#  A o   X   ? F
+#     \ / \ /
+#      o---o
+#      C   E
+#
+#   Commit A: simple simlink fickle->lagoon
+#   Commit B: redirect fickle->disneyland
+#   Commit C: redirect fickle->home
+#   Commit D: merge B&C, resolving in favor of B
+#   Commit E: merge B&C, resolving in favor of C
+#
+# This is an obvious modify/modify conflict for the symlink 'fickle'.  Can
+# git detect it?
+
+test_expect_success 'setup symlink modify/modify' '
+	test_create_repo symlink-modify-modify &&
+	(
+		cd symlink-modify-modify &&
+
+		test_ln_s_add lagoon fickle &&
+		git commit -m A &&
+		git tag A &&
+
+		git checkout -b B A &&
+		git rm fickle &&
+		test_ln_s_add disneyland fickle &&
+		git commit -m B &&
+
+		git checkout -b C A &&
+		git rm fickle &&
+		test_ln_s_add home fickle &&
+		git add fickle &&
+		git commit -m C &&
+
+		git checkout -q B^0 &&
+		git merge -s ours -m D C^0 &&
+		git tag D &&
+
+		git checkout -q C^0 &&
+		git merge -s ours -m E B^0 &&
+		git tag E
+	)
+'
+
+test_expect_failure 'check symlink modify/modify' '
+	(
+		cd symlink-modify-modify &&
+
+		git checkout D^0 &&
+
+		test_must_fail git merge -s recursive E^0 &&
+
+		git ls-files -s >out &&
+		test_line_count = 3 out &&
+		git ls-files -u >out &&
+		test_line_count = 3 out &&
+		git ls-files -o >out &&
+		test_line_count = 1 out
+	)
+'
+
+#
+# criss-cross with add/add of a symlink:
+#
+#      B   D
+#      o---o
+#     / \ / \
+#  A o   X   ? F
+#     \ / \ /
+#      o---o
+#      C   E
+#
+#   Commit A: No symlink or path exists yet
+#   Commit B: set up symlink: fickle->disneyland
+#   Commit C: set up symlink: fickle->home
+#   Commit D: merge B&C, resolving in favor of B
+#   Commit E: merge B&C, resolving in favor of C
+#
+# This is an obvious add/add conflict for the symlink 'fickle'.  Can
+# git detect it?
+
+test_expect_success 'setup symlink add/add' '
+	test_create_repo symlink-add-add &&
+	(
+		cd symlink-add-add &&
+
+		touch ignoreme &&
+		git add ignoreme &&
+		git commit -m A &&
+		git tag A &&
+
+		git checkout -b B A &&
+		test_ln_s_add disneyland fickle &&
+		git commit -m B &&
+
+		git checkout -b C A &&
+		test_ln_s_add home fickle &&
+		git add fickle &&
+		git commit -m C &&
+
+		git checkout -q B^0 &&
+		git merge -s ours -m D C^0 &&
+		git tag D &&
+
+		git checkout -q C^0 &&
+		git merge -s ours -m E B^0 &&
+		git tag E
+	)
+'
+
+test_expect_failure 'check symlink add/add' '
+	(
+		cd symlink-add-add &&
+
+		git checkout D^0 &&
+
+		test_must_fail git merge -s recursive E^0 &&
+
+		git ls-files -s >out &&
+		test_line_count = 2 out &&
+		git ls-files -u >out &&
+		test_line_count = 2 out &&
+		git ls-files -o >out &&
+		test_line_count = 1 out
+	)
+'
+
+#
+# criss-cross with modify/modify on a submodule:
+#
+#      B   D
+#      o---o
+#     / \ / \
+#  A o   X   ? F
+#     \ / \ /
+#      o---o
+#      C   E
+#
+#   Commit A: simple submodule repo
+#   Commit B: update repo
+#   Commit C: update repo differently
+#   Commit D: merge B&C, resolving in favor of B
+#   Commit E: merge B&C, resolving in favor of C
+#
+# This is an obvious modify/modify conflict for the submodule 'repo'.  Can
+# git detect it?
+
+test_expect_success 'setup submodule modify/modify' '
+	test_create_repo submodule-modify-modify &&
+	(
+		cd submodule-modify-modify &&
+
+		test_create_repo submod &&
+		(
+			cd submod &&
+			touch file-A &&
+			git add file-A &&
+			git commit -m A &&
+			git tag A &&
+
+			git checkout -b B A &&
+			touch file-B &&
+			git add file-B &&
+			git commit -m B &&
+			git tag B &&
+
+			git checkout -b C A &&
+			touch file-C &&
+			git add file-C &&
+			git commit -m C &&
+			git tag C
+		) &&
+
+		git -C submod reset --hard A &&
+		git add submod &&
+		git commit -m A &&
+		git tag A &&
+
+		git checkout -b B A &&
+		git -C submod reset --hard B &&
+		git add submod &&
+		git commit -m B &&
+
+		git checkout -b C A &&
+		git -C submod reset --hard C &&
+		git add submod &&
+		git commit -m C &&
+
+		git checkout -q B^0 &&
+		git merge -s ours -m D C^0 &&
+		git tag D &&
+
+		git checkout -q C^0 &&
+		git merge -s ours -m E B^0 &&
+		git tag E
+	)
+'
+
+test_expect_failure 'check submodule modify/modify' '
+	(
+		cd submodule-modify-modify &&
+
+		git checkout D^0 &&
+
+		test_must_fail git merge -s recursive E^0 &&
+
+		git ls-files -s >out &&
+		test_line_count = 3 out &&
+		git ls-files -u >out &&
+		test_line_count = 3 out &&
+		git ls-files -o >out &&
+		test_line_count = 1 out
+	)
+'
+
+#
+# criss-cross with add/add on a submodule:
+#
+#      B   D
+#      o---o
+#     / \ / \
+#  A o   X   ? F
+#     \ / \ /
+#      o---o
+#      C   E
+#
+#   Commit A: nothing of note
+#   Commit B: introduce submodule repo
+#   Commit C: introduce submodule repo at different commit
+#   Commit D: merge B&C, resolving in favor of B
+#   Commit E: merge B&C, resolving in favor of C
+#
+# This is an obvious add/add conflict for the submodule 'repo'.  Can
+# git detect it?
+
+test_expect_success 'setup submodule add/add' '
+	test_create_repo submodule-add-add &&
+	(
+		cd submodule-add-add &&
+
+		test_create_repo submod &&
+		(
+			cd submod &&
+			touch file-A &&
+			git add file-A &&
+			git commit -m A &&
+			git tag A &&
+
+			git checkout -b B A &&
+			touch file-B &&
+			git add file-B &&
+			git commit -m B &&
+			git tag B &&
+
+			git checkout -b C A &&
+			touch file-C &&
+			git add file-C &&
+			git commit -m C &&
+			git tag C
+		) &&
+
+		touch irrelevant-file &&
+		git add irrelevant-file &&
+		git commit -m A &&
+		git tag A &&
+
+		git checkout -b B A &&
+		git -C submod reset --hard B &&
+		git add submod &&
+		git commit -m B &&
+
+		git checkout -b C A &&
+		git -C submod reset --hard C &&
+		git add submod &&
+		git commit -m C &&
+
+		git checkout -q B^0 &&
+		git merge -s ours -m D C^0 &&
+		git tag D &&
+
+		git checkout -q C^0 &&
+		git merge -s ours -m E B^0 &&
+		git tag E
+	)
+'
+
+test_expect_failure 'check submodule add/add' '
+	(
+		cd submodule-add-add &&
+
+		git checkout D^0 &&
+
+		test_must_fail git merge -s recursive E^0 &&
+
+		git ls-files -s >out &&
+		test_line_count = 3 out &&
+		git ls-files -u >out &&
+		test_line_count = 2 out &&
+		git ls-files -o >out &&
+		test_line_count = 1 out
+	)
+'
+
+#
+# criss-cross with conflicting entry types:
+#
+#      B   D
+#      o---o
+#     / \ / \
+#  A o   X   ? F
+#     \ / \ /
+#      o---o
+#      C   E
+#
+#   Commit A: nothing of note
+#   Commit B: introduce submodule 'path'
+#   Commit C: introduce symlink 'path'
+#   Commit D: merge B&C, resolving in favor of B
+#   Commit E: merge B&C, resolving in favor of C
+#
+# This is an obvious add/add conflict for 'path'.  Can git detect it?
+
+test_expect_success 'setup conflicting entry types (submodule vs symlink)' '
+	test_create_repo submodule-symlink-add-add &&
+	(
+		cd submodule-symlink-add-add &&
+
+		test_create_repo path &&
+		(
+			cd path &&
+			touch file-B &&
+			git add file-B &&
+			git commit -m B &&
+			git tag B
+		) &&
+
+		touch irrelevant-file &&
+		git add irrelevant-file &&
+		git commit -m A &&
+		git tag A &&
+
+		git checkout -b B A &&
+		git -C path reset --hard B &&
+		git add path &&
+		git commit -m B &&
+
+		git checkout -b C A &&
+		rm -rf path/ &&
+		test_ln_s_add irrelevant-file path &&
+		git commit -m C &&
+
+		git checkout -q B^0 &&
+		git merge -s ours -m D C^0 &&
+		git tag D &&
+
+		git checkout -q C^0 &&
+		git merge -s ours -m E B^0 &&
+		git tag E
+	)
+'
+
+test_expect_failure 'check conflicting entry types (submodule vs symlink)' '
+	(
+		cd submodule-symlink-add-add &&
+
+		git checkout D^0 &&
+
+		test_must_fail git merge -s recursive E^0 &&
+
+		git ls-files -s >out &&
+		test_line_count = 3 out &&
+		git ls-files -u >out &&
+		test_line_count = 2 out &&
+		git ls-files -o >out &&
+		test_line_count = 1 out
+	)
+'
+
+#
+# criss-cross with regular files that have conflicting modes:
+#
+#      B   D
+#      o---o
+#     / \ / \
+#  A o   X   ? F
+#     \ / \ /
+#      o---o
+#      C   E
+#
+#   Commit A: nothing of note
+#   Commit B: introduce file source_me.bash, not executable
+#   Commit C: introduce file source_me.bash, executable
+#   Commit D: merge B&C, resolving in favor of B
+#   Commit E: merge B&C, resolving in favor of C
+#
+# This is an obvious add/add mode conflict.  Can git detect it?
+
+test_expect_success 'setup conflicting modes for regular file' '
+	test_create_repo regular-file-mode-conflict &&
+	(
+		cd regular-file-mode-conflict &&
+
+		touch irrelevant-file &&
+		git add irrelevant-file &&
+		git commit -m A &&
+		git tag A &&
+
+		git checkout -b B A &&
+		echo "command_to_run" >source_me.bash &&
+		git add source_me.bash &&
+		git commit -m B &&
+
+		git checkout -b C A &&
+		echo "command_to_run" >source_me.bash &&
+		git add source_me.bash &&
+		test_chmod +x source_me.bash &&
+		git commit -m C &&
+
+		git checkout -q B^0 &&
+		git merge -s ours -m D C^0 &&
+		git tag D &&
+
+		git checkout -q C^0 &&
+		git merge -s ours -m E B^0 &&
+		git tag E
+	)
+'
+
+test_expect_failure 'check conflicting modes for regular file' '
+	(
+		cd regular-file-mode-conflict &&
+
+		git checkout D^0 &&
+
+		test_must_fail git merge -s recursive E^0 &&
+
+		git ls-files -s >out &&
+		test_line_count = 3 out &&
+		git ls-files -u >out &&
+		test_line_count = 2 out &&
+		git ls-files -o >out &&
+		test_line_count = 1 out
+	)
+'
+
+# Setup:
+#          L1---L2
+#         /  \ /  \
+#   master    X    ?
+#         \  / \  /
+#          R1---R2
+#
+# Where:
+#   master has two files, named 'b' and 'a'
+#   branches L1 and R1 both modify each of the two files in conflicting ways
+#
+#   L2 is a merge of R1 into L1; more on it later.
+#   R2 is a merge of L1 into R1; more on it later.
+#
+#   X is an auto-generated merge-base used when merging L2 and R2.
+#   since X is a merge of L1 and R1, it has conflicting versions of each file
+#
+#   More about L2 and R2:
+#     - both resolve the conflicts in 'b' and 'a' differently
+#     - L2 renames 'b' to 'm'
+#     - R2 renames 'a' to 'm'
+#
+#   In the end, in file 'm' we have four different conflicting files (from
+#   two versions of 'b' and two of 'a').  In addition, if
+#   merge.conflictstyle is diff3, then the base version also has
+#   conflict markers of its own, leading to a total of three levels of
+#   conflict markers.  This is a pretty weird corner case, but we just want
+#   to ensure that we handle it as well as practical.
+
+test_expect_success 'setup nested conflicts' '
+	test_create_repo nested_conflicts &&
+	(
+		cd nested_conflicts &&
+
+		# Create some related files now
+		for i in $(test_seq 1 10)
+		do
+			echo Random base content line $i
+		done >initial &&
+
+		cp initial b_L1 &&
+		cp initial b_R1 &&
+		cp initial b_L2 &&
+		cp initial b_R2 &&
+		cp initial a_L1 &&
+		cp initial a_R1 &&
+		cp initial a_L2 &&
+		cp initial a_R2 &&
+
+		test_write_lines b b_L1 >>b_L1 &&
+		test_write_lines b b_R1 >>b_R1 &&
+		test_write_lines b b_L2 >>b_L2 &&
+		test_write_lines b b_R2 >>b_R2 &&
+		test_write_lines a a_L1 >>a_L1 &&
+		test_write_lines a a_R1 >>a_R1 &&
+		test_write_lines a a_L2 >>a_L2 &&
+		test_write_lines a a_R2 >>a_R2 &&
+
+		# Setup original commit (or merge-base), consisting of
+		# files named "b" and "a"
+		cp initial b &&
+		cp initial a &&
+		echo b >>b &&
+		echo a >>a &&
+		git add b a &&
+		test_tick && git commit -m initial &&
+
+		git branch L &&
+		git branch R &&
+
+		# Handle the left side
+		git checkout L &&
+		mv -f b_L1 b &&
+		mv -f a_L1 a &&
+		git add b a &&
+		test_tick && git commit -m "version L1 of files" &&
+		git tag L1 &&
+
+		# Handle the right side
+		git checkout R &&
+		mv -f b_R1 b &&
+		mv -f a_R1 a &&
+		git add b a &&
+		test_tick && git commit -m "version R1 of files" &&
+		git tag R1 &&
+
+		# Create first merge on left side
+		git checkout L &&
+		test_must_fail git merge R1 &&
+		mv -f b_L2 b &&
+		mv -f a_L2 a &&
+		git add b a &&
+		git mv b m &&
+		test_tick && git commit -m "left merge, rename b->m" &&
+		git tag L2 &&
+
+		# Create first merge on right side
+		git checkout R &&
+		test_must_fail git merge L1 &&
+		mv -f b_R2 b &&
+		mv -f a_R2 a &&
+		git add b a &&
+		git mv a m &&
+		test_tick && git commit -m "right merge, rename a->m" &&
+		git tag R2
+	)
+'
+
+test_expect_success 'check nested conflicts' '
+	(
+		cd nested_conflicts &&
+
+		git clean -f &&
+		MASTER=$(git rev-parse --short master) &&
+		git checkout L2^0 &&
+
+		# Merge must fail; there is a conflict
+		test_must_fail git -c merge.conflictstyle=diff3 merge -s recursive R2^0 &&
+
+		# Make sure the index has the right number of entries
+		git ls-files -s >out &&
+		test_line_count = 2 out &&
+		git ls-files -u >out &&
+		test_line_count = 2 out &&
+		# Ensure we have the correct number of untracked files
+		git ls-files -o >out &&
+		test_line_count = 1 out &&
+
+		# Create a and b from virtual merge base X
+		git cat-file -p master:a >base &&
+		git cat-file -p L1:a >ours &&
+		git cat-file -p R1:a >theirs &&
+		test_must_fail git merge-file --diff3 \
+			-L "Temporary merge branch 1" \
+			-L "$MASTER"  \
+			-L "Temporary merge branch 2" \
+			ours  \
+			base  \
+			theirs &&
+		sed -e "s/^\([<|=>]\)/\1\1/" ours >vmb_a &&
+
+		git cat-file -p master:b >base &&
+		git cat-file -p L1:b >ours &&
+		git cat-file -p R1:b >theirs &&
+		test_must_fail git merge-file --diff3 \
+			-L "Temporary merge branch 1" \
+			-L "$MASTER"  \
+			-L "Temporary merge branch 2" \
+			ours  \
+			base  \
+			theirs &&
+		sed -e "s/^\([<|=>]\)/\1\1/" ours >vmb_b &&
+
+		# Compare :2:m to expected values
+		git cat-file -p L2:m >ours &&
+		git cat-file -p R2:b >theirs &&
+		test_must_fail git merge-file --diff3  \
+			-L "HEAD:m"                    \
+			-L "merged common ancestors:b" \
+			-L "R2^0:b"                    \
+			ours                           \
+			vmb_b                          \
+			theirs                         &&
+		sed -e "s/^\([<|=>]\)/\1\1/" ours >m_stage_2 &&
+		git cat-file -p :2:m >actual &&
+		test_cmp m_stage_2 actual &&
+
+		# Compare :3:m to expected values
+		git cat-file -p L2:a >ours &&
+		git cat-file -p R2:m >theirs &&
+		test_must_fail git merge-file --diff3  \
+			-L "HEAD:a"                    \
+			-L "merged common ancestors:a" \
+			-L "R2^0:m"                    \
+			ours                           \
+			vmb_a                          \
+			theirs                         &&
+		sed -e "s/^\([<|=>]\)/\1\1/" ours >m_stage_3 &&
+		git cat-file -p :3:m >actual &&
+		test_cmp m_stage_3 actual &&
+
+		# Compare m to expected contents
+		>empty &&
+		cp m_stage_2 expected_final_m &&
+		test_must_fail git merge-file --diff3 \
+			-L "HEAD"                     \
+			-L "merged common ancestors"  \
+			-L "R2^0"                     \
+			expected_final_m              \
+			empty                         \
+			m_stage_3                     &&
+		test_cmp expected_final_m m
+	)
+'
+
+# Setup:
+#          L1---L2---L3
+#         /  \ /  \ /  \
+#   master    X1   X2   ?
+#         \  / \  / \  /
+#          R1---R2---R3
+#
+# Where:
+#   master has one file named 'content'
+#   branches L1 and R1 both modify each of the two files in conflicting ways
+#
+#   L<n> (n>1) is a merge of R<n-1> into L<n-1>
+#   R<n> (n>1) is a merge of L<n-1> into R<n-1>
+#   L<n> and R<n> resolve the conflicts differently.
+#
+#   X<n> is an auto-generated merge-base used when merging L<n+1> and R<n+1>.
+#   By construction, X1 has conflict markers due to conflicting versions.
+#   X2, due to using merge.conflictstyle=3, has nested conflict markers.
+#
+#   So, merging R3 into L3 using merge.conflictstyle=3 should show the
+#   nested conflict markers from X2 in the base version -- that means we
+#   have three levels of conflict markers.  Can we distinguish all three?
+
+test_expect_success 'setup virtual merge base with nested conflicts' '
+	test_create_repo virtual_merge_base_has_nested_conflicts &&
+	(
+		cd virtual_merge_base_has_nested_conflicts &&
+
+		# Create some related files now
+		for i in $(test_seq 1 10)
+		do
+			echo Random base content line $i
+		done >content &&
+
+		# Setup original commit
+		git add content &&
+		test_tick && git commit -m initial &&
+
+		git branch L &&
+		git branch R &&
+
+		# Create L1
+		git checkout L &&
+		echo left >>content &&
+		git add content &&
+		test_tick && git commit -m "version L1 of content" &&
+		git tag L1 &&
+
+		# Create R1
+		git checkout R &&
+		echo right >>content &&
+		git add content &&
+		test_tick && git commit -m "version R1 of content" &&
+		git tag R1 &&
+
+		# Create L2
+		git checkout L &&
+		test_must_fail git -c merge.conflictstyle=diff3 merge R1 &&
+		git checkout L1 content &&
+		test_tick && git commit -m "version L2 of content" &&
+		git tag L2 &&
+
+		# Create R2
+		git checkout R &&
+		test_must_fail git -c merge.conflictstyle=diff3 merge L1 &&
+		git checkout R1 content &&
+		test_tick && git commit -m "version R2 of content" &&
+		git tag R2 &&
+
+		# Create L3
+		git checkout L &&
+		test_must_fail git -c merge.conflictstyle=diff3 merge R2 &&
+		git checkout L1 content &&
+		test_tick && git commit -m "version L3 of content" &&
+		git tag L3 &&
+
+		# Create R3
+		git checkout R &&
+		test_must_fail git -c merge.conflictstyle=diff3 merge L2 &&
+		git checkout R1 content &&
+		test_tick && git commit -m "version R3 of content" &&
+		git tag R3
+	)
+'
 
-	test $(git rev-parse HEAD:a) = $(git rev-parse A:a) &&
-	test $(git rev-parse HEAD:c) = $(git rev-parse E:c)
+test_expect_success 'check virtual merge base with nested conflicts' '
+	(
+		cd virtual_merge_base_has_nested_conflicts &&
+
+		MASTER=$(git rev-parse --short master) &&
+		git checkout L3^0 &&
+
+		# Merge must fail; there is a conflict
+		test_must_fail git -c merge.conflictstyle=diff3 merge -s recursive R3^0 &&
+
+		# Make sure the index has the right number of entries
+		git ls-files -s >out &&
+		test_line_count = 3 out &&
+		git ls-files -u >out &&
+		test_line_count = 3 out &&
+		# Ensure we have the correct number of untracked files
+		git ls-files -o >out &&
+		test_line_count = 1 out &&
+
+		# Compare :[23]:content to expected values
+		git rev-parse L1:content R1:content >expect &&
+		git rev-parse :2:content :3:content >actual &&
+		test_cmp expect actual &&
+
+		# Imitate X1 merge base, except without long enough conflict
+		# markers because a subsequent sed will modify them.  Put
+		# result into vmb.
+		git cat-file -p master:content >base &&
+		git cat-file -p L:content >left &&
+		git cat-file -p R:content >right &&
+		cp left merged-once &&
+		test_must_fail git merge-file --diff3 \
+			-L "Temporary merge branch 1" \
+			-L "$MASTER"  \
+			-L "Temporary merge branch 2" \
+			merged-once \
+			base        \
+			right       &&
+		sed -e "s/^\([<|=>]\)/\1\1\1/" merged-once >vmb &&
+
+		# Imitate X2 merge base, overwriting vmb.  Note that we
+		# extend both sets of conflict markers to make them longer
+		# with the sed command.
+		cp left merged-twice &&
+		test_must_fail git merge-file --diff3 \
+			-L "Temporary merge branch 1" \
+			-L "merged common ancestors"  \
+			-L "Temporary merge branch 2" \
+			merged-twice \
+			vmb          \
+			right        &&
+		sed -e "s/^\([<|=>]\)/\1\1\1/" merged-twice >vmb &&
+
+		# Compare :1:content to expected value
+		git cat-file -p :1:content >actual &&
+		test_cmp vmb actual &&
+
+		# Determine expected content in final outer merge, compare to
+		# what the merge generated.
+		cp -f left expect &&
+		test_must_fail git merge-file --diff3                      \
+			-L "HEAD"  -L "merged common ancestors"  -L "R3^0" \
+			expect     vmb                           right     &&
+		test_cmp expect content
+	)
 '
 
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t6040-tracking-info.sh 1.2.3+git2.25.1-1/git/t/t6040-tracking-info.sh
--- 1.2.1+git2.18.0-1/git/t/t6040-tracking-info.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t6040-tracking-info.sh	2020-02-17 04:47:35.000000000 +0000
@@ -38,7 +38,7 @@ test_expect_success setup '
 	advance h
 '
 
-script='s/^..\(b.\) *[0-9a-f]* \(.*\)$/\1 \2/p'
+t6040_script='s/^..\(b.\) *[0-9a-f]* \(.*\)$/\1 \2/p'
 cat >expect <<\EOF
 b1 [ahead 1, behind 1] d
 b2 [ahead 1, behind 1] d
@@ -53,7 +53,7 @@ test_expect_success 'branch -v' '
 		cd test &&
 		git branch -v
 	) |
-	sed -n -e "$script" >actual &&
+	sed -n -e "$t6040_script" >actual &&
 	test_i18ncmp expect actual
 '
 
@@ -71,7 +71,7 @@ test_expect_success 'branch -vv' '
 		cd test &&
 		git branch -vv
 	) |
-	sed -n -e "$script" >actual &&
+	sed -n -e "$t6040_script" >actual &&
 	test_i18ncmp expect actual
 '
 
@@ -160,6 +160,19 @@ test_expect_success 'status -s -b --no-a
 '
 
 cat >expect <<\EOF
+## b1...origin/master [different]
+EOF
+
+test_expect_success 'status.aheadbehind=false status -s -b (diverged from upstream)' '
+	(
+		cd test &&
+		git checkout b1 >/dev/null &&
+		git -c status.aheadbehind=false status -s -b | head -1
+	) >actual &&
+	test_i18ncmp expect actual
+'
+
+cat >expect <<\EOF
 On branch b1
 Your branch and 'origin/master' have diverged,
 and have 1 and 1 different commits each, respectively.
@@ -174,6 +187,15 @@ test_expect_success 'status --long --bra
 	test_i18ncmp expect actual
 '
 
+test_expect_success 'status --long --branch' '
+	(
+		cd test &&
+		git checkout b1 >/dev/null &&
+		git -c status.aheadbehind=true status --long -b | head -3
+	) >actual &&
+	test_i18ncmp expect actual
+'
+
 cat >expect <<\EOF
 On branch b1
 Your branch and 'origin/master' refer to different commits.
@@ -187,6 +209,15 @@ test_expect_success 'status --long --bra
 	) >actual &&
 	test_i18ncmp expect actual
 '
+
+test_expect_success 'status.aheadbehind=false status --long --branch' '
+	(
+		cd test &&
+		git checkout b1 >/dev/null &&
+		git -c status.aheadbehind=false status --long -b | head -2
+	) >actual &&
+	test_i18ncmp expect actual
+'
 
 cat >expect <<\EOF
 ## b5...brokenbase [gone]
diff -pruN 1.2.1+git2.18.0-1/git/t/t6042-merge-rename-corner-cases.sh 1.2.3+git2.25.1-1/git/t/t6042-merge-rename-corner-cases.sh
--- 1.2.1+git2.18.0-1/git/t/t6042-merge-rename-corner-cases.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t6042-merge-rename-corner-cases.sh	2020-02-17 04:47:35.000000000 +0000
@@ -5,32 +5,42 @@ test_description="recursive merge corner
 
 . ./test-lib.sh
 
-test_expect_success 'setup rename/delete + untracked file' '
-	echo "A pretty inscription" >ring &&
-	git add ring &&
-	test_tick &&
-	git commit -m beginning &&
-
-	git branch people &&
-	git checkout -b rename-the-ring &&
-	git mv ring one-ring-to-rule-them-all &&
-	test_tick &&
-	git commit -m fullname &&
-
-	git checkout people &&
-	git rm ring &&
-	echo gollum >owner &&
-	git add owner &&
-	test_tick &&
-	git commit -m track-people-instead-of-objects &&
-	echo "Myyy PRECIOUSSS" >ring
-'
+test_setup_rename_delete_untracked () {
+	test_create_repo rename-delete-untracked &&
+	(
+		cd rename-delete-untracked &&
+
+		echo "A pretty inscription" >ring &&
+		git add ring &&
+		test_tick &&
+		git commit -m beginning &&
+
+		git branch people &&
+		git checkout -b rename-the-ring &&
+		git mv ring one-ring-to-rule-them-all &&
+		test_tick &&
+		git commit -m fullname &&
+
+		git checkout people &&
+		git rm ring &&
+		echo gollum >owner &&
+		git add owner &&
+		test_tick &&
+		git commit -m track-people-instead-of-objects &&
+		echo "Myyy PRECIOUSSS" >ring
+	)
+}
 
 test_expect_success "Does git preserve Gollum's precious artifact?" '
-	test_must_fail git merge -s recursive rename-the-ring &&
-
-	# Make sure git did not delete an untracked file
-	test -f ring
+	test_setup_rename_delete_untracked &&
+	(
+		cd rename-delete-untracked &&
+
+		test_must_fail git merge -s recursive rename-the-ring &&
+
+		# Make sure git did not delete an untracked file
+		test_path_is_file ring
+	)
 '
 
 # Testcase setup for rename/modify/add-source:
@@ -40,97 +50,129 @@ test_expect_success "Does git preserve G
 #
 # We should be able to merge B & C cleanly
 
-test_expect_success 'setup rename/modify/add-source conflict' '
-	git rm -rf . &&
-	git clean -fdqx &&
-	rm -rf .git &&
-	git init &&
-
-	printf "1\n2\n3\n4\n5\n6\n7\n" >a &&
-	git add a &&
-	git commit -m A &&
-	git tag A &&
-
-	git checkout -b B A &&
-	echo 8 >>a &&
-	git add a &&
-	git commit -m B &&
-
-	git checkout -b C A &&
-	git mv a b &&
-	echo something completely different >a &&
-	git add a &&
-	git commit -m C
-'
+test_setup_rename_modify_add_source () {
+	test_create_repo rename-modify-add-source &&
+	(
+		cd rename-modify-add-source &&
+
+		printf "1\n2\n3\n4\n5\n6\n7\n" >a &&
+		git add a &&
+		git commit -m A &&
+		git tag A &&
+
+		git checkout -b B A &&
+		echo 8 >>a &&
+		git add a &&
+		git commit -m B &&
+
+		git checkout -b C A &&
+		git mv a b &&
+		echo something completely different >a &&
+		git add a &&
+		git commit -m C
+	)
+}
 
 test_expect_failure 'rename/modify/add-source conflict resolvable' '
-	git checkout B^0 &&
-
-	git merge -s recursive C^0 &&
-
-	test $(git rev-parse B:a) = $(git rev-parse b) &&
-	test $(git rev-parse C:a) = $(git rev-parse a)
-'
-
-test_expect_success 'setup resolvable conflict missed if rename missed' '
-	git rm -rf . &&
-	git clean -fdqx &&
-	rm -rf .git &&
-	git init &&
-
-	printf "1\n2\n3\n4\n5\n" >a &&
-	echo foo >b &&
-	git add a b &&
-	git commit -m A &&
-	git tag A &&
-
-	git checkout -b B A &&
-	git mv a c &&
-	echo "Completely different content" >a &&
-	git add a &&
-	git commit -m B &&
-
-	git checkout -b C A &&
-	echo 6 >>a &&
-	git add a &&
-	git commit -m C
-'
+	test_setup_rename_modify_add_source &&
+	(
+		cd rename-modify-add-source &&
+
+		git checkout B^0 &&
+
+		git merge -s recursive C^0 &&
+
+		git rev-parse >expect \
+			B:a   C:a     &&
+		git rev-parse >actual \
+			b     c       &&
+		test_cmp expect actual
+	)
+'
+
+test_setup_break_detection_1 () {
+	test_create_repo break-detection-1 &&
+	(
+		cd break-detection-1 &&
+
+		printf "1\n2\n3\n4\n5\n" >a &&
+		echo foo >b &&
+		git add a b &&
+		git commit -m A &&
+		git tag A &&
+
+		git checkout -b B A &&
+		git mv a c &&
+		echo "Completely different content" >a &&
+		git add a &&
+		git commit -m B &&
+
+		git checkout -b C A &&
+		echo 6 >>a &&
+		git add a &&
+		git commit -m C
+	)
+}
 
 test_expect_failure 'conflict caused if rename not detected' '
-	git checkout -q C^0 &&
-	git merge -s recursive B^0 &&
-
-	test 3 -eq $(git ls-files -s | wc -l) &&
-	test 0 -eq $(git ls-files -u | wc -l) &&
-	test 0 -eq $(git ls-files -o | wc -l) &&
-
-	test_line_count = 6 c &&
-	test $(git rev-parse HEAD:a) = $(git rev-parse B:a) &&
-	test $(git rev-parse HEAD:b) = $(git rev-parse A:b)
-'
-
-test_expect_success 'setup conflict resolved wrong if rename missed' '
-	git reset --hard &&
-	git clean -f &&
-
-	git checkout -b D A &&
-	echo 7 >>a &&
-	git add a &&
-	git mv a c &&
-	echo "Completely different content" >a &&
-	git add a &&
-	git commit -m D &&
-
-	git checkout -b E A &&
-	git rm a &&
-	echo "Completely different content" >>a &&
-	git add a &&
-	git commit -m E
-'
+	test_setup_break_detection_1 &&
+	(
+		cd break-detection-1 &&
+
+		git checkout -q C^0 &&
+		git merge -s recursive B^0 &&
+
+		git ls-files -s >out &&
+		test_line_count = 3 out &&
+		git ls-files -u >out &&
+		test_line_count = 0 out &&
+		git ls-files -o >out &&
+		test_line_count = 1 out &&
+
+		test_line_count = 6 c &&
+		git rev-parse >expect \
+			B:a   A:b     &&
+		git rev-parse >actual \
+			:0:a  :0:b    &&
+		test_cmp expect actual
+	)
+'
+
+test_setup_break_detection_2 () {
+	test_create_repo break-detection-2 &&
+	(
+		cd break-detection-2 &&
+
+		printf "1\n2\n3\n4\n5\n" >a &&
+		echo foo >b &&
+		git add a b &&
+		git commit -m A &&
+		git tag A &&
+
+		git checkout -b D A &&
+		echo 7 >>a &&
+		git add a &&
+		git mv a c &&
+		echo "Completely different content" >a &&
+		git add a &&
+		git commit -m D &&
+
+		git checkout -b E A &&
+		git rm a &&
+		echo "Completely different content" >>a &&
+		git add a &&
+		git commit -m E
+	)
+}
 
 test_expect_failure 'missed conflict if rename not detected' '
-	git checkout -q E^0 &&
-	test_must_fail git merge -s recursive D^0
+	test_setup_break_detection_2 &&
+	(
+		cd break-detection-2 &&
+
+		git checkout -q E^0 &&
+		test_must_fail git merge -s recursive D^0
+	)
 '
 
 # Tests for undetected rename/add-source causing a file to erroneously be
@@ -144,199 +186,356 @@ test_expect_failure 'missed conflict if
 #   Commit B: rename a->b
 #   Commit C: rename a->b, add unrelated a
 
-test_expect_success 'setup undetected rename/add-source causes data loss' '
-	git rm -rf . &&
-	git clean -fdqx &&
-	rm -rf .git &&
-	git init &&
-
-	printf "1\n2\n3\n4\n5\n" >a &&
-	git add a &&
-	git commit -m A &&
-	git tag A &&
-
-	git checkout -b B A &&
-	git mv a b &&
-	git commit -m B &&
-
-	git checkout -b C A &&
-	git mv a b &&
-	echo foobar >a &&
-	git add a &&
-	git commit -m C
-'
+test_setup_break_detection_3 () {
+	test_create_repo break-detection-3 &&
+	(
+		cd break-detection-3 &&
+
+		printf "1\n2\n3\n4\n5\n" >a &&
+		git add a &&
+		git commit -m A &&
+		git tag A &&
+
+		git checkout -b B A &&
+		git mv a b &&
+		git commit -m B &&
+
+		git checkout -b C A &&
+		git mv a b &&
+		echo foobar >a &&
+		git add a &&
+		git commit -m C
+	)
+}
 
 test_expect_failure 'detect rename/add-source and preserve all data' '
-	git checkout B^0 &&
-
-	git merge -s recursive C^0 &&
-
-	test 2 -eq $(git ls-files -s | wc -l) &&
-	test 2 -eq $(git ls-files -u | wc -l) &&
-	test 0 -eq $(git ls-files -o | wc -l) &&
-
-	test -f a &&
-	test -f b &&
-
-	test $(git rev-parse HEAD:b) = $(git rev-parse A:a) &&
-	test $(git rev-parse HEAD:a) = $(git rev-parse C:a)
+	test_setup_break_detection_3 &&
+	(
+		cd break-detection-3 &&
+
+		git checkout B^0 &&
+
+		git merge -s recursive C^0 &&
+
+		git ls-files -s >out &&
+		test_line_count = 2 out &&
+		git ls-files -u >out &&
+		test_line_count = 2 out &&
+		git ls-files -o >out &&
+		test_line_count = 1 out &&
+
+		test_path_is_file a &&
+		test_path_is_file b &&
+
+		git rev-parse >expect \
+			A:a   C:a     &&
+		git rev-parse >actual \
+			:0:b  :0:a    &&
+		test_cmp expect actual
+	)
 '
 
 test_expect_failure 'detect rename/add-source and preserve all data, merge other way' '
-	git checkout C^0 &&
-
-	git merge -s recursive B^0 &&
-
-	test 2 -eq $(git ls-files -s | wc -l) &&
-	test 2 -eq $(git ls-files -u | wc -l) &&
-	test 0 -eq $(git ls-files -o | wc -l) &&
-
-	test -f a &&
-	test -f b &&
-
-	test $(git rev-parse HEAD:b) = $(git rev-parse A:a) &&
-	test $(git rev-parse HEAD:a) = $(git rev-parse C:a)
-'
-
-test_expect_success 'setup content merge + rename/directory conflict' '
-	git rm -rf . &&
-	git clean -fdqx &&
-	rm -rf .git &&
-	git init &&
-
-	printf "1\n2\n3\n4\n5\n6\n" >file &&
-	git add file &&
-	test_tick &&
-	git commit -m base &&
-	git tag base &&
-
-	git checkout -b right &&
-	echo 7 >>file &&
-	mkdir newfile &&
-	echo junk >newfile/realfile &&
-	git add file newfile/realfile &&
-	test_tick &&
-	git commit -m right &&
-
-	git checkout -b left-conflict base &&
-	echo 8 >>file &&
-	git add file &&
-	git mv file newfile &&
-	test_tick &&
-	git commit -m left &&
-
-	git checkout -b left-clean base &&
-	echo 0 >newfile &&
-	cat file >>newfile &&
-	git add newfile &&
-	git rm file &&
-	test_tick &&
-	git commit -m left
-'
+	test_setup_break_detection_3 &&
+	(
+		cd break-detection-3 &&
+
+		git checkout C^0 &&
+
+		git merge -s recursive B^0 &&
+
+		git ls-files -s >out &&
+		test_line_count = 2 out &&
+		git ls-files -u >out &&
+		test_line_count = 2 out &&
+		git ls-files -o >out &&
+		test_line_count = 1 out &&
+
+		test_path_is_file a &&
+		test_path_is_file b &&
+
+		git rev-parse >expect \
+			A:a   C:a     &&
+		git rev-parse >actual \
+			:0:b  :0:a    &&
+		test_cmp expect actual
+	)
+'
+
+test_setup_rename_directory () {
+	test_create_repo rename-directory-$1 &&
+	(
+		cd rename-directory-$1 &&
+
+		printf "1\n2\n3\n4\n5\n6\n" >file &&
+		git add file &&
+		test_tick &&
+		git commit -m base &&
+		git tag base &&
+
+		git checkout -b right &&
+		echo 7 >>file &&
+		mkdir newfile &&
+		echo junk >newfile/realfile &&
+		git add file newfile/realfile &&
+		test_tick &&
+		git commit -m right &&
+
+		git checkout -b left-conflict base &&
+		echo 8 >>file &&
+		git add file &&
+		git mv file newfile &&
+		test_tick &&
+		git commit -m left &&
+
+		git checkout -b left-clean base &&
+		echo 0 >newfile &&
+		cat file >>newfile &&
+		git add newfile &&
+		git rm file &&
+		test_tick &&
+		git commit -m left
+	)
+}
 
 test_expect_success 'rename/directory conflict + clean content merge' '
-	git reset --hard &&
-	git reset --hard &&
-	git clean -fdqx &&
-
-	git checkout left-clean^0 &&
-
-	test_must_fail git merge -s recursive right^0 &&
-
-	test 2 -eq $(git ls-files -s | wc -l) &&
-	test 1 -eq $(git ls-files -u | wc -l) &&
-	test 1 -eq $(git ls-files -o | wc -l) &&
-
-	echo 0 >expect &&
-	git cat-file -p base:file >>expect &&
-	echo 7 >>expect &&
-	test_cmp expect newfile~HEAD &&
-
-	test $(git rev-parse :2:newfile) = $(git hash-object expect) &&
-
-	test -f newfile/realfile &&
-	test -f newfile~HEAD
+	test_setup_rename_directory 1a &&
+	(
+		cd rename-directory-1a &&
+
+		git checkout left-clean^0 &&
+
+		test_must_fail git merge -s recursive right^0 &&
+
+		git ls-files -s >out &&
+		test_line_count = 2 out &&
+		git ls-files -u >out &&
+		test_line_count = 1 out &&
+		git ls-files -o >out &&
+		test_line_count = 2 out &&
+
+		echo 0 >expect &&
+		git cat-file -p base:file >>expect &&
+		echo 7 >>expect &&
+		test_cmp expect newfile~HEAD &&
+
+		test $(git rev-parse :2:newfile) = $(git hash-object expect) &&
+
+		test_path_is_file newfile/realfile &&
+		test_path_is_file newfile~HEAD
+	)
 '
 
 test_expect_success 'rename/directory conflict + content merge conflict' '
-	git reset --hard &&
-	git reset --hard &&
-	git clean -fdqx &&
-
-	git checkout left-conflict^0 &&
-
-	test_must_fail git merge -s recursive right^0 &&
-
-	test 4 -eq $(git ls-files -s | wc -l) &&
-	test 3 -eq $(git ls-files -u | wc -l) &&
-	test 1 -eq $(git ls-files -o | wc -l) &&
-
-	git cat-file -p left-conflict:newfile >left &&
-	git cat-file -p base:file    >base &&
-	git cat-file -p right:file   >right &&
-	test_must_fail git merge-file \
-		-L "HEAD:newfile" \
-		-L "" \
-		-L "right^0:file" \
-		left base right &&
-	test_cmp left newfile~HEAD &&
-
-	test $(git rev-parse :1:newfile) = $(git rev-parse base:file) &&
-	test $(git rev-parse :2:newfile) = $(git rev-parse left-conflict:newfile) &&
-	test $(git rev-parse :3:newfile) = $(git rev-parse right:file) &&
-
-	test -f newfile/realfile &&
-	test -f newfile~HEAD
-'
-
-test_expect_success 'setup content merge + rename/directory conflict w/ disappearing dir' '
-	git reset --hard &&
-	git rm -rf . &&
-	git clean -fdqx &&
-	rm -rf .git &&
-	git init &&
-
-	mkdir sub &&
-	printf "1\n2\n3\n4\n5\n6\n" >sub/file &&
-	git add sub/file &&
-	test_tick &&
-	git commit -m base &&
-	git tag base &&
-
-	git checkout -b right &&
-	echo 7 >>sub/file &&
-	git add sub/file &&
-	test_tick &&
-	git commit -m right &&
-
-	git checkout -b left base &&
-	echo 0 >newfile &&
-	cat sub/file >>newfile &&
-	git rm sub/file &&
-	mv newfile sub &&
-	git add sub &&
-	test_tick &&
-	git commit -m left
-'
+	test_setup_rename_directory 1b &&
+	(
+		cd rename-directory-1b &&
+
+		git reset --hard &&
+		git clean -fdqx &&
+
+		git checkout left-conflict^0 &&
+
+		test_must_fail git merge -s recursive right^0 &&
+
+		git ls-files -s >out &&
+		test_line_count = 4 out &&
+		git ls-files -u >out &&
+		test_line_count = 3 out &&
+		git ls-files -o >out &&
+		test_line_count = 2 out &&
+
+		git cat-file -p left-conflict:newfile >left &&
+		git cat-file -p base:file    >base &&
+		git cat-file -p right:file   >right &&
+		test_must_fail git merge-file \
+			-L "HEAD:newfile" \
+			-L "" \
+			-L "right^0:file" \
+			left base right &&
+		test_cmp left newfile~HEAD &&
+
+		git rev-parse >expect                                 \
+			base:file   left-conflict:newfile  right:file &&
+		git rev-parse >actual                                 \
+			:1:newfile  :2:newfile             :3:newfile &&
+		test_cmp expect actual &&
+
+		test_path_is_file newfile/realfile &&
+		test_path_is_file newfile~HEAD
+	)
+'
+
+test_setup_rename_directory_2 () {
+	test_create_repo rename-directory-2 &&
+	(
+		cd rename-directory-2 &&
+
+		mkdir sub &&
+		printf "1\n2\n3\n4\n5\n6\n" >sub/file &&
+		git add sub/file &&
+		test_tick &&
+		git commit -m base &&
+		git tag base &&
+
+		git checkout -b right &&
+		echo 7 >>sub/file &&
+		git add sub/file &&
+		test_tick &&
+		git commit -m right &&
+
+		git checkout -b left base &&
+		echo 0 >newfile &&
+		cat sub/file >>newfile &&
+		git rm sub/file &&
+		mv newfile sub &&
+		git add sub &&
+		test_tick &&
+		git commit -m left
+	)
+}
 
 test_expect_success 'disappearing dir in rename/directory conflict handled' '
-	git reset --hard &&
-	git clean -fdqx &&
-
-	git checkout left^0 &&
-
-	git merge -s recursive right^0 &&
-
-	test 1 -eq $(git ls-files -s | wc -l) &&
-	test 0 -eq $(git ls-files -u | wc -l) &&
-	test 0 -eq $(git ls-files -o | wc -l) &&
-
-	echo 0 >expect &&
-	git cat-file -p base:sub/file >>expect &&
-	echo 7 >>expect &&
-	test_cmp expect sub &&
-
-	test -f sub
+	test_setup_rename_directory_2 &&
+	(
+		cd rename-directory-2 &&
+
+		git checkout left^0 &&
+
+		git merge -s recursive right^0 &&
+
+		git ls-files -s >out &&
+		test_line_count = 1 out &&
+		git ls-files -u >out &&
+		test_line_count = 0 out &&
+		git ls-files -o >out &&
+		test_line_count = 1 out &&
+
+		echo 0 >expect &&
+		git cat-file -p base:sub/file >>expect &&
+		echo 7 >>expect &&
+		test_cmp expect sub &&
+
+		test_path_is_file sub
+	)
+'
+
+# Test for basic rename/add-dest conflict, with rename needing content merge:
+#   Commit O: a
+#   Commit A: rename a->b, modifying b too
+#   Commit B: modify a, add different b
+
+test_setup_rename_with_content_merge_and_add () {
+	test_create_repo rename-with-content-merge-and-add-$1 &&
+	(
+		cd rename-with-content-merge-and-add-$1 &&
+
+		test_seq 1 5 >a &&
+		git add a &&
+		git commit -m O &&
+		git tag O &&
+
+		git checkout -b A O &&
+		git mv a b &&
+		test_seq 0 5 >b &&
+		git add b &&
+		git commit -m A &&
+
+		git checkout -b B O &&
+		echo 6 >>a &&
+		echo hello world >b &&
+		git add a b &&
+		git commit -m B
+	)
+}
+
+test_expect_success 'handle rename-with-content-merge vs. add' '
+	test_setup_rename_with_content_merge_and_add AB &&
+	(
+		cd rename-with-content-merge-and-add-AB &&
+
+		git checkout A^0 &&
+
+		test_must_fail git merge -s recursive B^0 >out &&
+		test_i18ngrep "CONFLICT (rename/add)" out &&
+
+		git ls-files -s >out &&
+		test_line_count = 2 out &&
+		git ls-files -u >out &&
+		test_line_count = 2 out &&
+		# Also, make sure both unmerged entries are for "b"
+		git ls-files -u b >out &&
+		test_line_count = 2 out &&
+		git ls-files -o >out &&
+		test_line_count = 1 out &&
+
+		test_path_is_missing a &&
+		test_path_is_file b &&
+
+		test_seq 0 6 >tmp &&
+		git hash-object tmp >expect &&
+		git rev-parse B:b >>expect &&
+		git rev-parse >actual  \
+			:2:b    :3:b   &&
+		test_cmp expect actual &&
+
+		# Test that the two-way merge in b is as expected
+		git cat-file -p :2:b >>ours &&
+		git cat-file -p :3:b >>theirs &&
+		>empty &&
+		test_must_fail git merge-file \
+			-L "HEAD" \
+			-L "" \
+			-L "B^0" \
+			ours empty theirs &&
+		test_cmp ours b
+	)
+'
+
+test_expect_success 'handle rename-with-content-merge vs. add, merge other way' '
+	test_setup_rename_with_content_merge_and_add BA &&
+	(
+		cd rename-with-content-merge-and-add-BA &&
+
+		git reset --hard &&
+		git clean -fdx &&
+
+		git checkout B^0 &&
+
+		test_must_fail git merge -s recursive A^0 >out &&
+		test_i18ngrep "CONFLICT (rename/add)" out &&
+
+		git ls-files -s >out &&
+		test_line_count = 2 out &&
+		git ls-files -u >out &&
+		test_line_count = 2 out &&
+		# Also, make sure both unmerged entries are for "b"
+		git ls-files -u b >out &&
+		test_line_count = 2 out &&
+		git ls-files -o >out &&
+		test_line_count = 1 out &&
+
+		test_path_is_missing a &&
+		test_path_is_file b &&
+
+		test_seq 0 6 >tmp &&
+		git rev-parse B:b >expect &&
+		git hash-object tmp >>expect &&
+		git rev-parse >actual  \
+			:2:b    :3:b   &&
+		test_cmp expect actual &&
+
+		# Test that the two-way merge in b is as expected
+		git cat-file -p :2:b >>ours &&
+		git cat-file -p :3:b >>theirs &&
+		>empty &&
+		test_must_fail git merge-file \
+			-L "HEAD" \
+			-L "" \
+			-L "A^0" \
+			ours empty theirs &&
+		test_cmp ours b
+	)
 '
 
 # Test for all kinds of things that can go wrong with rename/rename (2to1):
@@ -351,94 +550,127 @@ test_expect_success 'disappearing dir in
 #   * The working copy should have two files, both of form c~<unique>; does it?
 #   * Nothing else should be present.  Is anything?
 
-test_expect_success 'setup rename/rename (2to1) + modify/modify' '
-	git rm -rf . &&
-	git clean -fdqx &&
-	rm -rf .git &&
-	git init &&
-
-	printf "1\n2\n3\n4\n5\n" >a &&
-	printf "5\n4\n3\n2\n1\n" >b &&
-	git add a b &&
-	git commit -m A &&
-	git tag A &&
-
-	git checkout -b B A &&
-	git mv a c &&
-	echo 0 >>b &&
-	git add b &&
-	git commit -m B &&
-
-	git checkout -b C A &&
-	git mv b c &&
-	echo 6 >>a &&
-	git add a &&
-	git commit -m C
-'
+test_setup_rename_rename_2to1 () {
+	test_create_repo rename-rename-2to1 &&
+	(
+		cd rename-rename-2to1 &&
+
+		printf "1\n2\n3\n4\n5\n" >a &&
+		printf "5\n4\n3\n2\n1\n" >b &&
+		git add a b &&
+		git commit -m A &&
+		git tag A &&
+
+		git checkout -b B A &&
+		git mv a c &&
+		echo 0 >>b &&
+		git add b &&
+		git commit -m B &&
+
+		git checkout -b C A &&
+		git mv b c &&
+		echo 6 >>a &&
+		git add a &&
+		git commit -m C
+	)
+}
 
 test_expect_success 'handle rename/rename (2to1) conflict correctly' '
-	git checkout B^0 &&
-
-	test_must_fail git merge -s recursive C^0 >out &&
-	test_i18ngrep "CONFLICT (rename/rename)" out &&
-
-	test 2 -eq $(git ls-files -s | wc -l) &&
-	test 2 -eq $(git ls-files -u | wc -l) &&
-	test 2 -eq $(git ls-files -u c | wc -l) &&
-	test 3 -eq $(git ls-files -o | wc -l) &&
-
-	test ! -f a &&
-	test ! -f b &&
-	test -f c~HEAD &&
-	test -f c~C^0 &&
-
-	test $(git hash-object c~HEAD) = $(git rev-parse C:a) &&
-	test $(git hash-object c~C^0) = $(git rev-parse B:b)
+	test_setup_rename_rename_2to1 &&
+	(
+		cd rename-rename-2to1 &&
+
+		git checkout B^0 &&
+
+		test_must_fail git merge -s recursive C^0 >out &&
+		test_i18ngrep "CONFLICT (rename/rename)" out &&
+
+		git ls-files -s >out &&
+		test_line_count = 2 out &&
+		git ls-files -u >out &&
+		test_line_count = 2 out &&
+		git ls-files -u c >out &&
+		test_line_count = 2 out &&
+		git ls-files -o >out &&
+		test_line_count = 1 out &&
+
+		test_path_is_missing a &&
+		test_path_is_missing b &&
+
+		git rev-parse >expect  \
+			C:a     B:b    &&
+		git rev-parse >actual  \
+			:2:c    :3:c   &&
+		test_cmp expect actual &&
+
+		# Test that the two-way merge in new_a is as expected
+		git cat-file -p :2:c >>ours &&
+		git cat-file -p :3:c >>theirs &&
+		>empty &&
+		test_must_fail git merge-file \
+			-L "HEAD" \
+			-L "" \
+			-L "C^0" \
+			ours empty theirs &&
+		git hash-object c >actual &&
+		git hash-object ours >expect &&
+		test_cmp expect actual
+	)
 '
 
 # Testcase setup for simple rename/rename (1to2) conflict:
 #   Commit A: new file: a
 #   Commit B: rename a->b
 #   Commit C: rename a->c
-test_expect_success 'setup simple rename/rename (1to2) conflict' '
-	git rm -rf . &&
-	git clean -fdqx &&
-	rm -rf .git &&
-	git init &&
-
-	echo stuff >a &&
-	git add a &&
-	test_tick &&
-	git commit -m A &&
-	git tag A &&
-
-	git checkout -b B A &&
-	git mv a b &&
-	test_tick &&
-	git commit -m B &&
-
-	git checkout -b C A &&
-	git mv a c &&
-	test_tick &&
-	git commit -m C
-'
+test_setup_rename_rename_1to2 () {
+	test_create_repo rename-rename-1to2 &&
+	(
+		cd rename-rename-1to2 &&
+
+		echo stuff >a &&
+		git add a &&
+		test_tick &&
+		git commit -m A &&
+		git tag A &&
+
+		git checkout -b B A &&
+		git mv a b &&
+		test_tick &&
+		git commit -m B &&
+
+		git checkout -b C A &&
+		git mv a c &&
+		test_tick &&
+		git commit -m C
+	)
+}
 
 test_expect_success 'merge has correct working tree contents' '
-	git checkout C^0 &&
-
-	test_must_fail git merge -s recursive B^0 &&
-
-	test 3 -eq $(git ls-files -s | wc -l) &&
-	test 3 -eq $(git ls-files -u | wc -l) &&
-	test 0 -eq $(git ls-files -o | wc -l) &&
-
-	test $(git rev-parse :1:a) = $(git rev-parse A:a) &&
-	test $(git rev-parse :3:b) = $(git rev-parse A:a) &&
-	test $(git rev-parse :2:c) = $(git rev-parse A:a) &&
-
-	test ! -f a &&
-	test $(git hash-object b) = $(git rev-parse A:a) &&
-	test $(git hash-object c) = $(git rev-parse A:a)
+	test_setup_rename_rename_1to2 &&
+	(
+		cd rename-rename-1to2 &&
+
+		git checkout C^0 &&
+
+		test_must_fail git merge -s recursive B^0 &&
+
+		git ls-files -s >out &&
+		test_line_count = 3 out &&
+		git ls-files -u >out &&
+		test_line_count = 3 out &&
+		git ls-files -o >out &&
+		test_line_count = 1 out &&
+
+		test_path_is_missing a &&
+		git rev-parse >expect   \
+			A:a   A:a   A:a \
+			A:a   A:a       &&
+		git rev-parse >actual    \
+			:1:a  :3:b  :2:c &&
+		git hash-object >>actual \
+			b     c          &&
+		test_cmp expect actual
+	)
 '
 
 # Testcase setup for rename/rename(1to2)/add-source conflict:
@@ -448,131 +680,703 @@ test_expect_success 'merge has correct w
 #
 # Merging of B & C should NOT be clean; there's a rename/rename conflict
 
-test_expect_success 'setup rename/rename(1to2)/add-source conflict' '
-	git rm -rf . &&
-	git clean -fdqx &&
-	rm -rf .git &&
-	git init &&
-
-	printf "1\n2\n3\n4\n5\n6\n7\n" >a &&
-	git add a &&
-	git commit -m A &&
-	git tag A &&
-
-	git checkout -b B A &&
-	git mv a b &&
-	git commit -m B &&
-
-	git checkout -b C A &&
-	git mv a c &&
-	echo something completely different >a &&
-	git add a &&
-	git commit -m C
-'
+test_setup_rename_rename_1to2_add_source_1 () {
+	test_create_repo rename-rename-1to2-add-source-1 &&
+	(
+		cd rename-rename-1to2-add-source-1 &&
+
+		printf "1\n2\n3\n4\n5\n6\n7\n" >a &&
+		git add a &&
+		git commit -m A &&
+		git tag A &&
+
+		git checkout -b B A &&
+		git mv a b &&
+		git commit -m B &&
+
+		git checkout -b C A &&
+		git mv a c &&
+		echo something completely different >a &&
+		git add a &&
+		git commit -m C
+	)
+}
 
 test_expect_failure 'detect conflict with rename/rename(1to2)/add-source merge' '
-	git checkout B^0 &&
-
-	test_must_fail git merge -s recursive C^0 &&
-
-	test 4 -eq $(git ls-files -s | wc -l) &&
-	test 0 -eq $(git ls-files -o | wc -l) &&
-
-	test $(git rev-parse 3:a) = $(git rev-parse C:a) &&
-	test $(git rev-parse 1:a) = $(git rev-parse A:a) &&
-	test $(git rev-parse 2:b) = $(git rev-parse B:b) &&
-	test $(git rev-parse 3:c) = $(git rev-parse C:c) &&
-
-	test -f a &&
-	test -f b &&
-	test -f c
-'
-
-test_expect_success 'setup rename/rename(1to2)/add-source resolvable conflict' '
-	git rm -rf . &&
-	git clean -fdqx &&
-	rm -rf .git &&
-	git init &&
-
-	>a &&
-	git add a &&
-	test_tick &&
-	git commit -m base &&
-	git tag A &&
-
-	git checkout -b B A &&
-	git mv a b &&
-	test_tick &&
-	git commit -m one &&
-
-	git checkout -b C A &&
-	git mv a b &&
-	echo important-info >a &&
-	git add a &&
-	test_tick &&
-	git commit -m two
-'
+	test_setup_rename_rename_1to2_add_source_1 &&
+	(
+		cd rename-rename-1to2-add-source-1 &&
+
+		git checkout B^0 &&
+
+		test_must_fail git merge -s recursive C^0 &&
+
+		git ls-files -s >out &&
+		test_line_count = 4 out &&
+		git ls-files -o >out &&
+		test_line_count = 1 out &&
+
+		git rev-parse >expect         \
+			C:a   A:a   B:b   C:C &&
+		git rev-parse >actual          \
+			:3:a  :1:a  :2:b  :3:c &&
+		test_cmp expect actual &&
+
+		test_path_is_file a &&
+		test_path_is_file b &&
+		test_path_is_file c
+	)
+'
+
+test_setup_rename_rename_1to2_add_source_2 () {
+	test_create_repo rename-rename-1to2-add-source-2 &&
+	(
+		cd rename-rename-1to2-add-source-2 &&
+
+		>a &&
+		git add a &&
+		test_tick &&
+		git commit -m base &&
+		git tag A &&
+
+		git checkout -b B A &&
+		git mv a b &&
+		test_tick &&
+		git commit -m one &&
+
+		git checkout -b C A &&
+		git mv a b &&
+		echo important-info >a &&
+		git add a &&
+		test_tick &&
+		git commit -m two
+	)
+}
 
 test_expect_failure 'rename/rename/add-source still tracks new a file' '
-	git checkout C^0 &&
-	git merge -s recursive B^0 &&
-
-	test 2 -eq $(git ls-files -s | wc -l) &&
-	test 0 -eq $(git ls-files -o | wc -l) &&
-
-	test $(git rev-parse HEAD:a) = $(git rev-parse C:a) &&
-	test $(git rev-parse HEAD:b) = $(git rev-parse A:a)
-'
-
-test_expect_success 'setup rename/rename(1to2)/add-dest conflict' '
-	git rm -rf . &&
-	git clean -fdqx &&
-	rm -rf .git &&
-	git init &&
-
-	echo stuff >a &&
-	git add a &&
-	test_tick &&
-	git commit -m base &&
-	git tag A &&
-
-	git checkout -b B A &&
-	git mv a b &&
-	echo precious-data >c &&
-	git add c &&
-	test_tick &&
-	git commit -m one &&
-
-	git checkout -b C A &&
-	git mv a c &&
-	echo important-info >b &&
-	git add b &&
-	test_tick &&
-	git commit -m two
-'
+	test_setup_rename_rename_1to2_add_source_2 &&
+	(
+		cd rename-rename-1to2-add-source-2 &&
+
+		git checkout C^0 &&
+		git merge -s recursive B^0 &&
+
+		git ls-files -s >out &&
+		test_line_count = 2 out &&
+		git ls-files -o >out &&
+		test_line_count = 1 out &&
+
+		git rev-parse >expect \
+			C:a   A:a     &&
+		git rev-parse >actual \
+			:0:a  :0:b    &&
+		test_cmp expect actual
+	)
+'
+
+test_setup_rename_rename_1to2_add_dest () {
+	test_create_repo rename-rename-1to2-add-dest &&
+	(
+		cd rename-rename-1to2-add-dest &&
+
+		echo stuff >a &&
+		git add a &&
+		test_tick &&
+		git commit -m base &&
+		git tag A &&
+
+		git checkout -b B A &&
+		git mv a b &&
+		echo precious-data >c &&
+		git add c &&
+		test_tick &&
+		git commit -m one &&
+
+		git checkout -b C A &&
+		git mv a c &&
+		echo important-info >b &&
+		git add b &&
+		test_tick &&
+		git commit -m two
+	)
+}
 
 test_expect_success 'rename/rename/add-dest merge still knows about conflicting file versions' '
-	git checkout C^0 &&
-	test_must_fail git merge -s recursive B^0 &&
-
-	test 5 -eq $(git ls-files -s | wc -l) &&
-	test 2 -eq $(git ls-files -u b | wc -l) &&
-	test 2 -eq $(git ls-files -u c | wc -l) &&
-	test 4 -eq $(git ls-files -o | wc -l) &&
-
-	test $(git rev-parse :1:a) = $(git rev-parse A:a) &&
-	test $(git rev-parse :2:b) = $(git rev-parse C:b) &&
-	test $(git rev-parse :3:b) = $(git rev-parse B:b) &&
-	test $(git rev-parse :2:c) = $(git rev-parse C:c) &&
-	test $(git rev-parse :3:c) = $(git rev-parse B:c) &&
-
-	test $(git hash-object c~HEAD) = $(git rev-parse C:c) &&
-	test $(git hash-object c~B\^0) = $(git rev-parse B:c) &&
-	test $(git hash-object b~HEAD) = $(git rev-parse C:b) &&
-	test $(git hash-object b~B\^0) = $(git rev-parse B:b) &&
-
-	test ! -f b &&
-	test ! -f c
+	test_setup_rename_rename_1to2_add_dest &&
+	(
+		cd rename-rename-1to2-add-dest &&
+
+		git checkout C^0 &&
+		test_must_fail git merge -s recursive B^0 &&
+
+		git ls-files -s >out &&
+		test_line_count = 5 out &&
+		git ls-files -u b >out &&
+		test_line_count = 2 out &&
+		git ls-files -u c >out &&
+		test_line_count = 2 out &&
+		git ls-files -o >out &&
+		test_line_count = 1 out &&
+
+		git rev-parse >expect               \
+			A:a   C:b   B:b   C:c   B:c &&
+		git rev-parse >actual                \
+			:1:a  :2:b  :3:b  :2:c  :3:c &&
+		test_cmp expect actual &&
+
+		# Record some contents for re-doing merges
+		git cat-file -p A:a >stuff &&
+		git cat-file -p C:b >important_info &&
+		git cat-file -p B:c >precious_data &&
+		>empty &&
+
+		# Test the merge in b
+		test_must_fail git merge-file \
+			-L "HEAD" \
+			-L "" \
+			-L "B^0" \
+			important_info empty stuff &&
+		test_cmp important_info b &&
+
+		# Test the merge in c
+		test_must_fail git merge-file \
+			-L "HEAD" \
+			-L "" \
+			-L "B^0" \
+			stuff empty precious_data &&
+		test_cmp stuff c
+	)
+'
+
+# Testcase rad, rename/add/delete
+#   Commit O: foo
+#   Commit A: rm foo, add different bar
+#   Commit B: rename foo->bar
+#   Expected: CONFLICT (rename/add/delete), two-way merged bar
+
+test_setup_rad () {
+	test_create_repo rad &&
+	(
+		cd rad &&
+		echo "original file" >foo &&
+		git add foo &&
+		git commit -m "original" &&
+
+		git branch O &&
+		git branch A &&
+		git branch B &&
+
+		git checkout A &&
+		git rm foo &&
+		echo "different file" >bar &&
+		git add bar &&
+		git commit -m "Remove foo, add bar" &&
+
+		git checkout B &&
+		git mv foo bar &&
+		git commit -m "rename foo to bar"
+	)
+}
+
+test_expect_failure 'rad-check: rename/add/delete conflict' '
+	test_setup_rad &&
+	(
+		cd rad &&
+
+		git checkout B^0 &&
+		test_must_fail git merge -s recursive A^0 >out 2>err &&
+
+		# Not sure whether the output should contain just one
+		# "CONFLICT (rename/add/delete)" line, or if it should break
+		# it into a pair of "CONFLICT (rename/delete)" and
+		# "CONFLICT (rename/add)"; allow for either.
+		test_i18ngrep "CONFLICT (rename.*add)" out &&
+		test_i18ngrep "CONFLICT (rename.*delete)" out &&
+		test_must_be_empty err &&
+
+		git ls-files -s >file_count &&
+		test_line_count = 2 file_count &&
+		git ls-files -u >file_count &&
+		test_line_count = 2 file_count &&
+		git ls-files -o >file_count &&
+		test_line_count = 2 file_count &&
+
+		git rev-parse >actual \
+			:2:bar :3:bar &&
+		git rev-parse >expect \
+			B:bar  A:bar  &&
+
+		test_cmp file_is_missing foo &&
+		# bar should have two-way merged contents of the different
+		# versions of bar; check that content from both sides is
+		# present.
+		grep original bar &&
+		grep different bar
+	)
+'
+
+# Testcase rrdd, rename/rename(2to1)/delete/delete
+#   Commit O: foo, bar
+#   Commit A: rename foo->baz, rm bar
+#   Commit B: rename bar->baz, rm foo
+#   Expected: CONFLICT (rename/rename/delete/delete), two-way merged baz
+
+test_setup_rrdd () {
+	test_create_repo rrdd &&
+	(
+		cd rrdd &&
+		echo foo >foo &&
+		echo bar >bar &&
+		git add foo bar &&
+		git commit -m O &&
+
+		git branch O &&
+		git branch A &&
+		git branch B &&
+
+		git checkout A &&
+		git mv foo baz &&
+		git rm bar &&
+		git commit -m "Rename foo, remove bar" &&
+
+		git checkout B &&
+		git mv bar baz &&
+		git rm foo &&
+		git commit -m "Rename bar, remove foo"
+	)
+}
+
+test_expect_failure 'rrdd-check: rename/rename(2to1)/delete/delete conflict' '
+	test_setup_rrdd &&
+	(
+		cd rrdd &&
+
+		git checkout A^0 &&
+		test_must_fail git merge -s recursive B^0 >out 2>err &&
+
+		# Not sure whether the output should contain just one
+		# "CONFLICT (rename/rename/delete/delete)" line, or if it
+		# should break it into three: "CONFLICT (rename/rename)" and
+		# two "CONFLICT (rename/delete)" lines; allow for either.
+		test_i18ngrep "CONFLICT (rename/rename)" out &&
+		test_i18ngrep "CONFLICT (rename.*delete)" out &&
+		test_must_be_empty err &&
+
+		git ls-files -s >file_count &&
+		test_line_count = 2 file_count &&
+		git ls-files -u >file_count &&
+		test_line_count = 2 file_count &&
+		git ls-files -o >file_count &&
+		test_line_count = 2 file_count &&
+
+		git rev-parse >actual \
+			:2:baz :3:baz &&
+		git rev-parse >expect \
+			O:foo  O:bar  &&
+
+		test_cmp file_is_missing foo &&
+		test_cmp file_is_missing bar &&
+		# baz should have two-way merged contents of the original
+		# contents of foo and bar; check that content from both sides
+		# is present.
+		grep foo baz &&
+		grep bar baz
+	)
+'
+
+# Testcase mod6, chains of rename/rename(1to2) and rename/rename(2to1)
+#   Commit O: one,      three,       five
+#   Commit A: one->two, three->four, five->six
+#   Commit B: one->six, three->two,  five->four
+#   Expected: six CONFLICT(rename/rename) messages, each path in two of the
+#             multi-way merged contents found in two, four, six
+
+test_setup_mod6 () {
+	test_create_repo mod6 &&
+	(
+		cd mod6 &&
+		test_seq 11 19 >one &&
+		test_seq 31 39 >three &&
+		test_seq 51 59 >five &&
+		git add . &&
+		test_tick &&
+		git commit -m "O" &&
+
+		git branch O &&
+		git branch A &&
+		git branch B &&
+
+		git checkout A &&
+		test_seq 10 19 >one &&
+		echo 40        >>three &&
+		git add one three &&
+		git mv  one   two  &&
+		git mv  three four &&
+		git mv  five  six  &&
+		test_tick &&
+		git commit -m "A" &&
+
+		git checkout B &&
+		echo 20    >>one       &&
+		echo forty >>three     &&
+		echo 60    >>five      &&
+		git add one three five &&
+		git mv  one   six  &&
+		git mv  three two  &&
+		git mv  five  four &&
+		test_tick &&
+		git commit -m "B"
+	)
+}
+
+test_expect_failure 'mod6-check: chains of rename/rename(1to2) and rename/rename(2to1)' '
+	test_setup_mod6 &&
+	(
+		cd mod6 &&
+
+		git checkout A^0 &&
+
+		test_must_fail git merge -s recursive B^0 >out 2>err &&
+
+		test_i18ngrep "CONFLICT (rename/rename)" out &&
+		test_must_be_empty err &&
+
+		git ls-files -s >file_count &&
+		test_line_count = 6 file_count &&
+		git ls-files -u >file_count &&
+		test_line_count = 6 file_count &&
+		git ls-files -o >file_count &&
+		test_line_count = 3 file_count &&
+
+		test_seq 10 20 >merged-one &&
+		test_seq 51 60 >merged-five &&
+		# Determine what the merge of three would give us.
+		test_seq 30 40 >three-side-A &&
+		test_seq 31 39 >three-side-B &&
+		echo forty >three-side-B &&
+		>empty &&
+		test_must_fail git merge-file \
+			-L "HEAD" \
+			-L "" \
+			-L "B^0" \
+			three-side-A empty three-side-B &&
+		sed -e "s/^\([<=>]\)/\1\1\1/" three-side-A >merged-three &&
+
+		# Verify the index is as expected
+		git rev-parse >actual         \
+			:2:two       :3:two   \
+			:2:four      :3:four  \
+			:2:six       :3:six   &&
+		git hash-object >expect           \
+			merged-one   merged-three \
+			merged-three merged-five  \
+			merged-five  merged-one   &&
+		test_cmp expect actual &&
+
+		git cat-file -p :2:two >expect &&
+		git cat-file -p :3:two >other &&
+		test_must_fail git merge-file    \
+			-L "HEAD"  -L ""  -L "B^0" \
+			expect     empty  other &&
+		test_cmp expect two &&
+
+		git cat-file -p :2:four >expect &&
+		git cat-file -p :3:four >other &&
+		test_must_fail git merge-file    \
+			-L "HEAD"  -L ""  -L "B^0" \
+			expect     empty  other &&
+		test_cmp expect four &&
+
+		git cat-file -p :2:six >expect &&
+		git cat-file -p :3:six >other &&
+		test_must_fail git merge-file    \
+			-L "HEAD"  -L ""  -L "B^0" \
+			expect     empty  other &&
+		test_cmp expect six
+	)
+'
+
+test_conflicts_with_adds_and_renames() {
+	sideL=$1
+	sideR=$2
+
+	# Setup:
+	#          L
+	#         / \
+	#   master   ?
+	#         \ /
+	#          R
+	#
+	# Where:
+	#   Both L and R have files named 'three' which collide.  Each of
+	#   the colliding files could have been involved in a rename, in
+	#   which case there was a file named 'one' or 'two' that was
+	#   modified on the opposite side of history and renamed into the
+	#   collision on this side of history.
+	#
+	# Questions:
+	#   1) The index should contain both a stage 2 and stage 3 entry
+	#      for the colliding file.  Does it?
+	#   2) When renames are involved, the content merges are clean, so
+	#      the index should reflect the content merges, not merely the
+	#      version of the colliding file from the prior commit.  Does
+	#      it?
+	#   3) There should be a file in the worktree named 'three'
+	#      containing the two-way merged contents of the content-merged
+	#      versions of 'three' from each of the two colliding
+	#      files.  Is it present?
+	#   4) There should not be any three~* files in the working
+	#      tree
+	test_setup_collision_conflict () {
+	#test_expect_success "setup simple $sideL/$sideR conflict" '
+		test_create_repo simple_${sideL}_${sideR} &&
+		(
+			cd simple_${sideL}_${sideR} &&
+
+			# Create some related files now
+			for i in $(test_seq 1 10)
+			do
+				echo Random base content line $i
+			done >file_v1 &&
+			cp file_v1 file_v2 &&
+			echo modification >>file_v2 &&
+
+			cp file_v1 file_v3 &&
+			echo more stuff >>file_v3 &&
+			cp file_v3 file_v4 &&
+			echo yet more stuff >>file_v4 &&
+
+			# Use a tag to record both these files for simple
+			# access, and clean out these untracked files
+			git tag file_v1 $(git hash-object -w file_v1) &&
+			git tag file_v2 $(git hash-object -w file_v2) &&
+			git tag file_v3 $(git hash-object -w file_v3) &&
+			git tag file_v4 $(git hash-object -w file_v4) &&
+			git clean -f &&
+
+			# Setup original commit (or merge-base), consisting of
+			# files named "one" and "two" if renames were involved.
+			touch irrelevant_file &&
+			git add irrelevant_file &&
+			if [ $sideL = "rename" ]
+			then
+				git show file_v1 >one &&
+				git add one
+			fi &&
+			if [ $sideR = "rename" ]
+			then
+				git show file_v3 >two &&
+				git add two
+			fi &&
+			test_tick && git commit -m initial &&
+
+			git branch L &&
+			git branch R &&
+
+			# Handle the left side
+			git checkout L &&
+			if [ $sideL = "rename" ]
+			then
+				git mv one three
+			else
+				git show file_v2 >three &&
+				git add three
+			fi &&
+			if [ $sideR = "rename" ]
+			then
+				git show file_v4 >two &&
+				git add two
+			fi &&
+			test_tick && git commit -m L &&
+
+			# Handle the right side
+			git checkout R &&
+			if [ $sideL = "rename" ]
+			then
+				git show file_v2 >one &&
+				git add one
+			fi &&
+			if [ $sideR = "rename" ]
+			then
+				git mv two three
+			else
+				git show file_v4 >three &&
+				git add three
+			fi &&
+			test_tick && git commit -m R
+		)
+	#'
+	}
+
+	test_expect_success "check simple $sideL/$sideR conflict" '
+		test_setup_collision_conflict &&
+		(
+			cd simple_${sideL}_${sideR} &&
+
+			git checkout L^0 &&
+
+			# Merge must fail; there is a conflict
+			test_must_fail git merge -s recursive R^0 &&
+
+			# Make sure the index has the right number of entries
+			git ls-files -s >out &&
+			test_line_count = 3 out &&
+			git ls-files -u >out &&
+			test_line_count = 2 out &&
+			# Ensure we have the correct number of untracked files
+			git ls-files -o >out &&
+			test_line_count = 1 out &&
+
+			# Nothing should have touched irrelevant_file
+			git rev-parse >actual      \
+				:0:irrelevant_file \
+				:2:three           \
+				:3:three           &&
+			git rev-parse >expected        \
+				master:irrelevant_file \
+				file_v2                \
+				file_v4                &&
+			test_cmp expected actual &&
+
+			# Make sure we have the correct merged contents for
+			# three
+			git show file_v1 >expected &&
+			cat <<-\EOF >>expected &&
+			<<<<<<< HEAD
+			modification
+			=======
+			more stuff
+			yet more stuff
+			>>>>>>> R^0
+			EOF
+
+			test_cmp expected three
+		)
+	'
+}
+
+test_conflicts_with_adds_and_renames rename rename
+test_conflicts_with_adds_and_renames rename add
+test_conflicts_with_adds_and_renames add    rename
+test_conflicts_with_adds_and_renames add    add
+
+# Setup:
+#          L
+#         / \
+#   master   ?
+#         \ /
+#          R
+#
+# Where:
+#   master has two files, named 'one' and 'two'.
+#   branches L and R both modify 'one', in conflicting ways.
+#   branches L and R both modify 'two', in conflicting ways.
+#   branch L also renames 'one' to 'three'.
+#   branch R also renames 'two' to 'three'.
+#
+#   So, we have four different conflicting files that all end up at path
+#   'three'.
+test_setup_nested_conflicts_from_rename_rename () {
+	test_create_repo nested_conflicts_from_rename_rename &&
+	(
+		cd nested_conflicts_from_rename_rename &&
+
+		# Create some related files now
+		for i in $(test_seq 1 10)
+		do
+			echo Random base content line $i
+		done >file_v1 &&
+
+		cp file_v1 file_v2 &&
+		cp file_v1 file_v3 &&
+		cp file_v1 file_v4 &&
+		cp file_v1 file_v5 &&
+		cp file_v1 file_v6 &&
+
+		echo one  >>file_v1 &&
+		echo uno  >>file_v2 &&
+		echo eins >>file_v3 &&
+
+		echo two  >>file_v4 &&
+		echo dos  >>file_v5 &&
+		echo zwei >>file_v6 &&
+
+		# Setup original commit (or merge-base), consisting of
+		# files named "one" and "two".
+		mv file_v1 one &&
+		mv file_v4 two &&
+		git add one two &&
+		test_tick && git commit -m english &&
+
+		git branch L &&
+		git branch R &&
+
+		# Handle the left side
+		git checkout L &&
+		git rm one two &&
+		mv -f file_v2 three &&
+		mv -f file_v5 two &&
+		git add two three &&
+		test_tick && git commit -m spanish &&
+
+		# Handle the right side
+		git checkout R &&
+		git rm one two &&
+		mv -f file_v3 one &&
+		mv -f file_v6 three &&
+		git add one three &&
+		test_tick && git commit -m german
+	)
+}
+
+test_expect_success 'check nested conflicts from rename/rename(2to1)' '
+	test_setup_nested_conflicts_from_rename_rename &&
+	(
+		cd nested_conflicts_from_rename_rename &&
+
+		git checkout L^0 &&
+
+		# Merge must fail; there is a conflict
+		test_must_fail git merge -s recursive R^0 &&
+
+		# Make sure the index has the right number of entries
+		git ls-files -s >out &&
+		test_line_count = 2 out &&
+		git ls-files -u >out &&
+		test_line_count = 2 out &&
+		# Ensure we have the correct number of untracked files
+		git ls-files -o >out &&
+		test_line_count = 1 out &&
+
+		# Compare :2:three to expected values
+		git cat-file -p master:one >base &&
+		git cat-file -p L:three >ours &&
+		git cat-file -p R:one >theirs &&
+		test_must_fail git merge-file    \
+			-L "HEAD:three"  -L ""  -L "R^0:one" \
+			ours             base   theirs &&
+		sed -e "s/^\([<=>]\)/\1\1/" ours >L-three &&
+		git cat-file -p :2:three >expect &&
+		test_cmp expect L-three &&
+
+		# Compare :2:three to expected values
+		git cat-file -p master:two >base &&
+		git cat-file -p L:two >ours &&
+		git cat-file -p R:three >theirs &&
+		test_must_fail git merge-file    \
+			-L "HEAD:two"  -L ""  -L "R^0:three" \
+			ours           base   theirs &&
+		sed -e "s/^\([<=>]\)/\1\1/" ours >R-three &&
+		git cat-file -p :3:three >expect &&
+		test_cmp expect R-three &&
+
+		# Compare three to expected contents
+		>empty &&
+		test_must_fail git merge-file    \
+			-L "HEAD"  -L ""  -L "R^0" \
+			L-three    empty  R-three &&
+		test_cmp three L-three
+	)
 '
 
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t6043-merge-rename-directories.sh 1.2.3+git2.25.1-1/git/t/t6043-merge-rename-directories.sh
--- 1.2.1+git2.18.0-1/git/t/t6043-merge-rename-directories.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t6043-merge-rename-directories.sh	2020-02-17 04:47:35.000000000 +0000
@@ -38,7 +38,7 @@ test_description="recursive merge with d
 #   Commit B: z/{b,c,d,e/f}
 #   Expected: y/{b,c,d,e/f}
 
-test_expect_success '1a-setup: Simple directory rename detection' '
+test_setup_1a () {
 	test_create_repo 1a &&
 	(
 		cd 1a &&
@@ -67,15 +67,16 @@ test_expect_success '1a-setup: Simple di
 		test_tick &&
 		git commit -m "B"
 	)
-'
+}
 
-test_expect_success '1a-check: Simple directory rename detection' '
+test_expect_success '1a: Simple directory rename detection' '
+	test_setup_1a &&
 	(
 		cd 1a &&
 
 		git checkout A^0 &&
 
-		git merge -s recursive B^0 &&
+		git -c merge.directoryRenames=true merge -s recursive B^0 >out &&
 
 		git ls-files -s >out &&
 		test_line_count = 4 out &&
@@ -103,7 +104,7 @@ test_expect_success '1a-check: Simple di
 #   Commit B: y/{b,c,d}
 #   Expected: y/{b,c,d,e}
 
-test_expect_success '1b-setup: Merge a directory with another' '
+test_setup_1b () {
 	test_create_repo 1b &&
 	(
 		cd 1b &&
@@ -134,15 +135,16 @@ test_expect_success '1b-setup: Merge a d
 		test_tick &&
 		git commit -m "B"
 	)
-'
+}
 
-test_expect_success '1b-check: Merge a directory with another' '
+test_expect_success '1b: Merge a directory with another' '
+	test_setup_1b &&
 	(
 		cd 1b &&
 
 		git checkout A^0 &&
 
-		git merge -s recursive B^0 &&
+		git -c merge.directoryRenames=true merge -s recursive B^0 &&
 
 		git ls-files -s >out &&
 		test_line_count = 4 out &&
@@ -165,7 +167,7 @@ test_expect_success '1b-check: Merge a d
 #   Commit B: z/{b,c,d}
 #   Expected: y/{b,c,d}  (because x/d -> z/d -> y/d)
 
-test_expect_success '1c-setup: Transitive renaming' '
+test_setup_1c () {
 	test_create_repo 1c &&
 	(
 		cd 1c &&
@@ -193,15 +195,16 @@ test_expect_success '1c-setup: Transitiv
 		test_tick &&
 		git commit -m "B"
 	)
-'
+}
 
-test_expect_success '1c-check: Transitive renaming' '
+test_expect_success '1c: Transitive renaming' '
+	test_setup_1c &&
 	(
 		cd 1c &&
 
 		git checkout A^0 &&
 
-		git merge -s recursive B^0 &&
+		git -c merge.directoryRenames=true merge -s recursive B^0 >out &&
 
 		git ls-files -s >out &&
 		test_line_count = 3 out &&
@@ -227,7 +230,7 @@ test_expect_success '1c-check: Transitiv
 #   Note: y/m & z/n should definitely move into x.  By the same token, both
 #         y/wham_1 & z/wham_2 should too...giving us a conflict.
 
-test_expect_success '1d-setup: Directory renames cause a rename/rename(2to1) conflict' '
+test_setup_1d () {
 	test_create_repo 1d &&
 	(
 		cd 1d &&
@@ -262,15 +265,16 @@ test_expect_success '1d-setup: Directory
 		test_tick &&
 		git commit -m "B"
 	)
-'
+}
 
-test_expect_success '1d-check: Directory renames cause a rename/rename(2to1) conflict' '
+test_expect_success '1d: Directory renames cause a rename/rename(2to1) conflict' '
+	test_setup_1d &&
 	(
 		cd 1d &&
 
 		git checkout A^0 &&
 
-		test_must_fail git merge -s recursive B^0 >out &&
+		test_must_fail git -c merge.directoryRenames=true merge -s recursive B^0 >out &&
 		test_i18ngrep "CONFLICT (rename/rename)" out &&
 
 		git ls-files -s >out &&
@@ -278,7 +282,7 @@ test_expect_success '1d-check: Directory
 		git ls-files -u >out &&
 		test_line_count = 2 out &&
 		git ls-files -o >out &&
-		test_line_count = 3 out &&
+		test_line_count = 1 out &&
 
 		git rev-parse >actual \
 			:0:x/b :0:x/c :0:x/d :0:x/e :0:x/m :0:x/n &&
@@ -293,15 +297,16 @@ test_expect_success '1d-check: Directory
 			 A:y/wham  B:z/wham &&
 		test_cmp expect actual &&
 
-		test_path_is_missing x/wham &&
-		test_path_is_file x/wham~HEAD &&
-		test_path_is_file x/wham~B^0 &&
-
-		git hash-object >actual \
-			x/wham~HEAD x/wham~B^0 &&
-		git rev-parse >expect \
-			A:y/wham    B:z/wham &&
-		test_cmp expect actual
+		# Test that the two-way merge in x/wham is as expected
+		git cat-file -p :2:x/wham >expect &&
+		git cat-file -p :3:x/wham >other &&
+		>empty &&
+		test_must_fail git merge-file \
+			-L "HEAD" \
+			-L "" \
+			-L "B^0" \
+			expect empty other &&
+		test_cmp expect x/wham
 	)
 '
 
@@ -312,7 +317,7 @@ test_expect_success '1d-check: Directory
 #   Commit B: z/{oldb,oldc,d}
 #   Expected: y/{newb,newc,d}
 
-test_expect_success '1e-setup: Renamed directory, with all files being renamed too' '
+test_setup_1e () {
 	test_create_repo 1e &&
 	(
 		cd 1e &&
@@ -341,15 +346,16 @@ test_expect_success '1e-setup: Renamed d
 		test_tick &&
 		git commit -m "B"
 	)
-'
+}
 
-test_expect_success '1e-check: Renamed directory, with all files being renamed too' '
+test_expect_success '1e: Renamed directory, with all files being renamed too' '
+	test_setup_1e &&
 	(
 		cd 1e &&
 
 		git checkout A^0 &&
 
-		git merge -s recursive B^0 &&
+		git -c merge.directoryRenames=true merge -s recursive B^0 &&
 
 		git ls-files -s >out &&
 		test_line_count = 3 out &&
@@ -370,7 +376,7 @@ test_expect_success '1e-check: Renamed d
 #   Commit B: y/{b,c}, x/{d,e,f}
 #   Expected: y/{b,c}, x/{d,e,f,g}
 
-test_expect_success '1f-setup: Split a directory into two other directories' '
+test_setup_1f () {
 	test_create_repo 1f &&
 	(
 		cd 1f &&
@@ -407,15 +413,16 @@ test_expect_success '1f-setup: Split a d
 		test_tick &&
 		git commit -m "B"
 	)
-'
+}
 
-test_expect_success '1f-check: Split a directory into two other directories' '
+test_expect_success '1f: Split a directory into two other directories' '
+	test_setup_1f &&
 	(
 		cd 1f &&
 
 		git checkout A^0 &&
 
-		git merge -s recursive B^0 &&
+		git -c merge.directoryRenames=true merge -s recursive B^0 &&
 
 		git ls-files -s >out &&
 		test_line_count = 6 out &&
@@ -458,7 +465,7 @@ test_expect_success '1f-check: Split a d
 #   Commit A: y/b, w/c
 #   Commit B: z/{b,c,d}
 #   Expected: y/b, w/c, z/d, with warning about z/ -> (y/ vs. w/) conflict
-test_expect_success '2a-setup: Directory split into two on one side, with equal numbers of paths' '
+test_setup_2a () {
 	test_create_repo 2a &&
 	(
 		cd 2a &&
@@ -488,15 +495,16 @@ test_expect_success '2a-setup: Directory
 		test_tick &&
 		git commit -m "B"
 	)
-'
+}
 
-test_expect_success '2a-check: Directory split into two on one side, with equal numbers of paths' '
+test_expect_success '2a: Directory split into two on one side, with equal numbers of paths' '
+	test_setup_2a &&
 	(
 		cd 2a &&
 
 		git checkout A^0 &&
 
-		test_must_fail git merge -s recursive B^0 >out &&
+		test_must_fail git -c merge.directoryRenames=true merge -s recursive B^0 >out &&
 		test_i18ngrep "CONFLICT.*directory rename split" out &&
 
 		git ls-files -s >out &&
@@ -519,7 +527,7 @@ test_expect_success '2a-check: Directory
 #   Commit A: y/b, w/c
 #   Commit B: z/{b,c}, x/d
 #   Expected: y/b, w/c, x/d; No warning about z/ -> (y/ vs. w/) conflict
-test_expect_success '2b-setup: Directory split into two on one side, with equal numbers of paths' '
+test_setup_2b () {
 	test_create_repo 2b &&
 	(
 		cd 2b &&
@@ -550,15 +558,16 @@ test_expect_success '2b-setup: Directory
 		test_tick &&
 		git commit -m "B"
 	)
-'
+}
 
-test_expect_success '2b-check: Directory split into two on one side, with equal numbers of paths' '
+test_expect_success '2b: Directory split into two on one side, with equal numbers of paths' '
+	test_setup_2b &&
 	(
 		cd 2b &&
 
 		git checkout A^0 &&
 
-		git merge -s recursive B^0 >out &&
+		git -c merge.directoryRenames=true merge -s recursive B^0 >out &&
 
 		git ls-files -s >out &&
 		test_line_count = 3 out &&
@@ -600,7 +609,7 @@ test_expect_success '2b-check: Directory
 #   Commit A: z/{b,c,d} (no change)
 #   Commit B: y/{b,c}, x/d
 #   Expected: y/{b,c}, x/d
-test_expect_success '3a-setup: Avoid implicit rename if involved as source on other side' '
+test_setup_3a () {
 	test_create_repo 3a &&
 	(
 		cd 3a &&
@@ -631,15 +640,16 @@ test_expect_success '3a-setup: Avoid imp
 		test_tick &&
 		git commit -m "B"
 	)
-'
+}
 
-test_expect_success '3a-check: Avoid implicit rename if involved as source on other side' '
+test_expect_success '3a: Avoid implicit rename if involved as source on other side' '
+	test_setup_3a &&
 	(
 		cd 3a &&
 
 		git checkout A^0 &&
 
-		git merge -s recursive B^0 &&
+		git -c merge.directoryRenames=true merge -s recursive B^0 &&
 
 		git ls-files -s >out &&
 		test_line_count = 3 out &&
@@ -663,7 +673,7 @@ test_expect_success '3a-check: Avoid imp
 #         get it involved in directory rename detection.  If it were, we might
 #         end up with CONFLICT:(z/d -> y/d vs. x/d vs. w/d), i.e. a
 #         rename/rename/rename(1to3) conflict, which is just weird.
-test_expect_success '3b-setup: Avoid implicit rename if involved as source on current side' '
+test_setup_3b () {
 	test_create_repo 3b &&
 	(
 		cd 3b &&
@@ -696,15 +706,16 @@ test_expect_success '3b-setup: Avoid imp
 		test_tick &&
 		git commit -m "B"
 	)
-'
+}
 
-test_expect_success '3b-check: Avoid implicit rename if involved as source on current side' '
+test_expect_success '3b: Avoid implicit rename if involved as source on current side' '
+	test_setup_3b &&
 	(
 		cd 3b &&
 
 		git checkout A^0 &&
 
-		test_must_fail git merge -s recursive B^0 >out &&
+		test_must_fail git -c merge.directoryRenames=true merge -s recursive B^0 >out &&
 		test_i18ngrep CONFLICT.*rename/rename.*z/d.*x/d.*w/d out &&
 		test_i18ngrep ! CONFLICT.*rename/rename.*y/d out &&
 
@@ -743,7 +754,7 @@ test_expect_success '3b-check: Avoid imp
 #
 # What if we were to attempt to do directory rename detection when someone
 # "mostly" moved a directory but still left some files around, or,
-# equivalently, fully renamed a directory in one commmit and then recreated
+# equivalently, fully renamed a directory in one commit and then recreated
 # that directory in a later commit adding some new files and then tried to
 # merge?
 #
@@ -785,7 +796,7 @@ test_expect_success '3b-check: Avoid imp
 #   Expected: y/{b,c,d}, z/{e,f}
 #   NOTE: Even though most files from z moved to y, we don't want f to follow.
 
-test_expect_success '4a-setup: Directory split, with original directory still present' '
+test_setup_4a () {
 	test_create_repo 4a &&
 	(
 		cd 4a &&
@@ -817,15 +828,16 @@ test_expect_success '4a-setup: Directory
 		test_tick &&
 		git commit -m "B"
 	)
-'
+}
 
-test_expect_success '4a-check: Directory split, with original directory still present' '
+test_expect_success '4a: Directory split, with original directory still present' '
+	test_setup_4a &&
 	(
 		cd 4a &&
 
 		git checkout A^0 &&
 
-		git merge -s recursive B^0 &&
+		git -c merge.directoryRenames=true merge -s recursive B^0 &&
 
 		git ls-files -s >out &&
 		test_line_count = 5 out &&
@@ -873,7 +885,7 @@ test_expect_success '4a-check: Directory
 #         of history, giving us no way to represent this conflict in the
 #         index.
 
-test_expect_success '5a-setup: Merge directories, other side adds files to original and target' '
+test_setup_5a () {
 	test_create_repo 5a &&
 	(
 		cd 5a &&
@@ -906,15 +918,16 @@ test_expect_success '5a-setup: Merge dir
 		test_tick &&
 		git commit -m "B"
 	)
-'
+}
 
-test_expect_success '5a-check: Merge directories, other side adds files to original and target' '
+test_expect_success '5a: Merge directories, other side adds files to original and target' '
+	test_setup_5a &&
 	(
 		cd 5a &&
 
 		git checkout A^0 &&
 
-		test_must_fail git merge -s recursive B^0 >out &&
+		test_must_fail git -c merge.directoryRenames=true merge -s recursive B^0 >out &&
 		test_i18ngrep "CONFLICT.*implicit dir rename" out &&
 
 		git ls-files -s >out &&
@@ -940,14 +953,14 @@ test_expect_success '5a-check: Merge dir
 #   Commit B: z/{b,c,d_1,e}, y/d_3
 #   Expected: y/{b,c,e}, CONFLICT(add/add: y/d_2 vs. y/d_3)
 #   NOTE: If z/d_1 in commit B were to be involved in dir rename detection, as
-#         we normaly would since z/ is being renamed to y/, then this would be
+#         we normally would since z/ is being renamed to y/, then this would be
 #         a rename/delete (z/d_1 -> y/d_1 vs. deleted) AND an add/add/add
 #         conflict of y/d_1 vs. y/d_2 vs. y/d_3.  Add/add/add is not
 #         representable in the index, so the existence of y/d_3 needs to
 #         cause us to bail on directory rename detection for that path, falling
 #         back to git behavior without the directory rename detection.
 
-test_expect_success '5b-setup: Rename/delete in order to get add/add/add conflict' '
+test_setup_5b () {
 	test_create_repo 5b &&
 	(
 		cd 5b &&
@@ -980,15 +993,16 @@ test_expect_success '5b-setup: Rename/de
 		test_tick &&
 		git commit -m "B"
 	)
-'
+}
 
-test_expect_success '5b-check: Rename/delete in order to get add/add/add conflict' '
+test_expect_success '5b: Rename/delete in order to get add/add/add conflict' '
+	test_setup_5b &&
 	(
 		cd 5b &&
 
 		git checkout A^0 &&
 
-		test_must_fail git merge -s recursive B^0 >out &&
+		test_must_fail git -c merge.directoryRenames=true merge -s recursive B^0 >out &&
 		test_i18ngrep "CONFLICT (add/add).* y/d" out &&
 
 		git ls-files -s >out &&
@@ -1023,7 +1037,7 @@ test_expect_success '5b-check: Rename/de
 #             y/d are y/d_2 and y/d_4.  We still do the move from z/e to y/e,
 #             though, because it doesn't have anything in the way.
 
-test_expect_success '5c-setup: Transitive rename would cause rename/rename/rename/add/add/add' '
+test_setup_5c () {
 	test_create_repo 5c &&
 	(
 		cd 5c &&
@@ -1060,15 +1074,16 @@ test_expect_success '5c-setup: Transitiv
 		test_tick &&
 		git commit -m "B"
 	)
-'
+}
 
-test_expect_success '5c-check: Transitive rename would cause rename/rename/rename/add/add/add' '
+test_expect_success '5c: Transitive rename would cause rename/rename/rename/add/add/add' '
+	test_setup_5c &&
 	(
 		cd 5c &&
 
 		git checkout A^0 &&
 
-		test_must_fail git merge -s recursive B^0 >out &&
+		test_must_fail git -c merge.directoryRenames=true merge -s recursive B^0 >out &&
 		test_i18ngrep "CONFLICT (rename/rename).*x/d.*w/d.*z/d" out &&
 		test_i18ngrep "CONFLICT (add/add).* y/d" out &&
 
@@ -1077,7 +1092,7 @@ test_expect_success '5c-check: Transitiv
 		git ls-files -u >out &&
 		test_line_count = 6 out &&
 		git ls-files -o >out &&
-		test_line_count = 3 out &&
+		test_line_count = 1 out &&
 
 		git rev-parse >actual \
 			:0:y/b :0:y/c :0:y/e &&
@@ -1093,9 +1108,9 @@ test_expect_success '5c-check: Transitiv
 		test_cmp expect actual &&
 
 		git hash-object >actual \
-			w/d~HEAD w/d~B^0 z/d &&
+			z/d &&
 		git rev-parse >expect \
-			O:x/d    B:w/d   O:x/d &&
+			O:x/d &&
 		test_cmp expect actual &&
 		test_path_is_missing x/d &&
 		test_path_is_file y/d &&
@@ -1112,7 +1127,7 @@ test_expect_success '5c-check: Transitiv
 #         detection for z/d_2, but that doesn't prevent us from applying the
 #         directory rename detection for z/f -> y/f.
 
-test_expect_success '5d-setup: Directory/file/file conflict due to directory rename' '
+test_setup_5d () {
 	test_create_repo 5d &&
 	(
 		cd 5d &&
@@ -1144,15 +1159,16 @@ test_expect_success '5d-setup: Directory
 		test_tick &&
 		git commit -m "B"
 	)
-'
+}
 
-test_expect_success '5d-check: Directory/file/file conflict due to directory rename' '
+test_expect_success '5d: Directory/file/file conflict due to directory rename' '
+	test_setup_5d &&
 	(
 		cd 5d &&
 
 		git checkout A^0 &&
 
-		test_must_fail git merge -s recursive B^0 >out &&
+		test_must_fail git -c merge.directoryRenames=true merge -s recursive B^0 >out &&
 		test_i18ngrep "CONFLICT (file/directory).*y/d" out &&
 
 		git ls-files -s >out &&
@@ -1204,7 +1220,7 @@ test_expect_success '5d-check: Directory
 #         them under y/ doesn't accidentally catch z/d and make it look like
 #         it is also involved in a rename/delete conflict.
 
-test_expect_success '6a-setup: Tricky rename/delete' '
+test_setup_6a () {
 	test_create_repo 6a &&
 	(
 		cd 6a &&
@@ -1234,15 +1250,16 @@ test_expect_success '6a-setup: Tricky re
 		test_tick &&
 		git commit -m "B"
 	)
-'
+}
 
-test_expect_success '6a-check: Tricky rename/delete' '
+test_expect_success '6a: Tricky rename/delete' '
+	test_setup_6a &&
 	(
 		cd 6a &&
 
 		git checkout A^0 &&
 
-		test_must_fail git merge -s recursive B^0 >out &&
+		test_must_fail git -c merge.directoryRenames=true merge -s recursive B^0 >out &&
 		test_i18ngrep "CONFLICT (rename/delete).*z/c.*y/c" out &&
 
 		git ls-files -s >out &&
@@ -1270,7 +1287,7 @@ test_expect_success '6a-check: Tricky re
 #         but B did that rename and still decided to put the file into z/,
 #         so we probably shouldn't apply directory rename detection for it.
 
-test_expect_success '6b-setup: Same rename done on both sides' '
+test_setup_6b () {
 	test_create_repo 6b &&
 	(
 		cd 6b &&
@@ -1299,15 +1316,16 @@ test_expect_success '6b-setup: Same rena
 		test_tick &&
 		git commit -m "B"
 	)
-'
+}
 
-test_expect_success '6b-check: Same rename done on both sides' '
+test_expect_success '6b: Same rename done on both sides' '
+	test_setup_6b &&
 	(
 		cd 6b &&
 
 		git checkout A^0 &&
 
-		git merge -s recursive B^0 &&
+		git -c merge.directoryRenames=true merge -s recursive B^0 &&
 
 		git ls-files -s >out &&
 		test_line_count = 3 out &&
@@ -1333,7 +1351,7 @@ test_expect_success '6b-check: Same rena
 #   NOTE: Seems obvious, but just checking that the implementation doesn't
 #         "accidentally detect a rename" and give us y/{b,c,d}.
 
-test_expect_success '6c-setup: Rename only done on same side' '
+test_setup_6c () {
 	test_create_repo 6c &&
 	(
 		cd 6c &&
@@ -1361,15 +1379,16 @@ test_expect_success '6c-setup: Rename on
 		test_tick &&
 		git commit -m "B"
 	)
-'
+}
 
-test_expect_success '6c-check: Rename only done on same side' '
+test_expect_success '6c: Rename only done on same side' '
+	test_setup_6c &&
 	(
 		cd 6c &&
 
 		git checkout A^0 &&
 
-		git merge -s recursive B^0 &&
+		git -c merge.directoryRenames=true merge -s recursive B^0 &&
 
 		git ls-files -s >out &&
 		test_line_count = 3 out &&
@@ -1395,7 +1414,7 @@ test_expect_success '6c-check: Rename on
 #   NOTE: Again, this seems obvious but just checking that the implementation
 #         doesn't "accidentally detect a rename" and give us y/{b,c,d}.
 
-test_expect_success '6d-setup: We do not always want transitive renaming' '
+test_setup_6d () {
 	test_create_repo 6d &&
 	(
 		cd 6d &&
@@ -1423,15 +1442,16 @@ test_expect_success '6d-setup: We do not
 		test_tick &&
 		git commit -m "B"
 	)
-'
+}
 
-test_expect_success '6d-check: We do not always want transitive renaming' '
+test_expect_success '6d: We do not always want transitive renaming' '
+	test_setup_6d &&
 	(
 		cd 6d &&
 
 		git checkout A^0 &&
 
-		git merge -s recursive B^0 &&
+		git -c merge.directoryRenames=true merge -s recursive B^0 &&
 
 		git ls-files -s >out &&
 		test_line_count = 3 out &&
@@ -1457,7 +1477,7 @@ test_expect_success '6d-check: We do not
 #         doesn't "accidentally detect a rename" and give us y/{b,c} +
 #         add/add conflict on y/d_1 vs y/d_2.
 
-test_expect_success '6e-setup: Add/add from one side' '
+test_setup_6e () {
 	test_create_repo 6e &&
 	(
 		cd 6e &&
@@ -1486,15 +1506,16 @@ test_expect_success '6e-setup: Add/add f
 		test_tick &&
 		git commit -m "B"
 	)
-'
+}
 
-test_expect_success '6e-check: Add/add from one side' '
+test_expect_success '6e: Add/add from one side' '
+	test_setup_6e &&
 	(
 		cd 6e &&
 
 		git checkout A^0 &&
 
-		git merge -s recursive B^0 &&
+		git -c merge.directoryRenames=true merge -s recursive B^0 &&
 
 		git ls-files -s >out &&
 		test_line_count = 4 out &&
@@ -1551,7 +1572,7 @@ test_expect_success '6e-check: Add/add f
 #   Expected: y/d, CONFLICT(rename/rename for both z/b and z/c)
 #   NOTE: There's a rename of z/ here, y/ has more renames, so z/d -> y/d.
 
-test_expect_success '7a-setup: rename-dir vs. rename-dir (NOT split evenly) PLUS add-other-file' '
+test_setup_7a () {
 	test_create_repo 7a &&
 	(
 		cd 7a &&
@@ -1582,15 +1603,16 @@ test_expect_success '7a-setup: rename-di
 		test_tick &&
 		git commit -m "B"
 	)
-'
+}
 
-test_expect_success '7a-check: rename-dir vs. rename-dir (NOT split evenly) PLUS add-other-file' '
+test_expect_success '7a: rename-dir vs. rename-dir (NOT split evenly) PLUS add-other-file' '
+	test_setup_7a &&
 	(
 		cd 7a &&
 
 		git checkout A^0 &&
 
-		test_must_fail git merge -s recursive B^0 >out &&
+		test_must_fail git -c merge.directoryRenames=true merge -s recursive B^0 >out &&
 		test_i18ngrep "CONFLICT (rename/rename).*z/b.*y/b.*w/b" out &&
 		test_i18ngrep "CONFLICT (rename/rename).*z/c.*y/c.*x/c" out &&
 
@@ -1622,7 +1644,7 @@ test_expect_success '7a-check: rename-di
 #   Commit B: z/{b,c,d_1},        w/d_2
 #   Expected: y/{b,c}, CONFLICT(rename/rename(2to1): x/d_1, w/d_2 -> y_d)
 
-test_expect_success '7b-setup: rename/rename(2to1), but only due to transitive rename' '
+test_setup_7b () {
 	test_create_repo 7b &&
 	(
 		cd 7b &&
@@ -1654,15 +1676,16 @@ test_expect_success '7b-setup: rename/re
 		test_tick &&
 		git commit -m "B"
 	)
-'
+}
 
-test_expect_success '7b-check: rename/rename(2to1), but only due to transitive rename' '
+test_expect_success '7b: rename/rename(2to1), but only due to transitive rename' '
+	test_setup_7b &&
 	(
 		cd 7b &&
 
 		git checkout A^0 &&
 
-		test_must_fail git merge -s recursive B^0 >out &&
+		test_must_fail git -c merge.directoryRenames=true merge -s recursive B^0 >out &&
 		test_i18ngrep "CONFLICT (rename/rename)" out &&
 
 		git ls-files -s >out &&
@@ -1670,7 +1693,7 @@ test_expect_success '7b-check: rename/re
 		git ls-files -u >out &&
 		test_line_count = 2 out &&
 		git ls-files -o >out &&
-		test_line_count = 3 out &&
+		test_line_count = 1 out &&
 
 		git rev-parse >actual \
 			:0:y/b :0:y/c :2:y/d :3:y/d &&
@@ -1678,15 +1701,16 @@ test_expect_success '7b-check: rename/re
 			 O:z/b  O:z/c  O:w/d  O:x/d &&
 		test_cmp expect actual &&
 
-		test_path_is_missing y/d &&
-		test_path_is_file y/d~HEAD &&
-		test_path_is_file y/d~B^0 &&
-
-		git hash-object >actual \
-			y/d~HEAD y/d~B^0 &&
-		git rev-parse >expect \
-			O:w/d    O:x/d &&
-		test_cmp expect actual
+		# Test that the two-way merge in y/d is as expected
+		git cat-file -p :2:y/d >expect &&
+		git cat-file -p :3:y/d >other &&
+		>empty &&
+		test_must_fail git merge-file \
+			-L "HEAD" \
+			-L "" \
+			-L "B^0" \
+			expect empty other &&
+		test_cmp expect y/d
 	)
 '
 
@@ -1700,7 +1724,7 @@ test_expect_success '7b-check: rename/re
 #         neither CONFLICT(x/d -> w/d vs. z/d)
 #         nor CONFLiCT x/d -> w/d vs. y/d vs. z/d)
 
-test_expect_success '7c-setup: rename/rename(1to...2or3); transitive rename may add complexity' '
+test_setup_7c () {
 	test_create_repo 7c &&
 	(
 		cd 7c &&
@@ -1730,15 +1754,16 @@ test_expect_success '7c-setup: rename/re
 		test_tick &&
 		git commit -m "B"
 	)
-'
+}
 
-test_expect_success '7c-check: rename/rename(1to...2or3); transitive rename may add complexity' '
+test_expect_success '7c: rename/rename(1to...2or3); transitive rename may add complexity' '
+	test_setup_7c &&
 	(
 		cd 7c &&
 
 		git checkout A^0 &&
 
-		test_must_fail git merge -s recursive B^0 >out &&
+		test_must_fail git -c merge.directoryRenames=true merge -s recursive B^0 >out &&
 		test_i18ngrep "CONFLICT (rename/rename).*x/d.*w/d.*y/d" out &&
 
 		git ls-files -s >out &&
@@ -1764,7 +1789,7 @@ test_expect_success '7c-check: rename/re
 #   Expected: y/{b,c}, CONFLICT(delete x/d vs rename to y/d)
 #   NOTE: z->y so NOT CONFLICT(delete x/d vs rename to z/d)
 
-test_expect_success '7d-setup: transitive rename involved in rename/delete; how is it reported?' '
+test_setup_7d () {
 	test_create_repo 7d &&
 	(
 		cd 7d &&
@@ -1794,15 +1819,16 @@ test_expect_success '7d-setup: transitiv
 		test_tick &&
 		git commit -m "B"
 	)
-'
+}
 
-test_expect_success '7d-check: transitive rename involved in rename/delete; how is it reported?' '
+test_expect_success '7d: transitive rename involved in rename/delete; how is it reported?' '
+	test_setup_7d &&
 	(
 		cd 7d &&
 
 		git checkout A^0 &&
 
-		test_must_fail git merge -s recursive B^0 >out &&
+		test_must_fail git -c merge.directoryRenames=true merge -s recursive B^0 >out &&
 		test_i18ngrep "CONFLICT (rename/delete).*x/d.*y/d" out &&
 
 		git ls-files -s >out &&
@@ -1849,7 +1875,7 @@ test_expect_success '7d-check: transitiv
 #         see testcases 9c and 9d for further discussion of this issue and
 #         how it's resolved.
 
-test_expect_success '7e-setup: transitive rename in rename/delete AND dirs in the way' '
+test_setup_7e () {
 	test_create_repo 7e &&
 	(
 		cd 7e &&
@@ -1884,15 +1910,16 @@ test_expect_success '7e-setup: transitiv
 		test_tick &&
 		git commit -m "B"
 	)
-'
+}
 
-test_expect_success '7e-check: transitive rename in rename/delete AND dirs in the way' '
+test_expect_success '7e: transitive rename in rename/delete AND dirs in the way' '
+	test_setup_7e &&
 	(
 		cd 7e &&
 
 		git checkout A^0 &&
 
-		test_must_fail git merge -s recursive B^0 >out &&
+		test_must_fail git -c merge.directoryRenames=true merge -s recursive B^0 >out &&
 		test_i18ngrep "CONFLICT (rename/delete).*x/d.*y/d" out &&
 
 		git ls-files -s >out &&
@@ -1943,7 +1970,7 @@ test_expect_success '7e-check: transitiv
 # simple rule from section 5 prevents me from handling this as optimally as
 # we potentially could.
 
-test_expect_success '8a-setup: Dual-directory rename, one into the others way' '
+test_setup_8a () {
 	test_create_repo 8a &&
 	(
 		cd 8a &&
@@ -1975,15 +2002,16 @@ test_expect_success '8a-setup: Dual-dire
 		test_tick &&
 		git commit -m "B"
 	)
-'
+}
 
-test_expect_success '8a-check: Dual-directory rename, one into the others way' '
+test_expect_success '8a: Dual-directory rename, one into the others way' '
+	test_setup_8a &&
 	(
 		cd 8a &&
 
 		git checkout A^0 &&
 
-		git merge -s recursive B^0 &&
+		git -c merge.directoryRenames=true merge -s recursive B^0 &&
 
 		git ls-files -s >out &&
 		test_line_count = 6 out &&
@@ -2021,7 +2049,7 @@ test_expect_success '8a-check: Dual-dire
 # making us fall back to pre-directory-rename-detection behavior for both
 # e_1 and e_2.
 
-test_expect_success '8b-setup: Dual-directory rename, one into the others way, with conflicting filenames' '
+test_setup_8b () {
 	test_create_repo 8b &&
 	(
 		cd 8b &&
@@ -2053,15 +2081,16 @@ test_expect_success '8b-setup: Dual-dire
 		test_tick &&
 		git commit -m "B"
 	)
-'
+}
 
-test_expect_success '8b-check: Dual-directory rename, one into the others way, with conflicting filenames' '
+test_expect_success '8b: Dual-directory rename, one into the others way, with conflicting filenames' '
+	test_setup_8b &&
 	(
 		cd 8b &&
 
 		git checkout A^0 &&
 
-		git merge -s recursive B^0 &&
+		git -c merge.directoryRenames=true merge -s recursive B^0 &&
 
 		git ls-files -s >out &&
 		test_line_count = 6 out &&
@@ -2087,14 +2116,14 @@ test_expect_success '8b-check: Dual-dire
 #
 #   Note: It could easily be argued that the correct resolution here is
 #         y/{b,c,e}, CONFLICT(rename/delete: z/d -> y/d vs deleted)
-#         and that the modifed version of d should be present in y/ after
+#         and that the modified version of d should be present in y/ after
 #         the merge, just marked as conflicted.  Indeed, I previously did
 #         argue that.  But applying directory renames to the side of
 #         history where a file is merely modified results in spurious
 #         rename/rename(1to2) conflicts -- see testcase 9h.  See also
 #         notes in 8d.
 
-test_expect_success '8c-setup: modify/delete or rename+modify/delete?' '
+test_setup_8c () {
 	test_create_repo 8c &&
 	(
 		cd 8c &&
@@ -2125,15 +2154,16 @@ test_expect_success '8c-setup: modify/de
 		test_tick &&
 		git commit -m "B"
 	)
-'
+}
 
-test_expect_success '8c-check: modify/delete or rename+modify/delete' '
+test_expect_success '8c: modify/delete or rename+modify/delete' '
+	test_setup_8c &&
 	(
 		cd 8c &&
 
 		git checkout A^0 &&
 
-		test_must_fail git merge -s recursive B^0 >out &&
+		test_must_fail git -c merge.directoryRenames=true merge -s recursive B^0 >out &&
 		test_i18ngrep "CONFLICT (modify/delete).* z/d" out &&
 
 		git ls-files -s >out &&
@@ -2173,7 +2203,7 @@ test_expect_success '8c-check: modify/de
 #   during merging are supposed to be about opposite sides doing things
 #   differently.
 
-test_expect_success '8d-setup: rename/delete...or not?' '
+test_setup_8d () {
 	test_create_repo 8d &&
 	(
 		cd 8d &&
@@ -2202,15 +2232,16 @@ test_expect_success '8d-setup: rename/de
 		test_tick &&
 		git commit -m "B"
 	)
-'
+}
 
-test_expect_success '8d-check: rename/delete...or not?' '
+test_expect_success '8d: rename/delete...or not?' '
+	test_setup_8d &&
 	(
 		cd 8d &&
 
 		git checkout A^0 &&
 
-		git merge -s recursive B^0 &&
+		git -c merge.directoryRenames=true merge -s recursive B^0 &&
 
 		git ls-files -s >out &&
 		test_line_count = 3 out &&
@@ -2248,7 +2279,7 @@ test_expect_success '8d-check: rename/de
 #        about the ramifications of doing that, I didn't know how to rule out
 #        that opening other weird edge and corner cases so I just punted.
 
-test_expect_success '8e-setup: Both sides rename, one side adds to original directory' '
+test_setup_8e () {
 	test_create_repo 8e &&
 	(
 		cd 8e &&
@@ -2277,15 +2308,16 @@ test_expect_success '8e-setup: Both side
 		test_tick &&
 		git commit -m "B"
 	)
-'
+}
 
-test_expect_success '8e-check: Both sides rename, one side adds to original directory' '
+test_expect_success '8e: Both sides rename, one side adds to original directory' '
+	test_setup_8e &&
 	(
 		cd 8e &&
 
 		git checkout A^0 &&
 
-		test_must_fail git merge -s recursive B^0 >out 2>err &&
+		test_must_fail git -c merge.directoryRenames=true merge -s recursive B^0 >out 2>err &&
 		test_i18ngrep CONFLICT.*rename/rename.*z/c.*y/c.*w/c out &&
 		test_i18ngrep CONFLICT.*rename/rename.*z/b.*y/b.*w/b out &&
 
@@ -2331,7 +2363,7 @@ test_expect_success '8e-check: Both side
 #         of which one had the most paths going to it.  A naive implementation
 #         of that could take the new file in commit B at z/i to x/w/i or x/i.
 
-test_expect_success '9a-setup: Inner renamed directory within outer renamed directory' '
+test_setup_9a () {
 	test_create_repo 9a &&
 	(
 		cd 9a &&
@@ -2364,15 +2396,16 @@ test_expect_success '9a-setup: Inner ren
 		test_tick &&
 		git commit -m "B"
 	)
-'
+}
 
-test_expect_success '9a-check: Inner renamed directory within outer renamed directory' '
+test_expect_success '9a: Inner renamed directory within outer renamed directory' '
+	test_setup_9a &&
 	(
 		cd 9a &&
 
 		git checkout A^0 &&
 
-		git merge -s recursive B^0 &&
+		git -c merge.directoryRenames=true merge -s recursive B^0 &&
 
 		git ls-files -s >out &&
 		test_line_count = 7 out &&
@@ -2402,7 +2435,7 @@ test_expect_success '9a-check: Inner ren
 #   Commit B: z/{b,c,d_3}
 #   Expected: y/{b,c,d_merged}
 
-test_expect_success '9b-setup: Transitive rename with content merge' '
+test_setup_9b () {
 	test_create_repo 9b &&
 	(
 		cd 9b &&
@@ -2434,15 +2467,16 @@ test_expect_success '9b-setup: Transitiv
 		test_tick &&
 		git commit -m "B"
 	)
-'
+}
 
-test_expect_success '9b-check: Transitive rename with content merge' '
+test_expect_success '9b: Transitive rename with content merge' '
+	test_setup_9b &&
 	(
 		cd 9b &&
 
 		git checkout A^0 &&
 
-		git merge -s recursive B^0 &&
+		git -c merge.directoryRenames=true merge -s recursive B^0 &&
 
 		git ls-files -s >out &&
 		test_line_count = 3 out &&
@@ -2489,7 +2523,7 @@ test_expect_success '9b-check: Transitiv
 #         away, then ignore that particular rename from the other side of
 #         history for any implicit directory renames.
 
-test_expect_success '9c-setup: Doubly transitive rename?' '
+test_setup_9c () {
 	test_create_repo 9c &&
 	(
 		cd 9c &&
@@ -2524,15 +2558,16 @@ test_expect_success '9c-setup: Doubly tr
 		test_tick &&
 		git commit -m "B"
 	)
-'
+}
 
-test_expect_success '9c-check: Doubly transitive rename?' '
+test_expect_success '9c: Doubly transitive rename?' '
+	test_setup_9c &&
 	(
 		cd 9c &&
 
 		git checkout A^0 &&
 
-		git merge -s recursive B^0 >out &&
+		git -c merge.directoryRenames=true merge -s recursive B^0 >out &&
 		test_i18ngrep "WARNING: Avoiding applying x -> z rename to x/f" out &&
 
 		git ls-files -s >out &&
@@ -2577,7 +2612,7 @@ test_expect_success '9c-check: Doubly tr
 #   simple rules that are consistent with what we need for all the other
 #   testcases and simplifies things for the user.
 
-test_expect_success '9d-setup: N-way transitive rename?' '
+test_setup_9d () {
 	test_create_repo 9d &&
 	(
 		cd 9d &&
@@ -2612,15 +2647,16 @@ test_expect_success '9d-setup: N-way tra
 		test_tick &&
 		git commit -m "B"
 	)
-'
+}
 
-test_expect_success '9d-check: N-way transitive rename?' '
+test_expect_success '9d: N-way transitive rename?' '
+	test_setup_9d &&
 	(
 		cd 9d &&
 
 		git checkout A^0 &&
 
-		git merge -s recursive B^0 >out &&
+		git -c merge.directoryRenames=true merge -s recursive B^0 >out &&
 		test_i18ngrep "WARNING: Avoiding applying z -> y rename to z/t" out &&
 		test_i18ngrep "WARNING: Avoiding applying y -> x rename to y/a" out &&
 		test_i18ngrep "WARNING: Avoiding applying x -> w rename to x/b" out &&
@@ -2651,7 +2687,7 @@ test_expect_success '9d-check: N-way tra
 #   Expected: combined/{a,b,c,d,e,f,g,h,i,j,k,l}, CONFLICT(Nto1) warnings,
 #             dir1/yo, dir2/yo, dir3/yo, dirN/yo
 
-test_expect_success '9e-setup: N-to-1 whammo' '
+test_setup_9e () {
 	test_create_repo 9e &&
 	(
 		cd 9e &&
@@ -2694,15 +2730,16 @@ test_expect_success '9e-setup: N-to-1 wh
 		test_tick &&
 		git commit -m "B"
 	)
-'
+}
 
-test_expect_success C_LOCALE_OUTPUT '9e-check: N-to-1 whammo' '
+test_expect_success C_LOCALE_OUTPUT '9e: N-to-1 whammo' '
+	test_setup_9e &&
 	(
 		cd 9e &&
 
 		git checkout A^0 &&
 
-		test_must_fail git merge -s recursive B^0 >out &&
+		test_must_fail git -c merge.directoryRenames=true merge -s recursive B^0 >out &&
 		grep "CONFLICT (implicit dir rename): Cannot map more than one path to combined/yo" out >error_line &&
 		grep -q dir1/yo error_line &&
 		grep -q dir2/yo error_line &&
@@ -2743,7 +2780,7 @@ test_expect_success C_LOCALE_OUTPUT '9e-
 #   Commit B: goal/{a,b}/$more_files, goal/c
 #   Expected: priority/{a,b}/$more_files, priority/c
 
-test_expect_success '9f-setup: Renamed directory that only contained immediate subdirs' '
+test_setup_9f () {
 	test_create_repo 9f &&
 	(
 		cd 9f &&
@@ -2772,15 +2809,16 @@ test_expect_success '9f-setup: Renamed d
 		test_tick &&
 		git commit -m "B"
 	)
-'
+}
 
-test_expect_success '9f-check: Renamed directory that only contained immediate subdirs' '
+test_expect_success '9f: Renamed directory that only contained immediate subdirs' '
+	test_setup_9f &&
 	(
 		cd 9f &&
 
 		git checkout A^0 &&
 
-		git merge -s recursive B^0 &&
+		git -c merge.directoryRenames=true merge -s recursive B^0 &&
 
 		git ls-files -s >out &&
 		test_line_count = 4 out &&
@@ -2807,7 +2845,7 @@ test_expect_success '9f-check: Renamed d
 #   Commit B: goal/{a,b}/$more_files, goal/c
 #   Expected: priority/{alpha,bravo}/$more_files, priority/c
 
-test_expect_success '9g-setup: Renamed directory that only contained immediate subdirs, immediate subdirs renamed' '
+test_setup_9g () {
 	test_create_repo 9g &&
 	(
 		cd 9g &&
@@ -2839,15 +2877,15 @@ test_expect_success '9g-setup: Renamed d
 		test_tick &&
 		git commit -m "B"
 	)
-'
+}
 
-test_expect_failure '9g-check: Renamed directory that only contained immediate subdirs, immediate subdirs renamed' '
+test_expect_failure '9g: Renamed directory that only contained immediate subdirs, immediate subdirs renamed' '
 	(
 		cd 9g &&
 
 		git checkout A^0 &&
 
-		git merge -s recursive B^0 &&
+		git -c merge.directoryRenames=true merge -s recursive B^0 &&
 
 		git ls-files -s >out &&
 		test_line_count = 4 out &&
@@ -2875,7 +2913,7 @@ test_expect_failure '9g-check: Renamed d
 #   Expected: y/{b,c}, x/d_2
 #   NOTE: If we applied the z/ -> y/ rename to z/d, then we'd end up with
 #         a rename/rename(1to2) conflict (z/d -> y/d vs. x/d)
-test_expect_success '9h-setup: Avoid dir rename on merely modified path' '
+test_setup_9h () {
 	test_create_repo 9h &&
 	(
 		cd 9h &&
@@ -2908,15 +2946,16 @@ test_expect_success '9h-setup: Avoid dir
 		test_tick &&
 		git commit -m "B"
 	)
-'
+}
 
-test_expect_success '9h-check: Avoid dir rename on merely modified path' '
+test_expect_success '9h: Avoid dir rename on merely modified path' '
+	test_setup_9h &&
 	(
 		cd 9h &&
 
 		git checkout A^0 &&
 
-		git merge -s recursive B^0 &&
+		git -c merge.directoryRenames=true merge -s recursive B^0 &&
 
 		git ls-files -s >out &&
 		test_line_count = 3 out &&
@@ -2955,7 +2994,7 @@ test_expect_success '9h-check: Avoid dir
 #   Expected: Aborted Merge +
 #       ERROR_MSG(untracked working tree files would be overwritten by merge)
 
-test_expect_success '10a-setup: Overwrite untracked with normal rename/delete' '
+test_setup_10a () {
 	test_create_repo 10a &&
 	(
 		cd 10a &&
@@ -2981,9 +3020,10 @@ test_expect_success '10a-setup: Overwrit
 		test_tick &&
 		git commit -m "B"
 	)
-'
+}
 
-test_expect_success '10a-check: Overwrite untracked with normal rename/delete' '
+test_expect_success '10a: Overwrite untracked with normal rename/delete' '
+	test_setup_10a &&
 	(
 		cd 10a &&
 
@@ -2991,7 +3031,7 @@ test_expect_success '10a-check: Overwrit
 		echo very >z/c &&
 		echo important >z/d &&
 
-		test_must_fail git merge -s recursive B^0 >out 2>err &&
+		test_must_fail git -c merge.directoryRenames=true merge -s recursive B^0 >out 2>err &&
 		test_i18ngrep "The following untracked working tree files would be overwritten by merge" err &&
 
 		git ls-files -s >out &&
@@ -3019,7 +3059,7 @@ test_expect_success '10a-check: Overwrit
 #             z/c_1 -> z/d_1 rename recorded at stage 3 for y/d +
 #       ERROR_MSG(refusing to lose untracked file at 'y/d')
 
-test_expect_success '10b-setup: Overwrite untracked with dir rename + delete' '
+test_setup_10b () {
 	test_create_repo 10b &&
 	(
 		cd 10b &&
@@ -3048,9 +3088,10 @@ test_expect_success '10b-setup: Overwrit
 		test_tick &&
 		git commit -m "B"
 	)
-'
+}
 
-test_expect_success '10b-check: Overwrite untracked with dir rename + delete' '
+test_expect_success '10b: Overwrite untracked with dir rename + delete' '
+	test_setup_10b &&
 	(
 		cd 10b &&
 
@@ -3059,7 +3100,7 @@ test_expect_success '10b-check: Overwrit
 		echo important >y/d &&
 		echo contents >y/e &&
 
-		test_must_fail git merge -s recursive B^0 >out 2>err &&
+		test_must_fail git -c merge.directoryRenames=true merge -s recursive B^0 >out 2>err &&
 		test_i18ngrep "CONFLICT (rename/delete).*Version B\^0 of y/d left in tree at y/d~B\^0" out &&
 		test_i18ngrep "Error: Refusing to lose untracked file at y/e; writing to y/e~B\^0 instead" out &&
 
@@ -3096,10 +3137,10 @@ test_expect_success '10b-check: Overwrit
 #             y/c~B^0 +
 #             ERROR_MSG(Refusing to lose untracked file at y/c)
 
-test_expect_success '10c-setup: Overwrite untracked with dir rename/rename(1to2)' '
-	test_create_repo 10c &&
+test_setup_10c () {
+	test_create_repo 10c_$1 &&
 	(
-		cd 10c &&
+		cd 10c_$1 &&
 
 		mkdir z x &&
 		echo a >z/a &&
@@ -3126,16 +3167,17 @@ test_expect_success '10c-setup: Overwrit
 		test_tick &&
 		git commit -m "B"
 	)
-'
+}
 
-test_expect_success '10c-check: Overwrite untracked with dir rename/rename(1to2)' '
+test_expect_success '10c1: Overwrite untracked with dir rename/rename(1to2)' '
+	test_setup_10c 1 &&
 	(
-		cd 10c &&
+		cd 10c_1 &&
 
 		git checkout A^0 &&
 		echo important >y/c &&
 
-		test_must_fail git merge -s recursive B^0 >out 2>err &&
+		test_must_fail git -c merge.directoryRenames=true merge -s recursive B^0 >out 2>err &&
 		test_i18ngrep "CONFLICT (rename/rename)" out &&
 		test_i18ngrep "Refusing to lose untracked file at y/c; adding as y/c~B\^0 instead" out &&
 
@@ -3161,15 +3203,53 @@ test_expect_success '10c-check: Overwrit
 	)
 '
 
+test_expect_success '10c2: Overwrite untracked with dir rename/rename(1to2), other direction' '
+	test_setup_10c 2 &&
+	(
+		cd 10c_2 &&
+
+		git reset --hard &&
+		git clean -fdqx &&
+
+		git checkout B^0 &&
+		mkdir y &&
+		echo important >y/c &&
+
+		test_must_fail git -c merge.directoryRenames=true merge -s recursive A^0 >out 2>err &&
+		test_i18ngrep "CONFLICT (rename/rename)" out &&
+		test_i18ngrep "Refusing to lose untracked file at y/c; adding as y/c~HEAD instead" out &&
+
+		git ls-files -s >out &&
+		test_line_count = 6 out &&
+		git ls-files -u >out &&
+		test_line_count = 3 out &&
+		git ls-files -o >out &&
+		test_line_count = 3 out &&
+
+		git rev-parse >actual \
+			:0:y/a :0:y/b :0:x/d :1:x/c :3:w/c :2:y/c &&
+		git rev-parse >expect \
+			 O:z/a  O:z/b  O:x/d  O:x/c  O:x/c  O:x/c &&
+		test_cmp expect actual &&
+
+		git hash-object y/c~HEAD >actual &&
+		git rev-parse O:x/c >expect &&
+		test_cmp expect actual &&
+
+		echo important >expect &&
+		test_cmp expect y/c
+	)
+'
+
 # Testcase 10d, Delete untracked w/ dir rename/rename(2to1)
 #   Commit O: z/{a,b,c_1},        x/{d,e,f_2}
 #   Commit A: y/{a,b},            x/{d,e,f_2,wham_1} + untracked y/wham
 #   Commit B: z/{a,b,c_1,wham_2}, y/{d,e}
-#   Expected: Failed Merge; y/{a,b,d,e} + untracked y/{wham,wham~B^0,wham~HEAD}+
+#   Expected: Failed Merge; y/{a,b,d,e} + untracked y/{wham,wham~merged}+
 #             CONFLICT(rename/rename) z/c_1 vs x/f_2 -> y/wham
 #             ERROR_MSG(Refusing to lose untracked file at y/wham)
 
-test_expect_success '10d-setup: Delete untracked with dir rename/rename(2to1)' '
+test_setup_10d () {
 	test_create_repo 10d &&
 	(
 		cd 10d &&
@@ -3201,16 +3281,17 @@ test_expect_success '10d-setup: Delete u
 		test_tick &&
 		git commit -m "B"
 	)
-'
+}
 
-test_expect_success '10d-check: Delete untracked with dir rename/rename(2to1)' '
+test_expect_success '10d: Delete untracked with dir rename/rename(2to1)' '
+	test_setup_10d &&
 	(
 		cd 10d &&
 
 		git checkout A^0 &&
 		echo important >y/wham &&
 
-		test_must_fail git merge -s recursive B^0 >out 2>err &&
+		test_must_fail git -c merge.directoryRenames=true merge -s recursive B^0 >out 2>err &&
 		test_i18ngrep "CONFLICT (rename/rename)" out &&
 		test_i18ngrep "Refusing to lose untracked file at y/wham" out &&
 
@@ -3219,7 +3300,7 @@ test_expect_success '10d-check: Delete u
 		git ls-files -u >out &&
 		test_line_count = 2 out &&
 		git ls-files -o >out &&
-		test_line_count = 4 out &&
+		test_line_count = 3 out &&
 
 		git rev-parse >actual \
 			:0:y/a :0:y/b :0:y/d :0:y/e :2:y/wham :3:y/wham &&
@@ -3232,11 +3313,16 @@ test_expect_success '10d-check: Delete u
 		echo important >expect &&
 		test_cmp expect y/wham &&
 
-		git hash-object >actual \
-			y/wham~B^0 y/wham~HEAD &&
-		git rev-parse >expect \
-			O:x/f      O:z/c &&
-		test_cmp expect actual
+		# Test that the two-way merge in y/wham~merged is as expected
+		git cat-file -p :2:y/wham >expect &&
+		git cat-file -p :3:y/wham >other &&
+		>empty &&
+		test_must_fail git merge-file \
+			-L "HEAD" \
+			-L "" \
+			-L "B^0" \
+			expect empty other &&
+		test_cmp expect y/wham~merged
 	)
 '
 
@@ -3246,7 +3332,7 @@ test_expect_success '10d-check: Delete u
 #   Commit B: z/{a,b,c}
 #   Expected: y/{a,b,c} + untracked z/c
 
-test_expect_success '10e-setup: Does git complain about untracked file that is not really in the way?' '
+test_setup_10e () {
 	test_create_repo 10e &&
 	(
 		cd 10e &&
@@ -3273,9 +3359,9 @@ test_expect_success '10e-setup: Does git
 		test_tick &&
 		git commit -m "B"
 	)
-'
+}
 
-test_expect_failure '10e-check: Does git complain about untracked file that is not really in the way?' '
+test_expect_failure '10e: Does git complain about untracked file that is not really in the way?' '
 	(
 		cd 10e &&
 
@@ -3283,7 +3369,7 @@ test_expect_failure '10e-check: Does git
 		mkdir z &&
 		echo random >z/c &&
 
-		git merge -s recursive B^0 >out 2>err &&
+		git -c merge.directoryRenames=true merge -s recursive B^0 >out 2>err &&
 		test_i18ngrep ! "following untracked working tree files would be overwritten by merge" err &&
 
 		git ls-files -s >out &&
@@ -3327,7 +3413,7 @@ test_expect_failure '10e-check: Does git
 #             z/c~HEAD with contents of B:z/b_v2,
 #             z/c with uncommitted mods on top of A:z/c_v1
 
-test_expect_success '11a-setup: Avoid losing dirty contents with simple rename' '
+test_setup_11a () {
 	test_create_repo 11a &&
 	(
 		cd 11a &&
@@ -3354,16 +3440,17 @@ test_expect_success '11a-setup: Avoid lo
 		test_tick &&
 		git commit -m "B"
 	)
-'
+}
 
-test_expect_success '11a-check: Avoid losing dirty contents with simple rename' '
+test_expect_success '11a: Avoid losing dirty contents with simple rename' '
+	test_setup_11a &&
 	(
 		cd 11a &&
 
 		git checkout A^0 &&
 		echo stuff >>z/c &&
 
-		test_must_fail git merge -s recursive B^0 >out 2>err &&
+		test_must_fail git -c merge.directoryRenames=true merge -s recursive B^0 >out 2>err &&
 		test_i18ngrep "Refusing to lose dirty file at z/c" out &&
 
 		test_seq 1 10 >expected &&
@@ -3397,7 +3484,7 @@ test_expect_success '11a-check: Avoid lo
 #             ERROR_MSG(Refusing to lose dirty file at z/c)
 
 
-test_expect_success '11b-setup: Avoid losing dirty file involved in directory rename' '
+test_setup_11b () {
 	test_create_repo 11b &&
 	(
 		cd 11b &&
@@ -3426,16 +3513,17 @@ test_expect_success '11b-setup: Avoid lo
 		test_tick &&
 		git commit -m "B"
 	)
-'
+}
 
-test_expect_success '11b-check: Avoid losing dirty file involved in directory rename' '
+test_expect_success '11b: Avoid losing dirty file involved in directory rename' '
+	test_setup_11b &&
 	(
 		cd 11b &&
 
 		git checkout A^0 &&
 		echo stuff >>z/c &&
 
-		git merge -s recursive B^0 >out 2>err &&
+		git -c merge.directoryRenames=true merge -s recursive B^0 >out 2>err &&
 		test_i18ngrep "Refusing to lose dirty file at z/c" out &&
 
 		grep -q stuff z/c &&
@@ -3471,7 +3559,7 @@ test_expect_success '11b-check: Avoid lo
 #   Expected: Abort_msg("following files would be overwritten by merge") +
 #             y/c left untouched (still has uncommitted mods)
 
-test_expect_success '11c-setup: Avoid losing not-uptodate with rename + D/F conflict' '
+test_setup_11c () {
 	test_create_repo 11c &&
 	(
 		cd 11c &&
@@ -3501,16 +3589,17 @@ test_expect_success '11c-setup: Avoid lo
 		test_tick &&
 		git commit -m "B"
 	)
-'
+}
 
-test_expect_success '11c-check: Avoid losing not-uptodate with rename + D/F conflict' '
+test_expect_success '11c: Avoid losing not-uptodate with rename + D/F conflict' '
+	test_setup_11c &&
 	(
 		cd 11c &&
 
 		git checkout A^0 &&
 		echo stuff >>y/c &&
 
-		test_must_fail git merge -s recursive B^0 >out 2>err &&
+		test_must_fail git -c merge.directoryRenames=true merge -s recursive B^0 >out 2>err &&
 		test_i18ngrep "following files would be overwritten by merge" err &&
 
 		grep -q stuff y/c &&
@@ -3537,7 +3626,7 @@ test_expect_success '11c-check: Avoid lo
 #             Warning_Msg("Refusing to lose dirty file at z/c) +
 #             y/{a,c~HEAD,c/d}, x/b, now-untracked z/c_v1 with uncommitted mods
 
-test_expect_success '11d-setup: Avoid losing not-uptodate with rename + D/F conflict' '
+test_setup_11d () {
 	test_create_repo 11d &&
 	(
 		cd 11d &&
@@ -3568,22 +3657,23 @@ test_expect_success '11d-setup: Avoid lo
 		test_tick &&
 		git commit -m "B"
 	)
-'
+}
 
-test_expect_success '11d-check: Avoid losing not-uptodate with rename + D/F conflict' '
+test_expect_success '11d: Avoid losing not-uptodate with rename + D/F conflict' '
+	test_setup_11d &&
 	(
 		cd 11d &&
 
 		git checkout A^0 &&
 		echo stuff >>z/c &&
 
-		test_must_fail git merge -s recursive B^0 >out 2>err &&
+		test_must_fail git -c merge.directoryRenames=true merge -s recursive B^0 >out 2>err &&
 		test_i18ngrep "Refusing to lose dirty file at z/c" out &&
 
 		grep -q stuff z/c &&
 		test_seq 1 10 >expected &&
 		echo stuff >>expected &&
-		test_cmp expected z/c
+		test_cmp expected z/c &&
 
 		git ls-files -s >out &&
 		test_line_count = 4 out &&
@@ -3615,7 +3705,7 @@ test_expect_success '11d-check: Avoid lo
 #             y/c~HEAD has A:y/c_2 contents
 #             y/c has dirty file from before merge
 
-test_expect_success '11e-setup: Avoid deleting not-uptodate with dir rename/rename(1to2)/add' '
+test_setup_11e () {
 	test_create_repo 11e &&
 	(
 		cd 11e &&
@@ -3647,16 +3737,17 @@ test_expect_success '11e-setup: Avoid de
 		test_tick &&
 		git commit -m "B"
 	)
-'
+}
 
-test_expect_success '11e-check: Avoid deleting not-uptodate with dir rename/rename(1to2)/add' '
+test_expect_success '11e: Avoid deleting not-uptodate with dir rename/rename(1to2)/add' '
+	test_setup_11e &&
 	(
 		cd 11e &&
 
 		git checkout A^0 &&
 		echo mods >>y/c &&
 
-		test_must_fail git merge -s recursive B^0 >out 2>err &&
+		test_must_fail git -c merge.directoryRenames=true merge -s recursive B^0 >out 2>err &&
 		test_i18ngrep "CONFLICT (rename/rename)" out &&
 		test_i18ngrep "Refusing to lose dirty file at y/c" out &&
 
@@ -3665,7 +3756,7 @@ test_expect_success '11e-check: Avoid de
 		git ls-files -u >out &&
 		test_line_count = 4 out &&
 		git ls-files -o >out &&
-		test_line_count = 4 out &&
+		test_line_count = 3 out &&
 
 		echo different >expected &&
 		echo mods >>expected &&
@@ -3677,11 +3768,17 @@ test_expect_success '11e-check: Avoid de
 			 O:z/a  O:z/b  O:x/d  O:x/c  O:x/c  A:y/c  O:x/c &&
 		test_cmp expect actual &&
 
-		git hash-object >actual \
-			y/c~B^0 y/c~HEAD &&
-		git rev-parse >expect \
-			O:x/c   A:y/c &&
-		test_cmp expect actual
+		# See if y/c~merged has expected contents; requires manually
+		# doing the expected file merge
+		git cat-file -p A:y/c >c1 &&
+		git cat-file -p B:z/c >c2 &&
+		>empty &&
+		test_must_fail git merge-file \
+			-L "HEAD" \
+			-L "" \
+			-L "B^0" \
+			c1 empty c2 &&
+		test_cmp c1 y/c~merged
 	)
 '
 
@@ -3689,12 +3786,12 @@ test_expect_success '11e-check: Avoid de
 #   Commit O: z/{a,b},        x/{c_1,d_2}
 #   Commit A: y/{a,b,wham_1}, x/d_2, except y/wham has uncommitted mods
 #   Commit B: z/{a,b,wham_2}, x/c_1
-#   Expected: Failed Merge; y/{a,b} + untracked y/{wham~B^0,wham~B^HEAD} +
+#   Expected: Failed Merge; y/{a,b} + untracked y/{wham~merged} +
 #             y/wham with dirty changes from before merge +
 #             CONFLICT(rename/rename) x/c vs x/d -> y/wham
 #             ERROR_MSG(Refusing to lose dirty file at y/wham)
 
-test_expect_success '11f-setup: Avoid deleting not-uptodate with dir rename/rename(2to1)' '
+test_setup_11f () {
 	test_create_repo 11f &&
 	(
 		cd 11f &&
@@ -3723,16 +3820,17 @@ test_expect_success '11f-setup: Avoid de
 		test_tick &&
 		git commit -m "B"
 	)
-'
+}
 
-test_expect_success '11f-check: Avoid deleting not-uptodate with dir rename/rename(2to1)' '
+test_expect_success '11f: Avoid deleting not-uptodate with dir rename/rename(2to1)' '
+	test_setup_11f &&
 	(
 		cd 11f &&
 
 		git checkout A^0 &&
 		echo important >>y/wham &&
 
-		test_must_fail git merge -s recursive B^0 >out 2>err &&
+		test_must_fail git -c merge.directoryRenames=true merge -s recursive B^0 >out 2>err &&
 		test_i18ngrep "CONFLICT (rename/rename)" out &&
 		test_i18ngrep "Refusing to lose dirty file at y/wham" out &&
 
@@ -3741,24 +3839,30 @@ test_expect_success '11f-check: Avoid de
 		git ls-files -u >out &&
 		test_line_count = 2 out &&
 		git ls-files -o >out &&
-		test_line_count = 4 out &&
+		test_line_count = 3 out &&
 
 		test_seq 1 10 >expected &&
 		echo important >>expected &&
 		test_cmp expected y/wham &&
 
 		test_must_fail git rev-parse :1:y/wham &&
-		git hash-object >actual \
-			y/wham~B^0 y/wham~HEAD &&
-		git rev-parse >expect \
-			O:x/d      O:x/c &&
-		test_cmp expect actual &&
 
 		git rev-parse >actual \
 			:0:y/a :0:y/b :2:y/wham :3:y/wham &&
 		git rev-parse >expect \
 			 O:z/a  O:z/b  O:x/c     O:x/d &&
-		test_cmp expect actual
+		test_cmp expect actual &&
+
+		# Test that the two-way merge in y/wham~merged is as expected
+		git cat-file -p :2:y/wham >expect &&
+		git cat-file -p :3:y/wham >other &&
+		>empty &&
+		test_must_fail git merge-file \
+			-L "HEAD" \
+			-L "" \
+			-L "B^0" \
+			expect empty other &&
+		test_cmp expect y/wham~merged
 	)
 '
 
@@ -3776,7 +3880,7 @@ test_expect_success '11f-check: Avoid de
 #   Commit B: node1/{leaf1,leaf2,leaf5}, node2/{leaf3,leaf4,leaf6}
 #   Expected: node1/{leaf1,leaf2,leaf5,node2/{leaf3,leaf4,leaf6}}
 
-test_expect_success '12a-setup: Moving one directory hierarchy into another' '
+test_setup_12a () {
 	test_create_repo 12a &&
 	(
 		cd 12a &&
@@ -3806,15 +3910,16 @@ test_expect_success '12a-setup: Moving o
 		test_tick &&
 		git commit -m "B"
 	)
-'
+}
 
-test_expect_success '12a-check: Moving one directory hierarchy into another' '
+test_expect_success '12a: Moving one directory hierarchy into another' '
+	test_setup_12a &&
 	(
 		cd 12a &&
 
 		git checkout A^0 &&
 
-		git merge -s recursive B^0 &&
+		git -c merge.directoryRenames=true merge -s recursive B^0 &&
 
 		git ls-files -s >out &&
 		test_line_count = 6 out &&
@@ -3854,7 +3959,7 @@ test_expect_success '12a-check: Moving o
 #         To which, I can do no more than shrug my shoulders and say that
 #         even simple rules give weird results when given weird inputs.
 
-test_expect_success '12b-setup: Moving one directory hierarchy into another' '
+test_setup_12b () {
 	test_create_repo 12b &&
 	(
 		cd 12b &&
@@ -3882,15 +3987,16 @@ test_expect_success '12b-setup: Moving o
 		test_tick &&
 		git commit -m "B"
 	)
-'
+}
 
-test_expect_success '12b-check: Moving one directory hierarchy into another' '
+test_expect_success '12b: Moving two directory hierarchies into each other' '
+	test_setup_12b &&
 	(
 		cd 12b &&
 
 		git checkout A^0 &&
 
-		git merge -s recursive B^0 &&
+		git -c merge.directoryRenames=true merge -s recursive B^0 &&
 
 		git ls-files -s >out &&
 		test_line_count = 4 out &&
@@ -3920,7 +4026,7 @@ test_expect_success '12b-check: Moving o
 #   NOTE: This is *exactly* like 12c, except that every path is modified on
 #         each side of the merge.
 
-test_expect_success '12c-setup: Moving one directory hierarchy into another w/ content merge' '
+test_setup_12c () {
 	test_create_repo 12c &&
 	(
 		cd 12c &&
@@ -3952,15 +4058,16 @@ test_expect_success '12c-setup: Moving o
 		test_tick &&
 		git commit -m "B"
 	)
-'
+}
 
-test_expect_success '12c-check: Moving one directory hierarchy into another w/ content merge' '
+test_expect_success '12c: Moving one directory hierarchy into another w/ content merge' '
+	test_setup_12c &&
 	(
 		cd 12c &&
 
 		git checkout A^0 &&
 
-		test_must_fail git merge -s recursive B^0 &&
+		test_must_fail git -c merge.directoryRenames=true merge -s recursive B^0 &&
 
 		git ls-files -u >out &&
 		test_line_count = 12 out &&
@@ -3995,4 +4102,592 @@ test_expect_success '12c-check: Moving o
 	)
 '
 
+# Testcase 12d, Rename/merge of subdirectory into the root
+#   Commit O: a/b/subdir/foo
+#   Commit A: subdir/foo
+#   Commit B: a/b/subdir/foo, a/b/bar
+#   Expected: subdir/foo, bar
+
+test_setup_12d () {
+	test_create_repo 12d &&
+	(
+		cd 12d &&
+
+		mkdir -p a/b/subdir &&
+		test_commit a/b/subdir/foo &&
+
+		git branch O &&
+		git branch A &&
+		git branch B &&
+
+		git checkout A &&
+		mkdir subdir &&
+		git mv a/b/subdir/foo.t subdir/foo.t &&
+		test_tick &&
+		git commit -m "A" &&
+
+		git checkout B &&
+		test_commit a/b/bar
+	)
+}
+
+test_expect_success '12d: Rename/merge subdir into the root, variant 1' '
+	test_setup_12d &&
+	(
+		cd 12d &&
+
+		git checkout A^0 &&
+
+		git -c merge.directoryRenames=true merge -s recursive B^0 &&
+
+		git ls-files -s >out &&
+		test_line_count = 2 out &&
+
+		git rev-parse >actual \
+			HEAD:subdir/foo.t   HEAD:bar.t &&
+		git rev-parse >expect \
+			O:a/b/subdir/foo.t  B:a/b/bar.t &&
+		test_cmp expect actual &&
+
+		git hash-object bar.t >actual &&
+		git rev-parse B:a/b/bar.t >expect &&
+		test_cmp expect actual &&
+
+		test_must_fail git rev-parse HEAD:a/b/subdir/foo.t &&
+		test_must_fail git rev-parse HEAD:a/b/bar.t &&
+		test_path_is_missing a/ &&
+		test_path_is_file bar.t
+	)
+'
+
+# Testcase 12e, Rename/merge of subdirectory into the root
+#   Commit O: a/b/foo
+#   Commit A: foo
+#   Commit B: a/b/foo, a/b/bar
+#   Expected: foo, bar
+
+test_setup_12e () {
+	test_create_repo 12e &&
+	(
+		cd 12e &&
+
+		mkdir -p a/b &&
+		test_commit a/b/foo &&
+
+		git branch O &&
+		git branch A &&
+		git branch B &&
+
+		git checkout A &&
+		mkdir subdir &&
+		git mv a/b/foo.t foo.t &&
+		test_tick &&
+		git commit -m "A" &&
+
+		git checkout B &&
+		test_commit a/b/bar
+	)
+}
+
+test_expect_success '12e: Rename/merge subdir into the root, variant 2' '
+	test_setup_12e &&
+	(
+		cd 12e &&
+
+		git checkout A^0 &&
+
+		git -c merge.directoryRenames=true merge -s recursive B^0 &&
+
+		git ls-files -s >out &&
+		test_line_count = 2 out &&
+
+		git rev-parse >actual \
+			HEAD:foo.t   HEAD:bar.t &&
+		git rev-parse >expect \
+			O:a/b/foo.t  B:a/b/bar.t &&
+		test_cmp expect actual &&
+
+		git hash-object bar.t >actual &&
+		git rev-parse B:a/b/bar.t >expect &&
+		test_cmp expect actual &&
+
+		test_must_fail git rev-parse HEAD:a/b/foo.t &&
+		test_must_fail git rev-parse HEAD:a/b/bar.t &&
+		test_path_is_missing a/ &&
+		test_path_is_file bar.t
+	)
+'
+
+###########################################################################
+# SECTION 13: Checking informational and conflict messages
+#
+# A year after directory rename detection became the default, it was
+# instead decided to report conflicts on the pathname on the basis that
+# some users may expect the new files added or moved into a directory to
+# be unrelated to all the other files in that directory, and thus that
+# directory rename detection is unexpected.  Test that the messages printed
+# match our expectation.
+###########################################################################
+
+# Testcase 13a, Basic directory rename with newly added files
+#   Commit O: z/{b,c}
+#   Commit A: y/{b,c}
+#   Commit B: z/{b,c,d,e/f}
+#   Expected: y/{b,c,d,e/f}, with notices/conflicts for both y/d and y/e/f
+
+test_setup_13a () {
+	test_create_repo 13a_$1 &&
+	(
+		cd 13a_$1 &&
+
+		mkdir z &&
+		echo b >z/b &&
+		echo c >z/c &&
+		git add z &&
+		test_tick &&
+		git commit -m "O" &&
+
+		git branch O &&
+		git branch A &&
+		git branch B &&
+
+		git checkout A &&
+		git mv z y &&
+		test_tick &&
+		git commit -m "A" &&
+
+		git checkout B &&
+		echo d >z/d &&
+		mkdir z/e &&
+		echo f >z/e/f &&
+		git add z/d z/e/f &&
+		test_tick &&
+		git commit -m "B"
+	)
+}
+
+test_expect_success '13a(conflict): messages for newly added files' '
+	test_setup_13a conflict &&
+	(
+		cd 13a_conflict &&
+
+		git checkout A^0 &&
+
+		test_must_fail git merge -s recursive B^0 >out 2>err &&
+
+		test_i18ngrep CONFLICT..file.location.*z/e/f.added.in.B^0.*y/e/f out &&
+		test_i18ngrep CONFLICT..file.location.*z/d.added.in.B^0.*y/d out &&
+
+		git ls-files >paths &&
+		! grep z/ paths &&
+		grep "y/[de]" paths &&
+
+		test_path_is_missing z/d &&
+		test_path_is_file    y/d &&
+		test_path_is_missing z/e/f &&
+		test_path_is_file    y/e/f
+	)
+'
+
+test_expect_success '13a(info): messages for newly added files' '
+	test_setup_13a info &&
+	(
+		cd 13a_info &&
+
+		git reset --hard &&
+		git checkout A^0 &&
+
+		git -c merge.directoryRenames=true merge -s recursive B^0 >out 2>err &&
+
+		test_i18ngrep Path.updated:.*z/e/f.added.in.B^0.*y/e/f out &&
+		test_i18ngrep Path.updated:.*z/d.added.in.B^0.*y/d out &&
+
+		git ls-files >paths &&
+		! grep z/ paths &&
+		grep "y/[de]" paths &&
+
+		test_path_is_missing z/d &&
+		test_path_is_file    y/d &&
+		test_path_is_missing z/e/f &&
+		test_path_is_file    y/e/f
+	)
+'
+
+# Testcase 13b, Transitive rename with conflicted content merge and default
+#               "conflict" setting
+#   (Related to testcase 1c, 9b)
+#   Commit O: z/{b,c},   x/d_1
+#   Commit A: y/{b,c},   x/d_2
+#   Commit B: z/{b,c,d_3}
+#   Expected: y/{b,c,d_merged}, with two conflict messages for y/d,
+#             one about content, and one about file location
+
+test_setup_13b () {
+	test_create_repo 13b_$1 &&
+	(
+		cd 13b_$1 &&
+
+		mkdir x &&
+		mkdir z &&
+		test_seq 1 10 >x/d &&
+		echo b >z/b &&
+		echo c >z/c &&
+		git add x z &&
+		test_tick &&
+		git commit -m "O" &&
+
+		git branch O &&
+		git branch A &&
+		git branch B &&
+
+		git checkout A &&
+		git mv z y &&
+		echo 11 >>x/d &&
+		git add x/d &&
+		test_tick &&
+		git commit -m "A" &&
+
+		git checkout B &&
+		echo eleven >>x/d &&
+		git mv x/d z/d &&
+		git add z/d &&
+		test_tick &&
+		git commit -m "B"
+	)
+}
+
+test_expect_success '13b(conflict): messages for transitive rename with conflicted content' '
+	test_setup_13b conflict &&
+	(
+		cd 13b_conflict &&
+
+		git checkout A^0 &&
+
+		test_must_fail git merge -s recursive B^0 >out 2>err &&
+
+		test_i18ngrep CONFLICT.*content.*Merge.conflict.in.y/d out &&
+		test_i18ngrep CONFLICT..file.location.*x/d.renamed.to.z/d.*moved.to.y/d out &&
+
+		git ls-files >paths &&
+		! grep z/ paths &&
+		grep "y/d" paths &&
+
+		test_path_is_missing z/d &&
+		test_path_is_file    y/d
+	)
+'
+
+test_expect_success '13b(info): messages for transitive rename with conflicted content' '
+	test_setup_13b info &&
+	(
+		cd 13b_info &&
+
+		git reset --hard &&
+		git checkout A^0 &&
+
+		test_must_fail git -c merge.directoryRenames=true merge -s recursive B^0 >out 2>err &&
+
+		test_i18ngrep CONFLICT.*content.*Merge.conflict.in.y/d out &&
+		test_i18ngrep Path.updated:.*x/d.renamed.to.z/d.in.B^0.*moving.it.to.y/d out &&
+
+		git ls-files >paths &&
+		! grep z/ paths &&
+		grep "y/d" paths &&
+
+		test_path_is_missing z/d &&
+		test_path_is_file    y/d
+	)
+'
+
+# Testcase 13c, Rename/rename(1to1) due to directory rename
+#   Commit O: z/{b,c},   x/{d,e}
+#   Commit A: y/{b,c,d}, x/e
+#   Commit B: z/{b,c,d}, x/e
+#   Expected: y/{b,c,d}, with info or conflict messages for d (
+#             A: renamed x/d -> z/d; B: renamed z/ -> y/ AND renamed x/d to y/d
+#             One could argue A had partial knowledge of what was done with
+#             d and B had full knowledge, but that's a slippery slope as
+#             shown in testcase 13d.
+
+test_setup_13c () {
+	test_create_repo 13c_$1 &&
+	(
+		cd 13c_$1 &&
+
+		mkdir x &&
+		mkdir z &&
+		test_seq 1 10 >x/d &&
+		echo e >x/e &&
+		echo b >z/b &&
+		echo c >z/c &&
+		git add x z &&
+		test_tick &&
+		git commit -m "O" &&
+
+		git branch O &&
+		git branch A &&
+		git branch B &&
+
+		git checkout A &&
+		git mv z y &&
+		git mv x/d y/ &&
+		test_tick &&
+		git commit -m "A" &&
+
+		git checkout B &&
+		git mv x/d z/d &&
+		git add z/d &&
+		test_tick &&
+		git commit -m "B"
+	)
+}
+
+test_expect_success '13c(conflict): messages for rename/rename(1to1) via transitive rename' '
+	test_setup_13c conflict &&
+	(
+		cd 13c_conflict &&
+
+		git checkout A^0 &&
+
+		test_must_fail git merge -s recursive B^0 >out 2>err &&
+
+		test_i18ngrep CONFLICT..file.location.*x/d.renamed.to.z/d.*moved.to.y/d out &&
+
+		git ls-files >paths &&
+		! grep z/ paths &&
+		grep "y/d" paths &&
+
+		test_path_is_missing z/d &&
+		test_path_is_file    y/d
+	)
+'
+
+test_expect_success '13c(info): messages for rename/rename(1to1) via transitive rename' '
+	test_setup_13c info &&
+	(
+		cd 13c_info &&
+
+		git reset --hard &&
+		git checkout A^0 &&
+
+		git -c merge.directoryRenames=true merge -s recursive B^0 >out 2>err &&
+
+		test_i18ngrep Path.updated:.*x/d.renamed.to.z/d.in.B^0.*moving.it.to.y/d out &&
+
+		git ls-files >paths &&
+		! grep z/ paths &&
+		grep "y/d" paths &&
+
+		test_path_is_missing z/d &&
+		test_path_is_file    y/d
+	)
+'
+
+# Testcase 13d, Rename/rename(1to1) due to directory rename on both sides
+#   Commit O: a/{z,y}, b/x,     c/w
+#   Commit A: a/z,     b/{y,x}, d/w
+#   Commit B: a/z,     d/x,     c/{y,w}
+#   Expected: a/z, d/{y,x,w} with no file location conflict for x
+#             Easy cases:
+#               * z is always in a; so it stays in a.
+#               * x starts in b, only modified on one side to move into d/
+#               * w starts in c, only modified on one side to move into d/
+#             Hard case:
+#               * A renames a/y to b/y, and B renames b/->d/ => a/y -> d/y
+#               * B renames a/y to c/y, and A renames c/->d/ => a/y -> d/y
+#               No conflict in where a/y ends up, so put it in d/y.
+
+test_setup_13d () {
+	test_create_repo 13d_$1 &&
+	(
+		cd 13d_$1 &&
+
+		mkdir a &&
+		mkdir b &&
+		mkdir c &&
+		echo z >a/z &&
+		echo y >a/y &&
+		echo x >b/x &&
+		echo w >c/w &&
+		git add a b c &&
+		test_tick &&
+		git commit -m "O" &&
+
+		git branch O &&
+		git branch A &&
+		git branch B &&
+
+		git checkout A &&
+		git mv a/y b/ &&
+		git mv c/ d/ &&
+		test_tick &&
+		git commit -m "A" &&
+
+		git checkout B &&
+		git mv a/y c/ &&
+		git mv b/ d/ &&
+		test_tick &&
+		git commit -m "B"
+	)
+}
+
+test_expect_success '13d(conflict): messages for rename/rename(1to1) via dual transitive rename' '
+	test_setup_13d conflict &&
+	(
+		cd 13d_conflict &&
+
+		git checkout A^0 &&
+
+		test_must_fail git merge -s recursive B^0 >out 2>err &&
+
+		test_i18ngrep CONFLICT..file.location.*a/y.renamed.to.b/y.*moved.to.d/y out &&
+		test_i18ngrep CONFLICT..file.location.*a/y.renamed.to.c/y.*moved.to.d/y out &&
+
+		git ls-files >paths &&
+		! grep b/ paths &&
+		! grep c/ paths &&
+		grep "d/y" paths &&
+
+		test_path_is_missing b/y &&
+		test_path_is_missing c/y &&
+		test_path_is_file    d/y
+	)
+'
+
+test_expect_success '13d(info): messages for rename/rename(1to1) via dual transitive rename' '
+	test_setup_13d info &&
+	(
+		cd 13d_info &&
+
+		git reset --hard &&
+		git checkout A^0 &&
+
+		git -c merge.directoryRenames=true merge -s recursive B^0 >out 2>err &&
+
+		test_i18ngrep Path.updated.*a/y.renamed.to.b/y.*moving.it.to.d/y out &&
+		test_i18ngrep Path.updated.*a/y.renamed.to.c/y.*moving.it.to.d/y out &&
+
+		git ls-files >paths &&
+		! grep b/ paths &&
+		! grep c/ paths &&
+		grep "d/y" paths &&
+
+		test_path_is_missing b/y &&
+		test_path_is_missing c/y &&
+		test_path_is_file    d/y
+	)
+'
+
+# Testcase 13e, directory rename in virtual merge base
+#
+# This testcase has a slightly different setup than all the above cases, in
+# order to include a recursive case:
+#
+#      A   C
+#      o - o
+#     / \ / \
+#  O o   X   ?
+#     \ / \ /
+#      o   o
+#      B   D
+#
+#   Commit O: a/{z,y}
+#   Commit A: b/{z,y}
+#   Commit B: a/{z,y,x}
+#   Commit C: b/{z,y,x}
+#   Commit D: b/{z,y}, a/x
+#   Expected: b/{z,y,x}  (sort of; see below for why this might not be expected)
+#
+#   NOTES: 'X' represents a virtual merge base.  With the default of
+#          directory rename detection yielding conflicts, merging A and B
+#          results in a conflict complaining about whether 'x' should be
+#          under 'a/' or 'b/'.  However, when creating the virtual merge
+#          base 'X', since virtual merge bases need to be written out as a
+#          tree, we cannot have a conflict, so some resolution has to be
+#          picked.
+#
+#          In choosing the right resolution, it's worth noting here that
+#          commits C & D are merges of A & B that choose different
+#          locations for 'x' (i.e. they resolve the conflict differently),
+#          and so it would be nice when merging C & D if git could detect
+#          this difference of opinion and report a conflict.  But the only
+#          way to do so that I can think of would be to have the virtual
+#          merge base place 'x' in some directory other than either 'a/' or
+#          'b/', which seems a little weird -- especially since it'd result
+#          in a rename/rename(1to2) conflict with a source path that never
+#          existed in any version.
+#
+#          So, for now, when directory rename detection is set to
+#          'conflict' just avoid doing directory rename detection at all in
+#          the recursive case.  This will not allow us to detect a conflict
+#          in the outer merge for this special kind of setup, but it at
+#          least avoids hitting a BUG().
+#
+test_setup_13e () {
+	test_create_repo 13e &&
+	(
+		cd 13e &&
+
+		mkdir a &&
+		echo z >a/z &&
+		echo y >a/y &&
+		git add a &&
+		test_tick &&
+		git commit -m "O" &&
+
+		git branch O &&
+		git branch A &&
+		git branch B &&
+
+		git checkout A &&
+		git mv a/ b/ &&
+		test_tick &&
+		git commit -m "A" &&
+
+		git checkout B &&
+		echo x >a/x &&
+		git add a &&
+		test_tick &&
+		git commit -m "B" &&
+
+		git branch C A &&
+		git branch D B &&
+
+		git checkout C &&
+		test_must_fail git -c merge.directoryRenames=conflict merge B &&
+		git add b/x &&
+		test_tick &&
+		git commit -m "C" &&
+
+
+		git checkout D &&
+		test_must_fail git -c merge.directoryRenames=conflict merge A &&
+		git add b/x &&
+		mkdir a &&
+		git mv b/x a/x &&
+		test_tick &&
+		git commit -m "D"
+	)
+}
+
+test_expect_success '13e: directory rename detection in recursive case' '
+	test_setup_13e &&
+	(
+		cd 13e &&
+
+		git checkout --quiet D^0 &&
+
+		git -c merge.directoryRenames=conflict merge -s recursive C^0 >out 2>err &&
+
+		test_i18ngrep ! CONFLICT out &&
+		test_i18ngrep ! BUG: err &&
+		test_i18ngrep ! core.dumped err &&
+		test_must_be_empty err &&
+
+		git ls-files >paths &&
+		! grep a/x paths &&
+		grep b/x paths
+	)
+'
+
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t6044-merge-unrelated-index-changes.sh 1.2.3+git2.25.1-1/git/t/t6044-merge-unrelated-index-changes.sh
--- 1.2.1+git2.18.0-1/git/t/t6044-merge-unrelated-index-changes.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t6044-merge-unrelated-index-changes.sh	2020-02-17 04:47:35.000000000 +0000
@@ -82,7 +82,8 @@ test_expect_success 'ff update, importan
 	touch subdir/e &&
 	git add subdir/e &&
 
-	test_must_fail git merge E^0
+	test_must_fail git merge E^0 &&
+	test_path_is_missing .git/MERGE_HEAD
 '
 
 test_expect_success 'resolve, trivial' '
@@ -91,7 +92,8 @@ test_expect_success 'resolve, trivial' '
 
 	touch random_file && git add random_file &&
 
-	test_must_fail git merge -s resolve C^0
+	test_must_fail git merge -s resolve C^0 &&
+	test_path_is_missing .git/MERGE_HEAD
 '
 
 test_expect_success 'resolve, non-trivial' '
@@ -100,7 +102,8 @@ test_expect_success 'resolve, non-trivia
 
 	touch random_file && git add random_file &&
 
-	test_must_fail git merge -s resolve D^0
+	test_must_fail git merge -s resolve D^0 &&
+	test_path_is_missing .git/MERGE_HEAD
 '
 
 test_expect_success 'recursive' '
@@ -109,7 +112,8 @@ test_expect_success 'recursive' '
 
 	touch random_file && git add random_file &&
 
-	test_must_fail git merge -s recursive C^0
+	test_must_fail git merge -s recursive C^0 &&
+	test_path_is_missing .git/MERGE_HEAD
 '
 
 test_expect_success 'recursive, when merge branch matches merge base' '
@@ -118,7 +122,45 @@ test_expect_success 'recursive, when mer
 
 	touch random_file && git add random_file &&
 
-	test_must_fail git merge -s recursive F^0
+	test_must_fail git merge -s recursive F^0 &&
+	test_path_is_missing .git/MERGE_HEAD
+'
+
+test_expect_success 'merge-recursive, when index==head but head!=HEAD' '
+	git reset --hard &&
+	git checkout C^0 &&
+
+	# Make index match B
+	git diff C B -- | git apply --cached &&
+	# Merge B & F, with B as "head"
+	git merge-recursive A -- B F > out &&
+	test_i18ngrep "Already up to date" out
+'
+
+test_expect_success 'recursive, when file has staged changes not matching HEAD nor what a merge would give' '
+	git reset --hard &&
+	git checkout B^0 &&
+
+	mkdir subdir &&
+	test_seq 1 10 >subdir/a &&
+	git add subdir/a &&
+
+	# We have staged changes; merge should error out
+	test_must_fail git merge -s recursive E^0 2>err &&
+	test_i18ngrep "changes to the following files would be overwritten" err
+'
+
+test_expect_success 'recursive, when file has staged changes matching what a merge would give' '
+	git reset --hard &&
+	git checkout B^0 &&
+
+	mkdir subdir &&
+	test_seq 1 11 >subdir/a &&
+	git add subdir/a &&
+
+	# We have staged changes; merge should error out
+	test_must_fail git merge -s recursive E^0 2>err &&
+	test_i18ngrep "changes to the following files would be overwritten" err
 '
 
 test_expect_success 'octopus, unrelated file touched' '
@@ -127,7 +169,8 @@ test_expect_success 'octopus, unrelated
 
 	touch random_file && git add random_file &&
 
-	test_must_fail git merge C^0 D^0
+	test_must_fail git merge C^0 D^0 &&
+	test_path_is_missing .git/MERGE_HEAD
 '
 
 test_expect_success 'octopus, related file removed' '
@@ -136,7 +179,8 @@ test_expect_success 'octopus, related fi
 
 	git rm b &&
 
-	test_must_fail git merge C^0 D^0
+	test_must_fail git merge C^0 D^0 &&
+	test_path_is_missing .git/MERGE_HEAD
 '
 
 test_expect_success 'octopus, related file modified' '
@@ -145,7 +189,8 @@ test_expect_success 'octopus, related fi
 
 	echo 12 >>a && git add a &&
 
-	test_must_fail git merge C^0 D^0
+	test_must_fail git merge C^0 D^0 &&
+	test_path_is_missing .git/MERGE_HEAD
 '
 
 test_expect_success 'ours' '
@@ -154,7 +199,8 @@ test_expect_success 'ours' '
 
 	touch random_file && git add random_file &&
 
-	test_must_fail git merge -s ours C^0
+	test_must_fail git merge -s ours C^0 &&
+	test_path_is_missing .git/MERGE_HEAD
 '
 
 test_expect_success 'subtree' '
@@ -163,7 +209,8 @@ test_expect_success 'subtree' '
 
 	touch random_file && git add random_file &&
 
-	test_must_fail git merge -s subtree E^0
+	test_must_fail git merge -s subtree E^0 &&
+	test_path_is_missing .git/MERGE_HEAD
 '
 
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t6046-merge-skip-unneeded-updates.sh 1.2.3+git2.25.1-1/git/t/t6046-merge-skip-unneeded-updates.sh
--- 1.2.1+git2.18.0-1/git/t/t6046-merge-skip-unneeded-updates.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t6046-merge-skip-unneeded-updates.sh	2020-02-17 04:47:35.000000000 +0000
@@ -36,10 +36,10 @@ test_description="merge cases"
 #   Commit B: b_3
 #   Expected: b_2
 
-test_expect_success '1a-setup: Modify(A)/Modify(B), change on B subset of A' '
-	test_create_repo 1a &&
+test_setup_1a () {
+	test_create_repo 1a_$1 &&
 	(
-		cd 1a &&
+		cd 1a_$1 &&
 
 		test_write_lines 1 2 3 4 5 6 7 8 9 10 >b &&
 		git add b &&
@@ -62,13 +62,12 @@ test_expect_success '1a-setup: Modify(A)
 		test_tick &&
 		git commit -m "B"
 	)
-'
+}
 
-test_expect_success '1a-check-L: Modify(A)/Modify(B), change on B subset of A' '
-	test_when_finished "git -C 1a reset --hard" &&
-	test_when_finished "git -C 1a clean -fd" &&
+test_expect_success '1a-L: Modify(A)/Modify(B), change on B subset of A' '
+	test_setup_1a L &&
 	(
-		cd 1a &&
+		cd 1a_L &&
 
 		git checkout A^0 &&
 
@@ -96,11 +95,10 @@ test_expect_success '1a-check-L: Modify(
 	)
 '
 
-test_expect_success '1a-check-R: Modify(A)/Modify(B), change on B subset of A' '
-	test_when_finished "git -C 1a reset --hard" &&
-	test_when_finished "git -C 1a clean -fd" &&
+test_expect_success '1a-R: Modify(A)/Modify(B), change on B subset of A' '
+	test_setup_1a R &&
 	(
-		cd 1a &&
+		cd 1a_R &&
 
 		git checkout B^0 &&
 
@@ -133,10 +131,10 @@ test_expect_success '1a-check-R: Modify(
 #   Commit B: c_1
 #   Expected: c_2
 
-test_expect_success '2a-setup: Modify(A)/rename(B)' '
-	test_create_repo 2a &&
+test_setup_2a () {
+	test_create_repo 2a_$1 &&
 	(
-		cd 2a &&
+		cd 2a_$1 &&
 
 		test_seq 1 10 >b &&
 		git add b &&
@@ -158,13 +156,12 @@ test_expect_success '2a-setup: Modify(A)
 		test_tick &&
 		git commit -m "B"
 	)
-'
+}
 
-test_expect_success '2a-check-L: Modify/rename, merge into modify side' '
-	test_when_finished "git -C 2a reset --hard" &&
-	test_when_finished "git -C 2a clean -fd" &&
+test_expect_success '2a-L: Modify/rename, merge into modify side' '
+	test_setup_2a L &&
 	(
-		cd 2a &&
+		cd 2a_L &&
 
 		git checkout A^0 &&
 
@@ -189,11 +186,10 @@ test_expect_success '2a-check-L: Modify/
 	)
 '
 
-test_expect_success '2a-check-R: Modify/rename, merge into rename side' '
-	test_when_finished "git -C 2a reset --hard" &&
-	test_when_finished "git -C 2a clean -fd" &&
+test_expect_success '2a-R: Modify/rename, merge into rename side' '
+	test_setup_2a R &&
 	(
-		cd 2a &&
+		cd 2a_R &&
 
 		git checkout B^0 &&
 
@@ -224,10 +220,10 @@ test_expect_success '2a-check-R: Modify/
 #   Commit B: b_3
 #   Expected: c_2
 
-test_expect_success '2b-setup: Rename+Mod(A)/Mod(B), B mods subset of A' '
-	test_create_repo 2b &&
+test_setup_2b () {
+	test_create_repo 2b_$1 &&
 	(
-		cd 2b &&
+		cd 2b_$1 &&
 
 		test_write_lines 1 2 3 4 5 6 7 8 9 10 >b &&
 		git add b &&
@@ -251,13 +247,12 @@ test_expect_success '2b-setup: Rename+Mo
 		test_tick &&
 		git commit -m "B"
 	)
-'
+}
 
-test_expect_success '2b-check-L: Rename+Mod(A)/Mod(B), B mods subset of A' '
-	test_when_finished "git -C 2b reset --hard" &&
-	test_when_finished "git -C 2b clean -fd" &&
+test_expect_success '2b-L: Rename+Mod(A)/Mod(B), B mods subset of A' '
+	test_setup_2b L &&
 	(
-		cd 2b &&
+		cd 2b_L &&
 
 		git checkout A^0 &&
 
@@ -288,11 +283,10 @@ test_expect_success '2b-check-L: Rename+
 	)
 '
 
-test_expect_success '2b-check-R: Rename+Mod(A)/Mod(B), B mods subset of A' '
-	test_when_finished "git -C 2b reset --hard" &&
-	test_when_finished "git -C 2b clean -fd" &&
+test_expect_success '2b-R: Rename+Mod(A)/Mod(B), B mods subset of A' '
+	test_setup_2b R &&
 	(
-		cd 2b &&
+		cd 2b_R &&
 
 		git checkout B^0 &&
 
@@ -332,7 +326,7 @@ test_expect_success '2b-check-R: Rename+
 #         skip the update, then we're in trouble.  This test verifies we do
 #         not make that particular mistake.
 
-test_expect_success '2c-setup: Modify b & add c VS rename b->c' '
+test_setup_2c () {
 	test_create_repo 2c &&
 	(
 		cd 2c &&
@@ -358,15 +352,18 @@ test_expect_success '2c-setup: Modify b
 		test_tick &&
 		git commit -m "B"
 	)
-'
+}
 
-test_expect_success '2c-check: Modify b & add c VS rename b->c' '
+test_expect_success '2c: Modify b & add c VS rename b->c' '
+	test_setup_2c &&
 	(
 		cd 2c &&
 
 		git checkout A^0 &&
 
-		GIT_MERGE_VERBOSITY=3 test_must_fail git merge -s recursive B^0 >out 2>err &&
+		GIT_MERGE_VERBOSITY=3 &&
+		export GIT_MERGE_VERBOSITY &&
+		test_must_fail git merge -s recursive B^0 >out 2>err &&
 
 		test_i18ngrep "CONFLICT (rename/add): Rename b->c" out &&
 		test_i18ngrep ! "Skipped c" out &&
@@ -426,10 +423,10 @@ test_expect_success '2c-check: Modify b
 #   Commit B: bq_1, bar/whatever
 #   Expected: bar/{bq_2, whatever}
 
-test_expect_success '3a-setup: bq_1->foo/bq_2 on A, foo/->bar/ on B' '
-	test_create_repo 3a &&
+test_setup_3a () {
+	test_create_repo 3a_$1 &&
 	(
-		cd 3a &&
+		cd 3a_$1 &&
 
 		mkdir foo &&
 		test_seq 1 10 >bq &&
@@ -454,17 +451,16 @@ test_expect_success '3a-setup: bq_1->foo
 		test_tick &&
 		git commit -m "B"
 	)
-'
+}
 
-test_expect_success '3a-check-L: bq_1->foo/bq_2 on A, foo/->bar/ on B' '
-	test_when_finished "git -C 3a reset --hard" &&
-	test_when_finished "git -C 3a clean -fd" &&
+test_expect_success '3a-L: bq_1->foo/bq_2 on A, foo/->bar/ on B' '
+	test_setup_3a L &&
 	(
-		cd 3a &&
+		cd 3a_L &&
 
 		git checkout A^0 &&
 
-		GIT_MERGE_VERBOSITY=3 git merge -s recursive B^0 >out 2>err &&
+		GIT_MERGE_VERBOSITY=3 git -c merge.directoryRenames=true merge -s recursive B^0 >out 2>err &&
 
 		test_i18ngrep ! "Skipped bar/bq" out &&
 		test_must_be_empty err &&
@@ -485,15 +481,14 @@ test_expect_success '3a-check-L: bq_1->f
 	)
 '
 
-test_expect_success '3a-check-R: bq_1->foo/bq_2 on A, foo/->bar/ on B' '
-	test_when_finished "git -C 3a reset --hard" &&
-	test_when_finished "git -C 3a clean -fd" &&
+test_expect_success '3a-R: bq_1->foo/bq_2 on A, foo/->bar/ on B' '
+	test_setup_3a R &&
 	(
-		cd 3a &&
+		cd 3a_R &&
 
 		git checkout B^0 &&
 
-		GIT_MERGE_VERBOSITY=3 git merge -s recursive A^0 >out 2>err &&
+		GIT_MERGE_VERBOSITY=3 git -c merge.directoryRenames=true merge -s recursive A^0 >out 2>err &&
 
 		test_i18ngrep ! "Skipped bar/bq" out &&
 		test_must_be_empty err &&
@@ -520,10 +515,10 @@ test_expect_success '3a-check-R: bq_1->f
 #   Commit B: bq_2, bar/whatever
 #   Expected: bar/{bq_2, whatever}
 
-test_expect_success '3b-setup: bq_1->foo/bq_2 on A, foo/->bar/ on B' '
-	test_create_repo 3b &&
+test_setup_3b () {
+	test_create_repo 3b_$1 &&
 	(
-		cd 3b &&
+		cd 3b_$1 &&
 
 		mkdir foo &&
 		test_seq 1 10 >bq &&
@@ -548,17 +543,16 @@ test_expect_success '3b-setup: bq_1->foo
 		test_tick &&
 		git commit -m "B"
 	)
-'
+}
 
-test_expect_success '3b-check-L: bq_1->foo/bq_2 on A, foo/->bar/ on B' '
-	test_when_finished "git -C 3b reset --hard" &&
-	test_when_finished "git -C 3b clean -fd" &&
+test_expect_success '3b-L: bq_1->foo/bq_2 on A, foo/->bar/ on B' '
+	test_setup_3b L &&
 	(
-		cd 3b &&
+		cd 3b_L &&
 
 		git checkout A^0 &&
 
-		GIT_MERGE_VERBOSITY=3 git merge -s recursive B^0 >out 2>err &&
+		GIT_MERGE_VERBOSITY=3 git -c merge.directoryRenames=true merge -s recursive B^0 >out 2>err &&
 
 		test_i18ngrep ! "Skipped bar/bq" out &&
 		test_must_be_empty err &&
@@ -579,15 +573,14 @@ test_expect_success '3b-check-L: bq_1->f
 	)
 '
 
-test_expect_success '3b-check-R: bq_1->foo/bq_2 on A, foo/->bar/ on B' '
-	test_when_finished "git -C 3b reset --hard" &&
-	test_when_finished "git -C 3b clean -fd" &&
+test_expect_success '3b-R: bq_1->foo/bq_2 on A, foo/->bar/ on B' '
+	test_setup_3b R &&
 	(
-		cd 3b &&
+		cd 3b_R &&
 
 		git checkout B^0 &&
 
-		GIT_MERGE_VERBOSITY=3 git merge -s recursive A^0 >out 2>err &&
+		GIT_MERGE_VERBOSITY=3 git -c merge.directoryRenames=true merge -s recursive A^0 >out 2>err &&
 
 		test_i18ngrep ! "Skipped bar/bq" out &&
 		test_must_be_empty err &&
@@ -619,7 +612,7 @@ test_expect_success '3b-check-R: bq_1->f
 #   Working copy: b_4
 #   Expected: b_2 for merge, b_4 in working copy
 
-test_expect_success '4a-setup: Change on A, change on B subset of A, dirty mods present' '
+test_setup_4a () {
 	test_create_repo 4a &&
 	(
 		cd 4a &&
@@ -645,7 +638,7 @@ test_expect_success '4a-setup: Change on
 		test_tick &&
 		git commit -m "B"
 	)
-'
+}
 
 # NOTE: For as long as we continue using unpack_trees() without index_only
 #   set to true, it will error out on a case like this claiming the the locally
@@ -653,9 +646,8 @@ test_expect_success '4a-setup: Change on
 #   correct requires doing the merge in-memory first, then realizing that no
 #   updates to the file are necessary, and thus that we can just leave the path
 #   alone.
-test_expect_failure '4a-check: Change on A, change on B subset of A, dirty mods present' '
-	test_when_finished "git -C 4a reset --hard" &&
-	test_when_finished "git -C 4a clean -fd" &&
+test_expect_failure '4a: Change on A, change on B subset of A, dirty mods present' '
+	test_setup_4a &&
 	(
 		cd 4a &&
 
@@ -693,7 +685,7 @@ test_expect_failure '4a-check: Change on
 #   Working copy: c_4
 #   Expected: c_2
 
-test_expect_success '4b-setup: Rename+Mod(A)/Mod(B), change on B subset of A, dirty mods present' '
+test_setup_4b () {
 	test_create_repo 4b &&
 	(
 		cd 4b &&
@@ -720,11 +712,10 @@ test_expect_success '4b-setup: Rename+Mo
 		test_tick &&
 		git commit -m "B"
 	)
-'
+}
 
-test_expect_success '4b-check: Rename+Mod(A)/Mod(B), change on B subset of A, dirty mods present' '
-	test_when_finished "git -C 4b reset --hard" &&
-	test_when_finished "git -C 4b clean -fd" &&
+test_expect_success '4b: Rename+Mod(A)/Mod(B), change on B subset of A, dirty mods present' '
+	test_setup_4b &&
 	(
 		cd 4b &&
 
diff -pruN 1.2.1+git2.18.0-1/git/t/t6047-diff3-conflict-markers.sh 1.2.3+git2.25.1-1/git/t/t6047-diff3-conflict-markers.sh
--- 1.2.1+git2.18.0-1/git/t/t6047-diff3-conflict-markers.sh	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t6047-diff3-conflict-markers.sh	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,202 @@
+#!/bin/sh
+
+test_description='recursive merge diff3 style conflict markers'
+
+. ./test-lib.sh
+
+# Setup:
+#          L1
+#            \
+#             ?
+#            /
+#          R1
+#
+# Where:
+#   L1 and R1 both have a file named 'content' but have no common history
+#
+
+test_expect_success 'setup no merge base' '
+	test_create_repo no_merge_base &&
+	(
+		cd no_merge_base &&
+
+		git checkout -b L &&
+		test_commit A content A &&
+
+		git checkout --orphan R &&
+		test_commit B content B
+	)
+'
+
+test_expect_success 'check no merge base' '
+	(
+		cd no_merge_base &&
+
+		git checkout L^0 &&
+
+		test_must_fail git -c merge.conflictstyle=diff3 merge --allow-unrelated-histories -s recursive R^0 &&
+
+		grep "|||||| empty tree" content
+	)
+'
+
+# Setup:
+#          L1
+#         /  \
+#   master    ?
+#         \  /
+#          R1
+#
+# Where:
+#   L1 and R1 have modified the same file ('content') in conflicting ways
+#
+
+test_expect_success 'setup unique merge base' '
+	test_create_repo unique_merge_base &&
+	(
+		cd unique_merge_base &&
+
+		test_commit base content "1
+2
+3
+4
+5
+" &&
+
+		git branch L &&
+		git branch R &&
+
+		git checkout L &&
+		test_commit L content "1
+2
+3
+4
+5
+7" &&
+
+		git checkout R &&
+		git rm content &&
+		test_commit R renamed "1
+2
+3
+4
+5
+six"
+	)
+'
+
+test_expect_success 'check unique merge base' '
+	(
+		cd unique_merge_base &&
+
+		git checkout L^0 &&
+		MASTER=$(git rev-parse --short master) &&
+
+		test_must_fail git -c merge.conflictstyle=diff3 merge -s recursive R^0 &&
+
+		grep "|||||| $MASTER:content" renamed
+	)
+'
+
+# Setup:
+#          L1---L2--L3
+#         /  \ /      \
+#   master    X1       ?
+#         \  / \      /
+#          R1---R2--R3
+#
+# Where:
+#   commits L1 and R1 have modified the same file in non-conflicting ways
+#   X1 is an auto-generated merge-base used when merging L1 and R1
+#   commits L2 and R2 are merges of R1 and L1 into L1 and R1, respectively
+#   commits L3 and R3 both modify 'content' in conflicting ways
+#
+
+test_expect_success 'setup multiple merge bases' '
+	test_create_repo multiple_merge_bases &&
+	(
+		cd multiple_merge_bases &&
+
+		test_commit initial content "1
+2
+3
+4
+5" &&
+
+		git branch L &&
+		git branch R &&
+
+		# Create L1
+		git checkout L &&
+		test_commit L1 content "0
+1
+2
+3
+4
+5" &&
+
+		# Create R1
+		git checkout R &&
+		test_commit R1 content "1
+2
+3
+4
+5
+6" &&
+
+		# Create L2
+		git checkout L &&
+		git merge R1 &&
+
+		# Create R2
+		git checkout R &&
+		git merge L1 &&
+
+		# Create L3
+		git checkout L &&
+		test_commit L3 content "0
+1
+2
+3
+4
+5
+A" &&
+
+		# Create R3
+		git checkout R &&
+		git rm content &&
+		test_commit R3 renamed "0
+2
+3
+4
+5
+six"
+	)
+'
+
+test_expect_success 'check multiple merge bases' '
+	(
+		cd multiple_merge_bases &&
+
+		git checkout L^0 &&
+
+		test_must_fail git -c merge.conflictstyle=diff3 merge -s recursive R^0 &&
+
+		grep "|||||| merged common ancestors:content" renamed
+	)
+'
+
+test_expect_success 'rebase describes fake ancestor base' '
+	test_create_repo rebase &&
+	(
+		cd rebase &&
+		test_commit base file &&
+		test_commit master file &&
+		git checkout -b side HEAD^ &&
+		test_commit side file &&
+		test_must_fail git -c merge.conflictstyle=diff3 rebase master &&
+		grep "||||||| constructed merge base" file
+	)
+'
+
+test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t6050-replace.sh 1.2.3+git2.25.1-1/git/t/t6050-replace.sh
--- 1.2.1+git2.18.0-1/git/t/t6050-replace.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t6050-replace.sh	2020-02-17 04:47:35.000000000 +0000
@@ -40,7 +40,8 @@ commit_peeling_shows_parents ()
 	test "$_found" = "$_parent" || return 1
 	_parent_number=$(( $_parent_number + 1 ))
     done &&
-    test_must_fail git rev-parse --verify $_commit^$_parent_number
+    test_must_fail git rev-parse --verify $_commit^$_parent_number 2>err &&
+    test_i18ngrep "Needed a single revision" err
 }
 
 commit_has_parents ()
@@ -113,6 +114,12 @@ test_expect_success 'test GIT_NO_REPLACE
      GIT_NO_REPLACE_OBJECTS=1 git show $HASH2 | grep "A U Thor"
 '
 
+test_expect_success 'test core.usereplacerefs config option' '
+	test_config core.usereplacerefs false &&
+	git cat-file commit $HASH2 | grep "author A U Thor" &&
+	git show $HASH2 | grep "A U Thor"
+'
+
 cat >tag.sig <<EOF
 object $HASH2
 type commit
@@ -127,8 +134,8 @@ test_expect_success 'tag replaced commit
 
 test_expect_success '"git fsck" works' '
      git fsck master >fsck_master.out &&
-     grep "dangling commit $R" fsck_master.out &&
-     grep "dangling tag $(cat .git/refs/tags/mytag)" fsck_master.out &&
+     test_i18ngrep "dangling commit $R" fsck_master.out &&
+     test_i18ngrep "dangling tag $(cat .git/refs/tags/mytag)" fsck_master.out &&
      test -z "$(git fsck)"
 '
 
@@ -387,9 +394,11 @@ test_expect_success 'replace ref cleanup
 '
 
 test_expect_success '--graft with and without already replaced object' '
-	test $(git log --oneline | wc -l) = 7 &&
+	git log --oneline >log &&
+	test_line_count = 7 log &&
 	git replace --graft $HASH5 &&
-	test $(git log --oneline | wc -l) = 3 &&
+	git log --oneline >log &&
+	test_line_count = 3 log &&
 	commit_has_parents $HASH5 &&
 	test_must_fail git replace --graft $HASH5 $HASH4 $HASH3 &&
 	git replace --force -g $HASH5 $HASH4 $HASH3 &&
@@ -397,6 +406,28 @@ test_expect_success '--graft with and wi
 	git replace -d $HASH5
 '
 
+test_expect_success '--graft using a tag as the new parent' '
+	git tag new_parent $HASH5 &&
+	git replace --graft $HASH7 new_parent &&
+	commit_has_parents $HASH7 $HASH5 &&
+	git replace -d $HASH7 &&
+	git tag -a -m "annotated new parent tag" annotated_new_parent $HASH5 &&
+	git replace --graft $HASH7 annotated_new_parent &&
+	commit_has_parents $HASH7 $HASH5 &&
+	git replace -d $HASH7
+'
+
+test_expect_success '--graft using a tag as the replaced object' '
+	git tag replaced_object $HASH7 &&
+	git replace --graft replaced_object $HASH5 &&
+	commit_has_parents $HASH7 $HASH5 &&
+	git replace -d $HASH7 &&
+	git tag -a -m "annotated replaced object tag" annotated_replaced_object $HASH7 &&
+	git replace --graft annotated_replaced_object $HASH5 &&
+	commit_has_parents $HASH7 $HASH5 &&
+	git replace -d $HASH7
+'
+
 test_expect_success GPG 'set up a signed commit' '
 	echo "line 17" >>hello &&
 	echo "line 18" >>hello &&
@@ -455,7 +486,10 @@ test_expect_success '--convert-graft-fil
 	printf "%s\n%s %s\n\n# comment\n%s\n" \
 		$(git rev-parse HEAD^^ HEAD^ HEAD^^ HEAD^2) \
 		>.git/info/grafts &&
-	git replace --convert-graft-file &&
+	git status 2>stderr &&
+	test_i18ngrep "hint:.*grafts is deprecated" stderr &&
+	git replace --convert-graft-file 2>stderr &&
+	test_i18ngrep ! "hint:.*grafts is deprecated" stderr &&
 	test_path_is_missing .git/info/grafts &&
 
 	: verify that the history is now "grafted" &&
diff -pruN 1.2.1+git2.18.0-1/git/t/t6060-merge-index.sh 1.2.3+git2.25.1-1/git/t/t6060-merge-index.sh
--- 1.2.1+git2.18.0-1/git/t/t6060-merge-index.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t6060-merge-index.sh	2020-02-17 04:47:35.000000000 +0000
@@ -44,8 +44,7 @@ test_expect_success 'read-tree does not
 test_expect_success 'git merge-index git-merge-one-file resolves' '
 	git merge-index git-merge-one-file -a &&
 	git diff-files --name-only --diff-filter=U >unmerged &&
-	>expect &&
-	test_cmp expect unmerged &&
+	test_must_be_empty unmerged &&
 	test_cmp expect-merged file &&
 	git cat-file blob :file >file-index &&
 	test_cmp expect-merged file-index
diff -pruN 1.2.1+git2.18.0-1/git/t/t6102-rev-list-unexpected-objects.sh 1.2.3+git2.25.1-1/git/t/t6102-rev-list-unexpected-objects.sh
--- 1.2.1+git2.18.0-1/git/t/t6102-rev-list-unexpected-objects.sh	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t6102-rev-list-unexpected-objects.sh	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,127 @@
+#!/bin/sh
+
+test_description='git rev-list should handle unexpected object types'
+
+. ./test-lib.sh
+
+test_expect_success 'setup well-formed objects' '
+	blob="$(printf "foo" | git hash-object -w --stdin)" &&
+	tree="$(printf "100644 blob $blob\tfoo" | git mktree)" &&
+	commit="$(git commit-tree $tree -m "first commit")" &&
+	git cat-file commit $commit >good-commit
+'
+
+test_expect_success 'setup unexpected non-blob entry' '
+	printf "100644 foo\0$(echo $tree | hex2oct)" >broken-tree &&
+	broken_tree="$(git hash-object -w --literally -t tree broken-tree)"
+'
+
+test_expect_failure 'traverse unexpected non-blob entry (lone)' '
+	test_must_fail git rev-list --objects $broken_tree
+'
+
+test_expect_success 'traverse unexpected non-blob entry (seen)' '
+	test_must_fail git rev-list --objects $tree $broken_tree >output 2>&1 &&
+	test_i18ngrep "is not a blob" output
+'
+
+test_expect_success 'setup unexpected non-tree entry' '
+	printf "40000 foo\0$(echo $blob | hex2oct)" >broken-tree &&
+	broken_tree="$(git hash-object -w --literally -t tree broken-tree)"
+'
+
+test_expect_success 'traverse unexpected non-tree entry (lone)' '
+	test_must_fail git rev-list --objects $broken_tree
+'
+
+test_expect_success 'traverse unexpected non-tree entry (seen)' '
+	test_must_fail git rev-list --objects $blob $broken_tree >output 2>&1 &&
+	test_i18ngrep "is not a tree" output
+'
+
+test_expect_success 'setup unexpected non-commit parent' '
+	sed "/^author/ { h; s/.*/parent $blob/; G; }" <good-commit \
+		>broken-commit &&
+	broken_commit="$(git hash-object -w --literally -t commit \
+		broken-commit)"
+'
+
+test_expect_success 'traverse unexpected non-commit parent (lone)' '
+	test_must_fail git rev-list --objects $broken_commit >output 2>&1 &&
+	test_i18ngrep "not a commit" output
+'
+
+test_expect_success 'traverse unexpected non-commit parent (seen)' '
+	test_must_fail git rev-list --objects $blob $broken_commit \
+		>output 2>&1 &&
+	test_i18ngrep "not a commit" output
+'
+
+test_expect_success 'setup unexpected non-tree root' '
+	sed -e "s/$tree/$blob/" <good-commit >broken-commit &&
+	broken_commit="$(git hash-object -w --literally -t commit \
+		broken-commit)"
+'
+
+test_expect_success 'traverse unexpected non-tree root (lone)' '
+	test_must_fail git rev-list --objects $broken_commit
+'
+
+test_expect_success 'traverse unexpected non-tree root (seen)' '
+	test_must_fail git rev-list --objects $blob $broken_commit \
+		>output 2>&1 &&
+	test_i18ngrep "not a tree" output
+'
+
+test_expect_success 'setup unexpected non-commit tag' '
+	git tag -a -m "tagged commit" tag $commit &&
+	git cat-file tag tag >good-tag &&
+	test_when_finished "git tag -d tag" &&
+	sed -e "s/$commit/$blob/" <good-tag >broken-tag &&
+	tag=$(git hash-object -w --literally -t tag broken-tag)
+'
+
+test_expect_success 'traverse unexpected non-commit tag (lone)' '
+	test_must_fail git rev-list --objects $tag
+'
+
+test_expect_success 'traverse unexpected non-commit tag (seen)' '
+	test_must_fail git rev-list --objects $blob $tag >output 2>&1 &&
+	test_i18ngrep "not a commit" output
+'
+
+test_expect_success 'setup unexpected non-tree tag' '
+	git tag -a -m "tagged tree" tag $tree &&
+	git cat-file tag tag >good-tag &&
+	test_when_finished "git tag -d tag" &&
+	sed -e "s/$tree/$blob/" <good-tag >broken-tag &&
+	tag=$(git hash-object -w --literally -t tag broken-tag)
+'
+
+test_expect_success 'traverse unexpected non-tree tag (lone)' '
+	test_must_fail git rev-list --objects $tag
+'
+
+test_expect_success 'traverse unexpected non-tree tag (seen)' '
+	test_must_fail git rev-list --objects $blob $tag >output 2>&1 &&
+	test_i18ngrep "not a tree" output
+'
+
+test_expect_success 'setup unexpected non-blob tag' '
+	git tag -a -m "tagged blob" tag $blob &&
+	git cat-file tag tag >good-tag &&
+	test_when_finished "git tag -d tag" &&
+	sed -e "s/$blob/$commit/" <good-tag >broken-tag &&
+	tag=$(git hash-object -w --literally -t tag broken-tag)
+'
+
+test_expect_failure 'traverse unexpected non-blob tag (lone)' '
+	test_must_fail git rev-list --objects $tag
+'
+
+test_expect_success 'traverse unexpected non-blob tag (seen)' '
+	test_must_fail git rev-list --objects $commit $tag >output 2>&1 &&
+	test_i18ngrep "not a blob" output
+'
+
+test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t6112-rev-list-filters-objects.sh 1.2.3+git2.25.1-1/git/t/t6112-rev-list-filters-objects.sh
--- 1.2.1+git2.18.0-1/git/t/t6112-rev-list-filters-objects.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t6112-rev-list-filters-objects.sh	2020-02-17 04:47:35.000000000 +0000
@@ -21,24 +21,43 @@ test_expect_success 'setup r1' '
 
 test_expect_success 'verify blob:none omits all 5 blobs' '
 	git -C r1 ls-files -s file.1 file.2 file.3 file.4 file.5 \
-		| awk -f print_2.awk \
-		| sort >expected &&
-	git -C r1 rev-list HEAD --quiet --objects --filter-print-omitted --filter=blob:none \
-		| awk -f print_1.awk \
-		| sed "s/~//" \
-		| sort >observed &&
-	test_cmp observed expected
+		>ls_files_result &&
+	awk -f print_2.awk ls_files_result |
+	sort >expected &&
+
+	git -C r1 rev-list --quiet --objects --filter-print-omitted \
+		--filter=blob:none HEAD >revs &&
+	awk -f print_1.awk revs |
+	sed "s/~//" |
+	sort >observed &&
+
+	test_cmp expected observed
+'
+
+test_expect_success 'specify blob explicitly prevents filtering' '
+	file_3=$(git -C r1 ls-files -s file.3 |
+		 awk -f print_2.awk) &&
+
+	file_4=$(git -C r1 ls-files -s file.4 |
+		 awk -f print_2.awk) &&
+
+	git -C r1 rev-list --objects --filter=blob:none HEAD $file_3 >observed &&
+	grep "$file_3" observed &&
+	! grep "$file_4" observed
 '
 
 test_expect_success 'verify emitted+omitted == all' '
-	git -C r1 rev-list HEAD --objects \
-		| awk -f print_1.awk \
-		| sort >expected &&
-	git -C r1 rev-list HEAD --objects --filter-print-omitted --filter=blob:none \
-		| awk -f print_1.awk \
-		| sed "s/~//" \
-		| sort >observed &&
-	test_cmp observed expected
+	git -C r1 rev-list --objects HEAD >revs &&
+	awk -f print_1.awk revs |
+	sort >expected &&
+
+	git -C r1 rev-list --objects --filter-print-omitted --filter=blob:none \
+		HEAD >revs &&
+	awk -f print_1.awk revs |
+	sed "s/~//" |
+	sort >observed &&
+
+	test_cmp expected observed
 '
 
 
@@ -58,70 +77,90 @@ test_expect_success 'setup r2' '
 '
 
 test_expect_success 'verify blob:limit=500 omits all blobs' '
-	git -C r2 ls-files -s large.1000 large.10000 \
-		| awk -f print_2.awk \
-		| sort >expected &&
-	git -C r2 rev-list HEAD --quiet --objects --filter-print-omitted --filter=blob:limit=500 \
-		| awk -f print_1.awk \
-		| sed "s/~//" \
-		| sort >observed &&
-	test_cmp observed expected
+	git -C r2 ls-files -s large.1000 large.10000 >ls_files_result &&
+	awk -f print_2.awk ls_files_result |
+	sort >expected &&
+
+	git -C r2 rev-list --quiet --objects --filter-print-omitted \
+		--filter=blob:limit=500 HEAD >revs &&
+	awk -f print_1.awk revs |
+	sed "s/~//" |
+	sort >observed &&
+
+	test_cmp expected observed
 '
 
 test_expect_success 'verify emitted+omitted == all' '
-	git -C r2 rev-list HEAD --objects \
-		| awk -f print_1.awk \
-		| sort >expected &&
-	git -C r2 rev-list HEAD --objects --filter-print-omitted --filter=blob:limit=500 \
-		| awk -f print_1.awk \
-		| sed "s/~//" \
-		| sort >observed &&
-	test_cmp observed expected
+	git -C r2 rev-list --objects HEAD >revs &&
+	awk -f print_1.awk revs |
+	sort >expected &&
+
+	git -C r2 rev-list --objects --filter-print-omitted \
+		--filter=blob:limit=500 HEAD >revs &&
+	awk -f print_1.awk revs |
+	sed "s/~//" |
+	sort >observed &&
+
+	test_cmp expected observed
 '
 
 test_expect_success 'verify blob:limit=1000' '
-	git -C r2 ls-files -s large.1000 large.10000 \
-		| awk -f print_2.awk \
-		| sort >expected &&
-	git -C r2 rev-list HEAD --quiet --objects --filter-print-omitted --filter=blob:limit=1000 \
-		| awk -f print_1.awk \
-		| sed "s/~//" \
-		| sort >observed &&
-	test_cmp observed expected
+	git -C r2 ls-files -s large.1000 large.10000 >ls_files_result &&
+	awk -f print_2.awk ls_files_result |
+	sort >expected &&
+
+	git -C r2 rev-list --quiet --objects --filter-print-omitted \
+		--filter=blob:limit=1000 HEAD >revs &&
+	awk -f print_1.awk revs |
+	sed "s/~//" |
+	sort >observed &&
+
+	test_cmp expected observed
 '
 
 test_expect_success 'verify blob:limit=1001' '
-	git -C r2 ls-files -s large.10000 \
-		| awk -f print_2.awk \
-		| sort >expected &&
-	git -C r2 rev-list HEAD --quiet --objects --filter-print-omitted --filter=blob:limit=1001 \
-		| awk -f print_1.awk \
-		| sed "s/~//" \
-		| sort >observed &&
-	test_cmp observed expected
+	git -C r2 ls-files -s large.10000 >ls_files_result &&
+	awk -f print_2.awk ls_files_result |
+	sort >expected &&
+
+	git -C r2 rev-list --quiet --objects --filter-print-omitted \
+		--filter=blob:limit=1001 HEAD >revs &&
+	awk -f print_1.awk revs |
+	sed "s/~//" |
+	sort >observed &&
+
+	test_cmp expected observed
 '
 
 test_expect_success 'verify blob:limit=1k' '
-	git -C r2 ls-files -s large.10000 \
-		| awk -f print_2.awk \
-		| sort >expected &&
-	git -C r2 rev-list HEAD --quiet --objects --filter-print-omitted --filter=blob:limit=1k \
-		| awk -f print_1.awk \
-		| sed "s/~//" \
-		| sort >observed &&
-	test_cmp observed expected
+	git -C r2 ls-files -s large.10000 >ls_files_result &&
+	awk -f print_2.awk ls_files_result |
+	sort >expected &&
+
+	git -C r2 rev-list --quiet --objects --filter-print-omitted \
+		--filter=blob:limit=1k HEAD >revs &&
+	awk -f print_1.awk revs |
+	sed "s/~//" |
+	sort >observed &&
+
+	test_cmp expected observed
 '
 
 test_expect_success 'verify blob:limit=1m' '
-	cat </dev/null >expected &&
-	git -C r2 rev-list HEAD --quiet --objects --filter-print-omitted --filter=blob:limit=1m \
-		| awk -f print_1.awk \
-		| sed "s/~//" \
-		| sort >observed &&
-	test_cmp observed expected
+	git -C r2 rev-list --quiet --objects --filter-print-omitted \
+		--filter=blob:limit=1m HEAD >revs &&
+	awk -f print_1.awk revs |
+	sed "s/~//" |
+	sort >observed &&
+
+	test_must_be_empty observed
 '
 
 # Test sparse:path=<path> filter.
+# !!!!
+# NOTE: sparse:path filter support has been dropped for security reasons,
+# so the tests have been changed to make sure that using it fails.
+# !!!!
 # Use a local file containing a sparse-checkout specification to filter
 # out blobs not required for the corresponding sparse-checkout.  We do not
 # require sparse-checkout to actually be enabled.
@@ -141,31 +180,20 @@ test_expect_success 'setup r3' '
 	echo sparse1 >pattern2
 '
 
-test_expect_success 'verify sparse:path=pattern1 omits top-level files' '
-	git -C r3 ls-files -s sparse1 sparse2 \
-		| awk -f print_2.awk \
-		| sort >expected &&
-	git -C r3 rev-list HEAD --quiet --objects --filter-print-omitted --filter=sparse:path=../pattern1 \
-		| awk -f print_1.awk \
-		| sed "s/~//" \
-		| sort >observed &&
-	test_cmp observed expected
-'
-
-test_expect_success 'verify sparse:path=pattern2 omits both sparse2 files' '
-	git -C r3 ls-files -s sparse2 dir1/sparse2 \
-		| awk -f print_2.awk \
-		| sort >expected &&
-	git -C r3 rev-list HEAD --quiet --objects --filter-print-omitted --filter=sparse:path=../pattern2 \
-		| awk -f print_1.awk \
-		| sed "s/~//" \
-		| sort >observed &&
-	test_cmp observed expected
+test_expect_success 'verify sparse:path=pattern1 fails' '
+	test_must_fail git -C r3 rev-list --quiet --objects \
+		--filter-print-omitted --filter=sparse:path=../pattern1 HEAD
+'
+
+test_expect_success 'verify sparse:path=pattern2 fails' '
+	test_must_fail git -C r3 rev-list --quiet --objects \
+		--filter-print-omitted --filter=sparse:path=../pattern2 HEAD
 '
 
 # Test sparse:oid=<oid-ish> filter.
-# Like sparse:path, but we get the sparse-checkout specification from
-# a blob rather than a file on disk.
+# Use a blob containing a sparse-checkout specification to filter
+# out blobs not required for the corresponding sparse-checkout.  We do not
+# require sparse-checkout to actually be enabled.
 
 test_expect_success 'setup r3 part 2' '
 	echo dir1/ >r3/pattern &&
@@ -174,26 +202,388 @@ test_expect_success 'setup r3 part 2' '
 '
 
 test_expect_success 'verify sparse:oid=OID omits top-level files' '
-	git -C r3 ls-files -s pattern sparse1 sparse2 \
-		| awk -f print_2.awk \
-		| sort >expected &&
+	git -C r3 ls-files -s pattern sparse1 sparse2 >ls_files_result &&
+	awk -f print_2.awk ls_files_result |
+	sort >expected &&
+
 	oid=$(git -C r3 ls-files -s pattern | awk -f print_2.awk) &&
-	git -C r3 rev-list HEAD --quiet --objects --filter-print-omitted --filter=sparse:oid=$oid \
-		| awk -f print_1.awk \
-		| sed "s/~//" \
-		| sort >observed &&
-	test_cmp observed expected
+
+	git -C r3 rev-list --quiet --objects --filter-print-omitted \
+		--filter=sparse:oid=$oid HEAD >revs &&
+	awk -f print_1.awk revs |
+	sed "s/~//" |
+	sort >observed &&
+
+	test_cmp expected observed
 '
 
 test_expect_success 'verify sparse:oid=oid-ish omits top-level files' '
-	git -C r3 ls-files -s pattern sparse1 sparse2 \
-		| awk -f print_2.awk \
-		| sort >expected &&
-	git -C r3 rev-list HEAD --quiet --objects --filter-print-omitted --filter=sparse:oid=master:pattern \
-		| awk -f print_1.awk \
-		| sed "s/~//" \
-		| sort >observed &&
-	test_cmp observed expected
+	git -C r3 ls-files -s pattern sparse1 sparse2 >ls_files_result &&
+	awk -f print_2.awk ls_files_result |
+	sort >expected &&
+
+	git -C r3 rev-list --quiet --objects --filter-print-omitted \
+		--filter=sparse:oid=master:pattern HEAD >revs &&
+	awk -f print_1.awk revs |
+	sed "s/~//" |
+	sort >observed &&
+
+	test_cmp expected observed
+'
+
+test_expect_success 'rev-list W/ --missing=print and --missing=allow-any for trees' '
+	TREE=$(git -C r3 rev-parse HEAD:dir1) &&
+
+	# Create a spare repo because we will be deleting objects from this one.
+	git clone r3 r3.b &&
+
+	rm r3.b/.git/objects/$(echo $TREE | sed "s|^..|&/|") &&
+
+	git -C r3.b rev-list --quiet --missing=print --objects HEAD \
+		>missing_objs 2>rev_list_err &&
+	echo "?$TREE" >expected &&
+	test_cmp expected missing_objs &&
+
+	# do not complain when a missing tree cannot be parsed
+	test_must_be_empty rev_list_err &&
+
+	git -C r3.b rev-list --missing=allow-any --objects HEAD \
+		>objs 2>rev_list_err &&
+	! grep $TREE objs &&
+	test_must_be_empty rev_list_err
+'
+
+# Test tree:0 filter.
+
+test_expect_success 'verify tree:0 includes trees in "filtered" output' '
+	git -C r3 rev-list --quiet --objects --filter-print-omitted \
+		--filter=tree:0 HEAD >revs &&
+
+	awk -f print_1.awk revs |
+	sed s/~// |
+	xargs -n1 git -C r3 cat-file -t >unsorted_filtered_types &&
+
+	sort -u unsorted_filtered_types >filtered_types &&
+	test_write_lines blob tree >expected &&
+	test_cmp expected filtered_types
+'
+
+# Make sure tree:0 does not iterate through any trees.
+
+test_expect_success 'verify skipping tree iteration when not collecting omits' '
+	GIT_TRACE=1 git -C r3 rev-list \
+		--objects --filter=tree:0 HEAD 2>filter_trace &&
+	grep "Skipping contents of tree [.][.][.]" filter_trace >actual &&
+	# One line for each commit traversed.
+	test_line_count = 2 actual &&
+
+	# Make sure no other trees were considered besides the root.
+	! grep "Skipping contents of tree [^.]" filter_trace &&
+
+	# Try this again with "combine:". If both sub-filters are skipping
+	# trees, the composite filter should also skip trees. This is not
+	# important unless the user does combine:tree:X+tree:Y or another filter
+	# besides "tree:" is implemented in the future which can skip trees.
+	GIT_TRACE=1 git -C r3 rev-list \
+		--objects --filter=combine:tree:1+tree:3 HEAD 2>filter_trace &&
+
+	# Only skip the dir1/ tree, which is shared between the two commits.
+	grep "Skipping contents of tree " filter_trace >actual &&
+	test_write_lines "Skipping contents of tree dir1/..." >expected &&
+	test_cmp expected actual
+'
+
+# Test tree:# filters.
+
+expect_has () {
+	commit=$1 &&
+	name=$2 &&
+
+	hash=$(git -C r3 rev-parse $commit:$name) &&
+	grep "^$hash $name$" actual
+}
+
+test_expect_success 'verify tree:1 includes root trees' '
+	git -C r3 rev-list --objects --filter=tree:1 HEAD >actual &&
+
+	# We should get two root directories and two commits.
+	expect_has HEAD "" &&
+	expect_has HEAD~1 ""  &&
+	test_line_count = 4 actual
+'
+
+test_expect_success 'verify tree:2 includes root trees and immediate children' '
+	git -C r3 rev-list --objects --filter=tree:2 HEAD >actual &&
+
+	expect_has HEAD "" &&
+	expect_has HEAD~1 "" &&
+	expect_has HEAD dir1 &&
+	expect_has HEAD pattern &&
+	expect_has HEAD sparse1 &&
+	expect_has HEAD sparse2 &&
+
+	# There are also 2 commit objects
+	test_line_count = 8 actual
+'
+
+test_expect_success 'verify tree:3 includes everything expected' '
+	git -C r3 rev-list --objects --filter=tree:3 HEAD >actual &&
+
+	expect_has HEAD "" &&
+	expect_has HEAD~1 "" &&
+	expect_has HEAD dir1 &&
+	expect_has HEAD dir1/sparse1 &&
+	expect_has HEAD dir1/sparse2 &&
+	expect_has HEAD pattern &&
+	expect_has HEAD sparse1 &&
+	expect_has HEAD sparse2 &&
+
+	# There are also 2 commit objects
+	test_line_count = 10 actual
+'
+
+test_expect_success 'combine:... for a simple combination' '
+	git -C r3 rev-list --objects --filter=combine:tree:2+blob:none HEAD \
+		>actual &&
+
+	expect_has HEAD "" &&
+	expect_has HEAD~1 "" &&
+	expect_has HEAD dir1 &&
+
+	# There are also 2 commit objects
+	test_line_count = 5 actual &&
+
+	cp actual expected &&
+
+	# Try again using repeated --filter - this is equivalent to a manual
+	# combine with "combine:...+..."
+	git -C r3 rev-list --objects --filter=combine:tree:2 \
+		--filter=blob:none HEAD >actual &&
+
+	test_cmp expected actual
+'
+
+test_expect_success 'combine:... with URL encoding' '
+	git -C r3 rev-list --objects \
+		--filter=combine:tree%3a2+blob:%6Eon%65 HEAD >actual &&
+
+	expect_has HEAD "" &&
+	expect_has HEAD~1 "" &&
+	expect_has HEAD dir1 &&
+
+	# There are also 2 commit objects
+	test_line_count = 5 actual
+'
+
+expect_invalid_filter_spec () {
+	spec="$1" &&
+	err="$2" &&
+
+	test_must_fail git -C r3 rev-list --objects --filter="$spec" HEAD \
+		>actual 2>actual_stderr &&
+	test_must_be_empty actual &&
+	test_i18ngrep "$err" actual_stderr
+}
+
+test_expect_success 'combine:... while URL-encoding things that should not be' '
+	expect_invalid_filter_spec combine%3Atree:2+blob:none \
+		"invalid filter-spec"
+'
+
+test_expect_success 'combine: with nothing after the :' '
+	expect_invalid_filter_spec combine: "expected something after combine:"
+'
+
+test_expect_success 'parse error in first sub-filter in combine:' '
+	expect_invalid_filter_spec combine:tree:asdf+blob:none \
+		"expected .tree:<depth>."
+'
+
+test_expect_success 'combine:... with non-encoded reserved chars' '
+	expect_invalid_filter_spec combine:tree:2+sparse:@xyz \
+		"must escape char in sub-filter-spec: .@." &&
+	expect_invalid_filter_spec combine:tree:2+sparse:\` \
+		"must escape char in sub-filter-spec: .\`." &&
+	expect_invalid_filter_spec combine:tree:2+sparse:~abc \
+		"must escape char in sub-filter-spec: .\~."
+'
+
+test_expect_success 'validate err msg for "combine:<valid-filter>+"' '
+	expect_invalid_filter_spec combine:tree:2+ "expected .tree:<depth>."
+'
+
+test_expect_success 'combine:... with edge-case hex digits: Ff Aa 0 9' '
+	git -C r3 rev-list --objects --filter="combine:tree:2+bl%6Fb:n%6fne" \
+		HEAD >actual &&
+	test_line_count = 5 actual &&
+	git -C r3 rev-list --objects --filter="combine:tree%3A2+blob%3anone" \
+		HEAD >actual &&
+	test_line_count = 5 actual &&
+	git -C r3 rev-list --objects --filter="combine:tree:%30" HEAD >actual &&
+	test_line_count = 2 actual &&
+	git -C r3 rev-list --objects --filter="combine:tree:%39+blob:none" \
+		HEAD >actual &&
+	test_line_count = 5 actual
+'
+
+test_expect_success 'add sparse pattern blobs whose paths have reserved chars' '
+	cp r3/pattern r3/pattern1+renamed% &&
+	cp r3/pattern "r3/p;at%ter+n" &&
+	cp r3/pattern r3/^~pattern &&
+	git -C r3 add pattern1+renamed% "p;at%ter+n" ^~pattern &&
+	git -C r3 commit -m "add sparse pattern files with reserved chars"
+'
+
+test_expect_success 'combine:... with more than two sub-filters' '
+	git -C r3 rev-list --objects \
+		--filter=combine:tree:3+blob:limit=40+sparse:oid=master:pattern \
+		HEAD >actual &&
+
+	expect_has HEAD "" &&
+	expect_has HEAD~1 "" &&
+	expect_has HEAD~2 "" &&
+	expect_has HEAD dir1 &&
+	expect_has HEAD dir1/sparse1 &&
+	expect_has HEAD dir1/sparse2 &&
+
+	# Should also have 3 commits
+	test_line_count = 9 actual &&
+
+	# Try again, this time making sure the last sub-filter is only
+	# URL-decoded once.
+	cp actual expect &&
+
+	git -C r3 rev-list --objects \
+		--filter=combine:tree:3+blob:limit=40+sparse:oid=master:pattern1%2brenamed%25 \
+		HEAD >actual &&
+	test_cmp expect actual &&
+
+	# Use the same composite filter again, but with a pattern file name that
+	# requires encoding multiple characters, and use implicit filter
+	# combining.
+	test_when_finished "rm -f trace1" &&
+	GIT_TRACE=$(pwd)/trace1 git -C r3 rev-list --objects \
+		--filter=tree:3 --filter=blob:limit=40 \
+		--filter=sparse:oid="master:p;at%ter+n" \
+		HEAD >actual &&
+
+	test_cmp expect actual &&
+	grep "Add to combine filter-spec: sparse:oid=master:p%3bat%25ter%2bn" \
+		trace1 &&
+
+	# Repeat the above test, but this time, the characters to encode are in
+	# the LHS of the combined filter.
+	test_when_finished "rm -f trace2" &&
+	GIT_TRACE=$(pwd)/trace2 git -C r3 rev-list --objects \
+		--filter=sparse:oid=master:^~pattern \
+		--filter=tree:3 --filter=blob:limit=40 \
+		HEAD >actual &&
+
+	test_cmp expect actual &&
+	grep "Add to combine filter-spec: sparse:oid=master:%5e%7epattern" \
+		trace2
+'
+
+# Test provisional omit collection logic with a repo that has objects appearing
+# at multiple depths - first deeper than the filter's threshold, then shallow.
+
+test_expect_success 'setup r4' '
+	git init r4 &&
+
+	echo foo > r4/foo &&
+	mkdir r4/subdir &&
+	echo bar > r4/subdir/bar &&
+
+	mkdir r4/filt &&
+	cp -r r4/foo r4/subdir r4/filt &&
+
+	git -C r4 add foo subdir filt &&
+	git -C r4 commit -m "commit msg"
+'
+
+expect_has_with_different_name () {
+	repo=$1 &&
+	name=$2 &&
+
+	hash=$(git -C $repo rev-parse HEAD:$name) &&
+	! grep "^$hash $name$" actual &&
+	grep "^$hash " actual &&
+	! grep "~$hash" actual
+}
+
+test_expect_success 'test tree:# filter provisional omit for blob and tree' '
+	git -C r4 rev-list --objects --filter-print-omitted --filter=tree:2 \
+		HEAD >actual &&
+	expect_has_with_different_name r4 filt/foo &&
+	expect_has_with_different_name r4 filt/subdir
+'
+
+test_expect_success 'verify skipping tree iteration when collecting omits' '
+	GIT_TRACE=1 git -C r4 rev-list --filter-print-omitted \
+		--objects --filter=tree:0 HEAD 2>filter_trace &&
+	grep "^Skipping contents of tree " filter_trace >actual &&
+
+	echo "Skipping contents of tree subdir/..." >expect &&
+	test_cmp expect actual
+'
+
+test_expect_success 'setup r5' '
+	git init r5 &&
+	mkdir -p r5/subdir &&
+
+	echo 1     >r5/short-root          &&
+	echo 12345 >r5/long-root           &&
+	echo a     >r5/subdir/short-subdir &&
+	echo abcde >r5/subdir/long-subdir  &&
+
+	git -C r5 add short-root long-root subdir &&
+	git -C r5 commit -m "commit msg"
+'
+
+test_expect_success 'verify collecting omits in combined: filter' '
+	# Note that this test guards against the naive implementation of simply
+	# giving both filters the same "omits" set and expecting it to
+	# automatically merge them.
+	git -C r5 rev-list --objects --quiet --filter-print-omitted \
+		--filter=combine:tree:2+blob:limit=3 HEAD >actual &&
+
+	# Expect 0 trees/commits, 3 blobs omitted (all blobs except short-root)
+	omitted_1=$(echo 12345 | git hash-object --stdin) &&
+	omitted_2=$(echo a     | git hash-object --stdin) &&
+	omitted_3=$(echo abcde | git hash-object --stdin) &&
+
+	grep ~$omitted_1 actual &&
+	grep ~$omitted_2 actual &&
+	grep ~$omitted_3 actual &&
+	test_line_count = 3 actual
+'
+
+# Test tree:<depth> where a tree is iterated to twice - once where a subentry is
+# too deep to be included, and again where the blob inside it is shallow enough
+# to be included. This makes sure we don't use LOFR_MARK_SEEN incorrectly (we
+# can't use it because a tree can be iterated over again at a lower depth).
+
+test_expect_success 'tree:<depth> where we iterate over tree at two levels' '
+	git init r5 &&
+
+	mkdir -p r5/a/subdir/b &&
+	echo foo > r5/a/subdir/b/foo &&
+
+	mkdir -p r5/subdir/b &&
+	echo foo > r5/subdir/b/foo &&
+
+	git -C r5 add a subdir &&
+	git -C r5 commit -m "commit msg" &&
+
+	git -C r5 rev-list --objects --filter=tree:4 HEAD >actual &&
+	expect_has_with_different_name r5 a/subdir/b/foo
+'
+
+test_expect_success 'tree:<depth> which filters out blob but given as arg' '
+	blob_hash=$(git -C r4 rev-parse HEAD:subdir/bar) &&
+
+	git -C r4 rev-list --objects --filter=tree:1 HEAD $blob_hash >actual &&
+	grep ^$blob_hash actual
 '
 
 # Delete some loose objects and use rev-list, but WITHOUT any filtering.
@@ -201,17 +591,21 @@ test_expect_success 'verify sparse:oid=o
 
 test_expect_success 'rev-list W/ --missing=print' '
 	git -C r1 ls-files -s file.1 file.2 file.3 file.4 file.5 \
-		| awk -f print_2.awk \
-		| sort >expected &&
+		>ls_files_result &&
+	awk -f print_2.awk ls_files_result |
+	sort >expected &&
+
 	for id in `cat expected | sed "s|..|&/|"`
 	do
 		rm r1/.git/objects/$id
 	done &&
-	git -C r1 rev-list --quiet HEAD --missing=print --objects \
-		| awk -f print_1.awk \
-		| sed "s/?//" \
-		| sort >observed &&
-	test_cmp observed expected
+
+	git -C r1 rev-list --quiet --missing=print --objects HEAD >revs &&
+	awk -f print_1.awk revs |
+	sed "s/?//" |
+	sort >observed &&
+
+	test_cmp expected observed
 '
 
 test_expect_success 'rev-list W/O --missing fails' '
@@ -222,4 +616,14 @@ test_expect_success 'rev-list W/ missing
 	git -C r1 rev-list --quiet --missing=allow-any --objects HEAD
 '
 
+# Test expansion of filter specs.
+
+test_expect_success 'expand blob limit in protocol' '
+	git -C r2 config --local uploadpack.allowfilter 1 &&
+	GIT_TRACE_PACKET="$(pwd)/trace" git -c protocol.version=2 clone \
+		--filter=blob:limit=1k "file://$(pwd)/r2" limit &&
+	! grep "blob:limit=1k" trace &&
+	grep "blob:limit=1024" trace
+'
+
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t6120-describe.sh 1.2.3+git2.25.1-1/git/t/t6120-describe.sh
--- 1.2.1+git2.18.0-1/git/t/t6120-describe.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t6120-describe.sh	2020-02-17 04:47:35.000000000 +0000
@@ -1,28 +1,27 @@
 #!/bin/sh
 
-test_description='test describe
+test_description='test describe'
+
+#  o---o-----o----o----o-------o----x
+#       \   D,R   e           /
+#        \---o-------------o-'
+#         \  B            /
+#          `-o----o----o-'
+#                 A    c
+#
+# First parent of a merge commit is on the same line, second parent below.
 
-                       B
-        .--------------o----o----o----x
-       /                   /    /
- o----o----o----o----o----.    /
-       \        A    c        /
-        .------------o---o---o
-                   D,R   e
-'
 . ./test-lib.sh
 
 check_describe () {
 	expect="$1"
 	shift
-	R=$(git describe "$@" 2>err.actual)
-	S=$?
-	cat err.actual >&3
-	test_expect_success "describe $*" '
-	test $S = 0 &&
+	describe_opts="$@"
+	test_expect_success "describe $describe_opts" '
+	R=$(git describe $describe_opts 2>err.actual) &&
 	case "$R" in
 	$expect)	echo happy ;;
-	*)	echo "Oops - $R is not $expect";
+	*)	echo "Oops - $R is not $expect" &&
 		false ;;
 	esac
 	'
@@ -121,10 +120,9 @@ test_expect_success 'describe --contains
 	test_cmp expect actual
 '
 
-: >err.expect
 check_describe tags/A --all A^0
 test_expect_success 'no warning was displayed for A' '
-	test_cmp err.expect err.actual
+	test_must_be_empty err.actual
 '
 
 test_expect_success 'rename tag A to Q locally' '
@@ -144,16 +142,46 @@ test_expect_success 'rename tag Q back t
 test_expect_success 'pack tag refs' 'git pack-refs'
 check_describe A-* HEAD
 
+test_expect_success 'describe works from outside repo using --git-dir' '
+	git clone --bare "$TRASH_DIRECTORY" "$TRASH_DIRECTORY/bare" &&
+	git --git-dir "$TRASH_DIRECTORY/bare" describe >out &&
+	grep -E "^A-[1-9][0-9]?-g[0-9a-f]+$" out
+'
+
 check_describe "A-*[0-9a-f]" --dirty
 
+test_expect_success 'describe --dirty with --work-tree' '
+	(
+		cd "$TEST_DIRECTORY" &&
+		git --git-dir "$TRASH_DIRECTORY/.git" --work-tree "$TRASH_DIRECTORY" describe --dirty >"$TRASH_DIRECTORY/out"
+	) &&
+	grep -E "^A-[1-9][0-9]?-g[0-9a-f]+$" out
+'
+
 test_expect_success 'set-up dirty work tree' '
 	echo >>file
 '
 
 check_describe "A-*[0-9a-f]-dirty" --dirty
 
+test_expect_success 'describe --dirty with --work-tree (dirty)' '
+	(
+		cd "$TEST_DIRECTORY" &&
+		git --git-dir "$TRASH_DIRECTORY/.git" --work-tree "$TRASH_DIRECTORY" describe --dirty >"$TRASH_DIRECTORY/out"
+	) &&
+	grep -E "^A-[1-9][0-9]?-g[0-9a-f]+-dirty$" out
+'
+
 check_describe "A-*[0-9a-f].mod" --dirty=.mod
 
+test_expect_success 'describe --dirty=.mod with --work-tree (dirty)' '
+	(
+		cd "$TEST_DIRECTORY" &&
+		git --git-dir "$TRASH_DIRECTORY/.git" --work-tree "$TRASH_DIRECTORY" describe --dirty=.mod >"$TRASH_DIRECTORY/out"
+	) &&
+	grep -E "^A-[1-9][0-9]?-g[0-9a-f]+.mod$" out
+'
+
 test_expect_success 'describe --dirty HEAD' '
 	test_must_fail git describe --dirty HEAD
 '
@@ -304,8 +332,17 @@ test_expect_success 'describe chokes on
 	mv .git/modules/sub1/ .git/modules/sub_moved &&
 	test_must_fail git describe --dirty
 '
+
 test_expect_success 'describe ignoring a broken submodule' '
 	git describe --broken >out &&
+	grep broken out
+'
+
+test_expect_success 'describe with --work-tree ignoring a broken submodule' '
+	(
+		cd "$TEST_DIRECTORY" &&
+		git --git-dir "$TRASH_DIRECTORY/.git" --work-tree "$TRASH_DIRECTORY" describe --broken >"$TRASH_DIRECTORY/out"
+	) &&
 	test_when_finished "mv .git/modules/sub_moved .git/modules/sub1" &&
 	grep broken out
 '
@@ -344,7 +381,7 @@ test_expect_success 'describe tag object
 	test_i18ngrep "fatal: test-blob-1 is neither a commit nor blob" actual
 '
 
-test_expect_failure ULIMIT_STACK_SIZE 'name-rev works in a deep repo' '
+test_expect_success ULIMIT_STACK_SIZE 'name-rev works in a deep repo' '
 	i=1 &&
 	while test $i -lt 8000
 	do
@@ -386,4 +423,60 @@ test_expect_success 'describe complains
 	test_must_fail git describe $ZERO_OID
 '
 
+test_expect_success 'name-rev a rev shortly after epoch' '
+	test_when_finished "git checkout master" &&
+
+	git checkout --orphan no-timestamp-underflow &&
+	# Any date closer to epoch than the CUTOFF_DATE_SLOP constant
+	# in builtin/name-rev.c.
+	GIT_COMMITTER_DATE="@1234 +0000" \
+	git commit -m "committer date shortly after epoch" &&
+	old_commit_oid=$(git rev-parse HEAD) &&
+
+	echo "$old_commit_oid no-timestamp-underflow" >expect &&
+	git name-rev $old_commit_oid >actual &&
+	test_cmp expect actual
+'
+
+# A--------------master
+#  \            /
+#   \----------M2
+#    \        /
+#     \---M1-C
+#      \ /
+#       B
+test_expect_success 'name-rev covers all conditions while looking at parents' '
+	git init repo &&
+	(
+		cd repo &&
+
+		echo A >file &&
+		git add file &&
+		git commit -m A &&
+		A=$(git rev-parse HEAD) &&
+
+		git checkout --detach &&
+		echo B >file &&
+		git commit -m B file &&
+		B=$(git rev-parse HEAD) &&
+
+		git checkout $A &&
+		git merge --no-ff $B &&  # M1
+
+		echo C >file &&
+		git commit -m C file &&
+
+		git checkout $A &&
+		git merge --no-ff HEAD@{1} && # M2
+
+		git checkout master &&
+		git merge --no-ff HEAD@{1} &&
+
+		echo "$B master^2^2~1^2" >expect &&
+		git name-rev $B >actual &&
+
+		test_cmp expect actual
+	)
+'
+
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t6130-pathspec-noglob.sh 1.2.3+git2.25.1-1/git/t/t6130-pathspec-noglob.sh
--- 1.2.1+git2.18.0-1/git/t/t6130-pathspec-noglob.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t6130-pathspec-noglob.sh	2020-02-17 04:47:35.000000000 +0000
@@ -10,6 +10,7 @@ test_expect_success 'create commits with
 	# the name "f*" in the worktree, because it is not allowed
 	# on Windows (the tests below do not depend on the presence
 	# of the file in the worktree)
+	git config core.protectNTFS false &&
 	git update-index --add --cacheinfo 100644 "$(git rev-parse HEAD:foo)" "f*" &&
 	test_tick &&
 	git commit -m star &&
@@ -97,9 +98,8 @@ test_expect_success 'no-glob option matc
 '
 
 test_expect_success 'no-glob option disables :(literal)' '
-	: >expect &&
 	git --literal-pathspecs log --format=%s -- ":(literal)foo" >actual &&
-	test_cmp expect actual
+	test_must_be_empty actual
 '
 
 test_expect_success 'no-glob environment variable works' '
@@ -130,9 +130,8 @@ test_expect_success '**/ works with :(gl
 '
 
 test_expect_success '**/ does not work with --noglob-pathspecs' '
-	: >expect &&
 	git --noglob-pathspecs log --format=%s -- "**/bar" >actual &&
-	test_cmp expect actual
+	test_must_be_empty actual
 '
 
 test_expect_success '**/ works with :(glob) and --noglob-pathspecs' '
@@ -154,9 +153,8 @@ test_expect_success '**/ works with --gl
 '
 
 test_expect_success '**/ does not work with :(literal) and --glob-pathspecs' '
-	: >expect &&
 	git --glob-pathspecs log --format=%s -- ":(literal)**/bar" >actual &&
-	test_cmp expect actual
+	test_must_be_empty actual
 '
 
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t6132-pathspec-exclude.sh 1.2.3+git2.25.1-1/git/t/t6132-pathspec-exclude.sh
--- 1.2.1+git2.18.0-1/git/t/t6132-pathspec-exclude.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t6132-pathspec-exclude.sh	2020-02-17 04:47:35.000000000 +0000
@@ -194,4 +194,21 @@ test_expect_success 'multiple exclusions
 	test_cmp expect actual
 '
 
+test_expect_success 't_e_i() exclude case #8' '
+	git init case8 &&
+	(
+		cd case8 &&
+		echo file >file1 &&
+		echo file >file2 &&
+		git add file1 file2 &&
+		git commit -m twofiles &&
+		git grep -l file HEAD :^file2 >actual &&
+		echo HEAD:file1 >expected &&
+		test_cmp expected actual &&
+		git grep -l file HEAD :^file1 >actual &&
+		echo HEAD:file2 >expected &&
+		test_cmp expected actual
+	)
+'
+
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t6135-pathspec-with-attrs.sh 1.2.3+git2.25.1-1/git/t/t6135-pathspec-with-attrs.sh
--- 1.2.1+git2.18.0-1/git/t/t6135-pathspec-with-attrs.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t6135-pathspec-with-attrs.sh	2020-02-17 04:47:35.000000000 +0000
@@ -31,7 +31,7 @@ test_expect_success 'setup a tree' '
 	mkdir sub &&
 	while read path
 	do
-		: >$path &&
+		echo content >$path &&
 		git add $path || return 1
 	done <expect &&
 	git commit -m "initial commit" &&
@@ -48,6 +48,10 @@ test_expect_success 'pathspec with label
 	test_must_be_empty actual
 '
 
+test_expect_success 'pathspec with labels and non existent .gitattributes (2)' '
+	test_must_fail git grep content HEAD -- ":(attr:label)"
+'
+
 test_expect_success 'setup .gitattributes' '
 	cat <<-\EOF >.gitattributes &&
 	fileA labelA
@@ -74,6 +78,15 @@ test_expect_success 'check specific set
 	test_cmp expect actual
 '
 
+test_expect_success 'check specific set attr (2)' '
+	cat <<-\EOF >expect &&
+	HEAD:fileSetLabel
+	HEAD:sub/fileSetLabel
+	EOF
+	git grep -l content HEAD ":(attr:label)" >actual &&
+	test_cmp expect actual
+'
+
 test_expect_success 'check specific unset attr' '
 	cat <<-\EOF >expect &&
 	fileUnsetLabel
@@ -83,6 +96,15 @@ test_expect_success 'check specific unse
 	test_cmp expect actual
 '
 
+test_expect_success 'check specific unset attr (2)' '
+	cat <<-\EOF >expect &&
+	HEAD:fileUnsetLabel
+	HEAD:sub/fileUnsetLabel
+	EOF
+	git grep -l content HEAD ":(attr:-label)" >actual &&
+	test_cmp expect actual
+'
+
 test_expect_success 'check specific value attr' '
 	cat <<-\EOF >expect &&
 	fileValue
@@ -94,6 +116,16 @@ test_expect_success 'check specific valu
 	test_must_be_empty actual
 '
 
+test_expect_success 'check specific value attr (2)' '
+	cat <<-\EOF >expect &&
+	HEAD:fileValue
+	HEAD:sub/fileValue
+	EOF
+	git grep -l content HEAD ":(attr:label=foo)" >actual &&
+	test_cmp expect actual &&
+	test_must_fail git grep -l content HEAD ":(attr:label=bar)"
+'
+
 test_expect_success 'check unspecified attr' '
 	cat <<-\EOF >expect &&
 	.gitattributes
@@ -118,6 +150,30 @@ test_expect_success 'check unspecified a
 	test_cmp expect actual
 '
 
+test_expect_success 'check unspecified attr (2)' '
+	cat <<-\EOF >expect &&
+	HEAD:.gitattributes
+	HEAD:fileA
+	HEAD:fileAB
+	HEAD:fileAC
+	HEAD:fileB
+	HEAD:fileBC
+	HEAD:fileC
+	HEAD:fileNoLabel
+	HEAD:fileWrongLabel
+	HEAD:sub/fileA
+	HEAD:sub/fileAB
+	HEAD:sub/fileAC
+	HEAD:sub/fileB
+	HEAD:sub/fileBC
+	HEAD:sub/fileC
+	HEAD:sub/fileNoLabel
+	HEAD:sub/fileWrongLabel
+	EOF
+	git grep -l ^ HEAD ":(attr:!label)" >actual &&
+	test_cmp expect actual
+'
+
 test_expect_success 'check multiple unspecified attr' '
 	cat <<-\EOF >expect &&
 	.gitattributes
@@ -166,7 +222,7 @@ test_expect_success 'fail if attr magic
 	# though, but git-add is convenient as it has its own internal pathspec
 	# parsing.
 	test_must_fail git add ":(attr:labelB)" 2>actual &&
-	test_i18ngrep "unsupported magic" actual
+	test_i18ngrep "magic not supported" actual
 '
 
 test_expect_success 'abort on giving invalid label on the command line' '
diff -pruN 1.2.1+git2.18.0-1/git/t/t6200-fmt-merge-msg.sh 1.2.3+git2.25.1-1/git/t/t6200-fmt-merge-msg.sh
--- 1.2.1+git2.18.0-1/git/t/t6200-fmt-merge-msg.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t6200-fmt-merge-msg.sh	2020-02-17 04:47:35.000000000 +0000
@@ -66,12 +66,7 @@ test_expect_success setup '
 	git commit -a -m "Right #5" &&
 
 	git checkout -b long &&
-	i=0 &&
-	while test $i -lt 30
-	do
-		test_commit $i one &&
-		i=$(($i+1))
-	done &&
+	test_commit_bulk --start=0 --message=%s --filename=one 30 &&
 
 	git show-branch &&
 
@@ -366,8 +361,6 @@ test_expect_success 'merge-msg with noth
 	test_unconfig merge.log &&
 	test_config merge.summary yes &&
 
-	>empty &&
-
 	(
 		cd remote &&
 		git checkout -b unrelated &&
@@ -376,7 +369,7 @@ test_expect_success 'merge-msg with noth
 		git fmt-merge-msg <.git/FETCH_HEAD >../actual
 	) &&
 
-	test_cmp empty actual
+	test_must_be_empty actual
 '
 
 test_expect_success 'merge-msg tag' '
diff -pruN 1.2.1+git2.18.0-1/git/t/t6300-for-each-ref.sh 1.2.3+git2.25.1-1/git/t/t6300-for-each-ref.sh
--- 1.2.1+git2.18.0-1/git/t/t6300-for-each-ref.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t6300-for-each-ref.sh	2020-02-17 04:47:35.000000000 +0000
@@ -83,6 +83,8 @@ test_atom head push:strip=1 remotes/myfo
 test_atom head push:strip=-1 master
 test_atom head objecttype commit
 test_atom head objectsize 171
+test_atom head objectsize:disk 138
+test_atom head deltabase 0000000000000000000000000000000000000000
 test_atom head objectname $(git rev-parse refs/heads/master)
 test_atom head objectname:short $(git rev-parse --short refs/heads/master)
 test_atom head objectname:short=1 $(git rev-parse --short=1 refs/heads/master)
@@ -124,6 +126,10 @@ test_atom tag upstream ''
 test_atom tag push ''
 test_atom tag objecttype tag
 test_atom tag objectsize 154
+test_atom tag objectsize:disk 138
+test_atom tag '*objectsize:disk' 138
+test_atom tag deltabase 0000000000000000000000000000000000000000
+test_atom tag '*deltabase' 0000000000000000000000000000000000000000
 test_atom tag objectname $(git rev-parse refs/tags/testtag)
 test_atom tag objectname:short $(git rev-parse --short refs/tags/testtag)
 test_atom head objectname:short=1 $(git rev-parse --short=1 refs/heads/master)
@@ -340,6 +346,32 @@ test_expect_success 'Verify descending s
 '
 
 cat >expected <<\EOF
+refs/tags/testtag
+refs/tags/testtag-2
+EOF
+
+test_expect_success 'exercise patterns with prefixes' '
+	git tag testtag-2 &&
+	test_when_finished "git tag -d testtag-2" &&
+	git for-each-ref --format="%(refname)" \
+		refs/tags/testtag refs/tags/testtag-2 >actual &&
+	test_cmp expected actual
+'
+
+cat >expected <<\EOF
+refs/tags/testtag
+refs/tags/testtag-2
+EOF
+
+test_expect_success 'exercise glob patterns with prefixes' '
+	git tag testtag-2 &&
+	test_when_finished "git tag -d testtag-2" &&
+	git for-each-ref --format="%(refname)" \
+		refs/tags/testtag "refs/tags/testtag-*" >actual &&
+	test_cmp expected actual
+'
+
+cat >expected <<\EOF
 'refs/heads/master'
 'refs/remotes/origin/master'
 'refs/tags/testtag'
@@ -386,8 +418,15 @@ test_atom head upstream:track '[ahead 1]
 test_atom head upstream:trackshort '>'
 test_atom head upstream:track,nobracket 'ahead 1'
 test_atom head upstream:nobracket,track 'ahead 1'
-test_atom head push:track '[ahead 1]'
-test_atom head push:trackshort '>'
+
+test_expect_success 'setup for push:track[short]' '
+	test_commit third &&
+	git update-ref refs/remotes/myfork/master master &&
+	git reset master~1
+'
+
+test_atom head push:track '[behind 1]'
+test_atom head push:trackshort '<'
 
 test_expect_success 'Check that :track[short] cannot be used with other atoms' '
 	test_must_fail git for-each-ref --format="%(refname:track)" 2>/dev/null &&
@@ -414,8 +453,10 @@ test_expect_success 'Check for invalid r
 test_expect_success 'set up color tests' '
 	cat >expected.color <<-EOF &&
 	$(git rev-parse --short refs/heads/master) <GREEN>master<RESET>
+	$(git rev-parse --short refs/remotes/myfork/master) <GREEN>myfork/master<RESET>
 	$(git rev-parse --short refs/remotes/origin/master) <GREEN>origin/master<RESET>
 	$(git rev-parse --short refs/tags/testtag) <GREEN>testtag<RESET>
+	$(git rev-parse --short refs/tags/third) <GREEN>third<RESET>
 	$(git rev-parse --short refs/tags/two) <GREEN>two<RESET>
 	EOF
 	sed "s/<[^>]*>//g" <expected.color >expected.bare &&
@@ -485,6 +526,25 @@ test_expect_success 'Check ambiguous hea
 	test_cmp expected actual
 '
 
+test_expect_success 'create tag without tagger' '
+	git tag -a -m "Broken tag" taggerless &&
+	git tag -f taggerless $(git cat-file tag taggerless |
+		sed -e "/^tagger /d" |
+		git hash-object --stdin -w -t tag)
+'
+
+test_atom refs/tags/taggerless type 'commit'
+test_atom refs/tags/taggerless tag 'taggerless'
+test_atom refs/tags/taggerless tagger ''
+test_atom refs/tags/taggerless taggername ''
+test_atom refs/tags/taggerless taggeremail ''
+test_atom refs/tags/taggerless taggerdate ''
+test_atom refs/tags/taggerless committer ''
+test_atom refs/tags/taggerless committername ''
+test_atom refs/tags/taggerless committeremail ''
+test_atom refs/tags/taggerless committerdate ''
+test_atom refs/tags/taggerless subject 'Broken tag'
+
 test_expect_success 'an unusual tag with an incomplete line' '
 
 	git tag -m "bogo" bogo &&
@@ -715,6 +775,29 @@ test_expect_success 'basic atom: head co
 	test_cmp expect actual.clean
 '
 
+test_expect_success 'trailer parsing not fooled by --- line' '
+	git commit --allow-empty -F - <<-\EOF &&
+	this is the subject
+
+	This is the body. The message has a "---" line which would confuse a
+	message+patch parser. But here we know we have only a commit message,
+	so we get it right.
+
+	trailer: wrong
+	---
+	This is more body.
+
+	trailer: right
+	EOF
+
+	{
+		echo "trailer: right" &&
+		echo
+	} >expect &&
+	git for-each-ref --format="%(trailers)" refs/heads/master >actual &&
+	test_cmp expect actual
+'
+
 test_expect_success 'Add symbolic ref for the following tests' '
 	git symbolic-ref refs/heads/sym refs/heads/master
 '
@@ -795,4 +878,14 @@ test_expect_success ':remotename and :re
 	)
 '
 
+test_expect_success 'for-each-ref --ignore-case ignores case' '
+	git for-each-ref --format="%(refname)" refs/heads/MASTER >actual &&
+	test_must_be_empty actual &&
+
+	echo refs/heads/master >expect &&
+	git for-each-ref --format="%(refname)" --ignore-case \
+		refs/heads/MASTER >actual &&
+	test_cmp expect actual
+'
+
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t6302-for-each-ref-filter.sh 1.2.3+git2.25.1-1/git/t/t6302-for-each-ref-filter.sh
--- 1.2.1+git2.18.0-1/git/t/t6302-for-each-ref-filter.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t6302-for-each-ref-filter.sh	2020-02-17 04:47:35.000000000 +0000
@@ -441,4 +441,17 @@ test_expect_success '--merged is incompa
 	test_must_fail git for-each-ref --merged HEAD --no-merged HEAD
 '
 
+test_expect_success 'validate worktree atom' '
+	cat >expect <<-EOF &&
+	master: $(pwd)
+	master_worktree: $(pwd)/worktree_dir
+	side: not checked out
+	EOF
+	git worktree add -b master_worktree worktree_dir master &&
+	git for-each-ref --format="%(refname:short): %(if)%(worktreepath)%(then)%(worktreepath)%(else)not checked out%(end)" refs/heads/ >actual &&
+	rm -r worktree_dir &&
+	git worktree prune &&
+	test_cmp expect actual
+'
+
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t6500-gc.sh 1.2.3+git2.25.1-1/git/t/t6500-gc.sh
--- 1.2.1+git2.18.0-1/git/t/t6500-gc.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t6500-gc.sh	2020-02-17 04:47:35.000000000 +0000
@@ -4,6 +4,7 @@ test_description='basic git gc tests
 '
 
 . ./test-lib.sh
+. "$TEST_DIRECTORY"/lib-terminal.sh
 
 test_expect_success 'setup' '
 	# do not let the amount of physical memory affects gc
@@ -70,6 +71,8 @@ test_expect_success 'gc --keep-largest-p
 		git gc --keep-largest-pack &&
 		( cd .git/objects/pack && ls *.pack ) >pack-list &&
 		test_line_count = 2 pack-list &&
+		awk "/^P /{print \$2}" <.git/objects/info/packs >pack-info &&
+		test_line_count = 2 pack-info &&
 		test_path_is_file $BASE_PACK &&
 		git fsck
 	)
@@ -99,6 +102,45 @@ test_expect_success 'auto gc with too ma
 	test_line_count = 2 new # There is one new pack and its .idx
 '
 
+test_expect_success 'gc --no-quiet' '
+	GIT_PROGRESS_DELAY=0 git -c gc.writeCommitGraph=true gc --no-quiet >stdout 2>stderr &&
+	test_must_be_empty stdout &&
+	test_i18ngrep "Computing commit graph generation numbers" stderr
+'
+
+test_expect_success TTY 'with TTY: gc --no-quiet' '
+	test_terminal env GIT_PROGRESS_DELAY=0 \
+		git -c gc.writeCommitGraph=true gc --no-quiet >stdout 2>stderr &&
+	test_must_be_empty stdout &&
+	test_i18ngrep "Enumerating objects" stderr &&
+	test_i18ngrep "Computing commit graph generation numbers" stderr
+'
+
+test_expect_success 'gc --quiet' '
+	git -c gc.writeCommitGraph=true gc --quiet >stdout 2>stderr &&
+	test_must_be_empty stdout &&
+	test_must_be_empty stderr
+'
+
+test_expect_success 'gc.reflogExpire{Unreachable,}=never skips "expire" via "gc"' '
+	test_config gc.reflogExpire never &&
+	test_config gc.reflogExpireUnreachable never &&
+
+	GIT_TRACE=$(pwd)/trace.out git gc &&
+
+	# Check that git-pack-refs is run as a sanity check (done via
+	# gc_before_repack()) but that git-expire is not.
+	grep -E "^trace: (built-in|exec|run_command): git pack-refs --" trace.out &&
+	! grep -E "^trace: (built-in|exec|run_command): git reflog expire --" trace.out
+'
+
+test_expect_success 'one of gc.reflogExpire{Unreachable,}=never does not skip "expire" via "gc"' '
+	>trace.out &&
+	test_config gc.reflogExpire never &&
+	GIT_TRACE=$(pwd)/trace.out git gc &&
+	grep -E "^trace: (built-in|exec|run_command): git reflog expire --" trace.out
+'
+
 run_and_wait_for_auto_gc () {
 	# We read stdout from gc for the side effect of waiting until the
 	# background gc process exits, closing its fd 9.  Furthermore, the
@@ -116,11 +158,11 @@ test_expect_success 'background auto gc
 	test_config gc.autopacklimit 1 &&
 	test_config gc.autodetach true &&
 	echo fleem >.git/gc.log &&
-	test_must_fail git gc --auto 2>err &&
-	test_i18ngrep "^error:" err &&
+	git gc --auto 2>err &&
+	test_i18ngrep "^warning:" err &&
 	test_config gc.logexpiry 5.days &&
 	test-tool chmtime =-345600 .git/gc.log &&
-	test_must_fail git gc --auto &&
+	git gc --auto &&
 	test_config gc.logexpiry 2.days &&
 	run_and_wait_for_auto_gc &&
 	ls .git/objects/pack/pack-*.pack >packs &&
@@ -141,7 +183,15 @@ test_expect_success 'background auto gc
 	# now fake a concurrent gc that holds the lock; we can use our
 	# shell pid so that it looks valid.
 	hostname=$(hostname || echo unknown) &&
-	printf "$$ %s" "$hostname" >.git/gc.pid &&
+	shell_pid=$$ &&
+	if test_have_prereq MINGW && test -f /proc/$shell_pid/winpid
+	then
+		# In Git for Windows, Bash (actually, the MSYS2 runtime) has a
+		# different idea of PIDs than git.exe (actually Windows). Use
+		# the Windows PID in this case.
+		shell_pid=$(cat /proc/$shell_pid/winpid)
+	fi &&
+	printf "%d %s" "$shell_pid" "$hostname" >.git/gc.pid &&
 
 	# our gc should exit zero without doing anything
 	run_and_wait_for_auto_gc &&
diff -pruN 1.2.1+git2.18.0-1/git/t/t6501-freshen-objects.sh 1.2.3+git2.25.1-1/git/t/t6501-freshen-objects.sh
--- 1.2.1+git2.18.0-1/git/t/t6501-freshen-objects.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t6501-freshen-objects.sh	2020-02-17 04:47:35.000000000 +0000
@@ -137,7 +137,7 @@ test_expect_success 'do not complain abo
 	some message
 	EOF
 	commit=$(git hash-object -t commit -w broken-commit) &&
-	git gc 2>stderr &&
+	git gc -q 2>stderr &&
 	verbose git cat-file -e $commit &&
 	test_must_be_empty stderr
 '
@@ -147,7 +147,7 @@ test_expect_success 'do not complain abo
 	100644 blob 0000000000000000000000000000000000000003	foo
 	EOF
 	tree=$(git mktree --missing <broken-tree) &&
-	git gc 2>stderr &&
+	git gc -q 2>stderr &&
 	git cat-file -e $tree &&
 	test_must_be_empty stderr
 '
@@ -162,7 +162,7 @@ test_expect_success 'do not complain abo
 	this is a broken tag
 	EOF
 	tag=$(git hash-object -t tag -w broken-tag) &&
-	git gc 2>stderr &&
+	git gc -q 2>stderr &&
 	git cat-file -e $tag &&
 	test_must_be_empty stderr
 '
diff -pruN 1.2.1+git2.18.0-1/git/t/t6600-test-reach.sh 1.2.3+git2.25.1-1/git/t/t6600-test-reach.sh
--- 1.2.1+git2.18.0-1/git/t/t6600-test-reach.sh	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t6600-test-reach.sh	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,408 @@
+#!/bin/sh
+
+test_description='basic commit reachability tests'
+
+. ./test-lib.sh
+
+# Construct a grid-like commit graph with points (x,y)
+# with 1 <= x <= 10, 1 <= y <= 10, where (x,y) has
+# parents (x-1, y) and (x, y-1), keeping in mind that
+# we drop a parent if a coordinate is nonpositive.
+#
+#             (10,10)
+#            /       \
+#         (10,9)    (9,10)
+#        /     \   /      \
+#    (10,8)    (9,9)      (8,10)
+#   /     \    /   \      /    \
+#         ( continued...)
+#   \     /    \   /      \    /
+#    (3,1)     (2,2)      (1,3)
+#        \     /    \     /
+#         (2,1)      (2,1)
+#              \    /
+#              (1,1)
+#
+# We use branch 'commit-x-y' to refer to (x,y).
+# This grid allows interesting reachability and
+# non-reachability queries: (x,y) can reach (x',y')
+# if and only if x' <= x and y' <= y.
+test_expect_success 'setup' '
+	for i in $(test_seq 1 10)
+	do
+		test_commit "1-$i" &&
+		git branch -f commit-1-$i &&
+		git tag -a -m "1-$i" tag-1-$i commit-1-$i
+	done &&
+	for j in $(test_seq 1 9)
+	do
+		git reset --hard commit-$j-1 &&
+		x=$(($j + 1)) &&
+		test_commit "$x-1" &&
+		git branch -f commit-$x-1 &&
+		git tag -a -m "$x-1" tag-$x-1 commit-$x-1 &&
+
+		for i in $(test_seq 2 10)
+		do
+			git merge commit-$j-$i -m "$x-$i" &&
+			git branch -f commit-$x-$i &&
+			git tag -a -m "$x-$i" tag-$x-$i commit-$x-$i
+		done
+	done &&
+	git commit-graph write --reachable &&
+	mv .git/objects/info/commit-graph commit-graph-full &&
+	git show-ref -s commit-5-5 | git commit-graph write --stdin-commits &&
+	mv .git/objects/info/commit-graph commit-graph-half &&
+	git config core.commitGraph true
+'
+
+run_three_modes () {
+	test_when_finished rm -rf .git/objects/info/commit-graph &&
+	"$@" <input >actual &&
+	test_cmp expect actual &&
+	cp commit-graph-full .git/objects/info/commit-graph &&
+	"$@" <input >actual &&
+	test_cmp expect actual &&
+	cp commit-graph-half .git/objects/info/commit-graph &&
+	"$@" <input >actual &&
+	test_cmp expect actual
+}
+
+test_three_modes () {
+	run_three_modes test-tool reach "$@"
+}
+
+test_expect_success 'ref_newer:miss' '
+	cat >input <<-\EOF &&
+	A:commit-5-7
+	B:commit-4-9
+	EOF
+	echo "ref_newer(A,B):0" >expect &&
+	test_three_modes ref_newer
+'
+
+test_expect_success 'ref_newer:hit' '
+	cat >input <<-\EOF &&
+	A:commit-5-7
+	B:commit-2-3
+	EOF
+	echo "ref_newer(A,B):1" >expect &&
+	test_three_modes ref_newer
+'
+
+test_expect_success 'in_merge_bases:hit' '
+	cat >input <<-\EOF &&
+	A:commit-5-7
+	B:commit-8-8
+	EOF
+	echo "in_merge_bases(A,B):1" >expect &&
+	test_three_modes in_merge_bases
+'
+
+test_expect_success 'in_merge_bases:miss' '
+	cat >input <<-\EOF &&
+	A:commit-6-8
+	B:commit-5-9
+	EOF
+	echo "in_merge_bases(A,B):0" >expect &&
+	test_three_modes in_merge_bases
+'
+
+test_expect_success 'is_descendant_of:hit' '
+	cat >input <<-\EOF &&
+	A:commit-5-7
+	X:commit-4-8
+	X:commit-6-6
+	X:commit-1-1
+	EOF
+	echo "is_descendant_of(A,X):1" >expect &&
+	test_three_modes is_descendant_of
+'
+
+test_expect_success 'is_descendant_of:miss' '
+	cat >input <<-\EOF &&
+	A:commit-6-8
+	X:commit-5-9
+	X:commit-4-10
+	X:commit-7-6
+	EOF
+	echo "is_descendant_of(A,X):0" >expect &&
+	test_three_modes is_descendant_of
+'
+
+test_expect_success 'get_merge_bases_many' '
+	cat >input <<-\EOF &&
+	A:commit-5-7
+	X:commit-4-8
+	X:commit-6-6
+	X:commit-8-3
+	EOF
+	{
+		echo "get_merge_bases_many(A,X):" &&
+		git rev-parse commit-5-6 \
+			      commit-4-7 | sort
+	} >expect &&
+	test_three_modes get_merge_bases_many
+'
+
+test_expect_success 'reduce_heads' '
+	cat >input <<-\EOF &&
+	X:commit-1-10
+	X:commit-2-8
+	X:commit-3-6
+	X:commit-4-4
+	X:commit-1-7
+	X:commit-2-5
+	X:commit-3-3
+	X:commit-5-1
+	EOF
+	{
+		echo "reduce_heads(X):" &&
+		git rev-parse commit-5-1 \
+			      commit-4-4 \
+			      commit-3-6 \
+			      commit-2-8 \
+			      commit-1-10 | sort
+	} >expect &&
+	test_three_modes reduce_heads
+'
+
+test_expect_success 'can_all_from_reach:hit' '
+	cat >input <<-\EOF &&
+	X:commit-2-10
+	X:commit-3-9
+	X:commit-4-8
+	X:commit-5-7
+	X:commit-6-6
+	X:commit-7-5
+	X:commit-8-4
+	X:commit-9-3
+	Y:commit-1-9
+	Y:commit-2-8
+	Y:commit-3-7
+	Y:commit-4-6
+	Y:commit-5-5
+	Y:commit-6-4
+	Y:commit-7-3
+	Y:commit-8-1
+	EOF
+	echo "can_all_from_reach(X,Y):1" >expect &&
+	test_three_modes can_all_from_reach
+'
+
+test_expect_success 'can_all_from_reach:miss' '
+	cat >input <<-\EOF &&
+	X:commit-2-10
+	X:commit-3-9
+	X:commit-4-8
+	X:commit-5-7
+	X:commit-6-6
+	X:commit-7-5
+	X:commit-8-4
+	X:commit-9-3
+	Y:commit-1-9
+	Y:commit-2-8
+	Y:commit-3-7
+	Y:commit-4-6
+	Y:commit-5-5
+	Y:commit-6-4
+	Y:commit-8-5
+	EOF
+	echo "can_all_from_reach(X,Y):0" >expect &&
+	test_three_modes can_all_from_reach
+'
+
+test_expect_success 'can_all_from_reach_with_flag: tags case' '
+	cat >input <<-\EOF &&
+	X:tag-2-10
+	X:tag-3-9
+	X:tag-4-8
+	X:commit-5-7
+	X:commit-6-6
+	X:commit-7-5
+	X:commit-8-4
+	X:commit-9-3
+	Y:tag-1-9
+	Y:tag-2-8
+	Y:tag-3-7
+	Y:commit-4-6
+	Y:commit-5-5
+	Y:commit-6-4
+	Y:commit-7-3
+	Y:commit-8-1
+	EOF
+	echo "can_all_from_reach_with_flag(X,_,_,0,0):1" >expect &&
+	test_three_modes can_all_from_reach_with_flag
+'
+
+test_expect_success 'commit_contains:hit' '
+	cat >input <<-\EOF &&
+	A:commit-7-7
+	X:commit-2-10
+	X:commit-3-9
+	X:commit-4-8
+	X:commit-5-7
+	X:commit-6-6
+	X:commit-7-5
+	X:commit-8-4
+	X:commit-9-3
+	EOF
+	echo "commit_contains(_,A,X,_):1" >expect &&
+	test_three_modes commit_contains &&
+	test_three_modes commit_contains --tag
+'
+
+test_expect_success 'commit_contains:miss' '
+	cat >input <<-\EOF &&
+	A:commit-6-5
+	X:commit-2-10
+	X:commit-3-9
+	X:commit-4-8
+	X:commit-5-7
+	X:commit-6-6
+	X:commit-7-5
+	X:commit-8-4
+	X:commit-9-3
+	EOF
+	echo "commit_contains(_,A,X,_):0" >expect &&
+	test_three_modes commit_contains &&
+	test_three_modes commit_contains --tag
+'
+
+test_expect_success 'rev-list: basic topo-order' '
+	git rev-parse \
+		commit-6-6 commit-5-6 commit-4-6 commit-3-6 commit-2-6 commit-1-6 \
+		commit-6-5 commit-5-5 commit-4-5 commit-3-5 commit-2-5 commit-1-5 \
+		commit-6-4 commit-5-4 commit-4-4 commit-3-4 commit-2-4 commit-1-4 \
+		commit-6-3 commit-5-3 commit-4-3 commit-3-3 commit-2-3 commit-1-3 \
+		commit-6-2 commit-5-2 commit-4-2 commit-3-2 commit-2-2 commit-1-2 \
+		commit-6-1 commit-5-1 commit-4-1 commit-3-1 commit-2-1 commit-1-1 \
+	>expect &&
+	run_three_modes git rev-list --topo-order commit-6-6
+'
+
+test_expect_success 'rev-list: first-parent topo-order' '
+	git rev-parse \
+		commit-6-6 \
+		commit-6-5 \
+		commit-6-4 \
+		commit-6-3 \
+		commit-6-2 \
+		commit-6-1 commit-5-1 commit-4-1 commit-3-1 commit-2-1 commit-1-1 \
+	>expect &&
+	run_three_modes git rev-list --first-parent --topo-order commit-6-6
+'
+
+test_expect_success 'rev-list: range topo-order' '
+	git rev-parse \
+		commit-6-6 commit-5-6 commit-4-6 commit-3-6 commit-2-6 commit-1-6 \
+		commit-6-5 commit-5-5 commit-4-5 commit-3-5 commit-2-5 commit-1-5 \
+		commit-6-4 commit-5-4 commit-4-4 commit-3-4 commit-2-4 commit-1-4 \
+		commit-6-3 commit-5-3 commit-4-3 \
+		commit-6-2 commit-5-2 commit-4-2 \
+		commit-6-1 commit-5-1 commit-4-1 \
+	>expect &&
+	run_three_modes git rev-list --topo-order commit-3-3..commit-6-6
+'
+
+test_expect_success 'rev-list: range topo-order' '
+	git rev-parse \
+		commit-6-6 commit-5-6 commit-4-6 \
+		commit-6-5 commit-5-5 commit-4-5 \
+		commit-6-4 commit-5-4 commit-4-4 \
+		commit-6-3 commit-5-3 commit-4-3 \
+		commit-6-2 commit-5-2 commit-4-2 \
+		commit-6-1 commit-5-1 commit-4-1 \
+	>expect &&
+	run_three_modes git rev-list --topo-order commit-3-8..commit-6-6
+'
+
+test_expect_success 'rev-list: first-parent range topo-order' '
+	git rev-parse \
+		commit-6-6 \
+		commit-6-5 \
+		commit-6-4 \
+		commit-6-3 \
+		commit-6-2 \
+		commit-6-1 commit-5-1 commit-4-1 \
+	>expect &&
+	run_three_modes git rev-list --first-parent --topo-order commit-3-8..commit-6-6
+'
+
+test_expect_success 'rev-list: ancestry-path topo-order' '
+	git rev-parse \
+		commit-6-6 commit-5-6 commit-4-6 commit-3-6 \
+		commit-6-5 commit-5-5 commit-4-5 commit-3-5 \
+		commit-6-4 commit-5-4 commit-4-4 commit-3-4 \
+		commit-6-3 commit-5-3 commit-4-3 \
+	>expect &&
+	run_three_modes git rev-list --topo-order --ancestry-path commit-3-3..commit-6-6
+'
+
+test_expect_success 'rev-list: symmetric difference topo-order' '
+	git rev-parse \
+		commit-6-6 commit-5-6 commit-4-6 \
+		commit-6-5 commit-5-5 commit-4-5 \
+		commit-6-4 commit-5-4 commit-4-4 \
+		commit-6-3 commit-5-3 commit-4-3 \
+		commit-6-2 commit-5-2 commit-4-2 \
+		commit-6-1 commit-5-1 commit-4-1 \
+		commit-3-8 commit-2-8 commit-1-8 \
+		commit-3-7 commit-2-7 commit-1-7 \
+	>expect &&
+	run_three_modes git rev-list --topo-order commit-3-8...commit-6-6
+'
+
+test_expect_success 'get_reachable_subset:all' '
+	cat >input <<-\EOF &&
+	X:commit-9-1
+	X:commit-8-3
+	X:commit-7-5
+	X:commit-6-6
+	X:commit-1-7
+	Y:commit-3-3
+	Y:commit-1-7
+	Y:commit-5-6
+	EOF
+	(
+		echo "get_reachable_subset(X,Y)" &&
+		git rev-parse commit-3-3 \
+			      commit-1-7 \
+			      commit-5-6 | sort
+	) >expect &&
+	test_three_modes get_reachable_subset
+'
+
+test_expect_success 'get_reachable_subset:some' '
+	cat >input <<-\EOF &&
+	X:commit-9-1
+	X:commit-8-3
+	X:commit-7-5
+	X:commit-1-7
+	Y:commit-3-3
+	Y:commit-1-7
+	Y:commit-5-6
+	EOF
+	(
+		echo "get_reachable_subset(X,Y)" &&
+		git rev-parse commit-3-3 \
+			      commit-1-7 | sort
+	) >expect &&
+	test_three_modes get_reachable_subset
+'
+
+test_expect_success 'get_reachable_subset:none' '
+	cat >input <<-\EOF &&
+	X:commit-9-1
+	X:commit-8-3
+	X:commit-7-5
+	X:commit-1-7
+	Y:commit-9-3
+	Y:commit-7-6
+	Y:commit-2-8
+	EOF
+	echo "get_reachable_subset(X,Y)" >expect &&
+	test_three_modes get_reachable_subset
+'
+
+test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t7001-mv.sh 1.2.3+git2.25.1-1/git/t/t7001-mv.sh
--- 1.2.1+git2.18.0-1/git/t/t7001-mv.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t7001-mv.sh	2020-02-17 04:47:35.000000000 +0000
@@ -384,7 +384,7 @@ test_expect_success 'mv does not complai
 	entry="$(git ls-files --stage sub | cut -f 1)" &&
 	mkdir mod &&
 	git mv sub mod/sub 2>actual.err &&
-	! test -s actual.err &&
+	test_must_be_empty actual.err &&
 	! test -e sub &&
 	[ "$entry" = "$(git ls-files --stage mod/sub | cut -f 1)" ] &&
 	(
@@ -408,7 +408,7 @@ test_expect_success 'mv will error out o
 	git diff-files --quiet -- sub &&
 	git add .gitmodules &&
 	git mv sub mod/sub 2>actual.err &&
-	! test -s actual.err &&
+	test_must_be_empty actual.err &&
 	! test -e sub &&
 	[ "$entry" = "$(git ls-files --stage mod/sub | cut -f 1)" ] &&
 	(
@@ -469,7 +469,7 @@ test_expect_success 'checking out a comm
 	git update-index --refresh &&
 	git diff-files --quiet -- sub .gitmodules &&
 	git status -s sub2 >actual &&
-	! test -s actual
+	test_must_be_empty actual
 '
 
 test_expect_success 'mv -k does not accidentally destroy submodules' '
@@ -509,7 +509,7 @@ test_expect_success 'moving nested submo
 		touch nested_level1 &&
 		git init &&
 		git add . &&
-		git commit -m "nested level 1"
+		git commit -m "nested level 1" &&
 		git submodule add ../sub_nested_nested &&
 		git commit -m "add nested level 2"
 	) &&
diff -pruN 1.2.1+git2.18.0-1/git/t/t7003-filter-branch.sh 1.2.3+git2.25.1-1/git/t/t7003-filter-branch.sh
--- 1.2.1+git2.18.0-1/git/t/t7003-filter-branch.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t7003-filter-branch.sh	2020-02-17 04:47:35.000000000 +0000
@@ -107,6 +107,21 @@ test_expect_success 'test that the direc
 	test dir/D = "$(cat diroh/D.t)"
 '
 
+V=$(git rev-parse HEAD)
+
+test_expect_success 'populate --state-branch' '
+	git filter-branch --state-branch state -f --tree-filter "touch file || :" HEAD
+'
+
+W=$(git rev-parse HEAD)
+
+test_expect_success 'using --state-branch to skip already rewritten commits' '
+	test_when_finished git reset --hard $V &&
+	git reset --hard $V &&
+	git filter-branch --state-branch state -f --tree-filter "touch file || :" HEAD &&
+	test_cmp_rev $W HEAD
+'
+
 git tag oldD HEAD~4
 test_expect_success 'rewrite one branch, keeping a side branch' '
 	git branch modD oldD &&
diff -pruN 1.2.1+git2.18.0-1/git/t/t7004-tag.sh 1.2.3+git2.25.1-1/git/t/t7004-tag.sh
--- 1.2.1+git2.18.0-1/git/t/t7004-tag.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t7004-tag.sh	2020-02-17 04:47:35.000000000 +0000
@@ -227,10 +227,10 @@ test_expect_success \
 test_expect_success \
 	'trying to delete two tags, existing and not, should fail in the 2nd' '
 	tag_exists mytag &&
-	! tag_exists myhead &&
-	test_must_fail git tag -d mytag anothertag &&
+	! tag_exists nonexistingtag &&
+	test_must_fail git tag -d mytag nonexistingtag &&
 	! tag_exists mytag &&
-	! tag_exists myhead
+	! tag_exists nonexistingtag
 '
 
 test_expect_success 'trying to delete an already deleted tag should fail' \
@@ -325,11 +325,10 @@ test_expect_success \
 	test_cmp expect actual
 '
 
->expect
 test_expect_success \
 	'listing tags using v.* should print nothing because none have v.' '
 	git tag -l "v.*" > actual &&
-	test_cmp expect actual
+	test_must_be_empty actual
 '
 
 cat >expect <<EOF
@@ -518,7 +517,6 @@ test_expect_success \
 test_expect_success \
 	'trying to create tags giving both -m or -F options should fail' '
 	echo "message file 1" >msgfile1 &&
-	echo "message file 2" >msgfile2 &&
 	! tag_exists msgtag &&
 	test_must_fail git tag -m "message 1" -F msgfile1 msgtag &&
 	! tag_exists msgtag &&
@@ -693,9 +691,8 @@ test_expect_success \
 '
 
 test_expect_success 'The -n 100 invocation means -n --list 100, not -n100' '
-	>expect &&
 	git tag -n 100 >actual &&
-	test_cmp expect actual &&
+	test_must_be_empty actual &&
 
 	git tag -m "A msg" 100 &&
 	echo "100             A msg" >expect &&
@@ -934,6 +931,27 @@ test_expect_success GPG \
 	test_cmp expect actual
 '
 
+get_tag_header gpgsign-enabled $commit commit $time >expect
+echo "A message" >>expect
+echo '-----BEGIN PGP SIGNATURE-----' >>expect
+test_expect_success GPG \
+	'git tag configured tag.gpgsign enables GPG sign' \
+	'test_config tag.gpgsign true &&
+	git tag -m "A message" gpgsign-enabled &&
+	get_tag_msg gpgsign-enabled>actual &&
+	test_cmp expect actual
+'
+
+get_tag_header no-sign $commit commit $time >expect
+echo "A message" >>expect
+test_expect_success GPG \
+	'git tag --no-sign configured tag.gpgsign skip GPG sign' \
+	'test_config tag.gpgsign true &&
+	git tag -a --no-sign -m "A message" no-sign &&
+	get_tag_msg no-sign>actual &&
+	test_cmp expect actual
+'
+
 test_expect_success GPG \
 	'trying to create a signed tag with non-existing -F file should fail' '
 	! test -f nonexistingfile &&
@@ -974,9 +992,8 @@ test_expect_success GPG 'verifying a pro
 '
 
 test_expect_success GPG 'verifying a forged tag with --format should fail silently' '
-	>expect &&
 	test_must_fail git tag -v --format="tagname : %(tag)" "forged-tag" >actual &&
-	test_cmp expect actual
+	test_must_be_empty actual
 '
 
 # blank and empty messages for signed tags:
@@ -1354,6 +1371,19 @@ test_expect_success GPG \
 	'test_config gpg.program echo &&
 	 test_must_fail git tag -s -m tail tag-gpg-failure'
 
+# try to sign with bad user.signingkey
+test_expect_success GPGSM \
+	'git tag -s fails if gpgsm is misconfigured (bad key)' \
+	'test_config user.signingkey BobTheMouse &&
+	 test_config gpg.format x509 &&
+	 test_must_fail git tag -s -m tail tag-gpg-failure'
+
+# try to produce invalid signature
+test_expect_success GPGSM \
+	'git tag -s fails if gpgsm is misconfigured (bad signature format)' \
+	'test_config gpg.x509.program echo &&
+	 test_config gpg.format x509 &&
+	 test_must_fail git tag -s -m tail tag-gpg-failure'
 
 # try to verify without gpg:
 
@@ -1382,15 +1412,14 @@ test_expect_success 'message in editor h
 test_expect_success \
 	'message in editor has initial comment: remainder' '
 	# remove commented lines from the remainder -- should be empty
-	>rest.expect &&
 	sed -e 1d -e "/^#/d" <actual >rest.actual &&
-	test_cmp rest.expect rest.actual
+	test_must_be_empty rest.actual
 '
 
 get_tag_header reuse $commit commit $time >expect
 echo "An annotation to be reused" >> expect
 test_expect_success \
-	'overwriting an annoted tag should use its previous body' '
+	'overwriting an annotated tag should use its previous body' '
 	git tag -a -m "An annotation to be reused" reuse &&
 	GIT_EDITOR=true git tag -f -a reuse &&
 	get_tag_msg reuse >actual &&
@@ -1466,19 +1495,18 @@ test_expect_success 'checking that first
 
 # All the --contains tests above, but with --no-contains
 test_expect_success 'checking that first commit is not listed in any tag with --no-contains  (hash)' "
-	>expected &&
 	git tag -l --no-contains $hash1 v* >actual &&
-	test_cmp expected actual
+	test_must_be_empty actual
 "
 
 test_expect_success 'checking that first commit is in all tags (tag)' "
 	git tag -l --no-contains v1.0 v* >actual &&
-	test_cmp expected actual
+	test_must_be_empty actual
 "
 
 test_expect_success 'checking that first commit is in all tags (relative)' "
 	git tag -l --no-contains HEAD~2 v* >actual &&
-	test_cmp expected actual
+	test_must_be_empty actual
 "
 
 cat > expected <<EOF
@@ -1502,12 +1530,9 @@ test_expect_success 'inverse of the last
 	test_cmp expected actual
 "
 
-cat > expected <<EOF
-EOF
-
 test_expect_success 'checking that third commit has no tags' "
 	git tag -l --contains $hash3 v* >actual &&
-	test_cmp expected actual
+	test_must_be_empty actual
 "
 
 cat > expected <<EOF
@@ -1606,9 +1631,8 @@ test_expect_success 'checking that --con
 '
 
 test_expect_success 'checking that initial commit is in all tags with --no-contains' "
-	>expected &&
 	git tag -l --no-contains $hash1 v* >actual &&
-	test_cmp expected actual
+	test_must_be_empty actual
 "
 
 # mixing modes and options:
@@ -1696,6 +1720,17 @@ test_expect_success '--points-at finds a
 	test_cmp expect actual
 '
 
+test_expect_success 'recursive tagging should give advice' '
+	sed -e "s/|$//" <<-EOF >expect &&
+	hint: You have created a nested tag. The object referred to by your new tag is
+	hint: already a tag. If you meant to tag the object that it points to, use:
+	hint: |
+	hint: 	git tag -f nested annotated-v4.0^{}
+	EOF
+	git tag -m nested nested annotated-v4.0 2>actual &&
+	test_i18ncmp expect actual
+'
+
 test_expect_success 'multiple --points-at are OR-ed together' '
 	cat >expect <<-\EOF &&
 	v2.0
@@ -1905,7 +1940,6 @@ test_expect_success 'version sort with v
 '
 
 test_expect_success ULIMIT_STACK_SIZE '--contains and --no-contains work in a deep repo' '
-	>expect &&
 	i=1 &&
 	while test $i -lt 8000
 	do
@@ -1920,7 +1954,7 @@ EOF"
 	git checkout master &&
 	git tag far-far-away HEAD^ &&
 	run_with_limited_stack git tag --contains HEAD >actual &&
-	test_cmp expect actual &&
+	test_must_be_empty actual &&
 	run_with_limited_stack git tag --no-contains HEAD >actual &&
 	test_line_count "-gt" 10 actual
 '
diff -pruN 1.2.1+git2.18.0-1/git/t/t7005-editor.sh 1.2.3+git2.25.1-1/git/t/t7005-editor.sh
--- 1.2.1+git2.18.0-1/git/t/t7005-editor.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t7005-editor.sh	2020-02-17 04:47:35.000000000 +0000
@@ -112,7 +112,7 @@ do
 done
 
 test_expect_success 'editor with a space' '
-	echo "echo space >\$1" >"e space.sh" &&
+	echo "echo space >\"\$1\"" >"e space.sh" &&
 	chmod a+x "e space.sh" &&
 	GIT_EDITOR="./e\ space.sh" git commit --amend &&
 	test space = "$(git show -s --pretty=format:%s)"
diff -pruN 1.2.1+git2.18.0-1/git/t/t7006-pager.sh 1.2.3+git2.25.1-1/git/t/t7006-pager.sh
--- 1.2.1+git2.18.0-1/git/t/t7006-pager.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t7006-pager.sh	2020-02-17 04:47:35.000000000 +0000
@@ -626,12 +626,11 @@ test_expect_success TTY 'sub-commands of
 
 test_expect_success TTY 'external command pagers override sub-commands' '
 	sane_unset PAGER GIT_PAGER &&
-	>expect &&
 	>actual &&
 	test_config pager.external false &&
 	test_config pager.log "sed s/^/log:/ >actual" &&
 	test_terminal git --exec-path=. external log --format=%s -1 &&
-	test_cmp expect actual
+	test_must_be_empty actual
 '
 
 test_expect_success 'command with underscores does not complain' '
diff -pruN 1.2.1+git2.18.0-1/git/t/t7008-filter-branch-null-sha1.sh 1.2.3+git2.25.1-1/git/t/t7008-filter-branch-null-sha1.sh
--- 1.2.1+git2.18.0-1/git/t/t7008-filter-branch-null-sha1.sh	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t7008-filter-branch-null-sha1.sh	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,55 @@
+#!/bin/sh
+
+test_description='filter-branch removal of trees with null sha1'
+. ./test-lib.sh
+
+test_expect_success 'setup: base commits' '
+	test_commit one &&
+	test_commit two &&
+	test_commit three
+'
+
+test_expect_success 'setup: a commit with a bogus null sha1 in the tree' '
+	{
+		git ls-tree HEAD &&
+		printf "160000 commit $ZERO_OID\\tbroken\\n"
+	} >broken-tree &&
+	echo "add broken entry" >msg &&
+
+	tree=$(git mktree <broken-tree) &&
+	test_tick &&
+	commit=$(git commit-tree $tree -p HEAD <msg) &&
+	git update-ref HEAD "$commit"
+'
+
+# we have to make one more commit on top removing the broken
+# entry, since otherwise our index does not match HEAD (and filter-branch will
+# complain). We could make the index match HEAD, but doing so would involve
+# writing a null sha1 into the index.
+test_expect_success 'setup: bring HEAD and index in sync' '
+	test_tick &&
+	git commit -a -m "back to normal"
+'
+
+test_expect_success 'noop filter-branch complains' '
+	test_must_fail git filter-branch \
+		--force --prune-empty \
+		--index-filter "true"
+'
+
+test_expect_success 'filter commands are still checked' '
+	test_must_fail git filter-branch \
+		--force --prune-empty \
+		--index-filter "git rm --cached --ignore-unmatch three.t"
+'
+
+test_expect_success 'removing the broken entry works' '
+	echo three >expect &&
+	git filter-branch \
+		--force --prune-empty \
+		--index-filter "git rm --cached --ignore-unmatch broken" &&
+	git log -1 --format=%s >actual &&
+	test_cmp expect actual
+'
+
+test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t7008-grep-binary.sh 1.2.3+git2.25.1-1/git/t/t7008-grep-binary.sh
--- 1.2.1+git2.18.0-1/git/t/t7008-grep-binary.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t7008-grep-binary.sh	1970-01-01 00:00:00.000000000 +0000
@@ -1,251 +0,0 @@
-#!/bin/sh
-
-test_description='git grep in binary files'
-
-. ./test-lib.sh
-
-nul_match () {
-	matches=$1
-	flags=$2
-	pattern=$3
-	pattern_human=$(echo "$pattern" | sed 's/Q/<NUL>/g')
-
-	if test "$matches" = 1
-	then
-		test_expect_success "git grep -f f $flags '$pattern_human' a" "
-			printf '$pattern' | q_to_nul >f &&
-			git grep -f f $flags a
-		"
-	elif test "$matches" = 0
-	then
-		test_expect_success "git grep -f f $flags '$pattern_human' a" "
-			printf '$pattern' | q_to_nul >f &&
-			test_must_fail git grep -f f $flags a
-		"
-	elif test "$matches" = T1
-	then
-		test_expect_failure "git grep -f f $flags '$pattern_human' a" "
-			printf '$pattern' | q_to_nul >f &&
-			git grep -f f $flags a
-		"
-	elif test "$matches" = T0
-	then
-		test_expect_failure "git grep -f f $flags '$pattern_human' a" "
-			printf '$pattern' | q_to_nul >f &&
-			test_must_fail git grep -f f $flags a
-		"
-	else
-		test_expect_success "PANIC: Test framework error. Unknown matches value $matches" 'false'
-	fi
-}
-
-test_expect_success 'setup' "
-	echo 'binaryQfileQm[*]cQ*æQð' | q_to_nul >a &&
-	git add a &&
-	git commit -m.
-"
-
-test_expect_success 'git grep ina a' '
-	echo Binary file a matches >expect &&
-	git grep ina a >actual &&
-	test_cmp expect actual
-'
-
-test_expect_success 'git grep -ah ina a' '
-	git grep -ah ina a >actual &&
-	test_cmp a actual
-'
-
-test_expect_success 'git grep -I ina a' '
-	: >expect &&
-	test_must_fail git grep -I ina a >actual &&
-	test_cmp expect actual
-'
-
-test_expect_success 'git grep -c ina a' '
-	echo a:1 >expect &&
-	git grep -c ina a >actual &&
-	test_cmp expect actual
-'
-
-test_expect_success 'git grep -l ina a' '
-	echo a >expect &&
-	git grep -l ina a >actual &&
-	test_cmp expect actual
-'
-
-test_expect_success 'git grep -L bar a' '
-	echo a >expect &&
-	git grep -L bar a >actual &&
-	test_cmp expect actual
-'
-
-test_expect_success 'git grep -q ina a' '
-	: >expect &&
-	git grep -q ina a >actual &&
-	test_cmp expect actual
-'
-
-test_expect_success 'git grep -F ile a' '
-	git grep -F ile a
-'
-
-test_expect_success 'git grep -Fi iLE a' '
-	git grep -Fi iLE a
-'
-
-# This test actually passes on platforms where regexec() supports the
-# flag REG_STARTEND.
-test_expect_success 'git grep ile a' '
-	git grep ile a
-'
-
-test_expect_failure 'git grep .fi a' '
-	git grep .fi a
-'
-
-nul_match 1 '-F' 'yQf'
-nul_match 0 '-F' 'yQx'
-nul_match 1 '-Fi' 'YQf'
-nul_match 0 '-Fi' 'YQx'
-nul_match 1 '' 'yQf'
-nul_match 0 '' 'yQx'
-nul_match 1 '' 'æQð'
-nul_match 1 '-F' 'eQm[*]c'
-nul_match 1 '-Fi' 'EQM[*]C'
-
-# Regex patterns that would match but shouldn't with -F
-nul_match 0 '-F' 'yQ[f]'
-nul_match 0 '-F' '[y]Qf'
-nul_match 0 '-Fi' 'YQ[F]'
-nul_match 0 '-Fi' '[Y]QF'
-nul_match 0 '-F' 'æQ[ð]'
-nul_match 0 '-F' '[æ]Qð'
-nul_match 0 '-Fi' 'ÆQ[Ð]'
-nul_match 0 '-Fi' '[Æ]QÐ'
-
-# kwset is disabled on -i & non-ASCII. No way to match non-ASCII \0
-# patterns case-insensitively.
-nul_match T1 '-i' 'ÆQÐ'
-
-# \0 implicitly disables regexes. This is an undocumented internal
-# limitation.
-nul_match T1 '' 'yQ[f]'
-nul_match T1 '' '[y]Qf'
-nul_match T1 '-i' 'YQ[F]'
-nul_match T1 '-i' '[Y]Qf'
-nul_match T1 '' 'æQ[ð]'
-nul_match T1 '' '[æ]Qð'
-nul_match T1 '-i' 'ÆQ[Ð]'
-
-# ... because of \0 implicitly disabling regexes regexes that
-# should/shouldn't match don't do the right thing.
-nul_match T1 '' 'eQm.*cQ'
-nul_match T1 '-i' 'EQM.*cQ'
-nul_match T0 '' 'eQm[*]c'
-nul_match T0 '-i' 'EQM[*]C'
-
-# Due to the REG_STARTEND extension when kwset() is disabled on -i &
-# non-ASCII the string will be matched in its entirety, but the
-# pattern will be cut off at the first \0.
-nul_match 0 '-i' 'NOMATCHQð'
-nul_match T0 '-i' '[Æ]QNOMATCH'
-nul_match T0 '-i' '[æ]QNOMATCH'
-# Matches, but for the wrong reasons, just stops at [æ]
-nul_match 1 '-i' '[Æ]Qð'
-nul_match 1 '-i' '[æ]Qð'
-
-# Ensure that the matcher doesn't regress to something that stops at
-# \0
-nul_match 0 '-F' 'yQ[f]'
-nul_match 0 '-Fi' 'YQ[F]'
-nul_match 0 '' 'yQNOMATCH'
-nul_match 0 '' 'QNOMATCH'
-nul_match 0 '-i' 'YQNOMATCH'
-nul_match 0 '-i' 'QNOMATCH'
-nul_match 0 '-F' 'æQ[ð]'
-nul_match 0 '-Fi' 'ÆQ[Ð]'
-nul_match 0 '' 'yQNÓMATCH'
-nul_match 0 '' 'QNÓMATCH'
-nul_match 0 '-i' 'YQNÓMATCH'
-nul_match 0 '-i' 'QNÓMATCH'
-
-test_expect_success 'grep respects binary diff attribute' '
-	echo text >t &&
-	git add t &&
-	echo t:text >expect &&
-	git grep text t >actual &&
-	test_cmp expect actual &&
-	echo "t -diff" >.gitattributes &&
-	echo "Binary file t matches" >expect &&
-	git grep text t >actual &&
-	test_cmp expect actual
-'
-
-test_expect_success 'grep --cached respects binary diff attribute' '
-	git grep --cached text t >actual &&
-	test_cmp expect actual
-'
-
-test_expect_success 'grep --cached respects binary diff attribute (2)' '
-	git add .gitattributes &&
-	rm .gitattributes &&
-	git grep --cached text t >actual &&
-	test_when_finished "git rm --cached .gitattributes" &&
-	test_when_finished "git checkout .gitattributes" &&
-	test_cmp expect actual
-'
-
-test_expect_success 'grep revision respects binary diff attribute' '
-	git commit -m new &&
-	echo "Binary file HEAD:t matches" >expect &&
-	git grep text HEAD -- t >actual &&
-	test_when_finished "git reset HEAD^" &&
-	test_cmp expect actual
-'
-
-test_expect_success 'grep respects not-binary diff attribute' '
-	echo binQary | q_to_nul >b &&
-	git add b &&
-	echo "Binary file b matches" >expect &&
-	git grep bin b >actual &&
-	test_cmp expect actual &&
-	echo "b diff" >.gitattributes &&
-	echo "b:binQary" >expect &&
-	git grep bin b >actual.raw &&
-	nul_to_q <actual.raw >actual &&
-	test_cmp expect actual
-'
-
-cat >nul_to_q_textconv <<'EOF'
-#!/bin/sh
-"$PERL_PATH" -pe 'y/\000/Q/' < "$1"
-EOF
-chmod +x nul_to_q_textconv
-
-test_expect_success 'setup textconv filters' '
-	echo a diff=foo >.gitattributes &&
-	git config diff.foo.textconv "\"$(pwd)\""/nul_to_q_textconv
-'
-
-test_expect_success 'grep does not honor textconv' '
-	test_must_fail git grep Qfile
-'
-
-test_expect_success 'grep --textconv honors textconv' '
-	echo "a:binaryQfileQm[*]cQ*æQð" >expect &&
-	git grep --textconv Qfile >actual &&
-	test_cmp expect actual
-'
-
-test_expect_success 'grep --no-textconv does not honor textconv' '
-	test_must_fail git grep --no-textconv Qfile
-'
-
-test_expect_success 'grep --textconv blob honors textconv' '
-	echo "HEAD:a:binaryQfileQm[*]cQ*æQð" >expect &&
-	git grep --textconv Qfile HEAD:a >actual &&
-	test_cmp expect actual
-'
-
-test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t7009-filter-branch-null-sha1.sh 1.2.3+git2.25.1-1/git/t/t7009-filter-branch-null-sha1.sh
--- 1.2.1+git2.18.0-1/git/t/t7009-filter-branch-null-sha1.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t7009-filter-branch-null-sha1.sh	1970-01-01 00:00:00.000000000 +0000
@@ -1,55 +0,0 @@
-#!/bin/sh
-
-test_description='filter-branch removal of trees with null sha1'
-. ./test-lib.sh
-
-test_expect_success 'setup: base commits' '
-	test_commit one &&
-	test_commit two &&
-	test_commit three
-'
-
-test_expect_success 'setup: a commit with a bogus null sha1 in the tree' '
-	{
-		git ls-tree HEAD &&
-		printf "160000 commit $ZERO_OID\\tbroken\\n"
-	} >broken-tree &&
-	echo "add broken entry" >msg &&
-
-	tree=$(git mktree <broken-tree) &&
-	test_tick &&
-	commit=$(git commit-tree $tree -p HEAD <msg) &&
-	git update-ref HEAD "$commit"
-'
-
-# we have to make one more commit on top removing the broken
-# entry, since otherwise our index does not match HEAD (and filter-branch will
-# complain). We could make the index match HEAD, but doing so would involve
-# writing a null sha1 into the index.
-test_expect_success 'setup: bring HEAD and index in sync' '
-	test_tick &&
-	git commit -a -m "back to normal"
-'
-
-test_expect_success 'noop filter-branch complains' '
-	test_must_fail git filter-branch \
-		--force --prune-empty \
-		--index-filter "true"
-'
-
-test_expect_success 'filter commands are still checked' '
-	test_must_fail git filter-branch \
-		--force --prune-empty \
-		--index-filter "git rm --cached --ignore-unmatch three.t"
-'
-
-test_expect_success 'removing the broken entry works' '
-	echo three >expect &&
-	git filter-branch \
-		--force --prune-empty \
-		--index-filter "git rm --cached --ignore-unmatch broken" &&
-	git log -1 --format=%s >actual &&
-	test_cmp expect actual
-'
-
-test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t7012-skip-worktree-writing.sh 1.2.3+git2.25.1-1/git/t/t7012-skip-worktree-writing.sh
--- 1.2.1+git2.18.0-1/git/t/t7012-skip-worktree-writing.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t7012-skip-worktree-writing.sh	2020-02-17 04:47:35.000000000 +0000
@@ -134,6 +134,21 @@ test_expect_success 'git-clean, dirty ca
 	test_i18ncmp expected result
 '
 
+test_expect_success '--ignore-skip-worktree-entries leaves worktree alone' '
+	test_commit keep-me &&
+	git update-index --skip-worktree keep-me.t &&
+	rm keep-me.t &&
+
+	: ignoring the worktree &&
+	git update-index --remove --ignore-skip-worktree-entries keep-me.t &&
+	git diff-index --cached --exit-code HEAD &&
+
+	: not ignoring the worktree, a deletion is staged &&
+	git update-index --remove keep-me.t &&
+	test_must_fail git diff-index --cached --exit-code HEAD \
+		--diff-filter=D -- keep-me.t
+'
+
 #TODO test_expect_failure 'git-apply adds file' false
 #TODO test_expect_failure 'git-apply updates file' false
 #TODO test_expect_failure 'git-apply removes file' false
diff -pruN 1.2.1+git2.18.0-1/git/t/t7030-verify-tag.sh 1.2.3+git2.25.1-1/git/t/t7030-verify-tag.sh
--- 1.2.1+git2.18.0-1/git/t/t7030-verify-tag.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t7030-verify-tag.sh	2020-02-17 04:47:35.000000000 +0000
@@ -41,6 +41,13 @@ test_expect_success GPG 'create signed t
 	git tag -uB7227189 -m eighth eighth-signed-alt
 '
 
+test_expect_success GPGSM 'create signed tags x509 ' '
+	test_config gpg.format x509 &&
+	test_config user.signingkey $GIT_COMMITTER_EMAIL &&
+	echo 9 >file && test_tick && git commit -a -m "ninth gpgsm-signed" &&
+	git tag -s -m ninth ninth-signed-x509
+'
+
 test_expect_success GPG 'verify and show signatures' '
 	(
 		for tag in initial second merge fourth-signed sixth-signed seventh-signed
@@ -72,9 +79,16 @@ test_expect_success GPG 'verify and show
 	)
 '
 
+test_expect_success GPGSM 'verify and show signatures x509' '
+	git verify-tag ninth-signed-x509 2>actual &&
+	grep "Good signature from" actual &&
+	! grep "BAD signature from" actual &&
+	echo ninth-signed-x509 OK
+'
+
 test_expect_success GPG 'detect fudged signature' '
 	git cat-file tag seventh-signed >raw &&
-	sed -e "s/seventh/7th forged/" raw >forged1 &&
+	sed -e "/^tag / s/seventh/7th forged/" raw >forged1 &&
 	git hash-object -w -t tag forged1 >forged1.tag &&
 	test_must_fail git verify-tag $(cat forged1.tag) 2>actual1 &&
 	grep "BAD signature from" actual1 &&
@@ -112,6 +126,13 @@ test_expect_success GPG 'verify signatur
 	)
 '
 
+test_expect_success GPGSM 'verify signatures with --raw x509' '
+	git verify-tag --raw ninth-signed-x509 2>actual &&
+	grep "GOODSIG" actual &&
+	! grep "BADSIG" actual &&
+	echo ninth-signed-x509 OK
+'
+
 test_expect_success GPG 'verify multiple tags' '
 	tags="fourth-signed sixth-signed seventh-signed" &&
 	for i in $tags
@@ -125,6 +146,19 @@ test_expect_success GPG 'verify multiple
 	test_cmp expect.stderr actual.stderr
 '
 
+test_expect_success GPGSM 'verify multiple tags x509' '
+	tags="seventh-signed ninth-signed-x509" &&
+	for i in $tags
+	do
+		git verify-tag -v --raw $i || return 1
+	done >expect.stdout 2>expect.stderr.1 &&
+	grep "^.GNUPG:." <expect.stderr.1 >expect.stderr &&
+	git verify-tag -v --raw $tags >actual.stdout 2>actual.stderr.1 &&
+	grep "^.GNUPG:." <actual.stderr.1 >actual.stderr &&
+	test_cmp expect.stdout actual.stdout &&
+	test_cmp expect.stderr actual.stderr
+'
+
 test_expect_success GPG 'verifying tag with --format' '
 	cat >expect <<-\EOF &&
 	tagname : fourth-signed
@@ -134,9 +168,8 @@ test_expect_success GPG 'verifying tag w
 '
 
 test_expect_success GPG 'verifying a forged tag with --format should fail silently' '
-	>expect &&
 	test_must_fail git verify-tag --format="tagname : %(tag)" $(cat forged1.tag) >actual-forged &&
-	test_cmp expect actual-forged
+	test_must_be_empty actual-forged
 '
 
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t7060-wtstatus.sh 1.2.3+git2.25.1-1/git/t/t7060-wtstatus.sh
--- 1.2.1+git2.18.0-1/git/t/t7060-wtstatus.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t7060-wtstatus.sh	2020-02-17 04:47:35.000000000 +0000
@@ -38,7 +38,6 @@ You have unmerged paths.
 
 Unmerged paths:
   (use "git add/rm <file>..." as appropriate to mark resolution)
-
 	deleted by us:   foo
 
 no changes added to commit (use "git add" and/or "git commit -a")
@@ -143,7 +142,6 @@ You have unmerged paths.
 
 Unmerged paths:
   (use "git add/rm <file>..." as appropriate to mark resolution)
-
 	both added:      conflict.txt
 	deleted by them: main.txt
 
@@ -177,7 +175,6 @@ You have unmerged paths.
 
 Unmerged paths:
   (use "git add/rm <file>..." as appropriate to mark resolution)
-
 	both deleted:    main.txt
 	added by them:   sub_master.txt
 	added by us:     sub_second.txt
@@ -201,12 +198,10 @@ You have unmerged paths.
   (use "git merge --abort" to abort the merge)
 
 Changes to be committed:
-
 	new file:   sub_master.txt
 
 Unmerged paths:
   (use "git rm <file>..." to mark resolution)
-
 	both deleted:    main.txt
 
 Untracked files not listed (use -u option to show untracked files)
diff -pruN 1.2.1+git2.18.0-1/git/t/t7061-wtstatus-ignore.sh 1.2.3+git2.25.1-1/git/t/t7061-wtstatus-ignore.sh
--- 1.2.1+git2.18.0-1/git/t/t7061-wtstatus-ignore.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t7061-wtstatus-ignore.sh	2020-02-17 04:47:35.000000000 +0000
@@ -43,11 +43,16 @@ test_expect_success 'status untracked di
 	test_cmp expected actual
 '
 cat >expected <<\EOF
-?? untracked/uncommitted
+?? untracked/
 !! untracked/ignored
 EOF
 
-test_expect_success 'status prefixed untracked directory with --ignored' '
+test_expect_success 'status of untracked directory with --ignored works with or without prefix' '
+	git status --porcelain --ignored >tmp &&
+	grep untracked/ tmp >actual &&
+	rm tmp &&
+	test_cmp expected actual &&
+
 	git status --porcelain --ignored untracked/ >actual &&
 	test_cmp expected actual
 '
diff -pruN 1.2.1+git2.18.0-1/git/t/t7063-status-untracked-cache.sh 1.2.3+git2.25.1-1/git/t/t7063-status-untracked-cache.sh
--- 1.2.1+git2.18.0-1/git/t/t7063-status-untracked-cache.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t7063-status-untracked-cache.sh	2020-02-17 04:47:35.000000000 +0000
@@ -26,9 +26,8 @@ avoid_racy() {
 }
 
 status_is_clean() {
-	>../status.expect &&
 	git status --porcelain >../status.actual &&
-	test_cmp ../status.expect ../status.actual
+	test_must_be_empty ../status.actual
 }
 
 test_lazy_prereq UNTRACKED_CACHE '
@@ -56,7 +55,7 @@ test_expect_success 'setup' '
 '
 
 test_expect_success 'untracked cache is empty' '
-	test-dump-untracked-cache >../actual &&
+	test-tool dump-untracked-cache >../actual &&
 	cat >../expect-empty <<EOF &&
 info/exclude 0000000000000000000000000000000000000000
 core.excludesfile 0000000000000000000000000000000000000000
@@ -107,7 +106,7 @@ EOF
 '
 
 test_expect_success 'untracked cache after first status' '
-	test-dump-untracked-cache >../actual &&
+	test-tool dump-untracked-cache >../actual &&
 	test_cmp ../dump.expect ../actual
 '
 
@@ -127,7 +126,7 @@ EOF
 '
 
 test_expect_success 'untracked cache after second status' '
-	test-dump-untracked-cache >../actual &&
+	test-tool dump-untracked-cache >../actual &&
 	test_cmp ../dump.expect ../actual
 '
 
@@ -158,7 +157,7 @@ EOF
 '
 
 test_expect_success 'verify untracked cache dump' '
-	test-dump-untracked-cache >../actual &&
+	test-tool dump-untracked-cache >../actual &&
 	cat >../expect <<EOF &&
 info/exclude $EMPTY_BLOB
 core.excludesfile 0000000000000000000000000000000000000000
@@ -205,7 +204,7 @@ EOF
 '
 
 test_expect_success 'verify untracked cache dump' '
-	test-dump-untracked-cache >../actual &&
+	test-tool dump-untracked-cache >../actual &&
 	cat >../expect <<EOF &&
 info/exclude $EMPTY_BLOB
 core.excludesfile 0000000000000000000000000000000000000000
@@ -249,7 +248,7 @@ EOF
 '
 
 test_expect_success 'verify untracked cache dump' '
-	test-dump-untracked-cache >../actual &&
+	test-tool dump-untracked-cache >../actual &&
 	cat >../expect <<EOF &&
 info/exclude 13263c0978fb9fad16b2d580fb800b6d811c3ff0
 core.excludesfile 0000000000000000000000000000000000000000
@@ -268,7 +267,7 @@ EOF
 
 test_expect_success 'move two from tracked to untracked' '
 	git rm --cached two &&
-	test-dump-untracked-cache >../actual &&
+	test-tool dump-untracked-cache >../actual &&
 	cat >../expect <<EOF &&
 info/exclude 13263c0978fb9fad16b2d580fb800b6d811c3ff0
 core.excludesfile 0000000000000000000000000000000000000000
@@ -305,7 +304,7 @@ EOF
 '
 
 test_expect_success 'verify untracked cache dump' '
-	test-dump-untracked-cache >../actual &&
+	test-tool dump-untracked-cache >../actual &&
 	cat >../expect <<EOF &&
 info/exclude 13263c0978fb9fad16b2d580fb800b6d811c3ff0
 core.excludesfile 0000000000000000000000000000000000000000
@@ -325,7 +324,7 @@ EOF
 
 test_expect_success 'move two from untracked to tracked' '
 	git add two &&
-	test-dump-untracked-cache >../actual &&
+	test-tool dump-untracked-cache >../actual &&
 	cat >../expect <<EOF &&
 info/exclude 13263c0978fb9fad16b2d580fb800b6d811c3ff0
 core.excludesfile 0000000000000000000000000000000000000000
@@ -362,7 +361,7 @@ EOF
 '
 
 test_expect_success 'verify untracked cache dump' '
-	test-dump-untracked-cache >../actual &&
+	test-tool dump-untracked-cache >../actual &&
 	cat >../expect <<EOF &&
 info/exclude 13263c0978fb9fad16b2d580fb800b6d811c3ff0
 core.excludesfile 0000000000000000000000000000000000000000
@@ -406,7 +405,7 @@ EOF
 '
 
 test_expect_success 'untracked cache correct after commit' '
-	test-dump-untracked-cache >../actual &&
+	test-tool dump-untracked-cache >../actual &&
 	cat >../expect <<EOF &&
 info/exclude 13263c0978fb9fad16b2d580fb800b6d811c3ff0
 core.excludesfile 0000000000000000000000000000000000000000
@@ -465,7 +464,7 @@ EOF
 '
 
 test_expect_success 'untracked cache correct after status' '
-	test-dump-untracked-cache >../actual &&
+	test-tool dump-untracked-cache >../actual &&
 	cat >../expect <<EOF &&
 info/exclude 13263c0978fb9fad16b2d580fb800b6d811c3ff0
 core.excludesfile 0000000000000000000000000000000000000000
@@ -533,7 +532,7 @@ EOF
 '
 
 test_expect_success 'verify untracked cache dump (sparse/subdirs)' '
-	test-dump-untracked-cache >../actual &&
+	test-tool dump-untracked-cache >../actual &&
 	cat >../expect-from-test-dump <<EOF &&
 info/exclude 13263c0978fb9fad16b2d580fb800b6d811c3ff0
 core.excludesfile 0000000000000000000000000000000000000000
@@ -599,66 +598,66 @@ EOF
 
 test_expect_success '--no-untracked-cache removes the cache' '
 	git update-index --no-untracked-cache &&
-	test-dump-untracked-cache >../actual &&
+	test-tool dump-untracked-cache >../actual &&
 	echo "no untracked cache" >../expect-no-uc &&
 	test_cmp ../expect-no-uc ../actual
 '
 
 test_expect_success 'git status does not change anything' '
 	git status &&
-	test-dump-untracked-cache >../actual &&
+	test-tool dump-untracked-cache >../actual &&
 	test_cmp ../expect-no-uc ../actual
 '
 
 test_expect_success 'setting core.untrackedCache to true and using git status creates the cache' '
 	git config core.untrackedCache true &&
-	test-dump-untracked-cache >../actual &&
+	test-tool dump-untracked-cache >../actual &&
 	test_cmp ../expect-no-uc ../actual &&
 	git status &&
-	test-dump-untracked-cache >../actual &&
+	test-tool dump-untracked-cache >../actual &&
 	test_cmp ../expect-from-test-dump ../actual
 '
 
 test_expect_success 'using --no-untracked-cache does not fail when core.untrackedCache is true' '
 	git update-index --no-untracked-cache &&
-	test-dump-untracked-cache >../actual &&
+	test-tool dump-untracked-cache >../actual &&
 	test_cmp ../expect-no-uc ../actual &&
 	git update-index --untracked-cache &&
-	test-dump-untracked-cache >../actual &&
+	test-tool dump-untracked-cache >../actual &&
 	test_cmp ../expect-empty ../actual
 '
 
 test_expect_success 'setting core.untrackedCache to false and using git status removes the cache' '
 	git config core.untrackedCache false &&
-	test-dump-untracked-cache >../actual &&
+	test-tool dump-untracked-cache >../actual &&
 	test_cmp ../expect-empty ../actual &&
 	git status &&
-	test-dump-untracked-cache >../actual &&
+	test-tool dump-untracked-cache >../actual &&
 	test_cmp ../expect-no-uc ../actual
 '
 
 test_expect_success 'using --untracked-cache does not fail when core.untrackedCache is false' '
 	git update-index --untracked-cache &&
-	test-dump-untracked-cache >../actual &&
+	test-tool dump-untracked-cache >../actual &&
 	test_cmp ../expect-empty ../actual
 '
 
 test_expect_success 'setting core.untrackedCache to keep' '
 	git config core.untrackedCache keep &&
 	git update-index --untracked-cache &&
-	test-dump-untracked-cache >../actual &&
+	test-tool dump-untracked-cache >../actual &&
 	test_cmp ../expect-empty ../actual &&
 	git status &&
-	test-dump-untracked-cache >../actual &&
+	test-tool dump-untracked-cache >../actual &&
 	test_cmp ../expect-from-test-dump ../actual &&
 	git update-index --no-untracked-cache &&
-	test-dump-untracked-cache >../actual &&
+	test-tool dump-untracked-cache >../actual &&
 	test_cmp ../expect-no-uc ../actual &&
 	git update-index --force-untracked-cache &&
-	test-dump-untracked-cache >../actual &&
+	test-tool dump-untracked-cache >../actual &&
 	test_cmp ../expect-empty ../actual &&
 	git status &&
-	test-dump-untracked-cache >../actual &&
+	test-tool dump-untracked-cache >../actual &&
 	test_cmp ../expect-from-test-dump ../actual
 '
 
@@ -666,29 +665,29 @@ test_expect_success 'test ident field is
 	mkdir ../other_worktree &&
 	cp -R done dthree dtwo four three ../other_worktree &&
 	GIT_WORK_TREE=../other_worktree git status 2>../err &&
-	echo "warning: Untracked cache is disabled on this system or location." >../expect &&
+	echo "warning: untracked cache is disabled on this system or location" >../expect &&
 	test_i18ncmp ../expect ../err
 '
 
 test_expect_success 'untracked cache survives a checkout' '
 	git commit --allow-empty -m empty &&
-	test-dump-untracked-cache >../before &&
+	test-tool dump-untracked-cache >../before &&
 	test_when_finished  "git checkout master" &&
 	git checkout -b other_branch &&
-	test-dump-untracked-cache >../after &&
+	test-tool dump-untracked-cache >../after &&
 	test_cmp ../before ../after &&
 	test_commit test &&
-	test-dump-untracked-cache >../before &&
+	test-tool dump-untracked-cache >../before &&
 	git checkout master &&
-	test-dump-untracked-cache >../after &&
+	test-tool dump-untracked-cache >../after &&
 	test_cmp ../before ../after
 '
 
 test_expect_success 'untracked cache survives a commit' '
-	test-dump-untracked-cache >../before &&
+	test-tool dump-untracked-cache >../before &&
 	git add done/two &&
 	git commit -m commit &&
-	test-dump-untracked-cache >../after &&
+	test-tool dump-untracked-cache >../after &&
 	test_cmp ../before ../after
 '
 
@@ -752,7 +751,7 @@ test_expect_success '"status" after file
 	git checkout master &&
 	avoid_racy &&
 	status_is_clean &&
-	test-dump-untracked-cache >../actual &&
+	test-tool dump-untracked-cache >../actual &&
 	grep -F "recurse valid" ../actual >../actual.grep &&
 	cat >../expect.grep <<EOF &&
 / 0000000000000000000000000000000000000000 recurse valid
diff -pruN 1.2.1+git2.18.0-1/git/t/t7064-wtstatus-pv2.sh 1.2.3+git2.25.1-1/git/t/t7064-wtstatus-pv2.sh
--- 1.2.1+git2.18.0-1/git/t/t7064-wtstatus-pv2.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t7064-wtstatus-pv2.sh	2020-02-17 04:47:35.000000000 +0000
@@ -364,11 +364,8 @@ test_expect_success 'verify upstream fie
 		test_cmp expect actual &&
 
 		## Repeat the above but without --branch.
-		cat >expect <<-EOF &&
-		EOF
-
 		git status --porcelain=v2 --untracked-files=all >actual &&
-		test_cmp expect actual &&
+		test_must_be_empty actual &&
 
 		## Test upstream-gone case. Fake this by pointing origin/master at
 		## a non-existing commit.
@@ -448,6 +445,14 @@ test_expect_success 'verify --[no-]ahead
 		EOF
 
 		git status --ahead-behind --porcelain=v2 --branch --untracked-files=all >actual &&
+		test_cmp expect actual &&
+
+		# Confirm that "status.aheadbehind" DOES NOT work on V2 format.
+		git -c status.aheadbehind=false status --porcelain=v2 --branch --untracked-files=all >actual &&
+		test_cmp expect actual &&
+
+		# Confirm that "status.aheadbehind" DOES NOT work on V2 format.
+		git -c status.aheadbehind=true status --porcelain=v2 --branch --untracked-files=all >actual &&
 		test_cmp expect actual
 	)
 '
diff -pruN 1.2.1+git2.18.0-1/git/t/t7102-reset.sh 1.2.3+git2.25.1-1/git/t/t7102-reset.sh
--- 1.2.1+git2.18.0-1/git/t/t7102-reset.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t7102-reset.sh	2020-02-17 04:47:35.000000000 +0000
@@ -549,8 +549,7 @@ test_expect_success 'reset -N keeps remo
 
 	tree=$(git write-tree) &&
 	git ls-tree $tree new-file >actual &&
-	>expect &&
-	test_cmp expect actual &&
+	test_must_be_empty actual &&
 
 	git diff --name-only >actual &&
 	echo new-file >expect &&
@@ -563,9 +562,8 @@ test_expect_success 'reset --mixed sets
 		cd mixed_worktree &&
 		test_commit dummy
 	) &&
-	: >expect &&
 	git --git-dir=mixed_worktree/.git --work-tree=mixed_worktree reset >actual &&
-	test_cmp expect actual
+	test_must_be_empty actual
 '
 
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t7105-reset-patch.sh 1.2.3+git2.25.1-1/git/t/t7105-reset-patch.sh
--- 1.2.1+git2.18.0-1/git/t/t7105-reset-patch.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t7105-reset-patch.sh	2020-02-17 04:47:35.000000000 +0000
@@ -19,25 +19,46 @@ test_expect_success PERL 'setup' '
 
 test_expect_success PERL 'saying "n" does nothing' '
 	set_and_save_state dir/foo work work &&
-	(echo n; echo n) | git reset -p &&
+	test_write_lines n n | git reset -p &&
 	verify_saved_state dir/foo &&
 	verify_saved_state bar
 '
 
 test_expect_success PERL 'git reset -p' '
-	(echo n; echo y) | git reset -p >output &&
+	test_write_lines n y | git reset -p >output &&
 	verify_state dir/foo work head &&
 	verify_saved_state bar &&
 	test_i18ngrep "Unstage" output
 '
 
 test_expect_success PERL 'git reset -p HEAD^' '
-	(echo n; echo y) | git reset -p HEAD^ >output &&
+	test_write_lines n y | git reset -p HEAD^ >output &&
 	verify_state dir/foo work parent &&
 	verify_saved_state bar &&
 	test_i18ngrep "Apply" output
 '
 
+test_expect_success PERL 'git reset -p HEAD^^{tree}' '
+	test_write_lines n y | git reset -p HEAD^^{tree} >output &&
+	verify_state dir/foo work parent &&
+	verify_saved_state bar &&
+	test_i18ngrep "Apply" output
+'
+
+test_expect_success PERL 'git reset -p HEAD^:dir/foo (blob fails)' '
+	set_and_save_state dir/foo work work &&
+	test_must_fail git reset -p HEAD^:dir/foo &&
+	verify_saved_state dir/foo &&
+	verify_saved_state bar
+'
+
+test_expect_success PERL 'git reset -p aaaaaaaa (unknown fails)' '
+	set_and_save_state dir/foo work work &&
+	test_must_fail git reset -p aaaaaaaa &&
+	verify_saved_state dir/foo &&
+	verify_saved_state bar
+'
+
 # The idea in the rest is that bar sorts first, so we always say 'y'
 # first and if the path limiter fails it'll apply to bar instead of
 # dir/foo.  There's always an extra 'n' to reject edits to dir/foo in
@@ -45,20 +66,20 @@ test_expect_success PERL 'git reset -p H
 
 test_expect_success PERL 'git reset -p dir' '
 	set_state dir/foo work work &&
-	(echo y; echo n) | git reset -p dir &&
+	test_write_lines y n | git reset -p dir &&
 	verify_state dir/foo work head &&
 	verify_saved_state bar
 '
 
 test_expect_success PERL 'git reset -p -- foo (inside dir)' '
 	set_state dir/foo work work &&
-	(echo y; echo n) | (cd dir && git reset -p -- foo) &&
+	test_write_lines y n | (cd dir && git reset -p -- foo) &&
 	verify_state dir/foo work head &&
 	verify_saved_state bar
 '
 
 test_expect_success PERL 'git reset -p HEAD^ -- dir' '
-	(echo y; echo n) | git reset -p HEAD^ -- dir &&
+	test_write_lines y n | git reset -p HEAD^ -- dir &&
 	verify_state dir/foo work parent &&
 	verify_saved_state bar
 '
diff -pruN 1.2.1+git2.18.0-1/git/t/t7106-reset-unborn-branch.sh 1.2.3+git2.25.1-1/git/t/t7106-reset-unborn-branch.sh
--- 1.2.1+git2.18.0-1/git/t/t7106-reset-unborn-branch.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t7106-reset-unborn-branch.sh	2020-02-17 04:47:35.000000000 +0000
@@ -12,9 +12,8 @@ test_expect_success 'reset' '
 	git add a b &&
 	git reset &&
 
-	>expect &&
 	git ls-files >actual &&
-	test_cmp expect actual
+	test_must_be_empty actual
 '
 
 test_expect_success 'reset HEAD' '
@@ -39,9 +38,8 @@ test_expect_success PERL 'reset -p' '
 	echo y >yes &&
 	git reset -p <yes >output &&
 
-	>expect &&
 	git ls-files >actual &&
-	test_cmp expect actual &&
+	test_must_be_empty actual &&
 	test_i18ngrep "Unstage" output
 '
 
@@ -61,9 +59,8 @@ test_expect_success 'reset --hard' '
 	test_when_finished "echo a >a" &&
 	git reset --hard &&
 
-	>expect &&
 	git ls-files >actual &&
-	test_cmp expect actual &&
+	test_must_be_empty actual &&
 	test_path_is_missing a
 '
 
diff -pruN 1.2.1+git2.18.0-1/git/t/t7107-reset-pathspec-file.sh 1.2.3+git2.25.1-1/git/t/t7107-reset-pathspec-file.sh
--- 1.2.1+git2.18.0-1/git/t/t7107-reset-pathspec-file.sh	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t7107-reset-pathspec-file.sh	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,155 @@
+#!/bin/sh
+
+test_description='reset --pathspec-from-file'
+
+. ./test-lib.sh
+
+test_tick
+
+test_expect_success setup '
+	echo A >fileA.t &&
+	echo B >fileB.t &&
+	echo C >fileC.t &&
+	echo D >fileD.t &&
+	git add . &&
+	git commit --include . -m "Commit" &&
+	git tag checkpoint
+'
+
+restore_checkpoint () {
+	git reset --hard checkpoint
+}
+
+verify_expect () {
+	git status --porcelain -- fileA.t fileB.t fileC.t fileD.t >actual &&
+	test_cmp expect actual
+}
+
+test_expect_success '--pathspec-from-file from stdin' '
+	restore_checkpoint &&
+
+	git rm fileA.t &&
+	echo fileA.t | git reset --pathspec-from-file=- &&
+
+	cat >expect <<-\EOF &&
+	 D fileA.t
+	EOF
+	verify_expect
+'
+
+test_expect_success '--pathspec-from-file from file' '
+	restore_checkpoint &&
+
+	git rm fileA.t &&
+	echo fileA.t >list &&
+	git reset --pathspec-from-file=list &&
+
+	cat >expect <<-\EOF &&
+	 D fileA.t
+	EOF
+	verify_expect
+'
+
+test_expect_success 'NUL delimiters' '
+	restore_checkpoint &&
+
+	git rm fileA.t fileB.t &&
+	printf "fileA.t\0fileB.t\0" | git reset --pathspec-from-file=- --pathspec-file-nul &&
+
+	cat >expect <<-\EOF &&
+	 D fileA.t
+	 D fileB.t
+	EOF
+	verify_expect
+'
+
+test_expect_success 'LF delimiters' '
+	restore_checkpoint &&
+
+	git rm fileA.t fileB.t &&
+	printf "fileA.t\nfileB.t\n" | git reset --pathspec-from-file=- &&
+
+	cat >expect <<-\EOF &&
+	 D fileA.t
+	 D fileB.t
+	EOF
+	verify_expect
+'
+
+test_expect_success 'no trailing delimiter' '
+	restore_checkpoint &&
+
+	git rm fileA.t fileB.t &&
+	printf "fileA.t\nfileB.t" | git reset --pathspec-from-file=- &&
+
+	cat >expect <<-\EOF &&
+	 D fileA.t
+	 D fileB.t
+	EOF
+	verify_expect
+'
+
+test_expect_success 'CRLF delimiters' '
+	restore_checkpoint &&
+
+	git rm fileA.t fileB.t &&
+	printf "fileA.t\r\nfileB.t\r\n" | git reset --pathspec-from-file=- &&
+
+	cat >expect <<-\EOF &&
+	 D fileA.t
+	 D fileB.t
+	EOF
+	verify_expect
+'
+
+test_expect_success 'quotes' '
+	restore_checkpoint &&
+
+	git rm fileA.t &&
+	printf "\"file\\101.t\"" | git reset --pathspec-from-file=- &&
+
+	cat >expect <<-\EOF &&
+	 D fileA.t
+	EOF
+	verify_expect
+'
+
+test_expect_success 'quotes not compatible with --pathspec-file-nul' '
+	restore_checkpoint &&
+
+	git rm fileA.t &&
+	printf "\"file\\101.t\"" >list &&
+	# Note: "git reset" has not yet learned to fail on wrong pathspecs
+	git reset --pathspec-from-file=list --pathspec-file-nul &&
+
+	cat >expect <<-\EOF &&
+	 D fileA.t
+	EOF
+	test_must_fail verify_expect
+'
+
+test_expect_success '--pathspec-from-file is not compatible with --soft or --hard' '
+	restore_checkpoint &&
+
+	git rm fileA.t &&
+	echo fileA.t >list &&
+	test_must_fail git reset --soft --pathspec-from-file=list &&
+	test_must_fail git reset --hard --pathspec-from-file=list
+'
+
+test_expect_success 'only touches what was listed' '
+	restore_checkpoint &&
+
+	git rm fileA.t fileB.t fileC.t fileD.t &&
+	printf "fileB.t\nfileC.t\n" | git reset --pathspec-from-file=- &&
+
+	cat >expect <<-\EOF &&
+	D  fileA.t
+	 D fileB.t
+	 D fileC.t
+	D  fileD.t
+	EOF
+	verify_expect
+'
+
+test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t7113-post-index-change-hook.sh 1.2.3+git2.25.1-1/git/t/t7113-post-index-change-hook.sh
--- 1.2.1+git2.18.0-1/git/t/t7113-post-index-change-hook.sh	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t7113-post-index-change-hook.sh	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,144 @@
+#!/bin/sh
+
+test_description='post index change hook'
+
+. ./test-lib.sh
+
+test_expect_success 'setup' '
+	mkdir -p dir1 &&
+	touch dir1/file1.txt &&
+	echo testing >dir1/file2.txt &&
+	git add . &&
+	git commit -m "initial"
+'
+
+test_expect_success 'test status, add, commit, others trigger hook without flags set' '
+	mkdir -p .git/hooks &&
+	write_script .git/hooks/post-index-change <<-\EOF &&
+		if test "$1" -eq 1; then
+			echo "Invalid combination of flags passed to hook; updated_workdir is set." >testfailure
+			exit 1
+		fi
+		if test "$2" -eq 1; then
+			echo "Invalid combination of flags passed to hook; updated_skipworktree is set." >testfailure
+			exit 1
+		fi
+		if test -f ".git/index.lock"; then
+			echo ".git/index.lock exists" >testfailure
+			exit 3
+		fi
+		if ! test -f ".git/index"; then
+			echo ".git/index does not exist" >testfailure
+			exit 3
+		fi
+		echo "success" >testsuccess
+	EOF
+	mkdir -p dir2 &&
+	touch dir2/file1.txt &&
+	touch dir2/file2.txt &&
+	: force index to be dirty &&
+	test-tool chmtime +60 dir1/file1.txt &&
+	git status &&
+	test_path_is_file testsuccess && rm -f testsuccess &&
+	test_path_is_missing testfailure &&
+	git add . &&
+	test_path_is_file testsuccess && rm -f testsuccess &&
+	test_path_is_missing testfailure &&
+	git commit -m "second" &&
+	test_path_is_file testsuccess && rm -f testsuccess &&
+	test_path_is_missing testfailure &&
+	git checkout -- dir1/file1.txt &&
+	test_path_is_file testsuccess && rm -f testsuccess &&
+	test_path_is_missing testfailure &&
+	git update-index &&
+	test_path_is_missing testsuccess &&
+	test_path_is_missing testfailure &&
+	git reset --soft &&
+	test_path_is_missing testsuccess &&
+	test_path_is_missing testfailure
+'
+
+test_expect_success 'test checkout and reset trigger the hook' '
+	write_script .git/hooks/post-index-change <<-\EOF &&
+		if test "$1" -eq 1 && test "$2" -eq 1; then
+			echo "Invalid combination of flags passed to hook; updated_workdir and updated_skipworktree are both set." >testfailure
+			exit 1
+		fi
+		if test "$1" -eq 0 && test "$2" -eq 0; then
+			echo "Invalid combination of flags passed to hook; neither updated_workdir or updated_skipworktree are set." >testfailure
+			exit 2
+		fi
+		if test "$1" -eq 1; then
+			if test -f ".git/index.lock"; then
+				echo "updated_workdir set but .git/index.lock exists" >testfailure
+				exit 3
+			fi
+			if ! test -f ".git/index"; then
+				echo "updated_workdir set but .git/index does not exist" >testfailure
+				exit 3
+			fi
+		else
+			echo "update_workdir should be set for checkout" >testfailure
+			exit 4
+		fi
+		echo "success" >testsuccess
+	EOF
+	: force index to be dirty &&
+	test-tool chmtime +60 dir1/file1.txt &&
+	git checkout master &&
+	test_path_is_file testsuccess && rm -f testsuccess &&
+	test_path_is_missing testfailure &&
+	test-tool chmtime +60 dir1/file1.txt &&
+	git checkout HEAD &&
+	test_path_is_file testsuccess && rm -f testsuccess &&
+	test_path_is_missing testfailure &&
+	test-tool chmtime +60 dir1/file1.txt &&
+	git reset --hard &&
+	test_path_is_file testsuccess && rm -f testsuccess &&
+	test_path_is_missing testfailure &&
+	git checkout -B test &&
+	test_path_is_file testsuccess && rm -f testsuccess &&
+	test_path_is_missing testfailure
+'
+
+test_expect_success 'test reset --mixed and update-index triggers the hook' '
+	write_script .git/hooks/post-index-change <<-\EOF &&
+		if test "$1" -eq 1 && test "$2" -eq 1; then
+			echo "Invalid combination of flags passed to hook; updated_workdir and updated_skipworktree are both set." >testfailure
+			exit 1
+		fi
+		if test "$1" -eq 0 && test "$2" -eq 0; then
+			echo "Invalid combination of flags passed to hook; neither updated_workdir or updated_skipworktree are set." >testfailure
+			exit 2
+		fi
+		if test "$2" -eq 1; then
+			if test -f ".git/index.lock"; then
+				echo "updated_skipworktree set but .git/index.lock exists" >testfailure
+				exit 3
+			fi
+			if ! test -f ".git/index"; then
+				echo "updated_skipworktree set but .git/index does not exist" >testfailure
+				exit 3
+			fi
+		else
+			echo "updated_skipworktree should be set for reset --mixed and update-index" >testfailure
+			exit 4
+		fi
+		echo "success" >testsuccess
+	EOF
+	: force index to be dirty &&
+	test-tool chmtime +60 dir1/file1.txt &&
+	git reset --mixed --quiet HEAD~1 &&
+	test_path_is_file testsuccess && rm -f testsuccess &&
+	test_path_is_missing testfailure &&
+	git hash-object -w --stdin <dir1/file2.txt >expect &&
+	git update-index --cacheinfo 100644 "$(cat expect)" dir1/file1.txt &&
+	test_path_is_file testsuccess && rm -f testsuccess &&
+	test_path_is_missing testfailure &&
+	git update-index --skip-worktree dir1/file2.txt &&
+	git update-index --remove dir1/file2.txt &&
+	test_path_is_file testsuccess && rm -f testsuccess &&
+	test_path_is_missing testfailure
+'
+
+test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t7201-co.sh 1.2.3+git2.25.1-1/git/t/t7201-co.sh
--- 1.2.1+git2.18.0-1/git/t/t7201-co.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t7201-co.sh	2020-02-17 04:47:35.000000000 +0000
@@ -116,9 +116,8 @@ test_expect_success "checkout -m with di
 	git diff --name-status side >current.side &&
 	test_cmp expect.side current.side &&
 
-	: >expect.index &&
 	git diff --cached >current.index &&
-	test_cmp expect.index current.index
+	test_must_be_empty current.index
 '
 
 test_expect_success "checkout -m with dirty tree, renamed" '
@@ -139,7 +138,7 @@ test_expect_success "checkout -m with di
 	test_cmp expect uno &&
 	! test -f one &&
 	git diff --cached >current &&
-	! test -s current
+	test_must_be_empty current
 
 '
 
@@ -161,9 +160,9 @@ test_expect_success 'checkout -m with me
 	git diff master:one :3:uno |
 	sed -e "1,/^@@/d" -e "/^ /d" -e "s/^-/d/" -e "s/^+/a/" >current &&
 	fill d2 aT d7 aS >expect &&
-	test_cmp current expect &&
+	test_cmp expect current &&
 	git diff --cached two >current &&
-	! test -s current
+	test_must_be_empty current
 '
 
 test_expect_success 'format of merge conflict from checkout -m' '
@@ -175,7 +174,7 @@ test_expect_success 'format of merge con
 
 	git ls-files >current &&
 	fill same two two two >expect &&
-	test_cmp current expect &&
+	test_cmp expect current &&
 
 	cat <<-EOF >expect &&
 	<<<<<<< simple
@@ -224,13 +223,8 @@ test_expect_success 'switch to another b
 	test_must_fail git checkout simple 2>errs &&
 	test_i18ngrep overwritten errs &&
 
-	git checkout --merge simple 2>errs &&
-	test_i18ngrep ! overwritten errs &&
-	git ls-files -u &&
-	test_must_fail git cat-file -t :0:two &&
-	test "$(git cat-file -t :1:two)" = blob &&
-	test "$(git cat-file -t :2:two)" = blob &&
-	test_must_fail git cat-file -t :3:two
+	test_must_fail git read-tree --quiet -m -u HEAD simple 2>errs &&
+	test_must_be_empty errs
 '
 
 test_expect_success 'checkout to detach HEAD (with advice declined)' '
@@ -255,9 +249,9 @@ test_expect_success 'checkout to detach
 test_expect_success 'checkout to detach HEAD' '
 	git config advice.detachedHead true &&
 	git checkout -f renamer && git clean -f &&
-	git checkout renamer^ 2>messages &&
-	test_i18ngrep "HEAD is now at 7329388" messages &&
-	(test_line_count -gt 1 messages || test -n "$GETTEXT_POISON") &&
+	GIT_TEST_GETTEXT_POISON=false git checkout renamer^ 2>messages &&
+	grep "HEAD is now at 7329388" messages &&
+	test_line_count -gt 1 messages &&
 	H=$(git rev-parse --verify HEAD) &&
 	M=$(git show-ref -s --verify refs/heads/master) &&
 	test "z$H" = "z$M" &&
@@ -528,10 +522,10 @@ test_expect_success 'checkout with --mer
 	cat sample >filf &&
 	git checkout -m -- fild file filf &&
 	(
-		echo "<<<<<<< ours"
-		echo ourside
-		echo "======="
-		echo theirside
+		echo "<<<<<<< ours" &&
+		echo ourside &&
+		echo "=======" &&
+		echo theirside &&
 		echo ">>>>>>> theirs"
 	) >merged &&
 	test_cmp expect fild &&
@@ -549,12 +543,12 @@ test_expect_success 'checkout with --mer
 	cat sample >filf &&
 	git checkout -m -- fild file filf &&
 	(
-		echo "<<<<<<< ours"
-		echo ourside
-		echo "||||||| base"
-		echo original
-		echo "======="
-		echo theirside
+		echo "<<<<<<< ours" &&
+		echo ourside &&
+		echo "||||||| base" &&
+		echo original &&
+		echo "=======" &&
+		echo theirside &&
 		echo ">>>>>>> theirs"
 	) >merged &&
 	test_cmp expect fild &&
@@ -572,10 +566,10 @@ test_expect_success 'checkout --conflict
 	cat sample >filf &&
 	git checkout --conflict=merge -- fild file filf &&
 	(
-		echo "<<<<<<< ours"
-		echo ourside
-		echo "======="
-		echo theirside
+		echo "<<<<<<< ours" &&
+		echo ourside &&
+		echo "=======" &&
+		echo theirside &&
 		echo ">>>>>>> theirs"
 	) >merged &&
 	test_cmp expect fild &&
@@ -593,12 +587,12 @@ test_expect_success 'checkout --conflict
 	cat sample >filf &&
 	git checkout --conflict=diff3 -- fild file filf &&
 	(
-		echo "<<<<<<< ours"
-		echo ourside
-		echo "||||||| base"
-		echo original
-		echo "======="
-		echo theirside
+		echo "<<<<<<< ours" &&
+		echo ourside &&
+		echo "||||||| base" &&
+		echo original &&
+		echo "=======" &&
+		echo theirside &&
 		echo ">>>>>>> theirs"
 	) >merged &&
 	test_cmp expect fild &&
@@ -673,7 +667,6 @@ test_expect_success 'custom merge driver
 		do
 			grep $t arm || exit 1
 		done
-		exit 0
 	) &&
 
 	mv arm expect &&
diff -pruN 1.2.1+git2.18.0-1/git/t/t7300-clean.sh 1.2.3+git2.25.1-1/git/t/t7300-clean.sh
--- 1.2.1+git2.18.0-1/git/t/t7300-clean.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t7300-clean.sh	2020-02-17 04:47:35.000000000 +0000
@@ -117,6 +117,7 @@ test_expect_success C_LOCALE_OUTPUT 'git
 	would_clean=$(
 		cd docs &&
 		git clean -n ../src |
+		grep part3 |
 		sed -n -e "s|^Would remove ||p"
 	) &&
 	verbose test "$would_clean" = ../src/part3.c
@@ -129,6 +130,7 @@ test_expect_success C_LOCALE_OUTPUT 'git
 	would_clean=$(
 		cd docs &&
 		git clean -n "$(pwd)/../src" |
+		grep part3 |
 		sed -n -e "s|^Would remove ||p"
 	) &&
 	verbose test "$would_clean" = ../src/part3.c
@@ -547,7 +549,7 @@ test_expect_failure 'nested (non-empty)
 	test_path_is_missing strange_bare
 '
 
-test_expect_success 'giving path in nested git work tree will remove it' '
+test_expect_success 'giving path in nested git work tree will NOT remove it' '
 	rm -fr repo &&
 	mkdir repo &&
 	(
@@ -559,7 +561,7 @@ test_expect_success 'giving path in nest
 	git clean -f -d repo/bar/baz &&
 	test_path_is_file repo/.git/HEAD &&
 	test_path_is_dir repo/bar/ &&
-	test_path_is_missing repo/bar/baz
+	test_path_is_file repo/bar/baz/hello.world
 '
 
 test_expect_success 'giving path to nested .git will not remove it' '
@@ -577,7 +579,7 @@ test_expect_success 'giving path to nest
 	test_path_is_dir untracked/
 '
 
-test_expect_success 'giving path to nested .git/ will remove contents' '
+test_expect_success 'giving path to nested .git/ will NOT remove contents' '
 	rm -fr repo untracked &&
 	mkdir repo untracked &&
 	(
@@ -587,7 +589,7 @@ test_expect_success 'giving path to nest
 	) &&
 	git clean -f -d repo/.git/ &&
 	test_path_is_dir repo/.git &&
-	test_dir_is_empty repo/.git &&
+	test_path_is_file repo/.git/HEAD &&
 	test_path_is_dir untracked/
 '
 
@@ -669,4 +671,79 @@ test_expect_success 'git clean -d skips
 	test_path_is_missing foo/b/bb
 '
 
+test_expect_success 'git clean -d skips nested repo containing ignored files' '
+	test_when_finished "rm -rf nested-repo-with-ignored-file" &&
+
+	git init nested-repo-with-ignored-file &&
+	(
+		cd nested-repo-with-ignored-file &&
+		>file &&
+		git add file &&
+		git commit -m Initial &&
+
+		# This file is ignored by a .gitignore rule in the outer repo
+		# added in the previous test.
+		>ignoreme
+	) &&
+
+	git clean -fd &&
+
+	test_path_is_file nested-repo-with-ignored-file/.git/index &&
+	test_path_is_file nested-repo-with-ignored-file/ignoreme &&
+	test_path_is_file nested-repo-with-ignored-file/file
+'
+
+test_expect_success 'git clean handles being told what to clean' '
+	mkdir -p d1 d2 &&
+	touch d1/ut d2/ut &&
+	git clean -f */ut &&
+	test_path_is_missing d1/ut &&
+	test_path_is_missing d2/ut
+'
+
+test_expect_success 'git clean handles being told what to clean, with -d' '
+	mkdir -p d1 d2 &&
+	touch d1/ut d2/ut &&
+	git clean -ffd */ut &&
+	test_path_is_missing d1/ut &&
+	test_path_is_missing d2/ut
+'
+
+test_expect_success 'git clean works if a glob is passed without -d' '
+	mkdir -p d1 d2 &&
+	touch d1/ut d2/ut &&
+	git clean -f "*ut" &&
+	test_path_is_missing d1/ut &&
+	test_path_is_missing d2/ut
+'
+
+test_expect_success 'git clean works if a glob is passed with -d' '
+	mkdir -p d1 d2 &&
+	touch d1/ut d2/ut &&
+	git clean -ffd "*ut" &&
+	test_path_is_missing d1/ut &&
+	test_path_is_missing d2/ut
+'
+
+test_expect_success MINGW 'handle clean & core.longpaths = false nicely' '
+	test_config core.longpaths false &&
+	a50=aaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa &&
+	mkdir -p $a50$a50/$a50$a50/$a50$a50 &&
+	: >"$a50$a50/test.txt" 2>"$a50$a50/$a50$a50/$a50$a50/test.txt" &&
+	# create a temporary outside the working tree to hide from "git clean"
+	test_must_fail git clean -xdf 2>.git/err &&
+	# grepping for a strerror string is unportable but it is OK here with
+	# MINGW prereq
+	test_i18ngrep "too long" .git/err
+'
+
+test_expect_success 'clean untracked paths by pathspec' '
+	git init untracked &&
+	mkdir untracked/dir &&
+	echo >untracked/dir/file.txt &&
+	git -C untracked clean -f dir/file.txt &&
+	ls untracked/dir >actual &&
+	test_must_be_empty actual
+'
+
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t7301-clean-interactive.sh 1.2.3+git2.25.1-1/git/t/t7301-clean-interactive.sh
--- 1.2.1+git2.18.0-1/git/t/t7301-clean-interactive.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t7301-clean-interactive.sh	2020-02-17 04:47:35.000000000 +0000
@@ -107,7 +107,7 @@ test_expect_success 'git clean -id (filt
 	mkdir -p build docs &&
 	touch a.out src/part3.c src/part3.h src/part4.c src/part4.h \
 	docs/manual.txt obj.o build/lib.so &&
-	(echo f; echo "*"; echo; echo c) | \
+	test_write_lines f "*" "" c |
 	git clean -id &&
 	test -f Makefile &&
 	test -f README &&
@@ -129,7 +129,7 @@ test_expect_success 'git clean -id (filt
 	mkdir -p build docs &&
 	touch a.out src/part3.c src/part3.h src/part4.c src/part4.h \
 	docs/manual.txt obj.o build/lib.so &&
-	(echo f; echo "part3.* *.out"; echo; echo c) | \
+	test_write_lines f "part3.* *.out" "" c |
 	git clean -id &&
 	test -f Makefile &&
 	test -f README &&
@@ -151,7 +151,7 @@ test_expect_success 'git clean -id (filt
 	mkdir -p build docs &&
 	touch a.out src/part3.c src/part3.h src/part4.c src/part4.h \
 	docs/manual.txt obj.o build/lib.so &&
-	(echo f; echo "* !*.out"; echo; echo c) | \
+	test_write_lines f "* !*.out" "" c |
 	git clean -id &&
 	test -f Makefile &&
 	test -f README &&
@@ -173,7 +173,7 @@ test_expect_success 'git clean -id (sele
 	mkdir -p build docs &&
 	touch a.out src/part3.c src/part3.h src/part4.c src/part4.h \
 	docs/manual.txt obj.o build/lib.so &&
-	(echo s; echo "*"; echo; echo c) | \
+	test_write_lines s "*" "" c |
 	git clean -id &&
 	test -f Makefile &&
 	test -f README &&
@@ -195,7 +195,7 @@ test_expect_success 'git clean -id (sele
 	mkdir -p build docs &&
 	touch a.out src/part3.c src/part3.h src/part4.c src/part4.h \
 	docs/manual.txt obj.o build/lib.so &&
-	(echo s; echo; echo c) | \
+	test_write_lines s "" c |
 	git clean -id &&
 	test -f Makefile &&
 	test -f README &&
@@ -217,7 +217,7 @@ test_expect_success 'git clean -id (sele
 	mkdir -p build docs &&
 	touch a.out src/part3.c src/part3.h src/part4.c src/part4.h \
 	docs/manual.txt obj.o build/lib.so &&
-	(echo s; echo 3; echo; echo c) | \
+	test_write_lines s 3 "" c |
 	git clean -id &&
 	test -f Makefile &&
 	test -f README &&
@@ -239,7 +239,7 @@ test_expect_success 'git clean -id (sele
 	mkdir -p build docs &&
 	touch a.out src/part3.c src/part3.h src/part4.c src/part4.h \
 	docs/manual.txt obj.o build/lib.so &&
-	(echo s; echo 2 3; echo 5; echo; echo c) | \
+	test_write_lines s "2 3" 5 "" c |
 	git clean -id &&
 	test -f Makefile &&
 	test -f README &&
@@ -261,7 +261,7 @@ test_expect_success 'git clean -id (sele
 	mkdir -p build docs &&
 	touch a.out src/part3.c src/part3.h src/part4.c src/part4.h \
 	docs/manual.txt obj.o build/lib.so &&
-	(echo s; echo 3,4 5; echo; echo c) | \
+	test_write_lines s "3,4 5" "" c |
 	git clean -id &&
 	test -f Makefile &&
 	test -f README &&
@@ -282,7 +282,7 @@ test_expect_success 'git clean -id (sele
 
 	mkdir -p build docs &&
 	touch a.out foo.txt bar.txt baz.txt &&
-	(echo s; echo a.out fo ba bar; echo; echo c) | \
+	test_write_lines s "a.out fo ba bar" "" c |
 	git clean -id &&
 	test -f Makefile &&
 	test ! -f a.out &&
@@ -298,7 +298,7 @@ test_expect_success 'git clean -id (sele
 	mkdir -p build docs &&
 	touch a.out src/part3.c src/part3.h src/part4.c src/part4.h \
 	docs/manual.txt obj.o build/lib.so &&
-	(echo s; echo 1,3-4; echo 2; echo; echo c) | \
+	test_write_lines s "1,3-4" 2 "" c |
 	git clean -id &&
 	test -f Makefile &&
 	test -f README &&
@@ -320,7 +320,7 @@ test_expect_success 'git clean -id (sele
 	mkdir -p build docs &&
 	touch a.out src/part3.c src/part3.h src/part4.c src/part4.h \
 	docs/manual.txt obj.o build/lib.so &&
-	(echo s; echo 4- 1; echo; echo c) | \
+	test_write_lines s "4- 1" "" c |
 	git clean -id &&
 	test -f Makefile &&
 	test -f README &&
@@ -342,7 +342,7 @@ test_expect_success 'git clean -id (inve
 	mkdir -p build docs &&
 	touch a.out src/part3.c src/part3.h src/part4.c src/part4.h \
 	docs/manual.txt obj.o build/lib.so &&
-	(echo s; echo "*"; echo -5- 1 -2; echo; echo c) | \
+	test_write_lines s "*" "-5- 1 -2" "" c |
 	git clean -id &&
 	test -f Makefile &&
 	test -f README &&
@@ -364,7 +364,7 @@ test_expect_success 'git clean -id (ask)
 	mkdir -p build docs &&
 	touch a.out src/part3.c src/part3.h src/part4.c src/part4.h \
 	docs/manual.txt obj.o build/lib.so &&
-	(echo a; echo Y; echo y; echo no; echo yes; echo bad; echo) | \
+	test_write_lines a Y y no yes bad "" |
 	git clean -id &&
 	test -f Makefile &&
 	test -f README &&
@@ -386,7 +386,7 @@ test_expect_success 'git clean -id (ask
 	mkdir -p build docs &&
 	touch a.out src/part3.c src/part3.h src/part4.c src/part4.h \
 	docs/manual.txt obj.o build/lib.so &&
-	(echo a; echo Y; echo no; echo yes; echo "\04") | \
+	test_write_lines a Y no yes "\04" |
 	git clean -id &&
 	test -f Makefile &&
 	test -f README &&
@@ -408,8 +408,8 @@ test_expect_success 'git clean -id with
 	mkdir -p build docs &&
 	touch a.out src/part3.c src/part3.h src/part4.c src/part4.h \
 	docs/manual.txt obj.o build/lib.so &&
-	(cd build/ && \
-	 (echo f; echo "docs"; echo "*.h"; echo ; echo c) | \
+	(cd build/ &&
+	 test_write_lines f docs "*.h" "" c |
 	 git clean -id ..) &&
 	test -f Makefile &&
 	test -f README &&
@@ -431,9 +431,8 @@ test_expect_success 'git clean -id with
 	mkdir -p build docs &&
 	touch a.out src/part3.c src/part3.h src/part4.c src/part4.h \
 	docs/manual.txt obj.o build/lib.so &&
-	(cd build/ && \
-	 (echo s; echo "../docs/"; echo "../src/part3.c"; \
-	  echo "../src/part4.c";  echo; echo c) | \
+	(cd build/ &&
+	 test_write_lines s ../docs/ ../src/part3.c ../src/part4.c "" c |
 	 git clean -id ..) &&
 	test -f Makefile &&
 	test -f README &&
@@ -455,8 +454,8 @@ test_expect_success 'git clean -id with
 	mkdir -p build docs &&
 	touch a.out src/part3.c src/part3.h src/part4.c src/part4.h \
 	docs/manual.txt obj.o build/lib.so &&
-	(cd build/ && \
-	 (echo a; echo Y; echo y; echo no; echo yes; echo bad; echo) | \
+	(cd build/ &&
+	 test_write_lines a Y y no yes bad "" |
 	 git clean -id ..) &&
 	test -f Makefile &&
 	test -f README &&
diff -pruN 1.2.1+git2.18.0-1/git/t/t7400-submodule-basic.sh 1.2.3+git2.25.1-1/git/t/t7400-submodule-basic.sh
--- 1.2.1+git2.18.0-1/git/t/t7400-submodule-basic.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t7400-submodule-basic.sh	2020-02-17 04:47:35.000000000 +0000
@@ -46,6 +46,15 @@ test_expect_success 'submodule update ab
 	test_must_fail git submodule init
 '
 
+test_expect_success 'add aborts on repository with no commits' '
+	cat >expect <<-\EOF &&
+	'"'repo-no-commits'"' does not have a commit checked out
+	EOF
+	git init repo-no-commits &&
+	test_must_fail git submodule add ../a ./repo-no-commits 2>actual &&
+	test_i18ncmp expect actual
+'
+
 test_expect_success 'setup - repository in init subdirectory' '
 	mkdir init &&
 	(
@@ -101,7 +110,6 @@ inspect() {
 
 test_expect_success 'submodule add' '
 	echo "refs/heads/master" >expect &&
-	>empty &&
 
 	(
 		cd addtest &&
@@ -123,7 +131,7 @@ test_expect_success 'submodule add' '
 	inspect addtest/submod ../.. &&
 	test_cmp expect heads &&
 	test_cmp expect head &&
-	test_cmp empty untracked
+	test_must_be_empty untracked
 '
 
 test_expect_success 'setup parent and one repository' '
@@ -171,12 +179,13 @@ test_expect_success 'submodule add to .g
 test_expect_success 'submodule add to reconfigure existing submodule with --force' '
 	(
 		cd addtest-ignore &&
-		git submodule add --force bogus-url submod &&
-		git submodule add -b initial "$submodurl" submod-branch &&
-		test "bogus-url" = "$(git config -f .gitmodules submodule.submod.url)" &&
-		test "bogus-url" = "$(git config submodule.submod.url)" &&
+		bogus_url="$(pwd)/bogus-url" &&
+		git submodule add --force "$bogus_url" submod &&
+		git submodule add --force -b initial "$submodurl" submod-branch &&
+		test "$bogus_url" = "$(git config -f .gitmodules submodule.submod.url)" &&
+		test "$bogus_url" = "$(git config submodule.submod.url)" &&
 		# Restore the url
-		git submodule add --force "$submodurl" submod
+		git submodule add --force "$submodurl" submod &&
 		test "$submodurl" = "$(git config -f .gitmodules submodule.submod.url)" &&
 		test "$submodurl" = "$(git config submodule.submod.url)"
 	)
@@ -188,7 +197,6 @@ test_expect_success 'submodule add --bra
 	refs/heads/initial
 	refs/heads/master
 	EOF
-	>empty &&
 
 	(
 		cd addtest &&
@@ -201,12 +209,11 @@ test_expect_success 'submodule add --bra
 	inspect addtest/submod-branch ../.. &&
 	test_cmp expect-heads heads &&
 	test_cmp expect-head head &&
-	test_cmp empty untracked
+	test_must_be_empty untracked
 '
 
 test_expect_success 'submodule add with ./ in path' '
 	echo "refs/heads/master" >expect &&
-	>empty &&
 
 	(
 		cd addtest &&
@@ -218,12 +225,11 @@ test_expect_success 'submodule add with
 	inspect addtest/dotsubmod/frotz ../../.. &&
 	test_cmp expect heads &&
 	test_cmp expect head &&
-	test_cmp empty untracked
+	test_must_be_empty untracked
 '
 
 test_expect_success 'submodule add with /././ in path' '
 	echo "refs/heads/master" >expect &&
-	>empty &&
 
 	(
 		cd addtest &&
@@ -235,12 +241,11 @@ test_expect_success 'submodule add with
 	inspect addtest/dotslashdotsubmod/frotz ../../.. &&
 	test_cmp expect heads &&
 	test_cmp expect head &&
-	test_cmp empty untracked
+	test_must_be_empty untracked
 '
 
 test_expect_success 'submodule add with // in path' '
 	echo "refs/heads/master" >expect &&
-	>empty &&
 
 	(
 		cd addtest &&
@@ -252,12 +257,11 @@ test_expect_success 'submodule add with
 	inspect addtest/slashslashsubmod/frotz ../../.. &&
 	test_cmp expect heads &&
 	test_cmp expect head &&
-	test_cmp empty untracked
+	test_must_be_empty untracked
 '
 
 test_expect_success 'submodule add with /.. in path' '
 	echo "refs/heads/master" >expect &&
-	>empty &&
 
 	(
 		cd addtest &&
@@ -269,12 +273,11 @@ test_expect_success 'submodule add with
 	inspect addtest/realsubmod ../.. &&
 	test_cmp expect heads &&
 	test_cmp expect head &&
-	test_cmp empty untracked
+	test_must_be_empty untracked
 '
 
 test_expect_success 'submodule add with ./, /.. and // in path' '
 	echo "refs/heads/master" >expect &&
-	>empty &&
 
 	(
 		cd addtest &&
@@ -286,7 +289,7 @@ test_expect_success 'submodule add with
 	inspect addtest/realsubmod2 ../.. &&
 	test_cmp expect heads &&
 	test_cmp expect head &&
-	test_cmp empty untracked
+	test_must_be_empty untracked
 '
 
 test_expect_success !CYGWIN 'submodule add with \\ in path' '
@@ -305,7 +308,6 @@ test_expect_success !CYGWIN 'submodule a
 
 test_expect_success 'submodule add in subdirectory' '
 	echo "refs/heads/master" >expect &&
-	>empty &&
 
 	mkdir addtest/sub &&
 	(
@@ -318,7 +320,7 @@ test_expect_success 'submodule add in su
 	inspect addtest/realsubmod3 ../.. &&
 	test_cmp expect heads &&
 	test_cmp expect head &&
-	test_cmp empty untracked
+	test_must_be_empty untracked
 '
 
 test_expect_success 'submodule add in subdirectory with relative path should fail' '
@@ -354,6 +356,28 @@ test_expect_success 'status should only
 	test_line_count = 1 lines
 '
 
+test_expect_success 'status from subdirectory should have the same SHA1' '
+	test_when_finished "rmdir addtest/subdir" &&
+	(
+		cd addtest &&
+		mkdir subdir &&
+		git submodule status >output &&
+		awk "{print \$1}" <output >expect &&
+		cd subdir &&
+		git submodule status >../output &&
+		awk "{print \$1}" <../output >../actual &&
+		test_cmp ../expect ../actual &&
+		git -C ../submod checkout HEAD^ &&
+		git submodule status >../output &&
+		awk "{print \$1}" <../output >../actual2 &&
+		cd .. &&
+		git submodule status >output &&
+		awk "{print \$1}" <output >expect2 &&
+		test_cmp expect2 actual2 &&
+		! test_cmp actual actual2
+	)
+'
+
 test_expect_success 'setup - fetch commit name from submodule' '
 	rev1=$(cd .subrepo && git rev-parse HEAD) &&
 	printf "rev1: %s\n" "$rev1" &&
@@ -377,7 +401,7 @@ test_expect_success 'init should registe
 
 test_failure_with_unknown_submodule () {
 	test_must_fail git submodule $1 no-such-submodule 2>output.err &&
-	grep "^error: .*no-such-submodule" output.err
+	test_i18ngrep "^error: .*no-such-submodule" output.err
 }
 
 test_expect_success 'init should fail with unknown submodule' '
@@ -501,8 +525,6 @@ test_expect_success 'checkout superproje
 '
 
 test_expect_success 'apply submodule diff' '
-	>empty &&
-
 	git branch second &&
 	(
 		cd init &&
@@ -517,7 +539,7 @@ test_expect_success 'apply submodule dif
 	git apply --index P.diff &&
 
 	git diff --cached master >staged &&
-	test_cmp empty staged
+	test_must_be_empty staged
 '
 
 test_expect_success 'update --init' '
@@ -527,7 +549,6 @@ test_expect_success 'update --init' '
 	test_must_fail git config submodule.example.url &&
 
 	git submodule update init 2> update.out &&
-	cat update.out &&
 	test_i18ngrep "not initialized" update.out &&
 	test_must_fail git rev-parse --resolve-git-dir init/.git &&
 
@@ -545,7 +566,6 @@ test_expect_success 'update --init from
 	(
 		cd sub &&
 		git submodule update ../init 2>update.out &&
-		cat update.out &&
 		test_i18ngrep "not initialized" update.out &&
 		test_must_fail git rev-parse --resolve-git-dir ../init/.git &&
 
@@ -818,7 +838,7 @@ test_expect_success '../bar/a/b/c works
 		cp pristine-.git-config .git/config &&
 		cp pristine-.gitmodules .gitmodules &&
 		mkdir -p a/b/c &&
-		(cd a/b/c; git init) &&
+		(cd a/b/c && git init && test_commit msg) &&
 		git config remote.origin.url ../foo/bar.git &&
 		git submodule add ../bar/a/b/c ./a/b/c &&
 		git submodule init &&
@@ -993,6 +1013,11 @@ test_expect_success 'submodule deinit sh
 	rmdir init
 '
 
+test_expect_success 'submodule deinit should unset core.worktree' '
+	test_path_is_file .git/modules/example/config &&
+	test_must_fail git config -f .git/modules/example/config core.worktree
+'
+
 test_expect_success 'submodule deinit from subdirectory' '
 	git submodule update --init &&
 	git config submodule.example.foo bar &&
@@ -1233,6 +1258,30 @@ test_expect_success 'submodule update an
 	test_cmp expect actual
 '
 
+test_expect_success 'clone active submodule without submodule url set' '
+	test_when_finished "rm -rf test/test" &&
+	mkdir test &&
+	# another dir breaks accidental relative paths still being correct
+	git clone file://"$pwd"/multisuper test/test &&
+	(
+		cd test/test &&
+		git config submodule.active "." &&
+
+		# do not pass --init flag, as the submodule is already active:
+		git submodule update &&
+		git submodule status >actual_raw &&
+
+		cut -c 1,43- actual_raw >actual &&
+		cat >expect <<-\EOF &&
+		 sub0 (test2)
+		 sub1 (test2)
+		 sub2 (test2)
+		 sub3 (test2)
+		EOF
+		test_cmp expect actual
+	)
+'
+
 test_expect_success 'clone --recurse-submodules with a pathspec works' '
 	test_when_finished "rm -rf multisuper_clone" &&
 	cat >expected <<-\EOF &&
diff -pruN 1.2.1+git2.18.0-1/git/t/t7401-submodule-summary.sh 1.2.3+git2.25.1-1/git/t/t7401-submodule-summary.sh
--- 1.2.1+git2.18.0-1/git/t/t7401-submodule-summary.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t7401-submodule-summary.sh	2020-02-17 04:47:35.000000000 +0000
@@ -64,8 +64,7 @@ test_expect_success 'added submodule (su
 		cd sub &&
 		git submodule summary . >../actual
 	) &&
-	>expected &&
-	test_cmp expected actual
+	test_must_be_empty actual
 "
 
 test_expect_success 'added submodule (subdirectory with explicit path)' "
@@ -301,7 +300,7 @@ test_expect_success 'should not fail in
 	git init xyzzy &&
 	cd xyzzy &&
 	git submodule summary >output 2>&1 &&
-	test_cmp output /dev/null
+	test_must_be_empty output
 "
 
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t7405-submodule-merge.sh 1.2.3+git2.25.1-1/git/t/t7405-submodule-merge.sh
--- 1.2.1+git2.18.0-1/git/t/t7405-submodule-merge.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t7405-submodule-merge.sh	2020-02-17 04:47:35.000000000 +0000
@@ -279,4 +279,177 @@ test_expect_success 'recursive merge wit
 	 grep "$(cat expect3)" actual > /dev/null)
 '
 
+# File/submodule conflict
+#   Commit O: <empty>
+#   Commit A: path (submodule)
+#   Commit B: path
+#   Expected: path/ is submodule and file contents for B's path are somewhere
+
+test_expect_success 'setup file/submodule conflict' '
+	test_create_repo file-submodule &&
+	(
+		cd file-submodule &&
+
+		git commit --allow-empty -m O &&
+
+		git branch A &&
+		git branch B &&
+
+		git checkout B &&
+		echo content >path &&
+		git add path &&
+		git commit -m B &&
+
+		git checkout A &&
+		test_create_repo path &&
+		test_commit -C path world &&
+		git submodule add ./path &&
+		git commit -m A
+	)
+'
+
+test_expect_failure 'file/submodule conflict' '
+	test_when_finished "git -C file-submodule reset --hard" &&
+	(
+		cd file-submodule &&
+
+		git checkout A^0 &&
+		test_must_fail git merge B^0 &&
+
+		git ls-files -s >out &&
+		test_line_count = 3 out &&
+		git ls-files -u >out &&
+		test_line_count = 2 out &&
+
+		# path/ is still a submodule
+		test_path_is_dir path/.git &&
+
+		# There is a submodule at "path", so B:path cannot be written
+		# there.  We expect it to be written somewhere in the same
+		# directory, though, so just grep for its content in all
+		# files, and ignore "grep: path: Is a directory" message
+		echo Checking if contents from B:path showed up anywhere &&
+		grep -q content * 2>/dev/null
+	)
+'
+
+test_expect_success 'file/submodule conflict; merge --abort works afterward' '
+	test_when_finished "git -C file-submodule reset --hard" &&
+	(
+		cd file-submodule &&
+
+		git checkout A^0 &&
+		test_must_fail git merge B^0 >out 2>err &&
+
+		test_path_is_file .git/MERGE_HEAD &&
+		git merge --abort
+	)
+'
+
+# Directory/submodule conflict
+#   Commit O: <empty>
+#   Commit A: path (submodule), with sole tracked file named 'world'
+#   Commit B1: path/file
+#   Commit B2: path/world
+#
+#   Expected from merge of A & B1:
+#     Contents under path/ from commit B1 are renamed elsewhere; we do not
+#     want to write files from one of our tracked directories into a submodule
+#
+#   Expected from merge of A & B2:
+#     Similar to last merge, but with a slight twist: we don't want paths
+#     under the submodule to be treated as untracked or in the way.
+
+test_expect_success 'setup directory/submodule conflict' '
+	test_create_repo directory-submodule &&
+	(
+		cd directory-submodule &&
+
+		git commit --allow-empty -m O &&
+
+		git branch A &&
+		git branch B1 &&
+		git branch B2 &&
+
+		git checkout B1 &&
+		mkdir path &&
+		echo contents >path/file &&
+		git add path/file &&
+		git commit -m B1 &&
+
+		git checkout B2 &&
+		mkdir path &&
+		echo contents >path/world &&
+		git add path/world &&
+		git commit -m B2 &&
+
+		git checkout A &&
+		test_create_repo path &&
+		test_commit -C path hello world &&
+		git submodule add ./path &&
+		git commit -m A
+	)
+'
+
+test_expect_failure 'directory/submodule conflict; keep submodule clean' '
+	test_when_finished "git -C directory-submodule reset --hard" &&
+	(
+		cd directory-submodule &&
+
+		git checkout A^0 &&
+		test_must_fail git merge B1^0 &&
+
+		git ls-files -s >out &&
+		test_line_count = 3 out &&
+		git ls-files -u >out &&
+		test_line_count = 1 out &&
+
+		# path/ is still a submodule
+		test_path_is_dir path/.git &&
+
+		echo Checking if contents from B1:path/file showed up &&
+		# Would rather use grep -r, but that is GNU extension...
+		git ls-files -co | xargs grep -q contents 2>/dev/null &&
+
+		# However, B1:path/file should NOT have shown up at path/file,
+		# because we should not write into the submodule
+		test_path_is_missing path/file
+	)
+'
+
+test_expect_failure !FAIL_PREREQS 'directory/submodule conflict; should not treat submodule files as untracked or in the way' '
+	test_when_finished "git -C directory-submodule/path reset --hard" &&
+	test_when_finished "git -C directory-submodule reset --hard" &&
+	(
+		cd directory-submodule &&
+
+		git checkout A^0 &&
+		test_must_fail git merge B2^0 >out 2>err &&
+
+		# We do not want files within the submodule to prevent the
+		# merge from starting; we should not be writing to such paths
+		# anyway.
+		test_i18ngrep ! "refusing to lose untracked file at" err
+	)
+'
+
+test_expect_failure 'directory/submodule conflict; merge --abort works afterward' '
+	test_when_finished "git -C directory-submodule/path reset --hard" &&
+	test_when_finished "git -C directory-submodule reset --hard" &&
+	(
+		cd directory-submodule &&
+
+		git checkout A^0 &&
+		test_must_fail git merge B2^0 &&
+		test_path_is_file .git/MERGE_HEAD &&
+
+		# merge --abort should succeed, should clear .git/MERGE_HEAD,
+		# and should not leave behind any conflicted files
+		git merge --abort &&
+		test_path_is_missing .git/MERGE_HEAD &&
+		git ls-files -u >conflicts &&
+		test_must_be_empty conflicts
+	)
+'
+
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t7406-submodule-update.sh 1.2.3+git2.25.1-1/git/t/t7406-submodule-update.sh
--- 1.2.1+git2.18.0-1/git/t/t7406-submodule-update.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t7406-submodule-update.sh	2020-02-17 04:47:35.000000000 +0000
@@ -115,17 +115,17 @@ Submodule path '../super/submodule': che
 EOF
 
 cat <<EOF >expect2
+Cloning into '$pwd/recursivesuper/super/merging'...
+Cloning into '$pwd/recursivesuper/super/none'...
+Cloning into '$pwd/recursivesuper/super/rebasing'...
+Cloning into '$pwd/recursivesuper/super/submodule'...
 Submodule 'merging' ($pwd/merging) registered for path '../super/merging'
 Submodule 'none' ($pwd/none) registered for path '../super/none'
 Submodule 'rebasing' ($pwd/rebasing) registered for path '../super/rebasing'
 Submodule 'submodule' ($pwd/submodule) registered for path '../super/submodule'
-Cloning into '$pwd/recursivesuper/super/merging'...
 done.
-Cloning into '$pwd/recursivesuper/super/none'...
 done.
-Cloning into '$pwd/recursivesuper/super/rebasing'...
 done.
-Cloning into '$pwd/recursivesuper/super/submodule'...
 done.
 EOF
 
@@ -137,7 +137,8 @@ test_expect_success 'submodule update --
 	 git submodule update --init --recursive ../super >../../actual 2>../../actual2
 	) &&
 	test_i18ncmp expect actual &&
-	test_i18ncmp expect2 actual2
+	sort actual2 >actual2.sorted &&
+	test_i18ncmp expect2 actual2.sorted
 '
 
 cat <<EOF >expect2
@@ -157,7 +158,6 @@ test_expect_success 'submodule update --
 	test_i18ncmp expect2 actual2
 '
 
-apos="'";
 test_expect_success 'submodule update does not fetch already present commits' '
 	(cd submodule &&
 	  echo line3 >> file &&
@@ -167,14 +167,14 @@ test_expect_success 'submodule update do
 	) &&
 	(cd super/submodule &&
 	  head=$(git rev-parse --verify HEAD) &&
-	  echo "Submodule path ${apos}submodule$apos: checked out $apos$head$apos" > ../../expected &&
+	  echo "Submodule path ${SQ}submodule$SQ: checked out $SQ$head$SQ" > ../../expected &&
 	  git reset --hard HEAD~1
 	) &&
 	(cd super &&
 	  git submodule update > ../actual 2> ../actual.err
 	) &&
 	test_i18ncmp expected actual &&
-	! test -s actual.err
+	test_must_be_empty actual.err
 '
 
 test_expect_success 'submodule update should fail due to local changes' '
@@ -406,12 +406,26 @@ test_expect_success 'submodule update -
 	)
 '
 
-test_expect_success 'submodule update - command in .gitmodules is ignored' '
+test_expect_success 'submodule update - command in .gitmodules is rejected' '
 	test_when_finished "git -C super reset --hard HEAD^" &&
 	git -C super config -f .gitmodules submodule.submodule.update "!false" &&
 	git -C super commit -a -m "add command to .gitmodules file" &&
 	git -C super/submodule reset --hard $submodulesha1^ &&
-	git -C super submodule update submodule
+	test_must_fail git -C super submodule update submodule
+'
+
+test_expect_success 'fsck detects command in .gitmodules' '
+	git init command-in-gitmodules &&
+	(
+		cd command-in-gitmodules &&
+		git submodule add ../submodule submodule &&
+		test_commit adding-submodule &&
+
+		git config -f .gitmodules submodule.submodule.update "!false" &&
+		git add .gitmodules &&
+		test_commit configuring-update &&
+		test_must_fail git fsck
+	)
 '
 
 cat << EOF >expect
@@ -480,17 +494,20 @@ test_expect_success 'recursive submodule
 '
 
 test_expect_success 'submodule init does not copy command into .git/config' '
+	test_when_finished "git -C super update-index --force-remove submodule1" &&
+	test_when_finished git config -f super/.gitmodules \
+		--remove-section submodule.submodule1 &&
 	(cd super &&
-	 H=$(git ls-files -s submodule | cut -d" " -f2) &&
+	 git ls-files -s submodule >out &&
+	 H=$(cut -d" " -f2 out) &&
 	 mkdir submodule1 &&
 	 git update-index --add --cacheinfo 160000 $H submodule1 &&
 	 git config -f .gitmodules submodule.submodule1.path submodule1 &&
 	 git config -f .gitmodules submodule.submodule1.url ../submodule &&
 	 git config -f .gitmodules submodule.submodule1.update !false &&
-	 git submodule init submodule1 &&
-	 echo "none" >expect &&
-	 git config submodule.submodule1.update >actual &&
-	 test_cmp expect actual
+	 test_must_fail git submodule init submodule1 &&
+	 test_expect_code 1 git config submodule.submodule1.update >actual &&
+	 test_must_be_empty actual
 	)
 '
 
@@ -579,9 +596,11 @@ test_expect_success 'submodule update -
 	  git checkout master &&
 	  compare_head
 	 ) &&
-	 git diff --raw | grep "	submodule" &&
+	 git diff --name-only >out &&
+	 grep ^submodule$ out &&
 	 git submodule update &&
-	 git diff --raw | grep "	submodule" &&
+	 git diff --name-only >out &&
+	 grep ^submodule$ out &&
 	 (cd submodule &&
 	  compare_head
 	 ) &&
@@ -597,11 +616,13 @@ test_expect_success 'submodule update -
 	  git checkout master &&
 	  compare_head
 	 ) &&
-	 git diff --raw | grep "	submodule" &&
+	 git diff --name-only >out &&
+	 grep ^submodule$ out &&
 	 git submodule update --checkout &&
-	 test_must_fail git diff --raw \| grep "	submodule" &&
+	 git diff --name-only >out &&
+	 ! grep ^submodule$ out &&
 	 (cd submodule &&
-	  test_must_fail compare_head
+	  ! compare_head
 	 ) &&
 	 git config --unset submodule.submodule.update
 	)
@@ -615,8 +636,8 @@ test_expect_success 'submodule update --
 	git clone super cloned &&
 	(cd cloned &&
 	 git submodule update --init &&
-	 test -e submodule/.git &&
-	 test_must_fail test -e none/.git
+	 test_path_exists submodule/.git &&
+	 test_path_is_missing none/.git
 	)
 '
 
@@ -783,7 +804,7 @@ test_expect_success 'submodule add place
 	 (cd .git/modules/deeper/submodule &&
 	  git log > ../../../../actual
 	 ) &&
-	 test_cmp actual expected
+	 test_cmp expected actual
 	)
 '
 
@@ -801,7 +822,7 @@ test_expect_success 'submodule update pl
 	 (cd .git/modules/deeper/submodule &&
 	  git log > ../../../../actual
 	 ) &&
-	 test_cmp actual expected
+	 test_cmp expected actual
 	)
 '
 
@@ -821,7 +842,7 @@ test_expect_success 'submodule add place
 	 git add deeper/submodule &&
 	 git commit -m "update submodule" &&
 	 git push origin : &&
-	 test_cmp actual expected
+	 test_cmp expected actual
 	)
 '
 
@@ -865,10 +886,10 @@ test_expect_success 'submodule update pl
 	 (cd submodule/subsubmodule &&
 	  git log > ../../expected
 	 ) &&
-	 (cd .git/modules/submodule/modules/subsubmodule
+	 (cd .git/modules/submodule/modules/subsubmodule &&
 	  git log > ../../../../../actual
-	 )
-	 test_cmp actual expected
+	 ) &&
+	 test_cmp expected actual
 	)
 '
 
@@ -885,8 +906,9 @@ test_expect_success 'submodule update pr
 	 H=$(git rev-parse --short HEAD) &&
 	 git commit -am "pre move" &&
 	 H2=$(git rev-parse --short HEAD) &&
-	 git status | sed "s/$H/XXX/" >expect &&
-	 H=$(cd submodule2; git rev-parse HEAD) &&
+	 git status >out &&
+	 sed "s/$H/XXX/" out >expect &&
+	 H=$(cd submodule2 && git rev-parse HEAD) &&
 	 git rm --cached submodule2 &&
 	 rm -rf submodule2 &&
 	 mkdir -p "moved/sub module" &&
@@ -894,7 +916,8 @@ test_expect_success 'submodule update pr
 	 git config -f .gitmodules submodule.submodule2.path "moved/sub module" &&
 	 git commit -am "post move" &&
 	 git submodule update &&
-	 git status | sed "s/$H2/XXX/" >actual &&
+	 git status > out &&
+	 sed "s/$H2/XXX/" out >actual &&
 	 test_cmp expect actual
 	)
 '
@@ -912,7 +935,7 @@ test_expect_success SYMLINKS 'submodule
 
 test_expect_success 'submodule update clone shallow submodule' '
 	test_when_finished "rm -rf super3" &&
-	first=$(git -C cloned submodule status submodule |cut -c2-41) &&
+	first=$(git -C cloned rev-parse HEAD:submodule) &&
 	second=$(git -C submodule rev-parse HEAD) &&
 	commit_count=$(git -C submodule rev-list --count $first^..$second) &&
 	git clone cloned super3 &&
@@ -922,7 +945,8 @@ test_expect_success 'submodule update cl
 		sed -e "s#url = ../#url = file://$pwd/#" <.gitmodules >.gitmodules.tmp &&
 		mv -f .gitmodules.tmp .gitmodules &&
 		git submodule update --init --depth=$commit_count &&
-		test 1 = $(git -C submodule log --oneline | wc -l)
+		git -C submodule log --oneline >out &&
+		test_line_count = 1 out
 	)
 '
 
@@ -934,11 +958,15 @@ test_expect_success 'submodule update cl
 		cd super3 &&
 		sed -e "s#url = ../#url = file://$pwd/#" <.gitmodules >.gitmodules.tmp &&
 		mv -f .gitmodules.tmp .gitmodules &&
-		test_must_fail git submodule update --init --depth=1 2>actual &&
+		# Some protocol versions (e.g. 2) support fetching
+		# unadvertised objects, so restrict this test to v0.
+		test_must_fail env GIT_TEST_PROTOCOL_VERSION= \
+			git submodule update --init --depth=1 2>actual &&
 		test_i18ngrep "Direct fetching of that commit failed." actual &&
 		git -C ../submodule config uploadpack.allowReachableSHA1InWant true &&
 		git submodule update --init --depth=1 >actual &&
-		test 1 = $(git -C submodule log --oneline | wc -l)
+		git -C submodule log --oneline >out &&
+		test_line_count = 1 out
 	)
 '
 
diff -pruN 1.2.1+git2.18.0-1/git/t/t7407-submodule-foreach.sh 1.2.3+git2.25.1-1/git/t/t7407-submodule-foreach.sh
--- 1.2.1+git2.18.0-1/git/t/t7407-submodule-foreach.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t7407-submodule-foreach.sh	2020-02-17 04:47:35.000000000 +0000
@@ -82,16 +82,16 @@ test_expect_success 'test basic "submodu
 
 cat >expect <<EOF
 Entering '../sub1'
-$pwd/clone-foo1-../sub1-$sub1sha1
+$pwd/clone-foo1-sub1-../sub1-$sub1sha1
 Entering '../sub3'
-$pwd/clone-foo3-../sub3-$sub3sha1
+$pwd/clone-foo3-sub3-../sub3-$sub3sha1
 EOF
 
 test_expect_success 'test "submodule foreach" from subdirectory' '
 	mkdir clone/sub &&
 	(
 		cd clone/sub &&
-		git submodule foreach "echo \$toplevel-\$name-\$sm_path-\$sha1" >../../actual
+		git submodule foreach "echo \$toplevel-\$name-\$sm_path-\$displaypath-\$sha1" >../../actual
 	) &&
 	test_i18ncmp expect actual
 '
@@ -196,6 +196,38 @@ test_expect_success 'test messages from
 	) &&
 	test_i18ncmp expect actual
 '
+sub1sha1=$(cd clone2/sub1 && git rev-parse HEAD)
+sub2sha1=$(cd clone2/sub2 && git rev-parse HEAD)
+sub3sha1=$(cd clone2/sub3 && git rev-parse HEAD)
+nested1sha1=$(cd clone2/nested1 && git rev-parse HEAD)
+nested2sha1=$(cd clone2/nested1/nested2 && git rev-parse HEAD)
+nested3sha1=$(cd clone2/nested1/nested2/nested3 && git rev-parse HEAD)
+submodulesha1=$(cd clone2/nested1/nested2/nested3/submodule && git rev-parse HEAD)
+
+cat >expect <<EOF
+Entering '../nested1'
+toplevel: $pwd/clone2 name: nested1 path: nested1 displaypath: ../nested1 hash: $nested1sha1
+Entering '../nested1/nested2'
+toplevel: $pwd/clone2/nested1 name: nested2 path: nested2 displaypath: ../nested1/nested2 hash: $nested2sha1
+Entering '../nested1/nested2/nested3'
+toplevel: $pwd/clone2/nested1/nested2 name: nested3 path: nested3 displaypath: ../nested1/nested2/nested3 hash: $nested3sha1
+Entering '../nested1/nested2/nested3/submodule'
+toplevel: $pwd/clone2/nested1/nested2/nested3 name: submodule path: submodule displaypath: ../nested1/nested2/nested3/submodule hash: $submodulesha1
+Entering '../sub1'
+toplevel: $pwd/clone2 name: foo1 path: sub1 displaypath: ../sub1 hash: $sub1sha1
+Entering '../sub2'
+toplevel: $pwd/clone2 name: foo2 path: sub2 displaypath: ../sub2 hash: $sub2sha1
+Entering '../sub3'
+toplevel: $pwd/clone2 name: foo3 path: sub3 displaypath: ../sub3 hash: $sub3sha1
+EOF
+
+test_expect_success 'test "submodule foreach --recursive" from subdirectory' '
+	(
+		cd clone2/untracked &&
+		git submodule foreach --recursive "echo toplevel: \$toplevel name: \$name path: \$sm_path displaypath: \$displaypath hash: \$sha1" >../../actual
+	) &&
+	test_i18ncmp expect actual
+'
 
 cat > expect <<EOF
 nested1-nested1
@@ -379,4 +411,21 @@ test_expect_success 'multi-argument comm
 	test_cmp expected actual
 '
 
+test_expect_success 'option-like arguments passed to foreach commands are not lost' '
+	(
+		cd super &&
+		git submodule foreach "echo be --quiet" > ../expected &&
+		git submodule foreach echo be --quiet > ../actual
+	) &&
+	grep -sq -e "--quiet" expected &&
+	test_cmp expected actual
+'
+
+test_expect_success 'option-like arguments passed to foreach recurse correctly' '
+	git -C clone2 submodule foreach --recursive "echo be --an-option" >expect &&
+	git -C clone2 submodule foreach --recursive echo be --an-option >actual &&
+	grep -e "--an-option" expect &&
+	test_cmp expect actual
+'
+
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t7408-submodule-reference.sh 1.2.3+git2.25.1-1/git/t/t7408-submodule-reference.sh
--- 1.2.1+git2.18.0-1/git/t/t7408-submodule-reference.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t7408-submodule-reference.sh	2020-02-17 04:47:35.000000000 +0000
@@ -148,7 +148,7 @@ test_expect_success 'preparing second su
 		cd supersuper &&
 		echo "I am super super." >file &&
 		git add file &&
-		git commit -m B-super-super-initial
+		git commit -m B-super-super-initial &&
 		git submodule add "file://$base_dir/super" subwithsub &&
 		git commit -m B-super-super-added &&
 		git submodule update --init --recursive &&
diff -pruN 1.2.1+git2.18.0-1/git/t/t7410-submodule-checkout-to.sh 1.2.3+git2.25.1-1/git/t/t7410-submodule-checkout-to.sh
--- 1.2.1+git2.18.0-1/git/t/t7410-submodule-checkout-to.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t7410-submodule-checkout-to.sh	2020-02-17 04:47:35.000000000 +0000
@@ -6,55 +6,72 @@ test_description='Combination of submodu
 
 base_path=$(pwd -P)
 
-test_expect_success 'setup: make origin' \
-    'mkdir -p origin/sub && ( cd origin/sub && git init &&
-	echo file1 >file1 &&
-	git add file1 &&
-	git commit -m file1 ) &&
-    mkdir -p origin/main && ( cd origin/main && git init &&
-	git submodule add ../sub &&
-	git commit -m "add sub" ) &&
-    ( cd origin/sub &&
-	echo file1updated >file1 &&
-	git add file1 &&
-	git commit -m "file1 updated" ) &&
-    ( cd origin/main/sub && git pull ) &&
-    ( cd origin/main &&
-	git add sub &&
-	git commit -m "sub updated" )'
-
-test_expect_success 'setup: clone' \
-    'mkdir clone && ( cd clone &&
-	git clone --recursive "$base_path/origin/main")'
+test_expect_success 'setup: make origin'  '
+	mkdir -p origin/sub &&
+	(
+		cd origin/sub && git init &&
+		echo file1 >file1 &&
+		git add file1 &&
+		git commit -m file1
+	) &&
+	mkdir -p origin/main &&
+	(
+		cd origin/main && git init &&
+		git submodule add ../sub &&
+		git commit -m "add sub"
+	) &&
+	(
+		cd origin/sub &&
+		echo file1updated >file1 &&
+		git add file1 &&
+		git commit -m "file1 updated"
+	) &&
+	git -C origin/main/sub pull &&
+	(
+		cd origin/main &&
+		git add sub &&
+		git commit -m "sub updated"
+	)
+'
+
+test_expect_success 'setup: clone' '
+	mkdir clone &&
+	git -C clone clone --recursive "$base_path/origin/main"
+'
 
 rev1_hash_main=$(git --git-dir=origin/main/.git show --pretty=format:%h -q "HEAD~1")
 rev1_hash_sub=$(git --git-dir=origin/sub/.git show --pretty=format:%h -q "HEAD~1")
 
-test_expect_success 'checkout main' \
-    'mkdir default_checkout &&
-    (cd clone/main &&
-	git worktree add "$base_path/default_checkout/main" "$rev1_hash_main")'
-
-test_expect_failure 'can see submodule diffs just after checkout' \
-    '(cd default_checkout/main && git diff --submodule master"^!" | grep "file1 updated")'
-
-test_expect_success 'checkout main and initialize independed clones' \
-    'mkdir fully_cloned_submodule &&
-    (cd clone/main &&
-	git worktree add "$base_path/fully_cloned_submodule/main" "$rev1_hash_main") &&
-    (cd fully_cloned_submodule/main && git submodule update)'
-
-test_expect_success 'can see submodule diffs after independed cloning' \
-    '(cd fully_cloned_submodule/main && git diff --submodule master"^!" | grep "file1 updated")'
-
-test_expect_success 'checkout sub manually' \
-    'mkdir linked_submodule &&
-    (cd clone/main &&
-	git worktree add "$base_path/linked_submodule/main" "$rev1_hash_main") &&
-    (cd clone/main/sub &&
-	git worktree add "$base_path/linked_submodule/main/sub" "$rev1_hash_sub")'
-
-test_expect_success 'can see submodule diffs after manual checkout of linked submodule' \
-    '(cd linked_submodule/main && git diff --submodule master"^!" | grep "file1 updated")'
+test_expect_success 'checkout main' '
+	mkdir default_checkout &&
+	git -C clone/main worktree add "$base_path/default_checkout/main" "$rev1_hash_main"
+'
+
+test_expect_failure 'can see submodule diffs just after checkout' '
+	git -C default_checkout/main diff --submodule master"^!" >out &&
+	grep "file1 updated" out
+'
+
+test_expect_success 'checkout main and initialize independent clones' '
+	mkdir fully_cloned_submodule &&
+	git -C clone/main worktree add "$base_path/fully_cloned_submodule/main" "$rev1_hash_main" &&
+	git -C fully_cloned_submodule/main submodule update
+'
+
+test_expect_success 'can see submodule diffs after independent cloning' '
+	git -C fully_cloned_submodule/main diff --submodule master"^!" >out &&
+	grep "file1 updated" out
+'
+
+test_expect_success 'checkout sub manually' '
+	mkdir linked_submodule &&
+	git -C clone/main worktree add "$base_path/linked_submodule/main" "$rev1_hash_main" &&
+	git -C clone/main/sub worktree add "$base_path/linked_submodule/main/sub" "$rev1_hash_sub"
+'
+
+test_expect_success 'can see submodule diffs after manual checkout of linked submodule' '
+	git -C linked_submodule/main diff --submodule master"^!" >out &&
+	grep "file1 updated" out
+'
 
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t7411-submodule-config.sh 1.2.3+git2.25.1-1/git/t/t7411-submodule-config.sh
--- 1.2.1+git2.18.0-1/git/t/t7411-submodule-config.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t7411-submodule-config.sh	2020-02-17 04:47:35.000000000 +0000
@@ -82,29 +82,23 @@ Submodule name: 'a' for path 'b'
 Submodule name: 'submodule' for path 'submodule'
 EOF
 
-test_expect_success 'error in one submodule config lets continue' '
+test_expect_success 'error in history of one submodule config lets continue, stderr message contains blob ref' '
+	ORIG=$(git -C super rev-parse HEAD) &&
+	test_when_finished "git -C super reset --hard $ORIG" &&
 	(cd super &&
 		cp .gitmodules .gitmodules.bak &&
 		echo "	value = \"" >>.gitmodules &&
 		git add .gitmodules &&
 		mv .gitmodules.bak .gitmodules &&
 		git commit -m "add error" &&
-		test-tool submodule-config \
-			HEAD b \
-			HEAD submodule \
-				>actual &&
-		test_cmp expect_error actual
-	)
-'
-
-test_expect_success 'error message contains blob reference' '
-	(cd super &&
 		sha1=$(git rev-parse HEAD) &&
 		test-tool submodule-config \
 			HEAD b \
 			HEAD submodule \
-				2>actual_err &&
-		test_i18ngrep "submodule-blob $sha1:.gitmodules" actual_err >/dev/null
+				>actual \
+				2>actual_stderr &&
+		test_cmp expect_error actual &&
+		test_i18ngrep "submodule-blob $sha1:.gitmodules" actual_stderr >/dev/null
 	)
 '
 
@@ -123,6 +117,8 @@ test_expect_success 'using different tre
 '
 
 test_expect_success 'error in history in fetchrecursesubmodule lets continue' '
+	ORIG=$(git -C super rev-parse HEAD) &&
+	test_when_finished "git -C super reset --hard $ORIG" &&
 	(cd super &&
 		git config -f .gitmodules \
 			submodule.submodule.fetchrecursesubmodules blabla &&
@@ -134,8 +130,128 @@ test_expect_success 'error in history in
 			HEAD b \
 			HEAD submodule \
 				>actual &&
-		test_cmp expect_error actual  &&
-		git reset --hard HEAD^
+		test_cmp expect_error actual
+	)
+'
+
+test_expect_success 'reading submodules config from the working tree with "submodule--helper config"' '
+	(cd super &&
+		echo "../submodule" >expect &&
+		git submodule--helper config submodule.submodule.url >actual &&
+		test_cmp expect actual
+	)
+'
+
+test_expect_success 'unsetting submodules config from the working tree with "submodule--helper config --unset"' '
+	(cd super &&
+		git submodule--helper config --unset submodule.submodule.url &&
+		git submodule--helper config submodule.submodule.url >actual &&
+		test_must_be_empty actual
+	)
+'
+
+
+test_expect_success 'writing submodules config with "submodule--helper config"' '
+	(cd super &&
+		echo "new_url" >expect &&
+		git submodule--helper config submodule.submodule.url "new_url" &&
+		git submodule--helper config submodule.submodule.url >actual &&
+		test_cmp expect actual
+	)
+'
+
+test_expect_success 'overwriting unstaged submodules config with "submodule--helper config"' '
+	test_when_finished "git -C super checkout .gitmodules" &&
+	(cd super &&
+		echo "newer_url" >expect &&
+		git submodule--helper config submodule.submodule.url "newer_url" &&
+		git submodule--helper config submodule.submodule.url >actual &&
+		test_cmp expect actual
+	)
+'
+
+test_expect_success 'writeable .gitmodules when it is in the working tree' '
+	git -C super submodule--helper config --check-writeable
+'
+
+test_expect_success 'writeable .gitmodules when it is nowhere in the repository' '
+	ORIG=$(git -C super rev-parse HEAD) &&
+	test_when_finished "git -C super reset --hard $ORIG" &&
+	(cd super &&
+		git rm .gitmodules &&
+		git commit -m "remove .gitmodules from the current branch" &&
+		git submodule--helper config --check-writeable
+	)
+'
+
+test_expect_success 'non-writeable .gitmodules when it is in the index but not in the working tree' '
+	test_when_finished "git -C super checkout .gitmodules" &&
+	(cd super &&
+		rm -f .gitmodules &&
+		test_must_fail git submodule--helper config --check-writeable
+	)
+'
+
+test_expect_success 'non-writeable .gitmodules when it is in the current branch but not in the index' '
+	ORIG=$(git -C super rev-parse HEAD) &&
+	test_when_finished "git -C super reset --hard $ORIG" &&
+	(cd super &&
+		git rm .gitmodules &&
+		test_must_fail git submodule--helper config --check-writeable
+	)
+'
+
+test_expect_success 'reading submodules config from the index when .gitmodules is not in the working tree' '
+	ORIG=$(git -C super rev-parse HEAD) &&
+	test_when_finished "git -C super reset --hard $ORIG" &&
+	(cd super &&
+		git submodule--helper config submodule.submodule.url "staged_url" &&
+		git add .gitmodules &&
+		rm -f .gitmodules &&
+		echo "staged_url" >expect &&
+		git submodule--helper config submodule.submodule.url >actual &&
+		test_cmp expect actual
+	)
+'
+
+test_expect_success 'reading submodules config from the current branch when .gitmodules is not in the index' '
+	ORIG=$(git -C super rev-parse HEAD) &&
+	test_when_finished "git -C super reset --hard $ORIG" &&
+	(cd super &&
+		git rm .gitmodules &&
+		echo "../submodule" >expect &&
+		git submodule--helper config submodule.submodule.url >actual &&
+		test_cmp expect actual
+	)
+'
+
+test_expect_success 'reading nested submodules config' '
+	(cd super &&
+		git init submodule/nested_submodule &&
+		echo "a" >submodule/nested_submodule/a &&
+		git -C submodule/nested_submodule add a &&
+		git -C submodule/nested_submodule commit -m "add a" &&
+		git -C submodule submodule add ./nested_submodule &&
+		git -C submodule add nested_submodule &&
+		git -C submodule commit -m "added nested_submodule" &&
+		git add submodule &&
+		git commit -m "updated submodule" &&
+		echo "./nested_submodule" >expect &&
+		test-tool submodule-nested-repo-config \
+			submodule submodule.nested_submodule.url >actual &&
+		test_cmp expect actual
+	)
+'
+
+test_expect_success 'reading nested submodules config when .gitmodules is not in the working tree' '
+	test_when_finished "git -C super/submodule checkout .gitmodules" &&
+	(cd super &&
+		echo "./nested_submodule" >expect &&
+		rm submodule/.gitmodules &&
+		test-tool submodule-nested-repo-config \
+			submodule submodule.nested_submodule.url >actual 2>warning &&
+		test_must_be_empty warning &&
+		test_cmp expect actual
 	)
 '
 
diff -pruN 1.2.1+git2.18.0-1/git/t/t7412-submodule-absorbgitdirs.sh 1.2.3+git2.25.1-1/git/t/t7412-submodule-absorbgitdirs.sh
--- 1.2.1+git2.18.0-1/git/t/t7412-submodule-absorbgitdirs.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t7412-submodule-absorbgitdirs.sh	2020-02-17 04:47:35.000000000 +0000
@@ -75,7 +75,12 @@ test_expect_success 're-setup nested sub
 	GIT_WORK_TREE=../../../nested git -C sub1/.git/modules/nested config \
 		core.worktree "../../../nested" &&
 	# make sure this re-setup is correct
-	git status --ignore-submodules=none
+	git status --ignore-submodules=none &&
+
+	# also make sure this old setup does not regress
+	git submodule update --init --recursive >out 2>err &&
+	test_must_be_empty out &&
+	test_must_be_empty err
 '
 
 test_expect_success 'absorb the git dir in a nested submodule' '
diff -pruN 1.2.1+git2.18.0-1/git/t/t7415-submodule-names.sh 1.2.3+git2.25.1-1/git/t/t7415-submodule-names.sh
--- 1.2.1+git2.18.0-1/git/t/t7415-submodule-names.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t7415-submodule-names.sh	2020-02-17 04:47:35.000000000 +0000
@@ -154,7 +154,7 @@ test_expect_success 'fsck detects symlin
 		# symlink detector; this grep string comes from the config
 		# variable name and will not be translated.
 		test_must_fail git fsck 2>output &&
-		grep gitmodulesSymlink output
+		test_i18ngrep gitmodulesSymlink output
 	)
 '
 
@@ -172,8 +172,80 @@ test_expect_success 'fsck detects non-bl
 		git ls-tree HEAD | sed s/subdir/.gitmodules/ | git mktree &&
 
 		test_must_fail git fsck 2>output &&
-		grep gitmodulesBlob output
+		test_i18ngrep gitmodulesBlob output
 	)
 '
 
+test_expect_success 'fsck detects corrupt .gitmodules' '
+	git init corrupt &&
+	(
+		cd corrupt &&
+
+		echo "[broken" >.gitmodules &&
+		git add .gitmodules &&
+		git commit -m "broken gitmodules" &&
+
+		git fsck 2>output &&
+		test_i18ngrep gitmodulesParse output &&
+		test_i18ngrep ! "bad config" output
+	)
+'
+
+test_expect_success MINGW 'prevent git~1 squatting on Windows' '
+	git init squatting &&
+	(
+		cd squatting &&
+		mkdir a &&
+		touch a/..git &&
+		git add a/..git &&
+		test_tick &&
+		git commit -m initial &&
+
+		modules="$(test_write_lines \
+			"[submodule \"b.\"]" "url = ." "path = c" \
+			"[submodule \"b\"]" "url = ." "path = d\\\\a" |
+			git hash-object -w --stdin)" &&
+		rev="$(git rev-parse --verify HEAD)" &&
+		hash="$(echo x | git hash-object -w --stdin)" &&
+		test_must_fail git update-index --add \
+			--cacheinfo 160000,$rev,d\\a 2>err &&
+		test_i18ngrep "Invalid path" err &&
+		git -c core.protectNTFS=false update-index --add \
+			--cacheinfo 100644,$modules,.gitmodules \
+			--cacheinfo 160000,$rev,c \
+			--cacheinfo 160000,$rev,d\\a \
+			--cacheinfo 100644,$hash,d./a/x \
+			--cacheinfo 100644,$hash,d./a/..git &&
+		test_tick &&
+		git -c core.protectNTFS=false commit -m "module"
+	) &&
+	test_must_fail git -c core.protectNTFS=false \
+		clone --recurse-submodules squatting squatting-clone 2>err &&
+	test_i18ngrep -e "directory not empty" -e "not an empty directory" err &&
+	! grep gitdir squatting-clone/d/a/git~2
+'
+
+test_expect_success 'git dirs of sibling submodules must not be nested' '
+	git init nested &&
+	test_commit -C nested nested &&
+	(
+		cd nested &&
+		cat >.gitmodules <<-EOF &&
+		[submodule "hippo"]
+			url = .
+			path = thing1
+		[submodule "hippo/hooks"]
+			url = .
+			path = thing2
+		EOF
+		git clone . thing1 &&
+		git clone . thing2 &&
+		git add .gitmodules thing1 thing2 &&
+		test_tick &&
+		git commit -m nested
+	) &&
+	test_must_fail git clone --recurse-submodules nested clone 2>err &&
+	test_i18ngrep "is inside git dir" err
+'
+
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t7416-submodule-dash-url.sh 1.2.3+git2.25.1-1/git/t/t7416-submodule-dash-url.sh
--- 1.2.1+git2.18.0-1/git/t/t7416-submodule-dash-url.sh	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t7416-submodule-dash-url.sh	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,63 @@
+#!/bin/sh
+
+test_description='check handling of .gitmodule url with dash'
+. ./test-lib.sh
+
+test_expect_success 'create submodule with protected dash in url' '
+	git init upstream &&
+	git -C upstream commit --allow-empty -m base &&
+	mv upstream ./-upstream &&
+	git submodule add ./-upstream sub &&
+	git add sub .gitmodules &&
+	git commit -m submodule
+'
+
+test_expect_success 'clone can recurse submodule' '
+	test_when_finished "rm -rf dst" &&
+	git clone --recurse-submodules . dst &&
+	echo base >expect &&
+	git -C dst/sub log -1 --format=%s >actual &&
+	test_cmp expect actual
+'
+
+test_expect_success 'fsck accepts protected dash' '
+	test_when_finished "rm -rf dst" &&
+	git init --bare dst &&
+	git -C dst config transfer.fsckObjects true &&
+	git push dst HEAD
+'
+
+test_expect_success 'remove ./ protection from .gitmodules url' '
+	perl -i -pe "s{\./}{}" .gitmodules &&
+	git commit -am "drop protection"
+'
+
+test_expect_success 'clone rejects unprotected dash' '
+	test_when_finished "rm -rf dst" &&
+	test_must_fail git clone --recurse-submodules . dst 2>err &&
+	test_i18ngrep ignoring err
+'
+
+test_expect_success 'fsck rejects unprotected dash' '
+	test_when_finished "rm -rf dst" &&
+	git init --bare dst &&
+	git -C dst config transfer.fsckObjects true &&
+	test_must_fail git push dst HEAD 2>err &&
+	grep gitmodulesUrl err
+'
+
+test_expect_success 'trailing backslash is handled correctly' '
+	git init testmodule &&
+	test_commit -C testmodule c &&
+	git submodule add ./testmodule &&
+	: ensure that the name ends in a double backslash &&
+	sed -e "s|\\(submodule \"testmodule\\)\"|\\1\\\\\\\\\"|" \
+		-e "s|url = .*|url = \" --should-not-be-an-option\"|" \
+		<.gitmodules >.new &&
+	mv .new .gitmodules &&
+	git commit -am "Add testmodule" &&
+	test_must_fail git clone --verbose --recurse-submodules . dolly 2>err &&
+	test_i18ngrep ! "unknown option" err
+'
+
+test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t7417-submodule-path-url.sh 1.2.3+git2.25.1-1/git/t/t7417-submodule-path-url.sh
--- 1.2.1+git2.18.0-1/git/t/t7417-submodule-path-url.sh	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t7417-submodule-path-url.sh	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,45 @@
+#!/bin/sh
+
+test_description='check handling of .gitmodule path with dash'
+. ./test-lib.sh
+
+test_expect_success 'create submodule with dash in path' '
+	git init upstream &&
+	git -C upstream commit --allow-empty -m base &&
+	git submodule add ./upstream sub &&
+	git mv sub ./-sub &&
+	git commit -m submodule
+'
+
+test_expect_success 'clone rejects unprotected dash' '
+	test_when_finished "rm -rf dst" &&
+	git clone --recurse-submodules . dst 2>err &&
+	test_i18ngrep ignoring err
+'
+
+test_expect_success 'fsck rejects unprotected dash' '
+	test_when_finished "rm -rf dst" &&
+	git init --bare dst &&
+	git -C dst config transfer.fsckObjects true &&
+	test_must_fail git push dst HEAD 2>err &&
+	grep gitmodulesPath err
+'
+
+test_expect_success MINGW 'submodule paths disallows trailing spaces' '
+	git init super &&
+	test_must_fail git -C super submodule add ../upstream "sub " &&
+
+	: add "sub", then rename "sub" to "sub ", the hard way &&
+	git -C super submodule add ../upstream sub &&
+	tree=$(git -C super write-tree) &&
+	git -C super ls-tree $tree >tree &&
+	sed "s/sub/sub /" <tree >tree.new &&
+	tree=$(git -C super mktree <tree.new) &&
+	commit=$(echo with space | git -C super commit-tree $tree) &&
+	git -C super update-ref refs/heads/master $commit &&
+
+	test_must_fail git clone --recurse-submodules super dst 2>err &&
+	test_i18ngrep "sub " err
+'
+
+test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t7418-submodule-sparse-gitmodules.sh 1.2.3+git2.25.1-1/git/t/t7418-submodule-sparse-gitmodules.sh
--- 1.2.1+git2.18.0-1/git/t/t7418-submodule-sparse-gitmodules.sh	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t7418-submodule-sparse-gitmodules.sh	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,122 @@
+#!/bin/sh
+#
+# Copyright (C) 2018  Antonio Ospite <ao2@ao2.it>
+#
+
+test_description='Test reading/writing .gitmodules when not in the working tree
+
+This test verifies that, when .gitmodules is in the current branch but is not
+in the working tree reading from it still works but writing to it does not.
+
+The test setup uses a sparse checkout, however the same scenario can be set up
+also by committing .gitmodules and then just removing it from the filesystem.
+'
+
+. ./test-lib.sh
+
+test_expect_success 'sparse checkout setup which hides .gitmodules' '
+	git init upstream &&
+	git init submodule &&
+	(cd submodule &&
+		echo file >file &&
+		git add file &&
+		test_tick &&
+		git commit -m "Add file"
+	) &&
+	(cd upstream &&
+		git submodule add ../submodule &&
+		test_tick &&
+		git commit -m "Add submodule"
+	) &&
+	git clone upstream super &&
+	(cd super &&
+		cat >.git/info/sparse-checkout <<-\EOF &&
+		/*
+		!/.gitmodules
+		EOF
+		git config core.sparsecheckout true &&
+		git read-tree -m -u HEAD &&
+		test_path_is_missing .gitmodules
+	)
+'
+
+test_expect_success 'reading gitmodules config file when it is not checked out' '
+	echo "../submodule" >expect &&
+	git -C super submodule--helper config submodule.submodule.url >actual &&
+	test_cmp expect actual
+'
+
+test_expect_success 'not writing gitmodules config file when it is not checked out' '
+	test_must_fail git -C super submodule--helper config submodule.submodule.url newurl &&
+	test_path_is_missing super/.gitmodules
+'
+
+test_expect_success 'initialising submodule when the gitmodules config is not checked out' '
+	test_must_fail git -C super config submodule.submodule.url &&
+	git -C super submodule init &&
+	git -C super config submodule.submodule.url >actual &&
+	echo "$(pwd)/submodule" >expect &&
+	test_cmp expect actual
+'
+
+test_expect_success 'updating submodule when the gitmodules config is not checked out' '
+	test_path_is_missing super/submodule/file &&
+	git -C super submodule update &&
+	test_cmp submodule/file super/submodule/file
+'
+
+ORIG_SUBMODULE=$(git -C submodule rev-parse HEAD)
+ORIG_UPSTREAM=$(git -C upstream rev-parse HEAD)
+ORIG_SUPER=$(git -C super rev-parse HEAD)
+
+test_expect_success 're-updating submodule when the gitmodules config is not checked out' '
+	test_when_finished "git -C submodule reset --hard $ORIG_SUBMODULE;
+			    git -C upstream reset --hard $ORIG_UPSTREAM;
+			    git -C super reset --hard $ORIG_SUPER;
+			    git -C upstream submodule update --remote;
+			    git -C super pull;
+			    git -C super submodule update --remote" &&
+	(cd submodule &&
+		echo file2 >file2 &&
+		git add file2 &&
+		test_tick &&
+		git commit -m "Add file2 to submodule"
+	) &&
+	(cd upstream &&
+		git submodule update --remote &&
+		git add submodule &&
+		test_tick &&
+		git commit -m "Update submodule"
+	) &&
+	git -C super pull &&
+	# The --for-status options reads the gitmodules config
+	git -C super submodule summary --for-status >actual &&
+	rev1=$(git -C submodule rev-parse --short HEAD) &&
+	rev2=$(git -C submodule rev-parse --short HEAD^) &&
+	cat >expect <<-EOF &&
+	* submodule ${rev1}...${rev2} (1):
+	  < Add file2 to submodule
+
+	EOF
+	test_cmp expect actual &&
+	# Test that the update actually succeeds
+	test_path_is_missing super/submodule/file2 &&
+	git -C super submodule update &&
+	test_cmp submodule/file2 super/submodule/file2 &&
+	git -C super status --short >output &&
+	test_must_be_empty output
+'
+
+test_expect_success 'not adding submodules when the gitmodules config is not checked out' '
+	git clone submodule new_submodule &&
+	test_must_fail git -C super submodule add ../new_submodule &&
+	test_path_is_missing .gitmodules
+'
+
+# This test checks that the previous "git submodule add" did not leave the
+# repository in a spurious state when it failed.
+test_expect_success 'init submodule still works even after the previous add failed' '
+	git -C super submodule init
+'
+
+test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t7419-submodule-set-branch.sh 1.2.3+git2.25.1-1/git/t/t7419-submodule-set-branch.sh
--- 1.2.1+git2.18.0-1/git/t/t7419-submodule-set-branch.sh	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t7419-submodule-set-branch.sh	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,93 @@
+#!/bin/sh
+#
+# Copyright (c) 2019 Denton Liu
+#
+
+test_description='Test submodules set-branch subcommand
+
+This test verifies that the set-branch subcommand of git-submodule is working
+as expected.
+'
+
+TEST_NO_CREATE_REPO=1
+. ./test-lib.sh
+
+test_expect_success 'submodule config cache setup' '
+	mkdir submodule &&
+	(cd submodule &&
+		git init &&
+		echo a >a &&
+		git add . &&
+		git commit -ma &&
+		git checkout -b topic &&
+		echo b >a &&
+		git add . &&
+		git commit -mb
+	) &&
+	mkdir super &&
+	(cd super &&
+		git init &&
+		git submodule add ../submodule &&
+		git commit -m "add submodule"
+	)
+'
+
+test_expect_success 'ensure submodule branch is unset' '
+	(cd super &&
+		! grep branch .gitmodules
+	)
+'
+
+test_expect_success 'test submodule set-branch --branch' '
+	(cd super &&
+		git submodule set-branch --branch topic submodule &&
+		grep "branch = topic" .gitmodules &&
+		git submodule update --remote &&
+		cat <<-\EOF >expect &&
+		b
+		EOF
+		git -C submodule show -s --pretty=%s >actual &&
+		test_cmp expect actual
+	)
+'
+
+test_expect_success 'test submodule set-branch --default' '
+	(cd super &&
+		git submodule set-branch --default submodule &&
+		! grep branch .gitmodules &&
+		git submodule update --remote &&
+		cat <<-\EOF >expect &&
+		a
+		EOF
+		git -C submodule show -s --pretty=%s >actual &&
+		test_cmp expect actual
+	)
+'
+
+test_expect_success 'test submodule set-branch -b' '
+	(cd super &&
+		git submodule set-branch -b topic submodule &&
+		grep "branch = topic" .gitmodules &&
+		git submodule update --remote &&
+		cat <<-\EOF >expect &&
+		b
+		EOF
+		git -C submodule show -s --pretty=%s >actual &&
+		test_cmp expect actual
+	)
+'
+
+test_expect_success 'test submodule set-branch -d' '
+	(cd super &&
+		git submodule set-branch -d submodule &&
+		! grep branch .gitmodules &&
+		git submodule update --remote &&
+		cat <<-\EOF >expect &&
+		a
+		EOF
+		git -C submodule show -s --pretty=%s >actual &&
+		test_cmp expect actual
+	)
+'
+
+test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t7420-submodule-set-url.sh 1.2.3+git2.25.1-1/git/t/t7420-submodule-set-url.sh
--- 1.2.1+git2.18.0-1/git/t/t7420-submodule-set-url.sh	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t7420-submodule-set-url.sh	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,55 @@
+#!/bin/sh
+#
+# Copyright (c) 2019 Denton Liu
+#
+
+test_description='Test submodules set-url subcommand
+
+This test verifies that the set-url subcommand of git-submodule is working
+as expected.
+'
+
+TEST_NO_CREATE_REPO=1
+. ./test-lib.sh
+
+test_expect_success 'submodule config cache setup' '
+	mkdir submodule &&
+	(
+		cd submodule &&
+		git init &&
+		echo a >file &&
+		git add file &&
+		git commit -ma
+	) &&
+	mkdir super &&
+	(
+		cd super &&
+		git init &&
+		git submodule add ../submodule &&
+		git commit -m "add submodule"
+	)
+'
+
+test_expect_success 'test submodule set-url' '
+	# add a commit and move the submodule (change the url)
+	(
+		cd submodule &&
+		echo b >>file &&
+		git add file &&
+		git commit -mb
+	) &&
+	mv submodule newsubmodule &&
+
+	git -C newsubmodule show >expect &&
+	(
+		cd super &&
+		test_must_fail git submodule update --remote &&
+		git submodule set-url submodule ../newsubmodule &&
+		grep -F "url = ../newsubmodule" .gitmodules &&
+		git submodule update --remote
+	) &&
+	git -C super/submodule show >actual &&
+	test_cmp expect actual
+'
+
+test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t7500-commit.sh 1.2.3+git2.25.1-1/git/t/t7500-commit.sh
--- 1.2.1+git2.18.0-1/git/t/t7500-commit.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t7500-commit.sh	1970-01-01 00:00:00.000000000 +0000
@@ -1,362 +0,0 @@
-#!/bin/sh
-#
-# Copyright (c) 2007 Steven Grimm
-#
-
-test_description='git commit
-
-Tests for selected commit options.'
-
-. ./test-lib.sh
-
-commit_msg_is () {
-	expect=commit_msg_is.expect
-	actual=commit_msg_is.actual
-
-	printf "%s" "$(git log --pretty=format:%s%b -1)" >"$actual" &&
-	printf "%s" "$1" >"$expect" &&
-	test_i18ncmp "$expect" "$actual"
-}
-
-# A sanity check to see if commit is working at all.
-test_expect_success 'a basic commit in an empty tree should succeed' '
-	echo content > foo &&
-	git add foo &&
-	git commit -m "initial commit"
-'
-
-test_expect_success 'nonexistent template file should return error' '
-	echo changes >> foo &&
-	git add foo &&
-	(
-		GIT_EDITOR="echo hello >\"\$1\"" &&
-		export GIT_EDITOR &&
-		test_must_fail git commit --template "$PWD"/notexist
-	)
-'
-
-test_expect_success 'nonexistent template file in config should return error' '
-	test_config commit.template "$PWD"/notexist &&
-	(
-		GIT_EDITOR="echo hello >\"\$1\"" &&
-		export GIT_EDITOR &&
-		test_must_fail git commit
-	)
-'
-
-# From now on we'll use a template file that exists.
-TEMPLATE="$PWD"/template
-
-test_expect_success 'unedited template should not commit' '
-	echo "template line" > "$TEMPLATE" &&
-	test_must_fail git commit --template "$TEMPLATE"
-'
-
-test_expect_success 'unedited template with comments should not commit' '
-	echo "# comment in template" >> "$TEMPLATE" &&
-	test_must_fail git commit --template "$TEMPLATE"
-'
-
-test_expect_success 'a Signed-off-by line by itself should not commit' '
-	(
-		test_set_editor "$TEST_DIRECTORY"/t7500/add-signed-off &&
-		test_must_fail git commit --template "$TEMPLATE"
-	)
-'
-
-test_expect_success 'adding comments to a template should not commit' '
-	(
-		test_set_editor "$TEST_DIRECTORY"/t7500/add-comments &&
-		test_must_fail git commit --template "$TEMPLATE"
-	)
-'
-
-test_expect_success 'adding real content to a template should commit' '
-	(
-		test_set_editor "$TEST_DIRECTORY"/t7500/add-content &&
-		git commit --template "$TEMPLATE"
-	) &&
-	commit_msg_is "template linecommit message"
-'
-
-test_expect_success '-t option should be short for --template' '
-	echo "short template" > "$TEMPLATE" &&
-	echo "new content" >> foo &&
-	git add foo &&
-	(
-		test_set_editor "$TEST_DIRECTORY"/t7500/add-content &&
-		git commit -t "$TEMPLATE"
-	) &&
-	commit_msg_is "short templatecommit message"
-'
-
-test_expect_success 'config-specified template should commit' '
-	echo "new template" > "$TEMPLATE" &&
-	test_config commit.template "$TEMPLATE" &&
-	echo "more content" >> foo &&
-	git add foo &&
-	(
-		test_set_editor "$TEST_DIRECTORY"/t7500/add-content &&
-		git commit
-	) &&
-	commit_msg_is "new templatecommit message"
-'
-
-test_expect_success 'explicit commit message should override template' '
-	echo "still more content" >> foo &&
-	git add foo &&
-	GIT_EDITOR="$TEST_DIRECTORY"/t7500/add-content git commit --template "$TEMPLATE" \
-		-m "command line msg" &&
-	commit_msg_is "command line msg"
-'
-
-test_expect_success 'commit message from file should override template' '
-	echo "content galore" >> foo &&
-	git add foo &&
-	echo "standard input msg" |
-	(
-		test_set_editor "$TEST_DIRECTORY"/t7500/add-content &&
-		git commit --template "$TEMPLATE" --file -
-	) &&
-	commit_msg_is "standard input msg"
-'
-
-cat >"$TEMPLATE" <<\EOF
-
-
-### template
-
-EOF
-test_expect_success 'commit message from template with whitespace issue' '
-	echo "content galore" >>foo &&
-	git add foo &&
-	GIT_EDITOR=\""$TEST_DIRECTORY"\"/t7500/add-whitespaced-content \
-	git commit --template "$TEMPLATE" &&
-	commit_msg_is "commit message"
-'
-
-test_expect_success 'using alternate GIT_INDEX_FILE (1)' '
-
-	cp .git/index saved-index &&
-	(
-		echo some new content >file &&
-	        GIT_INDEX_FILE=.git/another_index &&
-		export GIT_INDEX_FILE &&
-		git add file &&
-		git commit -m "commit using another index" &&
-		git diff-index --exit-code HEAD &&
-		git diff-files --exit-code
-	) &&
-	cmp .git/index saved-index >/dev/null
-
-'
-
-test_expect_success 'using alternate GIT_INDEX_FILE (2)' '
-
-	cp .git/index saved-index &&
-	(
-		rm -f .git/no-such-index &&
-		GIT_INDEX_FILE=.git/no-such-index &&
-		export GIT_INDEX_FILE &&
-		git commit -m "commit using nonexistent index" &&
-		test -z "$(git ls-files)" &&
-		test -z "$(git ls-tree HEAD)"
-
-	) &&
-	cmp .git/index saved-index >/dev/null
-'
-
-cat > expect << EOF
-zort
-
-Signed-off-by: C O Mitter <committer@example.com>
-EOF
-
-test_expect_success '--signoff' '
-	echo "yet another content *narf*" >> foo &&
-	echo "zort" | git commit -s -F - foo &&
-	git cat-file commit HEAD | sed "1,/^\$/d" > output &&
-	test_cmp expect output
-'
-
-test_expect_success 'commit message from file (1)' '
-	mkdir subdir &&
-	echo "Log in top directory" >log &&
-	echo "Log in sub directory" >subdir/log &&
-	(
-		cd subdir &&
-		git commit --allow-empty -F log
-	) &&
-	commit_msg_is "Log in sub directory"
-'
-
-test_expect_success 'commit message from file (2)' '
-	rm -f log &&
-	echo "Log in sub directory" >subdir/log &&
-	(
-		cd subdir &&
-		git commit --allow-empty -F log
-	) &&
-	commit_msg_is "Log in sub directory"
-'
-
-test_expect_success 'commit message from stdin' '
-	(
-		cd subdir &&
-		echo "Log with foo word" | git commit --allow-empty -F -
-	) &&
-	commit_msg_is "Log with foo word"
-'
-
-test_expect_success 'commit -F overrides -t' '
-	(
-		cd subdir &&
-		echo "-F log" > f.log &&
-		echo "-t template" > t.template &&
-		git commit --allow-empty -F f.log -t t.template
-	) &&
-	commit_msg_is "-F log"
-'
-
-test_expect_success 'Commit without message is allowed with --allow-empty-message' '
-	echo "more content" >>foo &&
-	git add foo &&
-	>empty &&
-	git commit --allow-empty-message <empty &&
-	commit_msg_is "" &&
-	git tag empty-message-commit
-'
-
-test_expect_success 'Commit without message is no-no without --allow-empty-message' '
-	echo "more content" >>foo &&
-	git add foo &&
-	>empty &&
-	test_must_fail git commit <empty
-'
-
-test_expect_success 'Commit a message with --allow-empty-message' '
-	echo "even more content" >>foo &&
-	git add foo &&
-	git commit --allow-empty-message -m"hello there" &&
-	commit_msg_is "hello there"
-'
-
-test_expect_success 'commit -C empty respects --allow-empty-message' '
-	echo more >>foo &&
-	git add foo &&
-	test_must_fail git commit -C empty-message-commit &&
-	git commit -C empty-message-commit --allow-empty-message &&
-	commit_msg_is ""
-'
-
-commit_for_rebase_autosquash_setup () {
-	echo "first content line" >>foo &&
-	git add foo &&
-	cat >log <<EOF &&
-target message subject line
-
-target message body line 1
-target message body line 2
-EOF
-	git commit -F log &&
-	echo "second content line" >>foo &&
-	git add foo &&
-	git commit -m "intermediate commit" &&
-	echo "third content line" >>foo &&
-	git add foo
-}
-
-test_expect_success 'commit --fixup provides correct one-line commit message' '
-	commit_for_rebase_autosquash_setup &&
-	git commit --fixup HEAD~1 &&
-	commit_msg_is "fixup! target message subject line"
-'
-
-test_expect_success 'commit --fixup -m"something" -m"extra"' '
-	commit_for_rebase_autosquash_setup &&
-	git commit --fixup HEAD~1 -m"something" -m"extra" &&
-	commit_msg_is "fixup! target message subject linesomething
-
-extra"
-'
-
-test_expect_success 'commit --squash works with -F' '
-	commit_for_rebase_autosquash_setup &&
-	echo "log message from file" >msgfile &&
-	git commit --squash HEAD~1 -F msgfile  &&
-	commit_msg_is "squash! target message subject linelog message from file"
-'
-
-test_expect_success 'commit --squash works with -m' '
-	commit_for_rebase_autosquash_setup &&
-	git commit --squash HEAD~1 -m "foo bar\nbaz" &&
-	commit_msg_is "squash! target message subject linefoo bar\nbaz"
-'
-
-test_expect_success 'commit --squash works with -C' '
-	commit_for_rebase_autosquash_setup &&
-	git commit --squash HEAD~1 -C HEAD &&
-	commit_msg_is "squash! target message subject lineintermediate commit"
-'
-
-test_expect_success 'commit --squash works with -c' '
-	commit_for_rebase_autosquash_setup &&
-	test_set_editor "$TEST_DIRECTORY"/t7500/edit-content &&
-	git commit --squash HEAD~1 -c HEAD &&
-	commit_msg_is "squash! target message subject lineedited commit"
-'
-
-test_expect_success 'commit --squash works with -C for same commit' '
-	commit_for_rebase_autosquash_setup &&
-	git commit --squash HEAD -C HEAD &&
-	commit_msg_is "squash! intermediate commit"
-'
-
-test_expect_success 'commit --squash works with -c for same commit' '
-	commit_for_rebase_autosquash_setup &&
-	test_set_editor "$TEST_DIRECTORY"/t7500/edit-content &&
-	git commit --squash HEAD -c HEAD &&
-	commit_msg_is "squash! edited commit"
-'
-
-test_expect_success 'commit --squash works with editor' '
-	commit_for_rebase_autosquash_setup &&
-	test_set_editor "$TEST_DIRECTORY"/t7500/add-content &&
-	git commit --squash HEAD~1 &&
-	commit_msg_is "squash! target message subject linecommit message"
-'
-
-test_expect_success 'invalid message options when using --fixup' '
-	echo changes >>foo &&
-	echo "message" >log &&
-	git add foo &&
-	test_must_fail git commit --fixup HEAD~1 --squash HEAD~2 &&
-	test_must_fail git commit --fixup HEAD~1 -C HEAD~2 &&
-	test_must_fail git commit --fixup HEAD~1 -c HEAD~2 &&
-	test_must_fail git commit --fixup HEAD~1 -F log
-'
-
-cat >expected-template <<EOF
-
-# Please enter the commit message for your changes. Lines starting
-# with '#' will be ignored, and an empty message aborts the commit.
-#
-# Author:    A U Thor <author@example.com>
-#
-# On branch commit-template-check
-# Changes to be committed:
-#	new file:   commit-template-check
-#
-# Untracked files not listed
-EOF
-
-test_expect_success 'new line found before status message in commit template' '
-	git checkout -b commit-template-check &&
-	git reset --hard HEAD &&
-	touch commit-template-check &&
-	git add commit-template-check &&
-	GIT_EDITOR="cat >editor-input" git commit --untracked-files=no --allow-empty-message &&
-	test_i18ncmp expected-template editor-input
-'
-
-test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t7500-commit-template-squash-signoff.sh 1.2.3+git2.25.1-1/git/t/t7500-commit-template-squash-signoff.sh
--- 1.2.1+git2.18.0-1/git/t/t7500-commit-template-squash-signoff.sh	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t7500-commit-template-squash-signoff.sh	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,394 @@
+#!/bin/sh
+#
+# Copyright (c) 2007 Steven Grimm
+#
+
+test_description='git commit
+
+Tests for template, signoff, squash and -F functions.'
+
+. ./test-lib.sh
+
+commit_msg_is () {
+	expect=commit_msg_is.expect
+	actual=commit_msg_is.actual
+
+	printf "%s" "$(git log --pretty=format:%s%b -1)" >"$actual" &&
+	printf "%s" "$1" >"$expect" &&
+	test_i18ncmp "$expect" "$actual"
+}
+
+# A sanity check to see if commit is working at all.
+test_expect_success 'a basic commit in an empty tree should succeed' '
+	echo content > foo &&
+	git add foo &&
+	git commit -m "initial commit"
+'
+
+test_expect_success 'nonexistent template file should return error' '
+	echo changes >> foo &&
+	git add foo &&
+	(
+		GIT_EDITOR="echo hello >\"\$1\"" &&
+		export GIT_EDITOR &&
+		test_must_fail git commit --template "$PWD"/notexist
+	)
+'
+
+test_expect_success 'nonexistent template file in config should return error' '
+	test_config commit.template "$PWD"/notexist &&
+	(
+		GIT_EDITOR="echo hello >\"\$1\"" &&
+		export GIT_EDITOR &&
+		test_must_fail git commit
+	)
+'
+
+# From now on we'll use a template file that exists.
+TEMPLATE="$PWD"/template
+
+test_expect_success 'unedited template should not commit' '
+	echo "template line" > "$TEMPLATE" &&
+	test_must_fail git commit --template "$TEMPLATE"
+'
+
+test_expect_success 'unedited template with comments should not commit' '
+	echo "# comment in template" >> "$TEMPLATE" &&
+	test_must_fail git commit --template "$TEMPLATE"
+'
+
+test_expect_success 'a Signed-off-by line by itself should not commit' '
+	(
+		test_set_editor "$TEST_DIRECTORY"/t7500/add-signed-off &&
+		test_must_fail git commit --template "$TEMPLATE"
+	)
+'
+
+test_expect_success 'adding comments to a template should not commit' '
+	(
+		test_set_editor "$TEST_DIRECTORY"/t7500/add-comments &&
+		test_must_fail git commit --template "$TEMPLATE"
+	)
+'
+
+test_expect_success 'adding real content to a template should commit' '
+	(
+		test_set_editor "$TEST_DIRECTORY"/t7500/add-content &&
+		git commit --template "$TEMPLATE"
+	) &&
+	commit_msg_is "template linecommit message"
+'
+
+test_expect_success '-t option should be short for --template' '
+	echo "short template" > "$TEMPLATE" &&
+	echo "new content" >> foo &&
+	git add foo &&
+	(
+		test_set_editor "$TEST_DIRECTORY"/t7500/add-content &&
+		git commit -t "$TEMPLATE"
+	) &&
+	commit_msg_is "short templatecommit message"
+'
+
+test_expect_success 'config-specified template should commit' '
+	echo "new template" > "$TEMPLATE" &&
+	test_config commit.template "$TEMPLATE" &&
+	echo "more content" >> foo &&
+	git add foo &&
+	(
+		test_set_editor "$TEST_DIRECTORY"/t7500/add-content &&
+		git commit
+	) &&
+	commit_msg_is "new templatecommit message"
+'
+
+test_expect_success 'explicit commit message should override template' '
+	echo "still more content" >> foo &&
+	git add foo &&
+	GIT_EDITOR="$TEST_DIRECTORY"/t7500/add-content git commit --template "$TEMPLATE" \
+		-m "command line msg" &&
+	commit_msg_is "command line msg"
+'
+
+test_expect_success 'commit message from file should override template' '
+	echo "content galore" >> foo &&
+	git add foo &&
+	echo "standard input msg" |
+	(
+		test_set_editor "$TEST_DIRECTORY"/t7500/add-content &&
+		git commit --template "$TEMPLATE" --file -
+	) &&
+	commit_msg_is "standard input msg"
+'
+
+cat >"$TEMPLATE" <<\EOF
+
+
+### template
+
+EOF
+test_expect_success 'commit message from template with whitespace issue' '
+	echo "content galore" >>foo &&
+	git add foo &&
+	GIT_EDITOR=\""$TEST_DIRECTORY"\"/t7500/add-whitespaced-content \
+	git commit --template "$TEMPLATE" &&
+	commit_msg_is "commit message"
+'
+
+test_expect_success 'using alternate GIT_INDEX_FILE (1)' '
+
+	cp .git/index saved-index &&
+	(
+		echo some new content >file &&
+	        GIT_INDEX_FILE=.git/another_index &&
+		export GIT_INDEX_FILE &&
+		git add file &&
+		git commit -m "commit using another index" &&
+		git diff-index --exit-code HEAD &&
+		git diff-files --exit-code
+	) &&
+	cmp .git/index saved-index >/dev/null
+
+'
+
+test_expect_success 'using alternate GIT_INDEX_FILE (2)' '
+
+	cp .git/index saved-index &&
+	(
+		rm -f .git/no-such-index &&
+		GIT_INDEX_FILE=.git/no-such-index &&
+		export GIT_INDEX_FILE &&
+		git commit -m "commit using nonexistent index" &&
+		test -z "$(git ls-files)" &&
+		test -z "$(git ls-tree HEAD)"
+
+	) &&
+	cmp .git/index saved-index >/dev/null
+'
+
+cat > expect << EOF
+zort
+
+Signed-off-by: C O Mitter <committer@example.com>
+EOF
+
+test_expect_success '--signoff' '
+	echo "yet another content *narf*" >> foo &&
+	echo "zort" | git commit -s -F - foo &&
+	git cat-file commit HEAD | sed "1,/^\$/d" > output &&
+	test_cmp expect output
+'
+
+test_expect_success 'commit message from file (1)' '
+	mkdir subdir &&
+	echo "Log in top directory" >log &&
+	echo "Log in sub directory" >subdir/log &&
+	(
+		cd subdir &&
+		git commit --allow-empty -F log
+	) &&
+	commit_msg_is "Log in sub directory"
+'
+
+test_expect_success 'commit message from file (2)' '
+	rm -f log &&
+	echo "Log in sub directory" >subdir/log &&
+	(
+		cd subdir &&
+		git commit --allow-empty -F log
+	) &&
+	commit_msg_is "Log in sub directory"
+'
+
+test_expect_success 'commit message from stdin' '
+	(
+		cd subdir &&
+		echo "Log with foo word" | git commit --allow-empty -F -
+	) &&
+	commit_msg_is "Log with foo word"
+'
+
+test_expect_success 'commit -F overrides -t' '
+	(
+		cd subdir &&
+		echo "-F log" > f.log &&
+		echo "-t template" > t.template &&
+		git commit --allow-empty -F f.log -t t.template
+	) &&
+	commit_msg_is "-F log"
+'
+
+test_expect_success 'Commit without message is allowed with --allow-empty-message' '
+	echo "more content" >>foo &&
+	git add foo &&
+	>empty &&
+	git commit --allow-empty-message <empty &&
+	commit_msg_is "" &&
+	git tag empty-message-commit
+'
+
+test_expect_success 'Commit without message is no-no without --allow-empty-message' '
+	echo "more content" >>foo &&
+	git add foo &&
+	>empty &&
+	test_must_fail git commit <empty
+'
+
+test_expect_success 'Commit a message with --allow-empty-message' '
+	echo "even more content" >>foo &&
+	git add foo &&
+	git commit --allow-empty-message -m"hello there" &&
+	commit_msg_is "hello there"
+'
+
+test_expect_success 'commit -C empty respects --allow-empty-message' '
+	echo more >>foo &&
+	git add foo &&
+	test_must_fail git commit -C empty-message-commit &&
+	git commit -C empty-message-commit --allow-empty-message &&
+	commit_msg_is ""
+'
+
+commit_for_rebase_autosquash_setup () {
+	echo "first content line" >>foo &&
+	git add foo &&
+	cat >log <<EOF &&
+target message subject line
+
+target message body line 1
+target message body line 2
+EOF
+	git commit -F log &&
+	echo "second content line" >>foo &&
+	git add foo &&
+	git commit -m "intermediate commit" &&
+	echo "third content line" >>foo &&
+	git add foo
+}
+
+test_expect_success 'commit --fixup provides correct one-line commit message' '
+	commit_for_rebase_autosquash_setup &&
+	git commit --fixup HEAD~1 &&
+	commit_msg_is "fixup! target message subject line"
+'
+
+test_expect_success 'commit --fixup -m"something" -m"extra"' '
+	commit_for_rebase_autosquash_setup &&
+	git commit --fixup HEAD~1 -m"something" -m"extra" &&
+	commit_msg_is "fixup! target message subject linesomething
+
+extra"
+'
+
+test_expect_success 'commit --squash works with -F' '
+	commit_for_rebase_autosquash_setup &&
+	echo "log message from file" >msgfile &&
+	git commit --squash HEAD~1 -F msgfile  &&
+	commit_msg_is "squash! target message subject linelog message from file"
+'
+
+test_expect_success 'commit --squash works with -m' '
+	commit_for_rebase_autosquash_setup &&
+	git commit --squash HEAD~1 -m "foo bar\nbaz" &&
+	commit_msg_is "squash! target message subject linefoo bar\nbaz"
+'
+
+test_expect_success 'commit --squash works with -C' '
+	commit_for_rebase_autosquash_setup &&
+	git commit --squash HEAD~1 -C HEAD &&
+	commit_msg_is "squash! target message subject lineintermediate commit"
+'
+
+test_expect_success 'commit --squash works with -c' '
+	commit_for_rebase_autosquash_setup &&
+	test_set_editor "$TEST_DIRECTORY"/t7500/edit-content &&
+	git commit --squash HEAD~1 -c HEAD &&
+	commit_msg_is "squash! target message subject lineedited commit"
+'
+
+test_expect_success 'commit --squash works with -C for same commit' '
+	commit_for_rebase_autosquash_setup &&
+	git commit --squash HEAD -C HEAD &&
+	commit_msg_is "squash! intermediate commit"
+'
+
+test_expect_success 'commit --squash works with -c for same commit' '
+	commit_for_rebase_autosquash_setup &&
+	test_set_editor "$TEST_DIRECTORY"/t7500/edit-content &&
+	git commit --squash HEAD -c HEAD &&
+	commit_msg_is "squash! edited commit"
+'
+
+test_expect_success 'commit --squash works with editor' '
+	commit_for_rebase_autosquash_setup &&
+	test_set_editor "$TEST_DIRECTORY"/t7500/add-content &&
+	git commit --squash HEAD~1 &&
+	commit_msg_is "squash! target message subject linecommit message"
+'
+
+test_expect_success 'invalid message options when using --fixup' '
+	echo changes >>foo &&
+	echo "message" >log &&
+	git add foo &&
+	test_must_fail git commit --fixup HEAD~1 --squash HEAD~2 &&
+	test_must_fail git commit --fixup HEAD~1 -C HEAD~2 &&
+	test_must_fail git commit --fixup HEAD~1 -c HEAD~2 &&
+	test_must_fail git commit --fixup HEAD~1 -F log
+'
+
+cat >expected-template <<EOF
+
+# Please enter the commit message for your changes. Lines starting
+# with '#' will be ignored, and an empty message aborts the commit.
+#
+# Author:    A U Thor <author@example.com>
+#
+# On branch commit-template-check
+# Changes to be committed:
+#	new file:   commit-template-check
+#
+# Untracked files not listed
+EOF
+
+test_expect_success 'new line found before status message in commit template' '
+	git checkout -b commit-template-check &&
+	git reset --hard HEAD &&
+	touch commit-template-check &&
+	git add commit-template-check &&
+	GIT_EDITOR="cat >editor-input" git commit --untracked-files=no --allow-empty-message &&
+	test_i18ncmp expected-template editor-input
+'
+
+test_expect_success 'setup empty commit with unstaged rename and copy' '
+	test_create_repo unstaged_rename_and_copy &&
+	(
+		cd unstaged_rename_and_copy &&
+
+		echo content >orig &&
+		git add orig &&
+		test_commit orig &&
+
+		cp orig new_copy &&
+		mv orig new_rename &&
+		git add -N new_copy new_rename
+	)
+'
+
+test_expect_success 'check commit with unstaged rename and copy' '
+	(
+		cd unstaged_rename_and_copy &&
+
+		test_must_fail git -c diff.renames=copy commit
+	)
+'
+
+test_expect_success 'commit without staging files fails and displays hints' '
+	echo "initial" >file &&
+	git add file &&
+	git commit -m initial &&
+	echo "changes" >>file &&
+	test_must_fail git commit -m update >actual &&
+	test_i18ngrep "no changes added to commit (use \"git add\" and/or \"git commit -a\")" actual
+'
+
+test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t7501-commit-basic-functionality.sh 1.2.3+git2.25.1-1/git/t/t7501-commit-basic-functionality.sh
--- 1.2.1+git2.18.0-1/git/t/t7501-commit-basic-functionality.sh	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t7501-commit-basic-functionality.sh	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,716 @@
+#!/bin/sh
+#
+# Copyright (c) 2007 Kristian Høgsberg <krh@redhat.com>
+#
+
+# FIXME: Test the various index usages, -i and -o, test reflog,
+# signoff
+
+test_description='git commit'
+. ./test-lib.sh
+. "$TEST_DIRECTORY/diff-lib.sh"
+
+author='The Real Author <someguy@his.email.org>'
+
+test_tick
+
+test_expect_success 'initial status' '
+	echo bongo bongo >file &&
+	git add file &&
+	git status >actual &&
+	test_i18ngrep "No commits yet" actual
+'
+
+test_expect_success 'fail initial amend' '
+	test_must_fail git commit --amend
+'
+
+test_expect_success 'setup: initial commit' '
+	git commit -m initial
+'
+
+test_expect_success '-m and -F do not mix' '
+	git checkout HEAD file && echo >>file && git add file &&
+	test_must_fail git commit -m foo -m bar -F file
+'
+
+test_expect_success '-m and -C do not mix' '
+	git checkout HEAD file && echo >>file && git add file &&
+	test_must_fail git commit -C HEAD -m illegal
+'
+
+test_expect_success 'paths and -a do not mix' '
+	echo King of the bongo >file &&
+	test_must_fail git commit -m foo -a file
+'
+
+test_expect_success PERL 'can use paths with --interactive' '
+	echo bong-o-bong >file &&
+	# 2: update, 1:st path, that is all, 7: quit
+	test_write_lines 2 1 "" 7 |
+	git commit -m foo --interactive file &&
+	git reset --hard HEAD^
+'
+
+test_expect_success 'removed files and relative paths' '
+	test_when_finished "rm -rf foo" &&
+	git init foo &&
+	>foo/foo.txt &&
+	git -C foo add foo.txt &&
+	git -C foo commit -m first &&
+	git -C foo rm foo.txt &&
+
+	mkdir -p foo/bar &&
+	git -C foo/bar commit -m second ../foo.txt
+'
+
+test_expect_success 'using invalid commit with -C' '
+	test_must_fail git commit --allow-empty -C bogus
+'
+
+test_expect_success 'nothing to commit' '
+	git reset --hard &&
+	test_must_fail git commit -m initial
+'
+
+test_expect_success '--dry-run fails with nothing to commit' '
+	test_must_fail git commit -m initial --dry-run
+'
+
+test_expect_success '--short fails with nothing to commit' '
+	test_must_fail git commit -m initial --short
+'
+
+test_expect_success '--porcelain fails with nothing to commit' '
+	test_must_fail git commit -m initial --porcelain
+'
+
+test_expect_success '--long fails with nothing to commit' '
+	test_must_fail git commit -m initial --long
+'
+
+test_expect_success 'setup: non-initial commit' '
+	echo bongo bongo bongo >file &&
+	git commit -m next -a
+'
+
+test_expect_success '--dry-run with stuff to commit returns ok' '
+	echo bongo bongo bongo >>file &&
+	git commit -m next -a --dry-run
+'
+
+test_expect_success '--short with stuff to commit returns ok' '
+	echo bongo bongo bongo >>file &&
+	git commit -m next -a --short
+'
+
+test_expect_success '--porcelain with stuff to commit returns ok' '
+	echo bongo bongo bongo >>file &&
+	git commit -m next -a --porcelain
+'
+
+test_expect_success '--long with stuff to commit returns ok' '
+	echo bongo bongo bongo >>file &&
+	git commit -m next -a --long
+'
+
+test_expect_success 'commit message from non-existing file' '
+	echo more bongo: bongo bongo bongo bongo >file &&
+	test_must_fail git commit -F gah -a
+'
+
+test_expect_success 'empty commit message' '
+	# Empty except stray tabs and spaces on a few lines.
+	sed -e "s/@//g" >msg <<-\EOF &&
+		@		@
+		@@
+		@  @
+		@Signed-off-by: hula@
+	EOF
+	test_must_fail git commit -F msg -a
+'
+
+test_expect_success 'template "emptyness" check does not kick in with -F' '
+	git checkout HEAD file && echo >>file && git add file &&
+	git commit -t file -F file
+'
+
+test_expect_success 'template "emptyness" check' '
+	git checkout HEAD file && echo >>file && git add file &&
+	test_must_fail git commit -t file 2>err &&
+	test_i18ngrep "did not edit" err
+'
+
+test_expect_success 'setup: commit message from file' '
+	git checkout HEAD file && echo >>file && git add file &&
+	echo this is the commit message, coming from a file >msg &&
+	git commit -F msg -a
+'
+
+test_expect_success 'amend commit' '
+	cat >editor <<-\EOF &&
+	#!/bin/sh
+	sed -e "s/a file/an amend commit/g" <"$1" >"$1-"
+	mv "$1-" "$1"
+	EOF
+	chmod 755 editor &&
+	EDITOR=./editor git commit --amend
+'
+
+test_expect_success 'amend --only ignores staged contents' '
+	cp file file.expect &&
+	echo changed >file &&
+	git add file &&
+	git commit --no-edit --amend --only &&
+	git cat-file blob HEAD:file >file.actual &&
+	test_cmp file.expect file.actual &&
+	git diff --exit-code
+'
+
+test_expect_success 'allow-empty --only ignores staged contents' '
+	echo changed-again >file &&
+	git add file &&
+	git commit --allow-empty --only -m "empty" &&
+	git cat-file blob HEAD:file >file.actual &&
+	test_cmp file.expect file.actual &&
+	git diff --exit-code
+'
+
+test_expect_success 'set up editor' '
+	cat >editor <<-\EOF &&
+	#!/bin/sh
+	sed -e "s/unamended/amended/g" <"$1" >"$1-"
+	mv "$1-" "$1"
+	EOF
+	chmod 755 editor
+'
+
+test_expect_success 'amend without launching editor' '
+	echo unamended >expect &&
+	git commit --allow-empty -m "unamended" &&
+	echo needs more bongo >file &&
+	git add file &&
+	EDITOR=./editor git commit --no-edit --amend &&
+	git diff --exit-code HEAD -- file &&
+	git diff-tree -s --format=%s HEAD >msg &&
+	test_cmp expect msg
+'
+
+test_expect_success '--amend --edit' '
+	echo amended >expect &&
+	git commit --allow-empty -m "unamended" &&
+	echo bongo again >file &&
+	git add file &&
+	EDITOR=./editor git commit --edit --amend &&
+	git diff-tree -s --format=%s HEAD >msg &&
+	test_cmp expect msg
+'
+
+test_expect_success '--amend --edit of empty message' '
+	cat >replace <<-\EOF &&
+	#!/bin/sh
+	echo "amended" >"$1"
+	EOF
+	chmod 755 replace &&
+	git commit --allow-empty --allow-empty-message -m "" &&
+	echo more bongo >file &&
+	git add file &&
+	EDITOR=./replace git commit --edit --amend &&
+	git diff-tree -s --format=%s HEAD >msg &&
+	./replace expect &&
+	test_cmp expect msg
+'
+
+test_expect_success '--amend to set message to empty' '
+	echo bata >file &&
+	git add file &&
+	git commit -m "unamended" &&
+	git commit --amend --allow-empty-message -m "" &&
+	git diff-tree -s --format=%s HEAD >msg &&
+	echo "" >expect &&
+	test_cmp expect msg
+'
+
+test_expect_success '--amend to set empty message needs --allow-empty-message' '
+	echo conga >file &&
+	git add file &&
+	git commit -m "unamended" &&
+	test_must_fail git commit --amend -m "" &&
+	git diff-tree -s --format=%s HEAD >msg &&
+	echo "unamended" >expect &&
+	test_cmp expect msg
+'
+
+test_expect_success '-m --edit' '
+	echo amended >expect &&
+	git commit --allow-empty -m buffer &&
+	echo bongo bongo >file &&
+	git add file &&
+	EDITOR=./editor git commit -m unamended --edit &&
+	git diff-tree -s  --format=%s HEAD >msg &&
+	test_cmp expect msg
+'
+
+test_expect_success '-m and -F do not mix' '
+	echo enough with the bongos >file &&
+	test_must_fail git commit -F msg -m amending .
+'
+
+test_expect_success 'using message from other commit' '
+	git commit -C HEAD^ .
+'
+
+test_expect_success 'editing message from other commit' '
+	cat >editor <<-\EOF &&
+	#!/bin/sh
+	sed -e "s/amend/older/g"  <"$1" >"$1-"
+	mv "$1-" "$1"
+	EOF
+	chmod 755 editor &&
+	echo hula hula >file &&
+	EDITOR=./editor git commit -c HEAD^ -a
+'
+
+test_expect_success 'message from stdin' '
+	echo silly new contents >file &&
+	echo commit message from stdin |
+	git commit -F - -a
+'
+
+test_expect_success 'overriding author from command line' '
+	echo gak >file &&
+	git commit -m author \
+		--author "Rubber Duck <rduck@convoy.org>" -a >output 2>&1 &&
+	grep Rubber.Duck output
+'
+
+test_expect_success PERL 'interactive add' '
+	echo 7 | test_must_fail git commit --interactive >out &&
+	grep "What now" out
+'
+
+test_expect_success PERL "commit --interactive doesn't change index if editor aborts" '
+	echo zoo >file &&
+	test_must_fail git diff --exit-code >diff1 &&
+	test_write_lines u "*" q |
+	(
+		EDITOR=: &&
+		export EDITOR &&
+		test_must_fail git commit --interactive
+	) &&
+	git diff >diff2 &&
+	compare_diff_patch diff1 diff2
+'
+
+test_expect_success 'editor not invoked if -F is given' '
+	cat >editor <<-\EOF &&
+	#!/bin/sh
+	sed -e s/good/bad/g <"$1" >"$1-"
+	mv "$1-" "$1"
+	EOF
+	chmod 755 editor &&
+
+	echo A good commit message. >msg &&
+	echo moo >file &&
+
+	EDITOR=./editor git commit -a -F msg &&
+	git show -s --pretty=format:%s >subject &&
+	grep -q good subject &&
+
+	echo quack >file &&
+	echo Another good message. |
+	EDITOR=./editor git commit -a -F - &&
+	git show -s --pretty=format:%s >subject &&
+	grep -q good subject
+'
+
+test_expect_success 'partial commit that involves removal (1)' '
+
+	git rm --cached file &&
+	mv file elif &&
+	git add elif &&
+	git commit -m "Partial: add elif" elif &&
+	git diff-tree --name-status HEAD^ HEAD >current &&
+	echo "A	elif" >expected &&
+	test_cmp expected current
+
+'
+
+test_expect_success 'partial commit that involves removal (2)' '
+
+	git commit -m "Partial: remove file" file &&
+	git diff-tree --name-status HEAD^ HEAD >current &&
+	echo "D	file" >expected &&
+	test_cmp expected current
+
+'
+
+test_expect_success 'partial commit that involves removal (3)' '
+
+	git rm --cached elif &&
+	echo elif >elif &&
+	git commit -m "Partial: modify elif" elif &&
+	git diff-tree --name-status HEAD^ HEAD >current &&
+	echo "M	elif" >expected &&
+	test_cmp expected current
+
+'
+
+test_expect_success 'amend commit to fix author' '
+
+	oldtick=$GIT_AUTHOR_DATE &&
+	test_tick &&
+	git reset --hard &&
+	git cat-file -p HEAD >commit &&
+	sed -e "s/author.*/author $author $oldtick/" \
+		-e "s/^\(committer.*> \).*$/\1$GIT_COMMITTER_DATE/" \
+		commit >expected &&
+	git commit --amend --author="$author" &&
+	git cat-file -p HEAD >current &&
+	test_cmp expected current
+
+'
+
+test_expect_success 'amend commit to fix date' '
+
+	test_tick &&
+	newtick=$GIT_AUTHOR_DATE &&
+	git reset --hard &&
+	git cat-file -p HEAD >commit &&
+	sed -e "s/author.*/author $author $newtick/" \
+		-e "s/^\(committer.*> \).*$/\1$GIT_COMMITTER_DATE/" \
+		commit >expected &&
+	git commit --amend --date="$newtick" &&
+	git cat-file -p HEAD >current &&
+	test_cmp expected current
+
+'
+
+test_expect_success 'commit mentions forced date in output' '
+	git commit --amend --date=2010-01-02T03:04:05 >output &&
+	grep "Date: *Sat Jan 2 03:04:05 2010" output
+'
+
+test_expect_success 'commit complains about completely bogus dates' '
+	test_must_fail git commit --amend --date=seventeen
+'
+
+test_expect_success 'commit --date allows approxidate' '
+	git commit --amend \
+		--date="midnight the 12th of october, anno domini 1979" &&
+	echo "Fri Oct 12 00:00:00 1979 +0000" >expect &&
+	git log -1 --format=%ad >actual &&
+	test_cmp expect actual
+'
+
+test_expect_success 'sign off (1)' '
+
+	echo 1 >positive &&
+	git add positive &&
+	git commit -s -m "thank you" &&
+	git cat-file commit HEAD >commit &&
+	sed -e "1,/^\$/d" commit >actual &&
+	(
+		echo thank you &&
+		echo &&
+		git var GIT_COMMITTER_IDENT >ident &&
+		sed -e "s/>.*/>/" -e "s/^/Signed-off-by: /" ident
+	) >expected &&
+	test_cmp expected actual
+
+'
+
+test_expect_success 'sign off (2)' '
+
+	echo 2 >positive &&
+	git add positive &&
+	existing="Signed-off-by: Watch This <watchthis@example.com>" &&
+	git commit -s -m "thank you
+
+$existing" &&
+	git cat-file commit HEAD >commit &&
+	sed -e "1,/^\$/d" commit >actual &&
+	(
+		echo thank you &&
+		echo &&
+		echo $existing &&
+		git var GIT_COMMITTER_IDENT >ident &&
+		sed -e "s/>.*/>/" -e "s/^/Signed-off-by: /" ident
+	) >expected &&
+	test_cmp expected actual
+
+'
+
+test_expect_success 'signoff gap' '
+
+	echo 3 >positive &&
+	git add positive &&
+	alt="Alt-RFC-822-Header: Value" &&
+	git commit -s -m "welcome
+
+$alt" &&
+	git cat-file commit HEAD >commit &&
+	sed -e "1,/^\$/d" commit >actual &&
+	(
+		echo welcome &&
+		echo &&
+		echo $alt &&
+		git var GIT_COMMITTER_IDENT >ident &&
+		sed -e "s/>.*/>/" -e "s/^/Signed-off-by: /" ident
+	) >expected &&
+	test_cmp expected actual
+'
+
+test_expect_success 'signoff gap 2' '
+
+	echo 4 >positive &&
+	git add positive &&
+	alt="fixed: 34" &&
+	git commit -s -m "welcome
+
+We have now
+$alt" &&
+	git cat-file commit HEAD >commit &&
+	sed -e "1,/^\$/d" commit >actual &&
+	(
+		echo welcome &&
+		echo &&
+		echo We have now &&
+		echo $alt &&
+		echo &&
+		git var GIT_COMMITTER_IDENT >ident &&
+		sed -e "s/>.*/>/" -e "s/^/Signed-off-by: /" ident
+	) >expected &&
+	test_cmp expected actual
+'
+
+test_expect_success 'signoff respects trailer config' '
+
+	echo 5 >positive &&
+	git add positive &&
+	git commit -s -m "subject
+
+non-trailer line
+Myfooter: x" &&
+	git cat-file commit HEAD >commit &&
+	sed -e "1,/^\$/d" commit >actual &&
+	(
+		echo subject &&
+		echo &&
+		echo non-trailer line &&
+		echo Myfooter: x &&
+		echo &&
+		echo "Signed-off-by: $GIT_COMMITTER_NAME <$GIT_COMMITTER_EMAIL>"
+	) >expected &&
+	test_cmp expected actual &&
+
+	echo 6 >positive &&
+	git add positive &&
+	git -c "trailer.Myfooter.ifexists=add" commit -s -m "subject
+
+non-trailer line
+Myfooter: x" &&
+	git cat-file commit HEAD >commit &&
+	sed -e "1,/^\$/d" commit >actual &&
+	(
+		echo subject &&
+		echo &&
+		echo non-trailer line &&
+		echo Myfooter: x &&
+		echo "Signed-off-by: $GIT_COMMITTER_NAME <$GIT_COMMITTER_EMAIL>"
+	) >expected &&
+	test_cmp expected actual
+'
+
+test_expect_success 'signoff not confused by ---' '
+	cat >expected <<-EOF &&
+		subject
+
+		body
+		---
+		these dashes confuse the parser!
+
+		Signed-off-by: $GIT_COMMITTER_NAME <$GIT_COMMITTER_EMAIL>
+	EOF
+	# should be a noop, since we already signed
+	git commit --allow-empty --signoff -F expected &&
+	git log -1 --pretty=format:%B >actual &&
+	test_cmp expected actual
+'
+
+test_expect_success 'multiple -m' '
+
+	>negative &&
+	git add negative &&
+	git commit -m "one" -m "two" -m "three" &&
+	git cat-file commit HEAD >commit &&
+	sed -e "1,/^\$/d" commit >actual &&
+	(
+		echo one &&
+		echo &&
+		echo two &&
+		echo &&
+		echo three
+	) >expected &&
+	test_cmp expected actual
+
+'
+
+test_expect_success 'amend commit to fix author' '
+
+	oldtick=$GIT_AUTHOR_DATE &&
+	test_tick &&
+	git reset --hard &&
+	git cat-file -p HEAD >commit &&
+	sed -e "s/author.*/author $author $oldtick/" \
+		-e "s/^\(committer.*> \).*$/\1$GIT_COMMITTER_DATE/" \
+		commit >expected &&
+	git commit --amend --author="$author" &&
+	git cat-file -p HEAD >current &&
+	test_cmp expected current
+
+'
+
+test_expect_success 'git commit <file> with dirty index' '
+	echo tacocat >elif &&
+	echo tehlulz >chz &&
+	git add chz &&
+	git commit elif -m "tacocat is a palindrome" &&
+	git show --stat >stat &&
+	grep elif stat &&
+	git diff --cached >diff &&
+	grep chz diff
+'
+
+test_expect_success 'same tree (single parent)' '
+
+	git reset --hard &&
+	test_must_fail git commit -m empty
+
+'
+
+test_expect_success 'same tree (single parent) --allow-empty' '
+
+	git commit --allow-empty -m "forced empty" &&
+	git cat-file commit HEAD >commit &&
+	grep forced commit
+
+'
+
+test_expect_success 'same tree (merge and amend merge)' '
+
+	git checkout -b side HEAD^ &&
+	echo zero >zero &&
+	git add zero &&
+	git commit -m "add zero" &&
+	git checkout master &&
+
+	git merge -s ours side -m "empty ok" &&
+	git diff HEAD^ HEAD >actual &&
+	test_must_be_empty actual &&
+
+	git commit --amend -m "empty really ok" &&
+	git diff HEAD^ HEAD >actual &&
+	test_must_be_empty actual
+
+'
+
+test_expect_success 'amend using the message from another commit' '
+
+	git reset --hard &&
+	test_tick &&
+	git commit --allow-empty -m "old commit" &&
+	old=$(git rev-parse --verify HEAD) &&
+	test_tick &&
+	git commit --allow-empty -m "new commit" &&
+	new=$(git rev-parse --verify HEAD) &&
+	test_tick &&
+	git commit --allow-empty --amend -C "$old" &&
+	git show --pretty="format:%ad %s" "$old" >expected &&
+	git show --pretty="format:%ad %s" HEAD >actual &&
+	test_cmp expected actual
+
+'
+
+test_expect_success 'amend using the message from a commit named with tag' '
+
+	git reset --hard &&
+	test_tick &&
+	git commit --allow-empty -m "old commit" &&
+	old=$(git rev-parse --verify HEAD) &&
+	git tag -a -m "tag on old" tagged-old HEAD &&
+	test_tick &&
+	git commit --allow-empty -m "new commit" &&
+	new=$(git rev-parse --verify HEAD) &&
+	test_tick &&
+	git commit --allow-empty --amend -C tagged-old &&
+	git show --pretty="format:%ad %s" "$old" >expected &&
+	git show --pretty="format:%ad %s" HEAD >actual &&
+	test_cmp expected actual
+
+'
+
+test_expect_success 'amend can copy notes' '
+
+	git config notes.rewrite.amend true &&
+	git config notes.rewriteRef "refs/notes/*" &&
+	test_commit foo &&
+	git notes add -m"a note" &&
+	test_tick &&
+	git commit --amend -m"new foo" &&
+	test "$(git notes show)" = "a note"
+
+'
+
+test_expect_success 'commit a file whose name is a dash' '
+	git reset --hard &&
+	for i in 1 2 3 4 5
+	do
+		echo $i
+	done >./- &&
+	git add ./- &&
+	test_tick &&
+	git commit -m "add dash" >output </dev/null &&
+	test_i18ngrep " changed, 5 insertions" output
+'
+
+test_expect_success '--only works on to-be-born branch' '
+	# This test relies on having something in the index, as it
+	# would not otherwise actually prove much.  So check this.
+	test -n "$(git ls-files)" &&
+	git checkout --orphan orphan &&
+	echo foo >newfile &&
+	git add newfile &&
+	git commit --only newfile -m"--only on unborn branch" &&
+	echo newfile >expected &&
+	git ls-tree -r --name-only HEAD >actual &&
+	test_cmp expected actual
+'
+
+test_expect_success '--dry-run with conflicts fixed from a merge' '
+	# setup two branches with conflicting information
+	# in the same file, resolve the conflict,
+	# call commit with --dry-run
+	echo "Initial contents, unimportant" >test-file &&
+	git add test-file &&
+	git commit -m "Initial commit" &&
+	echo "commit-1-state" >test-file &&
+	git commit -m "commit 1" -i test-file &&
+	git tag commit-1 &&
+	git checkout -b branch-2 HEAD^1 &&
+	echo "commit-2-state" >test-file &&
+	git commit -m "commit 2" -i test-file &&
+	test_must_fail git merge --no-commit commit-1 &&
+	echo "commit-2-state" >test-file &&
+	git add test-file &&
+	git commit --dry-run &&
+	git commit -m "conflicts fixed from merge."
+'
+
+test_expect_success '--dry-run --short' '
+	>test-file &&
+	git add test-file &&
+	git commit --dry-run --short
+'
+
+test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t7501-commit.sh 1.2.3+git2.25.1-1/git/t/t7501-commit.sh
--- 1.2.1+git2.18.0-1/git/t/t7501-commit.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t7501-commit.sh	1970-01-01 00:00:00.000000000 +0000
@@ -1,687 +0,0 @@
-#!/bin/sh
-#
-# Copyright (c) 2007 Kristian Høgsberg <krh@redhat.com>
-#
-
-# FIXME: Test the various index usages, -i and -o, test reflog,
-# signoff
-
-test_description='git commit'
-. ./test-lib.sh
-. "$TEST_DIRECTORY/diff-lib.sh"
-
-author='The Real Author <someguy@his.email.org>'
-
-test_tick
-
-test_expect_success 'initial status' '
-	echo bongo bongo >file &&
-	git add file &&
-	git status >actual &&
-	test_i18ngrep "No commits yet" actual
-'
-
-test_expect_success 'fail initial amend' '
-	test_must_fail git commit --amend
-'
-
-test_expect_success 'setup: initial commit' '
-	git commit -m initial
-'
-
-test_expect_success '-m and -F do not mix' '
-	git checkout HEAD file && echo >>file && git add file &&
-	test_must_fail git commit -m foo -m bar -F file
-'
-
-test_expect_success '-m and -C do not mix' '
-	git checkout HEAD file && echo >>file && git add file &&
-	test_must_fail git commit -C HEAD -m illegal
-'
-
-test_expect_success 'paths and -a do not mix' '
-	echo King of the bongo >file &&
-	test_must_fail git commit -m foo -a file
-'
-
-test_expect_success PERL 'can use paths with --interactive' '
-	echo bong-o-bong >file &&
-	# 2: update, 1:st path, that is all, 7: quit
-	( echo 2; echo 1; echo; echo 7 ) |
-	git commit -m foo --interactive file &&
-	git reset --hard HEAD^
-'
-
-test_expect_success 'removed files and relative paths' '
-	test_when_finished "rm -rf foo" &&
-	git init foo &&
-	>foo/foo.txt &&
-	git -C foo add foo.txt &&
-	git -C foo commit -m first &&
-	git -C foo rm foo.txt &&
-
-	mkdir -p foo/bar &&
-	git -C foo/bar commit -m second ../foo.txt
-'
-
-test_expect_success 'using invalid commit with -C' '
-	test_must_fail git commit --allow-empty -C bogus
-'
-
-test_expect_success 'nothing to commit' '
-	git reset --hard &&
-	test_must_fail git commit -m initial
-'
-
-test_expect_success '--dry-run fails with nothing to commit' '
-	test_must_fail git commit -m initial --dry-run
-'
-
-test_expect_success '--short fails with nothing to commit' '
-	test_must_fail git commit -m initial --short
-'
-
-test_expect_success '--porcelain fails with nothing to commit' '
-	test_must_fail git commit -m initial --porcelain
-'
-
-test_expect_success '--long fails with nothing to commit' '
-	test_must_fail git commit -m initial --long
-'
-
-test_expect_success 'setup: non-initial commit' '
-	echo bongo bongo bongo >file &&
-	git commit -m next -a
-'
-
-test_expect_success '--dry-run with stuff to commit returns ok' '
-	echo bongo bongo bongo >>file &&
-	git commit -m next -a --dry-run
-'
-
-test_expect_failure '--short with stuff to commit returns ok' '
-	echo bongo bongo bongo >>file &&
-	git commit -m next -a --short
-'
-
-test_expect_failure '--porcelain with stuff to commit returns ok' '
-	echo bongo bongo bongo >>file &&
-	git commit -m next -a --porcelain
-'
-
-test_expect_success '--long with stuff to commit returns ok' '
-	echo bongo bongo bongo >>file &&
-	git commit -m next -a --long
-'
-
-test_expect_success 'commit message from non-existing file' '
-	echo more bongo: bongo bongo bongo bongo >file &&
-	test_must_fail git commit -F gah -a
-'
-
-test_expect_success 'empty commit message' '
-	# Empty except stray tabs and spaces on a few lines.
-	sed -e "s/@//g" >msg <<-\EOF &&
-		@		@
-		@@
-		@  @
-		@Signed-off-by: hula@
-	EOF
-	test_must_fail git commit -F msg -a
-'
-
-test_expect_success 'template "emptyness" check does not kick in with -F' '
-	git checkout HEAD file && echo >>file && git add file &&
-	git commit -t file -F file
-'
-
-test_expect_success 'template "emptyness" check' '
-	git checkout HEAD file && echo >>file && git add file &&
-	test_must_fail git commit -t file 2>err &&
-	test_i18ngrep "did not edit" err
-'
-
-test_expect_success 'setup: commit message from file' '
-	git checkout HEAD file && echo >>file && git add file &&
-	echo this is the commit message, coming from a file >msg &&
-	git commit -F msg -a
-'
-
-test_expect_success 'amend commit' '
-	cat >editor <<-\EOF &&
-	#!/bin/sh
-	sed -e "s/a file/an amend commit/g" < "$1" > "$1-"
-	mv "$1-" "$1"
-	EOF
-	chmod 755 editor &&
-	EDITOR=./editor git commit --amend
-'
-
-test_expect_success 'amend --only ignores staged contents' '
-	cp file file.expect &&
-	echo changed >file &&
-	git add file &&
-	git commit --no-edit --amend --only &&
-	git cat-file blob HEAD:file >file.actual &&
-	test_cmp file.expect file.actual &&
-	git diff --exit-code
-'
-
-test_expect_success 'allow-empty --only ignores staged contents' '
-	echo changed-again >file &&
-	git add file &&
-	git commit --allow-empty --only -m "empty" &&
-	git cat-file blob HEAD:file >file.actual &&
-	test_cmp file.expect file.actual &&
-	git diff --exit-code
-'
-
-test_expect_success 'set up editor' '
-	cat >editor <<-\EOF &&
-	#!/bin/sh
-	sed -e "s/unamended/amended/g" <"$1" >"$1-"
-	mv "$1-" "$1"
-	EOF
-	chmod 755 editor
-'
-
-test_expect_success 'amend without launching editor' '
-	echo unamended >expect &&
-	git commit --allow-empty -m "unamended" &&
-	echo needs more bongo >file &&
-	git add file &&
-	EDITOR=./editor git commit --no-edit --amend &&
-	git diff --exit-code HEAD -- file &&
-	git diff-tree -s --format=%s HEAD >msg &&
-	test_cmp expect msg
-'
-
-test_expect_success '--amend --edit' '
-	echo amended >expect &&
-	git commit --allow-empty -m "unamended" &&
-	echo bongo again >file &&
-	git add file &&
-	EDITOR=./editor git commit --edit --amend &&
-	git diff-tree -s --format=%s HEAD >msg &&
-	test_cmp expect msg
-'
-
-test_expect_success '--amend --edit of empty message' '
-	cat >replace <<-\EOF &&
-	#!/bin/sh
-	echo "amended" >"$1"
-	EOF
-	chmod 755 replace &&
-	git commit --allow-empty --allow-empty-message -m "" &&
-	echo more bongo >file &&
-	git add file &&
-	EDITOR=./replace git commit --edit --amend &&
-	git diff-tree -s --format=%s HEAD >msg &&
-	./replace expect &&
-	test_cmp expect msg
-'
-
-test_expect_success '--amend to set message to empty' '
-	echo bata >file &&
-	git add file &&
-	git commit -m "unamended" &&
-	git commit --amend --allow-empty-message -m "" &&
-	git diff-tree -s --format=%s HEAD >msg &&
-	echo "" >expect &&
-	test_cmp expect msg
-'
-
-test_expect_success '--amend to set empty message needs --allow-empty-message' '
-	echo conga >file &&
-	git add file &&
-	git commit -m "unamended" &&
-	test_must_fail git commit --amend -m "" &&
-	git diff-tree -s --format=%s HEAD >msg &&
-	echo "unamended" >expect &&
-	test_cmp expect msg
-'
-
-test_expect_success '-m --edit' '
-	echo amended >expect &&
-	git commit --allow-empty -m buffer &&
-	echo bongo bongo >file &&
-	git add file &&
-	EDITOR=./editor git commit -m unamended --edit &&
-	git diff-tree -s  --format=%s HEAD >msg &&
-	test_cmp expect msg
-'
-
-test_expect_success '-m and -F do not mix' '
-	echo enough with the bongos >file &&
-	test_must_fail git commit -F msg -m amending .
-'
-
-test_expect_success 'using message from other commit' '
-	git commit -C HEAD^ .
-'
-
-test_expect_success 'editing message from other commit' '
-	cat >editor <<-\EOF &&
-	#!/bin/sh
-	sed -e "s/amend/older/g"  < "$1" > "$1-"
-	mv "$1-" "$1"
-	EOF
-	chmod 755 editor &&
-	echo hula hula >file &&
-	EDITOR=./editor git commit -c HEAD^ -a
-'
-
-test_expect_success 'message from stdin' '
-	echo silly new contents >file &&
-	echo commit message from stdin |
-	git commit -F - -a
-'
-
-test_expect_success 'overriding author from command line' '
-	echo gak >file &&
-	git commit -m author \
-		--author "Rubber Duck <rduck@convoy.org>" -a >output 2>&1 &&
-	grep Rubber.Duck output
-'
-
-test_expect_success PERL 'interactive add' '
-	echo 7 |
-	git commit --interactive |
-	grep "What now"
-'
-
-test_expect_success PERL "commit --interactive doesn't change index if editor aborts" '
-	echo zoo >file &&
-	test_must_fail git diff --exit-code >diff1 &&
-	(echo u ; echo "*" ; echo q) |
-	(
-		EDITOR=: &&
-		export EDITOR &&
-		test_must_fail git commit --interactive
-	) &&
-	git diff >diff2 &&
-	compare_diff_patch diff1 diff2
-'
-
-test_expect_success 'editor not invoked if -F is given' '
-	cat >editor <<-\EOF &&
-	#!/bin/sh
-	sed -e s/good/bad/g <"$1" >"$1-"
-	mv "$1-" "$1"
-	EOF
-	chmod 755 editor &&
-
-	echo A good commit message. >msg &&
-	echo moo >file &&
-
-	EDITOR=./editor git commit -a -F msg &&
-	git show -s --pretty=format:%s >subject &&
-	grep -q good subject &&
-
-	echo quack >file &&
-	echo Another good message. |
-	EDITOR=./editor git commit -a -F - &&
-	git show -s --pretty=format:%s >subject &&
-	grep -q good subject
-'
-
-test_expect_success 'partial commit that involves removal (1)' '
-
-	git rm --cached file &&
-	mv file elif &&
-	git add elif &&
-	git commit -m "Partial: add elif" elif &&
-	git diff-tree --name-status HEAD^ HEAD >current &&
-	echo "A	elif" >expected &&
-	test_cmp expected current
-
-'
-
-test_expect_success 'partial commit that involves removal (2)' '
-
-	git commit -m "Partial: remove file" file &&
-	git diff-tree --name-status HEAD^ HEAD >current &&
-	echo "D	file" >expected &&
-	test_cmp expected current
-
-'
-
-test_expect_success 'partial commit that involves removal (3)' '
-
-	git rm --cached elif &&
-	echo elif >elif &&
-	git commit -m "Partial: modify elif" elif &&
-	git diff-tree --name-status HEAD^ HEAD >current &&
-	echo "M	elif" >expected &&
-	test_cmp expected current
-
-'
-
-test_expect_success 'amend commit to fix author' '
-
-	oldtick=$GIT_AUTHOR_DATE &&
-	test_tick &&
-	git reset --hard &&
-	git cat-file -p HEAD |
-	sed -e "s/author.*/author $author $oldtick/" \
-		-e "s/^\(committer.*> \).*$/\1$GIT_COMMITTER_DATE/" > \
-		expected &&
-	git commit --amend --author="$author" &&
-	git cat-file -p HEAD > current &&
-	test_cmp expected current
-
-'
-
-test_expect_success 'amend commit to fix date' '
-
-	test_tick &&
-	newtick=$GIT_AUTHOR_DATE &&
-	git reset --hard &&
-	git cat-file -p HEAD |
-	sed -e "s/author.*/author $author $newtick/" \
-		-e "s/^\(committer.*> \).*$/\1$GIT_COMMITTER_DATE/" > \
-		expected &&
-	git commit --amend --date="$newtick" &&
-	git cat-file -p HEAD > current &&
-	test_cmp expected current
-
-'
-
-test_expect_success 'commit mentions forced date in output' '
-	git commit --amend --date=2010-01-02T03:04:05 >output &&
-	grep "Date: *Sat Jan 2 03:04:05 2010" output
-'
-
-test_expect_success 'commit complains about completely bogus dates' '
-	test_must_fail git commit --amend --date=seventeen
-'
-
-test_expect_success 'commit --date allows approxidate' '
-	git commit --amend \
-		--date="midnight the 12th of october, anno domini 1979" &&
-	echo "Fri Oct 12 00:00:00 1979 +0000" >expect &&
-	git log -1 --format=%ad >actual &&
-	test_cmp expect actual
-'
-
-test_expect_success 'sign off (1)' '
-
-	echo 1 >positive &&
-	git add positive &&
-	git commit -s -m "thank you" &&
-	git cat-file commit HEAD | sed -e "1,/^\$/d" >actual &&
-	(
-		echo thank you
-		echo
-		git var GIT_COMMITTER_IDENT |
-		sed -e "s/>.*/>/" -e "s/^/Signed-off-by: /"
-	) >expected &&
-	test_cmp expected actual
-
-'
-
-test_expect_success 'sign off (2)' '
-
-	echo 2 >positive &&
-	git add positive &&
-	existing="Signed-off-by: Watch This <watchthis@example.com>" &&
-	git commit -s -m "thank you
-
-$existing" &&
-	git cat-file commit HEAD | sed -e "1,/^\$/d" >actual &&
-	(
-		echo thank you
-		echo
-		echo $existing
-		git var GIT_COMMITTER_IDENT |
-		sed -e "s/>.*/>/" -e "s/^/Signed-off-by: /"
-	) >expected &&
-	test_cmp expected actual
-
-'
-
-test_expect_success 'signoff gap' '
-
-	echo 3 >positive &&
-	git add positive &&
-	alt="Alt-RFC-822-Header: Value" &&
-	git commit -s -m "welcome
-
-$alt" &&
-	git cat-file commit HEAD | sed -e "1,/^\$/d" > actual &&
-	(
-		echo welcome
-		echo
-		echo $alt
-		git var GIT_COMMITTER_IDENT |
-		sed -e "s/>.*/>/" -e "s/^/Signed-off-by: /"
-	) >expected &&
-	test_cmp expected actual
-'
-
-test_expect_success 'signoff gap 2' '
-
-	echo 4 >positive &&
-	git add positive &&
-	alt="fixed: 34" &&
-	git commit -s -m "welcome
-
-We have now
-$alt" &&
-	git cat-file commit HEAD | sed -e "1,/^\$/d" > actual &&
-	(
-		echo welcome
-		echo
-		echo We have now
-		echo $alt
-		echo
-		git var GIT_COMMITTER_IDENT |
-		sed -e "s/>.*/>/" -e "s/^/Signed-off-by: /"
-	) >expected &&
-	test_cmp expected actual
-'
-
-test_expect_success 'signoff respects trailer config' '
-
-	echo 5 >positive &&
-	git add positive &&
-	git commit -s -m "subject
-
-non-trailer line
-Myfooter: x" &&
-	git cat-file commit HEAD | sed -e "1,/^\$/d" > actual &&
-	(
-		echo subject
-		echo
-		echo non-trailer line
-		echo Myfooter: x
-		echo
-		echo "Signed-off-by: $GIT_COMMITTER_NAME <$GIT_COMMITTER_EMAIL>"
-	) >expected &&
-	test_cmp expected actual &&
-
-	echo 6 >positive &&
-	git add positive &&
-	git -c "trailer.Myfooter.ifexists=add" commit -s -m "subject
-
-non-trailer line
-Myfooter: x" &&
-	git cat-file commit HEAD | sed -e "1,/^\$/d" > actual &&
-	(
-		echo subject
-		echo
-		echo non-trailer line
-		echo Myfooter: x
-		echo "Signed-off-by: $GIT_COMMITTER_NAME <$GIT_COMMITTER_EMAIL>"
-	) >expected &&
-	test_cmp expected actual
-'
-
-test_expect_success 'multiple -m' '
-
-	>negative &&
-	git add negative &&
-	git commit -m "one" -m "two" -m "three" &&
-	git cat-file commit HEAD | sed -e "1,/^\$/d" >actual &&
-	(
-		echo one
-		echo
-		echo two
-		echo
-		echo three
-	) >expected &&
-	test_cmp expected actual
-
-'
-
-test_expect_success 'amend commit to fix author' '
-
-	oldtick=$GIT_AUTHOR_DATE &&
-	test_tick &&
-	git reset --hard &&
-	git cat-file -p HEAD |
-	sed -e "s/author.*/author $author $oldtick/" \
-		-e "s/^\(committer.*> \).*$/\1$GIT_COMMITTER_DATE/" > \
-		expected &&
-	git commit --amend --author="$author" &&
-	git cat-file -p HEAD > current &&
-	test_cmp expected current
-
-'
-
-test_expect_success 'git commit <file> with dirty index' '
-	echo tacocat > elif &&
-	echo tehlulz > chz &&
-	git add chz &&
-	git commit elif -m "tacocat is a palindrome" &&
-	git show --stat | grep elif &&
-	git diff --cached | grep chz
-'
-
-test_expect_success 'same tree (single parent)' '
-
-	git reset --hard &&
-	test_must_fail git commit -m empty
-
-'
-
-test_expect_success 'same tree (single parent) --allow-empty' '
-
-	git commit --allow-empty -m "forced empty" &&
-	git cat-file commit HEAD | grep forced
-
-'
-
-test_expect_success 'same tree (merge and amend merge)' '
-
-	git checkout -b side HEAD^ &&
-	echo zero >zero &&
-	git add zero &&
-	git commit -m "add zero" &&
-	git checkout master &&
-
-	git merge -s ours side -m "empty ok" &&
-	git diff HEAD^ HEAD >actual &&
-	: >expected &&
-	test_cmp expected actual &&
-
-	git commit --amend -m "empty really ok" &&
-	git diff HEAD^ HEAD >actual &&
-	: >expected &&
-	test_cmp expected actual
-
-'
-
-test_expect_success 'amend using the message from another commit' '
-
-	git reset --hard &&
-	test_tick &&
-	git commit --allow-empty -m "old commit" &&
-	old=$(git rev-parse --verify HEAD) &&
-	test_tick &&
-	git commit --allow-empty -m "new commit" &&
-	new=$(git rev-parse --verify HEAD) &&
-	test_tick &&
-	git commit --allow-empty --amend -C "$old" &&
-	git show --pretty="format:%ad %s" "$old" >expected &&
-	git show --pretty="format:%ad %s" HEAD >actual &&
-	test_cmp expected actual
-
-'
-
-test_expect_success 'amend using the message from a commit named with tag' '
-
-	git reset --hard &&
-	test_tick &&
-	git commit --allow-empty -m "old commit" &&
-	old=$(git rev-parse --verify HEAD) &&
-	git tag -a -m "tag on old" tagged-old HEAD &&
-	test_tick &&
-	git commit --allow-empty -m "new commit" &&
-	new=$(git rev-parse --verify HEAD) &&
-	test_tick &&
-	git commit --allow-empty --amend -C tagged-old &&
-	git show --pretty="format:%ad %s" "$old" >expected &&
-	git show --pretty="format:%ad %s" HEAD >actual &&
-	test_cmp expected actual
-
-'
-
-test_expect_success 'amend can copy notes' '
-
-	git config notes.rewrite.amend true &&
-	git config notes.rewriteRef "refs/notes/*" &&
-	test_commit foo &&
-	git notes add -m"a note" &&
-	test_tick &&
-	git commit --amend -m"new foo" &&
-	test "$(git notes show)" = "a note"
-
-'
-
-test_expect_success 'commit a file whose name is a dash' '
-	git reset --hard &&
-	for i in 1 2 3 4 5
-	do
-		echo $i
-	done >./- &&
-	git add ./- &&
-	test_tick &&
-	git commit -m "add dash" >output </dev/null &&
-	test_i18ngrep " changed, 5 insertions" output
-'
-
-test_expect_success '--only works on to-be-born branch' '
-	# This test relies on having something in the index, as it
-	# would not otherwise actually prove much.  So check this.
-	test -n "$(git ls-files)" &&
-	git checkout --orphan orphan &&
-	echo foo >newfile &&
-	git add newfile &&
-	git commit --only newfile -m"--only on unborn branch" &&
-	echo newfile >expected &&
-	git ls-tree -r --name-only HEAD >actual &&
-	test_cmp expected actual
-'
-
-test_expect_success '--dry-run with conflicts fixed from a merge' '
-	# setup two branches with conflicting information
-	# in the same file, resolve the conflict,
-	# call commit with --dry-run
-	echo "Initial contents, unimportant" >test-file &&
-	git add test-file &&
-	git commit -m "Initial commit" &&
-	echo "commit-1-state" >test-file &&
-	git commit -m "commit 1" -i test-file &&
-	git tag commit-1 &&
-	git checkout -b branch-2 HEAD^1 &&
-	echo "commit-2-state" >test-file &&
-	git commit -m "commit 2" -i test-file &&
-	! $(git merge --no-commit commit-1) &&
-	echo "commit-2-state" >test-file &&
-	git add test-file &&
-	git commit --dry-run &&
-	git commit -m "conflicts fixed from merge."
-'
-
-test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t7502-commit-porcelain.sh 1.2.3+git2.25.1-1/git/t/t7502-commit-porcelain.sh
--- 1.2.1+git2.18.0-1/git/t/t7502-commit-porcelain.sh	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t7502-commit-porcelain.sh	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,628 @@
+#!/bin/sh
+
+test_description='git commit porcelain-ish'
+
+. ./test-lib.sh
+
+commit_msg_is () {
+	expect=commit_msg_is.expect
+	actual=commit_msg_is.actual
+
+	printf "%s" "$(git log --pretty=format:%s%b -1)" >$actual &&
+	printf "%s" "$1" >$expect &&
+	test_i18ncmp $expect $actual
+}
+
+# Arguments: [<prefix] [<commit message>] [<commit options>]
+check_summary_oneline() {
+	test_tick &&
+	git commit ${3+"$3"} -m "$2" >raw &&
+	head -n 1 raw >act &&
+
+	# branch name
+	SUMMARY_PREFIX="$(git name-rev --name-only HEAD)" &&
+
+	# append the "special" prefix, like "root-commit", "detached HEAD"
+	if test -n "$1"
+	then
+		SUMMARY_PREFIX="$SUMMARY_PREFIX ($1)"
+	fi
+
+	# abbrev SHA-1
+	SUMMARY_POSTFIX="$(git log -1 --pretty='format:%h')"
+	echo "[$SUMMARY_PREFIX $SUMMARY_POSTFIX] $2" >exp &&
+
+	test_i18ncmp exp act
+}
+
+test_expect_success 'output summary format' '
+
+	echo new >file1 &&
+	git add file1 &&
+	check_summary_oneline "root-commit" "initial" &&
+
+	echo change >>file1 &&
+	git add file1
+'
+
+test_expect_success 'output summary format: root-commit' '
+	check_summary_oneline "" "a change"
+'
+
+test_expect_success 'output summary format for commit with an empty diff' '
+
+	check_summary_oneline "" "empty" "--allow-empty"
+'
+
+test_expect_success 'output summary format for merges' '
+
+	git checkout -b recursive-base &&
+	test_commit base file1 &&
+
+	git checkout -b recursive-a recursive-base &&
+	test_commit commit-a file1 &&
+
+	git checkout -b recursive-b recursive-base &&
+	test_commit commit-b file1 &&
+
+	# conflict
+	git checkout recursive-a &&
+	test_must_fail git merge recursive-b &&
+	# resolve the conflict
+	echo commit-a >file1 &&
+	git add file1 &&
+	check_summary_oneline "" "Merge"
+'
+
+output_tests_cleanup() {
+	# this is needed for "do not fire editor in the presence of conflicts"
+	git checkout master &&
+
+	# this is needed for the "partial removal" test to pass
+	git rm file1 &&
+	git commit -m "cleanup"
+}
+
+test_expect_success 'the basics' '
+
+	output_tests_cleanup &&
+
+	echo doing partial >"commit is" &&
+	mkdir not &&
+	echo very much encouraged but we should >not/forbid &&
+	git add "commit is" not &&
+	echo update added "commit is" file >"commit is" &&
+	echo also update another >not/forbid &&
+	test_tick &&
+	git commit -a -m "initial with -a" &&
+
+	git cat-file blob HEAD:"commit is" >current.1 &&
+	git cat-file blob HEAD:not/forbid >current.2 &&
+
+	cmp current.1 "commit is" &&
+	cmp current.2 not/forbid
+
+'
+
+test_expect_success 'partial' '
+
+	echo another >"commit is" &&
+	echo another >not/forbid &&
+	test_tick &&
+	git commit -m "partial commit to handle a file" "commit is" &&
+
+	changed=$(git diff-tree --name-only HEAD^ HEAD) &&
+	test "$changed" = "commit is"
+
+'
+
+test_expect_success 'partial modification in a subdirectory' '
+
+	test_tick &&
+	git commit -m "partial commit to subdirectory" not &&
+
+	changed=$(git diff-tree -r --name-only HEAD^ HEAD) &&
+	test "$changed" = "not/forbid"
+
+'
+
+test_expect_success 'partial removal' '
+
+	git rm not/forbid &&
+	git commit -m "partial commit to remove not/forbid" not &&
+
+	changed=$(git diff-tree -r --name-only HEAD^ HEAD) &&
+	test "$changed" = "not/forbid" &&
+	remain=$(git ls-tree -r --name-only HEAD) &&
+	test "$remain" = "commit is"
+
+'
+
+test_expect_success 'sign off' '
+
+	>positive &&
+	git add positive &&
+	git commit -s -m "thank you" &&
+	git cat-file commit HEAD >commit.msg &&
+	sed -ne "s/Signed-off-by: //p" commit.msg >actual &&
+	git var GIT_COMMITTER_IDENT >ident &&
+	sed -e "s/>.*/>/" ident >expected &&
+	test_cmp expected actual
+
+'
+
+test_expect_success 'multiple -m' '
+
+	>negative &&
+	git add negative &&
+	git commit -m "one" -m "two" -m "three" &&
+	actual=$(git cat-file commit HEAD >tmp && sed -e "1,/^\$/d" tmp && rm tmp) &&
+	expected=$(test_write_lines "one" "" "two" "" "three") &&
+	test "z$actual" = "z$expected"
+
+'
+
+test_expect_success 'verbose' '
+
+	echo minus >negative &&
+	git add negative &&
+	git status -v >raw &&
+	sed -ne "/^diff --git /p" raw >actual &&
+	echo "diff --git a/negative b/negative" >expect &&
+	test_cmp expect actual
+
+'
+
+test_expect_success 'verbose respects diff config' '
+
+	test_config diff.noprefix true &&
+	git status -v >actual &&
+	grep "diff --git negative negative" actual
+'
+
+mesg_with_comment_and_newlines='
+# text
+
+'
+
+test_expect_success 'prepare file with comment line and trailing newlines'  '
+	printf "%s" "$mesg_with_comment_and_newlines" >expect
+'
+
+test_expect_success 'cleanup commit messages (verbatim option,-t)' '
+
+	echo >>negative &&
+	git commit --cleanup=verbatim --no-status -t expect -a &&
+	git cat-file -p HEAD >raw &&
+	sed -e "1,/^\$/d" raw >actual &&
+	test_cmp expect actual
+
+'
+
+test_expect_success 'cleanup commit messages (verbatim option,-F)' '
+
+	echo >>negative &&
+	git commit --cleanup=verbatim -F expect -a &&
+	git cat-file -p HEAD >raw &&
+	sed -e "1,/^\$/d" raw >actual &&
+	test_cmp expect actual
+
+'
+
+test_expect_success 'cleanup commit messages (verbatim option,-m)' '
+
+	echo >>negative &&
+	git commit --cleanup=verbatim -m "$mesg_with_comment_and_newlines" -a &&
+	git cat-file -p HEAD >raw &&
+	sed -e "1,/^\$/d" raw >actual &&
+	test_cmp expect actual
+
+'
+
+test_expect_success 'cleanup commit messages (whitespace option,-F)' '
+
+	echo >>negative &&
+	test_write_lines "" "# text" "" >text &&
+	echo "# text" >expect &&
+	git commit --cleanup=whitespace -F text -a &&
+	git cat-file -p HEAD >raw &&
+	sed -e "1,/^\$/d" raw >actual &&
+	test_cmp expect actual
+
+'
+
+test_expect_success 'cleanup commit messages (scissors option,-F,-e)' '
+
+	echo >>negative &&
+	cat >text <<-\EOF &&
+
+	# to be kept
+
+	  # ------------------------ >8 ------------------------
+	# to be kept, too
+	# ------------------------ >8 ------------------------
+	to be removed
+	# ------------------------ >8 ------------------------
+	to be removed, too
+	EOF
+
+	cat >expect <<-\EOF &&
+	# to be kept
+
+	  # ------------------------ >8 ------------------------
+	# to be kept, too
+	EOF
+	git commit --cleanup=scissors -e -F text -a &&
+	git cat-file -p HEAD >raw &&
+	sed -e "1,/^\$/d" raw >actual &&
+	test_cmp expect actual
+'
+
+test_expect_success 'cleanup commit messages (scissors option,-F,-e, scissors on first line)' '
+
+	echo >>negative &&
+	cat >text <<-\EOF &&
+	# ------------------------ >8 ------------------------
+	to be removed
+	EOF
+	git commit --cleanup=scissors -e -F text -a --allow-empty-message &&
+	git cat-file -p HEAD >raw &&
+	sed -e "1,/^\$/d" raw >actual &&
+	test_must_be_empty actual
+'
+
+test_expect_success 'cleanup commit messages (strip option,-F)' '
+
+	echo >>negative &&
+	test_write_lines "" "# text" "sample" "" >text &&
+	echo sample >expect &&
+	git commit --cleanup=strip -F text -a &&
+	git cat-file -p HEAD >raw &&
+	sed -e "1,/^\$/d" raw >actual &&
+	test_cmp expect actual
+
+'
+
+test_expect_success 'cleanup commit messages (strip option,-F,-e)' '
+
+	echo >>negative &&
+	test_write_lines "" "sample" "" >text &&
+	git commit -e -F text -a &&
+	head -n 4 .git/COMMIT_EDITMSG >actual
+'
+
+echo "sample
+
+# Please enter the commit message for your changes. Lines starting
+# with '#' will be ignored, and an empty message aborts the commit." >expect
+
+test_expect_success 'cleanup commit messages (strip option,-F,-e): output' '
+	test_i18ncmp expect actual
+'
+
+test_expect_success 'cleanup commit message (fail on invalid cleanup mode option)' '
+	test_must_fail git commit --cleanup=non-existent
+'
+
+test_expect_success 'cleanup commit message (fail on invalid cleanup mode configuration)' '
+	test_must_fail git -c commit.cleanup=non-existent commit
+'
+
+test_expect_success 'cleanup commit message (no config and no option uses default)' '
+	echo content >>file &&
+	git add file &&
+	(
+	  test_set_editor "$TEST_DIRECTORY"/t7500/add-content-and-comment &&
+	  git commit --no-status
+	) &&
+	commit_msg_is "commit message"
+'
+
+test_expect_success 'cleanup commit message (option overrides default)' '
+	echo content >>file &&
+	git add file &&
+	(
+	  test_set_editor "$TEST_DIRECTORY"/t7500/add-content-and-comment &&
+	  git commit --cleanup=whitespace --no-status
+	) &&
+	commit_msg_is "commit message # comment"
+'
+
+test_expect_success 'cleanup commit message (config overrides default)' '
+	echo content >>file &&
+	git add file &&
+	(
+	  test_set_editor "$TEST_DIRECTORY"/t7500/add-content-and-comment &&
+	  git -c commit.cleanup=whitespace commit --no-status
+	) &&
+	commit_msg_is "commit message # comment"
+'
+
+test_expect_success 'cleanup commit message (option overrides config)' '
+	echo content >>file &&
+	git add file &&
+	(
+	  test_set_editor "$TEST_DIRECTORY"/t7500/add-content-and-comment &&
+	  git -c commit.cleanup=whitespace commit --cleanup=default
+	) &&
+	commit_msg_is "commit message"
+'
+
+test_expect_success 'cleanup commit message (default, -m)' '
+	echo content >>file &&
+	git add file &&
+	git commit -m "message #comment " &&
+	commit_msg_is "message #comment"
+'
+
+test_expect_success 'cleanup commit message (whitespace option, -m)' '
+	echo content >>file &&
+	git add file &&
+	git commit --cleanup=whitespace --no-status -m "message #comment " &&
+	commit_msg_is "message #comment"
+'
+
+test_expect_success 'cleanup commit message (whitespace config, -m)' '
+	echo content >>file &&
+	git add file &&
+	git -c commit.cleanup=whitespace commit --no-status -m "message #comment " &&
+	commit_msg_is "message #comment"
+'
+
+test_expect_success 'message shows author when it is not equal to committer' '
+	echo >>negative &&
+	git commit -e -m "sample" -a &&
+	test_i18ngrep \
+	  "^# Author: *A U Thor <author@example.com>\$" \
+	  .git/COMMIT_EDITMSG
+'
+
+test_expect_success 'message shows date when it is explicitly set' '
+	git commit --allow-empty -e -m foo --date="2010-01-02T03:04:05" &&
+	test_i18ngrep \
+	  "^# Date: *Sat Jan 2 03:04:05 2010 +0000" \
+	  .git/COMMIT_EDITMSG
+'
+
+test_expect_success AUTOIDENT 'message shows committer when it is automatic' '
+
+	echo >>negative &&
+	(
+		sane_unset GIT_COMMITTER_EMAIL &&
+		sane_unset GIT_COMMITTER_NAME &&
+		git commit -e -m "sample" -a
+	) &&
+	# the ident is calculated from the system, so we cannot
+	# check the actual value, only that it is there
+	test_i18ngrep "^# Committer: " .git/COMMIT_EDITMSG
+'
+
+write_script .git/FAKE_EDITOR <<EOF
+echo editor started >"$(pwd)/.git/result"
+exit 0
+EOF
+
+test_expect_success !FAIL_PREREQS,!AUTOIDENT 'do not fire editor when committer is bogus' '
+	>.git/result &&
+
+	echo >>negative &&
+	(
+		sane_unset GIT_COMMITTER_EMAIL &&
+		sane_unset GIT_COMMITTER_NAME &&
+		GIT_EDITOR="\"$(pwd)/.git/FAKE_EDITOR\"" &&
+		export GIT_EDITOR &&
+		test_must_fail git commit -e -m sample -a
+	) &&
+	test_must_be_empty .git/result
+'
+
+test_expect_success 'do not fire editor if -m <msg> was given' '
+	echo tick >file &&
+	git add file &&
+	echo "editor not started" >.git/result &&
+	(GIT_EDITOR="\"$(pwd)/.git/FAKE_EDITOR\"" git commit -m tick) &&
+	test "$(cat .git/result)" = "editor not started"
+'
+
+test_expect_success 'do not fire editor if -m "" was given' '
+	echo tock >file &&
+	git add file &&
+	echo "editor not started" >.git/result &&
+	(GIT_EDITOR="\"$(pwd)/.git/FAKE_EDITOR\"" \
+	 git commit -m "" --allow-empty-message) &&
+	test "$(cat .git/result)" = "editor not started"
+'
+
+test_expect_success 'do not fire editor in the presence of conflicts' '
+
+	git clean -f &&
+	echo f >g &&
+	git add g &&
+	git commit -m "add g" &&
+	git branch second &&
+	echo master >g &&
+	echo g >h &&
+	git add g h &&
+	git commit -m "modify g and add h" &&
+	git checkout second &&
+	echo second >g &&
+	git add g &&
+	git commit -m second &&
+	# Must fail due to conflict
+	test_must_fail git cherry-pick -n master &&
+	echo "editor not started" >.git/result &&
+	(
+		GIT_EDITOR="\"$(pwd)/.git/FAKE_EDITOR\"" &&
+		export GIT_EDITOR &&
+		test_must_fail git commit
+	) &&
+	test "$(cat .git/result)" = "editor not started"
+'
+
+write_script .git/FAKE_EDITOR <<EOF
+# kill -TERM command added below.
+EOF
+
+test_expect_success EXECKEEPSPID 'a SIGTERM should break locks' '
+	echo >>negative &&
+	! "$SHELL_PATH" -c '\''
+	  echo kill -TERM $$ >>.git/FAKE_EDITOR
+	  GIT_EDITOR=.git/FAKE_EDITOR
+	  export GIT_EDITOR
+	  exec git commit -a'\'' &&
+	test ! -f .git/index.lock
+'
+
+rm -f .git/MERGE_MSG .git/COMMIT_EDITMSG
+git reset -q --hard
+
+test_expect_success 'Hand committing of a redundant merge removes dups' '
+
+	git rev-parse second master >expect &&
+	test_must_fail git merge second master &&
+	git checkout master g &&
+	EDITOR=: git commit -a &&
+	git cat-file commit HEAD >raw &&
+	sed -n -e "s/^parent //p" -e "/^$/q" raw >actual &&
+	test_cmp expect actual
+
+'
+
+test_expect_success 'A single-liner subject with a token plus colon is not a footer' '
+
+	git reset --hard &&
+	git commit -s -m "hello: kitty" --allow-empty &&
+	git cat-file commit HEAD >raw &&
+	sed -e "1,/^$/d" raw >actual &&
+	test_line_count = 3 actual
+
+'
+
+test_expect_success 'commit -s places sob on third line after two empty lines' '
+	git commit -s --allow-empty --allow-empty-message &&
+	cat <<-EOF >expect &&
+
+
+	Signed-off-by: $GIT_COMMITTER_NAME <$GIT_COMMITTER_EMAIL>
+
+	EOF
+	sed -e "/^#/d" -e "s/^:.*//" .git/COMMIT_EDITMSG >actual &&
+	test_cmp expect actual
+'
+
+write_script .git/FAKE_EDITOR <<\EOF
+mv "$1" "$1.orig"
+(
+	echo message
+	cat "$1.orig"
+) >"$1"
+EOF
+
+echo '## Custom template' >template
+
+try_commit () {
+	git reset --hard &&
+	echo >>negative &&
+	GIT_EDITOR=.git/FAKE_EDITOR git commit -a $* $use_template &&
+	case "$use_template" in
+	'')
+		test_i18ngrep ! "^## Custom template" .git/COMMIT_EDITMSG ;;
+	*)
+		test_i18ngrep "^## Custom template" .git/COMMIT_EDITMSG ;;
+	esac
+}
+
+try_commit_status_combo () {
+
+	test_expect_success 'commit' '
+		try_commit "" &&
+		test_i18ngrep "^# Changes to be committed:" .git/COMMIT_EDITMSG
+	'
+
+	test_expect_success 'commit --status' '
+		try_commit --status &&
+		test_i18ngrep "^# Changes to be committed:" .git/COMMIT_EDITMSG
+	'
+
+	test_expect_success 'commit --no-status' '
+		try_commit --no-status &&
+		test_i18ngrep ! "^# Changes to be committed:" .git/COMMIT_EDITMSG
+	'
+
+	test_expect_success 'commit with commit.status = yes' '
+		test_config commit.status yes &&
+		try_commit "" &&
+		test_i18ngrep "^# Changes to be committed:" .git/COMMIT_EDITMSG
+	'
+
+	test_expect_success 'commit with commit.status = no' '
+		test_config commit.status no &&
+		try_commit "" &&
+		test_i18ngrep ! "^# Changes to be committed:" .git/COMMIT_EDITMSG
+	'
+
+	test_expect_success 'commit --status with commit.status = yes' '
+		test_config commit.status yes &&
+		try_commit --status &&
+		test_i18ngrep "^# Changes to be committed:" .git/COMMIT_EDITMSG
+	'
+
+	test_expect_success 'commit --no-status with commit.status = yes' '
+		test_config commit.status yes &&
+		try_commit --no-status &&
+		test_i18ngrep ! "^# Changes to be committed:" .git/COMMIT_EDITMSG
+	'
+
+	test_expect_success 'commit --status with commit.status = no' '
+		test_config commit.status no &&
+		try_commit --status &&
+		test_i18ngrep "^# Changes to be committed:" .git/COMMIT_EDITMSG
+	'
+
+	test_expect_success 'commit --no-status with commit.status = no' '
+		test_config commit.status no &&
+		try_commit --no-status &&
+		test_i18ngrep ! "^# Changes to be committed:" .git/COMMIT_EDITMSG
+	'
+
+}
+
+try_commit_status_combo
+
+use_template="-t template"
+
+try_commit_status_combo
+
+test_expect_success 'commit --status with custom comment character' '
+	test_config core.commentchar ";" &&
+	try_commit --status &&
+	test_i18ngrep "^; Changes to be committed:" .git/COMMIT_EDITMSG
+'
+
+test_expect_success 'switch core.commentchar' '
+	test_commit "#foo" foo &&
+	GIT_EDITOR=.git/FAKE_EDITOR git -c core.commentChar=auto commit --amend &&
+	test_i18ngrep "^; Changes to be committed:" .git/COMMIT_EDITMSG
+'
+
+test_expect_success 'switch core.commentchar but out of options' '
+	cat >text <<\EOF &&
+# 1
+; 2
+@ 3
+! 4
+$ 5
+% 6
+^ 7
+& 8
+| 9
+: 10
+EOF
+	git commit --amend -F text &&
+	(
+		test_set_editor .git/FAKE_EDITOR &&
+		test_must_fail git -c core.commentChar=auto commit --amend
+	)
+'
+
+test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t7502-commit.sh 1.2.3+git2.25.1-1/git/t/t7502-commit.sh
--- 1.2.1+git2.18.0-1/git/t/t7502-commit.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t7502-commit.sh	1970-01-01 00:00:00.000000000 +0000
@@ -1,616 +0,0 @@
-#!/bin/sh
-
-test_description='git commit porcelain-ish'
-
-. ./test-lib.sh
-
-commit_msg_is () {
-	expect=commit_msg_is.expect
-	actual=commit_msg_is.actual
-
-	printf "%s" "$(git log --pretty=format:%s%b -1)" >$actual &&
-	printf "%s" "$1" >$expect &&
-	test_i18ncmp $expect $actual
-}
-
-# Arguments: [<prefix] [<commit message>] [<commit options>]
-check_summary_oneline() {
-	test_tick &&
-	git commit ${3+"$3"} -m "$2" | head -1 > act &&
-
-	# branch name
-	SUMMARY_PREFIX="$(git name-rev --name-only HEAD)" &&
-
-	# append the "special" prefix, like "root-commit", "detached HEAD"
-	if test -n "$1"
-	then
-		SUMMARY_PREFIX="$SUMMARY_PREFIX ($1)"
-	fi
-
-	# abbrev SHA-1
-	SUMMARY_POSTFIX="$(git log -1 --pretty='format:%h')"
-	echo "[$SUMMARY_PREFIX $SUMMARY_POSTFIX] $2" >exp &&
-
-	test_i18ncmp exp act
-}
-
-test_expect_success 'output summary format' '
-
-	echo new >file1 &&
-	git add file1 &&
-	check_summary_oneline "root-commit" "initial" &&
-
-	echo change >>file1 &&
-	git add file1
-'
-
-test_expect_success 'output summary format: root-commit' '
-	check_summary_oneline "" "a change"
-'
-
-test_expect_success 'output summary format for commit with an empty diff' '
-
-	check_summary_oneline "" "empty" "--allow-empty"
-'
-
-test_expect_success 'output summary format for merges' '
-
-	git checkout -b recursive-base &&
-	test_commit base file1 &&
-
-	git checkout -b recursive-a recursive-base &&
-	test_commit commit-a file1 &&
-
-	git checkout -b recursive-b recursive-base &&
-	test_commit commit-b file1 &&
-
-	# conflict
-	git checkout recursive-a &&
-	test_must_fail git merge recursive-b &&
-	# resolve the conflict
-	echo commit-a > file1 &&
-	git add file1 &&
-	check_summary_oneline "" "Merge"
-'
-
-output_tests_cleanup() {
-	# this is needed for "do not fire editor in the presence of conflicts"
-	git checkout master &&
-
-	# this is needed for the "partial removal" test to pass
-	git rm file1 &&
-	git commit -m "cleanup"
-}
-
-test_expect_success 'the basics' '
-
-	output_tests_cleanup &&
-
-	echo doing partial >"commit is" &&
-	mkdir not &&
-	echo very much encouraged but we should >not/forbid &&
-	git add "commit is" not &&
-	echo update added "commit is" file >"commit is" &&
-	echo also update another >not/forbid &&
-	test_tick &&
-	git commit -a -m "initial with -a" &&
-
-	git cat-file blob HEAD:"commit is" >current.1 &&
-	git cat-file blob HEAD:not/forbid >current.2 &&
-
-	cmp current.1 "commit is" &&
-	cmp current.2 not/forbid
-
-'
-
-test_expect_success 'partial' '
-
-	echo another >"commit is" &&
-	echo another >not/forbid &&
-	test_tick &&
-	git commit -m "partial commit to handle a file" "commit is" &&
-
-	changed=$(git diff-tree --name-only HEAD^ HEAD) &&
-	test "$changed" = "commit is"
-
-'
-
-test_expect_success 'partial modification in a subdirectory' '
-
-	test_tick &&
-	git commit -m "partial commit to subdirectory" not &&
-
-	changed=$(git diff-tree -r --name-only HEAD^ HEAD) &&
-	test "$changed" = "not/forbid"
-
-'
-
-test_expect_success 'partial removal' '
-
-	git rm not/forbid &&
-	git commit -m "partial commit to remove not/forbid" not &&
-
-	changed=$(git diff-tree -r --name-only HEAD^ HEAD) &&
-	test "$changed" = "not/forbid" &&
-	remain=$(git ls-tree -r --name-only HEAD) &&
-	test "$remain" = "commit is"
-
-'
-
-test_expect_success 'sign off' '
-
-	>positive &&
-	git add positive &&
-	git commit -s -m "thank you" &&
-	actual=$(git cat-file commit HEAD | sed -ne "s/Signed-off-by: //p") &&
-	expected=$(git var GIT_COMMITTER_IDENT | sed -e "s/>.*/>/") &&
-	test "z$actual" = "z$expected"
-
-'
-
-test_expect_success 'multiple -m' '
-
-	>negative &&
-	git add negative &&
-	git commit -m "one" -m "two" -m "three" &&
-	actual=$(git cat-file commit HEAD | sed -e "1,/^\$/d") &&
-	expected=$(echo one; echo; echo two; echo; echo three) &&
-	test "z$actual" = "z$expected"
-
-'
-
-test_expect_success 'verbose' '
-
-	echo minus >negative &&
-	git add negative &&
-	git status -v | sed -ne "/^diff --git /p" >actual &&
-	echo "diff --git a/negative b/negative" >expect &&
-	test_cmp expect actual
-
-'
-
-test_expect_success 'verbose respects diff config' '
-
-	test_config diff.noprefix true &&
-	git status -v >actual &&
-	grep "diff --git negative negative" actual
-'
-
-mesg_with_comment_and_newlines='
-# text
-
-'
-
-test_expect_success 'prepare file with comment line and trailing newlines'  '
-	printf "%s" "$mesg_with_comment_and_newlines" >expect
-'
-
-test_expect_success 'cleanup commit messages (verbatim option,-t)' '
-
-	echo >>negative &&
-	git commit --cleanup=verbatim --no-status -t expect -a &&
-	git cat-file -p HEAD |sed -e "1,/^\$/d" >actual &&
-	test_cmp expect actual
-
-'
-
-test_expect_success 'cleanup commit messages (verbatim option,-F)' '
-
-	echo >>negative &&
-	git commit --cleanup=verbatim -F expect -a &&
-	git cat-file -p HEAD |sed -e "1,/^\$/d">actual &&
-	test_cmp expect actual
-
-'
-
-test_expect_success 'cleanup commit messages (verbatim option,-m)' '
-
-	echo >>negative &&
-	git commit --cleanup=verbatim -m "$mesg_with_comment_and_newlines" -a &&
-	git cat-file -p HEAD |sed -e "1,/^\$/d">actual &&
-	test_cmp expect actual
-
-'
-
-test_expect_success 'cleanup commit messages (whitespace option,-F)' '
-
-	echo >>negative &&
-	{ echo;echo "# text";echo; } >text &&
-	echo "# text" >expect &&
-	git commit --cleanup=whitespace -F text -a &&
-	git cat-file -p HEAD |sed -e "1,/^\$/d">actual &&
-	test_cmp expect actual
-
-'
-
-test_expect_success 'cleanup commit messages (scissors option,-F,-e)' '
-
-	echo >>negative &&
-	cat >text <<EOF &&
-
-# to be kept
-
-  # ------------------------ >8 ------------------------
-# to be kept, too
-# ------------------------ >8 ------------------------
-to be removed
-# ------------------------ >8 ------------------------
-to be removed, too
-EOF
-
-	cat >expect <<EOF &&
-# to be kept
-
-  # ------------------------ >8 ------------------------
-# to be kept, too
-EOF
-	git commit --cleanup=scissors -e -F text -a &&
-	git cat-file -p HEAD |sed -e "1,/^\$/d">actual &&
-	test_cmp expect actual
-'
-
-test_expect_success 'cleanup commit messages (scissors option,-F,-e, scissors on first line)' '
-
-	echo >>negative &&
-	cat >text <<EOF &&
-# ------------------------ >8 ------------------------
-to be removed
-EOF
-	git commit --cleanup=scissors -e -F text -a --allow-empty-message &&
-	git cat-file -p HEAD |sed -e "1,/^\$/d">actual &&
-	test_must_be_empty actual
-'
-
-test_expect_success 'cleanup commit messages (strip option,-F)' '
-
-	echo >>negative &&
-	{ echo;echo "# text";echo sample;echo; } >text &&
-	echo sample >expect &&
-	git commit --cleanup=strip -F text -a &&
-	git cat-file -p HEAD |sed -e "1,/^\$/d">actual &&
-	test_cmp expect actual
-
-'
-
-test_expect_success 'cleanup commit messages (strip option,-F,-e)' '
-
-	echo >>negative &&
-	{ echo;echo sample;echo; } >text &&
-	git commit -e -F text -a &&
-	head -n 4 .git/COMMIT_EDITMSG >actual
-'
-
-echo "sample
-
-# Please enter the commit message for your changes. Lines starting
-# with '#' will be ignored, and an empty message aborts the commit." >expect
-
-test_expect_success 'cleanup commit messages (strip option,-F,-e): output' '
-	test_i18ncmp expect actual
-'
-
-test_expect_success 'cleanup commit message (fail on invalid cleanup mode option)' '
-	test_must_fail git commit --cleanup=non-existent
-'
-
-test_expect_success 'cleanup commit message (fail on invalid cleanup mode configuration)' '
-	test_must_fail git -c commit.cleanup=non-existent commit
-'
-
-test_expect_success 'cleanup commit message (no config and no option uses default)' '
-	echo content >>file &&
-	git add file &&
-	(
-	  test_set_editor "$TEST_DIRECTORY"/t7500/add-content-and-comment &&
-	  git commit --no-status
-	) &&
-	commit_msg_is "commit message"
-'
-
-test_expect_success 'cleanup commit message (option overrides default)' '
-	echo content >>file &&
-	git add file &&
-	(
-	  test_set_editor "$TEST_DIRECTORY"/t7500/add-content-and-comment &&
-	  git commit --cleanup=whitespace --no-status
-	) &&
-	commit_msg_is "commit message # comment"
-'
-
-test_expect_success 'cleanup commit message (config overrides default)' '
-	echo content >>file &&
-	git add file &&
-	(
-	  test_set_editor "$TEST_DIRECTORY"/t7500/add-content-and-comment &&
-	  git -c commit.cleanup=whitespace commit --no-status
-	) &&
-	commit_msg_is "commit message # comment"
-'
-
-test_expect_success 'cleanup commit message (option overrides config)' '
-	echo content >>file &&
-	git add file &&
-	(
-	  test_set_editor "$TEST_DIRECTORY"/t7500/add-content-and-comment &&
-	  git -c commit.cleanup=whitespace commit --cleanup=default
-	) &&
-	commit_msg_is "commit message"
-'
-
-test_expect_success 'cleanup commit message (default, -m)' '
-	echo content >>file &&
-	git add file &&
-	git commit -m "message #comment " &&
-	commit_msg_is "message #comment"
-'
-
-test_expect_success 'cleanup commit message (whitespace option, -m)' '
-	echo content >>file &&
-	git add file &&
-	git commit --cleanup=whitespace --no-status -m "message #comment " &&
-	commit_msg_is "message #comment"
-'
-
-test_expect_success 'cleanup commit message (whitespace config, -m)' '
-	echo content >>file &&
-	git add file &&
-	git -c commit.cleanup=whitespace commit --no-status -m "message #comment " &&
-	commit_msg_is "message #comment"
-'
-
-test_expect_success 'message shows author when it is not equal to committer' '
-	echo >>negative &&
-	git commit -e -m "sample" -a &&
-	test_i18ngrep \
-	  "^# Author: *A U Thor <author@example.com>\$" \
-	  .git/COMMIT_EDITMSG
-'
-
-test_expect_success 'message shows date when it is explicitly set' '
-	git commit --allow-empty -e -m foo --date="2010-01-02T03:04:05" &&
-	test_i18ngrep \
-	  "^# Date: *Sat Jan 2 03:04:05 2010 +0000" \
-	  .git/COMMIT_EDITMSG
-'
-
-test_expect_success AUTOIDENT 'message shows committer when it is automatic' '
-
-	echo >>negative &&
-	(
-		sane_unset GIT_COMMITTER_EMAIL &&
-		sane_unset GIT_COMMITTER_NAME &&
-		git commit -e -m "sample" -a
-	) &&
-	# the ident is calculated from the system, so we cannot
-	# check the actual value, only that it is there
-	test_i18ngrep "^# Committer: " .git/COMMIT_EDITMSG
-'
-
-write_script .git/FAKE_EDITOR <<EOF
-echo editor started > "$(pwd)/.git/result"
-exit 0
-EOF
-
-test_expect_success !AUTOIDENT 'do not fire editor when committer is bogus' '
-	>.git/result &&
-	>expect &&
-
-	echo >>negative &&
-	(
-		sane_unset GIT_COMMITTER_EMAIL &&
-		sane_unset GIT_COMMITTER_NAME &&
-		GIT_EDITOR="\"$(pwd)/.git/FAKE_EDITOR\"" &&
-		export GIT_EDITOR &&
-		test_must_fail git commit -e -m sample -a
-	) &&
-	test_cmp expect .git/result
-'
-
-test_expect_success 'do not fire editor if -m <msg> was given' '
-	echo tick >file &&
-	git add file &&
-	echo "editor not started" >.git/result &&
-	(GIT_EDITOR="\"$(pwd)/.git/FAKE_EDITOR\"" git commit -m tick) &&
-	test "$(cat .git/result)" = "editor not started"
-'
-
-test_expect_success 'do not fire editor if -m "" was given' '
-	echo tock >file &&
-	git add file &&
-	echo "editor not started" >.git/result &&
-	(GIT_EDITOR="\"$(pwd)/.git/FAKE_EDITOR\"" \
-	 git commit -m "" --allow-empty-message) &&
-	test "$(cat .git/result)" = "editor not started"
-'
-
-test_expect_success 'do not fire editor in the presence of conflicts' '
-
-	git clean -f &&
-	echo f >g &&
-	git add g &&
-	git commit -m "add g" &&
-	git branch second &&
-	echo master >g &&
-	echo g >h &&
-	git add g h &&
-	git commit -m "modify g and add h" &&
-	git checkout second &&
-	echo second >g &&
-	git add g &&
-	git commit -m second &&
-	# Must fail due to conflict
-	test_must_fail git cherry-pick -n master &&
-	echo "editor not started" >.git/result &&
-	(
-		GIT_EDITOR="\"$(pwd)/.git/FAKE_EDITOR\"" &&
-		export GIT_EDITOR &&
-		test_must_fail git commit
-	) &&
-	test "$(cat .git/result)" = "editor not started"
-'
-
-write_script .git/FAKE_EDITOR <<EOF
-# kill -TERM command added below.
-EOF
-
-test_expect_success EXECKEEPSPID 'a SIGTERM should break locks' '
-	echo >>negative &&
-	! "$SHELL_PATH" -c '\''
-	  echo kill -TERM $$ >> .git/FAKE_EDITOR
-	  GIT_EDITOR=.git/FAKE_EDITOR
-	  export GIT_EDITOR
-	  exec git commit -a'\'' &&
-	test ! -f .git/index.lock
-'
-
-rm -f .git/MERGE_MSG .git/COMMIT_EDITMSG
-git reset -q --hard
-
-test_expect_success 'Hand committing of a redundant merge removes dups' '
-
-	git rev-parse second master >expect &&
-	test_must_fail git merge second master &&
-	git checkout master g &&
-	EDITOR=: git commit -a &&
-	git cat-file commit HEAD | sed -n -e "s/^parent //p" -e "/^$/q" >actual &&
-	test_cmp expect actual
-
-'
-
-test_expect_success 'A single-liner subject with a token plus colon is not a footer' '
-
-	git reset --hard &&
-	git commit -s -m "hello: kitty" --allow-empty &&
-	git cat-file commit HEAD | sed -e "1,/^$/d" >actual &&
-	test_line_count = 3 actual
-
-'
-
-test_expect_success 'commit -s places sob on third line after two empty lines' '
-	git commit -s --allow-empty --allow-empty-message &&
-	cat <<-EOF >expect &&
-
-
-	Signed-off-by: $GIT_COMMITTER_NAME <$GIT_COMMITTER_EMAIL>
-
-	EOF
-	sed -e "/^#/d" -e "s/^:.*//" .git/COMMIT_EDITMSG >actual &&
-	test_cmp expect actual
-'
-
-write_script .git/FAKE_EDITOR <<\EOF
-mv "$1" "$1.orig"
-(
-	echo message
-	cat "$1.orig"
-) >"$1"
-EOF
-
-echo '## Custom template' >template
-
-try_commit () {
-	git reset --hard &&
-	echo >>negative &&
-	GIT_EDITOR=.git/FAKE_EDITOR git commit -a $* $use_template &&
-	case "$use_template" in
-	'')
-		test_i18ngrep ! "^## Custom template" .git/COMMIT_EDITMSG ;;
-	*)
-		test_i18ngrep "^## Custom template" .git/COMMIT_EDITMSG ;;
-	esac
-}
-
-try_commit_status_combo () {
-
-	test_expect_success 'commit' '
-		try_commit "" &&
-		test_i18ngrep "^# Changes to be committed:" .git/COMMIT_EDITMSG
-	'
-
-	test_expect_success 'commit --status' '
-		try_commit --status &&
-		test_i18ngrep "^# Changes to be committed:" .git/COMMIT_EDITMSG
-	'
-
-	test_expect_success 'commit --no-status' '
-		try_commit --no-status &&
-		test_i18ngrep ! "^# Changes to be committed:" .git/COMMIT_EDITMSG
-	'
-
-	test_expect_success 'commit with commit.status = yes' '
-		test_config commit.status yes &&
-		try_commit "" &&
-		test_i18ngrep "^# Changes to be committed:" .git/COMMIT_EDITMSG
-	'
-
-	test_expect_success 'commit with commit.status = no' '
-		test_config commit.status no &&
-		try_commit "" &&
-		test_i18ngrep ! "^# Changes to be committed:" .git/COMMIT_EDITMSG
-	'
-
-	test_expect_success 'commit --status with commit.status = yes' '
-		test_config commit.status yes &&
-		try_commit --status &&
-		test_i18ngrep "^# Changes to be committed:" .git/COMMIT_EDITMSG
-	'
-
-	test_expect_success 'commit --no-status with commit.status = yes' '
-		test_config commit.status yes &&
-		try_commit --no-status &&
-		test_i18ngrep ! "^# Changes to be committed:" .git/COMMIT_EDITMSG
-	'
-
-	test_expect_success 'commit --status with commit.status = no' '
-		test_config commit.status no &&
-		try_commit --status &&
-		test_i18ngrep "^# Changes to be committed:" .git/COMMIT_EDITMSG
-	'
-
-	test_expect_success 'commit --no-status with commit.status = no' '
-		test_config commit.status no &&
-		try_commit --no-status &&
-		test_i18ngrep ! "^# Changes to be committed:" .git/COMMIT_EDITMSG
-	'
-
-}
-
-try_commit_status_combo
-
-use_template="-t template"
-
-try_commit_status_combo
-
-test_expect_success 'commit --status with custom comment character' '
-	test_config core.commentchar ";" &&
-	try_commit --status &&
-	test_i18ngrep "^; Changes to be committed:" .git/COMMIT_EDITMSG
-'
-
-test_expect_success 'switch core.commentchar' '
-	test_commit "#foo" foo &&
-	GIT_EDITOR=.git/FAKE_EDITOR git -c core.commentChar=auto commit --amend &&
-	test_i18ngrep "^; Changes to be committed:" .git/COMMIT_EDITMSG
-'
-
-test_expect_success 'switch core.commentchar but out of options' '
-	cat >text <<\EOF &&
-# 1
-; 2
-@ 3
-! 4
-$ 5
-% 6
-^ 7
-& 8
-| 9
-: 10
-EOF
-	git commit --amend -F text &&
-	(
-		test_set_editor .git/FAKE_EDITOR &&
-		test_must_fail git -c core.commentChar=auto commit --amend
-	)
-'
-
-test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t7503-pre-commit-and-pre-merge-commit-hooks.sh 1.2.3+git2.25.1-1/git/t/t7503-pre-commit-and-pre-merge-commit-hooks.sh
--- 1.2.1+git2.18.0-1/git/t/t7503-pre-commit-and-pre-merge-commit-hooks.sh	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t7503-pre-commit-and-pre-merge-commit-hooks.sh	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,281 @@
+#!/bin/sh
+
+test_description='pre-commit and pre-merge-commit hooks'
+
+. ./test-lib.sh
+
+HOOKDIR="$(git rev-parse --git-dir)/hooks"
+PRECOMMIT="$HOOKDIR/pre-commit"
+PREMERGE="$HOOKDIR/pre-merge-commit"
+
+# Prepare sample scripts that write their $0 to actual_hooks
+test_expect_success 'sample script setup' '
+	mkdir -p "$HOOKDIR" &&
+	write_script "$HOOKDIR/success.sample" <<-\EOF &&
+	echo $0 >>actual_hooks
+	exit 0
+	EOF
+	write_script "$HOOKDIR/fail.sample" <<-\EOF &&
+	echo $0 >>actual_hooks
+	exit 1
+	EOF
+	write_script "$HOOKDIR/non-exec.sample" <<-\EOF &&
+	echo $0 >>actual_hooks
+	exit 1
+	EOF
+	chmod -x "$HOOKDIR/non-exec.sample" &&
+	write_script "$HOOKDIR/require-prefix.sample" <<-\EOF &&
+	echo $0 >>actual_hooks
+	test $GIT_PREFIX = "success/"
+	EOF
+	write_script "$HOOKDIR/check-author.sample" <<-\EOF
+	echo $0 >>actual_hooks
+	test "$GIT_AUTHOR_NAME" = "New Author" &&
+	test "$GIT_AUTHOR_EMAIL" = "newauthor@example.com"
+	EOF
+'
+
+test_expect_success 'root commit' '
+	echo "root" >file &&
+	git add file &&
+	git commit -m "zeroth" &&
+	git checkout -b side &&
+	echo "foo" >foo &&
+	git add foo &&
+	git commit -m "make it non-ff" &&
+	git branch side-orig side &&
+	git checkout master
+'
+
+test_expect_success 'setup conflicting branches' '
+	test_when_finished "git checkout master" &&
+	git checkout -b conflicting-a master &&
+	echo a >conflicting &&
+	git add conflicting &&
+	git commit -m conflicting-a &&
+	git checkout -b conflicting-b master &&
+	echo b >conflicting &&
+	git add conflicting &&
+	git commit -m conflicting-b
+'
+
+test_expect_success 'with no hook' '
+	test_when_finished "rm -f actual_hooks" &&
+	echo "foo" >file &&
+	git add file &&
+	git commit -m "first" &&
+	test_path_is_missing actual_hooks
+'
+
+test_expect_success 'with no hook (merge)' '
+	test_when_finished "rm -f actual_hooks" &&
+	git branch -f side side-orig &&
+	git checkout side &&
+	git merge -m "merge master" master &&
+	git checkout master &&
+	test_path_is_missing actual_hooks
+'
+
+test_expect_success '--no-verify with no hook' '
+	test_when_finished "rm -f actual_hooks" &&
+	echo "bar" >file &&
+	git add file &&
+	git commit --no-verify -m "bar" &&
+	test_path_is_missing actual_hooks
+'
+
+test_expect_success '--no-verify with no hook (merge)' '
+	test_when_finished "rm -f actual_hooks" &&
+	git branch -f side side-orig &&
+	git checkout side &&
+	git merge --no-verify -m "merge master" master &&
+	git checkout master &&
+	test_path_is_missing actual_hooks
+'
+
+test_expect_success 'with succeeding hook' '
+	test_when_finished "rm -f \"$PRECOMMIT\" expected_hooks actual_hooks" &&
+	cp "$HOOKDIR/success.sample" "$PRECOMMIT" &&
+	echo "$PRECOMMIT" >expected_hooks &&
+	echo "more" >>file &&
+	git add file &&
+	git commit -m "more" &&
+	test_cmp expected_hooks actual_hooks
+'
+
+test_expect_success 'with succeeding hook (merge)' '
+	test_when_finished "rm -f \"$PREMERGE\" expected_hooks actual_hooks" &&
+	cp "$HOOKDIR/success.sample" "$PREMERGE" &&
+	echo "$PREMERGE" >expected_hooks &&
+	git checkout side &&
+	git merge -m "merge master" master &&
+	git checkout master &&
+	test_cmp expected_hooks actual_hooks
+'
+
+test_expect_success 'automatic merge fails; both hooks are available' '
+	test_when_finished "rm -f \"$PREMERGE\" \"$PRECOMMIT\"" &&
+	test_when_finished "rm -f expected_hooks actual_hooks" &&
+	test_when_finished "git checkout master" &&
+	cp "$HOOKDIR/success.sample" "$PREMERGE" &&
+	cp "$HOOKDIR/success.sample" "$PRECOMMIT" &&
+
+	git checkout conflicting-a &&
+	test_must_fail git merge -m "merge conflicting-b" conflicting-b &&
+	test_path_is_missing actual_hooks &&
+
+	echo "$PRECOMMIT" >expected_hooks &&
+	echo a+b >conflicting &&
+	git add conflicting &&
+	git commit -m "resolve conflict" &&
+	test_cmp expected_hooks actual_hooks
+'
+
+test_expect_success '--no-verify with succeeding hook' '
+	test_when_finished "rm -f \"$PRECOMMIT\" actual_hooks" &&
+	cp "$HOOKDIR/success.sample" "$PRECOMMIT" &&
+	echo "even more" >>file &&
+	git add file &&
+	git commit --no-verify -m "even more" &&
+	test_path_is_missing actual_hooks
+'
+
+test_expect_success '--no-verify with succeeding hook (merge)' '
+	test_when_finished "rm -f \"$PREMERGE\" actual_hooks" &&
+	cp "$HOOKDIR/success.sample" "$PREMERGE" &&
+	git branch -f side side-orig &&
+	git checkout side &&
+	git merge --no-verify -m "merge master" master &&
+	git checkout master &&
+	test_path_is_missing actual_hooks
+'
+
+test_expect_success 'with failing hook' '
+	test_when_finished "rm -f \"$PRECOMMIT\" expected_hooks actual_hooks" &&
+	cp "$HOOKDIR/fail.sample" "$PRECOMMIT" &&
+	echo "$PRECOMMIT" >expected_hooks &&
+	echo "another" >>file &&
+	git add file &&
+	test_must_fail git commit -m "another" &&
+	test_cmp expected_hooks actual_hooks
+'
+
+test_expect_success '--no-verify with failing hook' '
+	test_when_finished "rm -f \"$PRECOMMIT\" actual_hooks" &&
+	cp "$HOOKDIR/fail.sample" "$PRECOMMIT" &&
+	echo "stuff" >>file &&
+	git add file &&
+	git commit --no-verify -m "stuff" &&
+	test_path_is_missing actual_hooks
+'
+
+test_expect_success 'with failing hook (merge)' '
+	test_when_finished "rm -f \"$PREMERGE\" expected_hooks actual_hooks" &&
+	cp "$HOOKDIR/fail.sample" "$PREMERGE" &&
+	echo "$PREMERGE" >expected_hooks &&
+	git checkout side &&
+	test_must_fail git merge -m "merge master" master &&
+	git checkout master &&
+	test_cmp expected_hooks actual_hooks
+'
+
+test_expect_success '--no-verify with failing hook (merge)' '
+	test_when_finished "rm -f \"$PREMERGE\" actual_hooks" &&
+	cp "$HOOKDIR/fail.sample" "$PREMERGE" &&
+	git branch -f side side-orig &&
+	git checkout side &&
+	git merge --no-verify -m "merge master" master &&
+	git checkout master &&
+	test_path_is_missing actual_hooks
+'
+
+test_expect_success POSIXPERM 'with non-executable hook' '
+	test_when_finished "rm -f \"$PRECOMMIT\" actual_hooks" &&
+	cp "$HOOKDIR/non-exec.sample" "$PRECOMMIT" &&
+	echo "content" >>file &&
+	git add file &&
+	git commit -m "content" &&
+	test_path_is_missing actual_hooks
+'
+
+test_expect_success POSIXPERM '--no-verify with non-executable hook' '
+	test_when_finished "rm -f \"$PRECOMMIT\" actual_hooks" &&
+	cp "$HOOKDIR/non-exec.sample" "$PRECOMMIT" &&
+	echo "more content" >>file &&
+	git add file &&
+	git commit --no-verify -m "more content" &&
+	test_path_is_missing actual_hooks
+'
+
+test_expect_success POSIXPERM 'with non-executable hook (merge)' '
+	test_when_finished "rm -f \"$PREMERGE\" actual_hooks" &&
+	cp "$HOOKDIR/non-exec.sample" "$PREMERGE" &&
+	git branch -f side side-orig &&
+	git checkout side &&
+	git merge -m "merge master" master &&
+	git checkout master &&
+	test_path_is_missing actual_hooks
+'
+
+test_expect_success POSIXPERM '--no-verify with non-executable hook (merge)' '
+	test_when_finished "rm -f \"$PREMERGE\" actual_hooks" &&
+	cp "$HOOKDIR/non-exec.sample" "$PREMERGE" &&
+	git branch -f side side-orig &&
+	git checkout side &&
+	git merge --no-verify -m "merge master" master &&
+	git checkout master &&
+	test_path_is_missing actual_hooks
+'
+
+test_expect_success 'with hook requiring GIT_PREFIX' '
+	test_when_finished "rm -rf \"$PRECOMMIT\" expected_hooks actual_hooks success" &&
+	cp "$HOOKDIR/require-prefix.sample" "$PRECOMMIT" &&
+	echo "$PRECOMMIT" >expected_hooks &&
+	echo "more content" >>file &&
+	git add file &&
+	mkdir success &&
+	(
+		cd success &&
+		git commit -m "hook requires GIT_PREFIX = success/"
+	) &&
+	test_cmp expected_hooks actual_hooks
+'
+
+test_expect_success 'with failing hook requiring GIT_PREFIX' '
+	test_when_finished "rm -rf \"$PRECOMMIT\" expected_hooks actual_hooks fail" &&
+	cp "$HOOKDIR/require-prefix.sample" "$PRECOMMIT" &&
+	echo "$PRECOMMIT" >expected_hooks &&
+	echo "more content" >>file &&
+	git add file &&
+	mkdir fail &&
+	(
+		cd fail &&
+		test_must_fail git commit -m "hook must fail"
+	) &&
+	git checkout -- file &&
+	test_cmp expected_hooks actual_hooks
+'
+
+test_expect_success 'check the author in hook' '
+	test_when_finished "rm -f \"$PRECOMMIT\" expected_hooks actual_hooks" &&
+	cp "$HOOKDIR/check-author.sample" "$PRECOMMIT" &&
+	cat >expected_hooks <<-EOF &&
+	$PRECOMMIT
+	$PRECOMMIT
+	$PRECOMMIT
+	EOF
+	test_must_fail git commit --allow-empty -m "by a.u.thor" &&
+	(
+		GIT_AUTHOR_NAME="New Author" &&
+		GIT_AUTHOR_EMAIL="newauthor@example.com" &&
+		export GIT_AUTHOR_NAME GIT_AUTHOR_EMAIL &&
+		git commit --allow-empty -m "by new.author via env" &&
+		git show -s
+	) &&
+	git commit --author="New Author <newauthor@example.com>" \
+		--allow-empty -m "by new.author via command line" &&
+	git show -s &&
+	test_cmp expected_hooks actual_hooks
+'
+
+test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t7503-pre-commit-hook.sh 1.2.3+git2.25.1-1/git/t/t7503-pre-commit-hook.sh
--- 1.2.1+git2.18.0-1/git/t/t7503-pre-commit-hook.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t7503-pre-commit-hook.sh	1970-01-01 00:00:00.000000000 +0000
@@ -1,139 +0,0 @@
-#!/bin/sh
-
-test_description='pre-commit hook'
-
-. ./test-lib.sh
-
-test_expect_success 'with no hook' '
-
-	echo "foo" > file &&
-	git add file &&
-	git commit -m "first"
-
-'
-
-test_expect_success '--no-verify with no hook' '
-
-	echo "bar" > file &&
-	git add file &&
-	git commit --no-verify -m "bar"
-
-'
-
-# now install hook that always succeeds
-HOOKDIR="$(git rev-parse --git-dir)/hooks"
-HOOK="$HOOKDIR/pre-commit"
-mkdir -p "$HOOKDIR"
-cat > "$HOOK" <<EOF
-#!/bin/sh
-exit 0
-EOF
-chmod +x "$HOOK"
-
-test_expect_success 'with succeeding hook' '
-
-	echo "more" >> file &&
-	git add file &&
-	git commit -m "more"
-
-'
-
-test_expect_success '--no-verify with succeeding hook' '
-
-	echo "even more" >> file &&
-	git add file &&
-	git commit --no-verify -m "even more"
-
-'
-
-# now a hook that fails
-cat > "$HOOK" <<EOF
-#!/bin/sh
-exit 1
-EOF
-
-test_expect_success 'with failing hook' '
-
-	echo "another" >> file &&
-	git add file &&
-	test_must_fail git commit -m "another"
-
-'
-
-test_expect_success '--no-verify with failing hook' '
-
-	echo "stuff" >> file &&
-	git add file &&
-	git commit --no-verify -m "stuff"
-
-'
-
-chmod -x "$HOOK"
-test_expect_success POSIXPERM 'with non-executable hook' '
-
-	echo "content" >> file &&
-	git add file &&
-	git commit -m "content"
-
-'
-
-test_expect_success POSIXPERM '--no-verify with non-executable hook' '
-
-	echo "more content" >> file &&
-	git add file &&
-	git commit --no-verify -m "more content"
-
-'
-chmod +x "$HOOK"
-
-# a hook that checks $GIT_PREFIX and succeeds inside the
-# success/ subdirectory only
-cat > "$HOOK" <<EOF
-#!/bin/sh
-test \$GIT_PREFIX = success/
-EOF
-
-test_expect_success 'with hook requiring GIT_PREFIX' '
-
-	echo "more content" >> file &&
-	git add file &&
-	mkdir success &&
-	(
-		cd success &&
-		git commit -m "hook requires GIT_PREFIX = success/"
-	) &&
-	rmdir success
-'
-
-test_expect_success 'with failing hook requiring GIT_PREFIX' '
-
-	echo "more content" >> file &&
-	git add file &&
-	mkdir fail &&
-	(
-		cd fail &&
-		test_must_fail git commit -m "hook must fail"
-	) &&
-	rmdir fail &&
-	git checkout -- file
-'
-
-test_expect_success 'check the author in hook' '
-	write_script "$HOOK" <<-\EOF &&
-	test "$GIT_AUTHOR_NAME" = "New Author" &&
-	test "$GIT_AUTHOR_EMAIL" = "newauthor@example.com"
-	EOF
-	test_must_fail git commit --allow-empty -m "by a.u.thor" &&
-	(
-		GIT_AUTHOR_NAME="New Author" &&
-		GIT_AUTHOR_EMAIL="newauthor@example.com" &&
-		export GIT_AUTHOR_NAME GIT_AUTHOR_EMAIL &&
-		git commit --allow-empty -m "by new.author via env" &&
-		git show -s
-	) &&
-	git commit --author="New Author <newauthor@example.com>" \
-		--allow-empty -m "by new.author via command line" &&
-	git show -s
-'
-
-test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t7504-commit-msg-hook.sh 1.2.3+git2.25.1-1/git/t/t7504-commit-msg-hook.sh
--- 1.2.1+git2.18.0-1/git/t/t7504-commit-msg-hook.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t7504-commit-msg-hook.sh	2020-02-17 04:47:35.000000000 +0000
@@ -157,6 +157,7 @@ test_expect_success 'merge bypasses fail
 	test_when_finished "git branch -D newbranch" &&
 	test_when_finished "git checkout -f master" &&
 	git checkout --orphan newbranch &&
+	git rm -f file &&
 	: >file2 &&
 	git add file2 &&
 	git commit --no-verify file2 -m in-side-branch &&
@@ -168,7 +169,7 @@ test_expect_success 'merge bypasses fail
 chmod -x "$HOOK"
 test_expect_success POSIXPERM 'with non-executable hook' '
 
-	echo "content" >> file &&
+	echo "content" >file &&
 	git add file &&
 	git commit -m "content"
 
@@ -249,6 +250,7 @@ test_expect_success 'hook called in git-
 	test_when_finished "git branch -D newbranch" &&
 	test_when_finished "git checkout -f master" &&
 	git checkout --orphan newbranch &&
+	git rm -f file &&
 	: >file2 &&
 	git add file2 &&
 	git commit --no-verify file2 -m in-side-branch &&
diff -pruN 1.2.1+git2.18.0-1/git/t/t7505/expected-rebase-i 1.2.3+git2.25.1-1/git/t/t7505/expected-rebase-i
--- 1.2.1+git2.18.0-1/git/t/t7505/expected-rebase-i	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t7505/expected-rebase-i	2020-02-17 04:47:35.000000000 +0000
@@ -7,7 +7,8 @@ message (no editor) [edit rebase-10]
 message [fixup rebase-9]
 message (no editor) [fixup rebase-8]
 message (no editor) [squash rebase-7]
-message [reword rebase-6]
+HEAD [reword rebase-6]
+message (no editor) [reword rebase-6]
 message [squash rebase-5]
 message (no editor) [fixup rebase-4]
 message (no editor) [pick rebase-3]
diff -pruN 1.2.1+git2.18.0-1/git/t/t7505-prepare-commit-msg-hook.sh 1.2.3+git2.25.1-1/git/t/t7505-prepare-commit-msg-hook.sh
--- 1.2.1+git2.18.0-1/git/t/t7505-prepare-commit-msg-hook.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t7505-prepare-commit-msg-hook.sh	2020-02-17 04:47:35.000000000 +0000
@@ -215,7 +215,7 @@ test_expect_success 'with hook and edito
 test_rebase () {
 	expect=$1 &&
 	mode=$2 &&
-	test_expect_$expect C_LOCALE_OUTPUT "with hook (rebase $mode)" '
+	test_expect_$expect C_LOCALE_OUTPUT "with hook (rebase ${mode:--i})" '
 		test_when_finished "\
 			git rebase --abort
 			git checkout -f master
@@ -225,7 +225,7 @@ test_rebase () {
 		GIT_EDITOR="\"$FAKE_EDITOR\"" &&
 		(
 			export GIT_SEQUENCE_EDITOR GIT_EDITOR &&
-			test_must_fail git rebase $mode b &&
+			test_must_fail git rebase -i $mode b &&
 			echo x >a &&
 			git add a &&
 			test_must_fail git rebase --continue &&
@@ -241,19 +241,13 @@ test_rebase () {
 			git add b &&
 			git rebase --continue
 		) &&
-		if test $mode = -p # reword amended after pick
-		then
-			n=18
-		else
-			n=17
-		fi &&
-		git log --pretty=%s -g -n$n HEAD@{1} >actual &&
-		test_cmp "$TEST_DIRECTORY/t7505/expected-rebase$mode" actual
+		git log --pretty=%s -g -n18 HEAD@{1} >actual &&
+		test_cmp "$TEST_DIRECTORY/t7505/expected-rebase${mode:--i}" actual
 	'
 }
 
-test_rebase success -i
-test_rebase success -p
+test_rebase success
+test_have_prereq !REBASE_P || test_rebase success -p
 
 test_expect_success 'with hook (cherry-pick)' '
 	test_when_finished "git checkout -f master" &&
diff -pruN 1.2.1+git2.18.0-1/git/t/t7506-status-submodule.sh 1.2.3+git2.25.1-1/git/t/t7506-status-submodule.sh
--- 1.2.1+git2.18.0-1/git/t/t7506-status-submodule.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t7506-status-submodule.sh	2020-02-17 04:47:35.000000000 +0000
@@ -193,9 +193,9 @@ test_expect_success 'status with added a
 
 test_expect_success 'setup .git file for sub' '
 	(cd sub &&
-	 rm -f new-file
+	 rm -f new-file &&
 	 REAL="$(pwd)/../.real" &&
-	 mv .git "$REAL"
+	 mv .git "$REAL" &&
 	 echo "gitdir: $REAL" >.git) &&
 	 echo .real >>.gitignore &&
 	 git commit -m "added .real to .gitignore" .gitignore
@@ -209,12 +209,12 @@ test_expect_success 'status with added f
 
 test_expect_success 'status with a lot of untracked files in the submodule' '
 	(
-		cd sub
+		cd sub &&
 		i=0 &&
 		while test $i -lt 1024
 		do
-			>some-file-$i
-			i=$(( $i + 1 ))
+			>some-file-$i &&
+			i=$(( $i + 1 )) || exit 1
 		done
 	) &&
 	git status --porcelain sub 2>err.actual &&
@@ -325,7 +325,8 @@ test_expect_success 'setup superproject
 	(
 		cd super &&
 		git clean -dfx &&
-		rm .gitmodules &&
+		git rm .gitmodules &&
+		git commit -m "remove .gitmodules" &&
 		git submodule add -f ./sub1 &&
 		git submodule add -f ./sub2 &&
 		git submodule add -f ./sub1 sub3 &&
diff -pruN 1.2.1+git2.18.0-1/git/t/t7508-status.sh 1.2.3+git2.25.1-1/git/t/t7508-status.sh
--- 1.2.1+git2.18.0-1/git/t/t7508-status.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t7508-status.sh	2020-02-17 04:47:35.000000000 +0000
@@ -94,19 +94,16 @@ test_expect_success 'status --column' '
 #   (use "git pull" to merge the remote branch into yours)
 #
 # Changes to be committed:
-#   (use "git reset HEAD <file>..." to unstage)
-#
+#   (use "git restore --staged <file>..." to unstage)
 #	new file:   dir2/added
 #
 # Changes not staged for commit:
 #   (use "git add <file>..." to update what will be committed)
-#   (use "git checkout -- <file>..." to discard changes in working directory)
-#
+#   (use "git restore <file>..." to discard changes in working directory)
 #	modified:   dir1/modified
 #
 # Untracked files:
 #   (use "git add <file>..." to include in what will be committed)
-#
 #	dir1/untracked dir2/untracked
 #	dir2/modified  untracked
 #
@@ -128,19 +125,16 @@ cat >expect <<\EOF
 #   (use "git pull" to merge the remote branch into yours)
 #
 # Changes to be committed:
-#   (use "git reset HEAD <file>..." to unstage)
-#
+#   (use "git restore --staged <file>..." to unstage)
 #	new file:   dir2/added
 #
 # Changes not staged for commit:
 #   (use "git add <file>..." to update what will be committed)
-#   (use "git checkout -- <file>..." to discard changes in working directory)
-#
+#   (use "git restore <file>..." to discard changes in working directory)
 #	modified:   dir1/modified
 #
 # Untracked files:
 #   (use "git add <file>..." to include in what will be committed)
-#
 #	dir1/untracked
 #	dir2/modified
 #	dir2/untracked
@@ -278,24 +272,20 @@ and have 1 and 2 different commits each,
   (use "git pull" to merge the remote branch into yours)
 
 Changes to be committed:
-  (use "git reset HEAD <file>..." to unstage)
-
+  (use "git restore --staged <file>..." to unstage)
 	new file:   dir2/added
 
 Changes not staged for commit:
   (use "git add <file>..." to update what will be committed)
-  (use "git checkout -- <file>..." to discard changes in working directory)
-
+  (use "git restore <file>..." to discard changes in working directory)
 	modified:   dir1/modified
 
 Untracked files:
   (use "git add <file>..." to include in what will be committed)
-
 	dir2/modified
 
 Ignored files:
   (use "git add -f <file>..." to include in what will be committed)
-
 	.gitignore
 	dir1/untracked
 	dir2/untracked
@@ -347,19 +337,16 @@ and have 1 and 2 different commits each,
   (use "git pull" to merge the remote branch into yours)
 
 Changes to be committed:
-  (use "git reset HEAD <file>..." to unstage)
-
+  (use "git restore --staged <file>..." to unstage)
 	new file:   dir2/added
 
 Changes not staged for commit:
   (use "git add <file>..." to update what will be committed)
-  (use "git checkout -- <file>..." to discard changes in working directory)
-
+  (use "git restore <file>..." to discard changes in working directory)
 	modified:   dir1/modified
 
 Ignored files:
   (use "git add -f <file>..." to include in what will be committed)
-
 	.gitignore
 	dir1/untracked
 	dir2/modified
@@ -420,14 +407,12 @@ and have 1 and 2 different commits each,
   (use "git pull" to merge the remote branch into yours)
 
 Changes to be committed:
-  (use "git reset HEAD <file>..." to unstage)
-
+  (use "git restore --staged <file>..." to unstage)
 	new file:   dir2/added
 
 Changes not staged for commit:
   (use "git add <file>..." to update what will be committed)
-  (use "git checkout -- <file>..." to discard changes in working directory)
-
+  (use "git restore <file>..." to discard changes in working directory)
 	modified:   dir1/modified
 
 Untracked files not listed (use -u option to show untracked files)
@@ -484,19 +469,16 @@ and have 1 and 2 different commits each,
   (use "git pull" to merge the remote branch into yours)
 
 Changes to be committed:
-  (use "git reset HEAD <file>..." to unstage)
-
+  (use "git restore --staged <file>..." to unstage)
 	new file:   dir2/added
 
 Changes not staged for commit:
   (use "git add <file>..." to update what will be committed)
-  (use "git checkout -- <file>..." to discard changes in working directory)
-
+  (use "git restore <file>..." to discard changes in working directory)
 	modified:   dir1/modified
 
 Untracked files:
   (use "git add <file>..." to include in what will be committed)
-
 	dir1/untracked
 	dir2/modified
 	dir2/untracked
@@ -542,19 +524,16 @@ and have 1 and 2 different commits each,
   (use "git pull" to merge the remote branch into yours)
 
 Changes to be committed:
-  (use "git reset HEAD <file>..." to unstage)
-
+  (use "git restore --staged <file>..." to unstage)
 	new file:   dir2/added
 
 Changes not staged for commit:
   (use "git add <file>..." to update what will be committed)
-  (use "git checkout -- <file>..." to discard changes in working directory)
-
+  (use "git restore <file>..." to discard changes in working directory)
 	modified:   dir1/modified
 
 Untracked files:
   (use "git add <file>..." to include in what will be committed)
-
 	dir1/untracked
 	dir2/modified
 	dir2/untracked
@@ -605,19 +584,16 @@ and have 1 and 2 different commits each,
   (use "git pull" to merge the remote branch into yours)
 
 Changes to be committed:
-  (use "git reset HEAD <file>..." to unstage)
-
+  (use "git restore --staged <file>..." to unstage)
 	new file:   ../dir2/added
 
 Changes not staged for commit:
   (use "git add <file>..." to update what will be committed)
-  (use "git checkout -- <file>..." to discard changes in working directory)
-
+  (use "git restore <file>..." to discard changes in working directory)
 	modified:   modified
 
 Untracked files:
   (use "git add <file>..." to include in what will be committed)
-
 	untracked
 	../dir2/modified
 	../dir2/untracked
@@ -676,19 +652,16 @@ and have 1 and 2 different commits each,
   (use "git pull" to merge the remote branch into yours)
 
 Changes to be committed:
-  (use "git reset HEAD <file>..." to unstage)
-
+  (use "git restore --staged <file>..." to unstage)
 	<GREEN>new file:   dir2/added<RESET>
 
 Changes not staged for commit:
   (use "git add <file>..." to update what will be committed)
-  (use "git checkout -- <file>..." to discard changes in working directory)
-
+  (use "git restore <file>..." to discard changes in working directory)
 	<RED>modified:   dir1/modified<RESET>
 
 Untracked files:
   (use "git add <file>..." to include in what will be committed)
-
 	<BLUE>dir1/untracked<RESET>
 	<BLUE>dir2/modified<RESET>
 	<BLUE>dir2/untracked<RESET>
@@ -802,19 +775,16 @@ and have 1 and 2 different commits each,
   (use "git pull" to merge the remote branch into yours)
 
 Changes to be committed:
-  (use "git reset HEAD <file>..." to unstage)
-
+  (use "git restore --staged <file>..." to unstage)
 	new file:   dir2/added
 
 Changes not staged for commit:
   (use "git add <file>..." to update what will be committed)
-  (use "git checkout -- <file>..." to discard changes in working directory)
-
+  (use "git restore <file>..." to discard changes in working directory)
 	modified:   dir1/modified
 
 Untracked files:
   (use "git add <file>..." to include in what will be committed)
-
 	dir1/untracked
 	dir2/modified
 	dir2/untracked
@@ -852,13 +822,11 @@ and have 1 and 2 different commits each,
   (use "git pull" to merge the remote branch into yours)
 
 Changes to be committed:
-  (use "git reset HEAD <file>..." to unstage)
-
+  (use "git restore --staged <file>..." to unstage)
 	modified:   dir1/modified
 
 Untracked files:
   (use "git add <file>..." to include in what will be committed)
-
 	dir1/untracked
 	dir2/
 	untracked
@@ -896,20 +864,17 @@ and have 1 and 2 different commits each,
   (use "git pull" to merge the remote branch into yours)
 
 Changes to be committed:
-  (use "git reset HEAD <file>..." to unstage)
-
+  (use "git restore --staged <file>..." to unstage)
 	new file:   dir2/added
 	new file:   sm
 
 Changes not staged for commit:
   (use "git add <file>..." to update what will be committed)
-  (use "git checkout -- <file>..." to discard changes in working directory)
-
+  (use "git restore <file>..." to discard changes in working directory)
 	modified:   dir1/modified
 
 Untracked files:
   (use "git add <file>..." to include in what will be committed)
-
 	dir1/untracked
 	dir2/modified
 	dir2/untracked
@@ -956,15 +921,13 @@ and have 1 and 2 different commits each,
   (use "git pull" to merge the remote branch into yours)
 
 Changes to be committed:
-  (use "git reset HEAD <file>..." to unstage)
-
+  (use "git restore --staged <file>..." to unstage)
 	new file:   dir2/added
 	new file:   sm
 
 Changes not staged for commit:
   (use "git add <file>..." to update what will be committed)
-  (use "git checkout -- <file>..." to discard changes in working directory)
-
+  (use "git restore <file>..." to discard changes in working directory)
 	modified:   dir1/modified
 
 Submodule changes to be committed:
@@ -974,7 +937,6 @@ Submodule changes to be committed:
 
 Untracked files:
   (use "git add <file>..." to include in what will be committed)
-
 	dir1/untracked
 	dir2/modified
 	dir2/untracked
@@ -1019,13 +981,11 @@ and have 2 and 2 different commits each,
 
 Changes not staged for commit:
   (use "git add <file>..." to update what will be committed)
-  (use "git checkout -- <file>..." to discard changes in working directory)
-
+  (use "git restore <file>..." to discard changes in working directory)
 	modified:   dir1/modified
 
 Untracked files:
   (use "git add <file>..." to include in what will be committed)
-
 	dir1/untracked
 	dir2/modified
 	dir2/untracked
@@ -1068,15 +1028,13 @@ and have 2 and 2 different commits each,
   (use "git pull" to merge the remote branch into yours)
 
 Changes to be committed:
-  (use "git reset HEAD^1 <file>..." to unstage)
-
+  (use "git restore --source=HEAD^1 --staged <file>..." to unstage)
 	new file:   dir2/added
 	new file:   sm
 
 Changes not staged for commit:
   (use "git add <file>..." to update what will be committed)
-  (use "git checkout -- <file>..." to discard changes in working directory)
-
+  (use "git restore <file>..." to discard changes in working directory)
 	modified:   dir1/modified
 
 Submodule changes to be committed:
@@ -1086,7 +1044,6 @@ Submodule changes to be committed:
 
 Untracked files:
   (use "git add <file>..." to include in what will be committed)
-
 	dir1/untracked
 	dir2/modified
 	dir2/untracked
@@ -1099,6 +1056,7 @@ EOF
 '
 
 test_expect_success POSIXPERM,SANITY 'status succeeds in a read-only repository' '
+	test_when_finished "chmod 775 .git" &&
 	(
 		chmod a-w .git &&
 		# make dir1/tracked stat-dirty
@@ -1108,9 +1066,6 @@ test_expect_success POSIXPERM,SANITY 'st
 		# make sure "status" succeeded without writing index out
 		git diff-files | grep dir1/tracked
 	)
-	status=$?
-	chmod 775 .git
-	(exit $status)
 '
 
 (cd sm && echo > bar && git add bar && git commit -q -m 'Add bar') && git add sm
@@ -1125,14 +1080,12 @@ and have 2 and 2 different commits each,
   (use "git pull" to merge the remote branch into yours)
 
 Changes to be committed:
-  (use "git reset HEAD <file>..." to unstage)
-
+  (use "git restore --staged <file>..." to unstage)
 	modified:   sm
 
 Changes not staged for commit:
   (use "git add <file>..." to update what will be committed)
-  (use "git checkout -- <file>..." to discard changes in working directory)
-
+  (use "git restore <file>..." to discard changes in working directory)
 	modified:   dir1/modified
 
 Submodule changes to be committed:
@@ -1142,7 +1095,6 @@ Submodule changes to be committed:
 
 Untracked files:
   (use "git add <file>..." to include in what will be committed)
-
 	.gitmodules
 	dir1/untracked
 	dir2/modified
@@ -1237,15 +1189,13 @@ and have 2 and 2 different commits each,
   (use "git pull" to merge the remote branch into yours)
 
 Changes to be committed:
-  (use "git reset HEAD <file>..." to unstage)
-
+  (use "git restore --staged <file>..." to unstage)
 	modified:   sm
 
 Changes not staged for commit:
   (use "git add <file>..." to update what will be committed)
-  (use "git checkout -- <file>..." to discard changes in working directory)
+  (use "git restore <file>..." to discard changes in working directory)
   (commit or discard the untracked or modified content in submodules)
-
 	modified:   dir1/modified
 	modified:   sm (modified content)
 
@@ -1256,7 +1206,6 @@ Submodule changes to be committed:
 
 Untracked files:
   (use "git add <file>..." to include in what will be committed)
-
 	.gitmodules
 	dir1/untracked
 	dir2/modified
@@ -1297,14 +1246,12 @@ and have 2 and 2 different commits each,
   (use "git pull" to merge the remote branch into yours)
 
 Changes to be committed:
-  (use "git reset HEAD <file>..." to unstage)
-
+  (use "git restore --staged <file>..." to unstage)
 	modified:   sm
 
 Changes not staged for commit:
   (use "git add <file>..." to update what will be committed)
-  (use "git checkout -- <file>..." to discard changes in working directory)
-
+  (use "git restore <file>..." to discard changes in working directory)
 	modified:   dir1/modified
 	modified:   sm (new commits)
 
@@ -1320,7 +1267,6 @@ Submodules changed but not updated:
 
 Untracked files:
   (use "git add <file>..." to include in what will be committed)
-
 	.gitmodules
 	dir1/untracked
 	dir2/modified
@@ -1381,14 +1327,12 @@ cat > expect << EOF
 ;   (use "git pull" to merge the remote branch into yours)
 ;
 ; Changes to be committed:
-;   (use "git reset HEAD <file>..." to unstage)
-;
+;   (use "git restore --staged <file>..." to unstage)
 ;	modified:   sm
 ;
 ; Changes not staged for commit:
 ;   (use "git add <file>..." to update what will be committed)
-;   (use "git checkout -- <file>..." to discard changes in working directory)
-;
+;   (use "git restore <file>..." to discard changes in working directory)
 ;	modified:   dir1/modified
 ;	modified:   sm (new commits)
 ;
@@ -1404,7 +1348,6 @@ cat > expect << EOF
 ;
 ; Untracked files:
 ;   (use "git add <file>..." to include in what will be committed)
-;
 ;	.gitmodules
 ;	dir1/untracked
 ;	dir2/modified
@@ -1433,13 +1376,11 @@ and have 2 and 2 different commits each,
 
 Changes not staged for commit:
   (use "git add <file>..." to update what will be committed)
-  (use "git checkout -- <file>..." to discard changes in working directory)
-
+  (use "git restore <file>..." to discard changes in working directory)
 	modified:   dir1/modified
 
 Untracked files:
   (use "git add <file>..." to include in what will be committed)
-
 	.gitmodules
 	dir1/untracked
 	dir2/modified
@@ -1460,19 +1401,16 @@ and have 2 and 2 different commits each,
   (use "git pull" to merge the remote branch into yours)
 
 Changes to be committed:
-  (use "git reset HEAD <file>..." to unstage)
-
+  (use "git restore --staged <file>..." to unstage)
 	modified:   sm
 
 Changes not staged for commit:
   (use "git add <file>..." to update what will be committed)
-  (use "git checkout -- <file>..." to discard changes in working directory)
-
+  (use "git restore <file>..." to discard changes in working directory)
 	modified:   dir1/modified
 
 Untracked files:
   (use "git add <file>..." to include in what will be committed)
-
 	.gitmodules
 	dir1/untracked
 	dir2/modified
@@ -1583,14 +1521,12 @@ and have 2 and 2 different commits each,
   (use "git pull" to merge the remote branch into yours)
 
 Changes to be committed:
-  (use "git reset HEAD <file>..." to unstage)
-
+  (use "git restore --staged <file>..." to unstage)
 	modified:   sm
 
 Changes not staged for commit:
   (use "git add <file>..." to update what will be committed)
-  (use "git checkout -- <file>..." to discard changes in working directory)
-
+  (use "git restore <file>..." to discard changes in working directory)
 	modified:   dir1/modified
 
 Untracked files not listed (use -u option to show untracked files)
@@ -1635,7 +1571,7 @@ test_expect_success '"status.showStash=t
 	test_cmp expected_without_stash actual
 '
 
-test_expect_success 'no additionnal info if no stash entries' '
+test_expect_success 'no additional info if no stash entries' '
 	git stash clear &&
 	git -c status.showStash=true status >actual &&
 	test_cmp expected_without_stash actual
diff -pruN 1.2.1+git2.18.0-1/git/t/t7509-commit-authorship.sh 1.2.3+git2.25.1-1/git/t/t7509-commit-authorship.sh
--- 1.2.1+git2.18.0-1/git/t/t7509-commit-authorship.sh	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t7509-commit-authorship.sh	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,177 @@
+#!/bin/sh
+#
+# Copyright (c) 2009 Erick Mattos
+#
+
+test_description='commit tests of various authorhip options. '
+
+. ./test-lib.sh
+
+author_header () {
+	git cat-file commit "$1" |
+	sed -n -e '/^$/q' -e '/^author /p'
+}
+
+message_body () {
+	git cat-file commit "$1" |
+	sed -e '1,/^$/d'
+}
+
+test_expect_success '-C option copies authorship and message' '
+	echo "Initial" >foo &&
+	git add foo &&
+	test_tick &&
+	git commit -m "Initial Commit" --author Frigate\ \<flying@over.world\> &&
+	git tag Initial &&
+	echo "Test 1" >>foo &&
+	test_tick &&
+	git commit -a -C Initial &&
+	author_header Initial >expect &&
+	author_header HEAD >actual &&
+	test_cmp expect actual &&
+
+	message_body Initial >expect &&
+	message_body HEAD >actual &&
+	test_cmp expect actual
+'
+
+test_expect_success '-C option copies only the message with --reset-author' '
+	echo "Test 2" >>foo &&
+	test_tick &&
+	git commit -a -C Initial --reset-author &&
+	echo "author $GIT_AUTHOR_NAME <$GIT_AUTHOR_EMAIL> $GIT_AUTHOR_DATE" >expect &&
+	author_header HEAD >actual &&
+	test_cmp expect actual &&
+
+	message_body Initial >expect &&
+	message_body HEAD >actual &&
+	test_cmp expect actual
+'
+
+test_expect_success '-c option copies authorship and message' '
+	echo "Test 3" >>foo &&
+	test_tick &&
+	EDITOR=: VISUAL=: git commit -a -c Initial &&
+	author_header Initial >expect &&
+	author_header HEAD >actual &&
+	test_cmp expect actual
+'
+
+test_expect_success '-c option copies only the message with --reset-author' '
+	echo "Test 4" >>foo &&
+	test_tick &&
+	EDITOR=: VISUAL=: git commit -a -c Initial --reset-author &&
+	echo "author $GIT_AUTHOR_NAME <$GIT_AUTHOR_EMAIL> $GIT_AUTHOR_DATE" >expect &&
+	author_header HEAD >actual &&
+	test_cmp expect actual &&
+
+	message_body Initial >expect &&
+	message_body HEAD >actual &&
+	test_cmp expect actual
+'
+
+test_expect_success '--amend option copies authorship' '
+	git checkout Initial &&
+	echo "Test 5" >>foo &&
+	test_tick &&
+	git commit -a --amend -m "amend test" &&
+	author_header Initial >expect &&
+	author_header HEAD >actual &&
+	test_cmp expect actual &&
+
+	echo "amend test" >expect &&
+	message_body HEAD >actual &&
+	test_cmp expect actual
+'
+
+sha1_file() {
+	echo "$*" | sed "s#..#.git/objects/&/#"
+}
+remove_object() {
+	rm -f $(sha1_file "$*")
+}
+
+test_expect_success '--amend option with empty author' '
+	git cat-file commit Initial >tmp &&
+	sed "s/author [^<]* </author  </" tmp >empty-author &&
+	sha=$(git hash-object -t commit -w empty-author) &&
+	test_when_finished "remove_object $sha" &&
+	git checkout $sha &&
+	test_when_finished "git checkout Initial" &&
+	echo "Empty author test" >>foo &&
+	test_tick &&
+	test_must_fail git commit -a -m "empty author" --amend 2>err &&
+	test_i18ngrep "empty ident" err
+'
+
+test_expect_success '--amend option with missing author' '
+	git cat-file commit Initial >tmp &&
+	sed "s/author [^<]* </author </" tmp >malformed &&
+	sha=$(git hash-object -t commit -w malformed) &&
+	test_when_finished "remove_object $sha" &&
+	git checkout $sha &&
+	test_when_finished "git checkout Initial" &&
+	echo "Missing author test" >>foo &&
+	test_tick &&
+	test_must_fail git commit -a -m "malformed author" --amend 2>err &&
+	test_i18ngrep "empty ident" err
+'
+
+test_expect_success '--reset-author makes the commit ours even with --amend option' '
+	git checkout Initial &&
+	echo "Test 6" >>foo &&
+	test_tick &&
+	git commit -a --reset-author -m "Changed again" --amend &&
+	echo "author $GIT_AUTHOR_NAME <$GIT_AUTHOR_EMAIL> $GIT_AUTHOR_DATE" >expect &&
+	author_header HEAD >actual &&
+	test_cmp expect actual &&
+
+	echo "Changed again" >expect &&
+	message_body HEAD >actual &&
+	test_cmp expect actual
+'
+
+test_expect_success '--reset-author and --author are mutually exclusive' '
+	git checkout Initial &&
+	echo "Test 7" >>foo &&
+	test_tick &&
+	test_must_fail git commit -a --reset-author --author="Xyzzy <frotz@nitfol.xz>"
+'
+
+test_expect_success '--reset-author should be rejected without -c/-C/--amend' '
+	git checkout Initial &&
+	echo "Test 7" >>foo &&
+	test_tick &&
+	test_must_fail git commit -a --reset-author -m done
+'
+
+test_expect_success 'commit respects CHERRY_PICK_HEAD and MERGE_MSG' '
+	echo "cherry-pick 1a" >>foo &&
+	test_tick &&
+	git commit -am "cherry-pick 1" --author="Cherry <cherry@pick.er>" &&
+	git tag cherry-pick-head &&
+	git rev-parse cherry-pick-head >.git/CHERRY_PICK_HEAD &&
+	echo "This is a MERGE_MSG" >.git/MERGE_MSG &&
+	echo "cherry-pick 1b" >>foo &&
+	test_tick &&
+	git commit -a &&
+	author_header cherry-pick-head >expect &&
+	author_header HEAD >actual &&
+	test_cmp expect actual &&
+
+	echo "This is a MERGE_MSG" >expect &&
+	message_body HEAD >actual &&
+	test_cmp expect actual
+'
+
+test_expect_success '--reset-author with CHERRY_PICK_HEAD' '
+	git rev-parse cherry-pick-head >.git/CHERRY_PICK_HEAD &&
+	echo "cherry-pick 2" >>foo &&
+	test_tick &&
+	git commit -am "cherry-pick 2" --reset-author &&
+	echo "author $GIT_AUTHOR_NAME <$GIT_AUTHOR_EMAIL> $GIT_AUTHOR_DATE" >expect &&
+	author_header HEAD >actual &&
+	test_cmp expect actual
+'
+
+test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t7509-commit.sh 1.2.3+git2.25.1-1/git/t/t7509-commit.sh
--- 1.2.1+git2.18.0-1/git/t/t7509-commit.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t7509-commit.sh	1970-01-01 00:00:00.000000000 +0000
@@ -1,177 +0,0 @@
-#!/bin/sh
-#
-# Copyright (c) 2009 Erick Mattos
-#
-
-test_description='git commit --reset-author'
-
-. ./test-lib.sh
-
-author_header () {
-	git cat-file commit "$1" |
-	sed -n -e '/^$/q' -e '/^author /p'
-}
-
-message_body () {
-	git cat-file commit "$1" |
-	sed -e '1,/^$/d'
-}
-
-test_expect_success '-C option copies authorship and message' '
-	echo "Initial" >foo &&
-	git add foo &&
-	test_tick &&
-	git commit -m "Initial Commit" --author Frigate\ \<flying@over.world\> &&
-	git tag Initial &&
-	echo "Test 1" >>foo &&
-	test_tick &&
-	git commit -a -C Initial &&
-	author_header Initial >expect &&
-	author_header HEAD >actual &&
-	test_cmp expect actual &&
-
-	message_body Initial >expect &&
-	message_body HEAD >actual &&
-	test_cmp expect actual
-'
-
-test_expect_success '-C option copies only the message with --reset-author' '
-	echo "Test 2" >>foo &&
-	test_tick &&
-	git commit -a -C Initial --reset-author &&
-	echo "author $GIT_AUTHOR_NAME <$GIT_AUTHOR_EMAIL> $GIT_AUTHOR_DATE" >expect &&
-	author_header HEAD >actual &&
-	test_cmp expect actual &&
-
-	message_body Initial >expect &&
-	message_body HEAD >actual &&
-	test_cmp expect actual
-'
-
-test_expect_success '-c option copies authorship and message' '
-	echo "Test 3" >>foo &&
-	test_tick &&
-	EDITOR=: VISUAL=: git commit -a -c Initial &&
-	author_header Initial >expect &&
-	author_header HEAD >actual &&
-	test_cmp expect actual
-'
-
-test_expect_success '-c option copies only the message with --reset-author' '
-	echo "Test 4" >>foo &&
-	test_tick &&
-	EDITOR=: VISUAL=: git commit -a -c Initial --reset-author &&
-	echo "author $GIT_AUTHOR_NAME <$GIT_AUTHOR_EMAIL> $GIT_AUTHOR_DATE" >expect &&
-	author_header HEAD >actual &&
-	test_cmp expect actual &&
-
-	message_body Initial >expect &&
-	message_body HEAD >actual &&
-	test_cmp expect actual
-'
-
-test_expect_success '--amend option copies authorship' '
-	git checkout Initial &&
-	echo "Test 5" >>foo &&
-	test_tick &&
-	git commit -a --amend -m "amend test" &&
-	author_header Initial >expect &&
-	author_header HEAD >actual &&
-	test_cmp expect actual &&
-
-	echo "amend test" >expect &&
-	message_body HEAD >actual &&
-	test_cmp expect actual
-'
-
-sha1_file() {
-	echo "$*" | sed "s#..#.git/objects/&/#"
-}
-remove_object() {
-	rm -f $(sha1_file "$*")
-}
-
-test_expect_success '--amend option with empty author' '
-	git cat-file commit Initial >tmp &&
-	sed "s/author [^<]* </author  </" tmp >empty-author &&
-	sha=$(git hash-object -t commit -w empty-author) &&
-	test_when_finished "remove_object $sha" &&
-	git checkout $sha &&
-	test_when_finished "git checkout Initial" &&
-	echo "Empty author test" >>foo &&
-	test_tick &&
-	test_must_fail git commit -a -m "empty author" --amend 2>err &&
-	test_i18ngrep "empty ident" err
-'
-
-test_expect_success '--amend option with missing author' '
-	git cat-file commit Initial >tmp &&
-	sed "s/author [^<]* </author </" tmp >malformed &&
-	sha=$(git hash-object -t commit -w malformed) &&
-	test_when_finished "remove_object $sha" &&
-	git checkout $sha &&
-	test_when_finished "git checkout Initial" &&
-	echo "Missing author test" >>foo &&
-	test_tick &&
-	test_must_fail git commit -a -m "malformed author" --amend 2>err &&
-	test_i18ngrep "empty ident" err
-'
-
-test_expect_success '--reset-author makes the commit ours even with --amend option' '
-	git checkout Initial &&
-	echo "Test 6" >>foo &&
-	test_tick &&
-	git commit -a --reset-author -m "Changed again" --amend &&
-	echo "author $GIT_AUTHOR_NAME <$GIT_AUTHOR_EMAIL> $GIT_AUTHOR_DATE" >expect &&
-	author_header HEAD >actual &&
-	test_cmp expect actual &&
-
-	echo "Changed again" >expect &&
-	message_body HEAD >actual &&
-	test_cmp expect actual
-'
-
-test_expect_success '--reset-author and --author are mutually exclusive' '
-	git checkout Initial &&
-	echo "Test 7" >>foo &&
-	test_tick &&
-	test_must_fail git commit -a --reset-author --author="Xyzzy <frotz@nitfol.xz>"
-'
-
-test_expect_success '--reset-author should be rejected without -c/-C/--amend' '
-	git checkout Initial &&
-	echo "Test 7" >>foo &&
-	test_tick &&
-	test_must_fail git commit -a --reset-author -m done
-'
-
-test_expect_success 'commit respects CHERRY_PICK_HEAD and MERGE_MSG' '
-	echo "cherry-pick 1a" >>foo &&
-	test_tick &&
-	git commit -am "cherry-pick 1" --author="Cherry <cherry@pick.er>" &&
-	git tag cherry-pick-head &&
-	git rev-parse cherry-pick-head >.git/CHERRY_PICK_HEAD &&
-	echo "This is a MERGE_MSG" >.git/MERGE_MSG &&
-	echo "cherry-pick 1b" >>foo &&
-	test_tick &&
-	git commit -a &&
-	author_header cherry-pick-head >expect &&
-	author_header HEAD >actual &&
-	test_cmp expect actual &&
-
-	echo "This is a MERGE_MSG" >expect &&
-	message_body HEAD >actual &&
-	test_cmp expect actual
-'
-
-test_expect_success '--reset-author with CHERRY_PICK_HEAD' '
-	git rev-parse cherry-pick-head >.git/CHERRY_PICK_HEAD &&
-	echo "cherry-pick 2" >>foo &&
-	test_tick &&
-	git commit -am "cherry-pick 2" --reset-author &&
-	echo "author $GIT_AUTHOR_NAME <$GIT_AUTHOR_EMAIL> $GIT_AUTHOR_DATE" >expect &&
-	author_header HEAD >actual &&
-	test_cmp expect actual
-'
-
-test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t7510-signed-commit.sh 1.2.3+git2.25.1-1/git/t/t7510-signed-commit.sh
--- 1.2.1+git2.18.0-1/git/t/t7510-signed-commit.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t7510-signed-commit.sh	2020-02-17 04:47:35.000000000 +0000
@@ -49,15 +49,28 @@ test_expect_success GPG 'create signed c
 	git tag eighth-signed-alt &&
 
 	# commit.gpgsign is still on but this must not be signed
-	git tag ninth-unsigned $(echo 9 | git commit-tree HEAD^{tree}) &&
+	echo 9 | git commit-tree HEAD^{tree} >oid &&
+	test_line_count = 1 oid &&
+	git tag ninth-unsigned $(cat oid) &&
 	# explicit -S of course must sign.
-	git tag tenth-signed $(echo 9 | git commit-tree -S HEAD^{tree})
+	echo 10 | git commit-tree -S HEAD^{tree} >oid &&
+	test_line_count = 1 oid &&
+	git tag tenth-signed $(cat oid) &&
+
+	# --gpg-sign[=<key-id>] must sign.
+	echo 11 | git commit-tree --gpg-sign HEAD^{tree} >oid &&
+	test_line_count = 1 oid &&
+	git tag eleventh-signed $(cat oid) &&
+	echo 12 | git commit-tree --gpg-sign=B7227189 HEAD^{tree} >oid &&
+	test_line_count = 1 oid &&
+	git tag twelfth-signed-alt $(cat oid)
 '
 
 test_expect_success GPG 'verify and show signatures' '
 	(
 		for commit in initial second merge fourth-signed \
-			fifth-signed sixth-signed seventh-signed tenth-signed
+			fifth-signed sixth-signed seventh-signed tenth-signed \
+			eleventh-signed
 		do
 			git verify-commit $commit &&
 			git show --pretty=short --show-signature $commit >actual &&
@@ -78,7 +91,7 @@ test_expect_success GPG 'verify and show
 		done
 	) &&
 	(
-		for commit in eighth-signed-alt
+		for commit in eighth-signed-alt twelfth-signed-alt
 		do
 			git show --pretty=short --show-signature $commit >actual &&
 			grep "Good signature from" actual &&
@@ -142,10 +155,9 @@ test_expect_success GPG 'show signed com
 
 test_expect_success GPG 'detect fudged signature' '
 	git cat-file commit seventh-signed >raw &&
-
-	sed -e "s/seventh/7th forged/" raw >forged1 &&
+	sed -e "s/^seventh/7th forged/" raw >forged1 &&
 	git hash-object -w -t commit forged1 >forged1.commit &&
-	! git verify-commit $(cat forged1.commit) &&
+	test_must_fail git verify-commit $(cat forged1.commit) &&
 	git show --pretty=short --show-signature $(cat forged1.commit) >actual1 &&
 	grep "BAD signature from" actual1 &&
 	! grep "Good signature from" actual1
@@ -156,7 +168,7 @@ test_expect_success GPG 'detect fudged s
 	cat raw >forged2 &&
 	echo Qwik | tr "Q" "\000" >>forged2 &&
 	git hash-object -w -t commit forged2 >forged2.commit &&
-	! git verify-commit $(cat forged2.commit) &&
+	test_must_fail git verify-commit $(cat forged2.commit) &&
 	git show --pretty=short --show-signature $(cat forged2.commit) >actual2 &&
 	grep "BAD signature from" actual2 &&
 	! grep "Good signature from" actual2
@@ -176,8 +188,10 @@ test_expect_success GPG 'show good signa
 	G
 	13B6F51ECDDE430D
 	C O Mitter <committer@example.com>
+	73D758744BE721698EC54E8713B6F51ECDDE430D
+	73D758744BE721698EC54E8713B6F51ECDDE430D
 	EOF
-	git log -1 --format="%G?%n%GK%n%GS" sixth-signed >actual &&
+	git log -1 --format="%G?%n%GK%n%GS%n%GF%n%GP" sixth-signed >actual &&
 	test_cmp expect actual
 '
 
@@ -186,28 +200,34 @@ test_expect_success GPG 'show bad signat
 	B
 	13B6F51ECDDE430D
 	C O Mitter <committer@example.com>
+
+
 	EOF
-	git log -1 --format="%G?%n%GK%n%GS" $(cat forged1.commit) >actual &&
+	git log -1 --format="%G?%n%GK%n%GS%n%GF%n%GP" $(cat forged1.commit) >actual &&
 	test_cmp expect actual
 '
 
 test_expect_success GPG 'show untrusted signature with custom format' '
 	cat >expect <<-\EOF &&
 	U
-	61092E85B7227189
+	65A0EEA02E30CAD7
 	Eris Discordia <discord@example.net>
+	F8364A59E07FFE9F4D63005A65A0EEA02E30CAD7
+	D4BE22311AD3131E5EDA29A461092E85B7227189
 	EOF
-	git log -1 --format="%G?%n%GK%n%GS" eighth-signed-alt >actual &&
+	git log -1 --format="%G?%n%GK%n%GS%n%GF%n%GP" eighth-signed-alt >actual &&
 	test_cmp expect actual
 '
 
 test_expect_success GPG 'show unknown signature with custom format' '
 	cat >expect <<-\EOF &&
 	E
-	61092E85B7227189
+	65A0EEA02E30CAD7
+
+
 
 	EOF
-	GNUPGHOME="$GNUPGHOME_NOT_USED" git log -1 --format="%G?%n%GK%n%GS" eighth-signed-alt >actual &&
+	GNUPGHOME="$GNUPGHOME_NOT_USED" git log -1 --format="%G?%n%GK%n%GS%n%GF%n%GP" eighth-signed-alt >actual &&
 	test_cmp expect actual
 '
 
@@ -216,8 +236,10 @@ test_expect_success GPG 'show lack of si
 	N
 
 
+
+
 	EOF
-	git log -1 --format="%G?%n%GK%n%GS" seventh-unsigned >actual &&
+	git log -1 --format="%G?%n%GK%n%GS%n%GF%n%GP" seventh-unsigned >actual &&
 	test_cmp expect actual
 '
 
@@ -228,4 +250,39 @@ test_expect_success GPG 'log.showsignatu
 	grep "gpg: Good signature" actual
 '
 
+test_expect_success GPG 'check config gpg.format values' '
+	test_config gpg.format openpgp &&
+	git commit -S --amend -m "success" &&
+	test_config gpg.format OpEnPgP &&
+	test_must_fail git commit -S --amend -m "fail"
+'
+
+test_expect_success GPG 'detect fudged commit with double signature' '
+	sed -e "/gpgsig/,/END PGP/d" forged1 >double-base &&
+	sed -n -e "/gpgsig/,/END PGP/p" forged1 | \
+		sed -e "s/^gpgsig//;s/^ //" | gpg --dearmor >double-sig1.sig &&
+	gpg -o double-sig2.sig -u 29472784 --detach-sign double-base &&
+	cat double-sig1.sig double-sig2.sig | gpg --enarmor >double-combined.asc &&
+	sed -e "s/^\(-.*\)ARMORED FILE/\1SIGNATURE/;1s/^/gpgsig /;2,\$s/^/ /" \
+		double-combined.asc > double-gpgsig &&
+	sed -e "/committer/r double-gpgsig" double-base >double-commit &&
+	git hash-object -w -t commit double-commit >double-commit.commit &&
+	test_must_fail git verify-commit $(cat double-commit.commit) &&
+	git show --pretty=short --show-signature $(cat double-commit.commit) >double-actual &&
+	grep "BAD signature from" double-actual &&
+	grep "Good signature from" double-actual
+'
+
+test_expect_success GPG 'show double signature with custom format' '
+	cat >expect <<-\EOF &&
+	E
+
+
+
+
+	EOF
+	git log -1 --format="%G?%n%GK%n%GS%n%GF%n%GP" $(cat double-commit.commit) >actual &&
+	test_cmp expect actual
+'
+
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t7512-status-help.sh 1.2.3+git2.25.1-1/git/t/t7512-status-help.sh
--- 1.2.1+git2.18.0-1/git/t/t7512-status-help.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t7512-status-help.sh	2020-02-17 04:47:35.000000000 +0000
@@ -33,7 +33,6 @@ You have unmerged paths.
 
 Unmerged paths:
   (use "git add <file>..." to mark resolution)
-
 	both modified:   main.txt
 
 no changes added to commit (use "git add" and/or "git commit -a")
@@ -54,7 +53,6 @@ All conflicts fixed but you are still me
   (use "git commit" to conclude merge)
 
 Changes to be committed:
-
 	modified:   main.txt
 
 Untracked files not listed (use -u option to show untracked files)
@@ -85,9 +83,8 @@ You are currently rebasing branch '\''re
   (use "git rebase --abort" to check out the original branch)
 
 Unmerged paths:
-  (use "git reset HEAD <file>..." to unstage)
+  (use "git restore --staged <file>..." to unstage)
   (use "git add <file>..." to mark resolution)
-
 	both modified:   main.txt
 
 no changes added to commit (use "git add" and/or "git commit -a")
@@ -110,8 +107,7 @@ You are currently rebasing branch '\''re
   (all conflicts fixed: run "git rebase --continue")
 
 Changes to be committed:
-  (use "git reset HEAD <file>..." to unstage)
-
+  (use "git restore --staged <file>..." to unstage)
 	modified:   main.txt
 
 Untracked files not listed (use -u option to show untracked files)
@@ -148,9 +144,8 @@ You are currently rebasing branch '\''re
   (use "git rebase --abort" to check out the original branch)
 
 Unmerged paths:
-  (use "git reset HEAD <file>..." to unstage)
+  (use "git restore --staged <file>..." to unstage)
   (use "git add <file>..." to mark resolution)
-
 	both modified:   main.txt
 
 no changes added to commit (use "git add" and/or "git commit -a")
@@ -176,8 +171,7 @@ You are currently rebasing branch '\''re
   (all conflicts fixed: run "git rebase --continue")
 
 Changes to be committed:
-  (use "git reset HEAD <file>..." to unstage)
-
+  (use "git restore --staged <file>..." to unstage)
 	modified:   main.txt
 
 Untracked files not listed (use -u option to show untracked files)
@@ -246,8 +240,7 @@ You are currently splitting a commit whi
 
 Changes not staged for commit:
   (use "git add <file>..." to update what will be committed)
-  (use "git checkout -- <file>..." to discard changes in working directory)
-
+  (use "git restore <file>..." to discard changes in working directory)
 	modified:   main.txt
 
 no changes added to commit (use "git add" and/or "git commit -a")
@@ -354,8 +347,7 @@ You are currently splitting a commit whi
 
 Changes not staged for commit:
   (use "git add <file>..." to update what will be committed)
-  (use "git checkout -- <file>..." to discard changes in working directory)
-
+  (use "git restore <file>..." to discard changes in working directory)
 	modified:   main.txt
 
 no changes added to commit (use "git add" and/or "git commit -a")
@@ -453,8 +445,7 @@ You are currently splitting a commit whi
 
 Changes not staged for commit:
   (use "git add <file>..." to update what will be committed)
-  (use "git checkout -- <file>..." to discard changes in working directory)
-
+  (use "git restore <file>..." to discard changes in working directory)
 	modified:   main.txt
 
 no changes added to commit (use "git add" and/or "git commit -a")
@@ -557,8 +548,7 @@ You are currently splitting a commit whi
 
 Changes not staged for commit:
   (use "git add <file>..." to update what will be committed)
-  (use "git checkout -- <file>..." to discard changes in working directory)
-
+  (use "git restore <file>..." to discard changes in working directory)
 	modified:   main.txt
 
 no changes added to commit (use "git add" and/or "git commit -a")
@@ -743,11 +733,11 @@ test_expect_success 'status when cherry-
 On branch cherry_branch
 You are currently cherry-picking commit $TO_CHERRY_PICK.
   (fix conflicts and run "git cherry-pick --continue")
+  (use "git cherry-pick --skip" to skip this patch)
   (use "git cherry-pick --abort" to cancel the cherry-pick operation)
 
 Unmerged paths:
   (use "git add <file>..." to mark resolution)
-
 	both modified:   main.txt
 
 no changes added to commit (use "git add" and/or "git commit -a")
@@ -768,10 +758,10 @@ test_expect_success 'status when cherry-
 On branch cherry_branch
 You are currently cherry-picking commit $TO_CHERRY_PICK.
   (all conflicts fixed: run "git cherry-pick --continue")
+  (use "git cherry-pick --skip" to skip this patch)
   (use "git cherry-pick --abort" to cancel the cherry-pick operation)
 
 Changes to be committed:
-
 	modified:   main.txt
 
 Untracked files not listed (use -u option to show untracked files)
@@ -780,6 +770,41 @@ EOF
 	test_i18ncmp expected actual
 '
 
+test_expect_success 'status when cherry-picking after committing conflict resolution' '
+	git reset --hard cherry_branch &&
+	test_when_finished "git cherry-pick --abort" &&
+	test_must_fail git cherry-pick cherry_branch_second one_cherry &&
+	echo end >main.txt &&
+	git commit -a &&
+	cat >expected <<EOF &&
+On branch cherry_branch
+Cherry-pick currently in progress.
+  (run "git cherry-pick --continue" to continue)
+  (use "git cherry-pick --skip" to skip this patch)
+  (use "git cherry-pick --abort" to cancel the cherry-pick operation)
+
+nothing to commit (use -u to show untracked files)
+EOF
+	git status --untracked-files=no >actual &&
+	test_i18ncmp expected actual
+'
+
+test_expect_success 'status shows cherry-pick with invalid oid' '
+	mkdir .git/sequencer &&
+	test_write_lines "pick invalid-oid" >.git/sequencer/todo &&
+	git status --untracked-files=no >actual 2>err &&
+	git cherry-pick --quit &&
+	test_must_be_empty err &&
+	test_i18ncmp expected actual
+'
+
+test_expect_success 'status does not show error if .git/sequencer is a file' '
+	test_when_finished "rm .git/sequencer" &&
+	test_write_lines hello >.git/sequencer &&
+	git status --untracked-files=no 2>err &&
+	test_must_be_empty err
+'
+
 test_expect_success 'status showing detached at and from a tag' '
 	test_commit atag tagging &&
 	git checkout atag &&
@@ -813,12 +838,12 @@ test_expect_success 'status while revert
 On branch master
 You are currently reverting commit $TO_REVERT.
   (fix conflicts and run "git revert --continue")
+  (use "git revert --skip" to skip this patch)
   (use "git revert --abort" to cancel the revert operation)
 
 Unmerged paths:
-  (use "git reset HEAD <file>..." to unstage)
+  (use "git restore --staged <file>..." to unstage)
   (use "git add <file>..." to mark resolution)
-
 	both modified:   to-revert.txt
 
 no changes added to commit (use "git add" and/or "git commit -a")
@@ -834,11 +859,11 @@ test_expect_success 'status while revert
 On branch master
 You are currently reverting commit $TO_REVERT.
   (all conflicts fixed: run "git revert --continue")
+  (use "git revert --skip" to skip this patch)
   (use "git revert --abort" to cancel the revert operation)
 
 Changes to be committed:
-  (use "git reset HEAD <file>..." to unstage)
-
+  (use "git restore --staged <file>..." to unstage)
 	modified:   to-revert.txt
 
 Untracked files not listed (use -u option to show untracked files)
@@ -854,6 +879,25 @@ On branch master
 nothing to commit (use -u to show untracked files)
 EOF
 	git status --untracked-files=no >actual &&
+	test_i18ncmp expected actual
+'
+
+test_expect_success 'status while reverting after committing conflict resolution' '
+	test_when_finished "git revert --abort" &&
+	git reset --hard new &&
+	test_must_fail git revert old new &&
+	echo reverted >to-revert.txt &&
+	git commit -a &&
+	cat >expected <<EOF &&
+On branch master
+Revert currently in progress.
+  (run "git revert --continue" to continue)
+  (use "git revert --skip" to skip this patch)
+  (use "git revert --abort" to cancel the revert operation)
+
+nothing to commit (use -u to show untracked files)
+EOF
+	git status --untracked-files=no >actual &&
 	test_i18ncmp expected actual
 '
 
diff -pruN 1.2.1+git2.18.0-1/git/t/t7513-interpret-trailers.sh 1.2.3+git2.25.1-1/git/t/t7513-interpret-trailers.sh
--- 1.2.1+git2.18.0-1/git/t/t7513-interpret-trailers.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t7513-interpret-trailers.sh	2020-02-17 04:47:35.000000000 +0000
@@ -538,33 +538,50 @@ test_expect_success 'with 2 files argume
 	test_cmp expected actual
 '
 
-test_expect_success 'with message that has comments' '
-	cat basic_message >message_with_comments &&
-	sed -e "s/ Z\$/ /" >>message_with_comments <<-\EOF &&
-		# comment
-
-		# other comment
-		Cc: Z
-		# yet another comment
-		Reviewed-by: Johan
-		Reviewed-by: Z
-		# last comment
-
-	EOF
-	cat basic_patch >>message_with_comments &&
-	cat basic_message >expected &&
-	cat >>expected <<-\EOF &&
-		# comment
-
-		Reviewed-by: Johan
-		Cc: Peff
-		# last comment
-
-	EOF
-	cat basic_patch >>expected &&
-	git interpret-trailers --trim-empty --trailer "Cc: Peff" message_with_comments >actual &&
-	test_cmp expected actual
-'
+# Cover multiple comment characters with the same test input.
+for char in "#" ";"
+do
+	case "$char" in
+	"#")
+		# This is the default, so let's explicitly _not_
+		# set any config to make sure it behaves as we expect.
+		;;
+	*)
+		config="-c core.commentChar=$char"
+		;;
+	esac
+
+	test_expect_success "with message that has comments ($char)" '
+		cat basic_message >message_with_comments &&
+		sed -e "s/ Z\$/ /" \
+		    -e "s/#/$char/g" >>message_with_comments <<-EOF &&
+			# comment
+
+			# other comment
+			Cc: Z
+			# yet another comment
+			Reviewed-by: Johan
+			Reviewed-by: Z
+			# last comment
+
+		EOF
+		cat basic_patch >>message_with_comments &&
+		cat basic_message >expected &&
+		sed -e "s/#/$char/g" >>expected <<-\EOF &&
+			# comment
+
+			Reviewed-by: Johan
+			Cc: Peff
+			# last comment
+
+		EOF
+		cat basic_patch >>expected &&
+		git $config interpret-trailers \
+			--trim-empty --trailer "Cc: Peff" \
+			message_with_comments >actual &&
+		test_cmp expected actual
+	'
+done
 
 test_expect_success 'with message that has an old style conflict block' '
 	cat basic_message >message_with_comments &&
@@ -1217,7 +1234,7 @@ test_expect_success 'with simple command
 	test_cmp expected actual
 '
 
-test_expect_success 'with command using commiter information' '
+test_expect_success 'with command using committer information' '
 	git config trailer.sign.ifExists "addIfDifferent" &&
 	git config trailer.sign.command "echo \"\$GIT_COMMITTER_NAME <\$GIT_COMMITTER_EMAIL>\"" &&
 	cat complex_message_body >expected &&
@@ -1417,4 +1434,46 @@ test_expect_success 'unfold' '
 	test_cmp expected actual
 '
 
+test_expect_success 'handling of --- lines in input' '
+	echo "real-trailer: just right" >expected &&
+
+	git interpret-trailers --parse >actual <<-\EOF &&
+	subject
+
+	body
+
+	not-a-trailer: too soon
+	------ this is just a line in the commit message with a bunch of
+	------ dashes; it does not have any syntactic meaning.
+
+	real-trailer: just right
+	---
+	below the dashed line may be a patch, etc.
+
+	not-a-trailer: too late
+	EOF
+
+	test_cmp expected actual
+'
+
+test_expect_success 'suppress --- handling' '
+	echo "real-trailer: just right" >expected &&
+
+	git interpret-trailers --parse --no-divider >actual <<-\EOF &&
+	subject
+
+	This commit message has a "---" in it, but because we tell
+	interpret-trailers not to respect that, it has no effect.
+
+	not-a-trailer: too soon
+	---
+
+	This is still the commit message body.
+
+	real-trailer: just right
+	EOF
+
+	test_cmp expected actual
+'
+
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t7517-per-repo-email.sh 1.2.3+git2.25.1-1/git/t/t7517-per-repo-email.sh
--- 1.2.1+git2.18.0-1/git/t/t7517-per-repo-email.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t7517-per-repo-email.sh	2020-02-17 04:47:35.000000000 +0000
@@ -72,15 +72,91 @@ test_expect_success 'noop interactive re
 	git rebase -i HEAD^
 '
 
-test_expect_success 'fast-forward rebase does not care about ident (preserve)' '
+test_expect_success REBASE_P \
+	'fast-forward rebase does not care about ident (preserve)' '
 	git checkout -B tmp side-without-commit &&
 	git rebase -p master
 '
 
-test_expect_success 'non-fast-forward rebase refuses to write commits (preserve)' '
+test_expect_success REBASE_P \
+	'non-fast-forward rebase refuses to write commits (preserve)' '
 	test_when_finished "git rebase --abort || true" &&
 	git checkout -B tmp side-with-commit &&
 	test_must_fail git rebase -p master
 '
 
+test_expect_success 'author.name overrides user.name' '
+	test_config user.name user &&
+	test_config user.email user@example.com &&
+	test_config author.name author &&
+	test_commit author-name-override-user &&
+	echo author user@example.com > expected-author &&
+	echo user user@example.com > expected-committer &&
+	git log --format="%an %ae" -1 > actual-author &&
+	git log --format="%cn %ce" -1 > actual-committer &&
+	test_cmp expected-author actual-author &&
+	test_cmp expected-committer actual-committer
+'
+
+test_expect_success 'author.email overrides user.email' '
+	test_config user.name user &&
+	test_config user.email user@example.com &&
+	test_config author.email author@example.com &&
+	test_commit author-email-override-user &&
+	echo user author@example.com > expected-author &&
+	echo user user@example.com > expected-committer &&
+	git log --format="%an %ae" -1 > actual-author &&
+	git log --format="%cn %ce" -1 > actual-committer &&
+	test_cmp expected-author actual-author &&
+	test_cmp expected-committer actual-committer
+'
+
+test_expect_success 'committer.name overrides user.name' '
+	test_config user.name user &&
+	test_config user.email user@example.com &&
+	test_config committer.name committer &&
+	test_commit committer-name-override-user &&
+	echo user user@example.com > expected-author &&
+	echo committer user@example.com > expected-committer &&
+	git log --format="%an %ae" -1 > actual-author &&
+	git log --format="%cn %ce" -1 > actual-committer &&
+	test_cmp expected-author actual-author &&
+	test_cmp expected-committer actual-committer
+'
+
+test_expect_success 'committer.email overrides user.email' '
+	test_config user.name user &&
+	test_config user.email user@example.com &&
+	test_config committer.email committer@example.com &&
+	test_commit committer-email-override-user &&
+	echo user user@example.com > expected-author &&
+	echo user committer@example.com > expected-committer &&
+	git log --format="%an %ae" -1 > actual-author &&
+	git log --format="%cn %ce" -1 > actual-committer &&
+	test_cmp expected-author actual-author &&
+	test_cmp expected-committer actual-committer
+'
+
+test_expect_success 'author and committer environment variables override config settings' '
+	test_config user.name user &&
+	test_config user.email user@example.com &&
+	test_config author.name author &&
+	test_config author.email author@example.com &&
+	test_config committer.name committer &&
+	test_config committer.email committer@example.com &&
+	GIT_AUTHOR_NAME=env_author && export GIT_AUTHOR_NAME &&
+	GIT_AUTHOR_EMAIL=env_author@example.com && export GIT_AUTHOR_EMAIL &&
+	GIT_COMMITTER_NAME=env_commit && export GIT_COMMITTER_NAME &&
+	GIT_COMMITTER_EMAIL=env_commit@example.com && export GIT_COMMITTER_EMAIL &&
+	test_commit env-override-conf &&
+	echo env_author env_author@example.com > expected-author &&
+	echo env_commit env_commit@example.com > expected-committer &&
+	git log --format="%an %ae" -1 > actual-author &&
+	git log --format="%cn %ce" -1 > actual-committer &&
+	sane_unset GIT_AUTHOR_NAME GIT_AUTHOR_EMAIL &&
+	sane_unset GIT_COMMITTER_NAME GIT_COMMITTER_EMAIL &&
+	test_cmp expected-author actual-author &&
+	test_cmp expected-committer actual-committer
+'
+
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t7519/fsmonitor-env 1.2.3+git2.25.1-1/git/t/t7519/fsmonitor-env
--- 1.2.1+git2.18.0-1/git/t/t7519/fsmonitor-env	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t7519/fsmonitor-env	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,24 @@
+#!/bin/sh
+#
+# An test hook script to integrate with git to test fsmonitor.
+#
+# The hook is passed a version (currently 1) and a time in nanoseconds
+# formatted as a string and outputs to stdout all files that have been
+# modified since the given time. Paths must be relative to the root of
+# the working tree and separated by a single NUL.
+#
+#echo "$0 $*" >&2
+
+if test "$#" -ne 2
+then
+	echo "$0: exactly 2 arguments expected" >&2
+	exit 2
+fi
+
+if test "$1" != 1
+then
+	echo "Unsupported core.fsmonitor hook version." >&2
+	exit 1
+fi
+
+printf '%s\n' $FSMONITOR_LIST
diff -pruN 1.2.1+git2.18.0-1/git/t/t7519/fsmonitor-watchman 1.2.3+git2.25.1-1/git/t/t7519/fsmonitor-watchman
--- 1.2.1+git2.18.0-1/git/t/t7519/fsmonitor-watchman	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t7519/fsmonitor-watchman	2020-02-17 04:47:35.000000000 +0000
@@ -23,7 +23,8 @@ my ($version, $time) = @ARGV;
 
 if ($version == 1) {
 	# convert nanoseconds to seconds
-	$time = int $time / 1000000000;
+	# subtract one second to make sure watchman will return all changes
+	$time = int ($time / 1000000000) - 1;
 } else {
 	die "Unsupported query-fsmonitor hook version '$version'.\n" .
 	    "Falling back to scanning...\n";
@@ -54,18 +55,12 @@ sub launch_watchman {
 	#
 	# To accomplish this, we're using the "since" generator to use the
 	# recency index to select candidate nodes and "fields" to limit the
-	# output to file names only. Then we're using the "expression" term to
-	# further constrain the results.
-	#
-	# The category of transient files that we want to ignore will have a
-	# creation clock (cclock) newer than $time_t value and will also not
-	# currently exist.
+	# output to file names only.
 
 	my $query = <<"	END";
 		["query", "$git_work_tree", {
 			"since": $time,
-			"fields": ["name"],
-			"expression": ["not", ["allof", ["since", $time, "cclock"], ["not", "exists"]]]
+			"fields": ["name"]
 		}]
 	END
 	
diff -pruN 1.2.1+git2.18.0-1/git/t/t7519-status-fsmonitor.sh 1.2.3+git2.25.1-1/git/t/t7519-status-fsmonitor.sh
--- 1.2.1+git2.18.0-1/git/t/t7519-status-fsmonitor.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t7519-status-fsmonitor.sh	2020-02-17 04:47:35.000000000 +0000
@@ -4,13 +4,6 @@ test_description='git status with file s
 
 . ./test-lib.sh
 
-#
-# To run the entire git test suite using fsmonitor:
-#
-# copy t/t7519/fsmonitor-all to a location in your path and then set
-# GIT_FSMONITOR_TEST=fsmonitor-all and run your tests.
-#
-
 # Note, after "git reset --hard HEAD" no extensions exist other than 'TREE'
 # "git update-index --fsmonitor" can be used to get the extension written
 # before testing the results.
@@ -84,21 +77,21 @@ test_expect_success 'setup' '
 
 # test that the fsmonitor extension is off by default
 test_expect_success 'fsmonitor extension is off by default' '
-	test-dump-fsmonitor >actual &&
+	test-tool dump-fsmonitor >actual &&
 	grep "^no fsmonitor" actual
 '
 
 # test that "update-index --fsmonitor" adds the fsmonitor extension
 test_expect_success 'update-index --fsmonitor" adds the fsmonitor extension' '
 	git update-index --fsmonitor &&
-	test-dump-fsmonitor >actual &&
+	test-tool dump-fsmonitor >actual &&
 	grep "^fsmonitor last update" actual
 '
 
 # test that "update-index --no-fsmonitor" removes the fsmonitor extension
 test_expect_success 'update-index --no-fsmonitor" removes the fsmonitor extension' '
 	git update-index --no-fsmonitor &&
-	test-dump-fsmonitor >actual &&
+	test-tool dump-fsmonitor >actual &&
 	grep "^no fsmonitor" actual
 '
 
@@ -113,6 +106,8 @@ EOF
 
 # test that "update-index --fsmonitor-valid" sets the fsmonitor valid bit
 test_expect_success 'update-index --fsmonitor-valid" sets the fsmonitor valid bit' '
+	write_script .git/hooks/fsmonitor-test<<-\EOF &&
+	EOF
 	git update-index --fsmonitor &&
 	git update-index --fsmonitor-valid dir1/modified &&
 	git update-index --fsmonitor-valid dir2/modified &&
@@ -171,6 +166,8 @@ EOF
 
 # test that newly added files are marked valid
 test_expect_success 'newly added files are marked valid' '
+	write_script .git/hooks/fsmonitor-test<<-\EOF &&
+	EOF
 	git add new &&
 	git add dir1/new &&
 	git add dir2/new &&
@@ -225,11 +222,12 @@ test_expect_success '*only* files return
 # Ensure commands that call refresh_index() to move the index back in time
 # properly invalidate the fsmonitor cache
 test_expect_success 'refresh_index() invalidates fsmonitor cache' '
-	write_script .git/hooks/fsmonitor-test<<-\EOF &&
-	EOF
 	clean_repo &&
 	dirty_repo &&
+	write_integration_script &&
 	git add . &&
+	write_script .git/hooks/fsmonitor-test<<-\EOF &&
+	EOF
 	git commit -m "to reset" &&
 	git reset HEAD~1 &&
 	git status >actual &&
@@ -245,9 +243,9 @@ do
 		git config core.preloadIndex $preload_val &&
 		if test $preload_val = true
 		then
-			GIT_FORCE_PRELOAD_TEST=$preload_val; export GIT_FORCE_PRELOAD_TEST
+			GIT_TEST_PRELOAD_INDEX=$preload_val; export GIT_TEST_PRELOAD_INDEX
 		else
-			unset GIT_FORCE_PRELOAD_TEST
+			sane_unset GIT_TEST_PRELOAD_INDEX
 		fi
 	'
 
@@ -301,15 +299,15 @@ do
 	done
 done
 
-# test that splitting the index dosn't interfere
+# test that splitting the index doesn't interfere
 test_expect_success 'splitting the index results in the same state' '
 	write_integration_script &&
 	dirty_repo &&
 	git update-index --fsmonitor  &&
 	git ls-files -f >expect &&
-	test-dump-fsmonitor >&2 && echo &&
+	test-tool dump-fsmonitor >&2 && echo &&
 	git update-index --fsmonitor --split-index &&
-	test-dump-fsmonitor >&2 && echo &&
+	test-tool dump-fsmonitor >&2 && echo &&
 	git ls-files -f >actual &&
 	test_cmp expect actual
 '
@@ -333,7 +331,7 @@ test_expect_success UNTRACKED_CACHE 'ign
 		git update-index --fsmonitor &&
 		GIT_TRACE_UNTRACKED_STATS="$TRASH_DIRECTORY/trace-before" \
 		git status &&
-		test-dump-untracked-cache >../before
+		test-tool dump-untracked-cache >../before
 	) &&
 	cat >>dot-git/.git/hooks/fsmonitor-test <<-\EOF &&
 	printf ".git\0"
@@ -345,7 +343,7 @@ test_expect_success UNTRACKED_CACHE 'ign
 		cd dot-git &&
 		GIT_TRACE_UNTRACKED_STATS="$TRASH_DIRECTORY/trace-after" \
 		git status &&
-		test-dump-untracked-cache >../after
+		test-tool dump-untracked-cache >../after
 	) &&
 	grep "directory invalidation" trace-before >>before &&
 	grep "directory invalidation" trace-after >>after &&
@@ -353,4 +351,31 @@ test_expect_success UNTRACKED_CACHE 'ign
 	test_cmp before after
 '
 
+test_expect_success 'discard_index() also discards fsmonitor info' '
+	test_config core.fsmonitor "$TEST_DIRECTORY/t7519/fsmonitor-all" &&
+	test_might_fail git update-index --refresh &&
+	test-tool read-cache --print-and-refresh=tracked 2 >actual &&
+	printf "tracked is%s up to date\n" "" " not" >expect &&
+	test_cmp expect actual
+'
+
+# Test unstaging entries that:
+#  - Are not flagged with CE_FSMONITOR_VALID
+#  - Have a position in the index >= the number of entries present in the index
+#    after unstaging.
+test_expect_success 'status succeeds after staging/unstaging' '
+	test_create_repo fsmonitor-stage-unstage &&
+	(
+		cd fsmonitor-stage-unstage &&
+		test_commit initial &&
+		git update-index --fsmonitor &&
+		removed=$(test_seq 1 100 | sed "s/^/z/") &&
+		touch $removed &&
+		git add $removed &&
+		git config core.fsmonitor "$TEST_DIRECTORY/t7519/fsmonitor-env" &&
+		FSMONITOR_LIST="$removed" git restore -S $removed &&
+		FSMONITOR_LIST="$removed" git status
+	)
+'
+
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t7525-status-rename.sh 1.2.3+git2.25.1-1/git/t/t7525-status-rename.sh
--- 1.2.1+git2.18.0-1/git/t/t7525-status-rename.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t7525-status-rename.sh	2020-02-17 04:47:35.000000000 +0000
@@ -84,7 +84,7 @@ test_expect_success 'status score=100%'
 	test_i18ngrep "deleted:" actual &&
 	test_i18ngrep "new file:" actual &&
 
-	git status --find-rename=100% >actual &&
+	git status --find-renames=100% >actual &&
 	test_i18ngrep "deleted:" actual &&
 	test_i18ngrep "new file:" actual
 '
@@ -93,11 +93,11 @@ test_expect_success 'status score=01%' '
 	git status -M=01% >actual &&
 	test_i18ngrep "renamed:" actual &&
 
-	git status --find-rename=01% >actual &&
+	git status --find-renames=01% >actual &&
 	test_i18ngrep "renamed:" actual
 '
 
-test_expect_success 'copies not overridden by find-rename' '
+test_expect_success 'copies not overridden by find-renames' '
 	cp renamed copy &&
 	git add copy &&
 
@@ -105,7 +105,7 @@ test_expect_success 'copies not overridd
 	test_i18ngrep "copied:" actual &&
 	test_i18ngrep "renamed:" actual &&
 
-	git -c status.renames=copies status --find-rename=01% >actual &&
+	git -c status.renames=copies status --find-renames=01% >actual &&
 	test_i18ngrep "copied:" actual &&
 	test_i18ngrep "renamed:" actual
 '
diff -pruN 1.2.1+git2.18.0-1/git/t/t7526-commit-pathspec-file.sh 1.2.3+git2.25.1-1/git/t/t7526-commit-pathspec-file.sh
--- 1.2.1+git2.18.0-1/git/t/t7526-commit-pathspec-file.sh	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t7526-commit-pathspec-file.sh	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,136 @@
+#!/bin/sh
+
+test_description='commit --pathspec-from-file'
+
+. ./test-lib.sh
+
+test_tick
+
+test_expect_success setup '
+	test_commit file0 &&
+	git tag checkpoint &&
+
+	echo A >fileA.t &&
+	echo B >fileB.t &&
+	echo C >fileC.t &&
+	echo D >fileD.t &&
+	git add fileA.t fileB.t fileC.t fileD.t
+'
+
+restore_checkpoint () {
+	git reset --soft checkpoint
+}
+
+verify_expect () {
+	git diff-tree --no-commit-id --name-status -r HEAD >actual &&
+	test_cmp expect actual
+}
+
+test_expect_success '--pathspec-from-file from stdin' '
+	restore_checkpoint &&
+
+	echo fileA.t | git commit --pathspec-from-file=- -m "Commit" &&
+
+	cat >expect <<-\EOF &&
+	A	fileA.t
+	EOF
+	verify_expect
+'
+
+test_expect_success '--pathspec-from-file from file' '
+	restore_checkpoint &&
+
+	echo fileA.t >list &&
+	git commit --pathspec-from-file=list -m "Commit" &&
+
+	cat >expect <<-\EOF &&
+	A	fileA.t
+	EOF
+	verify_expect
+'
+
+test_expect_success 'NUL delimiters' '
+	restore_checkpoint &&
+
+	printf "fileA.t\0fileB.t\0" | git commit --pathspec-from-file=- --pathspec-file-nul -m "Commit" &&
+
+	cat >expect <<-\EOF &&
+	A	fileA.t
+	A	fileB.t
+	EOF
+	verify_expect
+'
+
+test_expect_success 'LF delimiters' '
+	restore_checkpoint &&
+
+	printf "fileA.t\nfileB.t\n" | git commit --pathspec-from-file=- -m "Commit" &&
+
+	cat >expect <<-\EOF &&
+	A	fileA.t
+	A	fileB.t
+	EOF
+	verify_expect
+'
+
+test_expect_success 'no trailing delimiter' '
+	restore_checkpoint &&
+
+	printf "fileA.t\nfileB.t" | git commit --pathspec-from-file=- -m "Commit" &&
+
+	cat >expect <<-\EOF &&
+	A	fileA.t
+	A	fileB.t
+	EOF
+	verify_expect
+'
+
+test_expect_success 'CRLF delimiters' '
+	restore_checkpoint &&
+
+	printf "fileA.t\r\nfileB.t\r\n" | git commit --pathspec-from-file=- -m "Commit" &&
+
+	cat >expect <<-\EOF &&
+	A	fileA.t
+	A	fileB.t
+	EOF
+	verify_expect
+'
+
+test_expect_success 'quotes' '
+	restore_checkpoint &&
+
+	printf "\"file\\101.t\"" | git commit --pathspec-from-file=- -m "Commit" &&
+
+	cat >expect <<-\EOF &&
+	A	fileA.t
+	EOF
+	verify_expect expect
+'
+
+test_expect_success 'quotes not compatible with --pathspec-file-nul' '
+	restore_checkpoint &&
+
+	printf "\"file\\101.t\"" >list &&
+	test_must_fail git commit --pathspec-from-file=list --pathspec-file-nul -m "Commit"
+'
+
+test_expect_success 'only touches what was listed' '
+	restore_checkpoint &&
+
+	printf "fileB.t\nfileC.t\n" | git commit --pathspec-from-file=- -m "Commit" &&
+
+	cat >expect <<-\EOF &&
+	A	fileB.t
+	A	fileC.t
+	EOF
+	verify_expect
+'
+
+test_expect_success '--pathspec-from-file and --all cannot be used together' '
+	restore_checkpoint &&
+	test_must_fail git commit --pathspec-from-file=- --all -m "Commit" 2>err &&
+	test_i18ngrep "[-]-pathspec-from-file with -a does not make sense" err
+'
+
+test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t7600-merge.sh 1.2.3+git2.25.1-1/git/t/t7600-merge.sh
--- 1.2.1+git2.18.0-1/git/t/t7600-merge.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t7600-merge.sh	2020-02-17 04:47:35.000000000 +0000
@@ -38,7 +38,6 @@ printf '%s\n' '1 X' 2 3 4 5 6 7 8 9 >res
 printf '%s\n' '1 X' 2 3 4 '5 X' 6 7 8 9 >result.1-5
 printf '%s\n' '1 X' 2 3 4 '5 X' 6 7 8 '9 X' >result.1-5-9
 printf '%s\n' 1 2 3 4 5 6 7 8 '9 Z' >result.9z
->empty
 
 create_merge_msgs () {
 	echo "Merge tag 'c2'" >msg.1-5 &&
@@ -58,8 +57,6 @@ create_merge_msgs () {
 		echo &&
 		git log --no-merges ^HEAD c2 c3
 	} >squash.1-5-9 &&
-	: >msg.nologff &&
-	: >msg.nolognoff &&
 	{
 		echo "* tag 'c3':" &&
 		echo "  commit 3"
@@ -236,20 +233,65 @@ test_expect_success 'merge --squash c3 w
 	cat result.9z >file &&
 	git commit --no-edit -a &&
 
-	{
-		cat <<-EOF
-		Squashed commit of the following:
+	cat >expect <<-EOF &&
+	Squashed commit of the following:
 
-		$(git show -s c7)
+	$(git show -s c7)
 
-		# Conflicts:
-		#	file
-		EOF
-	} >expect &&
-	git cat-file commit HEAD | sed -e '1,/^$/d' >actual &&
+	# Conflicts:
+	#	file
+	EOF
+	git cat-file commit HEAD >raw &&
+	sed -e '1,/^$/d' raw >actual &&
 	test_cmp expect actual
 '
 
+test_expect_success 'merge c3 with c7 with commit.cleanup = scissors' '
+	git config commit.cleanup scissors &&
+	git reset --hard c3 &&
+	test_must_fail git merge c7 &&
+	cat result.9z >file &&
+	git commit --no-edit -a &&
+
+	cat >expect <<-\EOF &&
+	Merge tag '"'"'c7'"'"'
+
+	# ------------------------ >8 ------------------------
+	# Do not modify or remove the line above.
+	# Everything below it will be ignored.
+	#
+	# Conflicts:
+	#	file
+	EOF
+	git cat-file commit HEAD >raw &&
+	sed -e '1,/^$/d' raw >actual &&
+	test_i18ncmp expect actual
+'
+
+test_expect_success 'merge c3 with c7 with --squash commit.cleanup = scissors' '
+	git config commit.cleanup scissors &&
+	git reset --hard c3 &&
+	test_must_fail git merge --squash c7 &&
+	cat result.9z >file &&
+	git commit --no-edit -a &&
+
+	cat >expect <<-EOF &&
+	Squashed commit of the following:
+
+	$(git show -s c7)
+
+	# ------------------------ >8 ------------------------
+	# Do not modify or remove the line above.
+	# Everything below it will be ignored.
+	#
+	# Conflicts:
+	#	file
+	EOF
+	git cat-file commit HEAD >raw &&
+	sed -e '1,/^$/d' raw >actual &&
+	test_i18ncmp expect actual
+'
+
 test_debug 'git log --graph --decorate --oneline --all'
 
 test_expect_success 'merge c1 with c2 and c3' '
@@ -519,7 +561,7 @@ test_expect_success 'tolerate unknown va
 	test_tick &&
 	git merge c1 2>message &&
 	verify_head "$c1" &&
-	test_cmp empty message
+	test_must_be_empty message
 '
 
 test_expect_success 'combining --squash and --no-ff is refused' '
@@ -528,6 +570,12 @@ test_expect_success 'combining --squash
 	test_must_fail git merge --no-ff --squash c1
 '
 
+test_expect_success 'combining --squash and --commit is refused' '
+	git reset --hard c0 &&
+	test_must_fail git merge --squash --commit c1 &&
+	test_must_fail git merge --commit --squash c1
+'
+
 test_expect_success 'option --ff-only overwrites --no-ff' '
 	git merge --no-ff --ff-only c1 &&
 	test_must_fail git merge --no-ff --ff-only c2
@@ -551,13 +599,13 @@ test_expect_success 'merge log message'
 	git reset --hard c0 &&
 	git merge --no-log c2 &&
 	git show -s --pretty=format:%b HEAD >msg.act &&
-	test_cmp msg.nologff msg.act &&
+	test_must_be_empty msg.act &&
 
 	git reset --hard c0 &&
 	test_config branch.master.mergeoptions "--no-ff" &&
 	git merge --no-log c2 &&
 	git show -s --pretty=format:%b HEAD >msg.act &&
-	test_cmp msg.nolognoff msg.act &&
+	test_must_be_empty msg.act &&
 
 	git merge --log c3 &&
 	git show -s --pretty=format:%b HEAD >msg.act &&
@@ -683,10 +731,10 @@ cat >editor <<\EOF
 (
 	echo "Merge work done on the side branch c1"
 	echo
-	cat <"$1"
+	cat "$1"
 ) >"$1.tmp" && mv "$1.tmp" "$1"
 # strip comments and blank lines from end of message
-sed -e '/^#/d' < "$1" | sed -e :a -e '/^\n*$/{$d;N;ba' -e '}' > expected
+sed -e '/^#/d' "$1" | sed -e :a -e '/^\n*$/{$d;N;ba' -e '}' >expected
 EOF
 chmod 755 editor
 
@@ -771,14 +819,14 @@ test_expect_success 'set up mod-256 conf
 	git commit -m base &&
 
 	# one side changes the first line of each to "master"
-	sed s/-1/-master/ <file >tmp &&
+	sed s/-1/-master/ file >tmp &&
 	mv tmp file &&
 	git commit -am master &&
 
 	# and the other to "side"; merging the two will
 	# yield 256 separate conflicts
 	git checkout -b side HEAD^ &&
-	sed s/-1/-side/ <file >tmp &&
+	sed s/-1/-side/ file >tmp &&
 	mv tmp file &&
 	git commit -am side
 '
@@ -817,7 +865,7 @@ EOF
 test_expect_success EXECKEEPSPID 'killed merge can be completed with --continue' '
 	git reset --hard c0 &&
 	! "$SHELL_PATH" -c '\''
-	  echo kill -TERM $$ >> .git/FAKE_EDITOR
+	  echo kill -TERM $$ >>.git/FAKE_EDITOR
 	  GIT_EDITOR=.git/FAKE_EDITOR
 	  export GIT_EDITOR
 	  exec git merge --no-ff --edit c1'\'' &&
@@ -825,4 +873,50 @@ test_expect_success EXECKEEPSPID 'killed
 	verify_parents $c0 $c1
 '
 
+test_expect_success 'merge --quit' '
+	git init merge-quit &&
+	(
+		cd merge-quit &&
+		test_commit base &&
+		echo one >>base.t &&
+		git commit -am one &&
+		git branch one &&
+		git checkout base &&
+		echo two >>base.t &&
+		git commit -am two &&
+		test_must_fail git -c rerere.enabled=true merge one &&
+		test_path_is_file .git/MERGE_HEAD &&
+		test_path_is_file .git/MERGE_MODE &&
+		test_path_is_file .git/MERGE_MSG &&
+		git rerere status >rerere.before &&
+		git merge --quit &&
+		test_path_is_missing .git/MERGE_HEAD &&
+		test_path_is_missing .git/MERGE_MODE &&
+		test_path_is_missing .git/MERGE_MSG &&
+		git rerere status >rerere.after &&
+		test_must_be_empty rerere.after &&
+		! test_cmp rerere.after rerere.before
+	)
+'
+
+test_expect_success 'merge suggests matching remote refname' '
+	git commit --allow-empty -m not-local &&
+	git update-ref refs/remotes/origin/not-local HEAD &&
+	git reset --hard HEAD^ &&
+
+	# This is white-box testing hackery; we happen to know
+	# that reading packed refs is more picky about the memory
+	# ownership of strings we pass to for_each_ref() callbacks.
+	git pack-refs --all --prune &&
+
+	test_must_fail git merge not-local 2>stderr &&
+	grep origin/not-local stderr
+'
+
+test_expect_success 'suggested names are not ambiguous' '
+	git update-ref refs/heads/origin/not-local HEAD &&
+	test_must_fail git merge not-local 2>stderr &&
+	grep remotes/origin/not-local stderr
+'
+
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t7604-merge-custom-message.sh 1.2.3+git2.25.1-1/git/t/t7604-merge-custom-message.sh
--- 1.2.1+git2.18.0-1/git/t/t7604-merge-custom-message.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t7604-merge-custom-message.sh	2020-02-17 04:47:35.000000000 +0000
@@ -16,16 +16,16 @@ create_merge_msgs() {
 }
 
 test_expect_success 'setup' '
-	echo c0 > c0.c &&
+	echo c0 >c0.c &&
 	git add c0.c &&
 	git commit -m c0 &&
 	git tag c0 &&
-	echo c1 > c1.c &&
+	echo c1 >c1.c &&
 	git add c1.c &&
 	git commit -m c1 &&
 	git tag c1 &&
 	git reset --hard c0 &&
-	echo c2 > c2.c &&
+	echo c2 >c2.c &&
 	git add c2.c &&
 	git commit -m c2 &&
 	git tag c2 &&
@@ -36,15 +36,80 @@ test_expect_success 'setup' '
 test_expect_success 'merge c2 with a custom message' '
 	git reset --hard c1 &&
 	git merge -m "$(cat exp.subject)" c2 &&
-	git cat-file commit HEAD | sed -e "1,/^$/d" >actual &&
+	git cat-file commit HEAD >raw &&
+	sed -e "1,/^$/d" raw >actual &&
 	test_cmp exp.subject actual
 '
 
 test_expect_success 'merge --log appends to custom message' '
 	git reset --hard c1 &&
 	git merge --log -m "$(cat exp.subject)" c2 &&
-	git cat-file commit HEAD | sed -e "1,/^$/d" >actual &&
+	git cat-file commit HEAD >raw &&
+	sed -e "1,/^$/d" raw >actual &&
 	test_cmp exp.log actual
 '
 
+mesg_with_comment_and_newlines='
+# text
+
+'
+
+test_expect_success 'prepare file with comment line and trailing newlines'  '
+	printf "%s" "$mesg_with_comment_and_newlines" >expect
+'
+
+test_expect_success 'cleanup commit messages (verbatim option)' '
+	git reset --hard c1 &&
+	git merge --cleanup=verbatim -F expect c2 &&
+	git cat-file commit HEAD >raw &&
+	sed -e "1,/^$/d" raw >actual &&
+	test_cmp expect actual
+'
+
+test_expect_success 'cleanup commit messages (whitespace option)' '
+	git reset --hard c1 &&
+	test_write_lines "" "# text" "" >text &&
+	echo "# text" >expect &&
+	git merge --cleanup=whitespace -F text c2 &&
+	git cat-file commit HEAD >raw &&
+	sed -e "1,/^$/d" raw >actual &&
+	test_cmp expect actual
+'
+
+test_expect_success 'cleanup merge messages (scissors option)' '
+	git reset --hard c1 &&
+	cat >text <<-\EOF &&
+
+	# to be kept
+
+	  # ------------------------ >8 ------------------------
+	# to be kept, too
+	# ------------------------ >8 ------------------------
+	to be removed
+	# ------------------------ >8 ------------------------
+	to be removed, too
+	EOF
+
+	cat >expect <<-\EOF &&
+	# to be kept
+
+	  # ------------------------ >8 ------------------------
+	# to be kept, too
+	EOF
+	git merge --cleanup=scissors -e -F text c2 &&
+	git cat-file commit HEAD >raw &&
+	sed -e "1,/^$/d" raw >actual &&
+	test_cmp expect actual
+'
+
+test_expect_success 'cleanup commit messages (strip option)' '
+	git reset --hard c1 &&
+	test_write_lines "" "# text" "sample" "" >text &&
+	echo sample >expect &&
+	git merge --cleanup=strip -F text c2 &&
+	git cat-file commit HEAD >raw &&
+	sed -e "1,/^$/d" raw >actual &&
+	test_cmp expect actual
+'
+
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t7610-mergetool.sh 1.2.3+git2.25.1-1/git/t/t7610-mergetool.sh
--- 1.2.1+git2.18.0-1/git/t/t7610-mergetool.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t7610-mergetool.sh	2020-02-17 04:47:35.000000000 +0000
@@ -57,18 +57,18 @@ test_expect_success 'setup' '
 
 	git checkout -b delete-base branch1 &&
 	mkdir -p a/a &&
-	(echo one; echo two; echo 3; echo 4) >a/a/file.txt &&
+	test_write_lines one two 3 4 >a/a/file.txt &&
 	git add a/a/file.txt &&
 	git commit -m"base file" &&
 	git checkout -b move-to-b delete-base &&
 	mkdir -p b/b &&
 	git mv a/a/file.txt b/b/file.txt &&
-	(echo one; echo two; echo 4) >b/b/file.txt &&
+	test_write_lines one two 4 >b/b/file.txt &&
 	git commit -a -m"move to b" &&
 	git checkout -b move-to-c delete-base &&
 	mkdir -p c/c &&
 	git mv a/a/file.txt c/c/file.txt &&
-	(echo one; echo two; echo 3) >c/c/file.txt &&
+	test_write_lines one two 3 >c/c/file.txt &&
 	git commit -a -m"move to c" &&
 
 	git checkout -b stash1 master &&
@@ -130,18 +130,71 @@ test_expect_success 'custom mergetool' '
 	test_when_finished "git reset --hard" &&
 	git checkout -b test$test_count branch1 &&
 	git submodule update -N &&
-	test_must_fail git merge master >/dev/null 2>&1 &&
-	( yes "" | git mergetool both >/dev/null 2>&1 ) &&
-	( yes "" | git mergetool file1 file1 ) &&
-	( yes "" | git mergetool file2 "spaced name" >/dev/null 2>&1 ) &&
-	( yes "" | git mergetool subdir/file3 >/dev/null 2>&1 ) &&
-	( yes "d" | git mergetool file11 >/dev/null 2>&1 ) &&
-	( yes "d" | git mergetool file12 >/dev/null 2>&1 ) &&
-	( yes "l" | git mergetool submod >/dev/null 2>&1 ) &&
-	test "$(cat file1)" = "master updated" &&
-	test "$(cat file2)" = "master new" &&
-	test "$(cat subdir/file3)" = "master new sub" &&
-	test "$(cat submod/bar)" = "branch1 submodule" &&
+	test_must_fail git merge master &&
+	yes "" | git mergetool both &&
+	yes "" | git mergetool file1 file1 &&
+	yes "" | git mergetool file2 "spaced name" &&
+	yes "" | git mergetool subdir/file3 &&
+	yes "d" | git mergetool file11 &&
+	yes "d" | git mergetool file12 &&
+	yes "l" | git mergetool submod &&
+	echo "master updated" >expect &&
+	test_cmp expect file1 &&
+	echo "master new" >expect &&
+	test_cmp expect file2 &&
+	echo "master new sub" >expect &&
+	test_cmp expect subdir/file3 &&
+	echo "branch1 submodule" >expect &&
+	test_cmp expect submod/bar &&
+	git commit -m "branch1 resolved with mergetool"
+'
+
+test_expect_success 'gui mergetool' '
+	test_config merge.guitool myguitool &&
+	test_config mergetool.myguitool.cmd "(printf \"gui \" && cat \"\$REMOTE\") >\"\$MERGED\"" &&
+	test_config mergetool.myguitool.trustExitCode true &&
+	test_when_finished "git reset --hard" &&
+	git checkout -b test$test_count branch1 &&
+	git submodule update -N &&
+	test_must_fail git merge master &&
+	yes "" | git mergetool --gui both &&
+	yes "" | git mergetool -g file1 file1 &&
+	yes "" | git mergetool --gui file2 "spaced name" &&
+	yes "" | git mergetool --gui subdir/file3 &&
+	yes "d" | git mergetool --gui file11 &&
+	yes "d" | git mergetool --gui file12 &&
+	yes "l" | git mergetool --gui submod &&
+	echo "gui master updated" >expect &&
+	test_cmp expect file1 &&
+	echo "gui master new" >expect &&
+	test_cmp expect file2 &&
+	echo "gui master new sub" >expect &&
+	test_cmp expect subdir/file3 &&
+	echo "branch1 submodule" >expect &&
+	test_cmp expect submod/bar &&
+	git commit -m "branch1 resolved with mergetool"
+'
+
+test_expect_success 'gui mergetool without merge.guitool set falls back to merge.tool' '
+	test_when_finished "git reset --hard" &&
+	git checkout -b test$test_count branch1 &&
+	git submodule update -N &&
+	test_must_fail git merge master &&
+	yes "" | git mergetool --gui both &&
+	yes "" | git mergetool -g file1 file1 &&
+	yes "" | git mergetool --gui file2 "spaced name" &&
+	yes "" | git mergetool --gui subdir/file3 &&
+	yes "d" | git mergetool --gui file11 &&
+	yes "d" | git mergetool --gui file12 &&
+	yes "l" | git mergetool --gui submod &&
+	echo "master updated" >expect &&
+	test_cmp expect file1 &&
+	echo "master new" >expect &&
+	test_cmp expect file2 &&
+	echo "master new sub" >expect &&
+	test_cmp expect subdir/file3 &&
+	echo "branch1 submodule" >expect &&
+	test_cmp expect submod/bar &&
 	git commit -m "branch1 resolved with mergetool"
 '
 
@@ -153,20 +206,21 @@ test_expect_success 'mergetool crlf' '
 	# test_when_finished is LIFO.)
 	test_config core.autocrlf true &&
 	git checkout -b test$test_count branch1 &&
-	test_must_fail git merge master >/dev/null 2>&1 &&
-	( yes "" | git mergetool file1 >/dev/null 2>&1 ) &&
-	( yes "" | git mergetool file2 >/dev/null 2>&1 ) &&
-	( yes "" | git mergetool "spaced name" >/dev/null 2>&1 ) &&
-	( yes "" | git mergetool both >/dev/null 2>&1 ) &&
-	( yes "" | git mergetool subdir/file3 >/dev/null 2>&1 ) &&
-	( yes "d" | git mergetool file11 >/dev/null 2>&1 ) &&
-	( yes "d" | git mergetool file12 >/dev/null 2>&1 ) &&
-	( yes "r" | git mergetool submod >/dev/null 2>&1 ) &&
+	test_must_fail git merge master &&
+	yes "" | git mergetool file1 &&
+	yes "" | git mergetool file2 &&
+	yes "" | git mergetool "spaced name" &&
+	yes "" | git mergetool both &&
+	yes "" | git mergetool subdir/file3 &&
+	yes "d" | git mergetool file11 &&
+	yes "d" | git mergetool file12 &&
+	yes "r" | git mergetool submod &&
 	test "$(printf x | cat file1 -)" = "$(printf "master updated\r\nx")" &&
 	test "$(printf x | cat file2 -)" = "$(printf "master new\r\nx")" &&
 	test "$(printf x | cat subdir/file3 -)" = "$(printf "master new sub\r\nx")" &&
 	git submodule update -N &&
-	test "$(cat submod/bar)" = "master submodule" &&
+	echo "master submodule" >expect &&
+	test_cmp expect submod/bar &&
 	git commit -m "branch1 resolved with mergetool - autocrlf"
 '
 
@@ -176,9 +230,10 @@ test_expect_success 'mergetool in subdir
 	git submodule update -N &&
 	(
 		cd subdir &&
-		test_must_fail git merge master >/dev/null 2>&1 &&
-		( yes "" | git mergetool file3 >/dev/null 2>&1 ) &&
-		test "$(cat file3)" = "master new sub"
+		test_must_fail git merge master &&
+		yes "" | git mergetool file3 &&
+		echo "master new sub" >expect &&
+		test_cmp expect file3
 	)
 '
 
@@ -188,17 +243,20 @@ test_expect_success 'mergetool on file i
 	git submodule update -N &&
 	(
 		cd subdir &&
-		test_must_fail git merge master >/dev/null 2>&1 &&
-		( yes "" | git mergetool file3 >/dev/null 2>&1 ) &&
-		( yes "" | git mergetool ../file1 >/dev/null 2>&1 ) &&
-		( yes "" | git mergetool ../file2 ../spaced\ name >/dev/null 2>&1 ) &&
-		( yes "" | git mergetool ../both >/dev/null 2>&1 ) &&
-		( yes "d" | git mergetool ../file11 >/dev/null 2>&1 ) &&
-		( yes "d" | git mergetool ../file12 >/dev/null 2>&1 ) &&
-		( yes "l" | git mergetool ../submod >/dev/null 2>&1 ) &&
-		test "$(cat ../file1)" = "master updated" &&
-		test "$(cat ../file2)" = "master new" &&
-		test "$(cat ../submod/bar)" = "branch1 submodule" &&
+		test_must_fail git merge master &&
+		yes "" | git mergetool file3 &&
+		yes "" | git mergetool ../file1 &&
+		yes "" | git mergetool ../file2 ../spaced\ name &&
+		yes "" | git mergetool ../both &&
+		yes "d" | git mergetool ../file11 &&
+		yes "d" | git mergetool ../file12 &&
+		yes "l" | git mergetool ../submod &&
+		echo "master updated" >expect &&
+		test_cmp expect ../file1 &&
+		echo "master new" >expect &&
+		test_cmp expect ../file2 &&
+		echo "branch1 submodule" >expect &&
+		test_cmp expect ../submod/bar &&
 		git commit -m "branch1 resolved with mergetool - subdir"
 	)
 '
@@ -209,9 +267,9 @@ test_expect_success 'mergetool skips aut
 	git submodule update -N &&
 	test_must_fail git merge master &&
 	test -n "$(git ls-files -u)" &&
-	( yes "d" | git mergetool file11 >/dev/null 2>&1 ) &&
-	( yes "d" | git mergetool file12 >/dev/null 2>&1 ) &&
-	( yes "l" | git mergetool submod >/dev/null 2>&1 ) &&
+	yes "d" | git mergetool file11 &&
+	yes "d" | git mergetool file12 &&
+	yes "l" | git mergetool submod &&
 	output="$(git mergetool --no-prompt)" &&
 	test "$output" = "No files need merging"
 '
@@ -223,13 +281,17 @@ test_expect_success 'mergetool merges al
 	(
 		cd subdir &&
 		test_must_fail git merge master &&
-		( yes "r" | git mergetool ../submod ) &&
-		( yes "d" "d" | git mergetool --no-prompt ) &&
-		test "$(cat ../file1)" = "master updated" &&
-		test "$(cat ../file2)" = "master new" &&
-		test "$(cat file3)" = "master new sub" &&
+		yes "r" | git mergetool ../submod &&
+		yes "d" "d" | git mergetool --no-prompt &&
+		echo "master updated" >expect &&
+		test_cmp expect ../file1 &&
+		echo "master new" >expect &&
+		test_cmp expect ../file2 &&
+		echo "master new sub" >expect &&
+		test_cmp expect file3 &&
 		( cd .. && git submodule update -N ) &&
-		test "$(cat ../submod/bar)" = "master submodule" &&
+		echo "master submodule" >expect &&
+		test_cmp expect ../submod/bar &&
 		git commit -m "branch2 resolved by mergetool from subdir"
 	)
 '
@@ -242,13 +304,17 @@ test_expect_success 'mergetool merges al
 	(
 		cd subdir &&
 		test_must_fail git merge master &&
-		( yes "r" | git mergetool ../submod ) &&
-		( yes "d" "d" | git mergetool --no-prompt ) &&
-		test "$(cat ../file1)" = "master updated" &&
-		test "$(cat ../file2)" = "master new" &&
-		test "$(cat file3)" = "master new sub" &&
+		yes "r" | git mergetool ../submod &&
+		yes "d" "d" | git mergetool --no-prompt &&
+		echo "master updated" >expect &&
+		test_cmp expect ../file1 &&
+		echo "master new" >expect &&
+		test_cmp expect ../file2 &&
+		echo "master new sub" >expect &&
+		test_cmp expect file3 &&
 		( cd .. && git submodule update -N ) &&
-		test "$(cat ../submod/bar)" = "master submodule" &&
+		echo "master submodule" >expect &&
+		test_cmp expect ../submod/bar &&
 		git commit -m "branch2 resolved by mergetool from subdir"
 	)
 '
@@ -259,9 +325,9 @@ test_expect_success 'mergetool skips res
 	rm -rf .git/rr-cache &&
 	git checkout -b test$test_count branch1 &&
 	git submodule update -N &&
-	test_must_fail git merge master >/dev/null 2>&1 &&
-	( yes "l" | git mergetool --no-prompt submod >/dev/null 2>&1 ) &&
-	( yes "d" "d" | git mergetool --no-prompt >/dev/null 2>&1 ) &&
+	test_must_fail git merge master &&
+	yes "l" | git mergetool --no-prompt submod &&
+	yes "d" "d" | git mergetool --no-prompt &&
 	git submodule update -N &&
 	output="$(yes "n" | git mergetool --no-prompt)" &&
 	test "$output" = "No files need merging"
@@ -302,9 +368,10 @@ test_expect_success 'mergetool takes par
 	git submodule update -N &&
 	test_must_fail git merge master &&
 
-	( yes "" | git mergetool subdir ) &&
+	yes "" | git mergetool subdir &&
 
-	test "$(cat subdir/file3)" = "master new sub"
+	echo "master new sub" >expect &&
+	test_cmp expect subdir/file3
 '
 
 test_expect_success 'mergetool delete/delete conflict' '
@@ -328,9 +395,8 @@ test_expect_success 'mergetool produces
 	git checkout -b test$test_count move-to-c &&
 	test_config mergetool.keepBackup true &&
 	test_must_fail git merge move-to-b &&
-	: >expect &&
 	echo d | git mergetool a/a/file.txt 2>actual &&
-	test_cmp expect actual &&
+	test_must_be_empty actual &&
 	! test -d a
 '
 
@@ -349,7 +415,7 @@ test_expect_success 'mergetool keeps tem
 	git checkout -b test$test_count move-to-c &&
 	test_config mergetool.keepTemporaries true &&
 	test_must_fail git merge move-to-b &&
-	! (echo a; echo n) | git mergetool a/a/file.txt &&
+	! test_write_lines a n | git mergetool a/a/file.txt &&
 	test -d a/a &&
 	cat >expect <<-\EOF &&
 	file_BASE_.txt
@@ -370,14 +436,16 @@ test_expect_success 'deleted vs modified
 	git checkout -b test$test_count.a test$test_count &&
 	test_must_fail git merge master &&
 	test -n "$(git ls-files -u)" &&
-	( yes "" | git mergetool file1 file2 spaced\ name subdir/file3 >/dev/null 2>&1 ) &&
-	( yes "" | git mergetool both >/dev/null 2>&1 ) &&
-	( yes "d" | git mergetool file11 file12 >/dev/null 2>&1 ) &&
-	( yes "r" | git mergetool submod ) &&
+	yes "" | git mergetool file1 file2 spaced\ name subdir/file3 &&
+	yes "" | git mergetool both &&
+	yes "d" | git mergetool file11 file12 &&
+	yes "r" | git mergetool submod &&
 	rmdir submod && mv submod-movedaside submod &&
-	test "$(cat submod/bar)" = "branch1 submodule" &&
+	echo "branch1 submodule" >expect &&
+	test_cmp expect submod/bar &&
 	git submodule update -N &&
-	test "$(cat submod/bar)" = "master submodule" &&
+	echo "master submodule" >expect &&
+	test_cmp expect submod/bar &&
 	output="$(git mergetool --no-prompt)" &&
 	test "$output" = "No files need merging" &&
 	git commit -m "Merge resolved by keeping module" &&
@@ -387,10 +455,10 @@ test_expect_success 'deleted vs modified
 	git submodule update -N &&
 	test_must_fail git merge master &&
 	test -n "$(git ls-files -u)" &&
-	( yes "" | git mergetool file1 file2 spaced\ name subdir/file3 >/dev/null 2>&1 ) &&
-	( yes "" | git mergetool both >/dev/null 2>&1 ) &&
-	( yes "d" | git mergetool file11 file12 >/dev/null 2>&1 ) &&
-	( yes "l" | git mergetool submod ) &&
+	yes "" | git mergetool file1 file2 spaced\ name subdir/file3 &&
+	yes "" | git mergetool both &&
+	yes "d" | git mergetool file11 file12 &&
+	yes "l" | git mergetool submod &&
 	test ! -e submod &&
 	output="$(git mergetool --no-prompt)" &&
 	test "$output" = "No files need merging" &&
@@ -401,10 +469,10 @@ test_expect_success 'deleted vs modified
 	git submodule update -N &&
 	test_must_fail git merge test$test_count &&
 	test -n "$(git ls-files -u)" &&
-	( yes "" | git mergetool file1 file2 spaced\ name subdir/file3 >/dev/null 2>&1 ) &&
-	( yes "" | git mergetool both >/dev/null 2>&1 ) &&
-	( yes "d" | git mergetool file11 file12 >/dev/null 2>&1 ) &&
-	( yes "r" | git mergetool submod ) &&
+	yes "" | git mergetool file1 file2 spaced\ name subdir/file3 &&
+	yes "" | git mergetool both &&
+	yes "d" | git mergetool file11 file12 &&
+	yes "r" | git mergetool submod &&
 	test ! -e submod &&
 	test -d submod.orig &&
 	git submodule update -N &&
@@ -417,13 +485,15 @@ test_expect_success 'deleted vs modified
 	git submodule update -N &&
 	test_must_fail git merge test$test_count &&
 	test -n "$(git ls-files -u)" &&
-	( yes "" | git mergetool file1 file2 spaced\ name subdir/file3 >/dev/null 2>&1 ) &&
-	( yes "" | git mergetool both >/dev/null 2>&1 ) &&
-	( yes "d" | git mergetool file11 file12 >/dev/null 2>&1 ) &&
-	( yes "l" | git mergetool submod ) &&
-	test "$(cat submod/bar)" = "master submodule" &&
+	yes "" | git mergetool file1 file2 spaced\ name subdir/file3 &&
+	yes "" | git mergetool both &&
+	yes "d" | git mergetool file11 file12 &&
+	yes "l" | git mergetool submod &&
+	echo "master submodule" >expect &&
+	test_cmp expect submod/bar &&
 	git submodule update -N &&
-	test "$(cat submod/bar)" = "master submodule" &&
+	echo "master submodule" >expect &&
+	test_cmp expect submod/bar &&
 	output="$(git mergetool --no-prompt)" &&
 	test "$output" = "No files need merging" &&
 	git commit -m "Merge resolved by keeping module"
@@ -441,14 +511,16 @@ test_expect_success 'file vs modified su
 	git checkout -b test$test_count.a branch1 &&
 	test_must_fail git merge master &&
 	test -n "$(git ls-files -u)" &&
-	( yes "" | git mergetool file1 file2 spaced\ name subdir/file3 >/dev/null 2>&1 ) &&
-	( yes "" | git mergetool both >/dev/null 2>&1 ) &&
-	( yes "d" | git mergetool file11 file12 >/dev/null 2>&1 ) &&
-	( yes "r" | git mergetool submod ) &&
+	yes "" | git mergetool file1 file2 spaced\ name subdir/file3 &&
+	yes "" | git mergetool both &&
+	yes "d" | git mergetool file11 file12 &&
+	yes "r" | git mergetool submod &&
 	rmdir submod && mv submod-movedaside submod &&
-	test "$(cat submod/bar)" = "branch1 submodule" &&
+	echo "branch1 submodule" >expect &&
+	test_cmp expect submod/bar &&
 	git submodule update -N &&
-	test "$(cat submod/bar)" = "master submodule" &&
+	echo "master submodule" >expect &&
+	test_cmp expect submod/bar &&
 	output="$(git mergetool --no-prompt)" &&
 	test "$output" = "No files need merging" &&
 	git commit -m "Merge resolved by keeping module" &&
@@ -457,12 +529,13 @@ test_expect_success 'file vs modified su
 	git checkout -b test$test_count.b test$test_count &&
 	test_must_fail git merge master &&
 	test -n "$(git ls-files -u)" &&
-	( yes "" | git mergetool file1 file2 spaced\ name subdir/file3 >/dev/null 2>&1 ) &&
-	( yes "" | git mergetool both >/dev/null 2>&1 ) &&
-	( yes "d" | git mergetool file11 file12 >/dev/null 2>&1 ) &&
-	( yes "l" | git mergetool submod ) &&
+	yes "" | git mergetool file1 file2 spaced\ name subdir/file3 &&
+	yes "" | git mergetool both &&
+	yes "d" | git mergetool file11 file12 &&
+	yes "l" | git mergetool submod &&
 	git submodule update -N &&
-	test "$(cat submod)" = "not a submodule" &&
+	echo "not a submodule" >expect &&
+	test_cmp expect submod &&
 	output="$(git mergetool --no-prompt)" &&
 	test "$output" = "No files need merging" &&
 	git commit -m "Merge resolved by keeping file" &&
@@ -473,13 +546,14 @@ test_expect_success 'file vs modified su
 	git submodule update -N &&
 	test_must_fail git merge test$test_count &&
 	test -n "$(git ls-files -u)" &&
-	( yes "" | git mergetool file1 file2 spaced\ name subdir/file3 >/dev/null 2>&1 ) &&
-	( yes "" | git mergetool both >/dev/null 2>&1 ) &&
-	( yes "d" | git mergetool file11 file12 >/dev/null 2>&1 ) &&
-	( yes "r" | git mergetool submod ) &&
+	yes "" | git mergetool file1 file2 spaced\ name subdir/file3 &&
+	yes "" | git mergetool both &&
+	yes "d" | git mergetool file11 file12 &&
+	yes "r" | git mergetool submod &&
 	test -d submod.orig &&
 	git submodule update -N &&
-	test "$(cat submod)" = "not a submodule" &&
+	echo "not a submodule" >expect &&
+	test_cmp expect submod &&
 	output="$(git mergetool --no-prompt)" &&
 	test "$output" = "No files need merging" &&
 	git commit -m "Merge resolved by keeping file" &&
@@ -489,13 +563,15 @@ test_expect_success 'file vs modified su
 	git submodule update -N &&
 	test_must_fail git merge test$test_count &&
 	test -n "$(git ls-files -u)" &&
-	( yes "" | git mergetool file1 file2 spaced\ name subdir/file3 >/dev/null 2>&1 ) &&
-	( yes "" | git mergetool both>/dev/null 2>&1 ) &&
-	( yes "d" | git mergetool file11 file12 >/dev/null 2>&1 ) &&
-	( yes "l" | git mergetool submod ) &&
-	test "$(cat submod/bar)" = "master submodule" &&
+	yes "" | git mergetool file1 file2 spaced\ name subdir/file3 &&
+	yes "" | git mergetool both &&
+	yes "d" | git mergetool file11 file12 &&
+	yes "l" | git mergetool submod &&
+	echo "master submodule" >expect &&
+	test_cmp expect submod/bar &&
 	git submodule update -N &&
-	test "$(cat submod/bar)" = "master submodule" &&
+	echo "master submodule" >expect &&
+	test_cmp expect submod/bar &&
 	output="$(git mergetool --no-prompt)" &&
 	test "$output" = "No files need merging" &&
 	git commit -m "Merge resolved by keeping module"
@@ -544,22 +620,26 @@ test_expect_success 'submodule in subdir
 	git add subdir/subdir_module &&
 	git commit -m "change submodule in subdirectory on test$test_count.b" &&
 
-	test_must_fail git merge test$test_count.a >/dev/null 2>&1 &&
+	test_must_fail git merge test$test_count.a &&
 	(
 		cd subdir &&
-		( yes "l" | git mergetool subdir_module )
+		yes "l" | git mergetool subdir_module
 	) &&
-	test "$(cat subdir/subdir_module/file15)" = "test$test_count.b" &&
+	echo "test$test_count.b" >expect &&
+	test_cmp expect subdir/subdir_module/file15 &&
 	git submodule update -N &&
-	test "$(cat subdir/subdir_module/file15)" = "test$test_count.b" &&
+	echo "test$test_count.b" >expect &&
+	test_cmp expect subdir/subdir_module/file15 &&
 	git reset --hard &&
 	git submodule update -N &&
 
-	test_must_fail git merge test$test_count.a >/dev/null 2>&1 &&
-	( yes "r" | git mergetool subdir/subdir_module ) &&
-	test "$(cat subdir/subdir_module/file15)" = "test$test_count.b" &&
+	test_must_fail git merge test$test_count.a &&
+	yes "r" | git mergetool subdir/subdir_module &&
+	echo "test$test_count.b" >expect &&
+	test_cmp expect subdir/subdir_module/file15 &&
 	git submodule update -N &&
-	test "$(cat subdir/subdir_module/file15)" = "test$test_count.a" &&
+	echo "test$test_count.a" >expect &&
+	test_cmp expect subdir/subdir_module/file15 &&
 	git commit -m "branch1 resolved with mergetool"
 '
 
@@ -575,22 +655,25 @@ test_expect_success 'directory vs modifi
 
 	test_must_fail git merge master &&
 	test -n "$(git ls-files -u)" &&
-	( yes "l" | git mergetool submod ) &&
-	test "$(cat submod/file16)" = "not a submodule" &&
+	yes "l" | git mergetool submod &&
+	echo "not a submodule" >expect &&
+	test_cmp expect submod/file16 &&
 	rm -rf submod.orig &&
 
 	git reset --hard &&
 	test_must_fail git merge master &&
 	test -n "$(git ls-files -u)" &&
 	test ! -e submod.orig &&
-	( yes "r" | git mergetool submod ) &&
+	yes "r" | git mergetool submod &&
 	test -d submod.orig &&
-	test "$(cat submod.orig/file16)" = "not a submodule" &&
+	echo "not a submodule" >expect &&
+	test_cmp expect submod.orig/file16 &&
 	rm -r submod.orig &&
 	mv submod-movedaside/.git submod &&
 	( cd submod && git clean -f && git reset --hard ) &&
 	git submodule update -N &&
-	test "$(cat submod/bar)" = "master submodule" &&
+	echo "master submodule" >expect &&
+	test_cmp expect submod/bar &&
 	git reset --hard &&
 	rm -rf submod-movedaside &&
 
@@ -598,17 +681,19 @@ test_expect_success 'directory vs modifi
 	git submodule update -N &&
 	test_must_fail git merge test$test_count &&
 	test -n "$(git ls-files -u)" &&
-	( yes "l" | git mergetool submod ) &&
+	yes "l" | git mergetool submod &&
 	git submodule update -N &&
-	test "$(cat submod/bar)" = "master submodule" &&
+	echo "master submodule" >expect &&
+	test_cmp expect submod/bar &&
 
 	git reset --hard &&
 	git submodule update -N &&
 	test_must_fail git merge test$test_count &&
 	test -n "$(git ls-files -u)" &&
 	test ! -e submod.orig &&
-	( yes "r" | git mergetool submod ) &&
-	test "$(cat submod/file16)" = "not a submodule" &&
+	yes "r" | git mergetool submod &&
+	echo "not a submodule" >expect &&
+	test_cmp expect submod/file16 &&
 
 	git reset --hard master &&
 	( cd submod && git clean -f && git reset --hard ) &&
@@ -620,8 +705,7 @@ test_expect_success 'file with no base'
 	git checkout -b test$test_count branch1 &&
 	test_must_fail git merge master &&
 	git mergetool --no-prompt --tool mybase -- both &&
-	>expected &&
-	test_cmp expected both
+	test_must_be_empty both
 '
 
 test_expect_success 'custom commands override built-ins' '
@@ -643,7 +727,7 @@ test_expect_success 'filenames seen by t
 	test_config mergetool.myecho.trustExitCode true &&
 	test_must_fail git merge master &&
 	git mergetool --no-prompt --tool myecho -- both >actual &&
-	grep ^\./both_LOCAL_ actual >/dev/null
+	grep ^\./both_LOCAL_ actual
 '
 
 test_lazy_prereq MKTEMP '
@@ -660,8 +744,8 @@ test_expect_success MKTEMP 'temporary fi
 	test_config mergetool.myecho.trustExitCode true &&
 	test_must_fail git merge master &&
 	git mergetool --no-prompt --tool myecho -- both >actual &&
-	! grep ^\./both_LOCAL_ actual >/dev/null &&
-	grep /both_LOCAL_ actual >/dev/null
+	! grep ^\./both_LOCAL_ actual &&
+	grep /both_LOCAL_ actual
 '
 
 test_expect_success 'diff.orderFile configuration is honored' '
diff -pruN 1.2.1+git2.18.0-1/git/t/t7611-merge-abort.sh 1.2.3+git2.25.1-1/git/t/t7611-merge-abort.sh
--- 1.2.1+git2.18.0-1/git/t/t7611-merge-abort.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t7611-merge-abort.sh	2020-02-17 04:47:35.000000000 +0000
@@ -187,31 +187,6 @@ test_expect_success 'Fail clean merge wi
 	test_cmp expect actual
 '
 
-test_expect_success 'Abort clean merge with matching dirty index' '
-	git add bar &&
-	git diff --staged > expect &&
-	git merge --no-commit clean_branch &&
-	test -f .git/MERGE_HEAD &&
-	### When aborting the merge, git will discard all staged changes,
-	### including those that were staged pre-merge. In other words,
-	### --abort will LOSE any staged changes (the staged changes that
-	### are lost must match the merge result, or the merge would not
-	### have been allowed to start). Change expectations accordingly:
-	rm expect &&
-	touch expect &&
-	# Abort merge
-	git merge --abort &&
-	test ! -f .git/MERGE_HEAD &&
-	test "$pre_merge_head" = "$(git rev-parse HEAD)" &&
-	git diff --staged > actual &&
-	test_cmp expect actual &&
-	test -z "$(git diff)"
-'
-
-test_expect_success 'Reset worktree changes' '
-	git reset --hard "$pre_merge_head"
-'
-
 test_expect_success 'Fail conflicting merge with matching dirty worktree' '
 	echo barf > bar &&
 	git diff > expect &&
@@ -223,97 +198,4 @@ test_expect_success 'Fail conflicting me
 	test_cmp expect actual
 '
 
-test_expect_success 'Abort conflicting merge with matching dirty index' '
-	git add bar &&
-	git diff --staged > expect &&
-	test_must_fail git merge conflict_branch &&
-	test -f .git/MERGE_HEAD &&
-	### When aborting the merge, git will discard all staged changes,
-	### including those that were staged pre-merge. In other words,
-	### --abort will LOSE any staged changes (the staged changes that
-	### are lost must match the merge result, or the merge would not
-	### have been allowed to start). Change expectations accordingly:
-	rm expect &&
-	touch expect &&
-	# Abort merge
-	git merge --abort &&
-	test ! -f .git/MERGE_HEAD &&
-	test "$pre_merge_head" = "$(git rev-parse HEAD)" &&
-	git diff --staged > actual &&
-	test_cmp expect actual &&
-	test -z "$(git diff)"
-'
-
-test_expect_success 'Reset worktree changes' '
-	git reset --hard "$pre_merge_head"
-'
-
-test_expect_success 'Abort merge with pre- and post-merge worktree changes' '
-	# Pre-merge worktree changes
-	echo xyzzy > foo &&
-	echo barf > bar &&
-	git add bar &&
-	git diff > expect &&
-	git diff --staged > expect-staged &&
-	# Perform merge
-	test_must_fail git merge conflict_branch &&
-	test -f .git/MERGE_HEAD &&
-	# Post-merge worktree changes
-	echo yzxxz > foo &&
-	echo blech > baz &&
-	### When aborting the merge, git will discard staged changes (bar)
-	### and unmerged changes (baz). Other changes that are neither
-	### staged nor marked as unmerged (foo), will be preserved. For
-	### these changed, git cannot tell pre-merge changes apart from
-	### post-merge changes, so the post-merge changes will be
-	### preserved. Change expectations accordingly:
-	git diff -- foo > expect &&
-	rm expect-staged &&
-	touch expect-staged &&
-	# Abort merge
-	git merge --abort &&
-	test ! -f .git/MERGE_HEAD &&
-	test "$pre_merge_head" = "$(git rev-parse HEAD)" &&
-	git diff > actual &&
-	test_cmp expect actual &&
-	git diff --staged > actual-staged &&
-	test_cmp expect-staged actual-staged
-'
-
-test_expect_success 'Reset worktree changes' '
-	git reset --hard "$pre_merge_head"
-'
-
-test_expect_success 'Abort merge with pre- and post-merge index changes' '
-	# Pre-merge worktree changes
-	echo xyzzy > foo &&
-	echo barf > bar &&
-	git add bar &&
-	git diff > expect &&
-	git diff --staged > expect-staged &&
-	# Perform merge
-	test_must_fail git merge conflict_branch &&
-	test -f .git/MERGE_HEAD &&
-	# Post-merge worktree changes
-	echo yzxxz > foo &&
-	echo blech > baz &&
-	git add foo bar &&
-	### When aborting the merge, git will discard all staged changes
-	### (foo, bar and baz), and no changes will be preserved. Whether
-	### the changes were staged pre- or post-merge does not matter
-	### (except for not preventing starting the merge).
-	### Change expectations accordingly:
-	rm expect expect-staged &&
-	touch expect &&
-	touch expect-staged &&
-	# Abort merge
-	git merge --abort &&
-	test ! -f .git/MERGE_HEAD &&
-	test "$pre_merge_head" = "$(git rev-parse HEAD)" &&
-	git diff > actual &&
-	test_cmp expect actual &&
-	git diff --staged > actual-staged &&
-	test_cmp expect-staged actual-staged
-'
-
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t7612-merge-verify-signatures.sh 1.2.3+git2.25.1-1/git/t/t7612-merge-verify-signatures.sh
--- 1.2.1+git2.18.0-1/git/t/t7612-merge-verify-signatures.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t7612-merge-verify-signatures.sh	2020-02-17 04:47:35.000000000 +0000
@@ -23,7 +23,7 @@ test_expect_success GPG 'create signed c
 	echo 3 >bar && git add bar &&
 	test_tick && git commit -S -m "bad on side" &&
 	git cat-file commit side-bad >raw &&
-	sed -e "s/bad/forged bad/" raw >forged &&
+	sed -e "s/^bad/forged bad/" raw >forged &&
 	git hash-object -w -t commit forged >forged.commit &&
 	git checkout initial &&
 
@@ -103,4 +103,11 @@ test_expect_success GPG 'merge commit wi
 	git merge --no-verify-signatures $(cat forged.commit)
 '
 
+test_expect_success GPG 'merge unsigned commit into unborn branch' '
+	test_when_finished "git checkout initial" &&
+	git checkout --orphan unborn &&
+	test_must_fail git merge --verify-signatures side-unsigned 2>mergeerror &&
+	test_i18ngrep "does not have a GPG signature" mergeerror
+'
+
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t7700-repack.sh 1.2.3+git2.25.1-1/git/t/t7700-repack.sh
--- 1.2.1+git2.18.0-1/git/t/t7700-repack.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t7700-repack.sh	2020-02-17 04:47:35.000000000 +0000
@@ -4,129 +4,104 @@ test_description='git repack works corre
 
 . ./test-lib.sh
 
-commit_and_pack() {
-	test_commit "$@" >/dev/null &&
-	SHA1=$(git pack-objects --all --unpacked --incremental .git/objects/pack/pack </dev/null) &&
-	echo pack-${SHA1}.pack
+commit_and_pack () {
+	test_commit "$@" 1>&2 &&
+	incrpackid=$(git pack-objects --all --unpacked --incremental .git/objects/pack/pack </dev/null) &&
+	echo pack-${incrpackid}.pack
+}
+
+test_no_missing_in_packs () {
+	myidx=$(ls -1 .git/objects/pack/*.idx) &&
+	test_path_is_file "$myidx" &&
+	git verify-pack -v alt_objects/pack/*.idx >orig.raw &&
+	sed -n -e "s/^\($OID_REGEX\).*/\1/p" orig.raw | sort >orig &&
+	git verify-pack -v $myidx >dest.raw &&
+	cut -d" " -f1 dest.raw | sort >dest &&
+	comm -23 orig dest >missing &&
+	test_must_be_empty missing
+}
+
+# we expect $packid and $oid to be defined
+test_has_duplicate_object () {
+	want_duplicate_object="$1"
+	found_duplicate_object=false
+	for p in .git/objects/pack/*.idx
+	do
+		idx=$(basename $p)
+		test "pack-$packid.idx" = "$idx" && continue
+		git verify-pack -v $p >packlist || return $?
+		if grep "^$oid" packlist
+		then
+			found_duplicate_object=true
+			echo "DUPLICATE OBJECT FOUND"
+			break
+		fi
+	done &&
+	test "$want_duplicate_object" = "$found_duplicate_object"
 }
 
 test_expect_success 'objects in packs marked .keep are not repacked' '
-	echo content1 > file1 &&
-	echo content2 > file2 &&
+	echo content1 >file1 &&
+	echo content2 >file2 &&
 	git add . &&
 	test_tick &&
 	git commit -m initial_commit &&
 	# Create two packs
 	# The first pack will contain all of the objects except one
-	git rev-list --objects --all | grep -v file2 |
-		git pack-objects pack > /dev/null &&
+	git rev-list --objects --all >objs &&
+	grep -v file2 objs | git pack-objects pack &&
 	# The second pack will contain the excluded object
-	packsha1=$(git rev-list --objects --all | grep file2 |
-		git pack-objects pack) &&
-	>pack-$packsha1.keep &&
-	objsha1=$(git verify-pack -v pack-$packsha1.idx | head -n 1 |
-		sed -e "s/^\([0-9a-f]\{40\}\).*/\1/") &&
+	packid=$(grep file2 objs | git pack-objects pack) &&
+	>pack-$packid.keep &&
+	git verify-pack -v pack-$packid.idx >packlist &&
+	oid=$(head -n 1 packlist | sed -e "s/^\($OID_REGEX\).*/\1/") &&
 	mv pack-* .git/objects/pack/ &&
 	git repack -A -d -l &&
 	git prune-packed &&
-	for p in .git/objects/pack/*.idx; do
-		idx=$(basename $p)
-		test "pack-$packsha1.idx" = "$idx" && continue
-		if git verify-pack -v $p | egrep "^$objsha1"; then
-			found_duplicate_object=1
-			echo "DUPLICATE OBJECT FOUND"
-			break
-		fi
-	done &&
-	test -z "$found_duplicate_object"
+	test_has_duplicate_object false
 '
 
 test_expect_success 'writing bitmaps via command-line can duplicate .keep objects' '
-	# build on $objsha1, $packsha1, and .keep state from previous
+	# build on $oid, $packid, and .keep state from previous
 	git repack -Adbl &&
-	test_when_finished "found_duplicate_object=" &&
-	for p in .git/objects/pack/*.idx; do
-		idx=$(basename $p)
-		test "pack-$packsha1.idx" = "$idx" && continue
-		if git verify-pack -v $p | egrep "^$objsha1"; then
-			found_duplicate_object=1
-			echo "DUPLICATE OBJECT FOUND"
-			break
-		fi
-	done &&
-	test "$found_duplicate_object" = 1
+	test_has_duplicate_object true
 '
 
 test_expect_success 'writing bitmaps via config can duplicate .keep objects' '
-	# build on $objsha1, $packsha1, and .keep state from previous
+	# build on $oid, $packid, and .keep state from previous
 	git -c repack.writebitmaps=true repack -Adl &&
-	test_when_finished "found_duplicate_object=" &&
-	for p in .git/objects/pack/*.idx; do
-		idx=$(basename $p)
-		test "pack-$packsha1.idx" = "$idx" && continue
-		if git verify-pack -v $p | egrep "^$objsha1"; then
-			found_duplicate_object=1
-			echo "DUPLICATE OBJECT FOUND"
-			break
-		fi
-	done &&
-	test "$found_duplicate_object" = 1
+	test_has_duplicate_object true
 '
 
 test_expect_success 'loose objects in alternate ODB are not repacked' '
 	mkdir alt_objects &&
-	echo $(pwd)/alt_objects > .git/objects/info/alternates &&
-	echo content3 > file3 &&
-	objsha1=$(GIT_OBJECT_DIRECTORY=alt_objects git hash-object -w file3) &&
+	echo $(pwd)/alt_objects >.git/objects/info/alternates &&
+	echo content3 >file3 &&
+	oid=$(GIT_OBJECT_DIRECTORY=alt_objects git hash-object -w file3) &&
 	git add file3 &&
 	test_tick &&
 	git commit -m commit_file3 &&
 	git repack -a -d -l &&
 	git prune-packed &&
-	for p in .git/objects/pack/*.idx; do
-		if git verify-pack -v $p | egrep "^$objsha1"; then
-			found_duplicate_object=1
-			echo "DUPLICATE OBJECT FOUND"
-			break
-		fi
-	done &&
-	test -z "$found_duplicate_object"
+	test_has_duplicate_object false
 '
 
 test_expect_success 'packed obs in alt ODB are repacked even when local repo is packless' '
 	mkdir alt_objects/pack &&
 	mv .git/objects/pack/* alt_objects/pack &&
 	git repack -a &&
-	myidx=$(ls -1 .git/objects/pack/*.idx) &&
-	test -f "$myidx" &&
-	for p in alt_objects/pack/*.idx; do
-		git verify-pack -v $p | sed -n -e "/^[0-9a-f]\{40\}/p"
-	done | while read sha1 rest; do
-		if ! ( git verify-pack -v $myidx | grep "^$sha1" ); then
-			echo "Missing object in local pack: $sha1"
-			return 1
-		fi
-	done
+	test_no_missing_in_packs
 '
 
 test_expect_success 'packed obs in alt ODB are repacked when local repo has packs' '
 	rm -f .git/objects/pack/* &&
-	echo new_content >> file1 &&
+	echo new_content >>file1 &&
 	git add file1 &&
 	test_tick &&
 	git commit -m more_content &&
 	git repack &&
 	git repack -a -d &&
-	myidx=$(ls -1 .git/objects/pack/*.idx) &&
-	test -f "$myidx" &&
-	for p in alt_objects/pack/*.idx; do
-		git verify-pack -v $p | sed -n -e "/^[0-9a-f]\{40\}/p"
-	done | while read sha1 rest; do
-		if ! ( git verify-pack -v $myidx | grep "^$sha1" ); then
-			echo "Missing object in local pack: $sha1"
-			return 1
-		fi
-	done
+	test_no_missing_in_packs
 '
 
 test_expect_success 'packed obs in alternate ODB kept pack are repacked' '
@@ -134,7 +109,7 @@ test_expect_success 'packed obs in alter
 	for p in alt_objects/pack/*.pack
 	do
 		base_name=$(basename $p .pack) &&
-		if test -f alt_objects/pack/$base_name.keep
+		if test_path_is_file alt_objects/pack/$base_name.keep
 		then
 			rm alt_objects/pack/$base_name.keep
 		else
@@ -142,22 +117,13 @@ test_expect_success 'packed obs in alter
 		fi
 	done &&
 	git repack -a -d &&
-	myidx=$(ls -1 .git/objects/pack/*.idx) &&
-	test -f "$myidx" &&
-	for p in alt_objects/pack/*.idx; do
-		git verify-pack -v $p | sed -n -e "/^[0-9a-f]\{40\}/p"
-	done | while read sha1 rest; do
-		if ! ( git verify-pack -v $myidx | grep "^$sha1" ); then
-			echo "Missing object in local pack: $sha1"
-			return 1
-		fi
-	done
+	test_no_missing_in_packs
 '
 
 test_expect_success 'packed unreachable obs in alternate ODB are not loosened' '
 	rm -f alt_objects/pack/*.keep &&
 	mv .git/objects/pack/* alt_objects/pack/ &&
-	csha1=$(git rev-parse HEAD^{commit}) &&
+	coid=$(git rev-parse HEAD^{commit}) &&
 	git reset --hard HEAD^ &&
 	test_tick &&
 	git reflog expire --expire=$test_tick --expire-unreachable=$test_tick --all &&
@@ -167,15 +133,15 @@ test_expect_success 'packed unreachable
 	    --unpack-unreachable </dev/null pack &&
 	rm -f .git/objects/pack/* &&
 	mv pack-* .git/objects/pack/ &&
-	test 0 = $(git verify-pack -v -- .git/objects/pack/*.idx |
-		egrep "^$csha1 " | sort | uniq | wc -l) &&
-	echo > .git/objects/info/alternates &&
-	test_must_fail git show $csha1
+	git verify-pack -v -- .git/objects/pack/*.idx >packlist &&
+	! grep "^$coid " packlist &&
+	echo >.git/objects/info/alternates &&
+	test_must_fail git show $coid
 '
 
 test_expect_success 'local packed unreachable obs that exist in alternate ODB are not loosened' '
-	echo $(pwd)/alt_objects > .git/objects/info/alternates &&
-	echo "$csha1" | git pack-objects --non-empty --all --reflog pack &&
+	echo $(pwd)/alt_objects >.git/objects/info/alternates &&
+	echo "$coid" | git pack-objects --non-empty --all --reflog pack &&
 	rm -f .git/objects/pack/* &&
 	mv pack-* .git/objects/pack/ &&
 	# The pack-objects call on the next line is equivalent to
@@ -184,10 +150,10 @@ test_expect_success 'local packed unreac
 	    --unpack-unreachable </dev/null pack &&
 	rm -f .git/objects/pack/* &&
 	mv pack-* .git/objects/pack/ &&
-	test 0 = $(git verify-pack -v -- .git/objects/pack/*.idx |
-		egrep "^$csha1 " | sort | uniq | wc -l) &&
-	echo > .git/objects/info/alternates &&
-	test_must_fail git show $csha1
+	git verify-pack -v -- .git/objects/pack/*.idx >packlist &&
+	! grep "^$coid " &&
+	echo >.git/objects/info/alternates &&
+	test_must_fail git show $coid
 '
 
 test_expect_success 'objects made unreachable by grafts only are kept' '
@@ -196,7 +162,7 @@ test_expect_success 'objects made unreac
 	H0=$(git rev-parse HEAD) &&
 	H1=$(git rev-parse HEAD^) &&
 	H2=$(git rev-parse HEAD^^) &&
-	echo "$H0 $H2" > .git/info/grafts &&
+	echo "$H0 $H2" >.git/info/grafts &&
 	git reflog expire --expire=$test_tick --expire-unreachable=$test_tick --all &&
 	git repack -a -d &&
 	git cat-file -t $H1
@@ -221,5 +187,45 @@ test_expect_success 'repack --keep-pack'
 	)
 '
 
-test_done
+test_expect_success 'bitmaps are created by default in bare repos' '
+	git clone --bare .git bare.git &&
+	git -C bare.git repack -ad &&
+	bitmap=$(ls bare.git/objects/pack/*.bitmap) &&
+	test_path_is_file "$bitmap"
+'
+
+test_expect_success 'incremental repack does not complain' '
+	git -C bare.git repack -q 2>repack.err &&
+	test_must_be_empty repack.err
+'
+
+test_expect_success 'bitmaps can be disabled on bare repos' '
+	git -c repack.writeBitmaps=false -C bare.git repack -ad &&
+	bitmap=$(ls bare.git/objects/pack/*.bitmap || :) &&
+	test -z "$bitmap"
+'
+
+test_expect_success 'no bitmaps created if .keep files present' '
+	pack=$(ls bare.git/objects/pack/*.pack) &&
+	test_path_is_file "$pack" &&
+	keep=${pack%.pack}.keep &&
+	test_when_finished "rm -f \"\$keep\"" &&
+	>"$keep" &&
+	git -C bare.git repack -ad 2>stderr &&
+	test_must_be_empty stderr &&
+	find bare.git/objects/pack/ -type f -name "*.bitmap" >actual &&
+	test_must_be_empty actual
+'
+
+test_expect_success 'auto-bitmaps do not complain if unavailable' '
+	test_config -C bare.git pack.packSizeLimit 1M &&
+	blob=$(test-tool genrandom big $((1024*1024)) |
+	       git -C bare.git hash-object -w --stdin) &&
+	git -C bare.git update-ref refs/tags/big $blob &&
+	git -C bare.git repack -ad 2>stderr &&
+	test_must_be_empty stderr &&
+	find bare.git/objects/pack -type f -name "*.bitmap" >actual &&
+	test_must_be_empty actual
+'
 
+test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t7800-difftool.sh 1.2.3+git2.25.1-1/git/t/t7800-difftool.sh
--- 1.2.1+git2.18.0-1/git/t/t7800-difftool.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t7800-difftool.sh	2020-02-17 04:47:35.000000000 +0000
@@ -125,15 +125,14 @@ test_expect_success 'difftool stops on e
 	test_when_finished "rm -f for-diff .git/fail-right-file" &&
 	test_when_finished "git reset -- for-diff" &&
 	write_script .git/fail-right-file <<-\EOF &&
-	echo "$2"
+	echo failed
 	exit 1
 	EOF
 	>for-diff &&
 	git add for-diff &&
-	echo file >expect &&
 	test_must_fail git difftool -y --trust-exit-code \
 		--extcmd .git/fail-right-file branch >actual &&
-	test_cmp expect actual
+	test_line_count = 1 actual
 '
 
 test_expect_success 'difftool honors exit status if command not found' '
@@ -279,11 +278,27 @@ test_expect_success 'difftool + mergetoo
 	echo branch >expect &&
 	git difftool --no-prompt branch >actual &&
 	test_cmp expect actual &&
+	git difftool --gui --no-prompt branch >actual &&
+	test_cmp expect actual &&
 
 	# set merge.tool to something bogus, diff.tool to test-tool
 	test_config merge.tool bogus-tool &&
 	test_config diff.tool test-tool &&
 	git difftool --no-prompt branch >actual &&
+	test_cmp expect actual &&
+	git difftool --gui --no-prompt branch >actual &&
+	test_cmp expect actual &&
+
+	# set merge.tool, diff.tool to something bogus, merge.guitool to test-tool
+	test_config diff.tool bogus-tool &&
+	test_config merge.guitool test-tool &&
+	git difftool --gui --no-prompt branch >actual &&
+	test_cmp expect actual &&
+
+	# set merge.tool, diff.tool, merge.guitool to something bogus, diff.guitool to test-tool
+	test_config merge.guitool bogus-tool &&
+	test_config diff.guitool test-tool &&
+	git difftool --gui --no-prompt branch >actual &&
 	test_cmp expect actual
 '
 
@@ -332,7 +347,7 @@ test_expect_success 'difftool --extcmd c
 test_expect_success 'difftool --extcmd cat arg2' '
 	echo branch >expect &&
 	git difftool --no-prompt \
-		--extcmd sh\ -c\ \"cat\ \$2\" branch >actual &&
+		--extcmd sh\ -c\ \"cat\ \\\"\$2\\\"\" branch >actual &&
 	test_cmp expect actual
 '
 
@@ -546,7 +561,7 @@ do
 done >actual
 EOF
 
-test_expect_success SYMLINKS 'difftool --dir-diff --symlink without unstaged changes' '
+test_expect_success SYMLINKS 'difftool --dir-diff --symlinks without unstaged changes' '
 	cat >expect <<-EOF &&
 	file
 	$PWD/file
@@ -555,9 +570,9 @@ test_expect_success SYMLINKS 'difftool -
 	sub/sub
 	$PWD/sub/sub
 	EOF
-	git difftool --dir-diff --symlink \
+	git difftool --dir-diff --symlinks \
 		--extcmd "./.git/CHECK_SYMLINKS" branch HEAD &&
-	test_cmp actual expect
+	test_cmp expect actual
 '
 
 write_script modify-right-file <<\EOF
@@ -705,4 +720,22 @@ test_expect_success SYMLINKS 'difftool -
 	test_cmp expect actual
 '
 
+test_expect_success 'outside worktree' '
+	echo 1 >1 &&
+	echo 2 >2 &&
+	test_expect_code 1 nongit git \
+		-c diff.tool=echo -c difftool.echo.cmd="echo \$LOCAL \$REMOTE" \
+		difftool --no-prompt --no-index ../1 ../2 >actual &&
+	echo "../1 ../2" >expect &&
+	test_cmp expect actual
+'
+
+test_expect_success 'difftool --gui, --tool and --extcmd are mutually exclusive' '
+	difftool_test_setup &&
+	test_must_fail git difftool --gui --tool=test-tool &&
+	test_must_fail git difftool --gui --extcmd=cat &&
+	test_must_fail git difftool --tool=test-tool --extcmd=cat &&
+	test_must_fail git difftool --gui --tool=test-tool --extcmd=cat
+'
+
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t7810-grep.sh 1.2.3+git2.25.1-1/git/t/t7810-grep.sh
--- 1.2.1+git2.18.0-1/git/t/t7810-grep.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t7810-grep.sh	2020-02-17 04:47:35.000000000 +0000
@@ -99,6 +99,101 @@ do
 		test_cmp expected actual
 	'
 
+	test_expect_success "grep -w $L (with --column)" '
+		{
+			echo ${HC}file:5:foo mmap bar
+			echo ${HC}file:14:foo_mmap bar mmap
+			echo ${HC}file:5:foo mmap bar_mmap
+			echo ${HC}file:14:foo_mmap bar mmap baz
+		} >expected &&
+		git grep --column -w -e mmap $H >actual &&
+		test_cmp expected actual
+	'
+
+	test_expect_success "grep -w $L (with --column, extended OR)" '
+		{
+			echo ${HC}file:14:foo_mmap bar mmap
+			echo ${HC}file:19:foo_mmap bar mmap baz
+		} >expected &&
+		git grep --column -w -e mmap$ --or -e baz $H >actual &&
+		test_cmp expected actual
+	'
+
+	test_expect_success "grep -w $L (with --column, --invert-match)" '
+		{
+			echo ${HC}file:1:foo mmap bar
+			echo ${HC}file:1:foo_mmap bar
+			echo ${HC}file:1:foo_mmap bar mmap
+			echo ${HC}file:1:foo mmap bar_mmap
+		} >expected &&
+		git grep --column --invert-match -w -e baz $H -- file >actual &&
+		test_cmp expected actual
+	'
+
+	test_expect_success "grep $L (with --column, --invert-match, extended OR)" '
+		{
+			echo ${HC}hello_world:6:HeLLo_world
+		} >expected &&
+		git grep --column --invert-match -e ll --or --not -e _ $H -- hello_world \
+			>actual &&
+		test_cmp expected actual
+	'
+
+	test_expect_success "grep $L (with --column, --invert-match, extended AND)" '
+		{
+			echo ${HC}hello_world:3:Hello world
+			echo ${HC}hello_world:3:Hello_world
+			echo ${HC}hello_world:6:HeLLo_world
+		} >expected &&
+		git grep --column --invert-match --not -e _ --and --not -e ll $H -- hello_world \
+			>actual &&
+		test_cmp expected actual
+	'
+
+	test_expect_success "grep $L (with --column, double-negation)" '
+		{
+			echo ${HC}file:1:foo_mmap bar mmap baz
+		} >expected &&
+		git grep --column --not \( --not -e foo --or --not -e baz \) $H -- file \
+			>actual &&
+		test_cmp expected actual
+	'
+
+	test_expect_success "grep -w $L (with --column, -C)" '
+		{
+			echo ${HC}file:5:foo mmap bar
+			echo ${HC}file-foo_mmap bar
+			echo ${HC}file:14:foo_mmap bar mmap
+			echo ${HC}file:5:foo mmap bar_mmap
+			echo ${HC}file:14:foo_mmap bar mmap baz
+		} >expected &&
+		git grep --column -w -C1 -e mmap $H >actual &&
+		test_cmp expected actual
+	'
+
+	test_expect_success "grep -w $L (with --line-number, --column)" '
+		{
+			echo ${HC}file:1:5:foo mmap bar
+			echo ${HC}file:3:14:foo_mmap bar mmap
+			echo ${HC}file:4:5:foo mmap bar_mmap
+			echo ${HC}file:5:14:foo_mmap bar mmap baz
+		} >expected &&
+		git grep -n --column -w -e mmap $H >actual &&
+		test_cmp expected actual
+	'
+
+	test_expect_success "grep -w $L (with non-extended patterns, --column)" '
+		{
+			echo ${HC}file:5:foo mmap bar
+			echo ${HC}file:10:foo_mmap bar
+			echo ${HC}file:10:foo_mmap bar mmap
+			echo ${HC}file:5:foo mmap bar_mmap
+			echo ${HC}file:10:foo_mmap bar mmap baz
+		} >expected &&
+		git grep --column -w -e bar -e mmap $H >actual &&
+		test_cmp expected actual
+	'
+
 	test_expect_success "grep -w $L" '
 		{
 			echo ${HC}file:1:foo mmap bar
@@ -122,9 +217,8 @@ do
 	'
 
 	test_expect_success "grep -w $L (w)" '
-		: >expected &&
 		test_must_fail git grep -n -w -e "^w" $H >actual &&
-		test_cmp expected actual
+		test_must_be_empty actual
 	'
 
 	test_expect_success "grep -w $L (x)" '
@@ -144,29 +238,42 @@ do
 	'
 
 	test_expect_success "grep -w $L (y-2)" '
-		: >expected &&
 		if git grep -n -w -e "^y y" $H >actual
 		then
 			echo should not have matched
 			cat actual
 			false
 		else
-			test_cmp expected actual
+			test_must_be_empty actual
 		fi
 	'
 
 	test_expect_success "grep -w $L (z)" '
-		: >expected &&
 		if git grep -n -w -e "^z" $H >actual
 		then
 			echo should not have matched
 			cat actual
 			false
 		else
-			test_cmp expected actual
+			test_must_be_empty actual
 		fi
 	'
 
+	test_expect_success "grep $L (with --column, --only-matching)" '
+		{
+			echo ${HC}file:1:5:mmap
+			echo ${HC}file:2:5:mmap
+			echo ${HC}file:3:5:mmap
+			echo ${HC}file:3:13:mmap
+			echo ${HC}file:4:5:mmap
+			echo ${HC}file:4:13:mmap
+			echo ${HC}file:5:5:mmap
+			echo ${HC}file:5:13:mmap
+		} >expected &&
+		git grep --column -n -o -e mmap $H >actual &&
+		test_cmp expected actual
+	'
+
 	test_expect_success "grep $L (t-1)" '
 		echo "${HC}t/t:1:test" >expected &&
 		git grep -n -e test $H >actual &&
@@ -202,6 +309,8 @@ do
 			echo ${HC}v:1:vvv
 		} >expected &&
 		git grep --max-depth -1 -n -e vvv $H >actual &&
+		test_cmp expected actual &&
+		git grep --recursive -n -e vvv $H >actual &&
 		test_cmp expected actual
 	'
 
@@ -210,6 +319,8 @@ do
 			echo ${HC}v:1:vvv
 		} >expected &&
 		git grep --max-depth 0 -n -e vvv $H >actual &&
+		test_cmp expected actual &&
+		git grep --no-recursive -n -e vvv $H >actual &&
 		test_cmp expected actual
 	'
 
@@ -220,6 +331,8 @@ do
 			echo ${HC}v:1:vvv
 		} >expected &&
 		git grep --max-depth 0 -n -e vvv $H -- "*" >actual &&
+		test_cmp expected actual &&
+		git grep --no-recursive -n -e vvv $H -- "*" >actual &&
 		test_cmp expected actual
 	'
 
@@ -237,6 +350,8 @@ do
 			echo ${HC}t/v:1:vvv
 		} >expected &&
 		git grep --max-depth 0 -n -e vvv $H -- t >actual &&
+		test_cmp expected actual &&
+		git grep --no-recursive -n -e vvv $H -- t >actual &&
 		test_cmp expected actual
 	'
 
@@ -246,6 +361,8 @@ do
 			echo ${HC}v:1:vvv
 		} >expected &&
 		git grep --max-depth 0 -n -e vvv $H -- . t >actual &&
+		test_cmp expected actual &&
+		git grep --no-recursive -n -e vvv $H -- . t >actual &&
 		test_cmp expected actual
 	'
 
@@ -255,6 +372,8 @@ do
 			echo ${HC}v:1:vvv
 		} >expected &&
 		git grep --max-depth 0 -n -e vvv $H -- t . >actual &&
+		test_cmp expected actual &&
+		git grep --no-recursive -n -e vvv $H -- t . >actual &&
 		test_cmp expected actual
 	'
 	test_expect_success "grep $L with grep.extendedRegexp=false" '
@@ -293,7 +412,7 @@ do
 		test_cmp expected actual
 	'
 
-	test_expect_success !PCRE "grep $L with grep.patterntype=perl errors without PCRE" '
+	test_expect_success !FAIL_PREREQS,!PCRE "grep $L with grep.patterntype=perl errors without PCRE" '
 		test_must_fail git -c grep.patterntype=perl grep "foo.*bar"
 	'
 
@@ -388,7 +507,7 @@ test_expect_success 'grep -L -C' '
 
 test_expect_success 'grep --files-without-match --quiet' '
 	git grep --files-without-match --quiet nonexistent_string >actual &&
-	test_cmp /dev/null actual
+	test_must_be_empty actual
 '
 
 cat >expected <<EOF
@@ -509,11 +628,10 @@ z:zzz
 EOF
 
 test_expect_success 'grep -q, silently report matches' '
-	>empty &&
 	git grep -q mmap >actual &&
-	test_cmp empty actual &&
+	test_must_be_empty actual &&
 	test_must_fail git grep -q qfwfq >actual &&
-	test_cmp empty actual
+	test_must_be_empty actual
 '
 
 test_expect_success 'grep -C1 hunk mark between files' '
@@ -581,8 +699,7 @@ test_expect_success 'log grep (5)' '
 
 test_expect_success 'log grep (6)' '
 	git log --author=-0700  --pretty=tformat:%s >actual &&
-	>expect &&
-	test_cmp expect actual
+	test_must_be_empty actual
 '
 
 test_expect_success 'log grep (7)' '
@@ -607,8 +724,7 @@ test_expect_success 'log grep (9)' '
 
 test_expect_success 'log grep (9)' '
 	git log -g --grep-reflog="commit: third" --author="non-existent" --pretty=tformat:%s >actual &&
-	: >expect &&
-	test_cmp expect actual
+	test_must_be_empty actual
 '
 
 test_expect_success 'log --grep-reflog can only be used under -g' '
@@ -698,15 +814,13 @@ test_expect_success 'log --all-match --g
 '
 
 test_expect_success 'log --author does not search in timestamp' '
-	: >expect &&
 	git log --author="$GIT_AUTHOR_DATE" >actual &&
-	test_cmp expect actual
+	test_must_be_empty actual
 '
 
 test_expect_success 'log --committer does not search in timestamp' '
-	: >expect &&
 	git log --committer="$GIT_COMMITTER_DATE" >actual &&
-	test_cmp expect actual
+	test_must_be_empty actual
 '
 
 test_expect_success 'grep with CE_VALID file' '
@@ -845,10 +959,9 @@ test_expect_success 'grep from a subdire
 test_expect_success 'grep from a subdirectory to search wider area (2)' '
 	mkdir -p s &&
 	(
-		cd s || exit 1
-		( git grep xxyyzz .. >out ; echo $? >status )
-		! test -s out &&
-		test 1 = $(cat status)
+		cd s &&
+		test_expect_code 1 git grep xxyyzz .. >out &&
+		test_must_be_empty out
 	)
 '
 
@@ -897,7 +1010,7 @@ test_expect_success 'outside of git repo
 			echo ".gitignore:.*o*" &&
 			cat ../expect.full
 		} >../expect.with.ignored &&
-		git grep --no-index --no-exclude o >../actual.full &&
+		git grep --no-index --no-exclude-standard o >../actual.full &&
 		test_cmp ../expect.with.ignored ../actual.full
 	)
 '
@@ -938,7 +1051,7 @@ test_expect_success 'outside of git repo
 			echo ".gitignore:.*o*" &&
 			cat ../expect.full
 		} >../expect.with.ignored &&
-		git -c grep.fallbackToNoIndex grep --no-exclude o >../actual.full &&
+		git -c grep.fallbackToNoIndex grep --no-exclude-standard o >../actual.full &&
 		test_cmp ../expect.with.ignored ../actual.full
 	)
 '
@@ -957,13 +1070,12 @@ test_expect_success 'inside git reposito
 		echo ".gitignore:.*o*" &&
 		cat is/expect.unignored
 	} >is/expect.full &&
-	: >is/expect.empty &&
 	echo file2:world >is/expect.sub &&
 	(
 		cd is/git &&
 		git init &&
 		test_must_fail git grep o >../actual.full &&
-		test_cmp ../expect.empty ../actual.full &&
+		test_must_be_empty ../actual.full &&
 
 		git grep --untracked o >../actual.unignored &&
 		test_cmp ../expect.unignored ../actual.unignored &&
@@ -976,7 +1088,7 @@ test_expect_success 'inside git reposito
 
 		cd sub &&
 		test_must_fail git grep o >../../actual.sub &&
-		test_cmp ../../expect.empty ../../actual.sub &&
+		test_must_be_empty ../../actual.sub &&
 
 		git grep --no-index o >../../actual.sub &&
 		test_cmp ../../expect.sub ../../actual.sub &&
@@ -1122,7 +1234,7 @@ test_expect_success PCRE 'grep --perl-re
 	test_cmp expected actual
 '
 
-test_expect_success !PCRE 'grep --perl-regexp pattern errors without PCRE' '
+test_expect_success !FAIL_PREREQS,!PCRE 'grep --perl-regexp pattern errors without PCRE' '
 	test_must_fail git grep --perl-regexp "foo.*bar"
 '
 
@@ -1137,15 +1249,14 @@ test_expect_success LIBPCRE2 "grep -P wi
 
 '
 
-test_expect_success !PCRE 'grep -P pattern errors without PCRE' '
+test_expect_success !FAIL_PREREQS,!PCRE 'grep -P pattern errors without PCRE' '
 	test_must_fail git grep -P "foo.*bar"
 '
 
 test_expect_success 'grep pattern with grep.extendedRegexp=true' '
-	>empty &&
 	test_must_fail git -c grep.extendedregexp=true \
 		grep "\p{Ps}.*?\p{Pe}" hello.c >actual &&
-	test_cmp empty actual
+	test_must_be_empty actual
 '
 
 test_expect_success PCRE 'grep -P pattern with grep.extendedRegexp=true' '
diff -pruN 1.2.1+git2.18.0-1/git/t/t7811-grep-open.sh 1.2.3+git2.25.1-1/git/t/t7811-grep-open.sh
--- 1.2.1+git2.18.0-1/git/t/t7811-grep-open.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t7811-grep-open.sh	2020-02-17 04:47:35.000000000 +0000
@@ -51,14 +51,13 @@ test_expect_success SIMPLEPAGER 'git gre
 	grep.h
 	EOF
 	echo grep.h >expect.notless &&
-	>empty &&
 
 	PATH=.:$PATH git grep -O GREP_PATTERN >out &&
 	{
 		test_cmp expect.less pager-args ||
 		test_cmp expect.notless pager-args
 	} &&
-	test_cmp empty out
+	test_must_be_empty out
 '
 
 test_expect_success 'git grep -O --cached' '
@@ -72,7 +71,6 @@ test_expect_success 'git grep -O --no-in
 	grep.h
 	untracked
 	EOF
-	>empty &&
 
 	(
 		GIT_PAGER='\''printf "%s\n" >pager-args'\'' &&
@@ -80,7 +78,7 @@ test_expect_success 'git grep -O --no-in
 		git grep --no-index -O GREP_PATTERN >out
 	) &&
 	test_cmp expect pager-args &&
-	test_cmp empty out
+	test_must_be_empty out
 '
 
 test_expect_success 'setup: fake "less"' '
@@ -96,15 +94,14 @@ test_expect_success 'git grep -O jumps t
 	+/*GREP_PATTERN
 	grep.h
 	EOF
-	>empty &&
 
 	GIT_PAGER=./less git grep -O GREP_PATTERN >out &&
 	test_cmp expect actual &&
-	test_cmp empty out &&
+	test_must_be_empty out &&
 
 	git grep -O./less GREP_PATTERN >out2 &&
 	test_cmp expect actual &&
-	test_cmp empty out2
+	test_must_be_empty out2
 '
 
 test_expect_success 'modified file' '
@@ -116,13 +113,12 @@ test_expect_success 'modified file' '
 	subdir/grep.c
 	unrelated
 	EOF
-	>empty &&
 
 	echo "enum grep_pat_token" >unrelated &&
 	test_when_finished "git checkout HEAD unrelated" &&
 	GIT_PAGER=./less git grep -F -O "enum grep_pat_token" >out &&
 	test_cmp expect actual &&
-	test_cmp empty out
+	test_must_be_empty out
 '
 
 test_expect_success 'copes with color settings' '
@@ -138,7 +134,6 @@ test_expect_success 'copes with color se
 test_expect_success 'run from subdir' '
 	rm -f actual &&
 	echo grep.c >expect &&
-	>empty &&
 
 	(
 		cd subdir &&
@@ -156,8 +151,8 @@ test_expect_success 'run from subdir' '
 		;;
 	esac &&
 	test_cmp expect args &&
-	test_cmp empty out &&
-	test_cmp empty out2
+	test_must_be_empty out &&
+	test_must_be_empty out2
 '
 
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t7812-grep-icase-non-ascii.sh 1.2.3+git2.25.1-1/git/t/t7812-grep-icase-non-ascii.sh
--- 1.2.1+git2.18.0-1/git/t/t7812-grep-icase-non-ascii.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t7812-grep-icase-non-ascii.sh	2020-02-17 04:47:35.000000000 +0000
@@ -53,4 +53,35 @@ test_expect_success REGEX_LOCALE 'pickax
 	test_cmp expected actual
 '
 
+test_expect_success GETTEXT_LOCALE,LIBPCRE2 'PCRE v2: setup invalid UTF-8 data' '
+	printf "\\200\\n" >invalid-0x80 &&
+	echo "ævar" >expected &&
+	cat expected >>invalid-0x80 &&
+	git add invalid-0x80
+'
+
+test_expect_success GETTEXT_LOCALE,LIBPCRE2 'PCRE v2: grep ASCII from invalid UTF-8 data' '
+	git grep -h "var" invalid-0x80 >actual &&
+	test_cmp expected actual &&
+	git grep -h "(*NO_JIT)var" invalid-0x80 >actual &&
+	test_cmp expected actual
+'
+
+test_expect_success GETTEXT_LOCALE,LIBPCRE2 'PCRE v2: grep non-ASCII from invalid UTF-8 data' '
+	git grep -h "æ" invalid-0x80 >actual &&
+	test_cmp expected actual &&
+	git grep -h "(*NO_JIT)æ" invalid-0x80 >actual &&
+	test_cmp expected actual
+'
+
+test_expect_success GETTEXT_LOCALE,LIBPCRE2 'PCRE v2: grep non-ASCII from invalid UTF-8 data with -i' '
+	test_might_fail git grep -hi "Æ" invalid-0x80 >actual &&
+	if test -s actual
+	then
+	    test_cmp expected actual
+	fi &&
+	test_must_fail git grep -hi "(*NO_JIT)Æ" invalid-0x80 >actual &&
+	! test_cmp expected actual
+'
+
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t7814-grep-recurse-submodules.sh 1.2.3+git2.25.1-1/git/t/t7814-grep-recurse-submodules.sh
--- 1.2.1+git2.18.0-1/git/t/t7814-grep-recurse-submodules.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t7814-grep-recurse-submodules.sh	2020-02-17 04:47:35.000000000 +0000
@@ -14,12 +14,14 @@ test_expect_success 'setup directory str
 	echo "(3|4)" >b/b &&
 	git add a b &&
 	git commit -m "add a and b" &&
+	test_tick &&
 	git init submodule &&
 	echo "(1|2)d(3|4)" >submodule/a &&
 	git -C submodule add a &&
 	git -C submodule commit -m "add a" &&
 	git submodule add ./submodule &&
-	git commit -m "added submodule"
+	git commit -m "added submodule" &&
+	test_tick
 '
 
 test_expect_success 'grep correctly finds patterns in a submodule' '
@@ -65,11 +67,14 @@ test_expect_success 'grep and nested sub
 	echo "(1|2)d(3|4)" >submodule/sub/a &&
 	git -C submodule/sub add a &&
 	git -C submodule/sub commit -m "add a" &&
+	test_tick &&
 	git -C submodule submodule add ./sub &&
 	git -C submodule add sub &&
 	git -C submodule commit -m "added sub" &&
+	test_tick &&
 	git add submodule &&
 	git commit -m "updated submodule" &&
+	test_tick &&
 
 	cat >expect <<-\EOF &&
 	a:(1|2)d(3|4)
@@ -179,15 +184,18 @@ test_expect_success !MINGW 'grep recurse
 	echo "(1|2)d(3|4)" >"parent/fi:le" &&
 	git -C parent add "fi:le" &&
 	git -C parent commit -m "add fi:le" &&
+	test_tick &&
 
 	git init "su:b" &&
 	test_when_finished "rm -rf su:b" &&
 	echo "(1|2)d(3|4)" >"su:b/fi:le" &&
 	git -C "su:b" add "fi:le" &&
 	git -C "su:b" commit -m "add fi:le" &&
+	test_tick &&
 
 	git -C parent submodule add "../su:b" "su:b" &&
 	git -C parent commit -m "add submodule" &&
+	test_tick &&
 
 	cat >expect <<-\EOF &&
 	fi:le:(1|2)d(3|4)
@@ -210,15 +218,18 @@ test_expect_success 'grep history with m
 	echo "(1|2)d(3|4)" >parent/file &&
 	git -C parent add file &&
 	git -C parent commit -m "add file" &&
+	test_tick &&
 
 	git init sub &&
 	test_when_finished "rm -rf sub" &&
 	echo "(1|2)d(3|4)" >sub/file &&
 	git -C sub add file &&
 	git -C sub commit -m "add file" &&
+	test_tick &&
 
 	git -C parent submodule add ../sub dir/sub &&
 	git -C parent commit -m "add submodule" &&
+	test_tick &&
 
 	cat >expect <<-\EOF &&
 	dir/sub/file:(1|2)d(3|4)
@@ -229,6 +240,7 @@ test_expect_success 'grep history with m
 
 	git -C parent mv dir/sub sub-moved &&
 	git -C parent commit -m "moved submodule" &&
+	test_tick &&
 
 	cat >expect <<-\EOF &&
 	file:(1|2)d(3|4)
@@ -251,6 +263,7 @@ test_expect_success 'grep using relative
 	echo "(1|2)d(3|4)" >sub/file &&
 	git -C sub add file &&
 	git -C sub commit -m "add file" &&
+	test_tick &&
 
 	git init parent &&
 	echo "(1|2)d(3|4)" >parent/file &&
@@ -260,6 +273,7 @@ test_expect_success 'grep using relative
 	git -C parent add src/file2 &&
 	git -C parent submodule add ../sub &&
 	git -C parent commit -m "add files and submodule" &&
+	test_tick &&
 
 	# From top works
 	cat >expect <<-\EOF &&
@@ -293,6 +307,7 @@ test_expect_success 'grep from a subdir'
 	echo "(1|2)d(3|4)" >sub/file &&
 	git -C sub add file &&
 	git -C sub commit -m "add file" &&
+	test_tick &&
 
 	git init parent &&
 	mkdir parent/src &&
@@ -301,6 +316,7 @@ test_expect_success 'grep from a subdir'
 	git -C parent submodule add ../sub src/sub &&
 	git -C parent submodule add ../sub sub &&
 	git -C parent commit -m "add files and submodules" &&
+	test_tick &&
 
 	# Verify grep from root works
 	cat >expect <<-\EOF &&
@@ -329,7 +345,16 @@ test_incompatible_with_recurse_submodule
 }
 
 test_incompatible_with_recurse_submodules --untracked
-test_incompatible_with_recurse_submodules --no-index
+
+test_expect_success 'grep --recurse-submodules --no-index ignores --recurse-submodules' '
+	git grep --recurse-submodules --no-index -e "^(.|.)[\d]" >actual &&
+	cat >expect <<-\EOF &&
+	a:(1|2)d(3|4)
+	submodule/a:(1|2)d(3|4)
+	submodule/sub/a:(1|2)d(3|4)
+	EOF
+	test_cmp expect actual
+'
 
 test_expect_success 'grep --recurse-submodules should pass the pattern type along' '
 	# Fixed
@@ -380,4 +405,37 @@ test_expect_success 'grep --recurse-subm
 	fi
 '
 
+test_expect_success 'grep --recurse-submodules with submodules without .gitmodules in the working tree' '
+	test_when_finished "git -C submodule checkout .gitmodules" &&
+	rm submodule/.gitmodules &&
+	git grep --recurse-submodules -e "(.|.)[\d]" >actual &&
+	cat >expect <<-\EOF &&
+	a:(1|2)d(3|4)
+	submodule/a:(1|2)d(3|4)
+	submodule/sub/a:(1|2)d(3|4)
+	EOF
+	test_cmp expect actual
+'
+
+reset_and_clean () {
+	git reset --hard &&
+	git clean -fd &&
+	git submodule foreach --recursive 'git reset --hard' &&
+	git submodule foreach --recursive 'git clean -fd'
+}
+
+test_expect_success 'grep --recurse-submodules without --cached considers worktree modifications' '
+	reset_and_clean &&
+	echo "A modified line in submodule" >>submodule/a &&
+	echo "submodule/a:A modified line in submodule" >expect &&
+	git grep --recurse-submodules "A modified line in submodule" >actual &&
+	test_cmp expect actual
+'
+
+test_expect_success 'grep --recurse-submodules with --cached ignores worktree modifications' '
+	reset_and_clean &&
+	echo "A modified line in submodule" >>submodule/a &&
+	test_must_fail git grep --recurse-submodules --cached "A modified line in submodule" >actual 2>&1 &&
+	test_must_be_empty actual
+'
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t7815-grep-binary.sh 1.2.3+git2.25.1-1/git/t/t7815-grep-binary.sh
--- 1.2.1+git2.18.0-1/git/t/t7815-grep-binary.sh	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t7815-grep-binary.sh	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,148 @@
+#!/bin/sh
+
+test_description='git grep in binary files'
+
+. ./test-lib.sh
+
+test_expect_success 'setup' "
+	echo 'binaryQfileQm[*]cQ*æQð' | q_to_nul >a &&
+	git add a &&
+	git commit -m.
+"
+
+test_expect_success 'git grep ina a' '
+	echo Binary file a matches >expect &&
+	git grep ina a >actual &&
+	test_cmp expect actual
+'
+
+test_expect_success 'git grep -ah ina a' '
+	git grep -ah ina a >actual &&
+	test_cmp a actual
+'
+
+test_expect_success 'git grep -I ina a' '
+	test_must_fail git grep -I ina a >actual &&
+	test_must_be_empty actual
+'
+
+test_expect_success 'git grep -c ina a' '
+	echo a:1 >expect &&
+	git grep -c ina a >actual &&
+	test_cmp expect actual
+'
+
+test_expect_success 'git grep -l ina a' '
+	echo a >expect &&
+	git grep -l ina a >actual &&
+	test_cmp expect actual
+'
+
+test_expect_success 'git grep -L bar a' '
+	echo a >expect &&
+	git grep -L bar a >actual &&
+	test_cmp expect actual
+'
+
+test_expect_success 'git grep -q ina a' '
+	git grep -q ina a >actual &&
+	test_must_be_empty actual
+'
+
+test_expect_success 'git grep -F ile a' '
+	git grep -F ile a
+'
+
+test_expect_success 'git grep -Fi iLE a' '
+	git grep -Fi iLE a
+'
+
+# This test actually passes on platforms where regexec() supports the
+# flag REG_STARTEND.
+test_expect_success 'git grep ile a' '
+	git grep ile a
+'
+
+test_expect_failure 'git grep .fi a' '
+	git grep .fi a
+'
+
+test_expect_success 'grep respects binary diff attribute' '
+	echo text >t &&
+	git add t &&
+	echo t:text >expect &&
+	git grep text t >actual &&
+	test_cmp expect actual &&
+	echo "t -diff" >.gitattributes &&
+	echo "Binary file t matches" >expect &&
+	git grep text t >actual &&
+	test_cmp expect actual
+'
+
+test_expect_success 'grep --cached respects binary diff attribute' '
+	git grep --cached text t >actual &&
+	test_cmp expect actual
+'
+
+test_expect_success 'grep --cached respects binary diff attribute (2)' '
+	git add .gitattributes &&
+	rm .gitattributes &&
+	git grep --cached text t >actual &&
+	test_when_finished "git rm --cached .gitattributes" &&
+	test_when_finished "git checkout .gitattributes" &&
+	test_cmp expect actual
+'
+
+test_expect_success 'grep revision respects binary diff attribute' '
+	git commit -m new &&
+	echo "Binary file HEAD:t matches" >expect &&
+	git grep text HEAD -- t >actual &&
+	test_when_finished "git reset HEAD^" &&
+	test_cmp expect actual
+'
+
+test_expect_success 'grep respects not-binary diff attribute' '
+	echo binQary | q_to_nul >b &&
+	git add b &&
+	echo "Binary file b matches" >expect &&
+	git grep bin b >actual &&
+	test_cmp expect actual &&
+	echo "b diff" >.gitattributes &&
+	echo "b:binQary" >expect &&
+	git grep bin b >actual.raw &&
+	nul_to_q <actual.raw >actual &&
+	test_cmp expect actual
+'
+
+cat >nul_to_q_textconv <<'EOF'
+#!/bin/sh
+"$PERL_PATH" -pe 'y/\000/Q/' < "$1"
+EOF
+chmod +x nul_to_q_textconv
+
+test_expect_success 'setup textconv filters' '
+	echo a diff=foo >.gitattributes &&
+	git config diff.foo.textconv "\"$(pwd)\""/nul_to_q_textconv
+'
+
+test_expect_success 'grep does not honor textconv' '
+	test_must_fail git grep Qfile
+'
+
+test_expect_success 'grep --textconv honors textconv' '
+	echo "a:binaryQfileQm[*]cQ*æQð" >expect &&
+	git grep --textconv Qfile >actual &&
+	test_cmp expect actual
+'
+
+test_expect_success 'grep --no-textconv does not honor textconv' '
+	test_must_fail git grep --no-textconv Qfile
+'
+
+test_expect_success 'grep --textconv blob honors textconv' '
+	echo "HEAD:a:binaryQfileQm[*]cQ*æQð" >expect &&
+	git grep --textconv Qfile HEAD:a >actual &&
+	test_cmp expect actual
+'
+
+test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t7816-grep-binary-pattern.sh 1.2.3+git2.25.1-1/git/t/t7816-grep-binary-pattern.sh
--- 1.2.1+git2.18.0-1/git/t/t7816-grep-binary-pattern.sh	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t7816-grep-binary-pattern.sh	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,127 @@
+#!/bin/sh
+
+test_description='git grep with a binary pattern files'
+
+. ./lib-gettext.sh
+
+nul_match_internal () {
+	matches=$1
+	prereqs=$2
+	lc_all=$3
+	extra_flags=$4
+	flags=$5
+	pattern=$6
+	pattern_human=$(echo "$pattern" | sed 's/Q/<NUL>/g')
+
+	if test "$matches" = 1
+	then
+		test_expect_success $prereqs "LC_ALL='$lc_all' git grep $extra_flags -f f $flags '$pattern_human' a" "
+			printf '$pattern' | q_to_nul >f &&
+			LC_ALL='$lc_all' git grep $extra_flags -f f $flags a
+		"
+	elif test "$matches" = 0
+	then
+		test_expect_success $prereqs "LC_ALL='$lc_all' git grep $extra_flags -f f $flags '$pattern_human' a" "
+			>stderr &&
+			printf '$pattern' | q_to_nul >f &&
+			test_must_fail env LC_ALL=\"$lc_all\" git grep $extra_flags -f f $flags a 2>stderr &&
+			test_i18ngrep ! 'This is only supported with -P under PCRE v2' stderr
+		"
+	elif test "$matches" = P
+	then
+		test_expect_success $prereqs "error, PCRE v2 only: LC_ALL='$lc_all' git grep -f f $flags '$pattern_human' a" "
+			>stderr &&
+			printf '$pattern' | q_to_nul >f &&
+			test_must_fail env LC_ALL=\"$lc_all\" git grep -f f $flags a 2>stderr &&
+			test_i18ngrep 'This is only supported with -P under PCRE v2' stderr
+		"
+	else
+		test_expect_success "PANIC: Test framework error. Unknown matches value $matches" 'false'
+	fi
+}
+
+nul_match () {
+	matches=$1
+	matches_pcre2=$2
+	matches_pcre2_locale=$3
+	flags=$4
+	pattern=$5
+	pattern_human=$(echo "$pattern" | sed 's/Q/<NUL>/g')
+
+	nul_match_internal "$matches" "" "C" "" "$flags" "$pattern"
+	nul_match_internal "$matches_pcre2" "LIBPCRE2" "C" "-P" "$flags" "$pattern"
+	nul_match_internal "$matches_pcre2_locale" "LIBPCRE2,GETTEXT_LOCALE" "$is_IS_locale" "-P" "$flags" "$pattern"
+}
+
+test_expect_success 'setup' "
+	echo 'binaryQfileQm[*]cQ*æQð' | q_to_nul >a &&
+	git add a &&
+	git commit -m.
+"
+
+# Simple fixed-string matching that can use kwset (no -i && non-ASCII)
+nul_match P P P '-F' 'yQf'
+nul_match P P P '-F' 'yQx'
+nul_match P P P '-Fi' 'YQf'
+nul_match P P P '-Fi' 'YQx'
+nul_match P P 1 '' 'yQf'
+nul_match P P 0 '' 'yQx'
+nul_match P P 1 '' 'æQð'
+nul_match P P P '-F' 'eQm[*]c'
+nul_match P P P '-Fi' 'EQM[*]C'
+
+# Regex patterns that would match but shouldn't with -F
+nul_match P P P '-F' 'yQ[f]'
+nul_match P P P '-F' '[y]Qf'
+nul_match P P P '-Fi' 'YQ[F]'
+nul_match P P P '-Fi' '[Y]QF'
+nul_match P P P '-F' 'æQ[ð]'
+nul_match P P P '-F' '[æ]Qð'
+
+# The -F kwset codepath can't handle -i && non-ASCII...
+nul_match P 1 1 '-i' '[æ]Qð'
+
+# ...PCRE v2 only matches non-ASCII with -i casefolding under UTF-8
+# semantics
+nul_match P P P '-Fi' 'ÆQ[Ð]'
+nul_match P 0 1 '-i'  'ÆQ[Ð]'
+nul_match P 0 1 '-i'  '[Æ]QÐ'
+nul_match P 0 1 '-i' '[Æ]Qð'
+nul_match P 0 1 '-i' 'ÆQÐ'
+
+# \0 in regexes can only work with -P & PCRE v2
+nul_match P P 1 '' 'yQ[f]'
+nul_match P P 1 '' '[y]Qf'
+nul_match P P 1 '-i' 'YQ[F]'
+nul_match P P 1 '-i' '[Y]Qf'
+nul_match P P 1 '' 'æQ[ð]'
+nul_match P P 1 '' '[æ]Qð'
+nul_match P P 1 '-i' 'ÆQ[Ð]'
+nul_match P P 1 '' 'eQm.*cQ'
+nul_match P P 1 '-i' 'EQM.*cQ'
+nul_match P P 0 '' 'eQm[*]c'
+nul_match P P 0 '-i' 'EQM[*]C'
+
+# Assert that we're using REG_STARTEND and the pattern doesn't match
+# just because it's cut off at the first \0.
+nul_match P P 0 '-i' 'NOMATCHQð'
+nul_match P P 0 '-i' '[Æ]QNOMATCH'
+nul_match P P 0 '-i' '[æ]QNOMATCH'
+
+# Ensure that the matcher doesn't regress to something that stops at
+# \0
+nul_match P P P '-F' 'yQ[f]'
+nul_match P P P '-Fi' 'YQ[F]'
+nul_match P P 0 '' 'yQNOMATCH'
+nul_match P P 0 '' 'QNOMATCH'
+nul_match P P 0 '-i' 'YQNOMATCH'
+nul_match P P 0 '-i' 'QNOMATCH'
+nul_match P P P '-F' 'æQ[ð]'
+nul_match P P P '-Fi' 'ÆQ[Ð]'
+nul_match P P 1 '-i' 'ÆQ[Ð]'
+nul_match P P 0 '' 'yQNÓMATCH'
+nul_match P P 0 '' 'QNÓMATCH'
+nul_match P P 0 '-i' 'YQNÓMATCH'
+nul_match P P 0 '-i' 'QNÓMATCH'
+
+test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t8002-blame.sh 1.2.3+git2.25.1-1/git/t/t8002-blame.sh
--- 1.2.1+git2.18.0-1/git/t/t8002-blame.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t8002-blame.sh	2020-02-17 04:47:35.000000000 +0000
@@ -118,4 +118,8 @@ test_expect_success '--no-abbrev works l
 	check_abbrev 40 --no-abbrev
 '
 
+test_expect_success '--exclude-promisor-objects does not BUG-crash' '
+	test_must_fail git blame --exclude-promisor-objects one
+'
+
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t8003-blame-corner-cases.sh 1.2.3+git2.25.1-1/git/t/t8003-blame-corner-cases.sh
--- 1.2.1+git2.18.0-1/git/t/t8003-blame-corner-cases.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t8003-blame-corner-cases.sh	2020-02-17 04:47:35.000000000 +0000
@@ -216,14 +216,18 @@ test_expect_success 'blame -L with inval
 '
 
 test_expect_success 'blame -L with invalid end' '
-	test_must_fail git blame -L1,5 tres 2>errors &&
-	test_i18ngrep "has only 2 lines" errors
+	git blame -L1,5 tres >out &&
+	test_line_count = 2 out
 '
 
 test_expect_success 'blame parses <end> part of -L' '
 	git blame -L1,1 tres >out &&
-	cat out &&
-	test $(wc -l < out) -eq 1
+	test_line_count = 1 out
+'
+
+test_expect_success 'blame -Ln,-(n+1)' '
+	git blame -L3,-4 nine_lines >out &&
+	test_line_count = 3 out
 '
 
 test_expect_success 'indent of line numbers, nine lines' '
@@ -271,4 +275,40 @@ test_expect_success 'blame file with CRL
 	grep "A U Thor" actual
 '
 
+# Tests the splitting and merging of blame entries in blame_coalesce().
+# The output of blame is the same, regardless of whether blame_coalesce() runs
+# or not, so we'd likely only notice a problem if blame crashes or assigned
+# blame to the "splitting" commit ('SPLIT' below).
+test_expect_success 'blame coalesce' '
+	cat >giraffe <<-\EOF &&
+	ABC
+	DEF
+	EOF
+	git add giraffe &&
+	git commit -m "original file" &&
+	oid=$(git rev-parse HEAD) &&
+
+	cat >giraffe <<-\EOF &&
+	ABC
+	SPLIT
+	DEF
+	EOF
+	git add giraffe &&
+	git commit -m "interior SPLIT line" &&
+
+	cat >giraffe <<-\EOF &&
+	ABC
+	DEF
+	EOF
+	git add giraffe &&
+	git commit -m "same contents as original" &&
+
+	cat >expect <<-EOF &&
+	$oid 1) ABC
+	$oid 2) DEF
+	EOF
+	git -c core.abbrev=40 blame -s giraffe >actual &&
+	test_cmp expect actual
+'
+
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t8010-cat-file-filters.sh 1.2.3+git2.25.1-1/git/t/t8010-cat-file-filters.sh
--- 1.2.1+git2.18.0-1/git/t/t8010-cat-file-filters.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t8010-cat-file-filters.sh	2020-02-17 04:47:35.000000000 +0000
@@ -47,7 +47,7 @@ test_expect_success 'cat-file --textconv
 test_expect_success '--path=<path> complains without --textconv/--filters' '
 	sha1=$(git rev-parse -q --verify HEAD:world.txt) &&
 	test_must_fail git cat-file --path=hello.txt blob $sha1 >actual 2>err &&
-	test ! -s actual &&
+	test_must_be_empty actual &&
 	grep "path.*needs.*filters" err
 '
 
diff -pruN 1.2.1+git2.18.0-1/git/t/t8013-blame-ignore-revs.sh 1.2.3+git2.25.1-1/git/t/t8013-blame-ignore-revs.sh
--- 1.2.1+git2.18.0-1/git/t/t8013-blame-ignore-revs.sh	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t8013-blame-ignore-revs.sh	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,274 @@
+#!/bin/sh
+
+test_description='ignore revisions when blaming'
+. ./test-lib.sh
+
+# Creates:
+# 	A--B--X
+# A added line 1 and B added line 2.  X makes changes to those lines.  Sanity
+# check that X is blamed for both lines.
+test_expect_success setup '
+	test_commit A file line1 &&
+
+	echo line2 >>file &&
+	git add file &&
+	test_tick &&
+	git commit -m B &&
+	git tag B &&
+
+	test_write_lines line-one line-two >file &&
+	git add file &&
+	test_tick &&
+	git commit -m X &&
+	git tag X &&
+
+	git blame --line-porcelain file >blame_raw &&
+
+	grep -E "^[0-9a-f]+ [0-9]+ 1" blame_raw | sed -e "s/ .*//" >actual &&
+	git rev-parse X >expect &&
+	test_cmp expect actual &&
+
+	grep -E "^[0-9a-f]+ [0-9]+ 2" blame_raw | sed -e "s/ .*//" >actual &&
+	git rev-parse X >expect &&
+	test_cmp expect actual
+	'
+
+# Ignore X, make sure A is blamed for line 1 and B for line 2.
+test_expect_success ignore_rev_changing_lines '
+	git blame --line-porcelain --ignore-rev X file >blame_raw &&
+
+	grep -E "^[0-9a-f]+ [0-9]+ 1" blame_raw | sed -e "s/ .*//" >actual &&
+	git rev-parse A >expect &&
+	test_cmp expect actual &&
+
+	grep -E "^[0-9a-f]+ [0-9]+ 2" blame_raw | sed -e "s/ .*//" >actual &&
+	git rev-parse B >expect &&
+	test_cmp expect actual
+	'
+
+# For ignored revs that have added 'unblamable' lines, attribute those to the
+# ignored commit.
+# 	A--B--X--Y
+# Where Y changes lines 1 and 2, and adds lines 3 and 4.  The added lines ought
+# to have nothing in common with "line-one" or "line-two", to keep any
+# heuristics from matching them with any lines in the parent.
+test_expect_success ignore_rev_adding_unblamable_lines '
+	test_write_lines line-one-change line-two-changed y3 y4 >file &&
+	git add file &&
+	test_tick &&
+	git commit -m Y &&
+	git tag Y &&
+
+	git rev-parse Y >expect &&
+	git blame --line-porcelain file --ignore-rev Y >blame_raw &&
+
+	grep -E "^[0-9a-f]+ [0-9]+ 3" blame_raw | sed -e "s/ .*//" >actual &&
+	test_cmp expect actual &&
+
+	grep -E "^[0-9a-f]+ [0-9]+ 4" blame_raw | sed -e "s/ .*//" >actual &&
+	test_cmp expect actual
+	'
+
+# Ignore X and Y, both in separate files.  Lines 1 == A, 2 == B.
+test_expect_success ignore_revs_from_files '
+	git rev-parse X >ignore_x &&
+	git rev-parse Y >ignore_y &&
+	git blame --line-porcelain file --ignore-revs-file ignore_x --ignore-revs-file ignore_y >blame_raw &&
+
+	grep -E "^[0-9a-f]+ [0-9]+ 1" blame_raw | sed -e "s/ .*//" >actual &&
+	git rev-parse A >expect &&
+	test_cmp expect actual &&
+
+	grep -E "^[0-9a-f]+ [0-9]+ 2" blame_raw | sed -e "s/ .*//" >actual &&
+	git rev-parse B >expect &&
+	test_cmp expect actual
+	'
+
+# Ignore X from the config option, Y from a file.
+test_expect_success ignore_revs_from_configs_and_files '
+	git config --add blame.ignoreRevsFile ignore_x &&
+	git blame --line-porcelain file --ignore-revs-file ignore_y >blame_raw &&
+
+	grep -E "^[0-9a-f]+ [0-9]+ 1" blame_raw | sed -e "s/ .*//" >actual &&
+	git rev-parse A >expect &&
+	test_cmp expect actual &&
+
+	grep -E "^[0-9a-f]+ [0-9]+ 2" blame_raw | sed -e "s/ .*//" >actual &&
+	git rev-parse B >expect &&
+	test_cmp expect actual
+	'
+
+# Override blame.ignoreRevsFile (ignore_x) with an empty string.  X should be
+# blamed now for lines 1 and 2, since we are no longer ignoring X.
+test_expect_success override_ignore_revs_file '
+	git blame --line-porcelain file --ignore-revs-file "" --ignore-revs-file ignore_y >blame_raw &&
+	git rev-parse X >expect &&
+
+	grep -E "^[0-9a-f]+ [0-9]+ 1" blame_raw | sed -e "s/ .*//" >actual &&
+	test_cmp expect actual &&
+
+	grep -E "^[0-9a-f]+ [0-9]+ 2" blame_raw | sed -e "s/ .*//" >actual &&
+	test_cmp expect actual
+	'
+test_expect_success bad_files_and_revs '
+	test_must_fail git blame file --ignore-rev NOREV 2>err &&
+	test_i18ngrep "cannot find revision NOREV to ignore" err &&
+
+	test_must_fail git blame file --ignore-revs-file NOFILE 2>err &&
+	test_i18ngrep "could not open.*: NOFILE" err &&
+
+	echo NOREV >ignore_norev &&
+	test_must_fail git blame file --ignore-revs-file ignore_norev 2>err &&
+	test_i18ngrep "invalid object name: NOREV" err
+	'
+
+# For ignored revs that have added 'unblamable' lines, mark those lines with a
+# '*'
+# 	A--B--X--Y
+# Lines 3 and 4 are from Y and unblamable.  This was set up in
+# ignore_rev_adding_unblamable_lines.
+test_expect_success mark_unblamable_lines '
+	git config --add blame.markUnblamableLines true &&
+
+	git blame --ignore-rev Y file >blame_raw &&
+	echo "*" >expect &&
+
+	sed -n "3p" blame_raw | cut -c1 >actual &&
+	test_cmp expect actual &&
+
+	sed -n "4p" blame_raw | cut -c1 >actual &&
+	test_cmp expect actual
+	'
+
+# Commit Z will touch the first two lines.  Y touched all four.
+# 	A--B--X--Y--Z
+# The blame output when ignoring Z should be:
+# ?Y ... 1)
+# ?Y ... 2)
+# Y  ... 3)
+# Y  ... 4)
+# We're checking only the first character
+test_expect_success mark_ignored_lines '
+	git config --add blame.markIgnoredLines true &&
+
+	test_write_lines line-one-Z line-two-Z y3 y4 >file &&
+	git add file &&
+	test_tick &&
+	git commit -m Z &&
+	git tag Z &&
+
+	git blame --ignore-rev Z file >blame_raw &&
+	echo "?" >expect &&
+
+	sed -n "1p" blame_raw | cut -c1 >actual &&
+	test_cmp expect actual &&
+
+	sed -n "2p" blame_raw | cut -c1 >actual &&
+	test_cmp expect actual &&
+
+	sed -n "3p" blame_raw | cut -c1 >actual &&
+	! test_cmp expect actual &&
+
+	sed -n "4p" blame_raw | cut -c1 >actual &&
+	! test_cmp expect actual
+	'
+
+# For ignored revs that added 'unblamable' lines and more recent commits changed
+# the blamable lines, mark the unblamable lines with a
+# '*'
+# 	A--B--X--Y--Z
+# Lines 3 and 4 are from Y and unblamable, as set up in
+# ignore_rev_adding_unblamable_lines.  Z changed lines 1 and 2.
+test_expect_success mark_unblamable_lines_intermediate '
+	git config --add blame.markUnblamableLines true &&
+
+	git blame --ignore-rev Y file >blame_raw 2>stderr &&
+	echo "*" >expect &&
+
+	sed -n "3p" blame_raw | cut -c1 >actual &&
+	test_cmp expect actual &&
+
+	sed -n "4p" blame_raw | cut -c1 >actual &&
+	test_cmp expect actual
+	'
+
+# The heuristic called by guess_line_blames() tries to find the size of a
+# blame_entry 'e' in the parent's address space.  Those calculations need to
+# check for negative or zero values for when a blame entry is completely outside
+# the window of the parent's version of a file.
+#
+# This happens when one commit adds several lines (commit B below).  A later
+# commit (C) changes one line in the middle of B's change.  Commit C gets blamed
+# for its change, and that breaks up B's change into multiple blame entries.
+# When processing B, one of the blame_entries is outside A's window (which was
+# zero - it had no lines added on its side of the diff).
+#
+# A--B--C, ignore B to test the ignore heuristic's boundary checks.
+test_expect_success ignored_chunk_negative_parent_size '
+	rm -rf .git/ &&
+	git init &&
+
+	test_write_lines L1 L2 L7 L8 L9 >file &&
+	git add file &&
+	test_tick &&
+	git commit -m A &&
+	git tag A &&
+
+	test_write_lines L1 L2 L3 L4 L5 L6 L7 L8 L9 >file &&
+	git add file &&
+	test_tick &&
+	git commit -m B &&
+	git tag B &&
+
+	test_write_lines L1 L2 L3 L4 xxx L6 L7 L8 L9 >file &&
+	git add file &&
+	test_tick &&
+	git commit -m C &&
+	git tag C &&
+
+	git blame file --ignore-rev B >blame_raw
+	'
+
+# Resetting the repo and creating:
+#
+# A--B--M
+#  \   /
+#   C-+
+#
+# 'A' creates a file.  B changes line 1, and C changes line 9.  M merges.
+test_expect_success ignore_merge '
+	rm -rf .git/ &&
+	git init &&
+
+	test_write_lines L1 L2 L3 L4 L5 L6 L7 L8 L9 >file &&
+	git add file &&
+	test_tick &&
+	git commit -m A &&
+	git tag A &&
+
+	test_write_lines BB L2 L3 L4 L5 L6 L7 L8 L9 >file &&
+	git add file &&
+	test_tick &&
+	git commit -m B &&
+	git tag B &&
+
+	git reset --hard A &&
+	test_write_lines L1 L2 L3 L4 L5 L6 L7 L8 CC >file &&
+	git add file &&
+	test_tick &&
+	git commit -m C &&
+	git tag C &&
+
+	test_merge M B &&
+	git blame --line-porcelain file --ignore-rev M >blame_raw &&
+
+	grep -E "^[0-9a-f]+ [0-9]+ 1" blame_raw | sed -e "s/ .*//" >actual &&
+	git rev-parse B >expect &&
+	test_cmp expect actual &&
+
+	grep -E "^[0-9a-f]+ [0-9]+ 9" blame_raw | sed -e "s/ .*//" >actual &&
+	git rev-parse C >expect &&
+	test_cmp expect actual
+	'
+
+test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t8014-blame-ignore-fuzzy.sh 1.2.3+git2.25.1-1/git/t/t8014-blame-ignore-fuzzy.sh
--- 1.2.1+git2.18.0-1/git/t/t8014-blame-ignore-fuzzy.sh	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t8014-blame-ignore-fuzzy.sh	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,437 @@
+#!/bin/sh
+
+test_description='git blame ignore fuzzy heuristic'
+. ./test-lib.sh
+
+pick_author='s/^[0-9a-f^]* *(\([^ ]*\) .*/\1/'
+
+# Each test is composed of 4 variables:
+# titleN - the test name
+# aN - the initial content
+# bN - the final content
+# expectedN - the line numbers from aN that we expect git blame
+#             on bN to identify, or "Final" if bN itself should
+#             be identified as the origin of that line.
+
+# We start at test 2 because setup will show as test 1
+title2="Regression test for partially overlapping search ranges"
+cat <<EOF >a2
+1
+2
+3
+abcdef
+5
+6
+7
+ijkl
+9
+10
+11
+pqrs
+13
+14
+15
+wxyz
+17
+18
+19
+EOF
+cat <<EOF >b2
+abcde
+ijk
+pqr
+wxy
+EOF
+cat <<EOF >expected2
+4
+8
+12
+16
+EOF
+
+title3="Combine 3 lines into 2"
+cat <<EOF >a3
+if ((maxgrow==0) ||
+	( single_line_field && (field->dcols < maxgrow)) ||
+	(!single_line_field && (field->drows < maxgrow)))
+EOF
+cat <<EOF >b3
+if ((maxgrow == 0) || (single_line_field && (field->dcols < maxgrow)) ||
+	(!single_line_field && (field->drows < maxgrow))) {
+EOF
+cat <<EOF >expected3
+2
+3
+EOF
+
+title4="Add curly brackets"
+cat <<EOF >a4
+	if (rows) *rows = field->rows;
+	if (cols) *cols = field->cols;
+	if (frow) *frow = field->frow;
+	if (fcol) *fcol = field->fcol;
+EOF
+cat <<EOF >b4
+	if (rows) {
+		*rows = field->rows;
+	}
+	if (cols) {
+		*cols = field->cols;
+	}
+	if (frow) {
+		*frow = field->frow;
+	}
+	if (fcol) {
+		*fcol = field->fcol;
+	}
+EOF
+cat <<EOF >expected4
+1
+1
+Final
+2
+2
+Final
+3
+3
+Final
+4
+4
+Final
+EOF
+
+
+title5="Combine many lines and change case"
+cat <<EOF >a5
+for(row=0,pBuffer=field->buf;
+	row<height;
+	row++,pBuffer+=width )
+{
+	if ((len = (int)( After_End_Of_Data( pBuffer, width ) - pBuffer )) > 0)
+	{
+		wmove( win, row, 0 );
+		waddnstr( win, pBuffer, len );
+EOF
+cat <<EOF >b5
+for (Row = 0, PBuffer = field->buf; Row < Height; Row++, PBuffer += Width) {
+	if ((Len = (int)(afterEndOfData(PBuffer, Width) - PBuffer)) > 0) {
+		wmove(win, Row, 0);
+		waddnstr(win, PBuffer, Len);
+EOF
+cat <<EOF >expected5
+1
+5
+7
+8
+EOF
+
+title6="Rename and combine lines"
+cat <<EOF >a6
+bool need_visual_update = ((form != (FORM *)0)      &&
+	(form->status & _POSTED) &&
+	(form->current==field));
+
+if (need_visual_update)
+	Synchronize_Buffer(form);
+
+if (single_line_field)
+{
+	growth = field->cols * amount;
+	if (field->maxgrow)
+		growth = Minimum(field->maxgrow - field->dcols,growth);
+	field->dcols += growth;
+	if (field->dcols == field->maxgrow)
+EOF
+cat <<EOF >b6
+bool NeedVisualUpdate = ((Form != (FORM *)0) && (Form->status & _POSTED) &&
+	(Form->current == field));
+
+if (NeedVisualUpdate) {
+	synchronizeBuffer(Form);
+}
+
+if (SingleLineField) {
+	Growth = field->cols * amount;
+	if (field->maxgrow) {
+		Growth = Minimum(field->maxgrow - field->dcols, Growth);
+	}
+	field->dcols += Growth;
+	if (field->dcols == field->maxgrow) {
+EOF
+cat <<EOF >expected6
+1
+3
+4
+5
+6
+Final
+7
+8
+10
+11
+12
+Final
+13
+14
+EOF
+
+# Both lines match identically so position must be used to tie-break.
+title7="Same line twice"
+cat <<EOF >a7
+abc
+abc
+EOF
+cat <<EOF >b7
+abcd
+abcd
+EOF
+cat <<EOF >expected7
+1
+2
+EOF
+
+title8="Enforce line order"
+cat <<EOF >a8
+abcdef
+ghijkl
+ab
+EOF
+cat <<EOF >b8
+ghijk
+abcd
+EOF
+cat <<EOF >expected8
+2
+3
+EOF
+
+title9="Expand lines and rename variables"
+cat <<EOF >a9
+int myFunction(int ArgumentOne, Thing *ArgTwo, Blah XuglyBug) {
+	Squiggle FabulousResult = squargle(ArgumentOne, *ArgTwo,
+		XuglyBug) + EwwwGlobalWithAReallyLongNameYepTooLong;
+	return FabulousResult * 42;
+}
+EOF
+cat <<EOF >b9
+int myFunction(int argument_one, Thing *arg_asdfgh,
+	Blah xugly_bug) {
+	Squiggle fabulous_result = squargle(argument_one,
+		*arg_asdfgh, xugly_bug)
+		+ g_ewww_global_with_a_really_long_name_yep_too_long;
+	return fabulous_result * 42;
+}
+EOF
+cat <<EOF >expected9
+1
+1
+2
+3
+3
+4
+5
+EOF
+
+title10="Two close matches versus one less close match"
+cat <<EOF >a10
+abcdef
+abcdef
+ghijkl
+EOF
+cat <<EOF >b10
+gh
+abcdefx
+EOF
+cat <<EOF >expected10
+Final
+2
+EOF
+
+# The first line of b matches best with the last line of a, but the overall
+# match is better if we match it with the the first line of a.
+title11="Piggy in the middle"
+cat <<EOF >a11
+abcdefg
+ijklmn
+abcdefgh
+EOF
+cat <<EOF >b11
+abcdefghx
+ijklm
+EOF
+cat <<EOF >expected11
+1
+2
+EOF
+
+title12="No trailing newline"
+printf "abc\ndef" >a12
+printf "abx\nstu" >b12
+cat <<EOF >expected12
+1
+Final
+EOF
+
+title13="Reorder includes"
+cat <<EOF >a13
+#include "c.h"
+#include "b.h"
+#include "a.h"
+#include "e.h"
+#include "d.h"
+EOF
+cat <<EOF >b13
+#include "a.h"
+#include "b.h"
+#include "c.h"
+#include "d.h"
+#include "e.h"
+EOF
+cat <<EOF >expected13
+3
+2
+1
+5
+4
+EOF
+
+last_test=13
+
+test_expect_success setup '
+	for i in $(test_seq 2 $last_test)
+	do
+		# Append each line in a separate commit to make it easy to
+		# check which original line the blame output relates to.
+
+		line_count=0 &&
+		while IFS= read line
+		do
+			line_count=$((line_count+1)) &&
+			echo "$line" >>"$i" &&
+			git add "$i" &&
+			test_tick &&
+			GIT_AUTHOR_NAME="$line_count" git commit -m "$line_count"
+		done <"a$i"
+	done &&
+
+	for i in $(test_seq 2 $last_test)
+	do
+		# Overwrite the files with the final content.
+		cp b$i $i &&
+		git add $i
+	done &&
+	test_tick &&
+
+	# Commit the final content all at once so it can all be
+	# referred to with the same commit ID.
+	GIT_AUTHOR_NAME=Final git commit -m Final &&
+
+	IGNOREME=$(git rev-parse HEAD)
+'
+
+for i in $(test_seq 2 $last_test); do
+	eval title="\$title$i"
+	test_expect_success "$title" \
+	"git blame -M9 --ignore-rev $IGNOREME $i >output &&
+	sed -e \"$pick_author\" output >actual &&
+	test_cmp expected$i actual"
+done
+
+# This invoked a null pointer dereference when the chunk callback was called
+# with a zero length parent chunk and there were no more suspects.
+test_expect_success 'Diff chunks with no suspects' '
+	test_write_lines xy1 A B C xy1 >file &&
+	git add file &&
+	test_tick &&
+	GIT_AUTHOR_NAME=1 git commit -m 1 &&
+
+	test_write_lines xy2 A B xy2 C xy2 >file &&
+	git add file &&
+	test_tick &&
+	GIT_AUTHOR_NAME=2 git commit -m 2 &&
+	REV_2=$(git rev-parse HEAD) &&
+
+	test_write_lines xy3 A >file &&
+	git add file &&
+	test_tick &&
+	GIT_AUTHOR_NAME=3 git commit -m 3 &&
+	REV_3=$(git rev-parse HEAD) &&
+
+	test_write_lines 1 1 >expected &&
+
+	git blame --ignore-rev $REV_2 --ignore-rev $REV_3 file >output &&
+	sed -e "$pick_author" output >actual &&
+
+	test_cmp expected actual
+	'
+
+test_expect_success 'position matching' '
+	test_write_lines abc def >file2 &&
+	git add file2 &&
+	test_tick &&
+	GIT_AUTHOR_NAME=1 git commit -m 1 &&
+
+	test_write_lines abc def abc def >file2 &&
+	git add file2 &&
+	test_tick &&
+	GIT_AUTHOR_NAME=2 git commit -m 2 &&
+
+	test_write_lines abcx defx abcx defx >file2 &&
+	git add file2 &&
+	test_tick &&
+	GIT_AUTHOR_NAME=3 git commit -m 3 &&
+	REV_3=$(git rev-parse HEAD) &&
+
+	test_write_lines abcy defy abcx defx >file2 &&
+	git add file2 &&
+	test_tick &&
+	GIT_AUTHOR_NAME=4 git commit -m 4 &&
+	REV_4=$(git rev-parse HEAD) &&
+
+	test_write_lines 1 1 2 2 >expected &&
+
+	git blame --ignore-rev $REV_3 --ignore-rev $REV_4 file2 >output &&
+	sed -e "$pick_author" output >actual &&
+
+	test_cmp expected actual
+	'
+
+# This fails if each blame entry is processed independently instead of
+# processing each diff change in full.
+test_expect_success 'preserve order' '
+	test_write_lines bcde >file3 &&
+	git add file3 &&
+	test_tick &&
+	GIT_AUTHOR_NAME=1 git commit -m 1 &&
+
+	test_write_lines bcde fghij >file3 &&
+	git add file3 &&
+	test_tick &&
+	GIT_AUTHOR_NAME=2 git commit -m 2 &&
+
+	test_write_lines bcde fghij abcd >file3 &&
+	git add file3 &&
+	test_tick &&
+	GIT_AUTHOR_NAME=3 git commit -m 3 &&
+
+	test_write_lines abcdx fghijx bcdex >file3 &&
+	git add file3 &&
+	test_tick &&
+	GIT_AUTHOR_NAME=4 git commit -m 4 &&
+	REV_4=$(git rev-parse HEAD) &&
+
+	test_write_lines abcdx fghijy bcdex >file3 &&
+	git add file3 &&
+	test_tick &&
+	GIT_AUTHOR_NAME=5 git commit -m 5 &&
+	REV_5=$(git rev-parse HEAD) &&
+
+	test_write_lines 1 2 3 >expected &&
+
+	git blame --ignore-rev $REV_4 --ignore-rev $REV_5 file3 >output &&
+	sed -e "$pick_author" output >actual &&
+
+	test_cmp expected actual
+	'
+
+test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t9001-send-email.sh 1.2.3+git2.25.1-1/git/t/t9001-send-email.sh
--- 1.2.1+git2.18.0-1/git/t/t9001-send-email.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t9001-send-email.sh	2020-02-17 04:47:35.000000000 +0000
@@ -225,6 +225,8 @@ X-Mailer: X-MAILER-STRING
 In-Reply-To: <unique-message-id@example.com>
 References: <unique-message-id@example.com>
 Reply-To: Reply <reply@example.com>
+MIME-Version: 1.0
+Content-Transfer-Encoding: 8bit
 
 Result: OK
 EOF
@@ -251,10 +253,9 @@ test_suppress_self () {
 
 	mv msgtxt1 msgtxt1-$3 &&
 	sed -e '/^$/q' msgtxt1-$3 >"msghdr1-$3" &&
-	>"expected-no-cc-$3" &&
 
 	(grep '^Cc:' msghdr1-$3 >"actual-no-cc-$3";
-	 test_cmp expected-no-cc-$3 actual-no-cc-$3)
+	 test_must_be_empty actual-no-cc-$3)
 }
 
 test_suppress_self_unquoted () {
@@ -330,7 +331,7 @@ test_expect_success $PREREQ 'Show all he
 
 test_expect_success $PREREQ 'Prompting works' '
 	clean_fake_sendmail &&
-	(echo "to@example.com"
+	(echo "to@example.com" &&
 	 echo ""
 	) | GIT_SEND_EMAIL_NOTTY=1 git send-email \
 		--smtp-server="$(pwd)/fake.sendmail" \
@@ -415,6 +416,7 @@ test_expect_success $PREREQ 'reject long
 		--from="Example <nobody@example.com>" \
 		--to=nobody@example.com \
 		--smtp-server="$(pwd)/fake.sendmail" \
+		--transfer-encoding=8bit \
 		$patches longline.patch \
 		2>errors &&
 	grep longline.patch errors
@@ -456,6 +458,71 @@ test_expect_success $PREREQ 'allow long
 		2>errors
 '
 
+test_expect_success $PREREQ 'short lines with auto encoding are 8bit' '
+	clean_fake_sendmail &&
+	git send-email \
+		--from="A <author@example.com>" \
+		--to=nobody@example.com \
+		--smtp-server="$(pwd)/fake.sendmail" \
+		--transfer-encoding=auto \
+		$patches &&
+	grep "Content-Transfer-Encoding: 8bit" msgtxt1
+'
+
+test_expect_success $PREREQ 'long lines with auto encoding are quoted-printable' '
+	clean_fake_sendmail &&
+	git send-email \
+		--from="Example <nobody@example.com>" \
+		--to=nobody@example.com \
+		--smtp-server="$(pwd)/fake.sendmail" \
+		--transfer-encoding=auto \
+		--no-validate \
+		longline.patch &&
+	grep "Content-Transfer-Encoding: quoted-printable" msgtxt1
+'
+
+test_expect_success $PREREQ 'carriage returns with auto encoding are quoted-printable' '
+	clean_fake_sendmail &&
+	cp $patches cr.patch &&
+	printf "this is a line\r\n" >>cr.patch &&
+	git send-email \
+		--from="Example <nobody@example.com>" \
+		--to=nobody@example.com \
+		--smtp-server="$(pwd)/fake.sendmail" \
+		--transfer-encoding=auto \
+		--no-validate \
+		cr.patch &&
+	grep "Content-Transfer-Encoding: quoted-printable" msgtxt1
+'
+
+for enc in auto quoted-printable base64
+do
+	test_expect_success $PREREQ "--validate passes with encoding $enc" '
+		git send-email \
+			--from="Example <nobody@example.com>" \
+			--to=nobody@example.com \
+			--smtp-server="$(pwd)/fake.sendmail" \
+			--transfer-encoding=$enc \
+			--validate \
+			$patches longline.patch
+	'
+
+done
+
+for enc in 7bit 8bit quoted-printable base64
+do
+	test_expect_success $PREREQ "--transfer-encoding=$enc produces correct header" '
+		clean_fake_sendmail &&
+		git send-email \
+			--from="Example <nobody@example.com>" \
+			--to=nobody@example.com \
+			--smtp-server="$(pwd)/fake.sendmail" \
+			--transfer-encoding=$enc \
+			$patches &&
+		grep "Content-Transfer-Encoding: $enc" msgtxt1
+	'
+done
+
 test_expect_success $PREREQ 'Invalid In-Reply-To' '
 	clean_fake_sendmail &&
 	git send-email \
@@ -470,8 +537,8 @@ test_expect_success $PREREQ 'Invalid In-
 
 test_expect_success $PREREQ 'Valid In-Reply-To when prompting' '
 	clean_fake_sendmail &&
-	(echo "From Example <from@example.com>"
-	 echo "To Example <to@example.com>"
+	(echo "From Example <from@example.com>" &&
+	 echo "To Example <to@example.com>" &&
 	 echo ""
 	) | GIT_SEND_EMAIL_NOTTY=1 git send-email \
 		--smtp-server="$(pwd)/fake.sendmail" \
@@ -573,6 +640,8 @@ Subject: [PATCH 1/1] Second.
 Date: DATE-STRING
 Message-Id: MESSAGE-ID-STRING
 X-Mailer: X-MAILER-STRING
+MIME-Version: 1.0
+Content-Transfer-Encoding: 8bit
 
 Result: OK
 EOF
@@ -617,6 +686,8 @@ Subject: [PATCH 1/1] Second.
 Date: DATE-STRING
 Message-Id: MESSAGE-ID-STRING
 X-Mailer: X-MAILER-STRING
+MIME-Version: 1.0
+Content-Transfer-Encoding: 8bit
 
 Result: OK
 EOF
@@ -652,6 +723,8 @@ Subject: [PATCH 1/1] Second.
 Date: DATE-STRING
 Message-Id: MESSAGE-ID-STRING
 X-Mailer: X-MAILER-STRING
+MIME-Version: 1.0
+Content-Transfer-Encoding: 8bit
 
 Result: OK
 EOF
@@ -678,6 +751,8 @@ Subject: [PATCH 1/1] Second.
 Date: DATE-STRING
 Message-Id: MESSAGE-ID-STRING
 X-Mailer: X-MAILER-STRING
+MIME-Version: 1.0
+Content-Transfer-Encoding: 8bit
 
 Result: OK
 EOF
@@ -712,6 +787,8 @@ Subject: [PATCH 1/1] Second.
 Date: DATE-STRING
 Message-Id: MESSAGE-ID-STRING
 X-Mailer: X-MAILER-STRING
+MIME-Version: 1.0
+Content-Transfer-Encoding: 8bit
 
 Result: OK
 EOF
@@ -743,6 +820,8 @@ Subject: [PATCH 1/1] Second.
 Date: DATE-STRING
 Message-Id: MESSAGE-ID-STRING
 X-Mailer: X-MAILER-STRING
+MIME-Version: 1.0
+Content-Transfer-Encoding: 8bit
 
 Result: OK
 EOF
@@ -774,6 +853,8 @@ Subject: [PATCH 1/1] Second.
 Date: DATE-STRING
 Message-Id: MESSAGE-ID-STRING
 X-Mailer: X-MAILER-STRING
+MIME-Version: 1.0
+Content-Transfer-Encoding: 8bit
 
 Result: OK
 EOF
@@ -809,6 +890,8 @@ Subject: [PATCH 1/1] Second.
 Date: DATE-STRING
 Message-Id: MESSAGE-ID-STRING
 X-Mailer: X-MAILER-STRING
+MIME-Version: 1.0
+Content-Transfer-Encoding: 8bit
 
 Result: OK
 EOF
@@ -837,6 +920,8 @@ Subject: [PATCH 1/1] Second.
 Date: DATE-STRING
 Message-Id: MESSAGE-ID-STRING
 X-Mailer: X-MAILER-STRING
+MIME-Version: 1.0
+Content-Transfer-Encoding: 8bit
 
 Result: OK
 EOF
@@ -1119,7 +1204,7 @@ test_expect_success $PREREQ 'no in-reply
 		--from="Example <nobody@example.com>" \
 		--to=nobody@example.com \
 		--no-thread \
-		$patches $patches >stdout &&
+		$patches >stdout &&
 	! grep "In-Reply-To: " stdout
 '
 
@@ -1139,17 +1224,72 @@ test_expect_success $PREREQ 'sendemail.t
 	git send-email \
 		--dry-run \
 		--from="Example <nobody@example.com>" \
-		$patches $patches >stdout &&
+		$patches >stdout &&
 	grep "To: Somebody <somebody@ex.com>" stdout
 '
 
+test_expect_success $PREREQ 'setup sendemail.identity' '
+	git config --replace-all sendemail.to "default@example.com" &&
+	git config --replace-all sendemail.isp.to "isp@example.com" &&
+	git config --replace-all sendemail.cloud.to "cloud@example.com"
+'
+
+test_expect_success $PREREQ 'sendemail.identity: reads the correct identity config' '
+	git -c sendemail.identity=cloud send-email \
+		--dry-run \
+		--from="nobody@example.com" \
+		$patches >stdout &&
+	grep "To: cloud@example.com" stdout
+'
+
+test_expect_success $PREREQ 'sendemail.identity: identity overrides sendemail.identity' '
+	git -c sendemail.identity=cloud send-email \
+		--identity=isp \
+		--dry-run \
+		--from="nobody@example.com" \
+		$patches >stdout &&
+	grep "To: isp@example.com" stdout
+'
+
+test_expect_success $PREREQ 'sendemail.identity: --no-identity clears previous identity' '
+	git -c sendemail.identity=cloud send-email \
+		--no-identity \
+		--dry-run \
+		--from="nobody@example.com" \
+		$patches >stdout &&
+	grep "To: default@example.com" stdout
+'
+
+test_expect_success $PREREQ 'sendemail.identity: bool identity variable existence overrides' '
+	git -c sendemail.identity=cloud \
+		-c sendemail.xmailer=true \
+		-c sendemail.cloud.xmailer=false \
+		send-email \
+		--dry-run \
+		--from="nobody@example.com" \
+		$patches >stdout &&
+	grep "To: cloud@example.com" stdout &&
+	! grep "X-Mailer" stdout
+'
+
+test_expect_success $PREREQ 'sendemail.identity: bool variable fallback' '
+	git -c sendemail.identity=cloud \
+		-c sendemail.xmailer=false \
+		send-email \
+		--dry-run \
+		--from="nobody@example.com" \
+		$patches >stdout &&
+	grep "To: cloud@example.com" stdout &&
+	! grep "X-Mailer" stdout
+'
+
 test_expect_success $PREREQ '--no-to overrides sendemail.to' '
 	git send-email \
 		--dry-run \
 		--from="Example <nobody@example.com>" \
 		--no-to \
 		--to=nobody@example.com \
-		$patches $patches >stdout &&
+		$patches >stdout &&
 	grep "To: nobody@example.com" stdout &&
 	! grep "To: Somebody <somebody@ex.com>" stdout
 '
@@ -1160,7 +1300,7 @@ test_expect_success $PREREQ 'sendemail.c
 		--dry-run \
 		--from="Example <nobody@example.com>" \
 		--to=nobody@example.com \
-		$patches $patches >stdout &&
+		$patches >stdout &&
 	grep "Cc: Somebody <somebody@ex.com>" stdout
 '
 
@@ -1171,7 +1311,7 @@ test_expect_success $PREREQ '--no-cc ove
 		--no-cc \
 		--cc=bodies@example.com \
 		--to=nobody@example.com \
-		$patches $patches >stdout &&
+		$patches >stdout &&
 	grep "Cc: bodies@example.com" stdout &&
 	! grep "Cc: Somebody <somebody@ex.com>" stdout
 '
@@ -1183,7 +1323,7 @@ test_expect_success $PREREQ 'sendemail.b
 		--from="Example <nobody@example.com>" \
 		--to=nobody@example.com \
 		--smtp-server relay.example.com \
-		$patches $patches >stdout &&
+		$patches >stdout &&
 	grep "RCPT TO:<other@ex.com>" stdout
 '
 
@@ -1195,7 +1335,7 @@ test_expect_success $PREREQ '--no-bcc ov
 		--bcc=bodies@example.com \
 		--to=nobody@example.com \
 		--smtp-server relay.example.com \
-		$patches $patches >stdout &&
+		$patches >stdout &&
 	grep "RCPT TO:<bodies@example.com>" stdout &&
 	! grep "RCPT TO:<other@ex.com>" stdout
 '
@@ -1352,10 +1492,10 @@ test_expect_success $PREREQ 'setup expec
 	EOF
 '
 
-test_expect_success $PREREQ 'sendemail.transferencoding=7bit fails on 8bit data' '
+test_expect_success $PREREQ '--transfer-encoding overrides sendemail.transferEncoding' '
 	clean_fake_sendmail &&
-	git config sendemail.transferEncoding 7bit &&
-	test_must_fail git send-email \
+	test_must_fail git -c sendemail.transferEncoding=8bit \
+		send-email \
 		--transfer-encoding=7bit \
 		--smtp-server="$(pwd)/fake.sendmail" \
 		email-using-8bit \
@@ -1364,11 +1504,10 @@ test_expect_success $PREREQ 'sendemail.t
 	test -z "$(ls msgtxt*)"
 '
 
-test_expect_success $PREREQ '--transfer-encoding overrides sendemail.transferEncoding' '
+test_expect_success $PREREQ 'sendemail.transferEncoding via config' '
 	clean_fake_sendmail &&
-	git config sendemail.transferEncoding 8bit &&
-	test_must_fail git send-email \
-		--transfer-encoding=7bit \
+	test_must_fail git -c sendemail.transferEncoding=7bit \
+		send-email \
 		--smtp-server="$(pwd)/fake.sendmail" \
 		email-using-8bit \
 		2>errors >out &&
@@ -1376,16 +1515,15 @@ test_expect_success $PREREQ '--transfer-
 	test -z "$(ls msgtxt*)"
 '
 
-test_expect_success $PREREQ 'sendemail.transferencoding=8bit' '
+test_expect_success $PREREQ 'sendemail.transferEncoding via cli' '
 	clean_fake_sendmail &&
-	git send-email \
-		--transfer-encoding=8bit \
+	test_must_fail git send-email \
+		--transfer-encoding=7bit \
 		--smtp-server="$(pwd)/fake.sendmail" \
 		email-using-8bit \
 		2>errors >out &&
-	sed '1,/^$/d' msgtxt1 >actual &&
-	sed '1,/^$/d' email-using-8bit >expected &&
-	test_cmp expected actual
+	grep "cannot send message as 7bit" errors &&
+	test -z "$(ls msgtxt*)"
 '
 
 test_expect_success $PREREQ 'setup expect' '
@@ -1702,6 +1840,15 @@ test_expect_success '--dump-aliases must
 	test_must_fail git send-email --dump-aliases --to=janice@example.com -1 refs/heads/accounting
 '
 
+test_expect_success $PREREQ 'aliases and sendemail.identity' '
+	test_must_fail git \
+		-c sendemail.identity=cloud \
+		-c sendemail.aliasesfile=default-aliases \
+		-c sendemail.cloud.aliasesfile=cloud-aliases \
+		send-email -1 2>stderr &&
+	test_i18ngrep "cloud-aliases" stderr
+'
+
 test_sendmail_aliases () {
 	msg="$1" && shift &&
 	expect="$@" &&
@@ -1919,7 +2066,7 @@ test_expect_success $PREREQ 'leading and
 	TO1=$(echo "QTo 1 <to1@example.com>" | q_to_tab) &&
 	TO2=$(echo "QZto2" | qz_to_tab_space) &&
 	CC1=$(echo "cc1" | append_cr) &&
-	BCC1=$(echo "Q bcc1@example.com Q" | q_to_nul) &&
+	BCC1=$(echo " bcc1@example.com Q" | q_to_nul) &&
 	git send-email \
 	--dry-run \
 	--from="	Example <from@example.com>" \
@@ -1966,11 +2113,11 @@ test_expect_success $PREREQ 'invoke hook
 
 		# Verify error message when a patch is rejected by the hook
 		sed -e "s/add master/x/" ../0001-add-master.patch >../another.patch &&
-		git send-email \
+		test_must_fail git send-email \
 			--from="Example <nobody@example.com>" \
 			--to=nobody@example.com \
 			--smtp-server="$(pwd)/../fake.sendmail" \
-			../another.patch 2>err
+			../another.patch 2>err &&
 		test_i18ngrep "rejected by sendemail-validate hook" err
 	)
 '
diff -pruN 1.2.1+git2.18.0-1/git/t/t9010-svn-fe.sh 1.2.3+git2.25.1-1/git/t/t9010-svn-fe.sh
--- 1.2.1+git2.18.0-1/git/t/t9010-svn-fe.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t9010-svn-fe.sh	2020-02-17 04:47:35.000000000 +0000
@@ -53,8 +53,6 @@ text_no_props () {
 	printf "%s\n" "$text"
 }
 
->empty
-
 test_expect_success 'empty dump' '
 	reinit_git &&
 	echo "SVN-fs-dump-format-version: 2" >input &&
@@ -208,7 +206,7 @@ test_expect_failure 'timestamp and empty
 	test_cmp expect.date actual.date &&
 	test_cmp expect.files actual.files &&
 	git checkout HEAD empty-file &&
-	test_cmp empty file
+	test_must_be_empty file
 '
 
 test_expect_success 'directory with files' '
diff -pruN 1.2.1+git2.18.0-1/git/t/t9011-svn-da.sh 1.2.3+git2.25.1-1/git/t/t9011-svn-da.sh
--- 1.2.1+git2.18.0-1/git/t/t9011-svn-da.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t9011-svn-da.sh	2020-02-17 04:47:35.000000000 +0000
@@ -18,7 +18,7 @@ test_expect_success 'reject empty delta'
 test_expect_success 'delta can empty file' '
 	printf "SVNQ" | q_to_nul >clear.delta &&
 	test-svn-fe -d preimage clear.delta 4 >actual &&
-	test_cmp empty actual
+	test_must_be_empty actual
 '
 
 test_expect_success 'reject svndiff2' '
@@ -29,7 +29,7 @@ test_expect_success 'reject svndiff2' '
 test_expect_success 'one-window empty delta' '
 	printf "SVNQ%s" "QQQQQ" | q_to_nul >clear.onewindow &&
 	test-svn-fe -d preimage clear.onewindow 9 >actual &&
-	test_cmp empty actual
+	test_must_be_empty actual
 '
 
 test_expect_success 'reject incomplete window header' '
@@ -50,7 +50,7 @@ test_expect_success 'two-window empty de
 	printf "SVNQ%s%s" "QQQQQ" "QQQQQ" | q_to_nul >clear.twowindow &&
 	test-svn-fe -d preimage clear.twowindow 14 >actual &&
 	test_must_fail test-svn-fe -d preimage clear.twowindow 13 &&
-	test_cmp empty actual
+	test_must_be_empty actual
 '
 
 test_expect_success 'noisy zeroes' '
@@ -60,7 +60,7 @@ test_expect_success 'noisy zeroes' '
 		q_to_nul >clear.noisy &&
 	len=$(wc -c <clear.noisy) &&
 	test-svn-fe -d preimage clear.noisy $len &&
-	test_cmp empty actual
+	test_must_be_empty actual
 '
 
 test_expect_success 'reject variable-length int in magic' '
@@ -83,7 +83,7 @@ test_expect_success 'reject truncated in
 test_expect_success 'nonempty (but unused) preimage view' '
 	printf "SVNQ%b" "Q\003QQQ" | q_to_nul >clear.readpreimage &&
 	test-svn-fe -d preimage clear.readpreimage 9 >actual &&
-	test_cmp empty actual
+	test_must_be_empty actual
 '
 
 test_expect_success 'preimage view: right endpoint cannot backtrack' '
@@ -99,7 +99,7 @@ test_expect_success 'preimage view: left
 		q_to_nul >clear.shrinkbacktrack &&
 	test-svn-fe -d preimage clear.preshrink 14 >actual &&
 	test_must_fail test-svn-fe -d preimage clear.shrinkbacktrack 14 &&
-	test_cmp empty actual
+	test_must_be_empty actual
 '
 
 test_expect_success 'preimage view: offsets compared by value' '
@@ -109,7 +109,7 @@ test_expect_success 'preimage view: offs
 		q_to_nul >clear.noisyadvance &&
 	test_must_fail test-svn-fe -d preimage clear.noisybacktrack 15 &&
 	test-svn-fe -d preimage clear.noisyadvance 15 &&
-	test_cmp empty actual
+	test_must_be_empty actual
 '
 
 test_expect_success 'preimage view: reject truncated preimage' '
diff -pruN 1.2.1+git2.18.0-1/git/t/t9100-git-svn-basic.sh 1.2.3+git2.25.1-1/git/t/t9100-git-svn-basic.sh
--- 1.2.1+git2.18.0-1/git/t/t9100-git-svn-basic.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t9100-git-svn-basic.sh	2020-02-17 04:47:35.000000000 +0000
@@ -31,7 +31,7 @@ test_expect_success \
 	(
 		cd import &&
 		echo foo >foo &&
-		ln -s foo foo.link
+		ln -s foo foo.link &&
 		mkdir -p dir/a/b/c/d/e &&
 		echo "deep dir" >dir/a/b/c/d/e/file &&
 		mkdir bar &&
@@ -221,7 +221,7 @@ tree d667270a1f7b109f5eb3aaea21ede14b56b
 tree 8f51f74cf0163afc9ad68a4b1537288c4558b5a4
 EOF
 
-test_expect_success POSIXPERM,SYMLINKS "$name" "test_cmp a expected"
+test_expect_success POSIXPERM,SYMLINKS "$name" "test_cmp expected a"
 
 test_expect_success 'exit if remote refs are ambigious' '
         git config --add svn-remote.svn.fetch \
diff -pruN 1.2.1+git2.18.0-1/git/t/t9101-git-svn-props.sh 1.2.3+git2.25.1-1/git/t/t9101-git-svn-props.sh
--- 1.2.1+git2.18.0-1/git/t/t9101-git-svn-props.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t9101-git-svn-props.sh	2020-02-17 04:47:35.000000000 +0000
@@ -149,7 +149,7 @@ test_expect_success 'test show-ignore' "
 		svn_cmd up &&
 		svn_cmd propset -R svn:ignore '
 no-such-file*
-' .
+' . &&
 		svn_cmd commit -m 'propset svn:ignore'
 	) &&
 	git svn show-ignore > show-ignore.got &&
@@ -174,7 +174,8 @@ test_expect_success 'test create-ignore'
 	cmp ./deeply/.gitignore create-ignore.expect &&
 	cmp ./deeply/nested/.gitignore create-ignore.expect &&
 	cmp ./deeply/nested/directory/.gitignore create-ignore.expect &&
-	git ls-files -s | grep gitignore | cmp - create-ignore-index.expect
+	git ls-files -s >ls_files_result &&
+	grep gitignore ls_files_result | cmp - create-ignore-index.expect
 	"
 
 cat >prop.expect <<\EOF
@@ -189,17 +190,21 @@ EOF
 # This test can be improved: since all the svn:ignore contain the same
 # pattern, it can pass even though the propget did not execute on the
 # right directory.
-test_expect_success 'test propget' "
-	git svn propget svn:ignore . | cmp - prop.expect &&
+test_expect_success 'test propget' '
+	test_propget () {
+		git svn propget $1 $2 >actual &&
+		cmp $3 actual
+	} &&
+	test_propget svn:ignore . prop.expect &&
 	cd deeply &&
-	git svn propget svn:ignore . | cmp - ../prop.expect &&
-	git svn propget svn:entry:committed-rev nested/directory/.keep \
-	  | cmp - ../prop2.expect &&
-	git svn propget svn:ignore .. | cmp - ../prop.expect &&
-	git svn propget svn:ignore nested/ | cmp - ../prop.expect &&
-	git svn propget svn:ignore ./nested | cmp - ../prop.expect &&
-	git svn propget svn:ignore .././deeply/nested | cmp - ../prop.expect
-	"
+	test_propget svn:ignore . ../prop.expect &&
+	test_propget svn:entry:committed-rev nested/directory/.keep \
+		../prop2.expect &&
+	test_propget svn:ignore .. ../prop.expect &&
+	test_propget svn:ignore nested/ ../prop.expect &&
+	test_propget svn:ignore ./nested ../prop.expect &&
+	test_propget svn:ignore .././deeply/nested ../prop.expect
+	'
 
 cat >prop.expect <<\EOF
 Properties on '.':
@@ -218,8 +223,11 @@ Properties on 'nested/directory/.keep':
 EOF
 
 test_expect_success 'test proplist' "
-	git svn proplist . | cmp - prop.expect &&
-	git svn proplist nested/directory/.keep | cmp - prop2.expect
+	git svn proplist . >actual &&
+	cmp prop.expect actual &&
+
+	git svn proplist nested/directory/.keep >actual &&
+	cmp prop2.expect actual
 	"
 
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t9104-git-svn-follow-parent.sh 1.2.3+git2.25.1-1/git/t/t9104-git-svn-follow-parent.sh
--- 1.2.1+git2.18.0-1/git/t/t9104-git-svn-follow-parent.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t9104-git-svn-follow-parent.sh	2020-02-17 04:47:35.000000000 +0000
@@ -215,7 +215,9 @@ test_expect_success "multi-fetch continu
 	"
 
 test_expect_success "multi-fetch works off a 'clean' repository" '
-	rm -rf "$GIT_DIR/svn" "$GIT_DIR/refs/remotes" &&
+	rm -rf "$GIT_DIR/svn" &&
+	git for-each-ref --format="option no-deref%0adelete %(refname)" refs/remotes |
+	git update-ref --stdin &&
 	git reflog expire --all --expire=all &&
 	mkdir "$GIT_DIR/svn" &&
 	git svn multi-fetch
diff -pruN 1.2.1+git2.18.0-1/git/t/t9115-git-svn-dcommit-funky-renames.sh 1.2.3+git2.25.1-1/git/t/t9115-git-svn-dcommit-funky-renames.sh
--- 1.2.1+git2.18.0-1/git/t/t9115-git-svn-dcommit-funky-renames.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t9115-git-svn-dcommit-funky-renames.sh	2020-02-17 04:47:35.000000000 +0000
@@ -120,6 +120,4 @@ test_expect_success !MINGW,!UTF8_NFD_TO_
 	git svn dcommit
 '
 
-stop_httpd
-
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t9118-git-svn-funky-branch-names.sh 1.2.3+git2.25.1-1/git/t/t9118-git-svn-funky-branch-names.sh
--- 1.2.1+git2.18.0-1/git/t/t9118-git-svn-funky-branch-names.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t9118-git-svn-funky-branch-names.sh	2020-02-17 04:47:35.000000000 +0000
@@ -87,6 +87,4 @@ test_expect_success 'test dcommit to tra
 	)
 	'
 
-stop_httpd
-
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t9119-git-svn-info.sh 1.2.3+git2.25.1-1/git/t/t9119-git-svn-info.sh
--- 1.2.1+git2.18.0-1/git/t/t9119-git-svn-info.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t9119-git-svn-info.sh	2020-02-17 04:47:35.000000000 +0000
@@ -22,8 +22,8 @@ esac
 # same value as "svn info" (i.e. the commit timestamp that touched the
 # path most recently); do not expect that field to match.
 test_cmp_info () {
-	sed -e '/^Text Last Updated:/d' "$1" >tmp.expect
-	sed -e '/^Text Last Updated:/d' "$2" >tmp.actual
+	sed -e '/^Text Last Updated:/d' "$1" >tmp.expect &&
+	sed -e '/^Text Last Updated:/d' "$2" >tmp.actual &&
 	test_cmp tmp.expect tmp.actual &&
 	rm -f tmp.expect tmp.actual
 }
@@ -59,24 +59,24 @@ test_expect_success 'setup repository an
 	'
 
 test_expect_success 'info' "
-	(cd svnwc; svn info) > expected.info &&
-	(cd gitwc; git svn info) > actual.info &&
+	(cd svnwc && svn info) > expected.info &&
+	(cd gitwc && git svn info) > actual.info &&
 	test_cmp_info expected.info actual.info
 	"
 
 test_expect_success 'info --url' '
-	test "$(cd gitwc; git svn info --url)" = "$quoted_svnrepo"
+	test "$(cd gitwc && git svn info --url)" = "$quoted_svnrepo"
 	'
 
 test_expect_success 'info .' "
-	(cd svnwc; svn info .) > expected.info-dot &&
-	(cd gitwc; git svn info .) > actual.info-dot &&
+	(cd svnwc && svn info .) > expected.info-dot &&
+	(cd gitwc && git svn info .) > actual.info-dot &&
 	test_cmp_info expected.info-dot actual.info-dot
 	"
 
 test_expect_success 'info $(pwd)' '
-	(cd svnwc; svn info "$(pwd)") >expected.info-pwd &&
-	(cd gitwc; git svn info "$(pwd)") >actual.info-pwd &&
+	(cd svnwc && svn info "$(pwd)") >expected.info-pwd &&
+	(cd gitwc && git svn info "$(pwd)") >actual.info-pwd &&
 	grep -v ^Path: <expected.info-pwd >expected.info-np &&
 	grep -v ^Path: <actual.info-pwd >actual.info-np &&
 	test_cmp_info expected.info-np actual.info-np &&
@@ -85,8 +85,8 @@ test_expect_success 'info $(pwd)' '
 	'
 
 test_expect_success 'info $(pwd)/../___wc' '
-	(cd svnwc; svn info "$(pwd)/../svnwc") >expected.info-pwd &&
-	(cd gitwc; git svn info "$(pwd)/../gitwc") >actual.info-pwd &&
+	(cd svnwc && svn info "$(pwd)/../svnwc") >expected.info-pwd &&
+	(cd gitwc && git svn info "$(pwd)/../gitwc") >actual.info-pwd &&
 	grep -v ^Path: <expected.info-pwd >expected.info-np &&
 	grep -v ^Path: <actual.info-pwd >actual.info-np &&
 	test_cmp_info expected.info-np actual.info-np &&
@@ -95,8 +95,8 @@ test_expect_success 'info $(pwd)/../___w
 	'
 
 test_expect_success 'info $(pwd)/../___wc//file' '
-	(cd svnwc; svn info "$(pwd)/../svnwc//file") >expected.info-pwd &&
-	(cd gitwc; git svn info "$(pwd)/../gitwc//file") >actual.info-pwd &&
+	(cd svnwc && svn info "$(pwd)/../svnwc//file") >expected.info-pwd &&
+	(cd gitwc && git svn info "$(pwd)/../gitwc//file") >actual.info-pwd &&
 	grep -v ^Path: <expected.info-pwd >expected.info-np &&
 	grep -v ^Path: <actual.info-pwd >actual.info-np &&
 	test_cmp_info expected.info-np actual.info-np &&
@@ -105,56 +105,56 @@ test_expect_success 'info $(pwd)/../___w
 	'
 
 test_expect_success 'info --url .' '
-	test "$(cd gitwc; git svn info --url .)" = "$quoted_svnrepo"
+	test "$(cd gitwc && git svn info --url .)" = "$quoted_svnrepo"
 	'
 
 test_expect_success 'info file' "
-	(cd svnwc; svn info file) > expected.info-file &&
-	(cd gitwc; git svn info file) > actual.info-file &&
+	(cd svnwc && svn info file) > expected.info-file &&
+	(cd gitwc && git svn info file) > actual.info-file &&
 	test_cmp_info expected.info-file actual.info-file
 	"
 
 test_expect_success 'info --url file' '
-	test "$(cd gitwc; git svn info --url file)" = "$quoted_svnrepo/file"
+	test "$(cd gitwc && git svn info --url file)" = "$quoted_svnrepo/file"
 	'
 
 test_expect_success 'info directory' "
-	(cd svnwc; svn info directory) > expected.info-directory &&
-	(cd gitwc; git svn info directory) > actual.info-directory &&
+	(cd svnwc && svn info directory) > expected.info-directory &&
+	(cd gitwc && git svn info directory) > actual.info-directory &&
 	test_cmp_info expected.info-directory actual.info-directory
 	"
 
 test_expect_success 'info inside directory' "
-	(cd svnwc/directory; svn info) > expected.info-inside-directory &&
-	(cd gitwc/directory; git svn info) > actual.info-inside-directory &&
+	(cd svnwc/directory && svn info) > expected.info-inside-directory &&
+	(cd gitwc/directory && git svn info) > actual.info-inside-directory &&
 	test_cmp_info expected.info-inside-directory actual.info-inside-directory
 	"
 
 test_expect_success 'info --url directory' '
-	test "$(cd gitwc; git svn info --url directory)" = "$quoted_svnrepo/directory"
+	test "$(cd gitwc && git svn info --url directory)" = "$quoted_svnrepo/directory"
 	'
 
 test_expect_success 'info symlink-file' "
-	(cd svnwc; svn info symlink-file) > expected.info-symlink-file &&
-	(cd gitwc; git svn info symlink-file) > actual.info-symlink-file &&
+	(cd svnwc && svn info symlink-file) > expected.info-symlink-file &&
+	(cd gitwc && git svn info symlink-file) > actual.info-symlink-file &&
 	test_cmp_info expected.info-symlink-file actual.info-symlink-file
 	"
 
 test_expect_success 'info --url symlink-file' '
-	test "$(cd gitwc; git svn info --url symlink-file)" \
+	test "$(cd gitwc && git svn info --url symlink-file)" \
 	     = "$quoted_svnrepo/symlink-file"
 	'
 
 test_expect_success 'info symlink-directory' "
-	(cd svnwc; svn info symlink-directory) \
+	(cd svnwc && svn info symlink-directory) \
 		> expected.info-symlink-directory &&
-	(cd gitwc; git svn info symlink-directory) \
+	(cd gitwc && git svn info symlink-directory) \
 		> actual.info-symlink-directory &&
 	test_cmp_info expected.info-symlink-directory actual.info-symlink-directory
 	"
 
 test_expect_success 'info --url symlink-directory' '
-	test "$(cd gitwc; git svn info --url symlink-directory)" \
+	test "$(cd gitwc && git svn info --url symlink-directory)" \
 	     = "$quoted_svnrepo/symlink-directory"
 	'
 
@@ -169,13 +169,13 @@ test_expect_success 'info added-file' "
 		cd svnwc &&
 		svn_cmd add added-file > /dev/null
 	) &&
-	(cd svnwc; svn info added-file) > expected.info-added-file &&
-	(cd gitwc; git svn info added-file) > actual.info-added-file &&
+	(cd svnwc && svn info added-file) > expected.info-added-file &&
+	(cd gitwc && git svn info added-file) > actual.info-added-file &&
 	test_cmp_info expected.info-added-file actual.info-added-file
 	"
 
 test_expect_success 'info --url added-file' '
-	test "$(cd gitwc; git svn info --url added-file)" \
+	test "$(cd gitwc && git svn info --url added-file)" \
 	     = "$quoted_svnrepo/added-file"
 	'
 
@@ -190,15 +190,15 @@ test_expect_success 'info added-director
 		cd gitwc &&
 		git add added-directory
 	) &&
-	(cd svnwc; svn info added-directory) \
+	(cd svnwc && svn info added-directory) \
 		> expected.info-added-directory &&
-	(cd gitwc; git svn info added-directory) \
+	(cd gitwc && git svn info added-directory) \
 		> actual.info-added-directory &&
 	test_cmp_info expected.info-added-directory actual.info-added-directory
 	"
 
 test_expect_success 'info --url added-directory' '
-	test "$(cd gitwc; git svn info --url added-directory)" \
+	test "$(cd gitwc && git svn info --url added-directory)" \
 	     = "$quoted_svnrepo/added-directory"
 	'
 
@@ -213,16 +213,16 @@ test_expect_success 'info added-symlink-
 		ln -s added-file added-symlink-file &&
 		svn_cmd add added-symlink-file > /dev/null
 	) &&
-	(cd svnwc; svn info added-symlink-file) \
+	(cd svnwc && svn info added-symlink-file) \
 		> expected.info-added-symlink-file &&
-	(cd gitwc; git svn info added-symlink-file) \
+	(cd gitwc && git svn info added-symlink-file) \
 		> actual.info-added-symlink-file &&
 	test_cmp_info expected.info-added-symlink-file \
 		actual.info-added-symlink-file
 	"
 
 test_expect_success 'info --url added-symlink-file' '
-	test "$(cd gitwc; git svn info --url added-symlink-file)" \
+	test "$(cd gitwc && git svn info --url added-symlink-file)" \
 	     = "$quoted_svnrepo/added-symlink-file"
 	'
 
@@ -237,16 +237,16 @@ test_expect_success 'info added-symlink-
 		ln -s added-directory added-symlink-directory &&
 		svn_cmd add added-symlink-directory > /dev/null
 	) &&
-	(cd svnwc; svn info added-symlink-directory) \
+	(cd svnwc && svn info added-symlink-directory) \
 		> expected.info-added-symlink-directory &&
-	(cd gitwc; git svn info added-symlink-directory) \
+	(cd gitwc && git svn info added-symlink-directory) \
 		> actual.info-added-symlink-directory &&
 	test_cmp_info expected.info-added-symlink-directory \
 		actual.info-added-symlink-directory
 	"
 
 test_expect_success 'info --url added-symlink-directory' '
-	test "$(cd gitwc; git svn info --url added-symlink-directory)" \
+	test "$(cd gitwc && git svn info --url added-symlink-directory)" \
 	     = "$quoted_svnrepo/added-symlink-directory"
 	'
 
@@ -259,13 +259,13 @@ test_expect_success 'info deleted-file'
 		cd svnwc &&
 		svn_cmd rm --force file > /dev/null
 	) &&
-	(cd svnwc; svn info file) >expected.info-deleted-file &&
-	(cd gitwc; git svn info file) >actual.info-deleted-file &&
+	(cd svnwc && svn info file) >expected.info-deleted-file &&
+	(cd gitwc && git svn info file) >actual.info-deleted-file &&
 	test_cmp_info expected.info-deleted-file actual.info-deleted-file
 	"
 
 test_expect_success 'info --url file (deleted)' '
-	test "$(cd gitwc; git svn info --url file)" \
+	test "$(cd gitwc && git svn info --url file)" \
 	     = "$quoted_svnrepo/file"
 	'
 
@@ -278,13 +278,13 @@ test_expect_success 'info deleted-direct
 		cd svnwc &&
 		svn_cmd rm --force directory > /dev/null
 	) &&
-	(cd svnwc; svn info directory) >expected.info-deleted-directory &&
-	(cd gitwc; git svn info directory) >actual.info-deleted-directory &&
+	(cd svnwc && svn info directory) >expected.info-deleted-directory &&
+	(cd gitwc && git svn info directory) >actual.info-deleted-directory &&
 	test_cmp_info expected.info-deleted-directory actual.info-deleted-directory
 	"
 
 test_expect_success 'info --url directory (deleted)' '
-	test "$(cd gitwc; git svn info --url directory)" \
+	test "$(cd gitwc && git svn info --url directory)" \
 	     = "$quoted_svnrepo/directory"
 	'
 
@@ -297,13 +297,13 @@ test_expect_success 'info deleted-symlin
 		cd svnwc &&
 		svn_cmd rm --force symlink-file > /dev/null
 	) &&
-	(cd svnwc; svn info symlink-file) >expected.info-deleted-symlink-file &&
-	(cd gitwc; git svn info symlink-file) >actual.info-deleted-symlink-file &&
+	(cd svnwc && svn info symlink-file) >expected.info-deleted-symlink-file &&
+	(cd gitwc && git svn info symlink-file) >actual.info-deleted-symlink-file &&
 	test_cmp_info expected.info-deleted-symlink-file actual.info-deleted-symlink-file
 	"
 
 test_expect_success 'info --url symlink-file (deleted)' '
-	test "$(cd gitwc; git svn info --url symlink-file)" \
+	test "$(cd gitwc && git svn info --url symlink-file)" \
 	     = "$quoted_svnrepo/symlink-file"
 	'
 
@@ -316,13 +316,13 @@ test_expect_success 'info deleted-symlin
 		cd svnwc &&
 		svn_cmd rm --force symlink-directory > /dev/null
 	) &&
-	(cd svnwc; svn info symlink-directory) >expected.info-deleted-symlink-directory &&
-	(cd gitwc; git svn info symlink-directory) >actual.info-deleted-symlink-directory &&
+	(cd svnwc && svn info symlink-directory) >expected.info-deleted-symlink-directory &&
+	(cd gitwc && git svn info symlink-directory) >actual.info-deleted-symlink-directory &&
 	test_cmp_info expected.info-deleted-symlink-directory actual.info-deleted-symlink-directory
 	"
 
 test_expect_success 'info --url symlink-directory (deleted)' '
-	test "$(cd gitwc; git svn info --url symlink-directory)" \
+	test "$(cd gitwc && git svn info --url symlink-directory)" \
 	     = "$quoted_svnrepo/symlink-directory"
 	'
 
@@ -331,27 +331,27 @@ test_expect_success 'info --url symlink-
 
 test_expect_success 'info unknown-file' "
 	echo two > gitwc/unknown-file &&
-	(cd gitwc; test_must_fail git svn info unknown-file) \
+	(cd gitwc && test_must_fail git svn info unknown-file) \
 		 2> actual.info-unknown-file &&
 	grep unknown-file actual.info-unknown-file
 	"
 
 test_expect_success 'info --url unknown-file' '
 	echo two > gitwc/unknown-file &&
-	(cd gitwc; test_must_fail git svn info --url unknown-file) \
+	(cd gitwc && test_must_fail git svn info --url unknown-file) \
 		 2> actual.info-url-unknown-file &&
 	grep unknown-file actual.info-url-unknown-file
 	'
 
 test_expect_success 'info unknown-directory' "
 	mkdir gitwc/unknown-directory svnwc/unknown-directory &&
-	(cd gitwc; test_must_fail git svn info unknown-directory) \
+	(cd gitwc && test_must_fail git svn info unknown-directory) \
 		 2> actual.info-unknown-directory &&
 	grep unknown-directory actual.info-unknown-directory
 	"
 
 test_expect_success 'info --url unknown-directory' '
-	(cd gitwc; test_must_fail git svn info --url unknown-directory) \
+	(cd gitwc && test_must_fail git svn info --url unknown-directory) \
 		 2> actual.info-url-unknown-directory &&
 	grep unknown-directory actual.info-url-unknown-directory
 	'
@@ -361,13 +361,13 @@ test_expect_success 'info unknown-symlin
 		cd gitwc &&
 		ln -s unknown-file unknown-symlink-file
 	) &&
-	(cd gitwc; test_must_fail git svn info unknown-symlink-file) \
+	(cd gitwc && test_must_fail git svn info unknown-symlink-file) \
 		 2> actual.info-unknown-symlink-file &&
 	grep unknown-symlink-file actual.info-unknown-symlink-file
 	"
 
 test_expect_success 'info --url unknown-symlink-file' '
-	(cd gitwc; test_must_fail git svn info --url unknown-symlink-file) \
+	(cd gitwc && test_must_fail git svn info --url unknown-symlink-file) \
 		 2> actual.info-url-unknown-symlink-file &&
 	grep unknown-symlink-file actual.info-url-unknown-symlink-file
 	'
@@ -377,13 +377,13 @@ test_expect_success 'info unknown-symlin
 		cd gitwc &&
 		ln -s unknown-directory unknown-symlink-directory
 	) &&
-	(cd gitwc; test_must_fail git svn info unknown-symlink-directory) \
+	(cd gitwc && test_must_fail git svn info unknown-symlink-directory) \
 		 2> actual.info-unknown-symlink-directory &&
 	grep unknown-symlink-directory actual.info-unknown-symlink-directory
 	"
 
 test_expect_success 'info --url unknown-symlink-directory' '
-	(cd gitwc; test_must_fail git svn info --url unknown-symlink-directory) \
+	(cd gitwc && test_must_fail git svn info --url unknown-symlink-directory) \
 		 2> actual.info-url-unknown-symlink-directory &&
 	grep unknown-symlink-directory actual.info-url-unknown-symlink-directory
 	'
diff -pruN 1.2.1+git2.18.0-1/git/t/t9120-git-svn-clone-with-percent-escapes.sh 1.2.3+git2.25.1-1/git/t/t9120-git-svn-clone-with-percent-escapes.sh
--- 1.2.1+git2.18.0-1/git/t/t9120-git-svn-clone-with-percent-escapes.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t9120-git-svn-clone-with-percent-escapes.sh	2020-02-17 04:47:35.000000000 +0000
@@ -74,6 +74,4 @@ test_expect_success 'test clone -s with
 	)
 '
 
-stop_httpd
-
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t9122-git-svn-author.sh 1.2.3+git2.25.1-1/git/t/t9122-git-svn-author.sh
--- 1.2.1+git2.18.0-1/git/t/t9122-git-svn-author.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t9122-git-svn-author.sh	2020-02-17 04:47:35.000000000 +0000
@@ -7,8 +7,8 @@ test_expect_success 'setup svn repositor
 	svn_cmd checkout "$svnrepo" work.svn &&
 	(
 		cd work.svn &&
-		echo >file
-		svn_cmd add file
+		echo >file &&
+		svn_cmd add file &&
 		svn_cmd commit -m "first commit" file
 	)
 '
@@ -17,7 +17,7 @@ test_expect_success 'interact with it vi
 	mkdir work.git &&
 	(
 		cd work.git &&
-		git svn init "$svnrepo"
+		git svn init "$svnrepo" &&
 		git svn fetch &&
 
 		echo modification >file &&
diff -pruN 1.2.1+git2.18.0-1/git/t/t9129-git-svn-i18n-commitencoding.sh 1.2.3+git2.25.1-1/git/t/t9129-git-svn-i18n-commitencoding.sh
--- 1.2.1+git2.18.0-1/git/t/t9129-git-svn-i18n-commitencoding.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t9129-git-svn-i18n-commitencoding.sh	2020-02-17 04:47:35.000000000 +0000
@@ -51,7 +51,7 @@ do
 		git add F &&
 		git commit -a -F "$TEST_DIRECTORY"/t3900/$H.txt &&
 		E=$(git cat-file commit HEAD | sed -ne "s/^encoding //p") &&
-		test "z$E" = "z$H"
+		test "z$E" = "z$H" &&
 		compare_git_head_with "$TEST_DIRECTORY"/t3900/$H.txt
 	)
 	'
diff -pruN 1.2.1+git2.18.0-1/git/t/t9130-git-svn-authors-file.sh 1.2.3+git2.25.1-1/git/t/t9130-git-svn-authors-file.sh
--- 1.2.1+git2.18.0-1/git/t/t9130-git-svn-authors-file.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t9130-git-svn-authors-file.sh	2020-02-17 04:47:35.000000000 +0000
@@ -25,7 +25,7 @@ test_expect_success 'start import with i
 
 test_expect_success 'imported 2 revisions successfully' '
 	(
-		cd x
+		cd x &&
 		git rev-list refs/remotes/git-svn >actual &&
 		test_line_count = 2 actual &&
 		git rev-list -1 --pretty=raw refs/remotes/git-svn >actual &&
@@ -42,7 +42,7 @@ EOF
 
 test_expect_success 'continues to import once authors have been added' '
 	(
-		cd x
+		cd x &&
 		git svn fetch --authors-file=../svn-authors &&
 		git rev-list refs/remotes/git-svn >actual &&
 		test_line_count = 4 actual &&
diff -pruN 1.2.1+git2.18.0-1/git/t/t9131-git-svn-empty-symlink.sh 1.2.3+git2.25.1-1/git/t/t9131-git-svn-empty-symlink.sh
--- 1.2.1+git2.18.0-1/git/t/t9131-git-svn-empty-symlink.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t9131-git-svn-empty-symlink.sh	2020-02-17 04:47:35.000000000 +0000
@@ -85,7 +85,7 @@ EOF
 test_expect_success 'clone using git svn' 'git svn clone -r1 "$svnrepo" x'
 test_expect_success 'enable broken symlink workaround' \
   '(cd x && git config svn.brokenSymlinkWorkaround true)'
-test_expect_success '"bar" is an empty file' 'test -f x/bar && ! test -s x/bar'
+test_expect_success '"bar" is an empty file' 'test_must_be_empty x/bar'
 test_expect_success 'get "bar" => symlink fix from svn' \
 		'(cd x && git svn rebase)'
 test_expect_success SYMLINKS '"bar" becomes a symlink' 'test -h x/bar'
@@ -94,14 +94,14 @@ test_expect_success SYMLINKS '"bar" beco
 test_expect_success 'clone using git svn' 'git svn clone -r1 "$svnrepo" y'
 test_expect_success 'disable broken symlink workaround' \
   '(cd y && git config svn.brokenSymlinkWorkaround false)'
-test_expect_success '"bar" is an empty file' 'test -f y/bar && ! test -s y/bar'
+test_expect_success '"bar" is an empty file' 'test_must_be_empty y/bar'
 test_expect_success 'get "bar" => symlink fix from svn' \
 		'(cd y && git svn rebase)'
 test_expect_success '"bar" does not become a symlink' '! test -L y/bar'
 
 # svn.brokenSymlinkWorkaround is unset
 test_expect_success 'clone using git svn' 'git svn clone -r1 "$svnrepo" z'
-test_expect_success '"bar" is an empty file' 'test -f z/bar && ! test -s z/bar'
+test_expect_success '"bar" is an empty file' 'test_must_be_empty z/bar'
 test_expect_success 'get "bar" => symlink fix from svn' \
 		'(cd z && git svn rebase)'
 test_expect_success '"bar" does not become a symlink' '! test -L z/bar'
diff -pruN 1.2.1+git2.18.0-1/git/t/t9133-git-svn-nested-git-repo.sh 1.2.3+git2.25.1-1/git/t/t9133-git-svn-nested-git-repo.sh
--- 1.2.1+git2.18.0-1/git/t/t9133-git-svn-nested-git-repo.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t9133-git-svn-nested-git-repo.sh	2020-02-17 04:47:35.000000000 +0000
@@ -45,7 +45,7 @@ test_expect_success 'update git svn-clon
 		git svn rebase &&
 		echo a > expect &&
 		echo b >> expect &&
-		test_cmp a expect &&
+		test_cmp expect a &&
 		rm expect
 	)
 '
@@ -69,7 +69,7 @@ test_expect_success 'update git svn-clon
 		git svn rebase &&
 		echo a > expect &&
 		echo b >> expect &&
-		test_cmp a expect &&
+		test_cmp expect a &&
 		rm expect
 	)
 '
@@ -93,7 +93,7 @@ test_expect_success 'update git svn-clon
 		echo a > expect &&
 		echo b >> expect &&
 		echo c >> expect &&
-		test_cmp a expect &&
+		test_cmp expect a &&
 		rm expect
 	)
 '
diff -pruN 1.2.1+git2.18.0-1/git/t/t9134-git-svn-ignore-paths.sh 1.2.3+git2.25.1-1/git/t/t9134-git-svn-ignore-paths.sh
--- 1.2.1+git2.18.0-1/git/t/t9134-git-svn-ignore-paths.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t9134-git-svn-ignore-paths.sh	2020-02-17 04:47:35.000000000 +0000
@@ -82,7 +82,7 @@ test_expect_success 'update git svn-clon
 test_expect_success 'SVN-side change inside of ignored www' '
 	(
 		cd s &&
-		echo zaq >> www/test_www.txt
+		echo zaq >> www/test_www.txt &&
 		svn_cmd commit -m "SVN-side change inside of www/test_www.txt" &&
 		svn_cmd up &&
 		svn_cmd log -v | fgrep "SVN-side change inside of www/test_www.txt"
@@ -114,8 +114,8 @@ test_expect_success 'update git svn-clon
 test_expect_success 'SVN-side change in and out of ignored www' '
 	(
 		cd s &&
-		echo cvf >> www/test_www.txt
-		echo ygg >> qqq/test_qqq.txt
+		echo cvf >> www/test_www.txt &&
+		echo ygg >> qqq/test_qqq.txt &&
 		svn_cmd commit -m "SVN-side change in and out of ignored www" &&
 		svn_cmd up &&
 		svn_cmd log -v | fgrep "SVN-side change in and out of ignored www"
diff -pruN 1.2.1+git2.18.0-1/git/t/t9135-git-svn-moved-branch-empty-file.sh 1.2.3+git2.25.1-1/git/t/t9135-git-svn-moved-branch-empty-file.sh
--- 1.2.1+git2.18.0-1/git/t/t9135-git-svn-moved-branch-empty-file.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t9135-git-svn-moved-branch-empty-file.sh	2020-02-17 04:47:35.000000000 +0000
@@ -13,8 +13,7 @@ test_expect_success 'test that b1 exists
 	(
 		cd x &&
 		git reset --hard origin/branch-c &&
-		test -f b1 &&
-		! test -s b1
+		test_must_be_empty b1
 	)
 	'
 
diff -pruN 1.2.1+git2.18.0-1/git/t/t9137-git-svn-dcommit-clobber-series.sh 1.2.3+git2.25.1-1/git/t/t9137-git-svn-dcommit-clobber-series.sh
--- 1.2.1+git2.18.0-1/git/t/t9137-git-svn-dcommit-clobber-series.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t9137-git-svn-dcommit-clobber-series.sh	2020-02-17 04:47:35.000000000 +0000
@@ -7,7 +7,7 @@ test_description='git svn dcommit clobbe
 test_expect_success 'initialize repo' '
 	mkdir import &&
 	(cd import &&
-	awk "BEGIN { for (i = 1; i < 64; i++) { print i } }" > file
+	awk "BEGIN { for (i = 1; i < 64; i++) { print i } }" > file &&
 	svn_cmd import -m "initial" . "$svnrepo"
 	) &&
 	git svn init "$svnrepo" &&
diff -pruN 1.2.1+git2.18.0-1/git/t/t9138-git-svn-authors-prog.sh 1.2.3+git2.25.1-1/git/t/t9138-git-svn-authors-prog.sh
--- 1.2.1+git2.18.0-1/git/t/t9138-git-svn-authors-prog.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t9138-git-svn-authors-prog.sh	2020-02-17 04:47:35.000000000 +0000
@@ -38,7 +38,7 @@ test_expect_success 'import authors with
 
 test_expect_success 'imported 6 revisions successfully' '
 	(
-		cd x
+		cd x &&
 		git rev-list refs/remotes/git-svn >actual &&
 		test_line_count = 6 actual
 	)
@@ -46,7 +46,7 @@ test_expect_success 'imported 6 revision
 
 test_expect_success 'authors-prog ran correctly' '
 	(
-		cd x
+		cd x &&
 		git rev-list -1 --pretty=raw refs/remotes/git-svn~1 >actual &&
 		grep "^author ee-foo <ee-foo@example\.com> " actual &&
 		git rev-list -1 --pretty=raw refs/remotes/git-svn~2 >actual &&
@@ -62,7 +62,7 @@ test_expect_success 'authors-prog ran co
 
 test_expect_success 'authors-file overrode authors-prog' '
 	(
-		cd x
+		cd x &&
 		git rev-list -1 --pretty=raw refs/remotes/git-svn >actual &&
 		grep "^author FFFFFFF FFFFFFF <fFf@other\.example\.com> " actual
 	)
diff -pruN 1.2.1+git2.18.0-1/git/t/t9142-git-svn-shallow-clone.sh 1.2.3+git2.25.1-1/git/t/t9142-git-svn-shallow-clone.sh
--- 1.2.1+git2.18.0-1/git/t/t9142-git-svn-shallow-clone.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t9142-git-svn-shallow-clone.sh	2020-02-17 04:47:35.000000000 +0000
@@ -26,6 +26,4 @@ test_expect_success 'clone trunk with "-
 	( cd g && git rev-parse --symbolic --verify HEAD )
 '
 
-stop_httpd
-
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t9146-git-svn-empty-dirs.sh 1.2.3+git2.25.1-1/git/t/t9146-git-svn-empty-dirs.sh
--- 1.2.1+git2.18.0-1/git/t/t9146-git-svn-empty-dirs.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t9146-git-svn-empty-dirs.sh	2020-02-17 04:47:35.000000000 +0000
@@ -21,7 +21,7 @@ test_expect_success 'empty directories e
 		do
 			if ! test -d "$i"
 			then
-				echo >&2 "$i does not exist"
+				echo >&2 "$i does not exist" &&
 				exit 1
 			fi
 		done
@@ -38,7 +38,7 @@ test_expect_success 'option automkdirs s
 		do
 			if test -d "$i"
 			then
-				echo >&2 "$i exists"
+				echo >&2 "$i exists" &&
 				exit 1
 			fi
 		done
@@ -63,7 +63,7 @@ test_expect_success 'git svn mkdirs recr
 		do
 			if ! test -d "$i"
 			then
-				echo >&2 "$i does not exist"
+				echo >&2 "$i does not exist" &&
 				exit 1
 			fi
 		done
@@ -79,21 +79,21 @@ test_expect_success 'git svn mkdirs -r w
 		do
 			if ! test -d "$i"
 			then
-				echo >&2 "$i does not exist"
+				echo >&2 "$i does not exist" &&
 				exit 1
 			fi
-		done
+		done &&
 
 		if test -d "! !"
 		then
-			echo >&2 "$i should not exist"
+			echo >&2 "$i should not exist" &&
 			exit 1
-		fi
+		fi &&
 
 		git svn mkdirs -r8 &&
 		if ! test -d "! !"
 		then
-			echo >&2 "$i not exist"
+			echo >&2 "$i not exist" &&
 			exit 1
 		fi
 	)
@@ -115,7 +115,7 @@ test_expect_success 'empty directories i
 		do
 			if ! test -d "$i"
 			then
-				echo >&2 "$i does not exist"
+				echo >&2 "$i does not exist" &&
 				exit 1
 			fi
 		done
@@ -148,7 +148,7 @@ test_expect_success 'git svn gc-ed files
 			do
 				if ! test -d "$i"
 				then
-					echo >&2 "$i does not exist"
+					echo >&2 "$i does not exist" &&
 					exit 1
 				fi
 			done
diff -pruN 1.2.1+git2.18.0-1/git/t/t9147-git-svn-include-paths.sh 1.2.3+git2.25.1-1/git/t/t9147-git-svn-include-paths.sh
--- 1.2.1+git2.18.0-1/git/t/t9147-git-svn-include-paths.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t9147-git-svn-include-paths.sh	2020-02-17 04:47:35.000000000 +0000
@@ -84,7 +84,7 @@ test_expect_success 'update git svn-clon
 test_expect_success 'SVN-side change inside of ignored www' '
 	(
 		cd s &&
-		echo zaq >> www/test_www.txt
+		echo zaq >> www/test_www.txt &&
 		svn_cmd commit -m "SVN-side change inside of www/test_www.txt" &&
 		svn_cmd up &&
 		svn_cmd log -v | fgrep "SVN-side change inside of www/test_www.txt"
@@ -116,8 +116,8 @@ test_expect_success 'update git svn-clon
 test_expect_success 'SVN-side change in and out of included qqq' '
 	(
 		cd s &&
-		echo cvf >> www/test_www.txt
-		echo ygg >> qqq/test_qqq.txt
+		echo cvf >> www/test_www.txt &&
+		echo ygg >> qqq/test_qqq.txt &&
 		svn_cmd commit -m "SVN-side change in and out of ignored www" &&
 		svn_cmd up &&
 		svn_cmd log -v | fgrep "SVN-side change in and out of ignored www"
diff -pruN 1.2.1+git2.18.0-1/git/t/t9152-svn-empty-dirs-after-gc.sh 1.2.3+git2.25.1-1/git/t/t9152-svn-empty-dirs-after-gc.sh
--- 1.2.1+git2.18.0-1/git/t/t9152-svn-empty-dirs-after-gc.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t9152-svn-empty-dirs-after-gc.sh	2020-02-17 04:47:35.000000000 +0000
@@ -30,7 +30,7 @@ test_expect_success 'git svn mkdirs recr
 		do
 			if ! test -d "$i"
 			then
-				echo >&2 "$i does not exist"
+				echo >&2 "$i does not exist" &&
 				exit 1
 			fi
 		done
diff -pruN 1.2.1+git2.18.0-1/git/t/t9164-git-svn-dcommit-concurrent.sh 1.2.3+git2.25.1-1/git/t/t9164-git-svn-dcommit-concurrent.sh
--- 1.2.1+git2.18.0-1/git/t/t9164-git-svn-dcommit-concurrent.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t9164-git-svn-dcommit-concurrent.sh	2020-02-17 04:47:35.000000000 +0000
@@ -12,7 +12,7 @@ test_expect_success 'setup svn repositor
 	svn_cmd checkout "$svnrepo" work.svn &&
 	(
 		cd work.svn &&
-		echo >file && echo > auto_updated_file
+		echo >file && echo > auto_updated_file &&
 		svn_cmd add file auto_updated_file &&
 		svn_cmd commit -m "initial commit"
 	) &&
diff -pruN 1.2.1+git2.18.0-1/git/t/t9165-git-svn-fetch-merge-branch-of-branch.sh 1.2.3+git2.25.1-1/git/t/t9165-git-svn-fetch-merge-branch-of-branch.sh
--- 1.2.1+git2.18.0-1/git/t/t9165-git-svn-fetch-merge-branch-of-branch.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t9165-git-svn-fetch-merge-branch-of-branch.sh	2020-02-17 04:47:35.000000000 +0000
@@ -39,7 +39,7 @@ test_expect_success 'initialize source s
 		svn_cmd commit -m trunk &&
 		svn_cmd switch "$svnrepo"/branches/branch2 &&
 		svn_cmd merge "$svnrepo"/trunk &&
-		svn_cmd commit -m "merge trunk"
+		svn_cmd commit -m "merge trunk" &&
 		svn_cmd switch "$svnrepo"/trunk &&
 		svn_cmd merge --reintegrate "$svnrepo"/branches/branch2 &&
 		svn_cmd commit -m "merge branch2"
diff -pruN 1.2.1+git2.18.0-1/git/t/t9200-git-cvsexportcommit.sh 1.2.3+git2.25.1-1/git/t/t9200-git-cvsexportcommit.sh
--- 1.2.1+git2.18.0-1/git/t/t9200-git-cvsexportcommit.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t9200-git-cvsexportcommit.sh	2020-02-17 04:47:35.000000000 +0000
@@ -43,11 +43,11 @@ check_entries () {
 	sed -ne '/^\//p' "$1/CVS/Entries" | sort | cut -d/ -f2,3,5 >actual
 	if test -z "$2"
 	then
-		>expected
+		test_must_be_empty actual
 	else
 		printf '%s\n' "$2" | tr '|' '\012' >expected
+		test_cmp expected actual
 	fi
-	test_cmp expected actual
 }
 
 test_expect_success \
@@ -187,7 +187,7 @@ test_expect_success \
       git commit -a -m "Update with spaces" &&
       id=$(git rev-list --max-count=1 HEAD) &&
       (cd "$CVSWORK" &&
-      git cvsexportcommit -c $id
+      git cvsexportcommit -c $id &&
       check_entries "G g" "with spaces.png/1.2/-kb|with spaces.txt/1.2/"
       )'
 
@@ -245,7 +245,7 @@ test_expect_success FILEMODE \
       git add G/off &&
       git commit -a -m "Execute test" &&
       (cd "$CVSWORK" &&
-      git cvsexportcommit -c HEAD
+      git cvsexportcommit -c HEAD &&
       test -x G/on &&
       ! test -x G/off
       )'
@@ -303,7 +303,7 @@ test_expect_success 're-commit a removed
     git add attic_gremlin &&
     git commit -m "Added attic_gremlin" &&
 	git cvsexportcommit -w "$CVSWORK" -c HEAD &&
-    (cd "$CVSWORK"; cvs -Q update -d) &&
+    (cd "$CVSWORK" && cvs -Q update -d) &&
     test -f "$CVSWORK/attic_gremlin"
 '
 
diff -pruN 1.2.1+git2.18.0-1/git/t/t9300-fast-import.sh 1.2.3+git2.25.1-1/git/t/t9300-fast-import.sh
--- 1.2.1+git2.18.0-1/git/t/t9300-fast-import.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t9300-fast-import.sh	2020-02-17 04:47:35.000000000 +0000
@@ -85,6 +85,36 @@ test_expect_success 'A: create pack from
 	An annotated tag that annotates a blob.
 	EOF
 
+	tag to-be-deleted
+	from :3
+	data <<EOF
+	Another annotated tag that annotates a blob.
+	EOF
+
+	reset refs/tags/to-be-deleted
+	from 0000000000000000000000000000000000000000
+
+	tag nested
+	mark :6
+	from :4
+	data <<EOF
+	Tag of our lovely commit
+	EOF
+
+	reset refs/tags/nested
+	from 0000000000000000000000000000000000000000
+
+	tag nested
+	mark :7
+	from :6
+	data <<EOF
+	Tag of tag of our lovely commit
+	EOF
+
+	alias
+	mark :8
+	to :5
+
 	INPUT_END
 	git fast-import --export-marks=marks.out <input &&
 	git whatchanged master
@@ -157,12 +187,19 @@ test_expect_success 'A: verify tag/serie
 	test_cmp expect actual
 '
 
+test_expect_success 'A: verify tag deletion is successful' '
+	test_must_fail git rev-parse --verify refs/tags/to-be-deleted
+'
+
 test_expect_success 'A: verify marks output' '
 	cat >expect <<-EOF &&
 	:2 $(git rev-parse --verify master:file2)
 	:3 $(git rev-parse --verify master:file3)
 	:4 $(git rev-parse --verify master:file4)
 	:5 $(git rev-parse --verify master^0)
+	:6 $(git cat-file tag nested | grep object | cut -d" " -f 2)
+	:7 $(git rev-parse --verify nested)
+	:8 $(git rev-parse --verify master^0)
 	EOF
 	test_cmp expect marks.out
 '
@@ -1558,7 +1595,7 @@ test_expect_success 'O: blank lines not
 	INPUT_END
 
 	git fast-import <input &&
-	test 8 = $(find .git/objects/pack -type f | wc -l) &&
+	test 8 = $(find .git/objects/pack -type f | grep -v multi-pack-index | wc -l) &&
 	test $(git rev-parse refs/tags/O3-2nd) = $(git rev-parse O3^) &&
 	git log --reverse --pretty=oneline O3 | sed s/^.*z// >actual &&
 	test_cmp expect actual
@@ -2106,12 +2143,27 @@ test_expect_success 'R: abort on receivi
 	test_must_fail git fast-import <input
 '
 
+test_expect_success 'R: import-marks features forbidden by default' '
+	>git.marks &&
+	echo "feature import-marks=git.marks" >input &&
+	test_must_fail git fast-import <input &&
+	echo "feature import-marks-if-exists=git.marks" >input &&
+	test_must_fail git fast-import <input
+'
+
 test_expect_success 'R: only one import-marks feature allowed per stream' '
+	>git.marks &&
+	>git2.marks &&
 	cat >input <<-EOF &&
 	feature import-marks=git.marks
 	feature import-marks=git2.marks
 	EOF
 
+	test_must_fail git fast-import --allow-unsafe-features <input
+'
+
+test_expect_success 'R: export-marks feature forbidden by default' '
+	echo "feature export-marks=git.marks" >input &&
 	test_must_fail git fast-import <input
 '
 
@@ -2125,19 +2177,29 @@ test_expect_success 'R: export-marks fea
 
 	EOF
 
-	cat input | git fast-import &&
+	git fast-import --allow-unsafe-features <input &&
 	grep :1 git.marks
 '
 
 test_expect_success 'R: export-marks options can be overridden by commandline options' '
-	cat input | git fast-import --export-marks=other.marks &&
-	grep :1 other.marks
+	cat >input <<-\EOF &&
+	feature export-marks=feature-sub/git.marks
+	blob
+	mark :1
+	data 3
+	hi
+
+	EOF
+	git fast-import --allow-unsafe-features \
+			--export-marks=cmdline-sub/other.marks <input &&
+	grep :1 cmdline-sub/other.marks &&
+	test_path_is_missing feature-sub
 '
 
 test_expect_success 'R: catch typo in marks file name' '
 	test_must_fail git fast-import --import-marks=nonexistent.marks </dev/null &&
 	echo "feature import-marks=nonexistent.marks" |
-	test_must_fail git fast-import
+	test_must_fail git fast-import --allow-unsafe-features
 '
 
 test_expect_success 'R: import and output marks can be the same file' '
@@ -2191,12 +2253,12 @@ test_expect_success 'R: --import-marks-i
 
 test_expect_success 'R: feature import-marks-if-exists' '
 	rm -f io.marks &&
-	>expect &&
 
-	git fast-import --export-marks=io.marks <<-\EOF &&
+	git fast-import --export-marks=io.marks \
+			--allow-unsafe-features <<-\EOF &&
 	feature import-marks-if-exists=not_io.marks
 	EOF
-	test_cmp expect io.marks &&
+	test_must_be_empty io.marks &&
 
 	blob=$(echo hi | git hash-object --stdin) &&
 
@@ -2204,7 +2266,8 @@ test_expect_success 'R: feature import-m
 	echo ":1 $blob" >expect &&
 	echo ":2 $blob" >>expect &&
 
-	git fast-import --export-marks=io.marks <<-\EOF &&
+	git fast-import --export-marks=io.marks \
+			--allow-unsafe-features <<-\EOF &&
 	feature import-marks-if-exists=io.marks
 	blob
 	mark :2
@@ -2217,7 +2280,8 @@ test_expect_success 'R: feature import-m
 	echo ":3 $blob" >>expect &&
 
 	git fast-import --import-marks=io.marks \
-			--export-marks=io.marks <<-\EOF &&
+			--export-marks=io.marks \
+			--allow-unsafe-features <<-\EOF &&
 	feature import-marks-if-exists=not_io.marks
 	blob
 	mark :3
@@ -2227,13 +2291,12 @@ test_expect_success 'R: feature import-m
 	EOF
 	test_cmp expect io.marks &&
 
-	>expect &&
-
 	git fast-import --import-marks-if-exists=not_io.marks \
-			--export-marks=io.marks <<-\EOF &&
+			--export-marks=io.marks \
+			--allow-unsafe-features <<-\EOF &&
 	feature import-marks-if-exists=io.marks
 	EOF
-	test_cmp expect io.marks
+	test_must_be_empty io.marks
 '
 
 test_expect_success 'R: import to output marks works without any content' '
@@ -2242,7 +2305,7 @@ test_expect_success 'R: import to output
 	feature export-marks=marks.new
 	EOF
 
-	cat input | git fast-import &&
+	git fast-import --allow-unsafe-features <input &&
 	test_cmp marks.out marks.new
 '
 
@@ -2252,7 +2315,7 @@ test_expect_success 'R: import marks pre
 	feature export-marks=marks.new
 	EOF
 
-	cat input | git fast-import --import-marks=marks.out &&
+	git fast-import --import-marks=marks.out --allow-unsafe-features <input &&
 	test_cmp marks.out marks.new
 '
 
@@ -2265,7 +2328,8 @@ test_expect_success 'R: multiple --impor
 
 	head -n2 marks.out > one.marks &&
 	tail -n +3 marks.out > two.marks &&
-	git fast-import --import-marks=one.marks --import-marks=two.marks <input &&
+	git fast-import --import-marks=one.marks --import-marks=two.marks \
+		--allow-unsafe-features <input &&
 	test_cmp marks.out combined.marks
 '
 
@@ -2278,7 +2342,7 @@ test_expect_success 'R: feature relative
 
 	mkdir -p .git/info/fast-import/ &&
 	cp marks.new .git/info/fast-import/relative.in &&
-	git fast-import <input &&
+	git fast-import --allow-unsafe-features <input &&
 	test_cmp marks.new .git/info/fast-import/relative.out
 '
 
@@ -2290,7 +2354,7 @@ test_expect_success 'R: feature no-relat
 	feature export-marks=non-relative.out
 	EOF
 
-	git fast-import <input &&
+	git fast-import --allow-unsafe-features <input &&
 	test_cmp marks.new non-relative.out
 '
 
@@ -2443,9 +2507,6 @@ test_expect_success PIPE 'R: copy using
 	echo $expect_id blob $expect_len >expect.response &&
 
 	rm -f blobs &&
-	cat >frontend <<-\FRONTEND_END &&
-	#!/bin/sh
-	FRONTEND_END
 
 	mkfifo blobs &&
 	(
@@ -2560,7 +2621,7 @@ test_expect_success 'R: quiet option res
 
 	EOF
 
-	cat input | git fast-import 2> output &&
+	git fast-import 2>output <input &&
 	test_must_be_empty output
 '
 
@@ -2784,7 +2845,6 @@ test_expect_success 'S: filemodify with
 	COMMIT
 	M 100644 :403x hello.c
 	EOF
-	cat err &&
 	test_i18ngrep "space after mark" err
 '
 
@@ -2801,7 +2861,6 @@ test_expect_success 'S: filemodify with
 	inline
 	BLOB
 	EOF
-	cat err &&
 	test_i18ngrep "nvalid dataref" err
 '
 
@@ -2815,7 +2874,6 @@ test_expect_success 'S: filemodify with
 	COMMIT
 	M 100644 ${sha1}x hello.c
 	EOF
-	cat err &&
 	test_i18ngrep "space after SHA1" err
 '
 
@@ -2831,7 +2889,6 @@ test_expect_success 'S: notemodify with
 	COMMIT
 	N :202x :302
 	EOF
-	cat err &&
 	test_i18ngrep "space after mark" err
 '
 
@@ -2847,7 +2904,6 @@ test_expect_success 'S: notemodify with
 	note blob
 	BLOB
 	EOF
-	cat err &&
 	test_i18ngrep "nvalid dataref" err
 '
 
@@ -2861,7 +2917,6 @@ test_expect_success 'S: notemodify with
 	COMMIT
 	N ${sha1}x :302
 	EOF
-	cat err &&
 	test_i18ngrep "space after SHA1" err
 '
 
@@ -2877,7 +2932,6 @@ test_expect_success 'S: notemodify with
 	COMMIT
 	N :202 :302x
 	EOF
-	cat err &&
 	test_i18ngrep "after mark" err
 '
 
@@ -2911,7 +2965,6 @@ test_expect_success 'S: from with garbag
 	EOF
 
 	# now evaluate the error
-	cat err &&
 	test_i18ngrep "after mark" err
 '
 
@@ -2931,7 +2984,6 @@ test_expect_success 'S: merge with garba
 	merge :303x
 	M 100644 :403 hello.c
 	EOF
-	cat err &&
 	test_i18ngrep "after mark" err
 '
 
@@ -2947,7 +2999,6 @@ test_expect_success 'S: tag with garbage
 	tag S
 	TAG
 	EOF
-	cat err &&
 	test_i18ngrep "after mark" err
 '
 
@@ -2958,7 +3009,6 @@ test_expect_success 'S: cat-blob with ga
 	test_must_fail git fast-import --import-marks=marks <<-EOF 2>err &&
 	cat-blob :403x
 	EOF
-	cat err &&
 	test_i18ngrep "after mark" err
 '
 
@@ -2969,7 +3019,6 @@ test_expect_success 'S: ls with garbage
 	test_must_fail git fast-import --import-marks=marks <<-EOF 2>err &&
 	ls :302x hello.c
 	EOF
-	cat err &&
 	test_i18ngrep "space after mark" err
 '
 
@@ -2978,7 +3027,6 @@ test_expect_success 'S: ls with garbage
 	test_must_fail git fast-import --import-marks=marks <<-EOF 2>err &&
 	ls ${sha1}x hello.c
 	EOF
-	cat err &&
 	test_i18ngrep "space after tree-ish" err
 '
 
@@ -3143,11 +3191,23 @@ background_import_then_checkpoint () {
 	exec 9<>V.output
 	rm V.output
 
-	git fast-import $options <&8 >&9 &
-	echo $! >V.pid
+	(
+		git fast-import $options <&8 >&9 &
+		echo $! >&9
+		wait $!
+		echo >&2 "background fast-import terminated too early with exit code $?"
+		# Un-block the read loop in the main shell process.
+		echo >&9 UNEXPECTED
+	) &
+	sh_pid=$!
+	read fi_pid <&9
 	# We don't mind if fast-import has already died by the time the test
 	# ends.
-	test_when_finished "exec 8>&-; exec 9>&-; kill $(cat V.pid) || true"
+	test_when_finished "
+		exec 8>&-; exec 9>&-;
+		kill $sh_pid && wait $sh_pid
+		kill $fi_pid && wait $fi_pid
+		true"
 
 	# Start in the background to ensure we adhere strictly to (blocking)
 	# pipes writing sequence. We want to assume that the write below could
@@ -3166,6 +3226,9 @@ background_import_then_checkpoint () {
 		then
 			error=0
 			break
+		elif test "$output" = "UNEXPECTED"
+		then
+			break
 		fi
 		# otherwise ignore cruft
 		echo >&2 "cruft: $output"
@@ -3178,7 +3241,7 @@ background_import_then_checkpoint () {
 }
 
 background_import_still_running () {
-	if ! kill -0 "$(cat V.pid)"
+	if ! kill -0 "$fi_pid"
 	then
 		echo >&2 "background fast-import terminated too early"
 		false
@@ -3262,4 +3325,61 @@ test_expect_success PIPE 'V: checkpoint
 	background_import_still_running
 '
 
+###
+### series W (get-mark and empty orphan commits)
+###
+
+cat >>W-input <<-W_INPUT_END
+	commit refs/heads/W-branch
+	mark :1
+	author Full Name <user@company.tld> 1000000000 +0100
+	committer Full Name <user@company.tld> 1000000000 +0100
+	data 27
+	Intentionally empty commit
+	LFsget-mark :1
+	W_INPUT_END
+
+test_expect_success !MINGW 'W: get-mark & empty orphan commit with no newlines' '
+	sed -e s/LFs// W-input | tr L "\n" | git fast-import
+'
+
+test_expect_success !MINGW 'W: get-mark & empty orphan commit with one newline' '
+	sed -e s/LFs/L/ W-input | tr L "\n" | git fast-import
+'
+
+test_expect_success !MINGW 'W: get-mark & empty orphan commit with ugly second newline' '
+	# Technically, this should fail as it has too many linefeeds
+	# according to the grammar in fast-import.txt.  But, for whatever
+	# reason, it works.  Since using the correct number of newlines
+	# does not work with older (pre-2.22) versions of git, allow apps
+	# that used this second-newline workaround to keep working by
+	# checking it with this test...
+	sed -e s/LFs/LL/ W-input | tr L "\n" | git fast-import
+'
+
+test_expect_success !MINGW 'W: get-mark & empty orphan commit with erroneous third newline' '
+	# ...but do NOT allow more empty lines than that (see previous test).
+	sed -e s/LFs/LLL/ W-input | tr L "\n" | test_must_fail git fast-import
+'
+
+###
+### series X (other new features)
+###
+
+test_expect_success 'X: handling encoding' '
+	test_tick &&
+	cat >input <<-INPUT_END &&
+	commit refs/heads/encoding
+	committer $GIT_COMMITTER_NAME <$GIT_COMMITTER_EMAIL> $GIT_COMMITTER_DATE
+	encoding iso-8859-7
+	data <<COMMIT
+	INPUT_END
+
+	printf "Pi: \360\nCOMMIT\n" >>input &&
+
+	git fast-import <input &&
+	git cat-file -p encoding | grep $(printf "\360") &&
+	git log -1 --format=%B encoding | grep $(printf "\317\200")
+'
+
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t9301-fast-import-notes.sh 1.2.3+git2.25.1-1/git/t/t9301-fast-import-notes.sh
--- 1.2.1+git2.18.0-1/git/t/t9301-fast-import-notes.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t9301-fast-import-notes.sh	2020-02-17 04:47:35.000000000 +0000
@@ -275,7 +275,7 @@ $whitespace
     third note for first commit
 EXPECT_END
 
-test_expect_success 'add concatentation notes with M command' '
+test_expect_success 'add concatenation notes with M command' '
 
 	git fast-import <input &&
 	GIT_NOTES_REF=refs/notes/test git log | grep "^    " > actual &&
diff -pruN 1.2.1+git2.18.0-1/git/t/t9302-fast-import-unpack-limit.sh 1.2.3+git2.25.1-1/git/t/t9302-fast-import-unpack-limit.sh
--- 1.2.1+git2.18.0-1/git/t/t9302-fast-import-unpack-limit.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t9302-fast-import-unpack-limit.sh	2020-02-17 04:47:35.000000000 +0000
@@ -80,7 +80,7 @@ test_expect_success 'lookups after check
 		do
 			if test $n -gt 30
 			then
-				echo >&2 "checkpoint did not update branch"
+				echo >&2 "checkpoint did not update branch" &&
 				exit 1
 			else
 				n=$(($n + 1))
diff -pruN 1.2.1+git2.18.0-1/git/t/t9303-fast-import-compression.sh 1.2.3+git2.25.1-1/git/t/t9303-fast-import-compression.sh
--- 1.2.1+git2.18.0-1/git/t/t9303-fast-import-compression.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t9303-fast-import-compression.sh	2020-02-17 04:47:35.000000000 +0000
@@ -6,7 +6,7 @@ test_description='compression setting of
 # This should be moved to test-lib.sh together with the
 # copy in t0021 after both topics have graduated to 'master'.
 file_size () {
-	perl -e 'print -s $ARGV[0]' "$1"
+	test-tool path-utils file-size "$1"
 }
 
 import_large () {
diff -pruN 1.2.1+git2.18.0-1/git/t/t9350/broken-iso-8859-7-commit-message.txt 1.2.3+git2.25.1-1/git/t/t9350/broken-iso-8859-7-commit-message.txt
--- 1.2.1+git2.18.0-1/git/t/t9350/broken-iso-8859-7-commit-message.txt	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t9350/broken-iso-8859-7-commit-message.txt	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1 @@
+Pi: ; Invalid: 
\ No newline at end of file
diff -pruN 1.2.1+git2.18.0-1/git/t/t9350/simple-iso-8859-7-commit-message.txt 1.2.3+git2.25.1-1/git/t/t9350/simple-iso-8859-7-commit-message.txt
--- 1.2.1+git2.18.0-1/git/t/t9350/simple-iso-8859-7-commit-message.txt	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t9350/simple-iso-8859-7-commit-message.txt	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1 @@
+Pi: 
\ No newline at end of file
diff -pruN 1.2.1+git2.18.0-1/git/t/t9350-fast-export.sh 1.2.3+git2.25.1-1/git/t/t9350-fast-export.sh
--- 1.2.1+git2.18.0-1/git/t/t9350-fast-export.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t9350-fast-export.sh	2020-02-17 04:47:35.000000000 +0000
@@ -53,6 +53,33 @@ test_expect_success 'fast-export | fast-
 
 '
 
+test_expect_success 'fast-export ^muss^{commit} muss' '
+	git fast-export --tag-of-filtered-object=rewrite ^muss^{commit} muss >actual &&
+	cat >expected <<-EOF &&
+	tag muss
+	from $(git rev-parse --verify muss^{commit})
+	$(git cat-file tag muss | grep tagger)
+	data 9
+	valentin
+
+	EOF
+	test_cmp expected actual
+'
+
+test_expect_success 'fast-export --mark-tags ^muss^{commit} muss' '
+	git fast-export --mark-tags --tag-of-filtered-object=rewrite ^muss^{commit} muss >actual &&
+	cat >expected <<-EOF &&
+	tag muss
+	mark :1
+	from $(git rev-parse --verify muss^{commit})
+	$(git cat-file tag muss | grep tagger)
+	data 9
+	valentin
+
+	EOF
+	test_cmp expected actual
+'
+
 test_expect_success 'fast-export master~2..master' '
 
 	git fast-export master~2..master >actual &&
@@ -66,22 +93,111 @@ test_expect_success 'fast-export master~
 
 '
 
-test_expect_success 'iso-8859-1' '
+test_expect_success 'fast-export --reference-excluded-parents master~2..master' '
+
+	git fast-export --reference-excluded-parents master~2..master >actual &&
+	grep commit.refs/heads/master actual >commit-count &&
+	test_line_count = 2 commit-count &&
+	sed "s/master/rewrite/" actual |
+		(cd new &&
+		 git fast-import &&
+		 test $MASTER = $(git rev-parse --verify refs/heads/rewrite))
+'
+
+test_expect_success 'fast-export --show-original-ids' '
+
+	git fast-export --show-original-ids master >output &&
+	grep ^original-oid output| sed -e s/^original-oid.// | sort >actual &&
+	git rev-list --objects master muss >objects-and-names &&
+	awk "{print \$1}" objects-and-names | sort >commits-trees-blobs &&
+	comm -23 actual commits-trees-blobs >unfound &&
+	test_must_be_empty unfound
+'
+
+test_expect_success 'fast-export --show-original-ids | git fast-import' '
 
-	git config i18n.commitencoding ISO8859-1 &&
-	# use author and committer name in ISO-8859-1 to match it.
-	. "$TEST_DIRECTORY"/t3901/8859-1.txt &&
+	git fast-export --show-original-ids master muss | git fast-import --quiet &&
+	test $MASTER = $(git rev-parse --verify refs/heads/master) &&
+	test $MUSS = $(git rev-parse --verify refs/tags/muss)
+'
+
+test_expect_success 'reencoding iso-8859-7' '
+
+	test_when_finished "git reset --hard HEAD~1" &&
+	test_config i18n.commitencoding iso-8859-7 &&
 	test_tick &&
 	echo rosten >file &&
-	git commit -s -m den file &&
-	git fast-export wer^..wer >iso8859-1.fi &&
-	sed "s/wer/i18n/" iso8859-1.fi |
+	git commit -s -F "$TEST_DIRECTORY/t9350/simple-iso-8859-7-commit-message.txt" file &&
+	git fast-export --reencode=yes wer^..wer >iso-8859-7.fi &&
+	sed "s/wer/i18n/" iso-8859-7.fi |
 		(cd new &&
 		 git fast-import &&
+		 # The commit object, if not re-encoded, would be 240 bytes.
+		 # Removing the "encoding iso-8859-7\n" header drops 20 bytes.
+		 # Re-encoding the Pi character from \xF0 (\360) in iso-8859-7
+		 # to \xCF\x80 (\317\200) in UTF-8 adds a byte.  Check for
+		 # the expected size.
+		 test 221 -eq "$(git cat-file -s i18n)" &&
+		 # ...and for the expected translation of bytes.
 		 git cat-file commit i18n >actual &&
-		 grep "Áéí óú" actual)
+		 grep $(printf "\317\200") actual &&
+		 # Also make sure the commit does not have the "encoding" header
+		 ! grep ^encoding actual)
+'
+
+test_expect_success 'aborting on iso-8859-7' '
+
+	test_when_finished "git reset --hard HEAD~1" &&
+	test_config i18n.commitencoding iso-8859-7 &&
+	echo rosten >file &&
+	git commit -s -F "$TEST_DIRECTORY/t9350/simple-iso-8859-7-commit-message.txt" file &&
+	test_must_fail git fast-export --reencode=abort wer^..wer >iso-8859-7.fi
+'
+
+test_expect_success 'preserving iso-8859-7' '
+
+	test_when_finished "git reset --hard HEAD~1" &&
+	test_config i18n.commitencoding iso-8859-7 &&
+	echo rosten >file &&
+	git commit -s -F "$TEST_DIRECTORY/t9350/simple-iso-8859-7-commit-message.txt" file &&
+	git fast-export --reencode=no wer^..wer >iso-8859-7.fi &&
+	sed "s/wer/i18n-no-recoding/" iso-8859-7.fi |
+		(cd new &&
+		 git fast-import &&
+		 # The commit object, if not re-encoded, is 240 bytes.
+		 # Removing the "encoding iso-8859-7\n" header would drops 20
+		 # bytes.  Re-encoding the Pi character from \xF0 (\360) in
+		 # iso-8859-7 to \xCF\x80 (\317\200) in UTF-8 adds a byte.
+		 # Check for the expected size...
+		 test 240 -eq "$(git cat-file -s i18n-no-recoding)" &&
+		 # ...as well as the expected byte.
+		 git cat-file commit i18n-no-recoding >actual &&
+		 grep $(printf "\360") actual &&
+		 # Also make sure the commit has the "encoding" header
+		 grep ^encoding actual)
+'
+
+test_expect_success 'encoding preserved if reencoding fails' '
 
+	test_when_finished "git reset --hard HEAD~1" &&
+	test_config i18n.commitencoding iso-8859-7 &&
+	echo rosten >file &&
+	git commit -s -F "$TEST_DIRECTORY/t9350/broken-iso-8859-7-commit-message.txt" file &&
+	git fast-export --reencode=yes wer^..wer >iso-8859-7.fi &&
+	sed "s/wer/i18n-invalid/" iso-8859-7.fi |
+		(cd new &&
+		 git fast-import &&
+		 git cat-file commit i18n-invalid >actual &&
+		 # Make sure the commit still has the encoding header
+		 grep ^encoding actual &&
+		 # Verify that the commit has the expected size; i.e.
+		 # that no bytes were re-encoded to a different encoding.
+		 test 252 -eq "$(git cat-file -s i18n-invalid)" &&
+		 # ...and check for the original special bytes
+		 grep $(printf "\360") actual &&
+		 grep $(printf "\377") actual)
 '
+
 test_expect_success 'import/export-marks' '
 
 	git checkout -b marks master &&
@@ -196,7 +312,6 @@ GIT_COMMITTER_NAME='C O Mitter'; export
 
 test_expect_success 'setup copies' '
 
-	git config --unset i18n.commitencoding &&
 	git checkout -b copy rein &&
 	git mv file file3 &&
 	git commit -m move1 &&
@@ -325,6 +440,22 @@ test_expect_success 'rewriting tag of fi
 )
 '
 
+test_expect_success 'rewrite tag predating pathspecs to nothing' '
+	test_create_repo rewrite_tag_predating_pathspecs &&
+	(
+		cd rewrite_tag_predating_pathspecs &&
+
+		test_commit initial &&
+
+		git tag -a -m "Some old tag" v0.0.0.0.0.0.1 &&
+
+		test_commit bar &&
+
+		git fast-export --tag-of-filtered-object=rewrite --all -- bar.t >output &&
+		grep from.$ZERO_OID output
+	)
+'
+
 cat > limit-by-paths/expected << EOF
 blob
 mark :1
@@ -366,6 +497,26 @@ test_expect_success 'path limiting with
 	grep file0 actual
 '
 
+test_expect_success 'avoid corrupt stream with non-existent mark' '
+	test_create_repo avoid_non_existent_mark &&
+	(
+		cd avoid_non_existent_mark &&
+
+		test_commit important-path &&
+
+		test_commit ignored &&
+
+		git branch A &&
+		git branch B &&
+
+		echo foo >>important-path.t &&
+		git add important-path.t &&
+		test_commit more changes &&
+
+		git fast-export --all -- important-path.t | git fast-import --force
+	)
+'
+
 test_expect_success 'full-tree re-shows unmodified files'        '
 	git checkout -f simple &&
 	git fast-export --full-tree simple >actual &&
@@ -389,10 +540,41 @@ test_expect_success 'tree_tag'        '
 '
 
 # NEEDSWORK: not just check return status, but validate the output
+# Note that these tests DO NOTHING other than print a warning that
+# they are omitting the one tag we asked them to export (because the
+# tags resolve to a tree).  They exist just to make sure we do not
+# abort but instead just warn.
 test_expect_success 'tree_tag-obj'    'git fast-export tree_tag-obj'
 test_expect_success 'tag-obj_tag'     'git fast-export tag-obj_tag'
 test_expect_success 'tag-obj_tag-obj' 'git fast-export tag-obj_tag-obj'
 
+test_expect_success 'handling tags of blobs' '
+	git tag -a -m "Tag of a blob" blobtag $(git rev-parse master:file) &&
+	git fast-export blobtag >actual &&
+	cat >expect <<-EOF &&
+	blob
+	mark :1
+	data 9
+	die Luft
+
+	tag blobtag
+	from :1
+	tagger $GIT_COMMITTER_NAME <$GIT_COMMITTER_EMAIL> $GIT_COMMITTER_DATE
+	data 14
+	Tag of a blob
+
+	EOF
+	test_cmp expect actual
+'
+
+test_expect_success 'handling nested tags' '
+	git tag -a -m "This is a nested tag" nested muss &&
+	git fast-export --mark-tags nested >output &&
+	grep "^from $ZERO_OID$" output &&
+	grep "^tag nested$" output >tag_lines &&
+	test_line_count = 2 tag_lines
+'
+
 test_expect_success 'directory becomes symlink'        '
 	git init dirtosymlink &&
 	git init result &&
@@ -418,9 +600,10 @@ test_expect_success 'directory becomes s
 
 test_expect_success 'fast-export quotes pathnames' '
 	git init crazy-paths &&
+	test_config -C crazy-paths core.protectNTFS false &&
 	(cd crazy-paths &&
 	 blob=$(echo foo | git hash-object -w --stdin) &&
-	 git update-index --add \
+	 git -c core.protectNTFS=false update-index --add \
 		--cacheinfo 100644 $blob "$(printf "path with\\nnewline")" \
 		--cacheinfo 100644 $blob "path with \"quote\"" \
 		--cacheinfo 100644 $blob "path with \\backslash" \
@@ -443,17 +626,15 @@ test_expect_success 'fast-export quotes
 '
 
 test_expect_success 'test bidirectionality' '
-	>marks-cur &&
-	>marks-new &&
 	git init marks-test &&
-	git fast-export --export-marks=marks-cur --import-marks=marks-cur --branches | \
-	git --git-dir=marks-test/.git fast-import --export-marks=marks-new --import-marks=marks-new &&
+	git fast-export --export-marks=marks-cur --import-marks-if-exists=marks-cur --branches | \
+	git --git-dir=marks-test/.git fast-import --export-marks=marks-new --import-marks-if-exists=marks-new &&
 	(cd marks-test &&
 	git reset --hard &&
 	echo Wohlauf > file &&
 	git commit -a -m "back in time") &&
-	git --git-dir=marks-test/.git fast-export --export-marks=marks-new --import-marks=marks-new --branches | \
-	git fast-import --export-marks=marks-cur --import-marks=marks-cur
+	git --git-dir=marks-test/.git fast-export --export-marks=marks-new --import-marks-if-exists=marks-new --branches | \
+	git fast-import --export-marks=marks-cur --import-marks-if-exists=marks-cur
 '
 
 cat > expected << EOF
@@ -508,10 +689,20 @@ test_expect_success 'use refspec' '
 	test_cmp expected actual
 '
 
-test_expect_success 'delete refspec' '
+test_expect_success 'delete ref because entire history excluded' '
 	git branch to-delete &&
-	git fast-export --refspec :refs/heads/to-delete to-delete ^to-delete > actual &&
-	cat > expected <<-EOF &&
+	git fast-export to-delete ^to-delete >actual &&
+	cat >expected <<-EOF &&
+	reset refs/heads/to-delete
+	from 0000000000000000000000000000000000000000
+
+	EOF
+	test_cmp expected actual
+'
+
+test_expect_success 'delete refspec' '
+	git fast-export --refspec :refs/heads/to-delete >actual &&
+	cat >expected <<-EOF &&
 	reset refs/heads/to-delete
 	from 0000000000000000000000000000000000000000
 
diff -pruN 1.2.1+git2.18.0-1/git/t/t9400-git-cvsserver-server.sh 1.2.3+git2.25.1-1/git/t/t9400-git-cvsserver-server.sh
--- 1.2.1+git2.18.0-1/git/t/t9400-git-cvsserver-server.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t9400-git-cvsserver-server.sh	2020-02-17 04:47:35.000000000 +0000
@@ -328,7 +328,7 @@ test_expect_success 'cvs update (subdire
   '(for dir in A A/B A/B/C A/D E; do
       mkdir $dir &&
       echo "test file in $dir" >"$dir/file_in_$(echo $dir|sed -e "s#/# #g")"  &&
-      git add $dir;
+      git add $dir
    done) &&
    git commit -q -m "deep sub directory structure" &&
    git push gitcvs.git >/dev/null &&
@@ -371,7 +371,7 @@ test_expect_success 'cvs update (merge)'
   'echo Line 0 >expected &&
    for i in 1 2 3 4 5 6 7
    do
-     echo Line $i >>merge
+     echo Line $i >>merge &&
      echo Line $i >>expected
    done &&
    echo Line 8 >>expected &&
@@ -382,7 +382,7 @@ test_expect_success 'cvs update (merge)'
    GIT_CONFIG="$git_config" cvs -Q update &&
    test "$(echo $(grep merge CVS/Entries|cut -d/ -f2,3,5))" = "merge/1.1/" &&
    test_cmp merge ../merge &&
-   ( echo Line 0; cat merge ) >merge.tmp &&
+   ( echo Line 0 && cat merge ) >merge.tmp &&
    mv merge.tmp merge &&
    cd "$WORKDIR" &&
    echo Line 8 >>merge &&
@@ -410,7 +410,7 @@ do
 done
 
 test_expect_success 'cvs update (conflict merge)' \
-  '( echo LINE 0; cat merge ) >merge.tmp &&
+  '( echo LINE 0 && cat merge ) >merge.tmp &&
    mv merge.tmp merge &&
    git add merge &&
    git commit -q -m "Merge test (conflict)" &&
diff -pruN 1.2.1+git2.18.0-1/git/t/t9502-gitweb-standalone-parse-output.sh 1.2.3+git2.25.1-1/git/t/t9502-gitweb-standalone-parse-output.sh
--- 1.2.1+git2.18.0-1/git/t/t9502-gitweb-standalone-parse-output.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t9502-gitweb-standalone-parse-output.sh	2020-02-17 04:47:35.000000000 +0000
@@ -188,8 +188,8 @@ test_expect_success 'forks: project_inde
 '
 
 xss() {
-	echo >&2 "Checking $1..." &&
-	gitweb_run "$1" &&
+	echo >&2 "Checking $*..." &&
+	gitweb_run "$@" &&
 	if grep "$TAG" gitweb.body; then
 		echo >&2 "xss: $TAG should have been quoted in output"
 		return 1
@@ -200,7 +200,8 @@ xss() {
 test_expect_success 'xss checks' '
 	TAG="<magic-xss-tag>" &&
 	xss "a=rss&p=$TAG" &&
-	xss "a=rss&p=foo.git&f=$TAG"
+	xss "a=rss&p=foo.git&f=$TAG" &&
+	xss "" "$TAG+"
 '
 
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t9600-cvsimport.sh 1.2.3+git2.25.1-1/git/t/t9600-cvsimport.sh
--- 1.2.1+git2.18.0-1/git/t/t9600-cvsimport.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t9600-cvsimport.sh	2020-02-17 04:47:35.000000000 +0000
@@ -135,7 +135,7 @@ test_expect_success PERL 'second update
 
 	(cd module-git &&
 	 git log --format="o_fortuna 1.1 %H" -1 HEAD^^ &&
-	 git log --format="o_fortuna 1.2 %H" -1 HEAD^
+	 git log --format="o_fortuna 1.2 %H" -1 HEAD^ &&
 	 git log --format="tick 1.1 %H" -1 HEAD) > expected &&
 	test_cmp expected module-git/.git/cvs-revisions
 '
@@ -148,7 +148,7 @@ test_expect_success PERL 'import from a
 		git cvsimport -a -z0 &&
 		echo 1 >expect &&
 		git log -1 --pretty=format:%s%n >actual &&
-		test_cmp actual expect
+		test_cmp expect actual
 	)
 
 '
diff -pruN 1.2.1+git2.18.0-1/git/t/t9603-cvsimport-patchsets.sh 1.2.3+git2.25.1-1/git/t/t9603-cvsimport-patchsets.sh
--- 1.2.1+git2.18.0-1/git/t/t9603-cvsimport-patchsets.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t9603-cvsimport-patchsets.sh	2020-02-17 04:47:35.000000000 +0000
@@ -29,11 +29,11 @@ test_expect_failure PERL 'import with cr
 Rev 3
 Rev 2
 Rev 1" > expect-master &&
-    test_cmp actual-master expect-master &&
+    test_cmp expect-master actual-master &&
 
     echo "Rev 5 Branch A Wed Mar 11 19:09:10 2009 +0000
 Rev 4 Branch A Wed Mar 11 19:03:52 2009 +0000" > expect-A &&
-    test_cmp actual-A expect-A
+    test_cmp expect-A actual-A
 '
 
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t9604-cvsimport-timestamps.sh 1.2.3+git2.25.1-1/git/t/t9604-cvsimport-timestamps.sh
--- 1.2.1+git2.18.0-1/git/t/t9604-cvsimport-timestamps.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t9604-cvsimport-timestamps.sh	2020-02-17 04:47:35.000000000 +0000
@@ -31,7 +31,7 @@ test_expect_success PERL 'check timestam
 	Rev  2 2005-02-01 00:00:00 +0000
 	Rev  1 2005-01-01 00:00:00 +0000
 	EOF
-	test_cmp actual-1 expect-1
+	test_cmp expect-1 actual-1
 '
 
 test_expect_success PERL 'check timestamps with author-specific timezones' '
@@ -65,7 +65,7 @@ test_expect_success PERL 'check timestam
 	Rev  2 2005-01-31 18:00:00 -0600 User Two
 	Rev  1 2005-01-01 00:00:00 +0000 User One
 	EOF
-	test_cmp actual-2 expect-2
+	test_cmp expect-2 actual-2
 '
 
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t9800-git-p4-basic.sh 1.2.3+git2.25.1-1/git/t/t9800-git-p4-basic.sh
--- 1.2.1+git2.18.0-1/git/t/t9800-git-p4-basic.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t9800-git-p4-basic.sh	2020-02-17 04:47:35.000000000 +0000
@@ -261,6 +261,35 @@ test_expect_success 'unresolvable host i
 	)
 '
 
+# Test following scenarios:
+#   - Without ".git/hooks/p4-pre-submit" , submit should continue
+#   - With the hook returning 0, submit should continue
+#   - With the hook returning 1, submit should abort
+test_expect_success 'run hook p4-pre-submit before submit' '
+	test_when_finished cleanup_git &&
+	git p4 clone --dest="$git" //depot &&
+	(
+		cd "$git" &&
+		echo "hello world" >hello.txt &&
+		git add hello.txt &&
+		git commit -m "add hello.txt" &&
+		git config git-p4.skipSubmitEdit true &&
+		git p4 submit --dry-run >out &&
+		grep "Would apply" out &&
+		mkdir -p .git/hooks &&
+		write_script .git/hooks/p4-pre-submit <<-\EOF &&
+		exit 0
+		EOF
+		git p4 submit --dry-run >out &&
+		grep "Would apply" out &&
+		write_script .git/hooks/p4-pre-submit <<-\EOF &&
+		exit 1
+		EOF
+		test_must_fail git p4 submit --dry-run >errs 2>&1 &&
+		! grep "Would apply" errs
+	)
+'
+
 test_expect_success 'submit from detached head' '
 	test_when_finished cleanup_git &&
 	git p4 clone --dest="$git" //depot &&
@@ -297,8 +326,4 @@ test_expect_success 'submit from worktre
 	)
 '
 
-test_expect_success 'kill p4d' '
-	kill_p4d
-'
-
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t9801-git-p4-branch.sh 1.2.3+git2.25.1-1/git/t/t9801-git-p4-branch.sh
--- 1.2.1+git2.18.0-1/git/t/t9801-git-p4-branch.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t9801-git-p4-branch.sh	2020-02-17 04:47:35.000000000 +0000
@@ -151,7 +151,7 @@ test_expect_success 'import depot, branc
 '
 
 test_expect_success 'restart p4d' '
-	kill_p4d &&
+	stop_and_cleanup_p4d &&
 	start_p4d
 '
 
@@ -411,6 +411,46 @@ test_expect_failure 'git p4 clone file s
 	)
 '
 
+# Check that excluded files are omitted during import
+test_expect_success 'git p4 clone complex branches with excluded files' '
+	test_when_finished cleanup_git &&
+	test_create_repo "$git" &&
+	(
+		cd "$git" &&
+		git config git-p4.branchList branch1:branch2 &&
+		git config --add git-p4.branchList branch1:branch3 &&
+		git config --add git-p4.branchList branch1:branch4 &&
+		git config --add git-p4.branchList branch1:branch5 &&
+		git config --add git-p4.branchList branch1:branch6 &&
+		git p4 clone --dest=. --detect-branches -//depot/branch1/file2 -//depot/branch2/file2 -//depot/branch3/file2 -//depot/branch4/file2 -//depot/branch5/file2 -//depot/branch6/file2 //depot@all &&
+		git log --all --graph --decorate --stat &&
+		git reset --hard p4/depot/branch1 &&
+		test_path_is_file file1 &&
+		test_path_is_missing file2 &&
+		test_path_is_file file3 &&
+		git reset --hard p4/depot/branch2 &&
+		test_path_is_file file1 &&
+		test_path_is_missing file2 &&
+		test_path_is_missing file3 &&
+		git reset --hard p4/depot/branch3 &&
+		test_path_is_file file1 &&
+		test_path_is_missing file2 &&
+		test_path_is_missing file3 &&
+		git reset --hard p4/depot/branch4 &&
+		test_path_is_file file1 &&
+		test_path_is_missing file2 &&
+		test_path_is_file file3 &&
+		git reset --hard p4/depot/branch5 &&
+		test_path_is_file file1 &&
+		test_path_is_missing file2 &&
+		test_path_is_file file3 &&
+		git reset --hard p4/depot/branch6 &&
+		test_path_is_file file1 &&
+		test_path_is_missing file2 &&
+		test_path_is_missing file3
+	)
+'
+
 # From a report in http://stackoverflow.com/questions/11893688
 # where --use-client-spec caused branch prefixes not to be removed;
 # every file in git appeared into a subdirectory of the branch name.
@@ -505,7 +545,7 @@ test_expect_success 'use-client-spec det
 '
 
 test_expect_success 'restart p4d' '
-	kill_p4d &&
+	stop_and_cleanup_p4d &&
 	start_p4d
 '
 
@@ -610,8 +650,96 @@ test_expect_success 'Update a file in gi
 	)
 '
 
-test_expect_success 'kill p4d' '
-	kill_p4d
+test_expect_success 'restart p4d (case folding enabled)' '
+	stop_and_cleanup_p4d &&
+	start_p4d -C1
+'
+
+#
+# 1: //depot/main/mf1
+# 2: integrate //depot/main/... -> //depot/branch1/...
+# 3: //depot/main/mf2
+# 4: //depot/BRANCH1/B1f3
+# 5: //depot/branch1/b1f4
+#
+test_expect_success !CASE_INSENSITIVE_FS 'basic p4 branches for case folding' '
+	(
+		cd "$cli" &&
+		mkdir -p main &&
+
+		echo mf1 >main/mf1 &&
+		p4 add main/mf1 &&
+		p4 submit -d "main/mf1" &&
+
+		p4 integrate //depot/main/... //depot/branch1/... &&
+		p4 submit -d "integrate main to branch1" &&
+
+		echo mf2 >main/mf2 &&
+		p4 add main/mf2 &&
+		p4 submit -d "main/mf2" &&
+
+		mkdir BRANCH1 &&
+		echo B1f3 >BRANCH1/B1f3 &&
+		p4 add BRANCH1/B1f3 &&
+		p4 submit -d "BRANCH1/B1f3" &&
+
+		echo b1f4 >branch1/b1f4 &&
+		p4 add branch1/b1f4 &&
+		p4 submit -d "branch1/b1f4"
+	)
+'
+
+# Check that files are properly split across branches when ignorecase is set
+test_expect_success !CASE_INSENSITIVE_FS 'git p4 clone, branchList branch definition, ignorecase' '
+	test_when_finished cleanup_git &&
+	test_create_repo "$git" &&
+	(
+		cd "$git" &&
+		git config git-p4.branchList main:branch1 &&
+		git config --type=bool core.ignoreCase true &&
+		git p4 clone --dest=. --detect-branches //depot@all &&
+
+		git log --all --graph --decorate --stat &&
+
+		git reset --hard p4/master &&
+		test_path_is_file mf1 &&
+		test_path_is_file mf2 &&
+		test_path_is_missing B1f3 &&
+		test_path_is_missing b1f4 &&
+
+		git reset --hard p4/depot/branch1 &&
+		test_path_is_file mf1 &&
+		test_path_is_missing mf2 &&
+		test_path_is_file B1f3 &&
+		test_path_is_file b1f4
+	)
+'
+
+# Check that files are properly split across branches when ignorecase is set, use-client-spec case
+test_expect_success !CASE_INSENSITIVE_FS 'git p4 clone with client-spec, branchList branch definition, ignorecase' '
+	client_view "//depot/... //client/..." &&
+	test_when_finished cleanup_git &&
+	test_create_repo "$git" &&
+	(
+		cd "$git" &&
+		git config git-p4.branchList main:branch1 &&
+		git config --type=bool core.ignoreCase true &&
+		git p4 clone --dest=. --use-client-spec --detect-branches //depot@all &&
+
+		git log --all --graph --decorate --stat &&
+
+		git reset --hard p4/master &&
+		test_path_is_file mf1 &&
+		test_path_is_file mf2 &&
+		test_path_is_missing B1f3 &&
+		test_path_is_missing b1f4 &&
+
+		git reset --hard p4/depot/branch1 &&
+		test_path_is_file mf1 &&
+		test_path_is_missing mf2 &&
+		test_path_is_file B1f3 &&
+		test_path_is_file b1f4
+	)
 '
 
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t9802-git-p4-filetype.sh 1.2.3+git2.25.1-1/git/t/t9802-git-p4-filetype.sh
--- 1.2.1+git2.18.0-1/git/t/t9802-git-p4-filetype.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t9802-git-p4-filetype.sh	2020-02-17 04:47:35.000000000 +0000
@@ -310,7 +310,7 @@ test_expect_success SYMLINKS 'empty syml
 		# p4 to sync here will make it generate errors.
 		cd "$cli" &&
 		p4 print -q //depot/empty-symlink#2 >out &&
-		test ! -s out
+		test_must_be_empty out
 	) &&
 	test_when_finished cleanup_git &&
 
@@ -333,8 +333,4 @@ test_expect_success SYMLINKS 'empty syml
 	)
 '
 
-test_expect_success 'kill p4d' '
-	kill_p4d
-'
-
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t9803-git-p4-shell-metachars.sh 1.2.3+git2.25.1-1/git/t/t9803-git-p4-shell-metachars.sh
--- 1.2.1+git2.18.0-1/git/t/t9803-git-p4-shell-metachars.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t9803-git-p4-shell-metachars.sh	2020-02-17 04:47:35.000000000 +0000
@@ -105,8 +105,4 @@ test_expect_success 'branch with shell c
 	)
 '
 
-test_expect_success 'kill p4d' '
-	kill_p4d
-'
-
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t9804-git-p4-label.sh 1.2.3+git2.25.1-1/git/t/t9804-git-p4-label.sh
--- 1.2.1+git2.18.0-1/git/t/t9804-git-p4-label.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t9804-git-p4-label.sh	2020-02-17 04:47:35.000000000 +0000
@@ -108,8 +108,4 @@ test_expect_failure 'two labels on the s
 	)
 '
 
-test_expect_success 'kill p4d' '
-	kill_p4d
-'
-
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t9805-git-p4-skip-submit-edit.sh 1.2.3+git2.25.1-1/git/t/t9805-git-p4-skip-submit-edit.sh
--- 1.2.1+git2.18.0-1/git/t/t9805-git-p4-skip-submit-edit.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t9805-git-p4-skip-submit-edit.sh	2020-02-17 04:47:35.000000000 +0000
@@ -98,8 +98,4 @@ test_expect_success 'no config, edited'
 	)
 '
 
-test_expect_success 'kill p4d' '
-	kill_p4d
-'
-
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t9806-git-p4-options.sh 1.2.3+git2.25.1-1/git/t/t9806-git-p4-options.sh
--- 1.2.1+git2.18.0-1/git/t/t9806-git-p4-options.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t9806-git-p4-options.sh	2020-02-17 04:47:35.000000000 +0000
@@ -134,7 +134,7 @@ test_expect_success 'clone --changesfile
 	(
 		cd "$git" &&
 		git log --oneline p4/master >lines &&
-		test_line_count = 2 lines
+		test_line_count = 2 lines &&
 		test_path_is_file file1 &&
 		test_path_is_missing file2 &&
 		test_path_is_file file3
@@ -300,9 +300,4 @@ test_expect_success 'use --git-dir optio
 	test_path_is_file "$git"/cli_file2.t
 '
 
-
-test_expect_success 'kill p4d' '
-	kill_p4d
-'
-
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t9807-git-p4-submit.sh 1.2.3+git2.25.1-1/git/t/t9807-git-p4-submit.sh
--- 1.2.1+git2.18.0-1/git/t/t9807-git-p4-submit.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t9807-git-p4-submit.sh	2020-02-17 04:47:35.000000000 +0000
@@ -500,6 +500,10 @@ test_expect_success 'submit --shelve' '
 	)
 '
 
+last_shelve () {
+	p4 -G changes -s shelved -m 1 //depot/... | marshal_dump change
+}
+
 make_shelved_cl() {
 	test_commit "$1" >/dev/null &&
 	git p4 submit --origin HEAD^ --shelve >/dev/null &&
@@ -533,17 +537,60 @@ test_expect_success 'submit --update-she
 	) &&
 	(
 		cd "$cli" &&
-		change=$(p4 -G changes -s shelved -m 1 //depot/... | \
-			 marshal_dump change) &&
+		change=$(last_shelve) &&
 		p4 unshelve -c $change -s $change &&
 		grep -q updated-line shelf.t &&
 		p4 describe -S $change | grep added-file.t &&
-		test_path_is_missing shelved-change-1.t
+		test_path_is_missing shelved-change-1.t &&
+		p4 revert ...
 	)
 '
 
-test_expect_success 'kill p4d' '
-	kill_p4d
+test_expect_success 'update a shelve involving moved and copied files' '
+	test_when_finished cleanup_git &&
+	(
+		cd "$cli" &&
+		: >file_to_move &&
+		p4 add file_to_move &&
+		p4 submit -d "change1" &&
+		p4 edit file_to_move &&
+		echo change >>file_to_move &&
+		p4 submit -d "change2" &&
+		p4 opened
+	) &&
+	git p4 clone --dest="$git" //depot &&
+	(
+		cd "$git" &&
+		git config git-p4.detectCopies true &&
+		git config git-p4.detectRenames true &&
+		git config git-p4.skipSubmitEdit true &&
+		mkdir moved &&
+		cp file_to_move copy_of_file &&
+		git add copy_of_file &&
+		git mv file_to_move moved/ &&
+		git commit -m "rename a file" &&
+		git p4 submit -M --shelve --origin HEAD^ &&
+		: >new_file &&
+		git add new_file &&
+		git commit --amend &&
+		git show --stat HEAD &&
+		change=$(last_shelve) &&
+		git p4 submit -M --update-shelve $change --commit HEAD
+	) &&
+	(
+		cd "$cli" &&
+		change=$(last_shelve) &&
+		echo change=$change &&
+		p4 unshelve -s $change &&
+		p4 submit -d "Testing update-shelve" &&
+		test_path_is_file copy_of_file &&
+		test_path_is_file moved/file_to_move &&
+		test_path_is_missing file_to_move &&
+		test_path_is_file new_file &&
+		echo "unshelved and submitted change $change" &&
+		p4 changes moved/file_to_move | grep "Testing update-shelve" &&
+		p4 changes copy_of_file | grep "Testing update-shelve"
+	)
 '
 
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t9808-git-p4-chdir.sh 1.2.3+git2.25.1-1/git/t/t9808-git-p4-chdir.sh
--- 1.2.1+git2.18.0-1/git/t/t9808-git-p4-chdir.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t9808-git-p4-chdir.sh	2020-02-17 04:47:35.000000000 +0000
@@ -83,8 +83,4 @@ test_expect_success SYMLINKS 'p4 client
 	)
 '
 
-test_expect_success 'kill p4d' '
-	kill_p4d
-'
-
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t9809-git-p4-client-view.sh 1.2.3+git2.25.1-1/git/t/t9809-git-p4-client-view.sh
--- 1.2.1+git2.18.0-1/git/t/t9809-git-p4-client-view.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t9809-git-p4-client-view.sh	2020-02-17 04:47:35.000000000 +0000
@@ -407,7 +407,7 @@ test_expect_success 'reinit depot' '
 '
 
 #
-# What happens when two files of the same name are overlayed together?
+# What happens when two files of the same name are overlaid together?
 # The last-listed file should take preference.
 #
 # //depot
@@ -836,8 +836,4 @@ test_expect_success 'quotes on both side
 	git_verify "cdir 1/file11" "cdir 1/file12"
 '
 
-test_expect_success 'kill p4d' '
-	kill_p4d
-'
-
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t9810-git-p4-rcs.sh 1.2.3+git2.25.1-1/git/t/t9810-git-p4-rcs.sh
--- 1.2.1+git2.18.0-1/git/t/t9810-git-p4-rcs.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t9810-git-p4-rcs.sh	2020-02-17 04:47:35.000000000 +0000
@@ -161,7 +161,7 @@ test_expect_success 'cleanup after failu
 test_expect_success 'ktext expansion should not expand multi-line $File::' '
 	(
 		cd "$cli" &&
-		cat >lv.pm <<-\EOF
+		cat >lv.pm <<-\EOF &&
 		my $wanted = sub { my $f = $File::Find::name;
 				    if ( -f && $f =~ /foo/ ) {
 		EOF
@@ -360,8 +360,4 @@ test_expect_failure 'Add keywords in git
 	)
 '
 
-test_expect_success 'kill p4d' '
-	kill_p4d
-'
-
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t9811-git-p4-label-import.sh 1.2.3+git2.25.1-1/git/t/t9811-git-p4-label-import.sh
--- 1.2.1+git2.18.0-1/git/t/t9811-git-p4-label-import.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t9811-git-p4-label-import.sh	2020-02-17 04:47:35.000000000 +0000
@@ -133,7 +133,7 @@ test_expect_success 'export git tags to
 		p4 labels ... | grep LIGHTWEIGHT_TAG &&
 		p4 label -o GIT_TAG_1 | grep "tag created in git:xyzzy" &&
 		p4 sync ...@GIT_TAG_1 &&
-		! test -f main/f10
+		! test -f main/f10 &&
 		p4 sync ...@GIT_TAG_2 &&
 		test -f main/f10
 	)
@@ -191,7 +191,7 @@ test_expect_success 'tag that cannot be
 	(
 		cd "$cli" &&
 		p4 sync ... &&
-		!(p4 labels | grep GIT_TAG_ON_A_BRANCH)
+		! p4 labels | grep GIT_TAG_ON_A_BRANCH
 	)
 '
 
@@ -259,9 +259,4 @@ test_expect_success 'importing labels wi
 	)
 '
 
-
-test_expect_success 'kill p4d' '
-	kill_p4d
-'
-
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t9812-git-p4-wildcards.sh 1.2.3+git2.25.1-1/git/t/t9812-git-p4-wildcards.sh
--- 1.2.1+git2.18.0-1/git/t/t9812-git-p4-wildcards.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t9812-git-p4-wildcards.sh	2020-02-17 04:47:35.000000000 +0000
@@ -211,8 +211,4 @@ test_expect_success 'wildcard files requ
 	)
 '
 
-test_expect_success 'kill p4d' '
-	kill_p4d
-'
-
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t9813-git-p4-preserve-users.sh 1.2.3+git2.25.1-1/git/t/t9813-git-p4-preserve-users.sh
--- 1.2.1+git2.18.0-1/git/t/t9813-git-p4-preserve-users.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t9813-git-p4-preserve-users.sh	2020-02-17 04:47:35.000000000 +0000
@@ -138,8 +138,4 @@ test_expect_success 'not preserving user
 	)
 '
 
-test_expect_success 'kill p4d' '
-	kill_p4d
-'
-
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t9814-git-p4-rename.sh 1.2.3+git2.25.1-1/git/t/t9814-git-p4-rename.sh
--- 1.2.1+git2.18.0-1/git/t/t9814-git-p4-rename.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t9814-git-p4-rename.sh	2020-02-17 04:47:35.000000000 +0000
@@ -9,23 +9,11 @@ test_expect_success 'start p4d' '
 '
 
 # We rely on this behavior to detect for p4 move availability.
-test_expect_success 'p4 help unknown returns 1' '
+test_expect_success '"p4 help unknown" errors out' '
 	(
 		cd "$cli" &&
-		(
-			p4 help client >errs 2>&1
-			echo $? >retval
-		)
-		echo 0 >expected &&
-		test_cmp expected retval &&
-		rm retval &&
-		(
-			p4 help nosuchcommand >errs 2>&1
-			echo $? >retval
-		)
-		echo 1 >expected &&
-		test_cmp expected retval &&
-		rm retval
+		p4 help client &&
+		! p4 help nosuchcommand
 	)
 '
 
@@ -254,8 +242,4 @@ test_expect_success P4D_HAVE_CONFIGURABL
 	)
 '
 
-test_expect_success 'kill p4d' '
-	kill_p4d
-'
-
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t9815-git-p4-submit-fail.sh 1.2.3+git2.25.1-1/git/t/t9815-git-p4-submit-fail.sh
--- 1.2.1+git2.18.0-1/git/t/t9815-git-p4-submit-fail.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t9815-git-p4-submit-fail.sh	2020-02-17 04:47:35.000000000 +0000
@@ -394,7 +394,7 @@ test_expect_success 'cleanup rename afte
 	(
 		cd "$cli" &&
 		test_path_is_missing text2 &&
-		p4 fstat -T action text2 2>&1 | grep "no such file"
+		p4 fstat -T action text2 2>&1 | grep "no such file" &&
 		test_path_is_file text &&
 		! p4 fstat -T action text
 	)
@@ -422,8 +422,4 @@ test_expect_success 'cleanup chmod after
 	)
 '
 
-test_expect_success 'kill p4d' '
-	kill_p4d
-'
-
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t9816-git-p4-locked.sh 1.2.3+git2.25.1-1/git/t/t9816-git-p4-locked.sh
--- 1.2.1+git2.18.0-1/git/t/t9816-git-p4-locked.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t9816-git-p4-locked.sh	2020-02-17 04:47:35.000000000 +0000
@@ -138,8 +138,4 @@ test_expect_failure 'move with lock take
 	)
 '
 
-test_expect_success 'kill p4d' '
-	kill_p4d
-'
-
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t9817-git-p4-exclude.sh 1.2.3+git2.25.1-1/git/t/t9817-git-p4-exclude.sh
--- 1.2.1+git2.18.0-1/git/t/t9817-git-p4-exclude.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t9817-git-p4-exclude.sh	2020-02-17 04:47:35.000000000 +0000
@@ -22,7 +22,9 @@ test_expect_success 'create exclude repo
 		mkdir -p wanted discard &&
 		echo wanted >wanted/foo &&
 		echo discard >discard/foo &&
-		p4 add wanted/foo discard/foo &&
+		echo discard_file >discard_file &&
+		echo discard_file_not >discard_file_not &&
+		p4 add wanted/foo discard/foo discard_file discard_file_not &&
 		p4 submit -d "initial revision"
 	)
 '
@@ -33,7 +35,9 @@ test_expect_success 'check the repo was
 	(
 		cd "$git" &&
 		test_path_is_file wanted/foo &&
-		test_path_is_file discard/foo
+		test_path_is_file discard/foo &&
+		test_path_is_file discard_file &&
+		test_path_is_file discard_file_not
 	)
 '
 
@@ -43,7 +47,21 @@ test_expect_success 'clone, excluding pa
 	(
 		cd "$git" &&
 		test_path_is_file wanted/foo &&
-		test_path_is_missing discard/foo
+		test_path_is_missing discard/foo &&
+		test_path_is_file discard_file &&
+		test_path_is_file discard_file_not
+	)
+'
+
+test_expect_success 'clone, excluding single file, no trailing /' '
+	test_when_finished cleanup_git &&
+	git p4 clone -//depot/discard_file --dest="$git" //depot/...@all &&
+	(
+		cd "$git" &&
+		test_path_is_file wanted/foo &&
+		test_path_is_file discard/foo &&
+		test_path_is_missing discard_file &&
+		test_path_is_file discard_file_not
 	)
 '
 
@@ -52,20 +70,39 @@ test_expect_success 'clone, then sync wi
 	git p4 clone -//depot/discard/... --dest="$git" //depot/...@all &&
 	(
 		cd "$cli" &&
-		p4 edit wanted/foo discard/foo &&
+		p4 edit wanted/foo discard/foo discard_file_not &&
 		date >>wanted/foo &&
 		date >>discard/foo &&
+		date >>discard_file_not &&
 		p4 submit -d "updating" &&
 
 		cd "$git" &&
 		git p4 sync -//depot/discard/... &&
 		test_path_is_file wanted/foo &&
-		test_path_is_missing discard/foo
+		test_path_is_missing discard/foo &&
+		test_path_is_file discard_file &&
+		test_path_is_file discard_file_not
 	)
 '
 
-test_expect_success 'kill p4d' '
-	kill_p4d
+test_expect_success 'clone, then sync with exclude, no trailing /' '
+	test_when_finished cleanup_git &&
+	git p4 clone -//depot/discard/... -//depot/discard_file --dest="$git" //depot/...@all &&
+	(
+		cd "$cli" &&
+		p4 edit wanted/foo discard/foo discard_file_not &&
+		date >>wanted/foo &&
+		date >>discard/foo &&
+		date >>discard_file_not &&
+		p4 submit -d "updating" &&
+
+		cd "$git" &&
+		git p4 sync -//depot/discard/... -//depot/discard_file &&
+		test_path_is_file wanted/foo &&
+		test_path_is_missing discard/foo &&
+		test_path_is_missing discard_file &&
+		test_path_is_file discard_file_not
+	)
 '
 
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t9818-git-p4-block.sh 1.2.3+git2.25.1-1/git/t/t9818-git-p4-block.sh
--- 1.2.1+git2.18.0-1/git/t/t9818-git-p4-block.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t9818-git-p4-block.sh	2020-02-17 04:47:35.000000000 +0000
@@ -146,8 +146,4 @@ test_expect_success 'Clone repo with sel
 	test_line_count \> 10 log
 '
 
-test_expect_success 'kill p4d' '
-	kill_p4d
-'
-
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t9819-git-p4-case-folding.sh 1.2.3+git2.25.1-1/git/t/t9819-git-p4-case-folding.sh
--- 1.2.1+git2.18.0-1/git/t/t9819-git-p4-case-folding.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t9819-git-p4-case-folding.sh	2020-02-17 04:47:35.000000000 +0000
@@ -53,8 +53,4 @@ test_expect_failure 'Clone UC repo with
 	test_must_fail git p4 clone //depot/uc/...
 '
 
-test_expect_success 'kill p4d' '
-	kill_p4d
-'
-
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t9820-git-p4-editor-handling.sh 1.2.3+git2.25.1-1/git/t/t9820-git-p4-editor-handling.sh
--- 1.2.1+git2.18.0-1/git/t/t9820-git-p4-editor-handling.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t9820-git-p4-editor-handling.sh	2020-02-17 04:47:35.000000000 +0000
@@ -31,8 +31,4 @@ test_expect_success 'EDITOR with options
 	)
 '
 
-test_expect_success 'kill p4d' '
-	kill_p4d
-'
-
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t9821-git-p4-path-variations.sh 1.2.3+git2.25.1-1/git/t/t9821-git-p4-path-variations.sh
--- 1.2.1+git2.18.0-1/git/t/t9821-git-p4-path-variations.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t9821-git-p4-path-variations.sh	2020-02-17 04:47:35.000000000 +0000
@@ -193,8 +193,4 @@ test_expect_success 'Add a new file and
 	)
 '
 
-test_expect_success 'kill p4d' '
-	kill_p4d
-'
-
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t9822-git-p4-path-encoding.sh 1.2.3+git2.25.1-1/git/t/t9822-git-p4-path-encoding.sh
--- 1.2.1+git2.18.0-1/git/t/t9822-git-p4-path-encoding.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t9822-git-p4-path-encoding.sh	2020-02-17 04:47:35.000000000 +0000
@@ -7,6 +7,13 @@ test_description='Clone repositories wit
 UTF8_ESCAPED="a-\303\244_o-\303\266_u-\303\274.txt"
 ISO8859_ESCAPED="a-\344_o-\366_u-\374.txt"
 
+ISO8859="$(printf "$ISO8859_ESCAPED")" &&
+echo content123 >"$ISO8859" &&
+rm "$ISO8859" || {
+	skip_all="fs does not accept ISO-8859-1 filenames"
+	test_done
+}
+
 test_expect_success 'start p4d' '
 	start_p4d
 '
@@ -67,8 +74,4 @@ test_expect_success 'Delete iso8859-1 en
 	)
 '
 
-test_expect_success 'kill p4d' '
-	kill_p4d
-'
-
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t9823-git-p4-mock-lfs.sh 1.2.3+git2.25.1-1/git/t/t9823-git-p4-mock-lfs.sh
--- 1.2.1+git2.18.0-1/git/t/t9823-git-p4-mock-lfs.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t9823-git-p4-mock-lfs.sh	2020-02-17 04:47:35.000000000 +0000
@@ -185,8 +185,4 @@ test_expect_success 'Run git p4 submit i
 	)
 '
 
-test_expect_success 'kill p4d' '
-	kill_p4d
-'
-
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t9824-git-p4-git-lfs.sh 1.2.3+git2.25.1-1/git/t/t9824-git-p4-git-lfs.sh
--- 1.2.1+git2.18.0-1/git/t/t9824-git-p4-git-lfs.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t9824-git-p4-git-lfs.sh	2020-02-17 04:47:35.000000000 +0000
@@ -287,8 +287,4 @@ test_expect_success 'Add big files to re
 	)
 '
 
-test_expect_success 'kill p4d' '
-	kill_p4d
-'
-
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t9825-git-p4-handle-utf16-without-bom.sh 1.2.3+git2.25.1-1/git/t/t9825-git-p4-handle-utf16-without-bom.sh
--- 1.2.1+git2.18.0-1/git/t/t9825-git-p4-handle-utf16-without-bom.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t9825-git-p4-handle-utf16-without-bom.sh	2020-02-17 04:47:35.000000000 +0000
@@ -43,8 +43,4 @@ test_expect_failure 'clone depot with in
 	git p4 clone --dest="$git" //depot
 '
 
-test_expect_success 'kill p4d' '
-	kill_p4d
-'
-
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t9826-git-p4-keep-empty-commits.sh 1.2.3+git2.25.1-1/git/t/t9826-git-p4-keep-empty-commits.sh
--- 1.2.1+git2.18.0-1/git/t/t9826-git-p4-keep-empty-commits.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t9826-git-p4-keep-empty-commits.sh	2020-02-17 04:47:35.000000000 +0000
@@ -127,8 +127,4 @@ test_expect_success 'Clone repo subdir w
 	)
 '
 
-test_expect_success 'kill p4d' '
-	kill_p4d
-'
-
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t9827-git-p4-change-filetype.sh 1.2.3+git2.25.1-1/git/t/t9827-git-p4-change-filetype.sh
--- 1.2.1+git2.18.0-1/git/t/t9827-git-p4-change-filetype.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t9827-git-p4-change-filetype.sh	2020-02-17 04:47:35.000000000 +0000
@@ -59,8 +59,4 @@ test_expect_success SYMLINKS 'change sym
 	)
 '
 
-test_expect_success 'kill p4d' '
-	kill_p4d
-'
-
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t9828-git-p4-map-user.sh 1.2.3+git2.25.1-1/git/t/t9828-git-p4-map-user.sh
--- 1.2.1+git2.18.0-1/git/t/t9828-git-p4-map-user.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t9828-git-p4-map-user.sh	2020-02-17 04:47:35.000000000 +0000
@@ -54,8 +54,4 @@ test_expect_success 'Clone repo root pat
 	)
 '
 
-test_expect_success 'kill p4d' '
-	kill_p4d
-'
-
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t9829-git-p4-jobs.sh 1.2.3+git2.25.1-1/git/t/t9829-git-p4-jobs.sh
--- 1.2.1+git2.18.0-1/git/t/t9829-git-p4-jobs.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t9829-git-p4-jobs.sh	2020-02-17 04:47:35.000000000 +0000
@@ -92,8 +92,4 @@ test_expect_success 'check log message o
 	)
 '
 
-test_expect_success 'kill p4d' '
-	kill_p4d
-'
-
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t9830-git-p4-symlink-dir.sh 1.2.3+git2.25.1-1/git/t/t9830-git-p4-symlink-dir.sh
--- 1.2.1+git2.18.0-1/git/t/t9830-git-p4-symlink-dir.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t9830-git-p4-symlink-dir.sh	2020-02-17 04:47:35.000000000 +0000
@@ -30,14 +30,10 @@ test_expect_success 'symlinked directory
 	(
 		cd "$cli" &&
 		p4 sync &&
-		test -L some/sub/directory/subdir2
+		test -L some/sub/directory/subdir2 &&
 		test_path_is_file some/sub/directory/subdir2/file.t
 	)
 
 '
 
-test_expect_success 'kill p4d' '
-	kill_p4d
-'
-
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t9831-git-p4-triggers.sh 1.2.3+git2.25.1-1/git/t/t9831-git-p4-triggers.sh
--- 1.2.1+git2.18.0-1/git/t/t9831-git-p4-triggers.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t9831-git-p4-triggers.sh	2020-02-17 04:47:35.000000000 +0000
@@ -13,7 +13,7 @@ test_expect_success 'init depot' '
 		cd "$cli" &&
 		echo file1 >file1 &&
 		p4 add file1 &&
-		p4 submit -d "change 1"
+		p4 submit -d "change 1" &&
 		echo file2 >file2 &&
 		p4 add file2 &&
 		p4 submit -d "change 2"
@@ -96,8 +96,4 @@ test_expect_success 'submit description
 	)
 '
 
-test_expect_success 'kill p4d' '
-	kill_p4d
-'
-
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t9832-unshelve.sh 1.2.3+git2.25.1-1/git/t/t9832-unshelve.sh
--- 1.2.1+git2.18.0-1/git/t/t9832-unshelve.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t9832-unshelve.sh	2020-02-17 04:47:35.000000000 +0000
@@ -19,8 +19,13 @@ test_expect_success 'init depot' '
 		p4 add file1 &&
 		p4 submit -d "change 1" &&
 		: >file_to_delete &&
+		: >file_to_move &&
 		p4 add file_to_delete &&
-		p4 submit -d "file to delete"
+		p4 add file_to_move &&
+		p4 submit -d "add files to delete" &&
+		echo file_to_integrate >file_to_integrate &&
+		p4 add file_to_integrate &&
+		p4 submit -d "add file to integrate"
 	)
 '
 
@@ -36,6 +41,9 @@ test_expect_success 'create shelved chan
 		echo "new file" >file2 &&
 		p4 add file2 &&
 		p4 delete file_to_delete &&
+		p4 edit file_to_move &&
+		p4 move file_to_move moved_file &&
+		p4 integrate file_to_integrate integrated_file &&
 		p4 opened &&
 		p4 shelve -i <<EOF
 Change: new
@@ -47,6 +55,9 @@ Files:
 	//depot/file1
 	//depot/file2
 	//depot/file_to_delete
+	//depot/file_to_move
+	//depot/moved_file
+	//depot/integrated_file
 EOF
 
 	) &&
@@ -54,12 +65,15 @@ EOF
 		cd "$git" &&
 		change=$(last_shelved_change) &&
 		git p4 unshelve $change &&
-		git show refs/remotes/p4/unshelved/$change | grep -q "Further description" &&
-		git cherry-pick refs/remotes/p4/unshelved/$change &&
+		git show refs/remotes/p4-unshelved/$change | grep -q "Further description" &&
+		git cherry-pick refs/remotes/p4-unshelved/$change &&
 		test_path_is_file file2 &&
 		test_cmp file1 "$cli"/file1 &&
 		test_cmp file2 "$cli"/file2 &&
-		test_path_is_missing file_to_delete
+		test_cmp file_to_integrate "$cli"/integrated_file &&
+		test_path_is_missing file_to_delete &&
+		test_path_is_missing file_to_move &&
+		test_path_is_file moved_file
 	)
 '
 
@@ -88,10 +102,22 @@ EOF
 		cd "$git" &&
 		change=$(last_shelved_change) &&
 		git p4 unshelve $change &&
-		git diff refs/remotes/p4/unshelved/$change.0 refs/remotes/p4/unshelved/$change | grep -q file3
+		git diff refs/remotes/p4-unshelved/$change.0 refs/remotes/p4-unshelved/$change | grep -q file3
 	)
 '
 
+shelve_one_file () {
+	description="Change to be unshelved" &&
+	file="$1" &&
+	p4 shelve -i <<EOF
+Change: new
+Description:
+	$description
+Files:
+	$file
+EOF
+}
+
 # This is the tricky case where the shelved changelist base revision doesn't
 # match git-p4's idea of the base revision
 #
@@ -108,31 +134,51 @@ test_expect_success 'create shelved chan
 		p4 submit -d "change:foo" &&
 		p4 edit file1 &&
 		echo "bar" >>file1 &&
-		p4 shelve -i <<EOF &&
-Change: new
-Description:
-	Change to be unshelved
-Files:
-	//depot/file1
-EOF
+		shelve_one_file //depot/file1 &&
 		change=$(last_shelved_change) &&
-		p4 describe -S $change | grep -q "Change to be unshelved"
+		p4 describe -S $change >out.txt &&
+		grep -q "Change to be unshelved" out.txt
 	)
 '
 
-# Now try to unshelve it. git-p4 should refuse to do so.
+# Now try to unshelve it.
 test_expect_success 'try to unshelve the change' '
 	test_when_finished cleanup_git &&
 	(
 		change=$(last_shelved_change) &&
 		cd "$git" &&
-		test_must_fail git p4 unshelve $change 2>out.txt &&
-		grep -q "cannot unshelve" out.txt
+		git p4 unshelve $change >out.txt &&
+		grep -q "unshelved changelist $change" out.txt
 	)
 '
 
-test_expect_success 'kill p4d' '
-	kill_p4d
+# Specify the origin. Create 2 unrelated files, and check that
+# we only get the one in HEAD~, not the one in HEAD.
+
+test_expect_success 'unshelve specifying the origin' '
+	(
+		cd "$cli" &&
+		: >unrelated_file0 &&
+		p4 add unrelated_file0 &&
+		p4 submit -d "unrelated" &&
+		: >unrelated_file1 &&
+		p4 add unrelated_file1 &&
+		p4 submit -d "unrelated" &&
+		: >file_to_shelve &&
+		p4 add file_to_shelve &&
+		shelve_one_file //depot/file_to_shelve
+	) &&
+	test_when_finished cleanup_git &&
+	git p4 clone --dest="$git" //depot/@all &&
+	(
+		cd "$git" &&
+		change=$(last_shelved_change) &&
+		git p4 unshelve --origin HEAD~ $change &&
+		git checkout refs/remotes/p4-unshelved/$change &&
+		test_path_is_file unrelated_file0 &&
+		test_path_is_missing unrelated_file1 &&
+		test_path_is_file file_to_shelve
+	)
 '
 
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t9833-errors.sh 1.2.3+git2.25.1-1/git/t/t9833-errors.sh
--- 1.2.1+git2.18.0-1/git/t/t9833-errors.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t9833-errors.sh	2020-02-17 04:47:35.000000000 +0000
@@ -26,7 +26,9 @@ test_expect_success 'error handling' '
 	) &&
 	p4 passwd -P newpassword &&
 	(
-		P4PASSWD=badpassword test_must_fail git p4 clone //depot/foo 2>errmsg &&
+		P4PASSWD=badpassword &&
+		export P4PASSWD &&
+		test_must_fail git p4 clone //depot/foo 2>errmsg &&
 		grep -q "failure accessing depot.*P4PASSWD" errmsg
 	)
 '
@@ -43,36 +45,4 @@ test_expect_success 'ticket logged out'
 	)
 '
 
-test_expect_success 'create group with short ticket expiry' '
-	P4TICKETS="$cli/tickets" &&
-	echo "newpassword" | p4 login &&
-	p4_add_user short_expiry_user &&
-	p4 -u short_expiry_user passwd -P password &&
-	p4 group -i <<-EOF &&
-	Group: testgroup
-	Timeout: 3
-	Users: short_expiry_user
-	EOF
-
-	p4 users | grep short_expiry_user
-'
-
-test_expect_success 'git operation with expired ticket' '
-	P4TICKETS="$cli/tickets" &&
-	P4USER=short_expiry_user &&
-	echo "password" | p4 login &&
-	(
-		cd "$git" &&
-		git p4 sync &&
-		sleep 5 &&
-		test_must_fail git p4 sync 2>errmsg &&
-		grep "failure accessing depot" errmsg
-	)
-'
-
-test_expect_success 'kill p4d' '
-	kill_p4d
-'
-
-
 test_done
diff -pruN 1.2.1+git2.18.0-1/git/t/t9902-completion.sh 1.2.3+git2.25.1-1/git/t/t9902-completion.sh
--- 1.2.1+git2.18.0-1/git/t/t9902-completion.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t9902-completion.sh	2020-02-17 04:47:35.000000000 +0000
@@ -28,10 +28,10 @@ complete ()
 #
 # (2) A test makes sure that common subcommands are included in the
 #     completion for "git <TAB>", and a plumbing is excluded.  "add",
-#     "filter-branch" and "ls-files" are listed for this.
+#     "rebase" and "ls-files" are listed for this.
 
-GIT_TESTING_ALL_COMMAND_LIST='add checkout check-attr filter-branch ls-files'
-GIT_TESTING_PORCELAIN_COMMAND_LIST='add checkout filter-branch'
+GIT_TESTING_ALL_COMMAND_LIST='add checkout check-attr rebase ls-files'
+GIT_TESTING_PORCELAIN_COMMAND_LIST='add checkout rebase'
 
 . "$GIT_BUILD_DIR/contrib/completion/git-completion.bash"
 
@@ -378,7 +378,7 @@ test_expect_success '__gitdir - finds re
 '
 
 
-test_expect_success '__gitdir - returns error when cant find repo' '
+test_expect_success '__gitdir - returns error when cannot find repo' '
 	(
 		__git_dir="non-existing" &&
 		test_must_fail __gitdir >"$actual"
@@ -501,6 +501,42 @@ test_expect_success '__gitcomp - suffix'
 	EOF
 '
 
+test_expect_success '__gitcomp - ignore optional negative options' '
+	test_gitcomp "--" "--abc --def --no-one -- --no-two" <<-\EOF
+	--abc Z
+	--def Z
+	--no-one Z
+	--no-... Z
+	EOF
+'
+
+test_expect_success '__gitcomp - ignore/narrow optional negative options' '
+	test_gitcomp "--a" "--abc --abcdef --no-one -- --no-two" <<-\EOF
+	--abc Z
+	--abcdef Z
+	EOF
+'
+
+test_expect_success '__gitcomp - ignore/narrow optional negative options' '
+	test_gitcomp "--n" "--abc --def --no-one -- --no-two" <<-\EOF
+	--no-one Z
+	--no-... Z
+	EOF
+'
+
+test_expect_success '__gitcomp - expand all negative options' '
+	test_gitcomp "--no-" "--abc --def --no-one -- --no-two" <<-\EOF
+	--no-one Z
+	--no-two Z
+	EOF
+'
+
+test_expect_success '__gitcomp - expand/narrow all negative options' '
+	test_gitcomp "--no-o" "--abc --def --no-one -- --no-two" <<-\EOF
+	--no-one Z
+	EOF
+'
+
 test_expect_success '__gitcomp - doesnt fail because of invalid variable name' '
 	__gitcomp "$invalid_variable_name"
 '
@@ -909,7 +945,7 @@ test_expect_success 'setup for filtering
 	rm -f .git/FETCH_HEAD
 '
 
-test_expect_success '__git_refs - dont filter refs unless told so' '
+test_expect_success '__git_refs - do not filter refs unless told so' '
 	cat >expected <<-EOF &&
 	HEAD
 	master
@@ -1067,7 +1103,7 @@ test_expect_success '__git_complete_refs
 	master-in-other Z
 	EOF
 	(
-		cur=
+		cur= &&
 		__git_complete_refs --remote=other &&
 		print_comp
 	) &&
@@ -1086,7 +1122,7 @@ test_expect_success '__git_complete_refs
 	master-in-other Z
 	EOF
 	(
-		cur=
+		cur= &&
 		__git_complete_refs --track &&
 		print_comp
 	) &&
@@ -1213,7 +1249,7 @@ test_expect_success 'teardown after ref
 
 test_path_completion ()
 {
-	test $# = 2 || error "bug in the test script: not 2 parameters to test_path_completion"
+	test $# = 2 || BUG "not 2 parameters to test_path_completion"
 
 	local cur="$1" expected="$2"
 	echo "$expected" >expected &&
@@ -1221,7 +1257,7 @@ test_path_completion ()
 		# In the following tests calling this function we only
 		# care about how __git_complete_index_file() deals with
 		# unusual characters in path names.  By requesting only
-		# untracked files we dont have to bother adding any
+		# untracked files we do not have to bother adding any
 		# paths to the index in those tests.
 		__git_complete_index_file --others &&
 		print_comp
@@ -1242,7 +1278,7 @@ test_expect_success 'setup for path comp
 	   touch BS\\dir/DQ\"file \
 		 '$'separators\034in\035dir/sep\036in\037file''
 	then
-		test_set_prereq FUNNYNAMES
+		test_set_prereq FUNNIERNAMES
 	else
 		rm -rf BS\\dir '$'separators\034in\035dir''
 	fi
@@ -1284,7 +1320,7 @@ test_expect_success '__git_complete_inde
 	test_path_completion árvíztűrő/С "árvíztűrő/Сайн яваарай"
 '
 
-test_expect_success FUNNYNAMES \
+test_expect_success FUNNIERNAMES \
     '__git_complete_index_file - C-style escapes in ls-files output' '
 	test_path_completion BS \
 			     BS\\dir &&
@@ -1296,7 +1332,7 @@ test_expect_success FUNNYNAMES \
 			     BS\\dir/DQ\"file
 '
 
-test_expect_success FUNNYNAMES \
+test_expect_success FUNNIERNAMES \
     '__git_complete_index_file - \nnn-escaped characters in ls-files output' '
 	test_path_completion sep '$'separators\034in\035dir'' &&
 	test_path_completion '$'separators\034i'' \
@@ -1356,12 +1392,12 @@ test_expect_success 'basic' '
 	# built-in
 	grep -q "^add \$" out &&
 	# script
-	grep -q "^filter-branch \$" out &&
+	grep -q "^rebase \$" out &&
 	# plumbing
 	! grep -q "^ls-files \$" out &&
 
-	run_completion "git f" &&
-	! grep -q -v "^f" out
+	run_completion "git r" &&
+	! grep -q -v "^r" out
 '
 
 test_expect_success 'double dash "git" itself' '
@@ -1398,8 +1434,12 @@ test_expect_success 'double dash "git ch
 	--ignore-other-worktrees Z
 	--recurse-submodules Z
 	--progress Z
-	--no-track Z
-	--no-recurse-submodules Z
+	--guess Z
+	--no-guess Z
+	--no-... Z
+	--overlay Z
+	--pathspec-file-nul Z
+	--pathspec-from-file=Z
 	EOF
 '
 
@@ -1446,6 +1486,12 @@ test_expect_success 'git --help completi
 	test_completion "git --help core" "core-tutorial "
 '
 
+test_expect_success 'completion.commands removes multiple commands' '
+	test_config completion.commands "-cherry -mergetool" &&
+	git --list-cmds=list-mainporcelain,list-complete,config >out &&
+	! grep -E "^(cherry|mergetool)$" out
+'
+
 test_expect_success 'setup for integration tests' '
 	echo content >file1 &&
 	echo more >file2 &&
@@ -1479,8 +1525,8 @@ test_expect_success 'show completes all
 
 test_expect_success '<ref>: completes paths' '
 	test_completion "git show mytag:f" <<-\EOF
-	file1 Z
-	file2 Z
+	file1Z
+	file2Z
 	EOF
 '
 
@@ -1489,7 +1535,7 @@ test_expect_success 'complete tree filen
 	git add "name with spaces" &&
 	git commit -m spaces &&
 	test_completion "git show HEAD:nam" <<-\EOF
-	name with spaces Z
+	name with spacesZ
 	EOF
 '
 
@@ -1498,13 +1544,16 @@ test_expect_success 'complete tree filen
 	git add "name with \${meta}" &&
 	git commit -m meta &&
 	test_completion "git show HEAD:nam" <<-\EOF
-	name with ${meta} Z
-	name with spaces Z
+	name with ${meta}Z
+	name with spacesZ
 	EOF
 '
 
-test_expect_success 'send-email' '
-	test_completion "git send-email --cov" "--cover-letter " &&
+test_expect_success PERL 'send-email' '
+	test_completion "git send-email --cov" <<-\EOF &&
+	--cover-from-description=Z
+	--cover-letter Z
+	EOF
 	test_completion "git send-email ma" "master "
 '
 
@@ -1607,6 +1656,7 @@ test_expect_success 'completion used <cm
 test_expect_success 'completion without explicit _git_xxx function' '
 	test_completion "git version --" <<-\EOF
 	--build-options Z
+	--no-build-options Z
 	EOF
 '
 
@@ -1653,6 +1703,69 @@ do
 	'
 done
 
+test_expect_success 'git config - section' '
+	test_completion "git config br" <<-\EOF
+	branch.Z
+	browser.Z
+	EOF
+'
+
+test_expect_success 'git config - variable name' '
+	test_completion "git config log.d" <<-\EOF
+	log.date Z
+	log.decorate Z
+	EOF
+'
+
+test_expect_success 'git config - value' '
+	test_completion "git config color.pager " <<-\EOF
+	false Z
+	true Z
+	EOF
+'
+
+test_expect_success 'git -c - section' '
+	test_completion "git -c br" <<-\EOF
+	branch.Z
+	browser.Z
+	EOF
+'
+
+test_expect_success 'git -c - variable name' '
+	test_completion "git -c log.d" <<-\EOF
+	log.date=Z
+	log.decorate=Z
+	EOF
+'
+
+test_expect_success 'git -c - value' '
+	test_completion "git -c color.pager=" <<-\EOF
+	false Z
+	true Z
+	EOF
+'
+
+test_expect_success 'git clone --config= - section' '
+	test_completion "git clone --config=br" <<-\EOF
+	branch.Z
+	browser.Z
+	EOF
+'
+
+test_expect_success 'git clone --config= - variable name' '
+	test_completion "git clone --config=log.d" <<-\EOF
+	log.date=Z
+	log.decorate=Z
+	EOF
+'
+
+test_expect_success 'git clone --config= - value' '
+	test_completion "git clone --config=color.pager=" <<-\EOF
+	false Z
+	true Z
+	EOF
+'
+
 test_expect_success 'sourcing the completion script clears cached commands' '
 	__git_compute_all_commands &&
 	verbose test -n "$__git_all_commands" &&
@@ -1660,7 +1773,8 @@ test_expect_success 'sourcing the comple
 	verbose test -z "$__git_all_commands"
 '
 
-test_expect_success !GETTEXT_POISON 'sourcing the completion script clears cached merge strategies' '
+test_expect_success 'sourcing the completion script clears cached merge strategies' '
+	GIT_TEST_GETTEXT_POISON=false &&
 	__git_compute_merge_strategies &&
 	verbose test -n "$__git_merge_strategies" &&
 	. "$GIT_BUILD_DIR/contrib/completion/git-completion.bash" &&
diff -pruN 1.2.1+git2.18.0-1/git/t/t9903-bash-prompt.sh 1.2.3+git2.25.1-1/git/t/t9903-bash-prompt.sh
--- 1.2.1+git2.18.0-1/git/t/t9903-bash-prompt.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/t9903-bash-prompt.sh	2020-02-17 04:47:35.000000000 +0000
@@ -63,18 +63,15 @@ test_expect_success 'prompt - unborn bra
 	test_cmp expected "$actual"
 '
 
-repo_with_newline='repo
-with
-newline'
-
-if test_have_prereq !MINGW && mkdir "$repo_with_newline" 2>/dev/null
-then
-	test_set_prereq FUNNYNAMES
-else
+if test_have_prereq !FUNNYNAMES; then
 	say 'Your filesystem does not allow newlines in filenames.'
 fi
 
 test_expect_success FUNNYNAMES 'prompt - with newline in path' '
+    repo_with_newline="repo
+with
+newline" &&
+	mkdir "$repo_with_newline" &&
 	printf " (master)" >expected &&
 	git init "$repo_with_newline" &&
 	test_when_finished "rm -rf \"$repo_with_newline\"" &&
@@ -183,7 +180,7 @@ test_expect_success 'prompt - interactiv
 '
 
 test_expect_success 'prompt - rebase merge' '
-	printf " (b2|REBASE-m 1/3)" >expected &&
+	printf " (b2|REBASE-i 1/3)" >expected &&
 	git checkout b2 &&
 	test_when_finished "git checkout master" &&
 	test_must_fail git rebase --merge b1 b2 &&
@@ -214,8 +211,24 @@ test_expect_success 'prompt - merge' '
 
 test_expect_success 'prompt - cherry-pick' '
 	printf " (master|CHERRY-PICKING)" >expected &&
-	test_must_fail git cherry-pick b1 &&
-	test_when_finished "git reset --hard" &&
+	test_must_fail git cherry-pick b1 b1^ &&
+	test_when_finished "git cherry-pick --abort" &&
+	__git_ps1 >"$actual" &&
+	test_cmp expected "$actual" &&
+	git reset --merge &&
+	test_must_fail git rev-parse CHERRY_PICK_HEAD &&
+	__git_ps1 >"$actual" &&
+	test_cmp expected "$actual"
+'
+
+test_expect_success 'prompt - revert' '
+	printf " (master|REVERTING)" >expected &&
+	test_must_fail git revert b1^ b1 &&
+	test_when_finished "git revert --abort" &&
+	__git_ps1 >"$actual" &&
+	test_cmp expected "$actual" &&
+	git reset --merge &&
+	test_must_fail git rev-parse REVERT_HEAD &&
 	__git_ps1 >"$actual" &&
 	test_cmp expected "$actual"
 '
@@ -516,10 +529,9 @@ test_expect_success 'prompt - format str
 
 test_expect_success 'prompt - pc mode' '
 	printf "BEFORE: (\${__git_ps1_branch_name}):AFTER\\nmaster" >expected &&
-	printf "" >expected_output &&
 	(
 		__git_ps1 "BEFORE:" ":AFTER" >"$actual" &&
-		test_cmp expected_output "$actual" &&
+		test_must_be_empty "$actual" &&
 		printf "%s\\n%s" "$PS1" "${__git_ps1_branch_name}" >"$actual"
 	) &&
 	test_cmp expected "$actual"
@@ -529,7 +541,7 @@ test_expect_success 'prompt - bash color
 	printf "BEFORE: (${c_green}\${__git_ps1_branch_name}${c_clear}):AFTER\\nmaster" >expected &&
 	(
 		GIT_PS1_SHOWCOLORHINTS=y &&
-		__git_ps1 "BEFORE:" ":AFTER" >"$actual"
+		__git_ps1 "BEFORE:" ":AFTER" >"$actual" &&
 		printf "%s\\n%s" "$PS1" "${__git_ps1_branch_name}" >"$actual"
 	) &&
 	test_cmp expected "$actual"
@@ -715,13 +727,12 @@ test_expect_success 'prompt - hide if pw
 '
 
 test_expect_success 'prompt - hide if pwd ignored - env var set, config unset' '
-	printf "" >expected &&
 	(
 		cd ignored_dir &&
 		GIT_PS1_HIDE_IF_PWD_IGNORED=y &&
 		__git_ps1 >"$actual"
 	) &&
-	test_cmp expected "$actual"
+	test_must_be_empty "$actual"
 '
 
 test_expect_success 'prompt - hide if pwd ignored - env var set, config unset, pc mode' '
diff -pruN 1.2.1+git2.18.0-1/git/t/test-lib-functions.sh 1.2.3+git2.25.1-1/git/t/test-lib-functions.sh
--- 1.2.1+git2.18.0-1/git/t/test-lib-functions.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/test-lib-functions.sh	2020-02-17 04:47:35.000000000 +0000
@@ -42,6 +42,8 @@ test_decode_color () {
 		function name(n) {
 			if (n == 0) return "RESET";
 			if (n == 1) return "BOLD";
+			if (n == 2) return "FAINT";
+			if (n == 3) return "ITALIC";
 			if (n == 7) return "REVERSE";
 			if (n == 30) return "BLACK";
 			if (n == 31) return "RED";
@@ -114,6 +116,13 @@ remove_cr () {
 	tr '\015' Q | sed -e 's/Q$//'
 }
 
+# Generate an output of $1 bytes of all zeroes (NULs, not ASCII zeroes).
+# If $1 is 'infinity', output forever or until the receiving pipe stops reading,
+# whichever comes first.
+generate_zero_bytes () {
+	test-tool genzeros "$@"
+}
+
 # In some bourne shell implementations, the "unset" builtin returns
 # nonzero status when a variable to be unset was not set in the first
 # place.
@@ -219,9 +228,134 @@ test_commit () {
 # can be a tag pointing to the commit-to-merge.
 
 test_merge () {
+	label="$1" &&
+	shift &&
 	test_tick &&
-	git merge -m "$1" "$2" &&
-	git tag "$1"
+	git merge -m "$label" "$@" &&
+	git tag "$label"
+}
+
+# Efficiently create <nr> commits, each with a unique number (from 1 to <nr>
+# by default) in the commit message.
+#
+# Usage: test_commit_bulk [options] <nr>
+#   -C <dir>:
+#	Run all git commands in directory <dir>
+#   --ref=<n>:
+#	ref on which to create commits (default: HEAD)
+#   --start=<n>:
+#	number commit messages from <n> (default: 1)
+#   --message=<msg>:
+#	use <msg> as the commit mesasge (default: "commit %s")
+#   --filename=<fn>:
+#	modify <fn> in each commit (default: %s.t)
+#   --contents=<string>:
+#	place <string> in each file (default: "content %s")
+#   --id=<string>:
+#	shorthand to use <string> and %s in message, filename, and contents
+#
+# The message, filename, and contents strings are evaluated by printf, with the
+# first "%s" replaced by the current commit number. So you can do:
+#
+#   test_commit_bulk --filename=file --contents="modification %s"
+#
+# to have every commit touch the same file, but with unique content.
+#
+test_commit_bulk () {
+	tmpfile=.bulk-commit.input
+	indir=.
+	ref=HEAD
+	n=1
+	message='commit %s'
+	filename='%s.t'
+	contents='content %s'
+	while test $# -gt 0
+	do
+		case "$1" in
+		-C)
+			indir=$2
+			shift
+			;;
+		--ref=*)
+			ref=${1#--*=}
+			;;
+		--start=*)
+			n=${1#--*=}
+			;;
+		--message=*)
+			message=${1#--*=}
+			;;
+		--filename=*)
+			filename=${1#--*=}
+			;;
+		--contents=*)
+			contents=${1#--*=}
+			;;
+		--id=*)
+			message="${1#--*=} %s"
+			filename="${1#--*=}-%s.t"
+			contents="${1#--*=} %s"
+			;;
+		-*)
+			BUG "invalid test_commit_bulk option: $1"
+			;;
+		*)
+			break
+			;;
+		esac
+		shift
+	done
+	total=$1
+
+	add_from=
+	if git -C "$indir" rev-parse --quiet --verify "$ref"
+	then
+		add_from=t
+	fi
+
+	while test "$total" -gt 0
+	do
+		test_tick &&
+		echo "commit $ref"
+		printf 'author %s <%s> %s\n' \
+			"$GIT_AUTHOR_NAME" \
+			"$GIT_AUTHOR_EMAIL" \
+			"$GIT_AUTHOR_DATE"
+		printf 'committer %s <%s> %s\n' \
+			"$GIT_COMMITTER_NAME" \
+			"$GIT_COMMITTER_EMAIL" \
+			"$GIT_COMMITTER_DATE"
+		echo "data <<EOF"
+		printf "$message\n" $n
+		echo "EOF"
+		if test -n "$add_from"
+		then
+			echo "from $ref^0"
+			add_from=
+		fi
+		printf "M 644 inline $filename\n" $n
+		echo "data <<EOF"
+		printf "$contents\n" $n
+		echo "EOF"
+		echo
+		n=$((n + 1))
+		total=$((total - 1))
+	done >"$tmpfile"
+
+	git -C "$indir" \
+	    -c fastimport.unpacklimit=0 \
+	    fast-import <"$tmpfile" || return 1
+
+	# This will be left in place on failure, which may aid debugging.
+	rm -f "$tmpfile"
+
+	# If we updated HEAD, then be nice and update the index and working
+	# tree, too.
+	if test "$ref" = "HEAD"
+	then
+		git -C "$indir" checkout -f HEAD || return 1
+	fi
+
 }
 
 # This function helps systems where core.filemode=false is set.
@@ -300,6 +434,26 @@ test_unset_prereq () {
 }
 
 test_set_prereq () {
+	if test -n "$GIT_TEST_FAIL_PREREQS_INTERNAL"
+	then
+		case "$1" in
+		# The "!" case is handled below with
+		# test_unset_prereq()
+		!*)
+			;;
+		# (Temporary?) whitelist of things we can't easily
+		# pretend not to support
+		SYMLINKS)
+			;;
+		# Inspecting whether GIT_TEST_FAIL_PREREQS is on
+		# should be unaffected.
+		FAIL_PREREQS)
+			;;
+		*)
+			return
+		esac
+	fi
+
 	case "$1" in
 	!*)
 		test_unset_prereq "${1#!}"
@@ -416,19 +570,19 @@ test_declared_prereq () {
 test_verify_prereq () {
 	test -z "$test_prereq" ||
 	expr >/dev/null "$test_prereq" : '[A-Z0-9_,!]*$' ||
-	error "bug in the test script: '$test_prereq' does not look like a prereq"
+	BUG "'$test_prereq' does not look like a prereq"
 }
 
 test_expect_failure () {
 	test_start_
 	test "$#" = 3 && { test_prereq=$1; shift; } || test_prereq=
 	test "$#" = 2 ||
-	error "bug in the test script: not 2 or 3 parameters to test-expect-failure"
+	BUG "not 2 or 3 parameters to test-expect-failure"
 	test_verify_prereq
 	export test_prereq
 	if ! test_skip "$@"
 	then
-		say >&3 "checking known breakage: $2"
+		say >&3 "checking known breakage of $TEST_NUMBER.$test_count '$1': $2"
 		if test_run_ "$2" expecting_failure
 		then
 			test_known_broken_ok_ "$1"
@@ -443,12 +597,12 @@ test_expect_success () {
 	test_start_
 	test "$#" = 3 && { test_prereq=$1; shift; } || test_prereq=
 	test "$#" = 2 ||
-	error "bug in the test script: not 2 or 3 parameters to test-expect-success"
+	BUG "not 2 or 3 parameters to test-expect-success"
 	test_verify_prereq
 	export test_prereq
 	if ! test_skip "$@"
 	then
-		say >&3 "expecting success: $2"
+		say >&3 "expecting success of $TEST_NUMBER.$test_count '$1': $2"
 		if test_run_ "$2"
 		then
 			test_ok_ "$1"
@@ -470,7 +624,7 @@ test_expect_success () {
 test_external () {
 	test "$#" = 4 && { test_prereq=$1; shift; } || test_prereq=
 	test "$#" = 3 ||
-	error >&5 "bug in the test script: not 3 or 4 parameters to test_external"
+	BUG "not 3 or 4 parameters to test_external"
 	descr="$1"
 	shift
 	test_verify_prereq
@@ -565,6 +719,14 @@ test_path_is_dir () {
 	fi
 }
 
+test_path_exists () {
+	if ! test -e "$1"
+	then
+		echo "Path $1 doesn't exist. $2"
+		false
+	fi
+}
+
 # Check if the directory exists and is empty as expected, barf otherwise.
 test_dir_is_empty () {
 	test_path_is_dir "$1" &&
@@ -576,6 +738,15 @@ test_dir_is_empty () {
 	fi
 }
 
+# Check if the file exists and has a size greater than zero
+test_file_not_empty () {
+	if ! test -s "$1"
+	then
+		echo "'$1' is not a non-empty file."
+		false
+	fi
+}
+
 test_path_is_missing () {
 	if test -e "$1"
 	then
@@ -603,7 +774,7 @@ test_path_is_missing () {
 test_line_count () {
 	if test $# != 3
 	then
-		error "bug in the test script: not 3 parameters to test_line_count"
+		BUG "not 3 parameters to test_line_count"
 	elif ! test $(wc -l <"$3") "$1" "$2"
 	then
 		echo "test_line_count: line count for $3 !$1 $2"
@@ -737,6 +908,29 @@ test_cmp() {
 	$GIT_TEST_CMP "$@"
 }
 
+# Check that the given config key has the expected value.
+#
+#    test_cmp_config [-C <dir>] <expected-value>
+#                    [<git-config-options>...] <config-key>
+#
+# for example to check that the value of core.bar is foo
+#
+#    test_cmp_config foo core.bar
+#
+test_cmp_config() {
+	local GD &&
+	if test "$1" = "-C"
+	then
+		shift &&
+		GD="-C $1" &&
+		shift
+	fi &&
+	printf "%s\n" "$1" >expect.config &&
+	shift &&
+	git $GD config "$@" >actual.config &&
+	test_cmp expect.config actual.config
+}
+
 # test_cmp_bin - helper to compare binary files
 
 test_cmp_bin() {
@@ -745,31 +939,30 @@ test_cmp_bin() {
 
 # Use this instead of test_cmp to compare files that contain expected and
 # actual output from git commands that can be translated.  When running
-# under GETTEXT_POISON this pretends that the command produced expected
+# under GIT_TEST_GETTEXT_POISON this pretends that the command produced expected
 # results.
 test_i18ncmp () {
-	test -n "$GETTEXT_POISON" || test_cmp "$@"
+	! test_have_prereq C_LOCALE_OUTPUT || test_cmp "$@"
 }
 
 # Use this instead of "grep expected-string actual" to see if the
 # output from a git command that can be translated either contains an
 # expected string, or does not contain an unwanted one.  When running
-# under GETTEXT_POISON this pretends that the command produced expected
+# under GIT_TEST_GETTEXT_POISON this pretends that the command produced expected
 # results.
 test_i18ngrep () {
 	eval "last_arg=\${$#}"
 
 	test -f "$last_arg" ||
-	error "bug in the test script: test_i18ngrep requires a file" \
-	      "to read as the last parameter"
+	BUG "test_i18ngrep requires a file to read as the last parameter"
 
 	if test $# -lt 2 ||
 	   { test "x!" = "x$1" && test $# -lt 3 ; }
 	then
-		error "bug in the test script: too few parameters to test_i18ngrep"
+		BUG "too few parameters to test_i18ngrep"
 	fi
 
-	if test -n "$GETTEXT_POISON"
+	if test_have_prereq !C_LOCALE_OUTPUT
 	then
 		# pretend success
 		return 0
@@ -819,11 +1012,51 @@ test_must_be_empty () {
 	fi
 }
 
-# Tests that its two parameters refer to the same revision
+# Tests that its two parameters refer to the same revision, or if '!' is
+# provided first, that its other two parameters refer to different
+# revisions.
 test_cmp_rev () {
-	git rev-parse --verify "$1" >expect.rev &&
-	git rev-parse --verify "$2" >actual.rev &&
-	test_cmp expect.rev actual.rev
+	local op='=' wrong_result=different
+
+	if test $# -ge 1 && test "x$1" = 'x!'
+	then
+	    op='!='
+	    wrong_result='the same'
+	    shift
+	fi
+	if test $# != 2
+	then
+		error "bug in the test script: test_cmp_rev requires two revisions, but got $#"
+	else
+		local r1 r2
+		r1=$(git rev-parse --verify "$1") &&
+		r2=$(git rev-parse --verify "$2") || return 1
+
+		if ! test "$r1" "$op" "$r2"
+		then
+			cat >&4 <<-EOF
+			error: two revisions point to $wrong_result objects:
+			  '$1': $r1
+			  '$2': $r2
+			EOF
+			return 1
+		fi
+	fi
+}
+
+# Compare paths respecting core.ignoreCase
+test_cmp_fspath () {
+	if test "x$1" = "x$2"
+	then
+		return 0
+	fi
+
+	if test true != "$(git config --get --type=bool core.ignorecase)"
+	then
+		return 1
+	fi
+
+	test "x$(echo "$1" | tr A-Z a-z)" =  "x$(echo "$2" | tr A-Z a-z)"
 }
 
 # Print a sequence of integers in increasing order, either with
@@ -838,7 +1071,7 @@ test_seq () {
 	case $# in
 	1)	set 1 "$@" ;;
 	2)	;;
-	*)	error "bug in the test script: not 1 or 2 parameters to test_seq" ;;
+	*)	BUG "not 1 or 2 parameters to test_seq" ;;
 	esac
 	test_seq_counter__=$1
 	while test "$test_seq_counter__" -le "$2"
@@ -876,21 +1109,50 @@ test_when_finished () {
 	# doing so on Bash is better than nothing (the test will
 	# silently pass on other shells).
 	test "${BASH_SUBSHELL-0}" = 0 ||
-	error "bug in test script: test_when_finished does nothing in a subshell"
+	BUG "test_when_finished does nothing in a subshell"
 	test_cleanup="{ $*
 		} && (exit \"\$eval_ret\"); eval_ret=\$?; $test_cleanup"
 }
 
+# This function can be used to schedule some commands to be run
+# unconditionally at the end of the test script, e.g. to stop a daemon:
+#
+#	test_expect_success 'test git daemon' '
+#		git daemon &
+#		daemon_pid=$! &&
+#		test_atexit 'kill $daemon_pid' &&
+#		hello world
+#	'
+#
+# The commands will be executed before the trash directory is removed,
+# i.e. the atexit commands will still be able to access any pidfiles or
+# socket files.
+#
+# Note that these commands will be run even when a test script run
+# with '--immediate' fails.  Be careful with your atexit commands to
+# minimize any changes to the failed state.
+
+test_atexit () {
+	# We cannot detect when we are in a subshell in general, but by
+	# doing so on Bash is better than nothing (the test will
+	# silently pass on other shells).
+	test "${BASH_SUBSHELL-0}" = 0 ||
+	error "bug in test script: test_atexit does nothing in a subshell"
+	test_atexit_cleanup="{ $*
+		} && (exit \"\$eval_ret\"); eval_ret=\$?; $test_atexit_cleanup"
+}
+
 # Most tests can use the created repository, but some may need to create more.
 # Usage: test_create_repo <directory>
 test_create_repo () {
 	test "$#" = 1 ||
-	error "bug in the test script: not 1 parameter to test-create-repo"
+	BUG "not 1 parameter to test-create-repo"
 	repo="$1"
 	mkdir -p "$repo"
 	(
 		cd "$repo" || error "Cannot setup test environment"
-		"$GIT_EXEC_PATH/git-init" "--template=$GIT_BUILD_DIR/templates/blt/" >&3 2>&4 ||
+		"${GIT_TEST_INSTALLED:-$GIT_EXEC_PATH}/git$X" init \
+			"--template=$GIT_BUILD_DIR/templates/blt/" >&3 2>&4 ||
 		error "cannot run git init -- have you built things yet?"
 		mv .git/hooks .git/hooks-disabled
 	) || exit
@@ -924,62 +1186,48 @@ perl () {
 	command "$PERL_PATH" "$@" 2>&7
 } 7>&2 2>&4
 
-# Is the value one of the various ways to spell a boolean true/false?
-test_normalize_bool () {
-	git -c magic.variable="$1" config --bool magic.variable 2>/dev/null
-}
-
-# Given a variable $1, normalize the value of it to one of "true",
-# "false", or "auto" and store the result to it.
-#
-#     test_tristate GIT_TEST_HTTPD
-#
-# A variable set to an empty string is set to 'false'.
-# A variable set to 'false' or 'auto' keeps its value.
-# Anything else is set to 'true'.
-# An unset variable defaults to 'auto'.
-#
-# The last rule is to allow people to set the variable to an empty
-# string and export it to decline testing the particular feature
-# for versions both before and after this change.  We used to treat
-# both unset and empty variable as a signal for "do not test" and
-# took any non-empty string as "please test".
-
-test_tristate () {
-	if eval "test x\"\${$1+isset}\" = xisset"
-	then
-		# explicitly set
-		eval "
-			case \"\$$1\" in
-			'')	$1=false ;;
-			auto)	;;
-			*)	$1=\$(test_normalize_bool \$$1 || echo true) ;;
-			esac
-		"
-	else
-		eval "$1=auto"
+# Given the name of an environment variable with a bool value, normalize
+# its value to a 0 (true) or 1 (false or empty string) return code.
+#
+#   test_bool_env GIT_TEST_HTTPD <default-value>
+#
+# Return with code corresponding to the given default value if the variable
+# is unset.
+# Abort the test script if either the value of the variable or the default
+# are not valid bool values.
+
+test_bool_env () {
+	if test $# != 2
+	then
+		BUG "test_bool_env requires two parameters (variable name and default value)"
 	fi
+
+	git env--helper --type=bool --default="$2" --exit-code "$1"
+	ret=$?
+	case $ret in
+	0|1)	# unset or valid bool value
+		;;
+	*)	# invalid bool value or something unexpected
+		error >&7 "test_bool_env requires bool values both for \$$1 and for the default fallback"
+		;;
+	esac
+	return $ret
 }
 
 # Exit the test suite, either by skipping all remaining tests or by
-# exiting with an error. If "$1" is "auto", we then we assume we were
-# opportunistically trying to set up some tests and we skip. If it is
-# "true", then we report a failure.
+# exiting with an error. If our prerequisite variable $1 falls back
+# on a default assume we were opportunistically trying to set up some
+# tests and we skip. If it is explicitly "true", then we report a failure.
 #
 # The error/skip message should be given by $2.
 #
 test_skip_or_die () {
-	case "$1" in
-	auto)
+	if ! test_bool_env "$1" false
+	then
 		skip_all=$2
 		test_done
-		;;
-	true)
-		error "$2"
-		;;
-	*)
-		error "BUG: test tristate is '$1' (real error: $2)"
-	esac
+	fi
+	error "$2"
 }
 
 # The following mingw_* functions obey POSIX shell syntax, but are actually
@@ -1147,3 +1395,124 @@ depacketize () {
 		}
 	'
 }
+
+# Converts base-16 data into base-8. The output is given as a sequence of
+# escaped octals, suitable for consumption by 'printf'.
+hex2oct () {
+	perl -ne 'printf "\\%03o", hex for /../g'
+}
+
+# Set the hash algorithm in use to $1.  Only useful when testing the testsuite.
+test_set_hash () {
+	test_hash_algo="$1"
+}
+
+# Detect the hash algorithm in use.
+test_detect_hash () {
+	# Currently we only support SHA-1, but in the future this function will
+	# actually detect the algorithm in use.
+	test_hash_algo='sha1'
+}
+
+# Load common hash metadata and common placeholder object IDs for use with
+# test_oid.
+test_oid_init () {
+	test -n "$test_hash_algo" || test_detect_hash &&
+	test_oid_cache <"$TEST_DIRECTORY/oid-info/hash-info" &&
+	test_oid_cache <"$TEST_DIRECTORY/oid-info/oid"
+}
+
+# Load key-value pairs from stdin suitable for use with test_oid.  Blank lines
+# and lines starting with "#" are ignored.  Keys must be shell identifier
+# characters.
+#
+# Examples:
+# rawsz sha1:20
+# rawsz sha256:32
+test_oid_cache () {
+	local tag rest k v &&
+
+	{ test -n "$test_hash_algo" || test_detect_hash; } &&
+	while read tag rest
+	do
+		case $tag in
+		\#*)
+			continue;;
+		?*)
+			# non-empty
+			;;
+		*)
+			# blank line
+			continue;;
+		esac &&
+
+		k="${rest%:*}" &&
+		v="${rest#*:}" &&
+
+		if ! expr "$k" : '[a-z0-9][a-z0-9]*$' >/dev/null
+		then
+			BUG 'bad hash algorithm'
+		fi &&
+		eval "test_oid_${k}_$tag=\"\$v\""
+	done
+}
+
+# Look up a per-hash value based on a key ($1).  The value must have been loaded
+# by test_oid_init or test_oid_cache.
+test_oid () {
+	local var="test_oid_${test_hash_algo}_$1" &&
+
+	# If the variable is unset, we must be missing an entry for this
+	# key-hash pair, so exit with an error.
+	if eval "test -z \"\${$var+set}\""
+	then
+		BUG "undefined key '$1'"
+	fi &&
+	eval "printf '%s' \"\${$var}\""
+}
+
+# Insert a slash into an object ID so it can be used to reference a location
+# under ".git/objects".  For example, "deadbeef..." becomes "de/adbeef..".
+test_oid_to_path () {
+	local basename=${1#??}
+	echo "${1%$basename}/$basename"
+}
+
+# Choose a port number based on the test script's number and store it in
+# the given variable name, unless that variable already contains a number.
+test_set_port () {
+	local var=$1 port
+
+	if test $# -ne 1 || test -z "$var"
+	then
+		BUG "test_set_port requires a variable name"
+	fi
+
+	eval port=\$$var
+	case "$port" in
+	"")
+		# No port is set in the given env var, use the test
+		# number as port number instead.
+		# Remove not only the leading 't', but all leading zeros
+		# as well, so the arithmetic below won't (mis)interpret
+		# a test number like '0123' as an octal value.
+		port=${this_test#${this_test%%[1-9]*}}
+		if test "${port:-0}" -lt 1024
+		then
+			# root-only port, use a larger one instead.
+			port=$(($port + 10000))
+		fi
+		;;
+	*[!0-9]*|0*)
+		error >&7 "invalid port number: $port"
+		;;
+	*)
+		# The user has specified the port.
+		;;
+	esac
+
+	# Make sure that parallel '--stress' test jobs get different
+	# ports.
+	port=$(($port + ${GIT_TEST_STRESS_JOB_NR:-0}))
+	eval $var=$port
+}
diff -pruN 1.2.1+git2.18.0-1/git/t/test-lib.sh 1.2.3+git2.25.1-1/git/t/test-lib.sh
--- 1.2.1+git2.18.0-1/git/t/test-lib.sh	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/t/test-lib.sh	2020-02-17 04:47:35.000000000 +0000
@@ -49,31 +49,279 @@ export ASAN_OPTIONS
 : ${LSAN_OPTIONS=abort_on_error=1}
 export LSAN_OPTIONS
 
+if test ! -f "$GIT_BUILD_DIR"/GIT-BUILD-OPTIONS
+then
+	echo >&2 'error: GIT-BUILD-OPTIONS missing (has Git been built?).'
+	exit 1
+fi
+. "$GIT_BUILD_DIR"/GIT-BUILD-OPTIONS
+export PERL_PATH SHELL_PATH
+
+# Disallow the use of abbreviated options in the test suite by default
+if test -z "${GIT_TEST_DISALLOW_ABBREVIATED_OPTIONS}"
+then
+	GIT_TEST_DISALLOW_ABBREVIATED_OPTIONS=true
+	export GIT_TEST_DISALLOW_ABBREVIATED_OPTIONS
+fi
+
 ################################################################
 # It appears that people try to run tests without building...
-"$GIT_BUILD_DIR/git" >/dev/null
+"${GIT_TEST_INSTALLED:-$GIT_BUILD_DIR}/git$X" >/dev/null
 if test $? != 1
 then
-	echo >&2 'error: you do not seem to have built git yet.'
+	if test -n "$GIT_TEST_INSTALLED"
+	then
+		echo >&2 "error: there is no working Git at '$GIT_TEST_INSTALLED'"
+	else
+		echo >&2 'error: you do not seem to have built git yet.'
+	fi
 	exit 1
 fi
 
-. "$GIT_BUILD_DIR"/GIT-BUILD-OPTIONS
-export PERL_PATH SHELL_PATH
+# Parse options while taking care to leave $@ intact, so we will still
+# have all the original command line options when executing the test
+# script again for '--tee' and '--verbose-log' below.
+store_arg_to=
+prev_opt=
+for opt
+do
+	if test -n "$store_arg_to"
+	then
+		eval $store_arg_to=\$opt
+		store_arg_to=
+		prev_opt=
+		continue
+	fi
+
+	case "$opt" in
+	-d|--d|--de|--deb|--debu|--debug)
+		debug=t ;;
+	-i|--i|--im|--imm|--imme|--immed|--immedi|--immedia|--immediat|--immediate)
+		immediate=t ;;
+	-l|--l|--lo|--lon|--long|--long-|--long-t|--long-te|--long-tes|--long-test|--long-tests)
+		GIT_TEST_LONG=t; export GIT_TEST_LONG ;;
+	-r)
+		store_arg_to=run_list
+		;;
+	--run=*)
+		run_list=${opt#--*=} ;;
+	-h|--h|--he|--hel|--help)
+		help=t ;;
+	-v|--v|--ve|--ver|--verb|--verbo|--verbos|--verbose)
+		verbose=t ;;
+	--verbose-only=*)
+		verbose_only=${opt#--*=}
+		;;
+	-q|--q|--qu|--qui|--quie|--quiet)
+		# Ignore --quiet under a TAP::Harness. Saying how many tests
+		# passed without the ok/not ok details is always an error.
+		test -z "$HARNESS_ACTIVE" && quiet=t ;;
+	--with-dashes)
+		with_dashes=t ;;
+	--no-bin-wrappers)
+		no_bin_wrappers=t ;;
+	--no-color)
+		color= ;;
+	--va|--val|--valg|--valgr|--valgri|--valgrin|--valgrind)
+		valgrind=memcheck
+		tee=t
+		;;
+	--valgrind=*)
+		valgrind=${opt#--*=}
+		tee=t
+		;;
+	--valgrind-only=*)
+		valgrind_only=${opt#--*=}
+		tee=t
+		;;
+	--tee)
+		tee=t ;;
+	--root=*)
+		root=${opt#--*=} ;;
+	--chain-lint)
+		GIT_TEST_CHAIN_LINT=1 ;;
+	--no-chain-lint)
+		GIT_TEST_CHAIN_LINT=0 ;;
+	-x)
+		trace=t ;;
+	-V|--verbose-log)
+		verbose_log=t
+		tee=t
+		;;
+	--write-junit-xml)
+		write_junit_xml=t
+		;;
+	--stress)
+		stress=t ;;
+	--stress=*)
+		echo "error: --stress does not accept an argument: '$opt'" >&2
+		echo "did you mean --stress-jobs=${opt#*=} or --stress-limit=${opt#*=}?" >&2
+		exit 1
+		;;
+	--stress-jobs=*)
+		stress=t;
+		stress=${opt#--*=}
+		case "$stress" in
+		*[!0-9]*|0*|"")
+			echo "error: --stress-jobs=<N> requires the number of jobs to run" >&2
+			exit 1
+			;;
+		*)	# Good.
+			;;
+		esac
+		;;
+	--stress-limit=*)
+		stress=t;
+		stress_limit=${opt#--*=}
+		case "$stress_limit" in
+		*[!0-9]*|0*|"")
+			echo "error: --stress-limit=<N> requires the number of repetitions" >&2
+			exit 1
+			;;
+		*)	# Good.
+			;;
+		esac
+		;;
+	*)
+		echo "error: unknown test option '$opt'" >&2; exit 1 ;;
+	esac
+
+	prev_opt=$opt
+done
+if test -n "$store_arg_to"
+then
+	echo "error: $prev_opt requires an argument" >&2
+	exit 1
+fi
+
+if test -n "$valgrind_only"
+then
+	test -z "$valgrind" && valgrind=memcheck
+	test -z "$verbose" && verbose_only="$valgrind_only"
+elif test -n "$valgrind"
+then
+	test -z "$verbose_log" && verbose=t
+fi
+
+if test -n "$stress"
+then
+	verbose=t
+	trace=t
+	immediate=t
+fi
+
+TEST_STRESS_JOB_SFX="${GIT_TEST_STRESS_JOB_NR:+.stress-$GIT_TEST_STRESS_JOB_NR}"
+TEST_NAME="$(basename "$0" .sh)"
+TEST_NUMBER="${TEST_NAME%%-*}"
+TEST_NUMBER="${TEST_NUMBER#t}"
+TEST_RESULTS_DIR="$TEST_OUTPUT_DIRECTORY/test-results"
+TEST_RESULTS_BASE="$TEST_RESULTS_DIR/$TEST_NAME$TEST_STRESS_JOB_SFX"
+TRASH_DIRECTORY="trash directory.$TEST_NAME$TEST_STRESS_JOB_SFX"
+test -n "$root" && TRASH_DIRECTORY="$root/$TRASH_DIRECTORY"
+case "$TRASH_DIRECTORY" in
+/*) ;; # absolute path is good
+ *) TRASH_DIRECTORY="$TEST_OUTPUT_DIRECTORY/$TRASH_DIRECTORY" ;;
+esac
+
+# If --stress was passed, run this test repeatedly in several parallel loops.
+if test "$GIT_TEST_STRESS_STARTED" = "done"
+then
+	: # Don't stress test again.
+elif test -n "$stress"
+then
+	if test "$stress" != t
+	then
+		job_count=$stress
+	elif test -n "$GIT_TEST_STRESS_LOAD"
+	then
+		job_count="$GIT_TEST_STRESS_LOAD"
+	elif job_count=$(getconf _NPROCESSORS_ONLN 2>/dev/null) &&
+	     test -n "$job_count"
+	then
+		job_count=$((2 * $job_count))
+	else
+		job_count=8
+	fi
+
+	mkdir -p "$TEST_RESULTS_DIR"
+	stressfail="$TEST_RESULTS_BASE.stress-failed"
+	rm -f "$stressfail"
+
+	stress_exit=0
+	trap '
+		kill $job_pids 2>/dev/null
+		wait
+		stress_exit=1
+	' TERM INT HUP
+
+	job_pids=
+	job_nr=0
+	while test $job_nr -lt "$job_count"
+	do
+		(
+			GIT_TEST_STRESS_STARTED=done
+			GIT_TEST_STRESS_JOB_NR=$job_nr
+			export GIT_TEST_STRESS_STARTED GIT_TEST_STRESS_JOB_NR
+
+			trap '
+				kill $test_pid 2>/dev/null
+				wait
+				exit 1
+			' TERM INT
+
+			cnt=1
+			while ! test -e "$stressfail" &&
+			      { test -z "$stress_limit" ||
+				test $cnt -le $stress_limit ; }
+			do
+				$TEST_SHELL_PATH "$0" "$@" >"$TEST_RESULTS_BASE.stress-$job_nr.out" 2>&1 &
+				test_pid=$!
+
+				if wait $test_pid
+				then
+					printf "OK   %2d.%d\n" $GIT_TEST_STRESS_JOB_NR $cnt
+				else
+					echo $GIT_TEST_STRESS_JOB_NR >>"$stressfail"
+					printf "FAIL %2d.%d\n" $GIT_TEST_STRESS_JOB_NR $cnt
+				fi
+				cnt=$(($cnt + 1))
+			done
+		) &
+		job_pids="$job_pids $!"
+		job_nr=$(($job_nr + 1))
+	done
+
+	wait
+
+	if test -f "$stressfail"
+	then
+		stress_exit=1
+		echo "Log(s) of failed test run(s):"
+		for failed_job_nr in $(sort -n "$stressfail")
+		do
+			echo "Contents of '$TEST_RESULTS_BASE.stress-$failed_job_nr.out':"
+			cat "$TEST_RESULTS_BASE.stress-$failed_job_nr.out"
+		done
+		rm -rf "$TRASH_DIRECTORY.stress-failed"
+		# Move the last one.
+		mv "$TRASH_DIRECTORY.stress-$failed_job_nr" "$TRASH_DIRECTORY.stress-failed"
+	fi
+
+	exit $stress_exit
+fi
 
 # if --tee was passed, write the output not only to the terminal, but
 # additionally to the file test-results/$BASENAME.out, too.
-case "$GIT_TEST_TEE_STARTED, $* " in
-done,*)
-	# do not redirect again
-	;;
-*' --tee '*|*' --va'*|*' --verbose-log '*)
-	mkdir -p "$TEST_OUTPUT_DIRECTORY/test-results"
-	BASE="$TEST_OUTPUT_DIRECTORY/test-results/$(basename "$0" .sh)"
+if test "$GIT_TEST_TEE_STARTED" = "done"
+then
+	: # do not redirect again
+elif test -n "$tee"
+then
+	mkdir -p "$TEST_RESULTS_DIR"
 
 	# Make this filename available to the sub-process in case it is using
 	# --verbose-log.
-	GIT_TEST_TEE_OUTPUT_FILE=$BASE.out
+	GIT_TEST_TEE_OUTPUT_FILE=$TEST_RESULTS_BASE.out
 	export GIT_TEST_TEE_OUTPUT_FILE
 
 	# Truncate before calling "tee -a" to get rid of the results
@@ -81,11 +329,38 @@ done,*)
 	>"$GIT_TEST_TEE_OUTPUT_FILE"
 
 	(GIT_TEST_TEE_STARTED=done ${TEST_SHELL_PATH} "$0" "$@" 2>&1;
-	 echo $? >"$BASE.exit") | tee -a "$GIT_TEST_TEE_OUTPUT_FILE"
-	test "$(cat "$BASE.exit")" = 0
+	 echo $? >"$TEST_RESULTS_BASE.exit") | tee -a "$GIT_TEST_TEE_OUTPUT_FILE"
+	test "$(cat "$TEST_RESULTS_BASE.exit")" = 0
 	exit
-	;;
-esac
+fi
+
+if test -n "$trace" && test -n "$test_untraceable"
+then
+	# '-x' tracing requested, but this test script can't be reliably
+	# traced, unless it is run with a Bash version supporting
+	# BASH_XTRACEFD (introduced in Bash v4.1).
+	#
+	# Perform this version check _after_ the test script was
+	# potentially re-executed with $TEST_SHELL_PATH for '--tee' or
+	# '--verbose-log', so the right shell is checked and the
+	# warning is issued only once.
+	if test -n "$BASH_VERSION" && eval '
+	     test ${BASH_VERSINFO[0]} -gt 4 || {
+	       test ${BASH_VERSINFO[0]} -eq 4 &&
+	       test ${BASH_VERSINFO[1]} -ge 1
+	     }
+	   '
+	then
+		: Executed by a Bash version supporting BASH_XTRACEFD.  Good.
+	else
+		echo >&2 "warning: ignoring -x; '$0' is untraceable without BASH_XTRACEFD"
+		trace=
+	fi
+fi
+if test -n "$trace" && test -z "$verbose_log"
+then
+	verbose=t
+fi
 
 # For repeatability, reset the environment to known value.
 # TERM is sanitized below, after saving color control sequences.
@@ -95,6 +370,16 @@ PAGER=cat
 TZ=UTC
 export LANG LC_ALL PAGER TZ
 EDITOR=:
+
+# GIT_TEST_GETTEXT_POISON should not influence git commands executed
+# during initialization of test-lib and the test repo. Back it up,
+# unset and then restore after initialization is finished.
+if test -n "$GIT_TEST_GETTEXT_POISON"
+then
+	GIT_TEST_GETTEXT_POISON_ORIG=$GIT_TEST_GETTEXT_POISON
+	unset GIT_TEST_GETTEXT_POISON
+fi
+
 # A call to "unset" with no arguments causes at least Solaris 10
 # /usr/xpg4/bin/sh and /bin/ksh to bail out.  So keep the unsets
 # deriving from the command substitution clustered with the other
@@ -119,9 +404,13 @@ unset VISUAL EMAIL LANGUAGE COLUMNS $("$
 unset XDG_CACHE_HOME
 unset XDG_CONFIG_HOME
 unset GITPERLLIB
-GIT_AUTHOR_EMAIL=author@example.com
+TEST_AUTHOR_LOCALNAME=author
+TEST_AUTHOR_DOMAIN=example.com
+GIT_AUTHOR_EMAIL=${TEST_AUTHOR_LOCALNAME}@${TEST_AUTHOR_DOMAIN}
 GIT_AUTHOR_NAME='A U Thor'
-GIT_COMMITTER_EMAIL=committer@example.com
+TEST_COMMITTER_LOCALNAME=committer
+TEST_COMMITTER_DOMAIN=example.com
+GIT_COMMITTER_EMAIL=${TEST_COMMITTER_LOCALNAME}@${TEST_COMMITTER_DOMAIN}
 GIT_COMMITTER_NAME='C O Mitter'
 GIT_MERGE_VERBOSITY=5
 GIT_MERGE_AUTOEDIT=no
@@ -134,15 +423,46 @@ export EDITOR
 GIT_TRACE_BARE=1
 export GIT_TRACE_BARE
 
-if test -n "${TEST_GIT_INDEX_VERSION:+isset}"
+check_var_migration () {
+	# the warnings and hints given from this helper depends
+	# on end-user settings, which will disrupt the self-test
+	# done on the test framework itself.
+	case "$GIT_TEST_FRAMEWORK_SELFTEST" in
+	t)	return ;;
+	esac
+
+	old_name=$1 new_name=$2
+	eval "old_isset=\${${old_name}:+isset}"
+	eval "new_isset=\${${new_name}:+isset}"
+
+	case "$old_isset,$new_isset" in
+	isset,)
+		echo >&2 "warning: $old_name is now $new_name"
+		echo >&2 "hint: set $new_name too during the transition period"
+		eval "$new_name=\$$old_name"
+		;;
+	isset,isset)
+		# do this later
+		# echo >&2 "warning: $old_name is now $new_name"
+		# echo >&2 "hint: remove $old_name"
+		;;
+	esac
+}
+
+check_var_migration GIT_FSMONITOR_TEST GIT_TEST_FSMONITOR
+check_var_migration TEST_GIT_INDEX_VERSION GIT_TEST_INDEX_VERSION
+check_var_migration GIT_FORCE_PRELOAD_TEST GIT_TEST_PRELOAD_INDEX
+
+# Use specific version of the index file format
+if test -n "${GIT_TEST_INDEX_VERSION:+isset}"
 then
-	GIT_INDEX_VERSION="$TEST_GIT_INDEX_VERSION"
+	GIT_INDEX_VERSION="$GIT_TEST_INDEX_VERSION"
 	export GIT_INDEX_VERSION
 fi
 
 # Add libc MALLOC and MALLOC_PERTURB test
 # only if we are not executing the test with valgrind
-if expr " $GIT_TEST_OPTS " : ".* --valgrind " >/dev/null ||
+if test -n "$valgrind" ||
    test -n "$TEST_NO_MALLOC_CHECK"
 then
 	setup_malloc_check () {
@@ -193,6 +513,9 @@ EMPTY_BLOB=e69de29bb2d1d6434b8b29ae775ad
 LF='
 '
 
+# Single quote
+SQ=\'
+
 # UTF-8 ZERO WIDTH NON-JOINER, which HFS+ ignores
 # when case-folding filenames
 u200c=$(printf '\342\200\214')
@@ -213,100 +536,6 @@ test "x$TERM" != "xdumb" && (
 	) &&
 	color=t
 
-while test "$#" -ne 0
-do
-	case "$1" in
-	-d|--d|--de|--deb|--debu|--debug)
-		debug=t; shift ;;
-	-i|--i|--im|--imm|--imme|--immed|--immedi|--immedia|--immediat|--immediate)
-		immediate=t; shift ;;
-	-l|--l|--lo|--lon|--long|--long-|--long-t|--long-te|--long-tes|--long-test|--long-tests)
-		GIT_TEST_LONG=t; export GIT_TEST_LONG; shift ;;
-	-r)
-		shift; test "$#" -ne 0 || {
-			echo 'error: -r requires an argument' >&2;
-			exit 1;
-		}
-		run_list=$1; shift ;;
-	--run=*)
-		run_list=${1#--*=}; shift ;;
-	-h|--h|--he|--hel|--help)
-		help=t; shift ;;
-	-v|--v|--ve|--ver|--verb|--verbo|--verbos|--verbose)
-		verbose=t; shift ;;
-	--verbose-only=*)
-		verbose_only=${1#--*=}
-		shift ;;
-	-q|--q|--qu|--qui|--quie|--quiet)
-		# Ignore --quiet under a TAP::Harness. Saying how many tests
-		# passed without the ok/not ok details is always an error.
-		test -z "$HARNESS_ACTIVE" && quiet=t; shift ;;
-	--with-dashes)
-		with_dashes=t; shift ;;
-	--no-color)
-		color=; shift ;;
-	--va|--val|--valg|--valgr|--valgri|--valgrin|--valgrind)
-		valgrind=memcheck
-		shift ;;
-	--valgrind=*)
-		valgrind=${1#--*=}
-		shift ;;
-	--valgrind-only=*)
-		valgrind_only=${1#--*=}
-		shift ;;
-	--tee)
-		shift ;; # was handled already
-	--root=*)
-		root=${1#--*=}
-		shift ;;
-	--chain-lint)
-		GIT_TEST_CHAIN_LINT=1
-		shift ;;
-	--no-chain-lint)
-		GIT_TEST_CHAIN_LINT=0
-		shift ;;
-	-x)
-		# Some test scripts can't be reliably traced  with '-x',
-		# unless the test is run with a Bash version supporting
-		# BASH_XTRACEFD (introduced in Bash v4.1).  Check whether
-		# this test is marked as such, and ignore '-x' if it
-		# isn't executed with a suitable Bash version.
-		if test -z "$test_untraceable" || {
-		     test -n "$BASH_VERSION" && {
-		       test ${BASH_VERSINFO[0]} -gt 4 || {
-			 test ${BASH_VERSINFO[0]} -eq 4 &&
-			 test ${BASH_VERSINFO[1]} -ge 1
-		       }
-		     }
-		   }
-		then
-			trace=t
-		else
-			echo >&2 "warning: ignoring -x; '$0' is untraceable without BASH_XTRACEFD"
-		fi
-		shift ;;
-	--verbose-log)
-		verbose_log=t
-		shift ;;
-	*)
-		echo "error: unknown test option '$1'" >&2; exit 1 ;;
-	esac
-done
-
-if test -n "$valgrind_only"
-then
-	test -z "$valgrind" && valgrind=memcheck
-	test -z "$verbose" && verbose_only="$valgrind_only"
-elif test -n "$valgrind"
-then
-	test -z "$verbose_log" && verbose=t
-fi
-
-if test -n "$trace" && test -z "$verbose_log"
-then
-	verbose=t
-fi
-
 if test -n "$color"
 then
 	# Save the color control sequences now rather than run tput
@@ -347,10 +576,15 @@ export TERM
 
 error () {
 	say_color error "error: $*"
+	finalize_junit_xml
 	GIT_EXIT_OK=t
 	exit 1
 }
 
+BUG () {
+	error >&7 "bug in the test script: $*"
+}
+
 say () {
 	say_color info "$*"
 }
@@ -410,6 +644,10 @@ test_external_has_tap=0
 
 die () {
 	code=$?
+	# This is responsible for running the atexit commands even when a
+	# test script run with '--immediate' fails, or when the user hits
+	# ctrl-C, i.e. when 'test_done' is not invoked at all.
+	test_atexit_handler || code=$?
 	if test -n "$GIT_EXIT_OK"
 	then
 		exit $code
@@ -421,7 +659,10 @@ die () {
 
 GIT_EXIT_OK=
 trap 'die' EXIT
-trap 'exit $?' INT
+# Disable '-x' tracing, because with some shells, notably dash, it
+# prevents running the cleanup commands when a test script run with
+# '--verbose-log -x' is interrupted.
+trap '{ code=$?; set +x; } 2>/dev/null; exit $code' INT TERM HUP
 
 # The user-facing functions are loaded from a separate file so that
 # test_perf subshells can have them too
@@ -431,24 +672,56 @@ trap 'exit $?' INT
 # the test_expect_* functions instead.
 
 test_ok_ () {
+	if test -n "$write_junit_xml"
+	then
+		write_junit_xml_testcase "$*"
+	fi
 	test_success=$(($test_success + 1))
 	say_color "" "ok $test_count - $@"
 }
 
 test_failure_ () {
+	if test -n "$write_junit_xml"
+	then
+		junit_insert="<failure message=\"not ok $test_count -"
+		junit_insert="$junit_insert $(xml_attr_encode "$1")\">"
+		junit_insert="$junit_insert $(xml_attr_encode \
+			"$(if test -n "$GIT_TEST_TEE_OUTPUT_FILE"
+			   then
+				test-tool path-utils skip-n-bytes \
+					"$GIT_TEST_TEE_OUTPUT_FILE" $GIT_TEST_TEE_OFFSET
+			   else
+				printf '%s\n' "$@" | sed 1d
+			   fi)")"
+		junit_insert="$junit_insert</failure>"
+		if test -n "$GIT_TEST_TEE_OUTPUT_FILE"
+		then
+			junit_insert="$junit_insert<system-err>$(xml_attr_encode \
+				"$(cat "$GIT_TEST_TEE_OUTPUT_FILE")")</system-err>"
+		fi
+		write_junit_xml_testcase "$1" "      $junit_insert"
+	fi
 	test_failure=$(($test_failure + 1))
 	say_color error "not ok $test_count - $1"
 	shift
 	printf '%s\n' "$*" | sed -e 's/^/#	/'
-	test "$immediate" = "" || { GIT_EXIT_OK=t; exit 1; }
+	test "$immediate" = "" || { finalize_junit_xml; GIT_EXIT_OK=t; exit 1; }
 }
 
 test_known_broken_ok_ () {
+	if test -n "$write_junit_xml"
+	then
+		write_junit_xml_testcase "$* (breakage fixed)"
+	fi
 	test_fixed=$(($test_fixed+1))
 	say_color error "ok $test_count - $@ # TODO known breakage vanished"
 }
 
 test_known_broken_failure_ () {
+	if test -n "$write_junit_xml"
+	then
+		write_junit_xml_testcase "$* (known breakage)"
+	fi
 	test_broken=$(($test_broken+1))
 	say_color warn "not ok $test_count - $@ # TODO known breakage"
 }
@@ -675,9 +948,10 @@ test_run_ () {
 		trace=
 		# 117 is magic because it is unlikely to match the exit
 		# code of other programs
-		if test "OK-117" != "$(test_eval_ "(exit 117) && $1${LF}${LF}echo OK-\$?" 3>&1)"
+		if $(printf '%s\n' "$1" | sed -f "$GIT_BUILD_DIR/t/chainlint.sed" | grep -q '?![A-Z][A-Z]*?!') ||
+			test "OK-117" != "$(test_eval_ "(exit 117) && $1${LF}${LF}echo OK-\$?" 3>&1)"
 		then
-			error "bug in the test script: broken &&-chain or run-away HERE-DOC: $1"
+			BUG "broken &&-chain or run-away HERE-DOC: $1"
 		fi
 		trace=$trace_tmp
 	fi
@@ -705,12 +979,21 @@ test_start_ () {
 	test_count=$(($test_count+1))
 	maybe_setup_verbose
 	maybe_setup_valgrind
+	if test -n "$write_junit_xml"
+	then
+		junit_start=$(test-tool date getnanos)
+	fi
 }
 
 test_finish_ () {
 	echo >&3 ""
 	maybe_teardown_valgrind
 	maybe_teardown_verbose
+	if test -n "$GIT_TEST_TEE_OFFSET"
+	then
+		GIT_TEST_TEE_OFFSET=$(test-tool path-utils file-size \
+			"$GIT_TEST_TEE_OUTPUT_FILE")
+	fi
 }
 
 test_skip () {
@@ -721,6 +1004,12 @@ test_skip () {
 		to_skip=t
 		skipped_reason="GIT_SKIP_TESTS"
 	fi
+	if test -z "$to_skip" && test -n "$run_list" &&
+	   ! match_test_selector_list '--run' $test_count "$run_list"
+	then
+		to_skip=t
+		skipped_reason="--run"
+	fi
 	if test -z "$to_skip" && test -n "$test_prereq" &&
 	   ! test_have_prereq "$test_prereq"
 	then
@@ -733,15 +1022,16 @@ test_skip () {
 		fi
 		skipped_reason="missing $missing_prereq${of_prereq}"
 	fi
-	if test -z "$to_skip" && test -n "$run_list" &&
-		! match_test_selector_list '--run' $test_count "$run_list"
-	then
-		to_skip=t
-		skipped_reason="--run"
-	fi
 
 	case "$to_skip" in
 	t)
+		if test -n "$write_junit_xml"
+		then
+			message="$(xml_attr_encode "$skipped_reason")"
+			write_junit_xml_testcase "$1" \
+				"      <skipped message=\"$message\" />"
+		fi
+
 		say_color skip >&3 "skipping test: $@"
 		say_color skip "ok $test_count # skip $1 ($skipped_reason)"
 		: true
@@ -757,17 +1047,80 @@ test_at_end_hook_ () {
 	:
 }
 
+write_junit_xml () {
+	case "$1" in
+	--truncate)
+		>"$junit_xml_path"
+		junit_have_testcase=
+		shift
+		;;
+	esac
+	printf '%s\n' "$@" >>"$junit_xml_path"
+}
+
+xml_attr_encode () {
+	printf '%s\n' "$@" | test-tool xml-encode
+}
+
+write_junit_xml_testcase () {
+	junit_attrs="name=\"$(xml_attr_encode "$this_test.$test_count $1")\""
+	shift
+	junit_attrs="$junit_attrs classname=\"$this_test\""
+	junit_attrs="$junit_attrs time=\"$(test-tool \
+		date getnanos $junit_start)\""
+	write_junit_xml "$(printf '%s\n' \
+		"    <testcase $junit_attrs>" "$@" "    </testcase>")"
+	junit_have_testcase=t
+}
+
+finalize_junit_xml () {
+	if test -n "$write_junit_xml" && test -n "$junit_xml_path"
+	then
+		test -n "$junit_have_testcase" || {
+			junit_start=$(test-tool date getnanos)
+			write_junit_xml_testcase "all tests skipped"
+		}
+
+		# adjust the overall time
+		junit_time=$(test-tool date getnanos $junit_suite_start)
+		sed "s/<testsuite [^>]*/& time=\"$junit_time\"/" \
+			<"$junit_xml_path" >"$junit_xml_path.new"
+		mv "$junit_xml_path.new" "$junit_xml_path"
+
+		write_junit_xml "  </testsuite>" "</testsuites>"
+		write_junit_xml=
+	fi
+}
+
+test_atexit_cleanup=:
+test_atexit_handler () {
+	# In a succeeding test script 'test_atexit_handler' is invoked
+	# twice: first from 'test_done', then from 'die' in the trap on
+	# EXIT.
+	# This condition and resetting 'test_atexit_cleanup' below makes
+	# sure that the registered cleanup commands are run only once.
+	test : != "$test_atexit_cleanup" || return 0
+
+	setup_malloc_check
+	test_eval_ "$test_atexit_cleanup"
+	test_atexit_cleanup=:
+	teardown_malloc_check
+}
+
 test_done () {
 	GIT_EXIT_OK=t
 
+	# Run the atexit commands _before_ the trash directory is
+	# removed, so the commands can access pidfiles and socket files.
+	test_atexit_handler
+
+	finalize_junit_xml
+
 	if test -z "$HARNESS_ACTIVE"
 	then
-		test_results_dir="$TEST_OUTPUT_DIRECTORY/test-results"
-		mkdir -p "$test_results_dir"
-		base=${0##*/}
-		test_results_path="$test_results_dir/${base%.sh}.counts"
+		mkdir -p "$TEST_RESULTS_DIR"
 
-		cat >"$test_results_path" <<-EOF
+		cat >"$TEST_RESULTS_BASE.counts" <<-EOF
 		total $test_count
 		success $test_success
 		fixed $test_fixed
@@ -822,7 +1175,11 @@ test_done () {
 			error "Tests passed but trash directory already removed before test cleanup; aborting"
 
 			cd "$TRASH_DIRECTORY/.." &&
-			rm -fr "$TRASH_DIRECTORY" ||
+			rm -fr "$TRASH_DIRECTORY" || {
+				# try again in a bit
+				sleep 5;
+				rm -fr "$TRASH_DIRECTORY"
+			} ||
 			error "Tests passed but test cleanup failed; aborting"
 		fi
 		test_at_end_hook_
@@ -866,7 +1223,7 @@ then
 		# handle only executables, unless they are shell libraries that
 		# need to be in the exec-path.
 		test -x "$1" ||
-		test "# " = "$(head -c 2 <"$1")" ||
+		test "# " = "$(test_copy_bytes 2 <"$1")" ||
 		return;
 
 		base=$(basename "$1")
@@ -881,7 +1238,7 @@ then
 		# do not override scripts
 		if test -x "$symlink_target" &&
 		    test ! -d "$symlink_target" &&
-		    test "#!" != "$(head -c 2 < "$symlink_target")"
+		    test "#!" != "$(test_copy_bytes 2 <"$symlink_target")"
 		then
 			symlink_target=../valgrind.sh
 		fi
@@ -925,23 +1282,28 @@ elif test -n "$GIT_TEST_INSTALLED"
 then
 	GIT_EXEC_PATH=$($GIT_TEST_INSTALLED/git --exec-path)  ||
 	error "Cannot run git from $GIT_TEST_INSTALLED."
-	PATH=$GIT_TEST_INSTALLED:$GIT_BUILD_DIR:$PATH
+	PATH=$GIT_TEST_INSTALLED:$GIT_BUILD_DIR/t/helper:$PATH
 	GIT_EXEC_PATH=${GIT_TEST_EXEC_PATH:-$GIT_EXEC_PATH}
 else # normal case, use ../bin-wrappers only unless $with_dashes:
-	git_bin_dir="$GIT_BUILD_DIR/bin-wrappers"
-	if ! test -x "$git_bin_dir/git"
+	if test -n "$no_bin_wrappers"
 	then
-		if test -z "$with_dashes"
+		with_dashes=t
+	else
+		git_bin_dir="$GIT_BUILD_DIR/bin-wrappers"
+		if ! test -x "$git_bin_dir/git"
 		then
-			say "$git_bin_dir/git is not executable; using GIT_EXEC_PATH"
+			if test -z "$with_dashes"
+			then
+				say "$git_bin_dir/git is not executable; using GIT_EXEC_PATH"
+			fi
+			with_dashes=t
 		fi
-		with_dashes=t
+		PATH="$git_bin_dir:$PATH"
 	fi
-	PATH="$git_bin_dir:$PATH"
 	GIT_EXEC_PATH=$GIT_BUILD_DIR
 	if test -n "$with_dashes"
 	then
-		PATH="$GIT_BUILD_DIR:$PATH"
+		PATH="$GIT_BUILD_DIR:$GIT_BUILD_DIR/t/helper:$PATH"
 	fi
 fi
 GIT_TEMPLATE_DIR="$GIT_BUILD_DIR"/templates/blt
@@ -965,7 +1327,7 @@ test -d "$GIT_BUILD_DIR"/templates/blt |
 	error "You haven't built things yet, have you?"
 }
 
-if ! test -x "$GIT_BUILD_DIR"/t/helper/test-tool
+if ! test -x "$GIT_BUILD_DIR"/t/helper/test-tool$X
 then
 	echo >&2 'You need to build test-tool:'
 	echo >&2 'Run "make t/helper/test-tool" in the source (toplevel) directory'
@@ -973,12 +1335,6 @@ then
 fi
 
 # Test repository
-TRASH_DIRECTORY="trash directory.$(basename "$0" .sh)"
-test -n "$root" && TRASH_DIRECTORY="$root/$TRASH_DIRECTORY"
-case "$TRASH_DIRECTORY" in
-/*) ;; # absolute path is good
- *) TRASH_DIRECTORY="$TEST_OUTPUT_DIRECTORY/$TRASH_DIRECTORY" ;;
-esac
 rm -fr "$TRASH_DIRECTORY" || {
 	GIT_EXIT_OK=t
 	echo >&5 "FATAL: Cannot prepare test area"
@@ -995,6 +1351,7 @@ then
 else
 	mkdir -p "$TRASH_DIRECTORY"
 fi
+
 # Use -P to resolve symlinks in our working directory so that the cwd
 # in subprocesses like git equals our $PWD (for pathname comparisons).
 cd -P "$TRASH_DIRECTORY" || exit 1
@@ -1008,7 +1365,28 @@ then
 	test_done
 fi
 
-# Provide an implementation of the 'yes' utility
+if test -n "$write_junit_xml"
+then
+	junit_xml_dir="$TEST_OUTPUT_DIRECTORY/out"
+	mkdir -p "$junit_xml_dir"
+	junit_xml_base=${0##*/}
+	junit_xml_path="$junit_xml_dir/TEST-${junit_xml_base%.sh}.xml"
+	junit_attrs="name=\"${junit_xml_base%.sh}\""
+	junit_attrs="$junit_attrs timestamp=\"$(TZ=UTC \
+		date +%Y-%m-%dT%H:%M:%S)\""
+	write_junit_xml --truncate "<testsuites>" "  <testsuite $junit_attrs>"
+	junit_suite_start=$(test-tool date getnanos)
+	if test -n "$GIT_TEST_TEE_OUTPUT_FILE"
+	then
+		GIT_TEST_TEE_OFFSET=0
+	fi
+fi
+
+# Provide an implementation of the 'yes' utility; the upper bound
+# limit is there to help Windows that cannot stop this loop from
+# wasting cycles when the downstream stops reading, so do not be
+# tempted to turn it into an infinite loop. cf. 6129c930 ("test-lib:
+# limit the output of the yes utility", 2016-02-02)
 yes () {
 	if test $# = 0
 	then
@@ -1025,7 +1403,26 @@ yes () {
 	done
 }
 
-# Fix some commands on Windows
+# The GIT_TEST_FAIL_PREREQS code hooks into test_set_prereq(), and
+# thus needs to be set up really early, and set an internal variable
+# for convenience so the hot test_set_prereq() codepath doesn't need
+# to call "git env--helper" (via test_bool_env). Only do that work
+# if needed by seeing if GIT_TEST_FAIL_PREREQS is set at all.
+GIT_TEST_FAIL_PREREQS_INTERNAL=
+if test -n "$GIT_TEST_FAIL_PREREQS"
+then
+	if test_bool_env GIT_TEST_FAIL_PREREQS false
+	then
+		GIT_TEST_FAIL_PREREQS_INTERNAL=true
+		test_set_prereq FAIL_PREREQS
+	fi
+else
+	test_lazy_prereq FAIL_PREREQS '
+		test_bool_env GIT_TEST_FAIL_PREREQS false
+	'
+fi
+
+# Fix some commands on Windows, and other OS-specific things
 uname_s=$(uname -s)
 case $uname_s in
 *MINGW*)
@@ -1056,6 +1453,12 @@ case $uname_s in
 	test_set_prereq SED_STRIPS_CR
 	test_set_prereq GREP_STRIPS_CR
 	;;
+FreeBSD)
+	test_set_prereq REGEX_ILLSEQ
+	test_set_prereq POSIXPERM
+	test_set_prereq BSLASHPSPEC
+	test_set_prereq EXECKEEPSPID
+	;;
 *)
 	test_set_prereq POSIXPERM
 	test_set_prereq BSLASHPSPEC
@@ -1072,14 +1475,21 @@ test -n "$USE_LIBPCRE1" && test_set_prer
 test -n "$USE_LIBPCRE2" && test_set_prereq LIBPCRE2
 test -z "$NO_GETTEXT" && test_set_prereq GETTEXT
 
-# Can we rely on git's output in the C locale?
-if test -n "$GETTEXT_POISON"
+if test -n "$GIT_TEST_GETTEXT_POISON_ORIG"
 then
-	GIT_GETTEXT_POISON=YesPlease
-	export GIT_GETTEXT_POISON
-	test_set_prereq GETTEXT_POISON
-else
-	test_set_prereq C_LOCALE_OUTPUT
+	GIT_TEST_GETTEXT_POISON=$GIT_TEST_GETTEXT_POISON_ORIG
+	export GIT_TEST_GETTEXT_POISON
+	unset GIT_TEST_GETTEXT_POISON_ORIG
+fi
+
+test_lazy_prereq C_LOCALE_OUTPUT '
+	! test_bool_env GIT_TEST_GETTEXT_POISON false
+'
+
+if test -z "$GIT_TEST_CHECK_CACHE_TREE"
+then
+	GIT_TEST_CHECK_CACHE_TREE=true
+	export GIT_TEST_CHECK_CACHE_TREE
 fi
 
 test_lazy_prereq PIPE '
@@ -1103,6 +1513,20 @@ test_lazy_prereq CASE_INSENSITIVE_FS '
 	test "$(cat CamelCase)" != good
 '
 
+test_lazy_prereq FUNNYNAMES '
+	test_have_prereq !MINGW &&
+	touch -- \
+		"FUNNYNAMES tab	embedded" \
+		"FUNNYNAMES \"quote embedded\"" \
+		"FUNNYNAMES newline
+embedded" 2>/dev/null &&
+	rm -- \
+		"FUNNYNAMES tab	embedded" \
+		"FUNNYNAMES \"quote embedded\"" \
+		"FUNNYNAMES newline
+embedded" 2>/dev/null
+'
+
 test_lazy_prereq UTF8_NFD_TO_NFC '
 	# check whether FS converts nfd unicode to nfc
 	auml=$(printf "\303\244")
@@ -1135,7 +1559,7 @@ test_lazy_prereq NOT_ROOT '
 '
 
 test_lazy_prereq JGIT '
-	type jgit
+	jgit --version
 '
 
 # SANITY is about "can you correctly predict what the filesystem would
@@ -1157,7 +1581,7 @@ test_lazy_prereq SANITY '
 	chmod -w SANETESTD.1 &&
 	chmod -r SANETESTD.1/x &&
 	chmod -rx SANETESTD.2 ||
-	error "bug in test sript: cannot prepare SANETESTD"
+	BUG "cannot prepare SANETESTD"
 
 	! test -r SANETESTD.1/x &&
 	! rm SANETESTD.1/x && ! test -f SANETESTD.2/x
@@ -1165,7 +1589,7 @@ test_lazy_prereq SANITY '
 
 	chmod +rwx SANETESTD.1 SANETESTD.2 &&
 	rm -rf SANETESTD.1 SANETESTD.2 ||
-	error "bug in test sript: cannot clean SANETESTD"
+	BUG "cannot clean SANETESTD"
 	return $status
 '
 
@@ -1216,3 +1640,7 @@ test_lazy_prereq CURL '
 test_lazy_prereq SHA1 '
 	test $(git hash-object /dev/null) = e69de29bb2d1d6434b8b29ae775ad8c2e48c5391
 '
+
+test_lazy_prereq REBASE_P '
+	test -z "$GIT_TEST_SKIP_REBASE_P"
+'
diff -pruN 1.2.1+git2.18.0-1/git/tag.c 1.2.3+git2.25.1-1/git/tag.c
--- 1.2.1+git2.18.0-1/git/tag.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/tag.c	2020-02-17 04:47:35.000000000 +0000
@@ -1,9 +1,12 @@
 #include "cache.h"
 #include "tag.h"
+#include "object-store.h"
 #include "commit.h"
 #include "tree.h"
 #include "blob.h"
+#include "alloc.h"
 #include "gpg-interface.h"
+#include "packfile.h"
 
 const char *tag_type = "tag";
 
@@ -62,14 +65,20 @@ int gpg_verify_tag(const struct object_i
 	return ret;
 }
 
-struct object *deref_tag(struct object *o, const char *warn, int warnlen)
+struct object *deref_tag(struct repository *r, struct object *o, const char *warn, int warnlen)
 {
+	struct object_id *last_oid = NULL;
 	while (o && o->type == OBJ_TAG)
-		if (((struct tag *)o)->tagged)
-			o = parse_object(&((struct tag *)o)->tagged->oid);
-		else
+		if (((struct tag *)o)->tagged) {
+			last_oid = &((struct tag *)o)->tagged->oid;
+			o = parse_object(r, last_oid);
+		} else {
+			last_oid = NULL;
 			o = NULL;
+		}
 	if (!o && warn) {
+		if (last_oid && is_promisor_object(last_oid))
+			return NULL;
 		if (!warnlen)
 			warnlen = strlen(warn);
 		error("missing object referenced by '%.*s'", warnlen, warn);
@@ -80,7 +89,7 @@ struct object *deref_tag(struct object *
 struct object *deref_tag_noverify(struct object *o)
 {
 	while (o && o->type == OBJ_TAG) {
-		o = parse_object(&o->oid);
+		o = parse_object(the_repository, &o->oid);
 		if (o && o->type == OBJ_TAG && ((struct tag *)o)->tagged)
 			o = ((struct tag *)o)->tagged;
 		else
@@ -89,12 +98,12 @@ struct object *deref_tag_noverify(struct
 	return o;
 }
 
-struct tag *lookup_tag(const struct object_id *oid)
+struct tag *lookup_tag(struct repository *r, const struct object_id *oid)
 {
-	struct object *obj = lookup_object(oid->hash);
+	struct object *obj = lookup_object(r, oid);
 	if (!obj)
-		return create_object(oid->hash, alloc_tag_node());
-	return object_as_type(obj, OBJ_TAG, 0);
+		return create_object(r, oid, alloc_tag_node(r));
+	return object_as_type(r, obj, OBJ_TAG, 0);
 }
 
 static timestamp_t parse_tag_date(const char *buf, const char *tail)
@@ -114,7 +123,15 @@ static timestamp_t parse_tag_date(const
 	return parse_timestamp(dateptr, NULL, 10);
 }
 
-int parse_tag_buffer(struct tag *item, const void *data, unsigned long size)
+void release_tag_memory(struct tag *t)
+{
+	free(t->tag);
+	t->tagged = NULL;
+	t->object.parsed = 0;
+	t->date = 0;
+}
+
+int parse_tag_buffer(struct repository *r, struct tag *item, const void *data, unsigned long size)
 {
 	struct object_id oid;
 	char type[20];
@@ -124,9 +141,18 @@ int parse_tag_buffer(struct tag *item, c
 
 	if (item->object.parsed)
 		return 0;
-	item->object.parsed = 1;
 
-	if (size < GIT_SHA1_HEXSZ + 24)
+	if (item->tag) {
+		/*
+		 * Presumably left over from a previous failed parse;
+		 * clear it out in preparation for re-parsing (we'll probably
+		 * hit the same error, which lets us tell our current caller
+		 * about the problem).
+		 */
+		FREE_AND_NULL(item->tag);
+	}
+
+	if (size < the_hash_algo->hexsz + 24)
 		return -1;
 	if (memcmp("object ", bufptr, 7) || parse_oid_hex(bufptr + 7, &oid, &bufptr) || *bufptr++ != '\n')
 		return -1;
@@ -142,18 +168,23 @@ int parse_tag_buffer(struct tag *item, c
 	bufptr = nl + 1;
 
 	if (!strcmp(type, blob_type)) {
-		item->tagged = (struct object *)lookup_blob(&oid);
+		item->tagged = (struct object *)lookup_blob(r, &oid);
 	} else if (!strcmp(type, tree_type)) {
-		item->tagged = (struct object *)lookup_tree(&oid);
+		item->tagged = (struct object *)lookup_tree(r, &oid);
 	} else if (!strcmp(type, commit_type)) {
-		item->tagged = (struct object *)lookup_commit(&oid);
+		item->tagged = (struct object *)lookup_commit(r, &oid);
 	} else if (!strcmp(type, tag_type)) {
-		item->tagged = (struct object *)lookup_tag(&oid);
+		item->tagged = (struct object *)lookup_tag(r, &oid);
 	} else {
-		error("Unknown type %s", type);
-		item->tagged = NULL;
+		return error("unknown tag type '%s' in %s",
+			     type, oid_to_hex(&item->object.oid));
 	}
 
+	if (!item->tagged)
+		return error("bad tag pointer to %s in %s",
+			     oid_to_hex(&oid),
+			     oid_to_hex(&item->object.oid));
+
 	if (bufptr + 4 < tail && starts_with(bufptr, "tag "))
 		; 		/* good */
 	else
@@ -170,6 +201,7 @@ int parse_tag_buffer(struct tag *item, c
 	else
 		item->date = 0;
 
+	item->object.parsed = 1;
 	return 0;
 }
 
@@ -191,7 +223,14 @@ int parse_tag(struct tag *item)
 		return error("Object %s not a tag",
 			     oid_to_hex(&item->object.oid));
 	}
-	ret = parse_tag_buffer(item, data, size);
+	ret = parse_tag_buffer(the_repository, item, data, size);
 	free(data);
 	return ret;
 }
+
+struct object_id *get_tagged_oid(struct tag *tag)
+{
+	if (!tag->tagged)
+		die("bad tag");
+	return &tag->tagged->oid;
+}
diff -pruN 1.2.1+git2.18.0-1/git/tag.h 1.2.3+git2.25.1-1/git/tag.h
--- 1.2.1+git2.18.0-1/git/tag.h	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/tag.h	2020-02-17 04:47:35.000000000 +0000
@@ -11,13 +11,14 @@ struct tag {
 	char *tag;
 	timestamp_t date;
 };
-
-extern struct tag *lookup_tag(const struct object_id *oid);
-extern int parse_tag_buffer(struct tag *item, const void *data, unsigned long size);
-extern int parse_tag(struct tag *item);
-extern struct object *deref_tag(struct object *, const char *, int);
-extern struct object *deref_tag_noverify(struct object *);
-extern int gpg_verify_tag(const struct object_id *oid,
-		const char *name_to_report, unsigned flags);
+struct tag *lookup_tag(struct repository *r, const struct object_id *oid);
+int parse_tag_buffer(struct repository *r, struct tag *item, const void *data, unsigned long size);
+int parse_tag(struct tag *item);
+void release_tag_memory(struct tag *t);
+struct object *deref_tag(struct repository *r, struct object *, const char *, int);
+struct object *deref_tag_noverify(struct object *);
+int gpg_verify_tag(const struct object_id *oid,
+		   const char *name_to_report, unsigned flags);
+struct object_id *get_tagged_oid(struct tag *tag);
 
 #endif /* TAG_H */
diff -pruN 1.2.1+git2.18.0-1/git/tar.h 1.2.3+git2.25.1-1/git/tar.h
--- 1.2.1+git2.18.0-1/git/tar.h	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/tar.h	2020-02-17 04:47:35.000000000 +0000
@@ -1,3 +1,6 @@
+#ifndef TAR_H
+#define TAR_H
+
 #define TYPEFLAG_AUTO		'\0'
 #define TYPEFLAG_REG		'0'
 #define TYPEFLAG_LNK		'2'
@@ -23,3 +26,5 @@ struct ustar_header {
 	char devminor[8];	/* 337 */
 	char prefix[155];	/* 345 */
 };
+
+#endif /* TAR_H */
diff -pruN 1.2.1+git2.18.0-1/git/tempfile.c 1.2.3+git2.25.1-1/git/tempfile.c
--- 1.2.1+git2.18.0-1/git/tempfile.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/tempfile.c	2020-02-17 04:47:35.000000000 +0000
@@ -279,7 +279,7 @@ int reopen_tempfile(struct tempfile *tem
 		BUG("reopen_tempfile called for an inactive object");
 	if (0 <= tempfile->fd)
 		BUG("reopen_tempfile called for an open object");
-	tempfile->fd = open(tempfile->filename.buf, O_WRONLY);
+	tempfile->fd = open(tempfile->filename.buf, O_WRONLY|O_TRUNC);
 	return tempfile->fd;
 }
 
diff -pruN 1.2.1+git2.18.0-1/git/tempfile.h 1.2.3+git2.25.1-1/git/tempfile.h
--- 1.2.1+git2.18.0-1/git/tempfile.h	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/tempfile.h	2020-02-17 04:47:35.000000000 +0000
@@ -2,6 +2,7 @@
 #define TEMPFILE_H
 
 #include "list.h"
+#include "strbuf.h"
 
 /*
  * Handle temporary files.
@@ -88,7 +89,7 @@ struct tempfile {
  * a tempfile (whose "fd" member can be used for writing to it), or
  * NULL on error. It is an error if a file already exists at that path.
  */
-extern struct tempfile *create_tempfile(const char *path);
+struct tempfile *create_tempfile(const char *path);
 
 /*
  * Register an existing file as a tempfile, meaning that it will be
@@ -96,7 +97,7 @@ extern struct tempfile *create_tempfile(
  * but it can be worked with like any other closed tempfile (for
  * example, it can be opened using reopen_tempfile()).
  */
-extern struct tempfile *register_tempfile(const char *path);
+struct tempfile *register_tempfile(const char *path);
 
 
 /*
@@ -135,8 +136,8 @@ extern struct tempfile *register_tempfil
  */
 
 /* See "mks_tempfile functions" above. */
-extern struct tempfile *mks_tempfile_sm(const char *filename_template,
-					int suffixlen, int mode);
+struct tempfile *mks_tempfile_sm(const char *filename_template,
+				 int suffixlen, int mode);
 
 /* See "mks_tempfile functions" above. */
 static inline struct tempfile *mks_tempfile_s(const char *filename_template,
@@ -158,8 +159,8 @@ static inline struct tempfile *mks_tempf
 }
 
 /* See "mks_tempfile functions" above. */
-extern struct tempfile *mks_tempfile_tsm(const char *filename_template,
-					 int suffixlen, int mode);
+struct tempfile *mks_tempfile_tsm(const char *filename_template,
+				  int suffixlen, int mode);
 
 /* See "mks_tempfile functions" above. */
 static inline struct tempfile *mks_tempfile_ts(const char *filename_template,
@@ -181,7 +182,7 @@ static inline struct tempfile *mks_tempf
 }
 
 /* See "mks_tempfile functions" above. */
-extern struct tempfile *xmks_tempfile_m(const char *filename_template, int mode);
+struct tempfile *xmks_tempfile_m(const char *filename_template, int mode);
 
 /* See "mks_tempfile functions" above. */
 static inline struct tempfile *xmks_tempfile(const char *filename_template)
@@ -195,7 +196,7 @@ static inline struct tempfile *xmks_temp
  * stream is closed automatically when `close_tempfile_gently()` is called or
  * when the file is deleted or renamed.
  */
-extern FILE *fdopen_tempfile(struct tempfile *tempfile, const char *mode);
+FILE *fdopen_tempfile(struct tempfile *tempfile, const char *mode);
 
 static inline int is_tempfile_active(struct tempfile *tempfile)
 {
@@ -206,10 +207,10 @@ static inline int is_tempfile_active(str
  * Return the path of the lockfile. The return value is a pointer to a
  * field within the lock_file object and should not be freed.
  */
-extern const char *get_tempfile_path(struct tempfile *tempfile);
+const char *get_tempfile_path(struct tempfile *tempfile);
 
-extern int get_tempfile_fd(struct tempfile *tempfile);
-extern FILE *get_tempfile_fp(struct tempfile *tempfile);
+int get_tempfile_fd(struct tempfile *tempfile);
+FILE *get_tempfile_fp(struct tempfile *tempfile);
 
 /*
  * If the temporary file is still open, close it (and the file pointer
@@ -219,7 +220,7 @@ extern FILE *get_tempfile_fp(struct temp
  * should eventually be called regardless of whether `close_tempfile_gently()`
  * succeeds.
  */
-extern int close_tempfile_gently(struct tempfile *tempfile);
+int close_tempfile_gently(struct tempfile *tempfile);
 
 /*
  * Re-open a temporary file that has been closed using
@@ -235,12 +236,12 @@ extern int close_tempfile_gently(struct
  *   it (and nobody else) to inspect or even modify the file's
  *   contents.
  *
- * * `reopen_tempfile()` to reopen the temporary file. Make further
- *   updates to the contents.
+ * * `reopen_tempfile()` to reopen the temporary file, truncating the existing
+ *   contents. Write out the new contents.
  *
  * * `rename_tempfile()` to move the file to its permanent location.
  */
-extern int reopen_tempfile(struct tempfile *tempfile);
+int reopen_tempfile(struct tempfile *tempfile);
 
 /*
  * Close the file descriptor and/or file pointer and remove the
@@ -248,7 +249,7 @@ extern int reopen_tempfile(struct tempfi
  * `delete_tempfile()` for a `tempfile` object that has already been
  * deleted or renamed.
  */
-extern void delete_tempfile(struct tempfile **tempfile_p);
+void delete_tempfile(struct tempfile **tempfile_p);
 
 /*
  * Close the file descriptor and/or file pointer if they are still
@@ -259,6 +260,6 @@ extern void delete_tempfile(struct tempf
  * `rename(2)`. It is a bug to call `rename_tempfile()` for a
  * `tempfile` object that is not currently active.
  */
-extern int rename_tempfile(struct tempfile **tempfile_p, const char *path);
+int rename_tempfile(struct tempfile **tempfile_p, const char *path);
 
 #endif /* TEMPFILE_H */
diff -pruN 1.2.1+git2.18.0-1/git/templates/hooks--fsmonitor-watchman.sample 1.2.3+git2.25.1-1/git/templates/hooks--fsmonitor-watchman.sample
--- 1.2.1+git2.18.0-1/git/templates/hooks--fsmonitor-watchman.sample	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/templates/hooks--fsmonitor-watchman.sample	2020-02-17 04:47:35.000000000 +0000
@@ -22,7 +22,8 @@ my ($version, $time) = @ARGV;
 
 if ($version == 1) {
 	# convert nanoseconds to seconds
-	$time = int $time / 1000000000;
+	# subtract one second to make sure watchman will return all changes
+	$time = int ($time / 1000000000) - 1;
 } else {
 	die "Unsupported query-fsmonitor hook version '$version'.\n" .
 	    "Falling back to scanning...\n";
@@ -53,18 +54,12 @@ sub launch_watchman {
 	#
 	# To accomplish this, we're using the "since" generator to use the
 	# recency index to select candidate nodes and "fields" to limit the
-	# output to file names only. Then we're using the "expression" term to
-	# further constrain the results.
-	#
-	# The category of transient files that we want to ignore will have a
-	# creation clock (cclock) newer than $time_t value and will also not
-	# currently exist.
+	# output to file names only.
 
 	my $query = <<"	END";
 		["query", "$git_work_tree", {
 			"since": $time,
-			"fields": ["name"],
-			"expression": ["not", ["allof", ["since", $time, "cclock"], ["not", "exists"]]]
+			"fields": ["name"]
 		}]
 	END
 
diff -pruN 1.2.1+git2.18.0-1/git/templates/hooks--pre-merge-commit.sample 1.2.3+git2.25.1-1/git/templates/hooks--pre-merge-commit.sample
--- 1.2.1+git2.18.0-1/git/templates/hooks--pre-merge-commit.sample	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/templates/hooks--pre-merge-commit.sample	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,13 @@
+#!/bin/sh
+#
+# An example hook script to verify what is about to be committed.
+# Called by "git merge" with no arguments.  The hook should
+# exit with non-zero status after issuing an appropriate message to
+# stderr if it wants to stop the merge commit.
+#
+# To enable this hook, rename this file to "pre-merge-commit".
+
+. git-sh-setup
+test -x "$GIT_DIR/hooks/pre-commit" &&
+        exec "$GIT_DIR/hooks/pre-commit"
+:
diff -pruN 1.2.1+git2.18.0-1/git/thread-utils.c 1.2.3+git2.25.1-1/git/thread-utils.c
--- 1.2.1+git2.18.0-1/git/thread-utils.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/thread-utils.c	2020-02-17 04:47:35.000000000 +0000
@@ -20,6 +20,9 @@
 
 int online_cpus(void)
 {
+#ifdef NO_PTHREADS
+	return 1;
+#else
 #ifdef _SC_NPROCESSORS_ONLN
 	long ncpus;
 #endif
@@ -59,10 +62,12 @@ int online_cpus(void)
 #endif
 
 	return 1;
+#endif
 }
 
 int init_recursive_mutex(pthread_mutex_t *m)
 {
+#ifndef NO_PTHREADS
 	pthread_mutexattr_t a;
 	int ret;
 
@@ -74,4 +79,47 @@ int init_recursive_mutex(pthread_mutex_t
 		pthread_mutexattr_destroy(&a);
 	}
 	return ret;
+#else
+	return 0;
+#endif
+}
+
+#ifdef NO_PTHREADS
+int dummy_pthread_create(pthread_t *pthread, const void *attr,
+			 void *(*fn)(void *), void *data)
+{
+	/*
+	 * Do nothing.
+	 *
+	 * The main purpose of this function is to break compiler's
+	 * flow analysis and avoid -Wunused-variable false warnings.
+	 */
+	return ENOSYS;
+}
+
+int dummy_pthread_init(void *data)
+{
+	/*
+	 * Do nothing.
+	 *
+	 * The main purpose of this function is to break compiler's
+	 * flow analysis or it may realize that functions like
+	 * pthread_mutex_init() is no-op, which means the (static)
+	 * variable is not used/initialized at all and trigger
+	 * -Wunused-variable
+	 */
+	return ENOSYS;
 }
+
+int dummy_pthread_join(pthread_t pthread, void **retval)
+{
+	/*
+	 * Do nothing.
+	 *
+	 * The main purpose of this function is to break compiler's
+	 * flow analysis and avoid -Wunused-variable false warnings.
+	 */
+	return ENOSYS;
+}
+
+#endif
diff -pruN 1.2.1+git2.18.0-1/git/thread-utils.h 1.2.3+git2.25.1-1/git/thread-utils.h
--- 1.2.1+git2.18.0-1/git/thread-utils.h	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/thread-utils.h	2020-02-17 04:47:35.000000000 +0000
@@ -4,12 +4,54 @@
 #ifndef NO_PTHREADS
 #include <pthread.h>
 
-extern int online_cpus(void);
-extern int init_recursive_mutex(pthread_mutex_t*);
+#define HAVE_THREADS 1
 
 #else
 
-#define online_cpus() 1
+#define HAVE_THREADS 0
+
+/*
+ * macros instead of typedefs because pthread definitions may have
+ * been pulled in by some system dependencies even though the user
+ * wants to disable pthread.
+ */
+#define pthread_t int
+#define pthread_mutex_t int
+#define pthread_cond_t int
+#define pthread_key_t int
+
+#define pthread_mutex_init(mutex, attr) dummy_pthread_init(mutex)
+#define pthread_mutex_lock(mutex)
+#define pthread_mutex_unlock(mutex)
+#define pthread_mutex_destroy(mutex)
+
+#define pthread_cond_init(cond, attr) dummy_pthread_init(cond)
+#define pthread_cond_wait(cond, mutex)
+#define pthread_cond_signal(cond)
+#define pthread_cond_broadcast(cond)
+#define pthread_cond_destroy(cond)
+
+#define pthread_key_create(key, attr) dummy_pthread_init(key)
+#define pthread_key_delete(key)
+
+#define pthread_create(thread, attr, fn, data) \
+	dummy_pthread_create(thread, attr, fn, data)
+#define pthread_join(thread, retval) \
+	dummy_pthread_join(thread, retval)
+
+#define pthread_setspecific(key, data)
+#define pthread_getspecific(key) NULL
+
+int dummy_pthread_create(pthread_t *pthread, const void *attr,
+			 void *(*fn)(void *), void *data);
+int dummy_pthread_join(pthread_t pthread, void **retval);
+
+int dummy_pthread_init(void *);
 
 #endif
+
+int online_cpus(void);
+int init_recursive_mutex(pthread_mutex_t*);
+
+
 #endif /* THREAD_COMPAT_H */
diff -pruN 1.2.1+git2.18.0-1/git/trace2/tr2_cfg.c 1.2.3+git2.25.1-1/git/trace2/tr2_cfg.c
--- 1.2.1+git2.18.0-1/git/trace2/tr2_cfg.c	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/trace2/tr2_cfg.c	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,89 @@
+#include "cache.h"
+#include "config.h"
+#include "trace2/tr2_cfg.h"
+#include "trace2/tr2_sysenv.h"
+
+static struct strbuf **tr2_cfg_patterns;
+static int tr2_cfg_count_patterns;
+static int tr2_cfg_loaded;
+
+/*
+ * Parse a string containing a comma-delimited list of config keys
+ * or wildcard patterns into a list of strbufs.
+ */
+static int tr2_cfg_load_patterns(void)
+{
+	struct strbuf **s;
+	const char *envvar;
+
+	if (tr2_cfg_loaded)
+		return tr2_cfg_count_patterns;
+	tr2_cfg_loaded = 1;
+
+	envvar = tr2_sysenv_get(TR2_SYSENV_CFG_PARAM);
+	if (!envvar || !*envvar)
+		return tr2_cfg_count_patterns;
+
+	tr2_cfg_patterns = strbuf_split_buf(envvar, strlen(envvar), ',', -1);
+	for (s = tr2_cfg_patterns; *s; s++) {
+		struct strbuf *buf = *s;
+
+		if (buf->len && buf->buf[buf->len - 1] == ',')
+			strbuf_setlen(buf, buf->len - 1);
+		strbuf_trim_trailing_newline(*s);
+		strbuf_trim(*s);
+	}
+
+	tr2_cfg_count_patterns = s - tr2_cfg_patterns;
+	return tr2_cfg_count_patterns;
+}
+
+void tr2_cfg_free_patterns(void)
+{
+	if (tr2_cfg_patterns)
+		strbuf_list_free(tr2_cfg_patterns);
+	tr2_cfg_count_patterns = 0;
+	tr2_cfg_loaded = 0;
+}
+
+struct tr2_cfg_data {
+	const char *file;
+	int line;
+};
+
+/*
+ * See if the given config key matches any of our patterns of interest.
+ */
+static int tr2_cfg_cb(const char *key, const char *value, void *d)
+{
+	struct strbuf **s;
+	struct tr2_cfg_data *data = (struct tr2_cfg_data *)d;
+
+	for (s = tr2_cfg_patterns; *s; s++) {
+		struct strbuf *buf = *s;
+		int wm = wildmatch(buf->buf, key, WM_CASEFOLD);
+		if (wm == WM_MATCH) {
+			trace2_def_param_fl(data->file, data->line, key, value);
+			return 0;
+		}
+	}
+
+	return 0;
+}
+
+void tr2_cfg_list_config_fl(const char *file, int line)
+{
+	struct tr2_cfg_data data = { file, line };
+
+	if (tr2_cfg_load_patterns() > 0)
+		read_early_config(tr2_cfg_cb, &data);
+}
+
+void tr2_cfg_set_fl(const char *file, int line, const char *key,
+		    const char *value)
+{
+	struct tr2_cfg_data data = { file, line };
+
+	if (tr2_cfg_load_patterns() > 0)
+		tr2_cfg_cb(key, value, &data);
+}
diff -pruN 1.2.1+git2.18.0-1/git/trace2/tr2_cfg.h 1.2.3+git2.25.1-1/git/trace2/tr2_cfg.h
--- 1.2.1+git2.18.0-1/git/trace2/tr2_cfg.h	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/trace2/tr2_cfg.h	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,19 @@
+#ifndef TR2_CFG_H
+#define TR2_CFG_H
+
+/*
+ * Iterate over all config settings and emit 'def_param' events for the
+ * "interesting" ones to TRACE2.
+ */
+void tr2_cfg_list_config_fl(const char *file, int line);
+
+/*
+ * Emit a "def_param" event for the given key/value pair IF we consider
+ * the key to be "interesting".
+ */
+void tr2_cfg_set_fl(const char *file, int line, const char *key,
+		    const char *value);
+
+void tr2_cfg_free_patterns(void);
+
+#endif /* TR2_CFG_H */
diff -pruN 1.2.1+git2.18.0-1/git/trace2/tr2_cmd_name.c 1.2.3+git2.25.1-1/git/trace2/tr2_cmd_name.c
--- 1.2.1+git2.18.0-1/git/trace2/tr2_cmd_name.c	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/trace2/tr2_cmd_name.c	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,30 @@
+#include "cache.h"
+#include "trace2/tr2_cmd_name.h"
+
+#define TR2_ENVVAR_PARENT_NAME "GIT_TRACE2_PARENT_NAME"
+
+static struct strbuf tr2cmdname_hierarchy = STRBUF_INIT;
+
+void tr2_cmd_name_append_hierarchy(const char *name)
+{
+	const char *parent_name = getenv(TR2_ENVVAR_PARENT_NAME);
+
+	strbuf_reset(&tr2cmdname_hierarchy);
+	if (parent_name && *parent_name) {
+		strbuf_addstr(&tr2cmdname_hierarchy, parent_name);
+		strbuf_addch(&tr2cmdname_hierarchy, '/');
+	}
+	strbuf_addstr(&tr2cmdname_hierarchy, name);
+
+	setenv(TR2_ENVVAR_PARENT_NAME, tr2cmdname_hierarchy.buf, 1);
+}
+
+const char *tr2_cmd_name_get_hierarchy(void)
+{
+	return tr2cmdname_hierarchy.buf;
+}
+
+void tr2_cmd_name_release(void)
+{
+	strbuf_release(&tr2cmdname_hierarchy);
+}
diff -pruN 1.2.1+git2.18.0-1/git/trace2/tr2_cmd_name.h 1.2.3+git2.25.1-1/git/trace2/tr2_cmd_name.h
--- 1.2.1+git2.18.0-1/git/trace2/tr2_cmd_name.h	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/trace2/tr2_cmd_name.h	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,24 @@
+#ifndef TR2_CMD_NAME_H
+#define TR2_CMD_NAME_H
+
+/*
+ * Append the current command name to the list being maintained
+ * in the environment.
+ *
+ * The hierarchy for a top-level git command is just the current
+ * command name.  For a child git process, the hierarchy includes the
+ * names of the parent processes.
+ *
+ * The hierarchy for the current process will be exported to the
+ * environment and inherited by child processes.
+ */
+void tr2_cmd_name_append_hierarchy(const char *name);
+
+/*
+ * Get the command name hierarchy for the current process.
+ */
+const char *tr2_cmd_name_get_hierarchy(void);
+
+void tr2_cmd_name_release(void);
+
+#endif /* TR2_CMD_NAME_H */
diff -pruN 1.2.1+git2.18.0-1/git/trace2/tr2_dst.c 1.2.3+git2.25.1-1/git/trace2/tr2_dst.c
--- 1.2.1+git2.18.0-1/git/trace2/tr2_dst.c	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/trace2/tr2_dst.c	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,391 @@
+#include "cache.h"
+#include "trace2/tr2_dst.h"
+#include "trace2/tr2_sid.h"
+#include "trace2/tr2_sysenv.h"
+
+/*
+ * How many attempts we will make at creating an automatically-named trace file.
+ */
+#define MAX_AUTO_ATTEMPTS 10
+
+/*
+ * Sentinel file used to detect when we should discard new traces to avoid
+ * writing too many trace files to a directory.
+ */
+#define DISCARD_SENTINEL_NAME "git-trace2-discard"
+
+/*
+ * When set to zero, disables directory file count checks. Otherwise, controls
+ * how many files we can write to a directory before entering discard mode.
+ * This can be overridden via the TR2_SYSENV_MAX_FILES setting.
+ */
+static int tr2env_max_files = 0;
+
+static int tr2_dst_want_warning(void)
+{
+	static int tr2env_dst_debug = -1;
+
+	if (tr2env_dst_debug == -1) {
+		const char *env_value = tr2_sysenv_get(TR2_SYSENV_DST_DEBUG);
+		if (!env_value || !*env_value)
+			tr2env_dst_debug = 0;
+		else
+			tr2env_dst_debug = atoi(env_value) > 0;
+	}
+
+	return tr2env_dst_debug;
+}
+
+void tr2_dst_trace_disable(struct tr2_dst *dst)
+{
+	if (dst->need_close)
+		close(dst->fd);
+	dst->fd = 0;
+	dst->initialized = 1;
+	dst->need_close = 0;
+}
+
+/*
+ * Check to make sure we're not overloading the target directory with too many
+ * files. First get the threshold (if present) from the config or envvar. If
+ * it's zero or unset, disable this check. Next check for the presence of a
+ * sentinel file, then check file count.
+ *
+ * Returns 0 if tracing should proceed as normal. Returns 1 if the sentinel file
+ * already exists, which means tracing should be disabled. Returns -1 if there
+ * are too many files but there was no sentinel file, which means we have
+ * created and should write traces to the sentinel file.
+ *
+ * We expect that some trace processing system is gradually collecting files
+ * from the target directory; after it removes the sentinel file we'll start
+ * writing traces again.
+ */
+static int tr2_dst_too_many_files(struct tr2_dst *dst, const char *tgt_prefix)
+{
+	int file_count = 0, max_files = 0, ret = 0;
+	const char *max_files_var;
+	DIR *dirp;
+	struct strbuf path = STRBUF_INIT, sentinel_path = STRBUF_INIT;
+	struct stat statbuf;
+
+	/* Get the config or envvar and decide if we should continue this check */
+	max_files_var = tr2_sysenv_get(TR2_SYSENV_MAX_FILES);
+	if (max_files_var && *max_files_var && ((max_files = atoi(max_files_var)) >= 0))
+		tr2env_max_files = max_files;
+
+	if (!tr2env_max_files) {
+		ret = 0;
+		goto cleanup;
+	}
+
+	strbuf_addstr(&path, tgt_prefix);
+	if (!is_dir_sep(path.buf[path.len - 1])) {
+		strbuf_addch(&path, '/');
+	}
+
+	/* check sentinel */
+	strbuf_addbuf(&sentinel_path, &path);
+	strbuf_addstr(&sentinel_path, DISCARD_SENTINEL_NAME);
+	if (!stat(sentinel_path.buf, &statbuf)) {
+		ret = 1;
+		goto cleanup;
+	}
+
+	/* check file count */
+	dirp = opendir(path.buf);
+	while (file_count < tr2env_max_files && dirp && readdir(dirp))
+		file_count++;
+	if (dirp)
+		closedir(dirp);
+
+	if (file_count >= tr2env_max_files) {
+		dst->too_many_files = 1;
+		dst->fd = open(sentinel_path.buf, O_WRONLY | O_CREAT | O_EXCL, 0666);
+		ret = -1;
+		goto cleanup;
+	}
+
+cleanup:
+	strbuf_release(&path);
+	strbuf_release(&sentinel_path);
+	return ret;
+}
+
+static int tr2_dst_try_auto_path(struct tr2_dst *dst, const char *tgt_prefix)
+{
+	int too_many_files;
+	const char *last_slash, *sid = tr2_sid_get();
+	struct strbuf path = STRBUF_INIT;
+	size_t base_path_len;
+	unsigned attempt_count;
+
+	last_slash = strrchr(sid, '/');
+	if (last_slash)
+		sid = last_slash + 1;
+
+	strbuf_addstr(&path, tgt_prefix);
+	if (!is_dir_sep(path.buf[path.len - 1]))
+		strbuf_addch(&path, '/');
+	strbuf_addstr(&path, sid);
+	base_path_len = path.len;
+
+	too_many_files = tr2_dst_too_many_files(dst, tgt_prefix);
+	if (!too_many_files) {
+		for (attempt_count = 0; attempt_count < MAX_AUTO_ATTEMPTS; attempt_count++) {
+			if (attempt_count > 0) {
+				strbuf_setlen(&path, base_path_len);
+				strbuf_addf(&path, ".%d", attempt_count);
+			}
+
+			dst->fd = open(path.buf, O_WRONLY | O_CREAT | O_EXCL, 0666);
+			if (dst->fd != -1)
+				break;
+		}
+	} else if (too_many_files == 1) {
+		strbuf_release(&path);
+		if (tr2_dst_want_warning())
+			warning("trace2: not opening %s trace file due to too "
+				"many files in target directory %s",
+				tr2_sysenv_display_name(dst->sysenv_var),
+				tgt_prefix);
+		return 0;
+	}
+
+	if (dst->fd == -1) {
+		if (tr2_dst_want_warning())
+			warning("trace2: could not open '%.*s' for '%s' tracing: %s",
+				(int) base_path_len, path.buf,
+				tr2_sysenv_display_name(dst->sysenv_var),
+				strerror(errno));
+
+		tr2_dst_trace_disable(dst);
+		strbuf_release(&path);
+		return 0;
+	}
+
+	strbuf_release(&path);
+
+	dst->need_close = 1;
+	dst->initialized = 1;
+
+	return dst->fd;
+}
+
+static int tr2_dst_try_path(struct tr2_dst *dst, const char *tgt_value)
+{
+	int fd = open(tgt_value, O_WRONLY | O_APPEND | O_CREAT, 0666);
+	if (fd == -1) {
+		if (tr2_dst_want_warning())
+			warning("trace2: could not open '%s' for '%s' tracing: %s",
+				tgt_value,
+				tr2_sysenv_display_name(dst->sysenv_var),
+				strerror(errno));
+
+		tr2_dst_trace_disable(dst);
+		return 0;
+	}
+
+	dst->fd = fd;
+	dst->need_close = 1;
+	dst->initialized = 1;
+
+	return dst->fd;
+}
+
+#ifndef NO_UNIX_SOCKETS
+#define PREFIX_AF_UNIX "af_unix:"
+#define PREFIX_AF_UNIX_STREAM "af_unix:stream:"
+#define PREFIX_AF_UNIX_DGRAM "af_unix:dgram:"
+
+static int tr2_dst_try_uds_connect(const char *path, int sock_type, int *out_fd)
+{
+	int fd;
+	struct sockaddr_un sa;
+
+	fd = socket(AF_UNIX, sock_type, 0);
+	if (fd == -1)
+		return errno;
+
+	sa.sun_family = AF_UNIX;
+	strlcpy(sa.sun_path, path, sizeof(sa.sun_path));
+
+	if (connect(fd, (struct sockaddr *)&sa, sizeof(sa)) == -1) {
+		int e = errno;
+		close(fd);
+		return e;
+	}
+
+	*out_fd = fd;
+	return 0;
+}
+
+#define TR2_DST_UDS_TRY_STREAM (1 << 0)
+#define TR2_DST_UDS_TRY_DGRAM  (1 << 1)
+
+static int tr2_dst_try_unix_domain_socket(struct tr2_dst *dst,
+					  const char *tgt_value)
+{
+	unsigned int uds_try = 0;
+	int fd;
+	int e;
+	const char *path = NULL;
+
+	/*
+	 * Allow "af_unix:[<type>:]<absolute_path>"
+	 *
+	 * Trace2 always writes complete individual messages (without
+	 * chunking), so we can talk to either DGRAM or STREAM type sockets.
+	 *
+	 * Allow the user to explicitly request the socket type.
+	 *
+	 * If they omit the socket type, try one and then the other.
+	 */
+
+	if (skip_prefix(tgt_value, PREFIX_AF_UNIX_STREAM, &path))
+		uds_try |= TR2_DST_UDS_TRY_STREAM;
+
+	else if (skip_prefix(tgt_value, PREFIX_AF_UNIX_DGRAM, &path))
+		uds_try |= TR2_DST_UDS_TRY_DGRAM;
+
+	else if (skip_prefix(tgt_value, PREFIX_AF_UNIX, &path))
+		uds_try |= TR2_DST_UDS_TRY_STREAM | TR2_DST_UDS_TRY_DGRAM;
+
+	if (!path || !*path) {
+		if (tr2_dst_want_warning())
+			warning("trace2: invalid AF_UNIX value '%s' for '%s' tracing",
+				tgt_value,
+				tr2_sysenv_display_name(dst->sysenv_var));
+
+		tr2_dst_trace_disable(dst);
+		return 0;
+	}
+
+	if (!is_absolute_path(path) ||
+	    strlen(path) >= sizeof(((struct sockaddr_un *)0)->sun_path)) {
+		if (tr2_dst_want_warning())
+			warning("trace2: invalid AF_UNIX path '%s' for '%s' tracing",
+				path, tr2_sysenv_display_name(dst->sysenv_var));
+
+		tr2_dst_trace_disable(dst);
+		return 0;
+	}
+
+	if (uds_try & TR2_DST_UDS_TRY_STREAM) {
+		e = tr2_dst_try_uds_connect(path, SOCK_STREAM, &fd);
+		if (!e)
+			goto connected;
+		if (e != EPROTOTYPE)
+			goto error;
+	}
+	if (uds_try & TR2_DST_UDS_TRY_DGRAM) {
+		e = tr2_dst_try_uds_connect(path, SOCK_DGRAM, &fd);
+		if (!e)
+			goto connected;
+	}
+
+error:
+	if (tr2_dst_want_warning())
+		warning("trace2: could not connect to socket '%s' for '%s' tracing: %s",
+			path, tr2_sysenv_display_name(dst->sysenv_var),
+			strerror(e));
+
+	tr2_dst_trace_disable(dst);
+	return 0;
+
+connected:
+	dst->fd = fd;
+	dst->need_close = 1;
+	dst->initialized = 1;
+
+	return dst->fd;
+}
+#endif
+
+static void tr2_dst_malformed_warning(struct tr2_dst *dst,
+				      const char *tgt_value)
+{
+	warning("trace2: unknown value for '%s': '%s'",
+		tr2_sysenv_display_name(dst->sysenv_var), tgt_value);
+}
+
+int tr2_dst_get_trace_fd(struct tr2_dst *dst)
+{
+	const char *tgt_value;
+
+	/* don't open twice */
+	if (dst->initialized)
+		return dst->fd;
+
+	dst->initialized = 1;
+
+	tgt_value = tr2_sysenv_get(dst->sysenv_var);
+
+	if (!tgt_value || !strcmp(tgt_value, "") || !strcmp(tgt_value, "0") ||
+	    !strcasecmp(tgt_value, "false")) {
+		dst->fd = 0;
+		return dst->fd;
+	}
+
+	if (!strcmp(tgt_value, "1") || !strcasecmp(tgt_value, "true")) {
+		dst->fd = STDERR_FILENO;
+		return dst->fd;
+	}
+
+	if (strlen(tgt_value) == 1 && isdigit(*tgt_value)) {
+		dst->fd = atoi(tgt_value);
+		return dst->fd;
+	}
+
+	if (is_absolute_path(tgt_value)) {
+		if (is_directory(tgt_value))
+			return tr2_dst_try_auto_path(dst, tgt_value);
+		else
+			return tr2_dst_try_path(dst, tgt_value);
+	}
+
+#ifndef NO_UNIX_SOCKETS
+	if (starts_with(tgt_value, PREFIX_AF_UNIX))
+		return tr2_dst_try_unix_domain_socket(dst, tgt_value);
+#endif
+
+	/* Always warn about malformed values. */
+	tr2_dst_malformed_warning(dst, tgt_value);
+	tr2_dst_trace_disable(dst);
+	return 0;
+}
+
+int tr2_dst_trace_want(struct tr2_dst *dst)
+{
+	return !!tr2_dst_get_trace_fd(dst);
+}
+
+void tr2_dst_write_line(struct tr2_dst *dst, struct strbuf *buf_line)
+{
+	int fd = tr2_dst_get_trace_fd(dst);
+
+	strbuf_complete_line(buf_line); /* ensure final NL on buffer */
+
+	/*
+	 * We do not use write_in_full() because we do not want
+	 * a short-write to try again.  We are using O_APPEND mode
+	 * files and the kernel handles the atomic seek+write. If
+	 * another thread or git process is concurrently writing to
+	 * this fd or file, our remainder-write may not be contiguous
+	 * with our initial write of this message.  And that will
+	 * confuse readers.  So just don't bother.
+	 *
+	 * It is assumed that TRACE2 messages are short enough that
+	 * the system can write them in 1 attempt and we won't see
+	 * a short-write.
+	 *
+	 * If we get an IO error, just close the trace dst.
+	 */
+	if (write(fd, buf_line->buf, buf_line->len) >= 0)
+		return;
+
+	if (tr2_dst_want_warning())
+		warning("unable to write trace to '%s': %s",
+			tr2_sysenv_display_name(dst->sysenv_var),
+			strerror(errno));
+	tr2_dst_trace_disable(dst);
+}
diff -pruN 1.2.1+git2.18.0-1/git/trace2/tr2_dst.h 1.2.3+git2.25.1-1/git/trace2/tr2_dst.h
--- 1.2.1+git2.18.0-1/git/trace2/tr2_dst.h	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/trace2/tr2_dst.h	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,38 @@
+#ifndef TR2_DST_H
+#define TR2_DST_H
+
+struct strbuf;
+#include "trace2/tr2_sysenv.h"
+
+struct tr2_dst {
+	enum tr2_sysenv_variable sysenv_var;
+	int fd;
+	unsigned int initialized : 1;
+	unsigned int need_close : 1;
+	unsigned int too_many_files : 1;
+};
+
+/*
+ * Disable TRACE2 on the destination.  In TRACE2 a destination (DST)
+ * wraps a file descriptor; it is associated with a TARGET which
+ * defines the formatting.
+ */
+void tr2_dst_trace_disable(struct tr2_dst *dst);
+
+/*
+ * Return the file descriptor for the DST.
+ * If 0, the dst is closed or disabled.
+ */
+int tr2_dst_get_trace_fd(struct tr2_dst *dst);
+
+/*
+ * Return true if the DST is opened for writing.
+ */
+int tr2_dst_trace_want(struct tr2_dst *dst);
+
+/*
+ * Write a single line/message to the trace file.
+ */
+void tr2_dst_write_line(struct tr2_dst *dst, struct strbuf *buf_line);
+
+#endif /* TR2_DST_H */
diff -pruN 1.2.1+git2.18.0-1/git/trace2/tr2_sid.c 1.2.3+git2.25.1-1/git/trace2/tr2_sid.c
--- 1.2.1+git2.18.0-1/git/trace2/tr2_sid.c	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/trace2/tr2_sid.c	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,112 @@
+#include "cache.h"
+#include "trace2/tr2_tbuf.h"
+#include "trace2/tr2_sid.h"
+
+#define TR2_ENVVAR_PARENT_SID "GIT_TRACE2_PARENT_SID"
+
+static struct strbuf tr2sid_buf = STRBUF_INIT;
+static int tr2sid_nr_git_parents;
+
+/*
+ * Compute the final component of the SID representing the current process.
+ * This should uniquely identify the process and be a valid filename (to
+ * allow writing trace2 data to per-process files).  It should also be fixed
+ * length for possible use as a database key.
+ *
+ * "<yyyymmdd>T<hhmmss>.<fraction>Z-<host>-<process>"
+ *
+ * where <host> is a 9 character string:
+ *    "H<first_8_chars_of_sha1_of_hostname>"
+ *    "Localhost" when no hostname.
+ *
+ * where <process> is a 9 character string containing the least significant
+ * 32 bits in the process-id.
+ *    "P<pid>"
+ * (This is an abribrary choice.  On most systems pid_t is a 32 bit value,
+ * so limit doesn't matter.  On larger systems, a truncated value is fine
+ * for our purposes here.)
+ */
+static void tr2_sid_append_my_sid_component(void)
+{
+	const struct git_hash_algo *algo = &hash_algos[GIT_HASH_SHA1];
+	struct tr2_tbuf tb_now;
+	git_hash_ctx ctx;
+	pid_t pid = getpid();
+	unsigned char hash[GIT_MAX_RAWSZ + 1];
+	char hex[GIT_MAX_HEXSZ + 1];
+	char hostname[HOST_NAME_MAX + 1];
+
+	tr2_tbuf_utc_datetime(&tb_now);
+	strbuf_addstr(&tr2sid_buf, tb_now.buf);
+
+	strbuf_addch(&tr2sid_buf, '-');
+	if (xgethostname(hostname, sizeof(hostname)))
+		strbuf_add(&tr2sid_buf, "Localhost", 9);
+	else {
+		algo->init_fn(&ctx);
+		algo->update_fn(&ctx, hostname, strlen(hostname));
+		algo->final_fn(hash, &ctx);
+		hash_to_hex_algop_r(hex, hash, algo);
+		strbuf_addch(&tr2sid_buf, 'H');
+		strbuf_add(&tr2sid_buf, hex, 8);
+	}
+
+	strbuf_addf(&tr2sid_buf, "-P%08"PRIx32, (uint32_t)pid);
+}
+
+/*
+ * Compute a "unique" session id (SID) for the current process.  This allows
+ * all events from this process to have a single label (much like a PID).
+ *
+ * Export this into our environment so that all child processes inherit it.
+ *
+ * If we were started by another git instance, use our parent's SID as a
+ * prefix.  (This lets us track parent/child relationships even if there
+ * is an intermediate shell process.)
+ *
+ * Additionally, count the number of nested git processes.
+ */
+static void tr2_sid_compute(void)
+{
+	const char *parent_sid;
+
+	if (tr2sid_buf.len)
+		return;
+
+	parent_sid = getenv(TR2_ENVVAR_PARENT_SID);
+	if (parent_sid && *parent_sid) {
+		const char *p;
+		for (p = parent_sid; *p; p++)
+			if (*p == '/')
+				tr2sid_nr_git_parents++;
+
+		strbuf_addstr(&tr2sid_buf, parent_sid);
+		strbuf_addch(&tr2sid_buf, '/');
+		tr2sid_nr_git_parents++;
+	}
+
+	tr2_sid_append_my_sid_component();
+
+	setenv(TR2_ENVVAR_PARENT_SID, tr2sid_buf.buf, 1);
+}
+
+const char *tr2_sid_get(void)
+{
+	if (!tr2sid_buf.len)
+		tr2_sid_compute();
+
+	return tr2sid_buf.buf;
+}
+
+int tr2_sid_depth(void)
+{
+	if (!tr2sid_buf.len)
+		tr2_sid_compute();
+
+	return tr2sid_nr_git_parents;
+}
+
+void tr2_sid_release(void)
+{
+	strbuf_release(&tr2sid_buf);
+}
diff -pruN 1.2.1+git2.18.0-1/git/trace2/tr2_sid.h 1.2.3+git2.25.1-1/git/trace2/tr2_sid.h
--- 1.2.1+git2.18.0-1/git/trace2/tr2_sid.h	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/trace2/tr2_sid.h	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,18 @@
+#ifndef TR2_SID_H
+#define TR2_SID_H
+
+/*
+ * Get our session id. Compute if necessary.
+ */
+const char *tr2_sid_get(void);
+
+/*
+ * Get our process depth.  A top-level git process invoked from the
+ * command line will have depth=0.  A child git process will have
+ * depth=1 and so on.
+ */
+int tr2_sid_depth(void);
+
+void tr2_sid_release(void);
+
+#endif /* TR2_SID_H */
diff -pruN 1.2.1+git2.18.0-1/git/trace2/tr2_sysenv.c 1.2.3+git2.25.1-1/git/trace2/tr2_sysenv.c
--- 1.2.1+git2.18.0-1/git/trace2/tr2_sysenv.c	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/trace2/tr2_sysenv.c	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,130 @@
+#include "cache.h"
+#include "config.h"
+#include "dir.h"
+#include "tr2_sysenv.h"
+
+/*
+ * Each entry represents a trace2 setting.
+ * See Documentation/technical/api-trace2.txt
+ */
+struct tr2_sysenv_entry {
+	const char *env_var_name;
+	const char *git_config_name;
+
+	char *value;
+	unsigned int getenv_called : 1;
+};
+
+/*
+ * This table must match "enum tr2_sysenv_variable" in tr2_sysenv.h.
+ *
+ * The strings in this table are constant and must match the published
+ * config and environment variable names as described in the documentation.
+ *
+ * We do not define entries for the GIT_TRACE2_PARENT_* environment
+ * variables because they are transient and used to pass information
+ * from parent to child git processes, rather than settings.
+ */
+/* clang-format off */
+static struct tr2_sysenv_entry tr2_sysenv_settings[] = {
+	[TR2_SYSENV_CFG_PARAM]     = { "GIT_TRACE2_CONFIG_PARAMS",
+				       "trace2.configparams" },
+
+	[TR2_SYSENV_DST_DEBUG]     = { "GIT_TRACE2_DST_DEBUG",
+				       "trace2.destinationdebug" },
+
+	[TR2_SYSENV_NORMAL]        = { "GIT_TRACE2",
+				       "trace2.normaltarget" },
+	[TR2_SYSENV_NORMAL_BRIEF]  = { "GIT_TRACE2_BRIEF",
+				       "trace2.normalbrief" },
+
+	[TR2_SYSENV_EVENT]         = { "GIT_TRACE2_EVENT",
+				       "trace2.eventtarget" },
+	[TR2_SYSENV_EVENT_BRIEF]   = { "GIT_TRACE2_EVENT_BRIEF",
+				       "trace2.eventbrief" },
+	[TR2_SYSENV_EVENT_NESTING] = { "GIT_TRACE2_EVENT_NESTING",
+				       "trace2.eventnesting" },
+
+	[TR2_SYSENV_PERF]          = { "GIT_TRACE2_PERF",
+				       "trace2.perftarget" },
+	[TR2_SYSENV_PERF_BRIEF]    = { "GIT_TRACE2_PERF_BRIEF",
+				       "trace2.perfbrief" },
+
+	[TR2_SYSENV_MAX_FILES]     = { "GIT_TRACE2_MAX_FILES",
+				       "trace2.maxfiles" },
+};
+/* clang-format on */
+
+static int tr2_sysenv_cb(const char *key, const char *value, void *d)
+{
+	int k;
+
+	if (!starts_with(key, "trace2."))
+		return 0;
+
+	for (k = 0; k < ARRAY_SIZE(tr2_sysenv_settings); k++) {
+		if (!strcmp(key, tr2_sysenv_settings[k].git_config_name)) {
+			free(tr2_sysenv_settings[k].value);
+			tr2_sysenv_settings[k].value = xstrdup(value);
+			return 0;
+		}
+	}
+
+	return 0;
+}
+
+/*
+ * Load Trace2 settings from the system config (usually "/etc/gitconfig"
+ * unless we were built with a runtime-prefix).  These are intended to
+ * define the default values for Trace2 as requested by the administrator.
+ *
+ * Then override with the Trace2 settings from the global config.
+ */
+void tr2_sysenv_load(void)
+{
+	if (ARRAY_SIZE(tr2_sysenv_settings) != TR2_SYSENV_MUST_BE_LAST)
+		BUG("tr2_sysenv_settings size is wrong");
+
+	read_very_early_config(tr2_sysenv_cb, NULL);
+}
+
+/*
+ * Return the value for the requested Trace2 setting from these sources:
+ * the system config, the global config, and the environment.
+ */
+const char *tr2_sysenv_get(enum tr2_sysenv_variable var)
+{
+	if (var >= TR2_SYSENV_MUST_BE_LAST)
+		BUG("tr2_sysenv_get invalid var '%d'", var);
+
+	if (!tr2_sysenv_settings[var].getenv_called) {
+		const char *v = getenv(tr2_sysenv_settings[var].env_var_name);
+		if (v && *v) {
+			free(tr2_sysenv_settings[var].value);
+			tr2_sysenv_settings[var].value = xstrdup(v);
+		}
+		tr2_sysenv_settings[var].getenv_called = 1;
+	}
+
+	return tr2_sysenv_settings[var].value;
+}
+
+/*
+ * Return a friendly name for this setting that is suitable for printing
+ * in an error messages.
+ */
+const char *tr2_sysenv_display_name(enum tr2_sysenv_variable var)
+{
+	if (var >= TR2_SYSENV_MUST_BE_LAST)
+		BUG("tr2_sysenv_get invalid var '%d'", var);
+
+	return tr2_sysenv_settings[var].env_var_name;
+}
+
+void tr2_sysenv_release(void)
+{
+	int k;
+
+	for (k = 0; k < ARRAY_SIZE(tr2_sysenv_settings); k++)
+		free(tr2_sysenv_settings[k].value);
+}
diff -pruN 1.2.1+git2.18.0-1/git/trace2/tr2_sysenv.h 1.2.3+git2.25.1-1/git/trace2/tr2_sysenv.h
--- 1.2.1+git2.18.0-1/git/trace2/tr2_sysenv.h	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/trace2/tr2_sysenv.h	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,38 @@
+#ifndef TR2_SYSENV_H
+#define TR2_SYSENV_H
+
+/*
+ * The Trace2 settings that can be loaded from /etc/gitconfig
+ * and/or user environment variables.
+ *
+ * Note that this set does not contain any of the transient
+ * environment variables used to pass information from parent
+ * to child git processes, such "GIT_TRACE2_PARENT_SID".
+ */
+enum tr2_sysenv_variable {
+	TR2_SYSENV_CFG_PARAM = 0,
+
+	TR2_SYSENV_DST_DEBUG,
+
+	TR2_SYSENV_NORMAL,
+	TR2_SYSENV_NORMAL_BRIEF,
+
+	TR2_SYSENV_EVENT,
+	TR2_SYSENV_EVENT_BRIEF,
+	TR2_SYSENV_EVENT_NESTING,
+
+	TR2_SYSENV_PERF,
+	TR2_SYSENV_PERF_BRIEF,
+
+	TR2_SYSENV_MAX_FILES,
+
+	TR2_SYSENV_MUST_BE_LAST
+};
+
+void tr2_sysenv_load(void);
+
+const char *tr2_sysenv_get(enum tr2_sysenv_variable);
+const char *tr2_sysenv_display_name(enum tr2_sysenv_variable var);
+void tr2_sysenv_release(void);
+
+#endif /* TR2_SYSENV_H */
diff -pruN 1.2.1+git2.18.0-1/git/trace2/tr2_tbuf.c 1.2.3+git2.25.1-1/git/trace2/tr2_tbuf.c
--- 1.2.1+git2.18.0-1/git/trace2/tr2_tbuf.c	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/trace2/tr2_tbuf.c	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,47 @@
+#include "cache.h"
+#include "tr2_tbuf.h"
+
+void tr2_tbuf_local_time(struct tr2_tbuf *tb)
+{
+	struct timeval tv;
+	struct tm tm;
+	time_t secs;
+
+	gettimeofday(&tv, NULL);
+	secs = tv.tv_sec;
+	localtime_r(&secs, &tm);
+
+	xsnprintf(tb->buf, sizeof(tb->buf), "%02d:%02d:%02d.%06ld", tm.tm_hour,
+		  tm.tm_min, tm.tm_sec, (long)tv.tv_usec);
+}
+
+void tr2_tbuf_utc_datetime_extended(struct tr2_tbuf *tb)
+{
+	struct timeval tv;
+	struct tm tm;
+	time_t secs;
+
+	gettimeofday(&tv, NULL);
+	secs = tv.tv_sec;
+	gmtime_r(&secs, &tm);
+
+	xsnprintf(tb->buf, sizeof(tb->buf),
+		  "%4d-%02d-%02dT%02d:%02d:%02d.%06ldZ", tm.tm_year + 1900,
+		  tm.tm_mon + 1, tm.tm_mday, tm.tm_hour, tm.tm_min, tm.tm_sec,
+		  (long)tv.tv_usec);
+}
+
+void tr2_tbuf_utc_datetime(struct tr2_tbuf *tb)
+{
+	struct timeval tv;
+	struct tm tm;
+	time_t secs;
+
+	gettimeofday(&tv, NULL);
+	secs = tv.tv_sec;
+	gmtime_r(&secs, &tm);
+
+	xsnprintf(tb->buf, sizeof(tb->buf), "%4d%02d%02dT%02d%02d%02d.%06ldZ",
+		  tm.tm_year + 1900, tm.tm_mon + 1, tm.tm_mday, tm.tm_hour,
+		  tm.tm_min, tm.tm_sec, (long)tv.tv_usec);
+}
diff -pruN 1.2.1+git2.18.0-1/git/trace2/tr2_tbuf.h 1.2.3+git2.25.1-1/git/trace2/tr2_tbuf.h
--- 1.2.1+git2.18.0-1/git/trace2/tr2_tbuf.h	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/trace2/tr2_tbuf.h	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,24 @@
+#ifndef TR2_TBUF_H
+#define TR2_TBUF_H
+
+/*
+ * A simple wrapper around a fixed buffer to avoid C syntax
+ * quirks and the need to pass around an additional size_t
+ * argument.
+ */
+struct tr2_tbuf {
+	char buf[32];
+};
+
+/*
+ * Fill buffer with formatted local time string.
+ */
+void tr2_tbuf_local_time(struct tr2_tbuf *tb);
+
+/*
+ * Fill buffer with formatted UTC datatime string.
+ */
+void tr2_tbuf_utc_datetime_extended(struct tr2_tbuf *tb);
+void tr2_tbuf_utc_datetime(struct tr2_tbuf *tb);
+
+#endif /* TR2_TBUF_H */
diff -pruN 1.2.1+git2.18.0-1/git/trace2/tr2_tgt_event.c 1.2.3+git2.25.1-1/git/trace2/tr2_tgt_event.c
--- 1.2.1+git2.18.0-1/git/trace2/tr2_tgt_event.c	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/trace2/tr2_tgt_event.c	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,603 @@
+#include "cache.h"
+#include "config.h"
+#include "json-writer.h"
+#include "run-command.h"
+#include "version.h"
+#include "trace2/tr2_dst.h"
+#include "trace2/tr2_tbuf.h"
+#include "trace2/tr2_sid.h"
+#include "trace2/tr2_sysenv.h"
+#include "trace2/tr2_tgt.h"
+#include "trace2/tr2_tls.h"
+
+static struct tr2_dst tr2dst_event = { TR2_SYSENV_EVENT, 0, 0, 0, 0 };
+
+/*
+ * The version number of the JSON data generated by the EVENT target in this
+ * source file. The version should be incremented if new event types are added,
+ * if existing fields are removed, or if there are significant changes in
+ * interpretation of existing events or fields. Smaller changes, such as adding
+ * a new field to an existing event, do not require an increment to the EVENT
+ * format version.
+ */
+#define TR2_EVENT_VERSION "2"
+
+/*
+ * Region nesting limit for messages written to the event target.
+ *
+ * The "region_enter" and "region_leave" messages (especially recursive
+ * messages such as those produced while diving the worktree or index)
+ * are primarily intended for the performance target during debugging.
+ *
+ * Some of the outer-most messages, however, may be of interest to the
+ * event target.  Use the TR2_SYSENV_EVENT_NESTING setting to increase
+ * region details in the event target.
+ */
+static int tr2env_event_max_nesting_levels = 2;
+
+/*
+ * Use the TR2_SYSENV_EVENT_BRIEF to omit the <time>, <file>, and
+ * <line> fields from most events.
+ */
+static int tr2env_event_be_brief;
+
+static int fn_init(void)
+{
+	int want = tr2_dst_trace_want(&tr2dst_event);
+	int max_nesting;
+	int want_brief;
+	const char *nesting;
+	const char *brief;
+
+	if (!want)
+		return want;
+
+	nesting = tr2_sysenv_get(TR2_SYSENV_EVENT_NESTING);
+	if (nesting && *nesting && ((max_nesting = atoi(nesting)) > 0))
+		tr2env_event_max_nesting_levels = max_nesting;
+
+	brief = tr2_sysenv_get(TR2_SYSENV_EVENT_BRIEF);
+	if (brief && *brief &&
+	    ((want_brief = git_parse_maybe_bool(brief)) != -1))
+		tr2env_event_be_brief = want_brief;
+
+	return want;
+}
+
+static void fn_term(void)
+{
+	tr2_dst_trace_disable(&tr2dst_event);
+}
+
+/*
+ * Append common key-value pairs to the currently open JSON object.
+ *     "event:"<event_name>"
+ *      "sid":"<sid>"
+ *   "thread":"<thread_name>"
+ *     "time":"<time>"
+ *     "file":"<filename>"
+ *     "line":<line_number>
+ *     "repo":<repo_id>
+ */
+static void event_fmt_prepare(const char *event_name, const char *file,
+			      int line, const struct repository *repo,
+			      struct json_writer *jw)
+{
+	struct tr2tls_thread_ctx *ctx = tr2tls_get_self();
+	struct tr2_tbuf tb_now;
+
+	jw_object_string(jw, "event", event_name);
+	jw_object_string(jw, "sid", tr2_sid_get());
+	jw_object_string(jw, "thread", ctx->thread_name.buf);
+
+	/*
+	 * In brief mode, only emit <time> on these 2 event types.
+	 */
+	if (!tr2env_event_be_brief || !strcmp(event_name, "version") ||
+	    !strcmp(event_name, "atexit")) {
+		tr2_tbuf_utc_datetime_extended(&tb_now);
+		jw_object_string(jw, "time", tb_now.buf);
+	}
+
+	if (!tr2env_event_be_brief && file && *file) {
+		jw_object_string(jw, "file", file);
+		jw_object_intmax(jw, "line", line);
+	}
+
+	if (repo)
+		jw_object_intmax(jw, "repo", repo->trace2_repo_id);
+}
+
+static void fn_too_many_files_fl(const char *file, int line)
+{
+	const char *event_name = "too_many_files";
+	struct json_writer jw = JSON_WRITER_INIT;
+
+	jw_object_begin(&jw, 0);
+	event_fmt_prepare(event_name, file, line, NULL, &jw);
+	jw_end(&jw);
+
+	tr2_dst_write_line(&tr2dst_event, &jw.json);
+	jw_release(&jw);
+}
+
+static void fn_version_fl(const char *file, int line)
+{
+	const char *event_name = "version";
+	struct json_writer jw = JSON_WRITER_INIT;
+
+	jw_object_begin(&jw, 0);
+	event_fmt_prepare(event_name, file, line, NULL, &jw);
+	jw_object_string(&jw, "evt", TR2_EVENT_VERSION);
+	jw_object_string(&jw, "exe", git_version_string);
+	jw_end(&jw);
+
+	tr2_dst_write_line(&tr2dst_event, &jw.json);
+	jw_release(&jw);
+
+	if (tr2dst_event.too_many_files)
+		fn_too_many_files_fl(file, line);
+}
+
+static void fn_start_fl(const char *file, int line,
+			uint64_t us_elapsed_absolute, const char **argv)
+{
+	const char *event_name = "start";
+	struct json_writer jw = JSON_WRITER_INIT;
+	double t_abs = (double)us_elapsed_absolute / 1000000.0;
+
+	jw_object_begin(&jw, 0);
+	event_fmt_prepare(event_name, file, line, NULL, &jw);
+	jw_object_double(&jw, "t_abs", 6, t_abs);
+	jw_object_inline_begin_array(&jw, "argv");
+	jw_array_argv(&jw, argv);
+	jw_end(&jw);
+	jw_end(&jw);
+
+	tr2_dst_write_line(&tr2dst_event, &jw.json);
+	jw_release(&jw);
+}
+
+static void fn_exit_fl(const char *file, int line, uint64_t us_elapsed_absolute,
+		       int code)
+{
+	const char *event_name = "exit";
+	struct json_writer jw = JSON_WRITER_INIT;
+	double t_abs = (double)us_elapsed_absolute / 1000000.0;
+
+	jw_object_begin(&jw, 0);
+	event_fmt_prepare(event_name, file, line, NULL, &jw);
+	jw_object_double(&jw, "t_abs", 6, t_abs);
+	jw_object_intmax(&jw, "code", code);
+	jw_end(&jw);
+
+	tr2_dst_write_line(&tr2dst_event, &jw.json);
+	jw_release(&jw);
+}
+
+static void fn_signal(uint64_t us_elapsed_absolute, int signo)
+{
+	const char *event_name = "signal";
+	struct json_writer jw = JSON_WRITER_INIT;
+	double t_abs = (double)us_elapsed_absolute / 1000000.0;
+
+	jw_object_begin(&jw, 0);
+	event_fmt_prepare(event_name, __FILE__, __LINE__, NULL, &jw);
+	jw_object_double(&jw, "t_abs", 6, t_abs);
+	jw_object_intmax(&jw, "signo", signo);
+	jw_end(&jw);
+
+	tr2_dst_write_line(&tr2dst_event, &jw.json);
+	jw_release(&jw);
+}
+
+static void fn_atexit(uint64_t us_elapsed_absolute, int code)
+{
+	const char *event_name = "atexit";
+	struct json_writer jw = JSON_WRITER_INIT;
+	double t_abs = (double)us_elapsed_absolute / 1000000.0;
+
+	jw_object_begin(&jw, 0);
+	event_fmt_prepare(event_name, __FILE__, __LINE__, NULL, &jw);
+	jw_object_double(&jw, "t_abs", 6, t_abs);
+	jw_object_intmax(&jw, "code", code);
+	jw_end(&jw);
+
+	tr2_dst_write_line(&tr2dst_event, &jw.json);
+	jw_release(&jw);
+}
+
+static void maybe_add_string_va(struct json_writer *jw, const char *field_name,
+				const char *fmt, va_list ap)
+{
+	if (fmt && *fmt) {
+		va_list copy_ap;
+		struct strbuf buf = STRBUF_INIT;
+
+		va_copy(copy_ap, ap);
+		strbuf_vaddf(&buf, fmt, copy_ap);
+		va_end(copy_ap);
+
+		jw_object_string(jw, field_name, buf.buf);
+		strbuf_release(&buf);
+		return;
+	}
+}
+
+static void fn_error_va_fl(const char *file, int line, const char *fmt,
+			   va_list ap)
+{
+	const char *event_name = "error";
+	struct json_writer jw = JSON_WRITER_INIT;
+
+	jw_object_begin(&jw, 0);
+	event_fmt_prepare(event_name, file, line, NULL, &jw);
+	maybe_add_string_va(&jw, "msg", fmt, ap);
+	/*
+	 * Also emit the format string as a field in case
+	 * post-processors want to aggregate common error
+	 * messages by type without argument fields (such
+	 * as pathnames or branch names) cluttering it up.
+	 */
+	if (fmt && *fmt)
+		jw_object_string(&jw, "fmt", fmt);
+	jw_end(&jw);
+
+	tr2_dst_write_line(&tr2dst_event, &jw.json);
+	jw_release(&jw);
+}
+
+static void fn_command_path_fl(const char *file, int line, const char *pathname)
+{
+	const char *event_name = "cmd_path";
+	struct json_writer jw = JSON_WRITER_INIT;
+
+	jw_object_begin(&jw, 0);
+	event_fmt_prepare(event_name, file, line, NULL, &jw);
+	jw_object_string(&jw, "path", pathname);
+	jw_end(&jw);
+
+	tr2_dst_write_line(&tr2dst_event, &jw.json);
+	jw_release(&jw);
+}
+
+static void fn_command_name_fl(const char *file, int line, const char *name,
+			       const char *hierarchy)
+{
+	const char *event_name = "cmd_name";
+	struct json_writer jw = JSON_WRITER_INIT;
+
+	jw_object_begin(&jw, 0);
+	event_fmt_prepare(event_name, file, line, NULL, &jw);
+	jw_object_string(&jw, "name", name);
+	if (hierarchy && *hierarchy)
+		jw_object_string(&jw, "hierarchy", hierarchy);
+	jw_end(&jw);
+
+	tr2_dst_write_line(&tr2dst_event, &jw.json);
+	jw_release(&jw);
+}
+
+static void fn_command_mode_fl(const char *file, int line, const char *mode)
+{
+	const char *event_name = "cmd_mode";
+	struct json_writer jw = JSON_WRITER_INIT;
+
+	jw_object_begin(&jw, 0);
+	event_fmt_prepare(event_name, file, line, NULL, &jw);
+	jw_object_string(&jw, "name", mode);
+	jw_end(&jw);
+
+	tr2_dst_write_line(&tr2dst_event, &jw.json);
+	jw_release(&jw);
+}
+
+static void fn_alias_fl(const char *file, int line, const char *alias,
+			const char **argv)
+{
+	const char *event_name = "alias";
+	struct json_writer jw = JSON_WRITER_INIT;
+
+	jw_object_begin(&jw, 0);
+	event_fmt_prepare(event_name, file, line, NULL, &jw);
+	jw_object_string(&jw, "alias", alias);
+	jw_object_inline_begin_array(&jw, "argv");
+	jw_array_argv(&jw, argv);
+	jw_end(&jw);
+	jw_end(&jw);
+
+	tr2_dst_write_line(&tr2dst_event, &jw.json);
+	jw_release(&jw);
+}
+
+static void fn_child_start_fl(const char *file, int line,
+			      uint64_t us_elapsed_absolute,
+			      const struct child_process *cmd)
+{
+	const char *event_name = "child_start";
+	struct json_writer jw = JSON_WRITER_INIT;
+
+	jw_object_begin(&jw, 0);
+	event_fmt_prepare(event_name, file, line, NULL, &jw);
+	jw_object_intmax(&jw, "child_id", cmd->trace2_child_id);
+	if (cmd->trace2_hook_name) {
+		jw_object_string(&jw, "child_class", "hook");
+		jw_object_string(&jw, "hook_name", cmd->trace2_hook_name);
+	} else {
+		const char *child_class =
+			cmd->trace2_child_class ? cmd->trace2_child_class : "?";
+		jw_object_string(&jw, "child_class", child_class);
+	}
+	if (cmd->dir)
+		jw_object_string(&jw, "cd", cmd->dir);
+	jw_object_bool(&jw, "use_shell", cmd->use_shell);
+	jw_object_inline_begin_array(&jw, "argv");
+	if (cmd->git_cmd)
+		jw_array_string(&jw, "git");
+	jw_array_argv(&jw, cmd->argv);
+	jw_end(&jw);
+	jw_end(&jw);
+
+	tr2_dst_write_line(&tr2dst_event, &jw.json);
+	jw_release(&jw);
+}
+
+static void fn_child_exit_fl(const char *file, int line,
+			     uint64_t us_elapsed_absolute, int cid, int pid,
+			     int code, uint64_t us_elapsed_child)
+{
+	const char *event_name = "child_exit";
+	struct json_writer jw = JSON_WRITER_INIT;
+	double t_rel = (double)us_elapsed_child / 1000000.0;
+
+	jw_object_begin(&jw, 0);
+	event_fmt_prepare(event_name, file, line, NULL, &jw);
+	jw_object_intmax(&jw, "child_id", cid);
+	jw_object_intmax(&jw, "pid", pid);
+	jw_object_intmax(&jw, "code", code);
+	jw_object_double(&jw, "t_rel", 6, t_rel);
+	jw_end(&jw);
+
+	tr2_dst_write_line(&tr2dst_event, &jw.json);
+
+	jw_release(&jw);
+}
+
+static void fn_thread_start_fl(const char *file, int line,
+			       uint64_t us_elapsed_absolute)
+{
+	const char *event_name = "thread_start";
+	struct json_writer jw = JSON_WRITER_INIT;
+
+	jw_object_begin(&jw, 0);
+	event_fmt_prepare(event_name, file, line, NULL, &jw);
+	jw_end(&jw);
+
+	tr2_dst_write_line(&tr2dst_event, &jw.json);
+	jw_release(&jw);
+}
+
+static void fn_thread_exit_fl(const char *file, int line,
+			      uint64_t us_elapsed_absolute,
+			      uint64_t us_elapsed_thread)
+{
+	const char *event_name = "thread_exit";
+	struct json_writer jw = JSON_WRITER_INIT;
+	double t_rel = (double)us_elapsed_thread / 1000000.0;
+
+	jw_object_begin(&jw, 0);
+	event_fmt_prepare(event_name, file, line, NULL, &jw);
+	jw_object_double(&jw, "t_rel", 6, t_rel);
+	jw_end(&jw);
+
+	tr2_dst_write_line(&tr2dst_event, &jw.json);
+	jw_release(&jw);
+}
+
+static void fn_exec_fl(const char *file, int line, uint64_t us_elapsed_absolute,
+		       int exec_id, const char *exe, const char **argv)
+{
+	const char *event_name = "exec";
+	struct json_writer jw = JSON_WRITER_INIT;
+
+	jw_object_begin(&jw, 0);
+	event_fmt_prepare(event_name, file, line, NULL, &jw);
+	jw_object_intmax(&jw, "exec_id", exec_id);
+	if (exe)
+		jw_object_string(&jw, "exe", exe);
+	jw_object_inline_begin_array(&jw, "argv");
+	jw_array_argv(&jw, argv);
+	jw_end(&jw);
+	jw_end(&jw);
+
+	tr2_dst_write_line(&tr2dst_event, &jw.json);
+	jw_release(&jw);
+}
+
+static void fn_exec_result_fl(const char *file, int line,
+			      uint64_t us_elapsed_absolute, int exec_id,
+			      int code)
+{
+	const char *event_name = "exec_result";
+	struct json_writer jw = JSON_WRITER_INIT;
+
+	jw_object_begin(&jw, 0);
+	event_fmt_prepare(event_name, file, line, NULL, &jw);
+	jw_object_intmax(&jw, "exec_id", exec_id);
+	jw_object_intmax(&jw, "code", code);
+	jw_end(&jw);
+
+	tr2_dst_write_line(&tr2dst_event, &jw.json);
+	jw_release(&jw);
+}
+
+static void fn_param_fl(const char *file, int line, const char *param,
+			const char *value)
+{
+	const char *event_name = "def_param";
+	struct json_writer jw = JSON_WRITER_INIT;
+
+	jw_object_begin(&jw, 0);
+	event_fmt_prepare(event_name, file, line, NULL, &jw);
+	jw_object_string(&jw, "param", param);
+	jw_object_string(&jw, "value", value);
+	jw_end(&jw);
+
+	tr2_dst_write_line(&tr2dst_event, &jw.json);
+	jw_release(&jw);
+}
+
+static void fn_repo_fl(const char *file, int line,
+		       const struct repository *repo)
+{
+	const char *event_name = "def_repo";
+	struct json_writer jw = JSON_WRITER_INIT;
+
+	jw_object_begin(&jw, 0);
+	event_fmt_prepare(event_name, file, line, repo, &jw);
+	jw_object_string(&jw, "worktree", repo->worktree);
+	jw_end(&jw);
+
+	tr2_dst_write_line(&tr2dst_event, &jw.json);
+	jw_release(&jw);
+}
+
+static void fn_region_enter_printf_va_fl(const char *file, int line,
+					 uint64_t us_elapsed_absolute,
+					 const char *category,
+					 const char *label,
+					 const struct repository *repo,
+					 const char *fmt, va_list ap)
+{
+	const char *event_name = "region_enter";
+	struct tr2tls_thread_ctx *ctx = tr2tls_get_self();
+	if (ctx->nr_open_regions <= tr2env_event_max_nesting_levels) {
+		struct json_writer jw = JSON_WRITER_INIT;
+
+		jw_object_begin(&jw, 0);
+		event_fmt_prepare(event_name, file, line, repo, &jw);
+		jw_object_intmax(&jw, "nesting", ctx->nr_open_regions);
+		if (category)
+			jw_object_string(&jw, "category", category);
+		if (label)
+			jw_object_string(&jw, "label", label);
+		maybe_add_string_va(&jw, "msg", fmt, ap);
+		jw_end(&jw);
+
+		tr2_dst_write_line(&tr2dst_event, &jw.json);
+		jw_release(&jw);
+	}
+}
+
+static void fn_region_leave_printf_va_fl(
+	const char *file, int line, uint64_t us_elapsed_absolute,
+	uint64_t us_elapsed_region, const char *category, const char *label,
+	const struct repository *repo, const char *fmt, va_list ap)
+{
+	const char *event_name = "region_leave";
+	struct tr2tls_thread_ctx *ctx = tr2tls_get_self();
+	if (ctx->nr_open_regions <= tr2env_event_max_nesting_levels) {
+		struct json_writer jw = JSON_WRITER_INIT;
+		double t_rel = (double)us_elapsed_region / 1000000.0;
+
+		jw_object_begin(&jw, 0);
+		event_fmt_prepare(event_name, file, line, repo, &jw);
+		jw_object_double(&jw, "t_rel", 6, t_rel);
+		jw_object_intmax(&jw, "nesting", ctx->nr_open_regions);
+		if (category)
+			jw_object_string(&jw, "category", category);
+		if (label)
+			jw_object_string(&jw, "label", label);
+		maybe_add_string_va(&jw, "msg", fmt, ap);
+		jw_end(&jw);
+
+		tr2_dst_write_line(&tr2dst_event, &jw.json);
+		jw_release(&jw);
+	}
+}
+
+static void fn_data_fl(const char *file, int line, uint64_t us_elapsed_absolute,
+		       uint64_t us_elapsed_region, const char *category,
+		       const struct repository *repo, const char *key,
+		       const char *value)
+{
+	const char *event_name = "data";
+	struct tr2tls_thread_ctx *ctx = tr2tls_get_self();
+	if (ctx->nr_open_regions <= tr2env_event_max_nesting_levels) {
+		struct json_writer jw = JSON_WRITER_INIT;
+		double t_abs = (double)us_elapsed_absolute / 1000000.0;
+		double t_rel = (double)us_elapsed_region / 1000000.0;
+
+		jw_object_begin(&jw, 0);
+		event_fmt_prepare(event_name, file, line, repo, &jw);
+		jw_object_double(&jw, "t_abs", 6, t_abs);
+		jw_object_double(&jw, "t_rel", 6, t_rel);
+		jw_object_intmax(&jw, "nesting", ctx->nr_open_regions);
+		jw_object_string(&jw, "category", category);
+		jw_object_string(&jw, "key", key);
+		jw_object_string(&jw, "value", value);
+		jw_end(&jw);
+
+		tr2_dst_write_line(&tr2dst_event, &jw.json);
+		jw_release(&jw);
+	}
+}
+
+static void fn_data_json_fl(const char *file, int line,
+			    uint64_t us_elapsed_absolute,
+			    uint64_t us_elapsed_region, const char *category,
+			    const struct repository *repo, const char *key,
+			    const struct json_writer *value)
+{
+	const char *event_name = "data_json";
+	struct tr2tls_thread_ctx *ctx = tr2tls_get_self();
+	if (ctx->nr_open_regions <= tr2env_event_max_nesting_levels) {
+		struct json_writer jw = JSON_WRITER_INIT;
+		double t_abs = (double)us_elapsed_absolute / 1000000.0;
+		double t_rel = (double)us_elapsed_region / 1000000.0;
+
+		jw_object_begin(&jw, 0);
+		event_fmt_prepare(event_name, file, line, repo, &jw);
+		jw_object_double(&jw, "t_abs", 6, t_abs);
+		jw_object_double(&jw, "t_rel", 6, t_rel);
+		jw_object_intmax(&jw, "nesting", ctx->nr_open_regions);
+		jw_object_string(&jw, "category", category);
+		jw_object_string(&jw, "key", key);
+		jw_object_sub_jw(&jw, "value", value);
+		jw_end(&jw);
+
+		tr2_dst_write_line(&tr2dst_event, &jw.json);
+		jw_release(&jw);
+	}
+}
+
+struct tr2_tgt tr2_tgt_event = {
+	&tr2dst_event,
+
+	fn_init,
+	fn_term,
+
+	fn_version_fl,
+	fn_start_fl,
+	fn_exit_fl,
+	fn_signal,
+	fn_atexit,
+	fn_error_va_fl,
+	fn_command_path_fl,
+	fn_command_name_fl,
+	fn_command_mode_fl,
+	fn_alias_fl,
+	fn_child_start_fl,
+	fn_child_exit_fl,
+	fn_thread_start_fl,
+	fn_thread_exit_fl,
+	fn_exec_fl,
+	fn_exec_result_fl,
+	fn_param_fl,
+	fn_repo_fl,
+	fn_region_enter_printf_va_fl,
+	fn_region_leave_printf_va_fl,
+	fn_data_fl,
+	fn_data_json_fl,
+	NULL, /* printf */
+};
diff -pruN 1.2.1+git2.18.0-1/git/trace2/tr2_tgt.h 1.2.3+git2.25.1-1/git/trace2/tr2_tgt.h
--- 1.2.1+git2.18.0-1/git/trace2/tr2_tgt.h	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/trace2/tr2_tgt.h	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,134 @@
+#ifndef TR2_TGT_H
+#define TR2_TGT_H
+
+struct child_process;
+struct repository;
+struct json_writer;
+
+/*
+ * Function prototypes for a TRACE2 "target" vtable.
+ */
+
+typedef int(tr2_tgt_init_t)(void);
+typedef void(tr2_tgt_term_t)(void);
+
+typedef void(tr2_tgt_evt_version_fl_t)(const char *file, int line);
+
+typedef void(tr2_tgt_evt_start_fl_t)(const char *file, int line,
+				     uint64_t us_elapsed_absolute,
+				     const char **argv);
+typedef void(tr2_tgt_evt_exit_fl_t)(const char *file, int line,
+				    uint64_t us_elapsed_absolute, int code);
+typedef void(tr2_tgt_evt_signal_t)(uint64_t us_elapsed_absolute, int signo);
+typedef void(tr2_tgt_evt_atexit_t)(uint64_t us_elapsed_absolute, int code);
+
+typedef void(tr2_tgt_evt_error_va_fl_t)(const char *file, int line,
+					const char *fmt, va_list ap);
+
+typedef void(tr2_tgt_evt_command_path_fl_t)(const char *file, int line,
+					    const char *command_path);
+typedef void(tr2_tgt_evt_command_name_fl_t)(const char *file, int line,
+					    const char *name,
+					    const char *hierarchy);
+typedef void(tr2_tgt_evt_command_mode_fl_t)(const char *file, int line,
+					    const char *mode);
+
+typedef void(tr2_tgt_evt_alias_fl_t)(const char *file, int line,
+				     const char *alias, const char **argv);
+
+typedef void(tr2_tgt_evt_child_start_fl_t)(const char *file, int line,
+					   uint64_t us_elapsed_absolute,
+					   const struct child_process *cmd);
+typedef void(tr2_tgt_evt_child_exit_fl_t)(const char *file, int line,
+					  uint64_t us_elapsed_absolute, int cid,
+					  int pid, int code,
+					  uint64_t us_elapsed_child);
+
+typedef void(tr2_tgt_evt_thread_start_fl_t)(const char *file, int line,
+					    uint64_t us_elapsed_absolute);
+typedef void(tr2_tgt_evt_thread_exit_fl_t)(const char *file, int line,
+					   uint64_t us_elapsed_absolute,
+					   uint64_t us_elapsed_thread);
+
+typedef void(tr2_tgt_evt_exec_fl_t)(const char *file, int line,
+				    uint64_t us_elapsed_absolute, int exec_id,
+				    const char *exe, const char **argv);
+typedef void(tr2_tgt_evt_exec_result_fl_t)(const char *file, int line,
+					   uint64_t us_elapsed_absolute,
+					   int exec_id, int code);
+
+typedef void(tr2_tgt_evt_param_fl_t)(const char *file, int line,
+				     const char *param, const char *value);
+
+typedef void(tr2_tgt_evt_repo_fl_t)(const char *file, int line,
+				    const struct repository *repo);
+
+typedef void(tr2_tgt_evt_region_enter_printf_va_fl_t)(
+	const char *file, int line, uint64_t us_elapsed_absolute,
+	const char *category, const char *label, const struct repository *repo,
+	const char *fmt, va_list ap);
+typedef void(tr2_tgt_evt_region_leave_printf_va_fl_t)(
+	const char *file, int line, uint64_t us_elapsed_absolute,
+	uint64_t us_elapsed_region, const char *category, const char *label,
+	const struct repository *repo, const char *fmt, va_list ap);
+
+typedef void(tr2_tgt_evt_data_fl_t)(const char *file, int line,
+				    uint64_t us_elapsed_absolute,
+				    uint64_t us_elapsed_region,
+				    const char *category,
+				    const struct repository *repo,
+				    const char *key, const char *value);
+typedef void(tr2_tgt_evt_data_json_fl_t)(const char *file, int line,
+					 uint64_t us_elapsed_absolute,
+					 uint64_t us_elapsed_region,
+					 const char *category,
+					 const struct repository *repo,
+					 const char *key,
+					 const struct json_writer *value);
+
+typedef void(tr2_tgt_evt_printf_va_fl_t)(const char *file, int line,
+					 uint64_t us_elapsed_absolute,
+					 const char *fmt, va_list ap);
+
+/*
+ * "vtable" for a TRACE2 target.  Use NULL if a target does not want
+ * to emit that message.
+ */
+/* clang-format off */
+struct tr2_tgt {
+	struct tr2_dst                          *pdst;
+
+	tr2_tgt_init_t                          *pfn_init;
+	tr2_tgt_term_t                          *pfn_term;
+
+	tr2_tgt_evt_version_fl_t                *pfn_version_fl;
+	tr2_tgt_evt_start_fl_t                  *pfn_start_fl;
+	tr2_tgt_evt_exit_fl_t                   *pfn_exit_fl;
+	tr2_tgt_evt_signal_t                    *pfn_signal;
+	tr2_tgt_evt_atexit_t                    *pfn_atexit;
+	tr2_tgt_evt_error_va_fl_t               *pfn_error_va_fl;
+	tr2_tgt_evt_command_path_fl_t           *pfn_command_path_fl;
+	tr2_tgt_evt_command_name_fl_t           *pfn_command_name_fl;
+	tr2_tgt_evt_command_mode_fl_t           *pfn_command_mode_fl;
+	tr2_tgt_evt_alias_fl_t                  *pfn_alias_fl;
+	tr2_tgt_evt_child_start_fl_t            *pfn_child_start_fl;
+	tr2_tgt_evt_child_exit_fl_t             *pfn_child_exit_fl;
+	tr2_tgt_evt_thread_start_fl_t           *pfn_thread_start_fl;
+	tr2_tgt_evt_thread_exit_fl_t            *pfn_thread_exit_fl;
+	tr2_tgt_evt_exec_fl_t                   *pfn_exec_fl;
+	tr2_tgt_evt_exec_result_fl_t            *pfn_exec_result_fl;
+	tr2_tgt_evt_param_fl_t                  *pfn_param_fl;
+	tr2_tgt_evt_repo_fl_t                   *pfn_repo_fl;
+	tr2_tgt_evt_region_enter_printf_va_fl_t *pfn_region_enter_printf_va_fl;
+	tr2_tgt_evt_region_leave_printf_va_fl_t *pfn_region_leave_printf_va_fl;
+	tr2_tgt_evt_data_fl_t                   *pfn_data_fl;
+	tr2_tgt_evt_data_json_fl_t              *pfn_data_json_fl;
+	tr2_tgt_evt_printf_va_fl_t              *pfn_printf_va_fl;
+};
+/* clang-format on */
+
+extern struct tr2_tgt tr2_tgt_event;
+extern struct tr2_tgt tr2_tgt_normal;
+extern struct tr2_tgt tr2_tgt_perf;
+
+#endif /* TR2_TGT_H */
diff -pruN 1.2.1+git2.18.0-1/git/trace2/tr2_tgt_normal.c 1.2.3+git2.25.1-1/git/trace2/tr2_tgt_normal.c
--- 1.2.1+git2.18.0-1/git/trace2/tr2_tgt_normal.c	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/trace2/tr2_tgt_normal.c	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,325 @@
+#include "cache.h"
+#include "config.h"
+#include "run-command.h"
+#include "quote.h"
+#include "version.h"
+#include "trace2/tr2_dst.h"
+#include "trace2/tr2_sysenv.h"
+#include "trace2/tr2_tbuf.h"
+#include "trace2/tr2_tgt.h"
+#include "trace2/tr2_tls.h"
+
+static struct tr2_dst tr2dst_normal = { TR2_SYSENV_NORMAL, 0, 0, 0, 0 };
+
+/*
+ * Use the TR2_SYSENV_NORMAL_BRIEF setting to omit the "<time> <file>:<line>"
+ * fields from each line written to the builtin normal target.
+ *
+ * Unit tests may want to use this to help with testing.
+ */
+static int tr2env_normal_be_brief;
+
+#define TR2FMT_NORMAL_FL_WIDTH (50)
+
+static int fn_init(void)
+{
+	int want = tr2_dst_trace_want(&tr2dst_normal);
+	int want_brief;
+	const char *brief;
+
+	if (!want)
+		return want;
+
+	brief = tr2_sysenv_get(TR2_SYSENV_NORMAL_BRIEF);
+	if (brief && *brief &&
+	    ((want_brief = git_parse_maybe_bool(brief)) != -1))
+		tr2env_normal_be_brief = want_brief;
+
+	return want;
+}
+
+static void fn_term(void)
+{
+	tr2_dst_trace_disable(&tr2dst_normal);
+}
+
+static void normal_fmt_prepare(const char *file, int line, struct strbuf *buf)
+{
+	strbuf_setlen(buf, 0);
+
+	if (!tr2env_normal_be_brief) {
+		struct tr2_tbuf tb_now;
+
+		tr2_tbuf_local_time(&tb_now);
+		strbuf_addstr(buf, tb_now.buf);
+		strbuf_addch(buf, ' ');
+
+		if (file && *file)
+			strbuf_addf(buf, "%s:%d ", file, line);
+		while (buf->len < TR2FMT_NORMAL_FL_WIDTH)
+			strbuf_addch(buf, ' ');
+	}
+}
+
+static void normal_io_write_fl(const char *file, int line,
+			       const struct strbuf *buf_payload)
+{
+	struct strbuf buf_line = STRBUF_INIT;
+
+	normal_fmt_prepare(file, line, &buf_line);
+	strbuf_addbuf(&buf_line, buf_payload);
+	tr2_dst_write_line(&tr2dst_normal, &buf_line);
+	strbuf_release(&buf_line);
+}
+
+static void fn_version_fl(const char *file, int line)
+{
+	struct strbuf buf_payload = STRBUF_INIT;
+
+	strbuf_addf(&buf_payload, "version %s", git_version_string);
+	normal_io_write_fl(file, line, &buf_payload);
+	strbuf_release(&buf_payload);
+}
+
+static void fn_start_fl(const char *file, int line,
+			uint64_t us_elapsed_absolute, const char **argv)
+{
+	struct strbuf buf_payload = STRBUF_INIT;
+
+	strbuf_addstr(&buf_payload, "start ");
+	sq_append_quote_argv_pretty(&buf_payload, argv);
+	normal_io_write_fl(file, line, &buf_payload);
+	strbuf_release(&buf_payload);
+}
+
+static void fn_exit_fl(const char *file, int line, uint64_t us_elapsed_absolute,
+		       int code)
+{
+	struct strbuf buf_payload = STRBUF_INIT;
+	double elapsed = (double)us_elapsed_absolute / 1000000.0;
+
+	strbuf_addf(&buf_payload, "exit elapsed:%.6f code:%d", elapsed, code);
+	normal_io_write_fl(file, line, &buf_payload);
+	strbuf_release(&buf_payload);
+}
+
+static void fn_signal(uint64_t us_elapsed_absolute, int signo)
+{
+	struct strbuf buf_payload = STRBUF_INIT;
+	double elapsed = (double)us_elapsed_absolute / 1000000.0;
+
+	strbuf_addf(&buf_payload, "signal elapsed:%.6f code:%d", elapsed,
+		    signo);
+	normal_io_write_fl(__FILE__, __LINE__, &buf_payload);
+	strbuf_release(&buf_payload);
+}
+
+static void fn_atexit(uint64_t us_elapsed_absolute, int code)
+{
+	struct strbuf buf_payload = STRBUF_INIT;
+	double elapsed = (double)us_elapsed_absolute / 1000000.0;
+
+	strbuf_addf(&buf_payload, "atexit elapsed:%.6f code:%d", elapsed, code);
+	normal_io_write_fl(__FILE__, __LINE__, &buf_payload);
+	strbuf_release(&buf_payload);
+}
+
+static void maybe_append_string_va(struct strbuf *buf, const char *fmt,
+				   va_list ap)
+{
+	if (fmt && *fmt) {
+		va_list copy_ap;
+
+		va_copy(copy_ap, ap);
+		strbuf_vaddf(buf, fmt, copy_ap);
+		va_end(copy_ap);
+		return;
+	}
+}
+
+static void fn_error_va_fl(const char *file, int line, const char *fmt,
+			   va_list ap)
+{
+	struct strbuf buf_payload = STRBUF_INIT;
+
+	strbuf_addstr(&buf_payload, "error");
+	if (fmt && *fmt) {
+		strbuf_addch(&buf_payload, ' ');
+		maybe_append_string_va(&buf_payload, fmt, ap);
+	}
+	normal_io_write_fl(file, line, &buf_payload);
+	strbuf_release(&buf_payload);
+}
+
+static void fn_command_path_fl(const char *file, int line, const char *pathname)
+{
+	struct strbuf buf_payload = STRBUF_INIT;
+
+	strbuf_addf(&buf_payload, "cmd_path %s", pathname);
+	normal_io_write_fl(file, line, &buf_payload);
+	strbuf_release(&buf_payload);
+}
+
+static void fn_command_name_fl(const char *file, int line, const char *name,
+			       const char *hierarchy)
+{
+	struct strbuf buf_payload = STRBUF_INIT;
+
+	strbuf_addf(&buf_payload, "cmd_name %s", name);
+	if (hierarchy && *hierarchy)
+		strbuf_addf(&buf_payload, " (%s)", hierarchy);
+	normal_io_write_fl(file, line, &buf_payload);
+	strbuf_release(&buf_payload);
+}
+
+static void fn_command_mode_fl(const char *file, int line, const char *mode)
+{
+	struct strbuf buf_payload = STRBUF_INIT;
+
+	strbuf_addf(&buf_payload, "cmd_mode %s", mode);
+	normal_io_write_fl(file, line, &buf_payload);
+	strbuf_release(&buf_payload);
+}
+
+static void fn_alias_fl(const char *file, int line, const char *alias,
+			const char **argv)
+{
+	struct strbuf buf_payload = STRBUF_INIT;
+
+	strbuf_addf(&buf_payload, "alias %s -> ", alias);
+	sq_append_quote_argv_pretty(&buf_payload, argv);
+	normal_io_write_fl(file, line, &buf_payload);
+	strbuf_release(&buf_payload);
+}
+
+static void fn_child_start_fl(const char *file, int line,
+			      uint64_t us_elapsed_absolute,
+			      const struct child_process *cmd)
+{
+	struct strbuf buf_payload = STRBUF_INIT;
+
+	strbuf_addf(&buf_payload, "child_start[%d]", cmd->trace2_child_id);
+
+	if (cmd->dir) {
+		strbuf_addstr(&buf_payload, " cd ");
+		sq_quote_buf_pretty(&buf_payload, cmd->dir);
+		strbuf_addstr(&buf_payload, ";");
+	}
+
+	/*
+	 * TODO if (cmd->env) { Consider dumping changes to environment. }
+	 * See trace_add_env() in run-command.c as used by original trace.c
+	 */
+
+	strbuf_addch(&buf_payload, ' ');
+	if (cmd->git_cmd)
+		strbuf_addstr(&buf_payload, "git ");
+	sq_append_quote_argv_pretty(&buf_payload, cmd->argv);
+
+	normal_io_write_fl(file, line, &buf_payload);
+	strbuf_release(&buf_payload);
+}
+
+static void fn_child_exit_fl(const char *file, int line,
+			     uint64_t us_elapsed_absolute, int cid, int pid,
+			     int code, uint64_t us_elapsed_child)
+{
+	struct strbuf buf_payload = STRBUF_INIT;
+	double elapsed = (double)us_elapsed_child / 1000000.0;
+
+	strbuf_addf(&buf_payload, "child_exit[%d] pid:%d code:%d elapsed:%.6f",
+		    cid, pid, code, elapsed);
+	normal_io_write_fl(file, line, &buf_payload);
+	strbuf_release(&buf_payload);
+}
+
+static void fn_exec_fl(const char *file, int line, uint64_t us_elapsed_absolute,
+		       int exec_id, const char *exe, const char **argv)
+{
+	struct strbuf buf_payload = STRBUF_INIT;
+
+	strbuf_addf(&buf_payload, "exec[%d] ", exec_id);
+	if (exe) {
+		strbuf_addstr(&buf_payload, exe);
+		strbuf_addch(&buf_payload, ' ');
+	}
+	sq_append_quote_argv_pretty(&buf_payload, argv);
+	normal_io_write_fl(file, line, &buf_payload);
+	strbuf_release(&buf_payload);
+}
+
+static void fn_exec_result_fl(const char *file, int line,
+			      uint64_t us_elapsed_absolute, int exec_id,
+			      int code)
+{
+	struct strbuf buf_payload = STRBUF_INIT;
+
+	strbuf_addf(&buf_payload, "exec_result[%d] code:%d", exec_id, code);
+	if (code > 0)
+		strbuf_addf(&buf_payload, " err:%s", strerror(code));
+	normal_io_write_fl(file, line, &buf_payload);
+	strbuf_release(&buf_payload);
+}
+
+static void fn_param_fl(const char *file, int line, const char *param,
+			const char *value)
+{
+	struct strbuf buf_payload = STRBUF_INIT;
+
+	strbuf_addf(&buf_payload, "def_param %s=%s", param, value);
+	normal_io_write_fl(file, line, &buf_payload);
+	strbuf_release(&buf_payload);
+}
+
+static void fn_repo_fl(const char *file, int line,
+		       const struct repository *repo)
+{
+	struct strbuf buf_payload = STRBUF_INIT;
+
+	strbuf_addstr(&buf_payload, "worktree ");
+	sq_quote_buf_pretty(&buf_payload, repo->worktree);
+	normal_io_write_fl(file, line, &buf_payload);
+	strbuf_release(&buf_payload);
+}
+
+static void fn_printf_va_fl(const char *file, int line,
+			    uint64_t us_elapsed_absolute, const char *fmt,
+			    va_list ap)
+{
+	struct strbuf buf_payload = STRBUF_INIT;
+
+	maybe_append_string_va(&buf_payload, fmt, ap);
+	normal_io_write_fl(file, line, &buf_payload);
+	strbuf_release(&buf_payload);
+}
+
+struct tr2_tgt tr2_tgt_normal = {
+	&tr2dst_normal,
+
+	fn_init,
+	fn_term,
+
+	fn_version_fl,
+	fn_start_fl,
+	fn_exit_fl,
+	fn_signal,
+	fn_atexit,
+	fn_error_va_fl,
+	fn_command_path_fl,
+	fn_command_name_fl,
+	fn_command_mode_fl,
+	fn_alias_fl,
+	fn_child_start_fl,
+	fn_child_exit_fl,
+	NULL, /* thread_start */
+	NULL, /* thread_exit */
+	fn_exec_fl,
+	fn_exec_result_fl,
+	fn_param_fl,
+	fn_repo_fl,
+	NULL, /* region_enter */
+	NULL, /* region_leave */
+	NULL, /* data */
+	NULL, /* data_json */
+	fn_printf_va_fl,
+};
diff -pruN 1.2.1+git2.18.0-1/git/trace2/tr2_tgt_perf.c 1.2.3+git2.25.1-1/git/trace2/tr2_tgt_perf.c
--- 1.2.1+git2.18.0-1/git/trace2/tr2_tgt_perf.c	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/trace2/tr2_tgt_perf.c	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,551 @@
+#include "cache.h"
+#include "config.h"
+#include "run-command.h"
+#include "quote.h"
+#include "version.h"
+#include "json-writer.h"
+#include "trace2/tr2_dst.h"
+#include "trace2/tr2_sid.h"
+#include "trace2/tr2_sysenv.h"
+#include "trace2/tr2_tbuf.h"
+#include "trace2/tr2_tgt.h"
+#include "trace2/tr2_tls.h"
+
+static struct tr2_dst tr2dst_perf = { TR2_SYSENV_PERF, 0, 0, 0, 0 };
+
+/*
+ * Use TR2_SYSENV_PERF_BRIEF to omit the "<time> <file>:<line>"
+ * fields from each line written to the builtin performance target.
+ *
+ * Unit tests may want to use this to help with testing.
+ */
+static int tr2env_perf_be_brief;
+
+#define TR2FMT_PERF_FL_WIDTH (28)
+#define TR2FMT_PERF_MAX_EVENT_NAME (12)
+#define TR2FMT_PERF_REPO_WIDTH (3)
+#define TR2FMT_PERF_CATEGORY_WIDTH (12)
+
+#define TR2_INDENT (2)
+#define TR2_INDENT_LENGTH(ctx) (((ctx)->nr_open_regions - 1) * TR2_INDENT)
+
+static int fn_init(void)
+{
+	int want = tr2_dst_trace_want(&tr2dst_perf);
+	int want_brief;
+	const char *brief;
+
+	if (!want)
+		return want;
+
+	brief = tr2_sysenv_get(TR2_SYSENV_PERF_BRIEF);
+	if (brief && *brief &&
+	    ((want_brief = git_parse_maybe_bool(brief)) != -1))
+		tr2env_perf_be_brief = want_brief;
+
+	return want;
+}
+
+static void fn_term(void)
+{
+	tr2_dst_trace_disable(&tr2dst_perf);
+}
+
+/*
+ * Format trace line prefix in human-readable classic format for
+ * the performance target:
+ *     "[<time> [<file>:<line>] <bar>] <nr_parents> <bar>
+ *         <thread_name> <bar> <event_name> <bar> [<repo>] <bar>
+ *         [<elapsed_absolute>] [<elapsed_relative>] <bar>
+ *         [<category>] <bar> [<dots>] "
+ */
+static void perf_fmt_prepare(const char *event_name,
+			     struct tr2tls_thread_ctx *ctx, const char *file,
+			     int line, const struct repository *repo,
+			     uint64_t *p_us_elapsed_absolute,
+			     uint64_t *p_us_elapsed_relative,
+			     const char *category, struct strbuf *buf)
+{
+	int len;
+
+	strbuf_setlen(buf, 0);
+
+	if (!tr2env_perf_be_brief) {
+		struct tr2_tbuf tb_now;
+		size_t fl_end_col;
+
+		tr2_tbuf_local_time(&tb_now);
+		strbuf_addstr(buf, tb_now.buf);
+		strbuf_addch(buf, ' ');
+
+		fl_end_col = buf->len + TR2FMT_PERF_FL_WIDTH;
+
+		if (file && *file) {
+			struct strbuf buf_fl = STRBUF_INIT;
+
+			strbuf_addf(&buf_fl, "%s:%d", file, line);
+
+			if (buf_fl.len <= TR2FMT_PERF_FL_WIDTH)
+				strbuf_addbuf(buf, &buf_fl);
+			else {
+				size_t avail = TR2FMT_PERF_FL_WIDTH - 3;
+				strbuf_addstr(buf, "...");
+				strbuf_add(buf,
+					   &buf_fl.buf[buf_fl.len - avail],
+					   avail);
+			}
+
+			strbuf_release(&buf_fl);
+		}
+
+		while (buf->len < fl_end_col)
+			strbuf_addch(buf, ' ');
+
+		strbuf_addstr(buf, " | ");
+	}
+
+	strbuf_addf(buf, "d%d | ", tr2_sid_depth());
+	strbuf_addf(buf, "%-*s | %-*s | ", TR2_MAX_THREAD_NAME,
+		    ctx->thread_name.buf, TR2FMT_PERF_MAX_EVENT_NAME,
+		    event_name);
+
+	len = buf->len + TR2FMT_PERF_REPO_WIDTH;
+	if (repo)
+		strbuf_addf(buf, "r%d ", repo->trace2_repo_id);
+	while (buf->len < len)
+		strbuf_addch(buf, ' ');
+	strbuf_addstr(buf, " | ");
+
+	if (p_us_elapsed_absolute)
+		strbuf_addf(buf, "%9.6f | ",
+			    ((double)(*p_us_elapsed_absolute)) / 1000000.0);
+	else
+		strbuf_addf(buf, "%9s | ", " ");
+
+	if (p_us_elapsed_relative)
+		strbuf_addf(buf, "%9.6f | ",
+			    ((double)(*p_us_elapsed_relative)) / 1000000.0);
+	else
+		strbuf_addf(buf, "%9s | ", " ");
+
+	strbuf_addf(buf, "%-*.*s | ", TR2FMT_PERF_CATEGORY_WIDTH,
+		    TR2FMT_PERF_CATEGORY_WIDTH, (category ? category : ""));
+
+	if (ctx->nr_open_regions > 0)
+		strbuf_addchars(buf, '.', TR2_INDENT_LENGTH(ctx));
+}
+
+static void perf_io_write_fl(const char *file, int line, const char *event_name,
+			     const struct repository *repo,
+			     uint64_t *p_us_elapsed_absolute,
+			     uint64_t *p_us_elapsed_relative,
+			     const char *category,
+			     const struct strbuf *buf_payload)
+{
+	struct tr2tls_thread_ctx *ctx = tr2tls_get_self();
+	struct strbuf buf_line = STRBUF_INIT;
+
+	perf_fmt_prepare(event_name, ctx, file, line, repo,
+			 p_us_elapsed_absolute, p_us_elapsed_relative, category,
+			 &buf_line);
+	strbuf_addbuf(&buf_line, buf_payload);
+	tr2_dst_write_line(&tr2dst_perf, &buf_line);
+	strbuf_release(&buf_line);
+}
+
+static void fn_version_fl(const char *file, int line)
+{
+	const char *event_name = "version";
+	struct strbuf buf_payload = STRBUF_INIT;
+
+	strbuf_addstr(&buf_payload, git_version_string);
+
+	perf_io_write_fl(file, line, event_name, NULL, NULL, NULL, NULL,
+			 &buf_payload);
+	strbuf_release(&buf_payload);
+}
+
+static void fn_start_fl(const char *file, int line,
+			uint64_t us_elapsed_absolute, const char **argv)
+{
+	const char *event_name = "start";
+	struct strbuf buf_payload = STRBUF_INIT;
+
+	sq_append_quote_argv_pretty(&buf_payload, argv);
+
+	perf_io_write_fl(file, line, event_name, NULL, &us_elapsed_absolute,
+			 NULL, NULL, &buf_payload);
+	strbuf_release(&buf_payload);
+}
+
+static void fn_exit_fl(const char *file, int line, uint64_t us_elapsed_absolute,
+		       int code)
+{
+	const char *event_name = "exit";
+	struct strbuf buf_payload = STRBUF_INIT;
+
+	strbuf_addf(&buf_payload, "code:%d", code);
+
+	perf_io_write_fl(file, line, event_name, NULL, &us_elapsed_absolute,
+			 NULL, NULL, &buf_payload);
+	strbuf_release(&buf_payload);
+}
+
+static void fn_signal(uint64_t us_elapsed_absolute, int signo)
+{
+	const char *event_name = "signal";
+	struct strbuf buf_payload = STRBUF_INIT;
+
+	strbuf_addf(&buf_payload, "signo:%d", signo);
+
+	perf_io_write_fl(__FILE__, __LINE__, event_name, NULL,
+			 &us_elapsed_absolute, NULL, NULL, &buf_payload);
+	strbuf_release(&buf_payload);
+}
+
+static void fn_atexit(uint64_t us_elapsed_absolute, int code)
+{
+	const char *event_name = "atexit";
+	struct strbuf buf_payload = STRBUF_INIT;
+
+	strbuf_addf(&buf_payload, "code:%d", code);
+
+	perf_io_write_fl(__FILE__, __LINE__, event_name, NULL,
+			 &us_elapsed_absolute, NULL, NULL, &buf_payload);
+	strbuf_release(&buf_payload);
+}
+
+static void maybe_append_string_va(struct strbuf *buf, const char *fmt,
+				   va_list ap)
+{
+	if (fmt && *fmt) {
+		va_list copy_ap;
+
+		va_copy(copy_ap, ap);
+		strbuf_vaddf(buf, fmt, copy_ap);
+		va_end(copy_ap);
+		return;
+	}
+}
+
+static void fn_error_va_fl(const char *file, int line, const char *fmt,
+			   va_list ap)
+{
+	const char *event_name = "error";
+	struct strbuf buf_payload = STRBUF_INIT;
+
+	maybe_append_string_va(&buf_payload, fmt, ap);
+
+	perf_io_write_fl(file, line, event_name, NULL, NULL, NULL, NULL,
+			 &buf_payload);
+	strbuf_release(&buf_payload);
+}
+
+static void fn_command_path_fl(const char *file, int line, const char *pathname)
+{
+	const char *event_name = "cmd_path";
+	struct strbuf buf_payload = STRBUF_INIT;
+
+	strbuf_addstr(&buf_payload, pathname);
+
+	perf_io_write_fl(file, line, event_name, NULL, NULL, NULL, NULL,
+			 &buf_payload);
+	strbuf_release(&buf_payload);
+}
+
+static void fn_command_name_fl(const char *file, int line, const char *name,
+			       const char *hierarchy)
+{
+	const char *event_name = "cmd_name";
+	struct strbuf buf_payload = STRBUF_INIT;
+
+	strbuf_addstr(&buf_payload, name);
+	if (hierarchy && *hierarchy)
+		strbuf_addf(&buf_payload, " (%s)", hierarchy);
+
+	perf_io_write_fl(file, line, event_name, NULL, NULL, NULL, NULL,
+			 &buf_payload);
+	strbuf_release(&buf_payload);
+}
+
+static void fn_command_mode_fl(const char *file, int line, const char *mode)
+{
+	const char *event_name = "cmd_mode";
+	struct strbuf buf_payload = STRBUF_INIT;
+
+	strbuf_addstr(&buf_payload, mode);
+
+	perf_io_write_fl(file, line, event_name, NULL, NULL, NULL, NULL,
+			 &buf_payload);
+	strbuf_release(&buf_payload);
+}
+
+static void fn_alias_fl(const char *file, int line, const char *alias,
+			const char **argv)
+{
+	const char *event_name = "alias";
+	struct strbuf buf_payload = STRBUF_INIT;
+
+	strbuf_addf(&buf_payload, "alias:%s argv:[", alias);
+	sq_append_quote_argv_pretty(&buf_payload, argv);
+	strbuf_addch(&buf_payload, ']');
+
+	perf_io_write_fl(file, line, event_name, NULL, NULL, NULL, NULL,
+			 &buf_payload);
+	strbuf_release(&buf_payload);
+}
+
+static void fn_child_start_fl(const char *file, int line,
+			      uint64_t us_elapsed_absolute,
+			      const struct child_process *cmd)
+{
+	const char *event_name = "child_start";
+	struct strbuf buf_payload = STRBUF_INIT;
+
+	if (cmd->trace2_hook_name) {
+		strbuf_addf(&buf_payload, "[ch%d] class:hook hook:%s",
+			    cmd->trace2_child_id, cmd->trace2_hook_name);
+	} else {
+		const char *child_class =
+			cmd->trace2_child_class ? cmd->trace2_child_class : "?";
+		strbuf_addf(&buf_payload, "[ch%d] class:%s",
+			    cmd->trace2_child_id, child_class);
+	}
+
+	if (cmd->dir) {
+		strbuf_addstr(&buf_payload, " cd:");
+		sq_quote_buf_pretty(&buf_payload, cmd->dir);
+	}
+
+	strbuf_addstr(&buf_payload, " argv:[");
+	if (cmd->git_cmd) {
+		strbuf_addstr(&buf_payload, "git");
+		if (cmd->argv[0])
+			strbuf_addch(&buf_payload, ' ');
+	}
+	sq_append_quote_argv_pretty(&buf_payload, cmd->argv);
+	strbuf_addch(&buf_payload, ']');
+
+	perf_io_write_fl(file, line, event_name, NULL, &us_elapsed_absolute,
+			 NULL, NULL, &buf_payload);
+	strbuf_release(&buf_payload);
+}
+
+static void fn_child_exit_fl(const char *file, int line,
+			     uint64_t us_elapsed_absolute, int cid, int pid,
+			     int code, uint64_t us_elapsed_child)
+{
+	const char *event_name = "child_exit";
+	struct strbuf buf_payload = STRBUF_INIT;
+
+	strbuf_addf(&buf_payload, "[ch%d] pid:%d code:%d", cid, pid, code);
+
+	perf_io_write_fl(file, line, event_name, NULL, &us_elapsed_absolute,
+			 &us_elapsed_child, NULL, &buf_payload);
+	strbuf_release(&buf_payload);
+}
+
+static void fn_thread_start_fl(const char *file, int line,
+			       uint64_t us_elapsed_absolute)
+{
+	const char *event_name = "thread_start";
+	struct strbuf buf_payload = STRBUF_INIT;
+
+	perf_io_write_fl(file, line, event_name, NULL, &us_elapsed_absolute,
+			 NULL, NULL, &buf_payload);
+	strbuf_release(&buf_payload);
+}
+
+static void fn_thread_exit_fl(const char *file, int line,
+			      uint64_t us_elapsed_absolute,
+			      uint64_t us_elapsed_thread)
+{
+	const char *event_name = "thread_exit";
+	struct strbuf buf_payload = STRBUF_INIT;
+
+	perf_io_write_fl(file, line, event_name, NULL, &us_elapsed_absolute,
+			 &us_elapsed_thread, NULL, &buf_payload);
+	strbuf_release(&buf_payload);
+}
+
+static void fn_exec_fl(const char *file, int line, uint64_t us_elapsed_absolute,
+		       int exec_id, const char *exe, const char **argv)
+{
+	const char *event_name = "exec";
+	struct strbuf buf_payload = STRBUF_INIT;
+
+	strbuf_addf(&buf_payload, "id:%d ", exec_id);
+	strbuf_addstr(&buf_payload, "argv:[");
+	if (exe) {
+		strbuf_addstr(&buf_payload, exe);
+		if (argv[0])
+			strbuf_addch(&buf_payload, ' ');
+	}
+	sq_append_quote_argv_pretty(&buf_payload, argv);
+	strbuf_addch(&buf_payload, ']');
+
+	perf_io_write_fl(file, line, event_name, NULL, &us_elapsed_absolute,
+			 NULL, NULL, &buf_payload);
+	strbuf_release(&buf_payload);
+}
+
+static void fn_exec_result_fl(const char *file, int line,
+			      uint64_t us_elapsed_absolute, int exec_id,
+			      int code)
+{
+	const char *event_name = "exec_result";
+	struct strbuf buf_payload = STRBUF_INIT;
+
+	strbuf_addf(&buf_payload, "id:%d code:%d", exec_id, code);
+	if (code > 0)
+		strbuf_addf(&buf_payload, " err:%s", strerror(code));
+
+	perf_io_write_fl(file, line, event_name, NULL, &us_elapsed_absolute,
+			 NULL, NULL, &buf_payload);
+	strbuf_release(&buf_payload);
+}
+
+static void fn_param_fl(const char *file, int line, const char *param,
+			const char *value)
+{
+	const char *event_name = "def_param";
+	struct strbuf buf_payload = STRBUF_INIT;
+
+	strbuf_addf(&buf_payload, "%s:%s", param, value);
+
+	perf_io_write_fl(file, line, event_name, NULL, NULL, NULL, NULL,
+			 &buf_payload);
+	strbuf_release(&buf_payload);
+}
+
+static void fn_repo_fl(const char *file, int line,
+		       const struct repository *repo)
+{
+	const char *event_name = "def_repo";
+	struct strbuf buf_payload = STRBUF_INIT;
+
+	strbuf_addstr(&buf_payload, "worktree:");
+	sq_quote_buf_pretty(&buf_payload, repo->worktree);
+
+	perf_io_write_fl(file, line, event_name, repo, NULL, NULL, NULL,
+			 &buf_payload);
+	strbuf_release(&buf_payload);
+}
+
+static void fn_region_enter_printf_va_fl(const char *file, int line,
+					 uint64_t us_elapsed_absolute,
+					 const char *category,
+					 const char *label,
+					 const struct repository *repo,
+					 const char *fmt, va_list ap)
+{
+	const char *event_name = "region_enter";
+	struct strbuf buf_payload = STRBUF_INIT;
+
+	if (label)
+		strbuf_addf(&buf_payload, "label:%s", label);
+	if (fmt && *fmt) {
+		strbuf_addch(&buf_payload, ' ');
+		maybe_append_string_va(&buf_payload, fmt, ap);
+	}
+
+	perf_io_write_fl(file, line, event_name, repo, &us_elapsed_absolute,
+			 NULL, category, &buf_payload);
+	strbuf_release(&buf_payload);
+}
+
+static void fn_region_leave_printf_va_fl(
+	const char *file, int line, uint64_t us_elapsed_absolute,
+	uint64_t us_elapsed_region, const char *category, const char *label,
+	const struct repository *repo, const char *fmt, va_list ap)
+{
+	const char *event_name = "region_leave";
+	struct strbuf buf_payload = STRBUF_INIT;
+
+	if (label)
+		strbuf_addf(&buf_payload, "label:%s", label);
+	if (fmt && *fmt) {
+		strbuf_addch(&buf_payload, ' ' );
+		maybe_append_string_va(&buf_payload, fmt, ap);
+	}
+
+	perf_io_write_fl(file, line, event_name, repo, &us_elapsed_absolute,
+			 &us_elapsed_region, category, &buf_payload);
+	strbuf_release(&buf_payload);
+}
+
+static void fn_data_fl(const char *file, int line, uint64_t us_elapsed_absolute,
+		       uint64_t us_elapsed_region, const char *category,
+		       const struct repository *repo, const char *key,
+		       const char *value)
+{
+	const char *event_name = "data";
+	struct strbuf buf_payload = STRBUF_INIT;
+
+	strbuf_addf(&buf_payload, "%s:%s", key, value);
+
+	perf_io_write_fl(file, line, event_name, repo, &us_elapsed_absolute,
+			 &us_elapsed_region, category, &buf_payload);
+	strbuf_release(&buf_payload);
+}
+
+static void fn_data_json_fl(const char *file, int line,
+			    uint64_t us_elapsed_absolute,
+			    uint64_t us_elapsed_region, const char *category,
+			    const struct repository *repo, const char *key,
+			    const struct json_writer *value)
+{
+	const char *event_name = "data_json";
+	struct strbuf buf_payload = STRBUF_INIT;
+
+	strbuf_addf(&buf_payload, "%s:%s", key, value->json.buf);
+
+	perf_io_write_fl(file, line, event_name, repo, &us_elapsed_absolute,
+			 &us_elapsed_region, category, &buf_payload);
+	strbuf_release(&buf_payload);
+}
+
+static void fn_printf_va_fl(const char *file, int line,
+			    uint64_t us_elapsed_absolute, const char *fmt,
+			    va_list ap)
+{
+	const char *event_name = "printf";
+	struct strbuf buf_payload = STRBUF_INIT;
+
+	maybe_append_string_va(&buf_payload, fmt, ap);
+
+	perf_io_write_fl(file, line, event_name, NULL, &us_elapsed_absolute,
+			 NULL, NULL, &buf_payload);
+	strbuf_release(&buf_payload);
+}
+
+struct tr2_tgt tr2_tgt_perf = {
+	&tr2dst_perf,
+
+	fn_init,
+	fn_term,
+
+	fn_version_fl,
+	fn_start_fl,
+	fn_exit_fl,
+	fn_signal,
+	fn_atexit,
+	fn_error_va_fl,
+	fn_command_path_fl,
+	fn_command_name_fl,
+	fn_command_mode_fl,
+	fn_alias_fl,
+	fn_child_start_fl,
+	fn_child_exit_fl,
+	fn_thread_start_fl,
+	fn_thread_exit_fl,
+	fn_exec_fl,
+	fn_exec_result_fl,
+	fn_param_fl,
+	fn_repo_fl,
+	fn_region_enter_printf_va_fl,
+	fn_region_leave_printf_va_fl,
+	fn_data_fl,
+	fn_data_json_fl,
+	fn_printf_va_fl,
+};
diff -pruN 1.2.1+git2.18.0-1/git/trace2/tr2_tls.c 1.2.3+git2.25.1-1/git/trace2/tr2_tls.c
--- 1.2.1+git2.18.0-1/git/trace2/tr2_tls.c	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/trace2/tr2_tls.c	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,180 @@
+#include "cache.h"
+#include "thread-utils.h"
+#include "trace2/tr2_tls.h"
+
+/*
+ * Initialize size of the thread stack for nested regions.
+ * This is used to store nested region start times.  Note that
+ * this stack is per-thread and not per-trace-key.
+ */
+#define TR2_REGION_NESTING_INITIAL_SIZE (100)
+
+static struct tr2tls_thread_ctx *tr2tls_thread_main;
+static uint64_t tr2tls_us_start_process;
+
+static pthread_mutex_t tr2tls_mutex;
+static pthread_key_t tr2tls_key;
+
+static int tr2_next_thread_id; /* modify under lock */
+
+void tr2tls_start_process_clock(void)
+{
+	if (tr2tls_us_start_process)
+		return;
+
+	/*
+	 * Keep the absolute start time of the process (i.e. the main
+	 * process) in a fixed variable since other threads need to
+	 * access it.  This allows them to do that without a lock on
+	 * main thread's array data (because of reallocs).
+	 */
+	tr2tls_us_start_process = getnanotime() / 1000;
+}
+
+struct tr2tls_thread_ctx *tr2tls_create_self(const char *thread_name,
+					     uint64_t us_thread_start)
+{
+	struct tr2tls_thread_ctx *ctx = xcalloc(1, sizeof(*ctx));
+
+	/*
+	 * Implicitly "tr2tls_push_self()" to capture the thread's start
+	 * time in array_us_start[0].  For the main thread this gives us the
+	 * application run time.
+	 */
+	ctx->alloc = TR2_REGION_NESTING_INITIAL_SIZE;
+	ctx->array_us_start = (uint64_t *)xcalloc(ctx->alloc, sizeof(uint64_t));
+	ctx->array_us_start[ctx->nr_open_regions++] = us_thread_start;
+
+	ctx->thread_id = tr2tls_locked_increment(&tr2_next_thread_id);
+
+	strbuf_init(&ctx->thread_name, 0);
+	if (ctx->thread_id)
+		strbuf_addf(&ctx->thread_name, "th%02d:", ctx->thread_id);
+	strbuf_addstr(&ctx->thread_name, thread_name);
+	if (ctx->thread_name.len > TR2_MAX_THREAD_NAME)
+		strbuf_setlen(&ctx->thread_name, TR2_MAX_THREAD_NAME);
+
+	pthread_setspecific(tr2tls_key, ctx);
+
+	return ctx;
+}
+
+struct tr2tls_thread_ctx *tr2tls_get_self(void)
+{
+	struct tr2tls_thread_ctx *ctx;
+
+	if (!HAVE_THREADS)
+		return tr2tls_thread_main;
+
+	ctx = pthread_getspecific(tr2tls_key);
+
+	/*
+	 * If the thread-proc did not call trace2_thread_start(), we won't
+	 * have any TLS data associated with the current thread.  Fix it
+	 * here and silently continue.
+	 */
+	if (!ctx)
+		ctx = tr2tls_create_self("unknown", getnanotime() / 1000);
+
+	return ctx;
+}
+
+int tr2tls_is_main_thread(void)
+{
+	if (!HAVE_THREADS)
+		return 1;
+
+	return pthread_getspecific(tr2tls_key) == tr2tls_thread_main;
+}
+
+void tr2tls_unset_self(void)
+{
+	struct tr2tls_thread_ctx *ctx;
+
+	ctx = tr2tls_get_self();
+
+	pthread_setspecific(tr2tls_key, NULL);
+
+	free(ctx->array_us_start);
+	free(ctx);
+}
+
+void tr2tls_push_self(uint64_t us_now)
+{
+	struct tr2tls_thread_ctx *ctx = tr2tls_get_self();
+
+	ALLOC_GROW(ctx->array_us_start, ctx->nr_open_regions + 1, ctx->alloc);
+	ctx->array_us_start[ctx->nr_open_regions++] = us_now;
+}
+
+void tr2tls_pop_self(void)
+{
+	struct tr2tls_thread_ctx *ctx = tr2tls_get_self();
+
+	if (!ctx->nr_open_regions)
+		BUG("no open regions in thread '%s'", ctx->thread_name.buf);
+
+	ctx->nr_open_regions--;
+}
+
+void tr2tls_pop_unwind_self(void)
+{
+	struct tr2tls_thread_ctx *ctx = tr2tls_get_self();
+
+	while (ctx->nr_open_regions > 1)
+		tr2tls_pop_self();
+}
+
+uint64_t tr2tls_region_elasped_self(uint64_t us)
+{
+	struct tr2tls_thread_ctx *ctx;
+	uint64_t us_start;
+
+	ctx = tr2tls_get_self();
+	if (!ctx->nr_open_regions)
+		return 0;
+
+	us_start = ctx->array_us_start[ctx->nr_open_regions - 1];
+
+	return us - us_start;
+}
+
+uint64_t tr2tls_absolute_elapsed(uint64_t us)
+{
+	if (!tr2tls_thread_main)
+		return 0;
+
+	return us - tr2tls_us_start_process;
+}
+
+void tr2tls_init(void)
+{
+	tr2tls_start_process_clock();
+
+	pthread_key_create(&tr2tls_key, NULL);
+	init_recursive_mutex(&tr2tls_mutex);
+
+	tr2tls_thread_main =
+		tr2tls_create_self("main", tr2tls_us_start_process);
+}
+
+void tr2tls_release(void)
+{
+	tr2tls_unset_self();
+	tr2tls_thread_main = NULL;
+
+	pthread_mutex_destroy(&tr2tls_mutex);
+	pthread_key_delete(tr2tls_key);
+}
+
+int tr2tls_locked_increment(int *p)
+{
+	int current_value;
+
+	pthread_mutex_lock(&tr2tls_mutex);
+	current_value = *p;
+	*p = current_value + 1;
+	pthread_mutex_unlock(&tr2tls_mutex);
+
+	return current_value;
+}
diff -pruN 1.2.1+git2.18.0-1/git/trace2/tr2_tls.h 1.2.3+git2.25.1-1/git/trace2/tr2_tls.h
--- 1.2.1+git2.18.0-1/git/trace2/tr2_tls.h	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/trace2/tr2_tls.h	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,103 @@
+#ifndef TR2_TLS_H
+#define TR2_TLS_H
+
+#include "strbuf.h"
+
+/*
+ * Arbitry limit for thread names for column alignment.
+ */
+#define TR2_MAX_THREAD_NAME (24)
+
+struct tr2tls_thread_ctx {
+	struct strbuf thread_name;
+	uint64_t *array_us_start;
+	int alloc;
+	int nr_open_regions; /* plays role of "nr" in ALLOC_GROW */
+	int thread_id;
+};
+
+/*
+ * Create TLS data for the current thread.  This gives us a place to
+ * put per-thread data, such as thread start time, function nesting
+ * and a per-thread label for our messages.
+ *
+ * We assume the first thread is "main".  Other threads are given
+ * non-zero thread-ids to help distinguish messages from concurrent
+ * threads.
+ *
+ * Truncate the thread name if necessary to help with column alignment
+ * in printf-style messages.
+ *
+ * In this and all following functions the term "self" refers to the
+ * current thread.
+ */
+struct tr2tls_thread_ctx *tr2tls_create_self(const char *thread_name,
+					     uint64_t us_thread_start);
+
+/*
+ * Get our TLS data.
+ */
+struct tr2tls_thread_ctx *tr2tls_get_self(void);
+
+/*
+ * return true if the current thread is the main thread.
+ */
+int tr2tls_is_main_thread(void);
+
+/*
+ * Free our TLS data.
+ */
+void tr2tls_unset_self(void);
+
+/*
+ * Begin a new nested region and remember the start time.
+ */
+void tr2tls_push_self(uint64_t us_now);
+
+/*
+ * End the innermost nested region.
+ */
+void tr2tls_pop_self(void);
+
+/*
+ * Pop any extra (above the first) open regions on the current
+ * thread and discard.  During a thread-exit, we should only
+ * have region[0] that was pushed in trace2_thread_start() if
+ * the thread exits normally.
+ */
+void tr2tls_pop_unwind_self(void);
+
+/*
+ * Compute the elapsed time since the innermost region in the
+ * current thread started and the given time (usually now).
+ */
+uint64_t tr2tls_region_elasped_self(uint64_t us);
+
+/*
+ * Compute the elapsed time since the main thread started
+ * and the given time (usually now).  This is assumed to
+ * be the absolute run time of the process.
+ */
+uint64_t tr2tls_absolute_elapsed(uint64_t us);
+
+/*
+ * Initialize the tr2 TLS system.
+ */
+void tr2tls_init(void);
+
+/*
+ * Free all tr2 TLS resources.
+ */
+void tr2tls_release(void);
+
+/*
+ * Protected increment of an integer.
+ */
+int tr2tls_locked_increment(int *p);
+
+/*
+ * Capture the process start time and do nothing else.
+ */
+void tr2tls_start_process_clock(void);
+
+#endif /* TR2_TLS_H */
diff -pruN 1.2.1+git2.18.0-1/git/trace2.c 1.2.3+git2.25.1-1/git/trace2.c
--- 1.2.1+git2.18.0-1/git/trace2.c	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/trace2.c	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,785 @@
+#include "cache.h"
+#include "config.h"
+#include "json-writer.h"
+#include "quote.h"
+#include "run-command.h"
+#include "sigchain.h"
+#include "thread-utils.h"
+#include "version.h"
+#include "trace2/tr2_cfg.h"
+#include "trace2/tr2_cmd_name.h"
+#include "trace2/tr2_dst.h"
+#include "trace2/tr2_sid.h"
+#include "trace2/tr2_sysenv.h"
+#include "trace2/tr2_tgt.h"
+#include "trace2/tr2_tls.h"
+
+static int trace2_enabled;
+
+static int tr2_next_child_id; /* modify under lock */
+static int tr2_next_exec_id; /* modify under lock */
+static int tr2_next_repo_id = 1; /* modify under lock. zero is reserved */
+
+/*
+ * A table of the builtin TRACE2 targets.  Each of these may be independently
+ * enabled or disabled.  Each TRACE2 API method will try to write an event to
+ * *each* of the enabled targets.
+ */
+/* clang-format off */
+static struct tr2_tgt *tr2_tgt_builtins[] =
+{
+	&tr2_tgt_normal,
+	&tr2_tgt_perf,
+	&tr2_tgt_event,
+	NULL
+};
+/* clang-format on */
+
+/* clang-format off */
+#define for_each_builtin(j, tgt_j)			\
+	for (j = 0, tgt_j = tr2_tgt_builtins[j];	\
+	     tgt_j;					\
+	     j++, tgt_j = tr2_tgt_builtins[j])
+/* clang-format on */
+
+/* clang-format off */
+#define for_each_wanted_builtin(j, tgt_j)            \
+	for_each_builtin(j, tgt_j)                   \
+		if (tr2_dst_trace_want(tgt_j->pdst))
+/* clang-format on */
+
+/*
+ * Force (rather than lazily) initialize any of the requested
+ * builtin TRACE2 targets at startup (and before we've seen an
+ * actual TRACE2 event call) so we can see if we need to setup
+ * the TR2 and TLS machinery.
+ *
+ * Return the number of builtin targets enabled.
+ */
+static int tr2_tgt_want_builtins(void)
+{
+	struct tr2_tgt *tgt_j;
+	int j;
+	int sum = 0;
+
+	for_each_builtin (j, tgt_j)
+		if (tgt_j->pfn_init())
+			sum++;
+
+	return sum;
+}
+
+/*
+ * Properly terminate each builtin target.  Give each target
+ * a chance to write a summary event and/or flush if necessary
+ * and then close the fd.
+ */
+static void tr2_tgt_disable_builtins(void)
+{
+	struct tr2_tgt *tgt_j;
+	int j;
+
+	for_each_builtin (j, tgt_j)
+		tgt_j->pfn_term();
+}
+
+static int tr2main_exit_code;
+
+/*
+ * Our atexit routine should run after everything has finished.
+ *
+ * Note that events generated here might not actually appear if
+ * we are writing to fd 1 or 2 and our atexit routine runs after
+ * the pager's atexit routine (since it closes them to shutdown
+ * the pipes).
+ */
+static void tr2main_atexit_handler(void)
+{
+	struct tr2_tgt *tgt_j;
+	int j;
+	uint64_t us_now;
+	uint64_t us_elapsed_absolute;
+
+	us_now = getnanotime() / 1000;
+	us_elapsed_absolute = tr2tls_absolute_elapsed(us_now);
+
+	/*
+	 * Clear any unbalanced regions so that our atexit message
+	 * does not appear nested.  This improves the appearance of
+	 * the trace output if someone calls die(), for example.
+	 */
+	tr2tls_pop_unwind_self();
+
+	for_each_wanted_builtin (j, tgt_j)
+		if (tgt_j->pfn_atexit)
+			tgt_j->pfn_atexit(us_elapsed_absolute,
+					  tr2main_exit_code);
+
+	tr2_tgt_disable_builtins();
+
+	tr2tls_release();
+	tr2_sid_release();
+	tr2_cmd_name_release();
+	tr2_cfg_free_patterns();
+	tr2_sysenv_release();
+
+	trace2_enabled = 0;
+}
+
+static void tr2main_signal_handler(int signo)
+{
+	struct tr2_tgt *tgt_j;
+	int j;
+	uint64_t us_now;
+	uint64_t us_elapsed_absolute;
+
+	us_now = getnanotime() / 1000;
+	us_elapsed_absolute = tr2tls_absolute_elapsed(us_now);
+
+	for_each_wanted_builtin (j, tgt_j)
+		if (tgt_j->pfn_signal)
+			tgt_j->pfn_signal(us_elapsed_absolute, signo);
+
+	sigchain_pop(signo);
+	raise(signo);
+}
+
+void trace2_initialize_clock(void)
+{
+	tr2tls_start_process_clock();
+}
+
+void trace2_initialize_fl(const char *file, int line)
+{
+	struct tr2_tgt *tgt_j;
+	int j;
+
+	if (trace2_enabled)
+		return;
+
+	tr2_sysenv_load();
+
+	if (!tr2_tgt_want_builtins())
+		return;
+	trace2_enabled = 1;
+
+	tr2_sid_get();
+
+	atexit(tr2main_atexit_handler);
+	sigchain_push(SIGPIPE, tr2main_signal_handler);
+	tr2tls_init();
+
+	/*
+	 * Emit 'version' message on each active builtin target.
+	 */
+	for_each_wanted_builtin (j, tgt_j)
+		if (tgt_j->pfn_version_fl)
+			tgt_j->pfn_version_fl(file, line);
+}
+
+int trace2_is_enabled(void)
+{
+	return trace2_enabled;
+}
+
+void trace2_cmd_start_fl(const char *file, int line, const char **argv)
+{
+	struct tr2_tgt *tgt_j;
+	int j;
+	uint64_t us_now;
+	uint64_t us_elapsed_absolute;
+
+	if (!trace2_enabled)
+		return;
+
+	us_now = getnanotime() / 1000;
+	us_elapsed_absolute = tr2tls_absolute_elapsed(us_now);
+
+	for_each_wanted_builtin (j, tgt_j)
+		if (tgt_j->pfn_start_fl)
+			tgt_j->pfn_start_fl(file, line, us_elapsed_absolute,
+					    argv);
+}
+
+int trace2_cmd_exit_fl(const char *file, int line, int code)
+{
+	struct tr2_tgt *tgt_j;
+	int j;
+	uint64_t us_now;
+	uint64_t us_elapsed_absolute;
+
+	code &= 0xff;
+
+	if (!trace2_enabled)
+		return code;
+
+	trace2_collect_process_info(TRACE2_PROCESS_INFO_EXIT);
+
+	tr2main_exit_code = code;
+
+	us_now = getnanotime() / 1000;
+	us_elapsed_absolute = tr2tls_absolute_elapsed(us_now);
+
+	for_each_wanted_builtin (j, tgt_j)
+		if (tgt_j->pfn_exit_fl)
+			tgt_j->pfn_exit_fl(file, line, us_elapsed_absolute,
+					   code);
+
+	return code;
+}
+
+void trace2_cmd_error_va_fl(const char *file, int line, const char *fmt,
+			    va_list ap)
+{
+	struct tr2_tgt *tgt_j;
+	int j;
+
+	if (!trace2_enabled)
+		return;
+
+	/*
+	 * We expect each target function to treat 'ap' as constant
+	 * and use va_copy (because an 'ap' can only be walked once).
+	 */
+	for_each_wanted_builtin (j, tgt_j)
+		if (tgt_j->pfn_error_va_fl)
+			tgt_j->pfn_error_va_fl(file, line, fmt, ap);
+}
+
+void trace2_cmd_path_fl(const char *file, int line, const char *pathname)
+{
+	struct tr2_tgt *tgt_j;
+	int j;
+
+	if (!trace2_enabled)
+		return;
+
+	for_each_wanted_builtin (j, tgt_j)
+		if (tgt_j->pfn_command_path_fl)
+			tgt_j->pfn_command_path_fl(file, line, pathname);
+}
+
+void trace2_cmd_name_fl(const char *file, int line, const char *name)
+{
+	struct tr2_tgt *tgt_j;
+	const char *hierarchy;
+	int j;
+
+	if (!trace2_enabled)
+		return;
+
+	tr2_cmd_name_append_hierarchy(name);
+	hierarchy = tr2_cmd_name_get_hierarchy();
+
+	for_each_wanted_builtin (j, tgt_j)
+		if (tgt_j->pfn_command_name_fl)
+			tgt_j->pfn_command_name_fl(file, line, name, hierarchy);
+}
+
+void trace2_cmd_mode_fl(const char *file, int line, const char *mode)
+{
+	struct tr2_tgt *tgt_j;
+	int j;
+
+	if (!trace2_enabled)
+		return;
+
+	for_each_wanted_builtin (j, tgt_j)
+		if (tgt_j->pfn_command_mode_fl)
+			tgt_j->pfn_command_mode_fl(file, line, mode);
+}
+
+void trace2_cmd_alias_fl(const char *file, int line, const char *alias,
+			 const char **argv)
+{
+	struct tr2_tgt *tgt_j;
+	int j;
+
+	if (!trace2_enabled)
+		return;
+
+	for_each_wanted_builtin (j, tgt_j)
+		if (tgt_j->pfn_alias_fl)
+			tgt_j->pfn_alias_fl(file, line, alias, argv);
+}
+
+void trace2_cmd_list_config_fl(const char *file, int line)
+{
+	if (!trace2_enabled)
+		return;
+
+	tr2_cfg_list_config_fl(file, line);
+}
+
+void trace2_cmd_set_config_fl(const char *file, int line, const char *key,
+			      const char *value)
+{
+	if (!trace2_enabled)
+		return;
+
+	tr2_cfg_set_fl(file, line, key, value);
+}
+
+void trace2_child_start_fl(const char *file, int line,
+			   struct child_process *cmd)
+{
+	struct tr2_tgt *tgt_j;
+	int j;
+	uint64_t us_now;
+	uint64_t us_elapsed_absolute;
+
+	if (!trace2_enabled)
+		return;
+
+	us_now = getnanotime() / 1000;
+	us_elapsed_absolute = tr2tls_absolute_elapsed(us_now);
+
+	cmd->trace2_child_id = tr2tls_locked_increment(&tr2_next_child_id);
+	cmd->trace2_child_us_start = us_now;
+
+	for_each_wanted_builtin (j, tgt_j)
+		if (tgt_j->pfn_child_start_fl)
+			tgt_j->pfn_child_start_fl(file, line,
+						  us_elapsed_absolute, cmd);
+}
+
+void trace2_child_exit_fl(const char *file, int line, struct child_process *cmd,
+			  int child_exit_code)
+{
+	struct tr2_tgt *tgt_j;
+	int j;
+	uint64_t us_now;
+	uint64_t us_elapsed_absolute;
+	uint64_t us_elapsed_child;
+
+	if (!trace2_enabled)
+		return;
+
+	us_now = getnanotime() / 1000;
+	us_elapsed_absolute = tr2tls_absolute_elapsed(us_now);
+
+	if (cmd->trace2_child_us_start)
+		us_elapsed_child = us_now - cmd->trace2_child_us_start;
+	else
+		us_elapsed_child = 0;
+
+	for_each_wanted_builtin (j, tgt_j)
+		if (tgt_j->pfn_child_exit_fl)
+			tgt_j->pfn_child_exit_fl(file, line,
+						 us_elapsed_absolute,
+						 cmd->trace2_child_id, cmd->pid,
+						 child_exit_code,
+						 us_elapsed_child);
+}
+
+int trace2_exec_fl(const char *file, int line, const char *exe,
+		   const char **argv)
+{
+	struct tr2_tgt *tgt_j;
+	int j;
+	int exec_id;
+	uint64_t us_now;
+	uint64_t us_elapsed_absolute;
+
+	if (!trace2_enabled)
+		return -1;
+
+	us_now = getnanotime() / 1000;
+	us_elapsed_absolute = tr2tls_absolute_elapsed(us_now);
+
+	exec_id = tr2tls_locked_increment(&tr2_next_exec_id);
+
+	for_each_wanted_builtin (j, tgt_j)
+		if (tgt_j->pfn_exec_fl)
+			tgt_j->pfn_exec_fl(file, line, us_elapsed_absolute,
+					   exec_id, exe, argv);
+
+	return exec_id;
+}
+
+void trace2_exec_result_fl(const char *file, int line, int exec_id, int code)
+{
+	struct tr2_tgt *tgt_j;
+	int j;
+	uint64_t us_now;
+	uint64_t us_elapsed_absolute;
+
+	if (!trace2_enabled)
+		return;
+
+	us_now = getnanotime() / 1000;
+	us_elapsed_absolute = tr2tls_absolute_elapsed(us_now);
+
+	for_each_wanted_builtin (j, tgt_j)
+		if (tgt_j->pfn_exec_result_fl)
+			tgt_j->pfn_exec_result_fl(
+				file, line, us_elapsed_absolute, exec_id, code);
+}
+
+void trace2_thread_start_fl(const char *file, int line, const char *thread_name)
+{
+	struct tr2_tgt *tgt_j;
+	int j;
+	uint64_t us_now;
+	uint64_t us_elapsed_absolute;
+
+	if (!trace2_enabled)
+		return;
+
+	if (tr2tls_is_main_thread()) {
+		/*
+		 * We should only be called from the new thread's thread-proc,
+		 * so this is technically a bug.  But in those cases where the
+		 * main thread also runs the thread-proc function (or when we
+		 * are built with threading disabled), we need to allow it.
+		 *
+		 * Convert this call to a region-enter so the nesting looks
+		 * correct.
+		 */
+		trace2_region_enter_printf_fl(file, line, NULL, NULL, NULL,
+					      "thread-proc on main: %s",
+					      thread_name);
+		return;
+	}
+
+	us_now = getnanotime() / 1000;
+	us_elapsed_absolute = tr2tls_absolute_elapsed(us_now);
+
+	tr2tls_create_self(thread_name, us_now);
+
+	for_each_wanted_builtin (j, tgt_j)
+		if (tgt_j->pfn_thread_start_fl)
+			tgt_j->pfn_thread_start_fl(file, line,
+						   us_elapsed_absolute);
+}
+
+void trace2_thread_exit_fl(const char *file, int line)
+{
+	struct tr2_tgt *tgt_j;
+	int j;
+	uint64_t us_now;
+	uint64_t us_elapsed_absolute;
+	uint64_t us_elapsed_thread;
+
+	if (!trace2_enabled)
+		return;
+
+	if (tr2tls_is_main_thread()) {
+		/*
+		 * We should only be called from the exiting thread's
+		 * thread-proc, so this is technically a bug.  But in
+		 * those cases where the main thread also runs the
+		 * thread-proc function (or when we are built with
+		 * threading disabled), we need to allow it.
+		 *
+		 * Convert this call to a region-leave so the nesting
+		 * looks correct.
+		 */
+		trace2_region_leave_printf_fl(file, line, NULL, NULL, NULL,
+					      "thread-proc on main");
+		return;
+	}
+
+	us_now = getnanotime() / 1000;
+	us_elapsed_absolute = tr2tls_absolute_elapsed(us_now);
+
+	/*
+	 * Clear any unbalanced regions and then get the relative time
+	 * for the outer-most region (which we pushed when the thread
+	 * started).  This gives us the run time of the thread.
+	 */
+	tr2tls_pop_unwind_self();
+	us_elapsed_thread = tr2tls_region_elasped_self(us_now);
+
+	for_each_wanted_builtin (j, tgt_j)
+		if (tgt_j->pfn_thread_exit_fl)
+			tgt_j->pfn_thread_exit_fl(file, line,
+						  us_elapsed_absolute,
+						  us_elapsed_thread);
+
+	tr2tls_unset_self();
+}
+
+void trace2_def_param_fl(const char *file, int line, const char *param,
+			 const char *value)
+{
+	struct tr2_tgt *tgt_j;
+	int j;
+
+	if (!trace2_enabled)
+		return;
+
+	for_each_wanted_builtin (j, tgt_j)
+		if (tgt_j->pfn_param_fl)
+			tgt_j->pfn_param_fl(file, line, param, value);
+}
+
+void trace2_def_repo_fl(const char *file, int line, struct repository *repo)
+{
+	struct tr2_tgt *tgt_j;
+	int j;
+
+	if (!trace2_enabled)
+		return;
+
+	if (repo->trace2_repo_id)
+		return;
+
+	repo->trace2_repo_id = tr2tls_locked_increment(&tr2_next_repo_id);
+
+	for_each_wanted_builtin (j, tgt_j)
+		if (tgt_j->pfn_repo_fl)
+			tgt_j->pfn_repo_fl(file, line, repo);
+}
+
+void trace2_region_enter_printf_va_fl(const char *file, int line,
+				      const char *category, const char *label,
+				      const struct repository *repo,
+				      const char *fmt, va_list ap)
+{
+	struct tr2_tgt *tgt_j;
+	int j;
+	uint64_t us_now;
+	uint64_t us_elapsed_absolute;
+
+	if (!trace2_enabled)
+		return;
+
+	us_now = getnanotime() / 1000;
+	us_elapsed_absolute = tr2tls_absolute_elapsed(us_now);
+
+	/*
+	 * Print the region-enter message at the current nesting
+	 * (indentation) level and then push a new level.
+	 *
+	 * We expect each target function to treat 'ap' as constant
+	 * and use va_copy.
+	 */
+	for_each_wanted_builtin (j, tgt_j)
+		if (tgt_j->pfn_region_enter_printf_va_fl)
+			tgt_j->pfn_region_enter_printf_va_fl(
+				file, line, us_elapsed_absolute, category,
+				label, repo, fmt, ap);
+
+	tr2tls_push_self(us_now);
+}
+
+void trace2_region_enter_fl(const char *file, int line, const char *category,
+			    const char *label, const struct repository *repo, ...)
+{
+	va_list ap;
+	va_start(ap, repo);
+	trace2_region_enter_printf_va_fl(file, line, category, label, repo,
+					 NULL, ap);
+	va_end(ap);
+
+}
+
+void trace2_region_enter_printf_fl(const char *file, int line,
+				   const char *category, const char *label,
+				   const struct repository *repo,
+				   const char *fmt, ...)
+{
+	va_list ap;
+
+	va_start(ap, fmt);
+	trace2_region_enter_printf_va_fl(file, line, category, label, repo, fmt,
+					 ap);
+	va_end(ap);
+}
+
+#ifndef HAVE_VARIADIC_MACROS
+void trace2_region_enter_printf(const char *category, const char *label,
+				const struct repository *repo, const char *fmt,
+				...)
+{
+	va_list ap;
+
+	va_start(ap, fmt);
+	trace2_region_enter_printf_va_fl(NULL, 0, category, label, repo, fmt,
+					 ap);
+	va_end(ap);
+}
+#endif
+
+void trace2_region_leave_printf_va_fl(const char *file, int line,
+				      const char *category, const char *label,
+				      const struct repository *repo,
+				      const char *fmt, va_list ap)
+{
+	struct tr2_tgt *tgt_j;
+	int j;
+	uint64_t us_now;
+	uint64_t us_elapsed_absolute;
+	uint64_t us_elapsed_region;
+
+	if (!trace2_enabled)
+		return;
+
+	us_now = getnanotime() / 1000;
+	us_elapsed_absolute = tr2tls_absolute_elapsed(us_now);
+
+	/*
+	 * Get the elapsed time in the current region before we
+	 * pop it off the stack.  Pop the stack.  And then print
+	 * the perf message at the new (shallower) level so that
+	 * it lines up with the corresponding push/enter.
+	 */
+	us_elapsed_region = tr2tls_region_elasped_self(us_now);
+
+	tr2tls_pop_self();
+
+	/*
+	 * We expect each target function to treat 'ap' as constant
+	 * and use va_copy.
+	 */
+	for_each_wanted_builtin (j, tgt_j)
+		if (tgt_j->pfn_region_leave_printf_va_fl)
+			tgt_j->pfn_region_leave_printf_va_fl(
+				file, line, us_elapsed_absolute,
+				us_elapsed_region, category, label, repo, fmt,
+				ap);
+}
+
+void trace2_region_leave_fl(const char *file, int line, const char *category,
+			    const char *label, const struct repository *repo, ...)
+{
+	va_list ap;
+	va_start(ap, repo);
+	trace2_region_leave_printf_va_fl(file, line, category, label, repo,
+					 NULL, ap);
+	va_end(ap);
+}
+
+void trace2_region_leave_printf_fl(const char *file, int line,
+				   const char *category, const char *label,
+				   const struct repository *repo,
+				   const char *fmt, ...)
+{
+	va_list ap;
+
+	va_start(ap, fmt);
+	trace2_region_leave_printf_va_fl(file, line, category, label, repo, fmt,
+					 ap);
+	va_end(ap);
+}
+
+#ifndef HAVE_VARIADIC_MACROS
+void trace2_region_leave_printf(const char *category, const char *label,
+				const struct repository *repo, const char *fmt,
+				...)
+{
+	va_list ap;
+
+	va_start(ap, fmt);
+	trace2_region_leave_printf_va_fl(NULL, 0, category, label, repo, fmt,
+					 ap);
+	va_end(ap);
+}
+#endif
+
+void trace2_data_string_fl(const char *file, int line, const char *category,
+			   const struct repository *repo, const char *key,
+			   const char *value)
+{
+	struct tr2_tgt *tgt_j;
+	int j;
+	uint64_t us_now;
+	uint64_t us_elapsed_absolute;
+	uint64_t us_elapsed_region;
+
+	if (!trace2_enabled)
+		return;
+
+	us_now = getnanotime() / 1000;
+	us_elapsed_absolute = tr2tls_absolute_elapsed(us_now);
+	us_elapsed_region = tr2tls_region_elasped_self(us_now);
+
+	for_each_wanted_builtin (j, tgt_j)
+		if (tgt_j->pfn_data_fl)
+			tgt_j->pfn_data_fl(file, line, us_elapsed_absolute,
+					   us_elapsed_region, category, repo,
+					   key, value);
+}
+
+void trace2_data_intmax_fl(const char *file, int line, const char *category,
+			   const struct repository *repo, const char *key,
+			   intmax_t value)
+{
+	struct strbuf buf_string = STRBUF_INIT;
+
+	if (!trace2_enabled)
+		return;
+
+	strbuf_addf(&buf_string, "%" PRIdMAX, value);
+	trace2_data_string_fl(file, line, category, repo, key, buf_string.buf);
+	strbuf_release(&buf_string);
+}
+
+void trace2_data_json_fl(const char *file, int line, const char *category,
+			 const struct repository *repo, const char *key,
+			 const struct json_writer *value)
+{
+	struct tr2_tgt *tgt_j;
+	int j;
+	uint64_t us_now;
+	uint64_t us_elapsed_absolute;
+	uint64_t us_elapsed_region;
+
+	if (!trace2_enabled)
+		return;
+
+	us_now = getnanotime() / 1000;
+	us_elapsed_absolute = tr2tls_absolute_elapsed(us_now);
+	us_elapsed_region = tr2tls_region_elasped_self(us_now);
+
+	for_each_wanted_builtin (j, tgt_j)
+		if (tgt_j->pfn_data_json_fl)
+			tgt_j->pfn_data_json_fl(file, line, us_elapsed_absolute,
+						us_elapsed_region, category,
+						repo, key, value);
+}
+
+void trace2_printf_va_fl(const char *file, int line, const char *fmt,
+			 va_list ap)
+{
+	struct tr2_tgt *tgt_j;
+	int j;
+	uint64_t us_now;
+	uint64_t us_elapsed_absolute;
+
+	if (!trace2_enabled)
+		return;
+
+	us_now = getnanotime() / 1000;
+	us_elapsed_absolute = tr2tls_absolute_elapsed(us_now);
+
+	/*
+	 * We expect each target function to treat 'ap' as constant
+	 * and use va_copy.
+	 */
+	for_each_wanted_builtin (j, tgt_j)
+		if (tgt_j->pfn_printf_va_fl)
+			tgt_j->pfn_printf_va_fl(file, line, us_elapsed_absolute,
+						fmt, ap);
+}
+
+void trace2_printf_fl(const char *file, int line, const char *fmt, ...)
+{
+	va_list ap;
+
+	va_start(ap, fmt);
+	trace2_printf_va_fl(file, line, fmt, ap);
+	va_end(ap);
+}
+
+#ifndef HAVE_VARIADIC_MACROS
+void trace2_printf(const char *fmt, ...)
+{
+	va_list ap;
+
+	va_start(ap, fmt);
+	trace2_printf_va_fl(NULL, 0, fmt, ap);
+	va_end(ap);
+}
+#endif
diff -pruN 1.2.1+git2.18.0-1/git/trace2.h 1.2.3+git2.25.1-1/git/trace2.h
--- 1.2.1+git2.18.0-1/git/trace2.h	1970-01-01 00:00:00.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/trace2.h	2020-02-17 04:47:35.000000000 +0000
@@ -0,0 +1,490 @@
+#ifndef TRACE2_H
+#define TRACE2_H
+
+/**
+ * The Trace2 API can be used to print debug, performance, and telemetry
+ * information to stderr or a file.  The Trace2 feature is inactive unless
+ * explicitly enabled by enabling one or more Trace2 Targets.
+ *
+ * The Trace2 API is intended to replace the existing (Trace1)
+ * printf-style tracing provided by the existing `GIT_TRACE` and
+ * `GIT_TRACE_PERFORMANCE` facilities.  During initial implementation,
+ * Trace2 and Trace1 may operate in parallel.
+ *
+ * The Trace2 API defines a set of high-level messages with known fields,
+ * such as (`start`: `argv`) and (`exit`: {`exit-code`, `elapsed-time`}).
+ *
+ * Trace2 instrumentation throughout the Git code base sends Trace2
+ * messages to the enabled Trace2 Targets.  Targets transform these
+ * messages content into purpose-specific formats and write events to
+ * their data streams.  In this manner, the Trace2 API can drive
+ * many different types of analysis.
+ *
+ * Targets are defined using a VTable allowing easy extension to other
+ * formats in the future.  This might be used to define a binary format,
+ * for example.
+ *
+ * Trace2 is controlled using `trace2.*` config values in the system and
+ * global config files and `GIT_TRACE2*` environment variables.  Trace2 does
+ * not read from repo local or worktree config files or respect `-c`
+ * command line config settings.
+ *
+ * For more info about: trace2 targets, conventions for public functions and
+ * macros, trace2 target formats and examples on trace2 API usage refer to
+ * Documentation/technical/api-trace2.txt
+ *
+ */
+
+struct child_process;
+struct repository;
+struct json_writer;
+
+/*
+ * The public TRACE2 routines are grouped into the following groups:
+ *
+ * [] trace2_initialize -- initialization.
+ * [] trace2_cmd_*      -- emit command/control messages.
+ * [] trace2_child*     -- emit child start/stop messages.
+ * [] trace2_exec*      -- emit exec start/stop messages.
+ * [] trace2_thread*    -- emit thread start/stop messages.
+ * [] trace2_def*       -- emit definition/parameter mesasges.
+ * [] trace2_region*    -- emit region nesting messages.
+ * [] trace2_data*      -- emit region/thread/repo data messages.
+ * [] trace2_printf*    -- legacy trace[1] messages.
+ */
+
+/*
+ * Initialize the TRACE2 clock and do nothing else, in particular
+ * no mallocs, no system inspection, and no environment inspection.
+ *
+ * This should be called at the very top of main() to capture the
+ * process start time.  This is intended to reduce chicken-n-egg
+ * bootstrap pressure.
+ *
+ * It is safe to call this more than once.  This allows capturing
+ * absolute startup costs on Windows which uses a little trickery
+ * to do setup work before common-main.c:main() is called.
+ *
+ * The main trace2_initialize_fl() may be called a little later
+ * after more infrastructure is established.
+ */
+void trace2_initialize_clock(void);
+
+/*
+ * Initialize TRACE2 tracing facility if any of the builtin TRACE2
+ * targets are enabled in the system config or the environment.
+ * This includes setting up the Trace2 thread local storage (TLS).
+ * Emits a 'version' message containing the version of git
+ * and the Trace2 protocol.
+ *
+ * This function should be called from `main()` as early as possible in
+ * the life of the process after essential process initialization.
+ *
+ * Cleanup/Termination is handled automatically by a registered
+ * atexit() routine.
+ */
+void trace2_initialize_fl(const char *file, int line);
+
+#define trace2_initialize() trace2_initialize_fl(__FILE__, __LINE__)
+
+/*
+ * Return 1 if trace2 is enabled (at least one target is active).
+ */
+int trace2_is_enabled(void);
+
+/*
+ * Emit a 'start' event with the original (unmodified) argv.
+ */
+void trace2_cmd_start_fl(const char *file, int line, const char **argv);
+
+#define trace2_cmd_start(argv) trace2_cmd_start_fl(__FILE__, __LINE__, (argv))
+
+/*
+ * Emit an 'exit' event.
+ *
+ * Write the exit-code that will be passed to exit() or returned
+ * from main().
+ *
+ * Use this prior to actually calling exit().
+ * See "#define exit()" in git-compat-util.h
+ */
+int trace2_cmd_exit_fl(const char *file, int line, int code);
+
+#define trace2_cmd_exit(code) (trace2_cmd_exit_fl(__FILE__, __LINE__, (code)))
+
+/*
+ * Emit an 'error' event.
+ *
+ * Write an error message to the TRACE2 targets.
+ */
+void trace2_cmd_error_va_fl(const char *file, int line, const char *fmt,
+			    va_list ap);
+
+#define trace2_cmd_error_va(fmt, ap) \
+	trace2_cmd_error_va_fl(__FILE__, __LINE__, (fmt), (ap))
+
+/*
+ * Emit a 'pathname' event with the canonical pathname of the current process
+ * This gives post-processors a simple field to identify the command without
+ * having to parse the argv.  For example, to distinguish invocations from
+ * installed versus debug executables.
+ */
+void trace2_cmd_path_fl(const char *file, int line, const char *pathname);
+
+#define trace2_cmd_path(p) trace2_cmd_path_fl(__FILE__, __LINE__, (p))
+
+/*
+ * Emit a 'cmd_name' event with the canonical name of the command.
+ * This gives post-processors a simple field to identify the command
+ * without having to parse the argv.
+ */
+void trace2_cmd_name_fl(const char *file, int line, const char *name);
+
+#define trace2_cmd_name(v) trace2_cmd_name_fl(__FILE__, __LINE__, (v))
+
+/*
+ * Emit a 'cmd_mode' event to further describe the command being run.
+ * For example, "checkout" can checkout a single file or can checkout a
+ * different branch.  This gives post-processors a simple field to compare
+ * equivalent commands without having to parse the argv.
+ */
+void trace2_cmd_mode_fl(const char *file, int line, const char *mode);
+
+#define trace2_cmd_mode(sv) trace2_cmd_mode_fl(__FILE__, __LINE__, (sv))
+
+/*
+ * Emits an "alias" message containing the alias used and the argument
+ * expansion.
+ */
+void trace2_cmd_alias_fl(const char *file, int line, const char *alias,
+			 const char **argv);
+
+#define trace2_cmd_alias(alias, argv) \
+	trace2_cmd_alias_fl(__FILE__, __LINE__, (alias), (argv))
+
+/*
+ * Emit one or more 'def_param' events for "important" configuration
+ * settings.
+ *
+ * Use the TR2_SYSENV_CFG_PARAM setting to register a comma-separated
+ * list of patterns configured important.  For example:
+ *     git config --system trace2.configParams 'core.*,remote.*.url'
+ * or:
+ *     GIT_TRACE2_CONFIG_PARAMS=core.*,remote.*.url"
+ *
+ * Note: this routine does a read-only iteration on the config data
+ * (using read_early_config()), so it must not be called until enough
+ * of the process environment has been established.  This includes the
+ * location of the git and worktree directories, expansion of any "-c"
+ * and "-C" command line options, and etc.
+ */
+void trace2_cmd_list_config_fl(const char *file, int line);
+
+#define trace2_cmd_list_config() trace2_cmd_list_config_fl(__FILE__, __LINE__)
+
+/*
+ * Emit a "def_param" event for the given config key/value pair IF
+ * we consider the key to be "important".
+ *
+ * Use this for new/updated config settings created/updated after
+ * trace2_cmd_list_config() is called.
+ */
+void trace2_cmd_set_config_fl(const char *file, int line, const char *key,
+			      const char *value);
+
+#define trace2_cmd_set_config(k, v) \
+	trace2_cmd_set_config_fl(__FILE__, __LINE__, (k), (v))
+
+/**
+ * Emits a "child_start" message containing the "child-id",
+ * "child-argv", and "child-classification".
+ *
+ * Before calling optionally set "cmd->trace2_child_class" to a string
+ * describing the type of the child process.  For example, "editor" or
+ * "pager".
+ *
+ * This function assigns a unique "child-id" to `cmd->trace2_child_id`.
+ * This field is used later during the "child_exit" message to associate
+ * it with the "child_start" message.
+ *
+ * This function should be called before spawning the child process.
+ */
+void trace2_child_start_fl(const char *file, int line,
+			   struct child_process *cmd);
+
+#define trace2_child_start(cmd) trace2_child_start_fl(__FILE__, __LINE__, (cmd))
+
+/**
+ * Emits a "child_exit" message containing the "child-id",
+ * the child's elapsed time and exit-code.
+ *
+ * The reported elapsed time includes the process creation overhead and
+ * time spend waiting for it to exit, so it may be slightly longer than
+ * the time reported by the child itself.
+ *
+ * This function should be called after reaping the child process.
+ */
+void trace2_child_exit_fl(const char *file, int line, struct child_process *cmd,
+			  int child_exit_code);
+
+#define trace2_child_exit(cmd, code) \
+	trace2_child_exit_fl(__FILE__, __LINE__, (cmd), (code))
+
+/**
+ * Emit an 'exec' event prior to calling one of exec(), execv(),
+ * execvp(), and etc.  On Unix-derived systems, this will be the
+ * last event emitted for the current process, unless the exec
+ * fails.  On Windows, exec() behaves like 'child_start' and a
+ * waitpid(), so additional events may be emitted.
+ *
+ * Returns a unique "exec-id".  This value is used later
+ * if the exec() fails and a "exec-result" message is necessary.
+ */
+int trace2_exec_fl(const char *file, int line, const char *exe,
+		   const char **argv);
+
+#define trace2_exec(exe, argv) trace2_exec_fl(__FILE__, __LINE__, (exe), (argv))
+
+/**
+ * Emit an 'exec_result' when possible.  On Unix-derived systems,
+ * this should be called after exec() returns (which only happens
+ * when there is an error starting the new process).  On Windows,
+ * this should be called after the waitpid().
+ *
+ * The "exec_id" should be the value returned from trace2_exec().
+ */
+void trace2_exec_result_fl(const char *file, int line, int exec_id, int code);
+
+#define trace2_exec_result(id, code) \
+	trace2_exec_result_fl(__FILE__, __LINE__, (id), (code))
+
+/*
+ * Emit a 'thread_start' event.  This must be called from inside the
+ * thread-proc to set up the trace2 TLS data for the thread.
+ *
+ * Thread names should be descriptive, like "preload_index".
+ * Thread names will be decorated with an instance number automatically.
+ */
+void trace2_thread_start_fl(const char *file, int line,
+			    const char *thread_name);
+
+#define trace2_thread_start(thread_name) \
+	trace2_thread_start_fl(__FILE__, __LINE__, (thread_name))
+
+/*
+ * Emit a 'thread_exit' event.  This must be called from inside the
+ * thread-proc to report thread-specific data and cleanup TLS data
+ * for the thread.
+ */
+void trace2_thread_exit_fl(const char *file, int line);
+
+#define trace2_thread_exit() trace2_thread_exit_fl(__FILE__, __LINE__)
+
+/*
+ * Emits a "def_param" message containing a key/value pair.
+ *
+ * This message is intended to report some global aspect of the current
+ * command, such as a configuration setting or command line switch that
+ * significantly affects program performance or behavior, such as
+ * `core.abbrev`, `status.showUntrackedFiles`, or `--no-ahead-behind`.
+ */
+void trace2_def_param_fl(const char *file, int line, const char *param,
+			 const char *value);
+
+#define trace2_def_param(param, value) \
+	trace2_def_param_fl(__FILE__, __LINE__, (param), (value))
+
+/*
+ * Tell trace2 about a newly instantiated repo object and assign
+ * a trace2-repo-id to be used in subsequent activity events.
+ *
+ * Emits a 'worktree' event for this repo instance.
+ *
+ * Region and data messages may refer to this repo-id.
+ *
+ * The main/top-level repository will have repo-id value 1 (aka "r1").
+ *
+ * The repo-id field is in anticipation of future in-proc submodule
+ * repositories.
+ */
+void trace2_def_repo_fl(const char *file, int line, struct repository *repo);
+
+#define trace2_def_repo(repo) trace2_def_repo_fl(__FILE__, __LINE__, repo)
+
+/**
+ * Emit a 'region_enter' event for <category>.<label> with optional
+ * repo-id and printf message.
+ *
+ * This function pushes a new region nesting stack level on the current
+ * thread and starts a clock for the new stack frame.
+ *
+ * The `category` field is an arbitrary category name used to classify
+ * regions by feature area, such as "status" or "index".  At this time
+ * it is only just printed along with the rest of the message.  It may
+ * be used in the future to filter messages.
+ *
+ * The `label` field is an arbitrary label used to describe the activity
+ * being started, such as "read_recursive" or "do_read_index".
+ *
+ * The `repo` field, if set, will be used to get the "repo-id", so that
+ * recursive oerations can be attributed to the correct repository.
+ */
+void trace2_region_enter_fl(const char *file, int line, const char *category,
+			    const char *label, const struct repository *repo, ...);
+
+#define trace2_region_enter(category, label, repo) \
+	trace2_region_enter_fl(__FILE__, __LINE__, (category), (label), (repo))
+
+void trace2_region_enter_printf_va_fl(const char *file, int line,
+				      const char *category, const char *label,
+				      const struct repository *repo,
+				      const char *fmt, va_list ap);
+
+#define trace2_region_enter_printf_va(category, label, repo, fmt, ap)    \
+	trace2_region_enter_printf_va_fl(__FILE__, __LINE__, (category), \
+					 (label), (repo), (fmt), (ap))
+
+void trace2_region_enter_printf_fl(const char *file, int line,
+				   const char *category, const char *label,
+				   const struct repository *repo,
+				   const char *fmt, ...);
+
+#ifdef HAVE_VARIADIC_MACROS
+#define trace2_region_enter_printf(category, label, repo, ...)                 \
+	trace2_region_enter_printf_fl(__FILE__, __LINE__, (category), (label), \
+				      (repo), __VA_ARGS__)
+#else
+/* clang-format off */
+__attribute__((format (region_enter_printf, 4, 5)))
+void trace2_region_enter_printf(const char *category, const char *label,
+				const struct repository *repo, const char *fmt,
+				...);
+/* clang-format on */
+#endif
+
+/**
+ * Emit a 'region_leave' event for <category>.<label> with optional
+ * repo-id and printf message.
+ *
+ * Leave current nesting level and report the elapsed time spent
+ * in this nesting level.
+ *
+ * The `category`, `label`, and `repo` fields are the same as
+ * trace2_region_enter_fl. The `category` and `label` do not
+ * need to match the corresponding "region_enter" message,
+ * but it makes the data stream easier to understand.
+ */
+void trace2_region_leave_fl(const char *file, int line, const char *category,
+			    const char *label, const struct repository *repo, ...);
+
+#define trace2_region_leave(category, label, repo) \
+	trace2_region_leave_fl(__FILE__, __LINE__, (category), (label), (repo))
+
+void trace2_region_leave_printf_va_fl(const char *file, int line,
+				      const char *category, const char *label,
+				      const struct repository *repo,
+				      const char *fmt, va_list ap);
+
+#define trace2_region_leave_printf_va(category, label, repo, fmt, ap)    \
+	trace2_region_leave_printf_va_fl(__FILE__, __LINE__, (category), \
+					 (label), (repo), (fmt), (ap))
+
+void trace2_region_leave_printf_fl(const char *file, int line,
+				   const char *category, const char *label,
+				   const struct repository *repo,
+				   const char *fmt, ...);
+
+#ifdef HAVE_VARIADIC_MACROS
+#define trace2_region_leave_printf(category, label, repo, ...)                 \
+	trace2_region_leave_printf_fl(__FILE__, __LINE__, (category), (label), \
+				      (repo), __VA_ARGS__)
+#else
+/* clang-format off */
+__attribute__((format (region_leave_printf, 4, 5)))
+void trace2_region_leave_printf(const char *category, const char *label,
+				const struct repository *repo, const char *fmt,
+				...);
+/* clang-format on */
+#endif
+
+/**
+ * Emit a key-value pair 'data' event of the form <category>.<key> = <value>.
+ * This event implicitly contains information about thread, nesting region,
+ * and optional repo-id.
+ * This could be used to print the number of files in a directory during
+ * a multi-threaded recursive tree walk.
+ *
+ * On event-based TRACE2 targets, this generates a 'data' event suitable
+ * for post-processing.  On printf-based TRACE2 targets, this is converted
+ * into a fixed-format printf message.
+ */
+void trace2_data_string_fl(const char *file, int line, const char *category,
+			   const struct repository *repo, const char *key,
+			   const char *value);
+
+#define trace2_data_string(category, repo, key, value)                       \
+	trace2_data_string_fl(__FILE__, __LINE__, (category), (repo), (key), \
+			      (value))
+
+void trace2_data_intmax_fl(const char *file, int line, const char *category,
+			   const struct repository *repo, const char *key,
+			   intmax_t value);
+
+#define trace2_data_intmax(category, repo, key, value)                       \
+	trace2_data_intmax_fl(__FILE__, __LINE__, (category), (repo), (key), \
+			      (value))
+
+void trace2_data_json_fl(const char *file, int line, const char *category,
+			 const struct repository *repo, const char *key,
+			 const struct json_writer *jw);
+
+#define trace2_data_json(category, repo, key, value)                       \
+	trace2_data_json_fl(__FILE__, __LINE__, (category), (repo), (key), \
+			    (value))
+
+/*
+ * Emit a 'printf' event.
+ *
+ * Write an arbitrary formatted message to the TRACE2 targets.  These
+ * text messages should be considered as human-readable strings without
+ * any formatting guidelines.  Post-processors may choose to ignore
+ * them.
+ */
+void trace2_printf_va_fl(const char *file, int line, const char *fmt,
+			 va_list ap);
+
+#define trace2_printf_va(fmt, ap) \
+	trace2_printf_va_fl(__FILE__, __LINE__, (fmt), (ap))
+
+void trace2_printf_fl(const char *file, int line, const char *fmt, ...);
+
+#ifdef HAVE_VARIADIC_MACROS
+#define trace2_printf(...) trace2_printf_fl(__FILE__, __LINE__, __VA_ARGS__)
+#else
+/* clang-format off */
+__attribute__((format (printf, 1, 2)))
+void trace2_printf(const char *fmt, ...);
+/* clang-format on */
+#endif
+
+/*
+ * Optional platform-specific code to dump information about the
+ * current and any parent process(es).  This is intended to allow
+ * post-processors to know who spawned this git instance and anything
+ * else that the platform may be able to tell us about the current process.
+ */
+
+enum trace2_process_info_reason {
+	TRACE2_PROCESS_INFO_STARTUP,
+	TRACE2_PROCESS_INFO_EXIT,
+};
+
+#if defined(GIT_WINDOWS_NATIVE)
+void trace2_collect_process_info(enum trace2_process_info_reason reason);
+#else
+#define trace2_collect_process_info(reason) \
+	do {                                \
+	} while (0)
+#endif
+
+#endif /* TRACE2_H */
diff -pruN 1.2.1+git2.18.0-1/git/trace.c 1.2.3+git2.25.1-1/git/trace.c
--- 1.2.1+git2.18.0-1/git/trace.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/trace.c	2020-02-17 04:47:35.000000000 +0000
@@ -88,8 +88,6 @@ static int prepare_trace_line(const char
 	if (!trace_want(key))
 		return 0;
 
-	set_try_to_free_routine(NULL);	/* is never reset */
-
 	/* unit tests may want to disable additional trace output */
 	if (trace_want(&trace_bare))
 		return 1;
@@ -176,10 +174,30 @@ void trace_strbuf_fl(const char *file, i
 	strbuf_release(&buf);
 }
 
+static uint64_t perf_start_times[10];
+static int perf_indent;
+
+uint64_t trace_performance_enter(void)
+{
+	uint64_t now;
+
+	if (!trace_want(&trace_perf_key))
+		return 0;
+
+	now = getnanotime();
+	perf_start_times[perf_indent] = now;
+	if (perf_indent + 1 < ARRAY_SIZE(perf_start_times))
+		perf_indent++;
+	else
+		BUG("Too deep indentation");
+	return now;
+}
+
 static void trace_performance_vprintf_fl(const char *file, int line,
 					 uint64_t nanos, const char *format,
 					 va_list ap)
 {
+	static const char space[] = "          ";
 	struct strbuf buf = STRBUF_INIT;
 
 	if (!prepare_trace_line(file, line, &trace_perf_key, &buf))
@@ -188,7 +206,10 @@ static void trace_performance_vprintf_fl
 	strbuf_addf(&buf, "performance: %.9f s", (double) nanos / 1000000000);
 
 	if (format && *format) {
-		strbuf_addstr(&buf, ": ");
+		if (perf_indent >= strlen(space))
+			BUG("Too deep indentation");
+
+		strbuf_addf(&buf, ":%.*s ", perf_indent, space);
 		strbuf_vaddf(&buf, format, ap);
 	}
 
@@ -244,6 +265,24 @@ void trace_performance_since(uint64_t st
 	va_end(ap);
 }
 
+void trace_performance_leave(const char *format, ...)
+{
+	va_list ap;
+	uint64_t since;
+
+	if (perf_indent)
+		perf_indent--;
+
+	if (!format) /* Allow callers to leave without tracing anything */
+		return;
+
+	since = perf_start_times[perf_indent];
+	va_start(ap, format);
+	trace_performance_vprintf_fl(NULL, 0, getnanotime() - since,
+				     format, ap);
+	va_end(ap);
+}
+
 #else
 
 void trace_printf_key_fl(const char *file, int line, struct trace_key *key,
@@ -273,6 +312,24 @@ void trace_performance_fl(const char *fi
 	va_end(ap);
 }
 
+void trace_performance_leave_fl(const char *file, int line,
+				uint64_t nanos, const char *format, ...)
+{
+	va_list ap;
+	uint64_t since;
+
+	if (perf_indent)
+		perf_indent--;
+
+	if (!format) /* Allow callers to leave without tracing anything */
+		return;
+
+	since = perf_start_times[perf_indent];
+	va_start(ap, format);
+	trace_performance_vprintf_fl(file, line, nanos - since, format, ap);
+	va_end(ap);
+}
+
 #endif /* HAVE_VARIADIC_MACROS */
 
 
@@ -411,13 +468,11 @@ uint64_t getnanotime(void)
 	}
 }
 
-static uint64_t command_start_time;
 static struct strbuf command_line = STRBUF_INIT;
 
 static void print_command_performance_atexit(void)
 {
-	trace_performance_since(command_start_time, "git command:%s",
-				command_line.buf);
+	trace_performance_leave("git command:%s", command_line.buf);
 }
 
 void trace_command_performance(const char **argv)
@@ -425,10 +480,10 @@ void trace_command_performance(const cha
 	if (!trace_want(&trace_perf_key))
 		return;
 
-	if (!command_start_time)
+	if (!command_line.len)
 		atexit(print_command_performance_atexit);
 
 	strbuf_reset(&command_line);
 	sq_quote_argv_pretty(&command_line, argv);
-	command_start_time = getnanotime();
+	trace_performance_enter();
 }
diff -pruN 1.2.1+git2.18.0-1/git/trace.h 1.2.3+git2.25.1-1/git/trace.h
--- 1.2.1+git2.18.0-1/git/trace.h	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/trace.h	2020-02-17 04:47:35.000000000 +0000
@@ -4,6 +4,82 @@
 #include "git-compat-util.h"
 #include "strbuf.h"
 
+/**
+ * The trace API can be used to print debug messages to stderr or a file. Trace
+ * code is inactive unless explicitly enabled by setting `GIT_TRACE*` environment
+ * variables.
+ *
+ * The trace implementation automatically adds `timestamp file:line ... \n` to
+ * all trace messages. E.g.:
+ *
+ * ------------
+ * 23:59:59.123456 git.c:312               trace: built-in: git 'foo'
+ * 00:00:00.000001 builtin/foo.c:99        foo: some message
+ * ------------
+ *
+ * Bugs & Caveats
+ * --------------
+ *
+ * GIT_TRACE_* environment variables can be used to tell Git to show
+ * trace output to its standard error stream. Git can often spawn a pager
+ * internally to run its subcommand and send its standard output and
+ * standard error to it.
+ *
+ * Because GIT_TRACE_PERFORMANCE trace is generated only at the very end
+ * of the program with atexit(), which happens after the pager exits, it
+ * would not work well if you send its log to the standard error output
+ * and let Git spawn the pager at the same time.
+ *
+ * As a work around, you can for example use '--no-pager', or set
+ * GIT_TRACE_PERFORMANCE to another file descriptor which is redirected
+ * to stderr, or set GIT_TRACE_PERFORMANCE to a file specified by its
+ * absolute path.
+ *
+ * For example instead of the following command which by default may not
+ * print any performance information:
+ *
+ * ------------
+ * GIT_TRACE_PERFORMANCE=2 git log -1
+ * ------------
+ *
+ * you may want to use:
+ *
+ * ------------
+ * GIT_TRACE_PERFORMANCE=2 git --no-pager log -1
+ * ------------
+ *
+ * or:
+ *
+ * ------------
+ * GIT_TRACE_PERFORMANCE=3 3>&2 git log -1
+ * ------------
+ *
+ * or:
+ *
+ * ------------
+ * GIT_TRACE_PERFORMANCE=/path/to/log/file git log -1
+ * ------------
+ *
+ */
+
+/**
+ * Defines a trace key (or category). The default (for API functions that
+ * don't take a key) is `GIT_TRACE`.
+ *
+ * E.g. to define a trace key controlled by environment variable `GIT_TRACE_FOO`:
+ *
+ * ------------
+ * static struct trace_key trace_foo = TRACE_KEY_INIT(FOO);
+ *
+ * static void trace_print_foo(const char *message)
+ * {
+ * 	trace_printf_key(&trace_foo, "%s", message);
+ * }
+ * ------------
+ *
+ * Note: don't use `const` as the trace implementation stores internal state in
+ * the `trace_key` structure.
+ */
 struct trace_key {
 	const char * const key;
 	int fd;
@@ -17,33 +93,90 @@ extern struct trace_key trace_default_ke
 extern struct trace_key trace_perf_key;
 extern struct trace_key trace_setup_key;
 
-extern void trace_repo_setup(const char *prefix);
-extern int trace_want(struct trace_key *key);
-extern void trace_disable(struct trace_key *key);
-extern uint64_t getnanotime(void);
-extern void trace_command_performance(const char **argv);
-extern void trace_verbatim(struct trace_key *key, const void *buf, unsigned len);
+void trace_repo_setup(const char *prefix);
+
+/**
+ * Checks whether the trace key is enabled. Used to prevent expensive
+ * string formatting before calling one of the printing APIs.
+ */
+int trace_want(struct trace_key *key);
+
+/**
+ * Disables tracing for the specified key, even if the environment variable
+ * was set.
+ */
+void trace_disable(struct trace_key *key);
+
+/**
+ * Returns nanoseconds since the epoch (01/01/1970), typically used
+ * for performance measurements.
+ * Currently there are high precision timer implementations for Linux (using
+ * `clock_gettime(CLOCK_MONOTONIC)`) and Windows (`QueryPerformanceCounter`).
+ * Other platforms use `gettimeofday` as time source.
+ */
+uint64_t getnanotime(void);
+
+void trace_command_performance(const char **argv);
+void trace_verbatim(struct trace_key *key, const void *buf, unsigned len);
+uint64_t trace_performance_enter(void);
 
 #ifndef HAVE_VARIADIC_MACROS
 
+/**
+ * Prints a formatted message, similar to printf.
+ */
 __attribute__((format (printf, 1, 2)))
-extern void trace_printf(const char *format, ...);
+void trace_printf(const char *format, ...);
 
 __attribute__((format (printf, 2, 3)))
-extern void trace_printf_key(struct trace_key *key, const char *format, ...);
+void trace_printf_key(struct trace_key *key, const char *format, ...);
 
+/**
+ * Prints a formatted message, followed by a quoted list of arguments.
+ */
 __attribute__((format (printf, 2, 3)))
-extern void trace_argv_printf(const char **argv, const char *format, ...);
+void trace_argv_printf(const char **argv, const char *format, ...);
 
-extern void trace_strbuf(struct trace_key *key, const struct strbuf *data);
+/**
+ * Prints the strbuf, without additional formatting (i.e. doesn't
+ * choke on `%` or even `\0`).
+ */
+void trace_strbuf(struct trace_key *key, const struct strbuf *data);
 
-/* Prints elapsed time (in nanoseconds) if GIT_TRACE_PERFORMANCE is enabled. */
+/**
+ * Prints elapsed time (in nanoseconds) if GIT_TRACE_PERFORMANCE is enabled.
+ *
+ * Example:
+ * ------------
+ * uint64_t t = 0;
+ * for (;;) {
+ * 	// ignore
+ * t -= getnanotime();
+ * // code section to measure
+ * t += getnanotime();
+ * // ignore
+ * }
+ * trace_performance(t, "frotz");
+ * ------------
+ */
 __attribute__((format (printf, 2, 3)))
-extern void trace_performance(uint64_t nanos, const char *format, ...);
+void trace_performance(uint64_t nanos, const char *format, ...);
 
-/* Prints elapsed time since 'start' if GIT_TRACE_PERFORMANCE is enabled. */
+/**
+ * Prints elapsed time since 'start' if GIT_TRACE_PERFORMANCE is enabled.
+ *
+ * Example:
+ * ------------
+ * uint64_t start = getnanotime();
+ * // code section to measure
+ * trace_performance_since(start, "foobar");
+ * ------------
+ */
 __attribute__((format (printf, 2, 3)))
-extern void trace_performance_since(uint64_t start, const char *format, ...);
+void trace_performance_since(uint64_t start, const char *format, ...);
+
+__attribute__((format (printf, 1, 2)))
+void trace_performance_leave(const char *format, ...);
 
 #else
 
@@ -118,18 +251,29 @@ extern void trace_performance_since(uint
 					     __VA_ARGS__);		    \
 	} while (0)
 
+#define trace_performance_leave(...)					    \
+	do {								    \
+		if (trace_pass_fl(&trace_perf_key))			    \
+			trace_performance_leave_fl(TRACE_CONTEXT, __LINE__, \
+						   getnanotime(),	    \
+						   __VA_ARGS__);	    \
+	} while (0)
+
 /* backend functions, use non-*fl macros instead */
 __attribute__((format (printf, 4, 5)))
-extern void trace_printf_key_fl(const char *file, int line, struct trace_key *key,
-				const char *format, ...);
+void trace_printf_key_fl(const char *file, int line, struct trace_key *key,
+			 const char *format, ...);
+__attribute__((format (printf, 4, 5)))
+void trace_argv_printf_fl(const char *file, int line, const char **argv,
+			  const char *format, ...);
+void trace_strbuf_fl(const char *file, int line, struct trace_key *key,
+		     const struct strbuf *data);
 __attribute__((format (printf, 4, 5)))
-extern void trace_argv_printf_fl(const char *file, int line, const char **argv,
-				 const char *format, ...);
-extern void trace_strbuf_fl(const char *file, int line, struct trace_key *key,
-			    const struct strbuf *data);
+void trace_performance_fl(const char *file, int line,
+			  uint64_t nanos, const char *fmt, ...);
 __attribute__((format (printf, 4, 5)))
-extern void trace_performance_fl(const char *file, int line,
-				 uint64_t nanos, const char *fmt, ...);
+void trace_performance_leave_fl(const char *file, int line,
+				uint64_t nanos, const char *fmt, ...);
 static inline int trace_pass_fl(struct trace_key *key)
 {
 	return key->fd || !key->initialized;
diff -pruN 1.2.1+git2.18.0-1/git/trailer.c 1.2.3+git2.25.1-1/git/trailer.c
--- 1.2.1+git2.18.0-1/git/trailer.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/trailer.c	2020-02-17 04:47:35.000000000 +0000
@@ -585,7 +585,7 @@ static const char *token_from_item(struc
 	return item->conf.name;
 }
 
-static int token_matches_item(const char *tok, struct arg_item *item, int tok_len)
+static int token_matches_item(const char *tok, struct arg_item *item, size_t tok_len)
 {
 	if (!strncasecmp(tok, item->conf.name, tok_len))
 		return 1;
@@ -603,7 +603,7 @@ static int token_matches_item(const char
  * distinguished from the non-well-formed-line case (in which this function
  * returns -1) because some callers of this function need such a distinction.
  */
-static int find_separator(const char *line, const char *separators)
+static ssize_t find_separator(const char *line, const char *separators)
 {
 	int whitespace_found = 0;
 	const char *c;
@@ -630,10 +630,10 @@ static int find_separator(const char *li
  */
 static void parse_trailer(struct strbuf *tok, struct strbuf *val,
 			 const struct conf_info **conf, const char *trailer,
-			 int separator_pos)
+			 ssize_t separator_pos)
 {
 	struct arg_item *item;
-	int tok_len;
+	size_t tok_len;
 	struct list_head *pos;
 
 	if (separator_pos != -1) {
@@ -721,7 +721,7 @@ static void process_command_line_args(st
 	list_for_each(pos, new_trailer_head) {
 		struct new_trailer_item *tr =
 			list_entry(pos, struct new_trailer_item, list);
-		int separator_pos = find_separator(tr->text, cl_separators);
+		ssize_t separator_pos = find_separator(tr->text, cl_separators);
 
 		if (separator_pos == 0) {
 			struct strbuf sb = STRBUF_INIT;
@@ -763,9 +763,9 @@ static const char *next_line(const char
 /*
  * Return the position of the start of the last line. If len is 0, return -1.
  */
-static int last_line(const char *buf, size_t len)
+static ssize_t last_line(const char *buf, size_t len)
 {
-	int i;
+	ssize_t i;
 	if (len == 0)
 		return -1;
 	if (len == 1)
@@ -788,12 +788,14 @@ static int last_line(const char *buf, si
  * Return the position of the start of the patch or the length of str if there
  * is no patch in the message.
  */
-static int find_patch_start(const char *str)
+static size_t find_patch_start(const char *str)
 {
 	const char *s;
 
 	for (s = str; *s; s = next_line(s)) {
-		if (starts_with(s, "---"))
+		const char *v;
+
+		if (skip_prefix(s, "---", &v) && isspace(*v))
 			return s - str;
 	}
 
@@ -804,10 +806,11 @@ static int find_patch_start(const char *
  * Return the position of the first trailer line or len if there are no
  * trailers.
  */
-static int find_trailer_start(const char *buf, size_t len)
+static size_t find_trailer_start(const char *buf, size_t len)
 {
 	const char *s;
-	int end_of_title, l, only_spaces = 1;
+	ssize_t end_of_title, l;
+	int only_spaces = 1;
 	int recognized_prefix = 0, trailer_lines = 0, non_trailer_lines = 0;
 	/*
 	 * Number of possible continuation lines encountered. This will be
@@ -838,7 +841,7 @@ static int find_trailer_start(const char
 	     l = last_line(buf, l)) {
 		const char *bol = buf + l;
 		const char **p;
-		int separator_pos;
+		ssize_t separator_pos;
 
 		if (bol[0] == comment_line_char) {
 			non_trailer_lines += possible_continuation_lines;
@@ -899,14 +902,14 @@ continue_outer_loop:
 }
 
 /* Return the position of the end of the trailers. */
-static int find_trailer_end(const char *buf, size_t len)
+static size_t find_trailer_end(const char *buf, size_t len)
 {
 	return len - ignore_non_trailer(buf, len);
 }
 
 static int ends_with_blank_line(const char *buf, size_t len)
 {
-	int ll = last_line(buf, len);
+	ssize_t ll = last_line(buf, len);
 	if (ll < 0)
 		return 0;
 	return is_blank_line(buf + ll);
@@ -939,17 +942,17 @@ static void unfold_value(struct strbuf *
 	strbuf_release(&out);
 }
 
-static int process_input_file(FILE *outfile,
-			      const char *str,
-			      struct list_head *head,
-			      const struct process_trailer_options *opts)
+static size_t process_input_file(FILE *outfile,
+				 const char *str,
+				 struct list_head *head,
+				 const struct process_trailer_options *opts)
 {
 	struct trailer_info info;
 	struct strbuf tok = STRBUF_INIT;
 	struct strbuf val = STRBUF_INIT;
-	int i;
+	size_t i;
 
-	trailer_info_get(&info, str);
+	trailer_info_get(&info, str, opts);
 
 	/* Print lines before the trailers as is */
 	if (!opts->only_trailers)
@@ -1032,7 +1035,7 @@ void process_trailers(const char *file,
 {
 	LIST_HEAD(head);
 	struct strbuf sb = STRBUF_INIT;
-	int trailer_end;
+	size_t trailer_end;
 	FILE *outfile = stdout;
 
 	ensure_configured();
@@ -1066,7 +1069,8 @@ void process_trailers(const char *file,
 	strbuf_release(&sb);
 }
 
-void trailer_info_get(struct trailer_info *info, const char *str)
+void trailer_info_get(struct trailer_info *info, const char *str,
+		      const struct process_trailer_options *opts)
 {
 	int patch_start, trailer_end, trailer_start;
 	struct strbuf **trailer_lines, **ptr;
@@ -1076,7 +1080,11 @@ void trailer_info_get(struct trailer_inf
 
 	ensure_configured();
 
-	patch_start = find_patch_start(str);
+	if (opts->no_divider)
+		patch_start = strlen(str);
+	else
+		patch_start = find_patch_start(str);
+
 	trailer_end = find_trailer_end(str, patch_start);
 	trailer_start = find_trailer_start(str, trailer_end);
 
@@ -1111,7 +1119,7 @@ void trailer_info_get(struct trailer_inf
 
 void trailer_info_release(struct trailer_info *info)
 {
-	int i;
+	size_t i;
 	for (i = 0; i < info->trailer_nr; i++)
 		free(info->trailers[i]);
 	free(info->trailers);
@@ -1121,10 +1129,11 @@ static void format_trailer_info(struct s
 				const struct trailer_info *info,
 				const struct process_trailer_options *opts)
 {
-	int i;
+	size_t origlen = out->len;
+	size_t i;
 
 	/* If we want the whole block untouched, we can take the fast path. */
-	if (!opts->only_trailers && !opts->unfold) {
+	if (!opts->only_trailers && !opts->unfold && !opts->filter && !opts->separator) {
 		strbuf_add(out, info->trailer_start,
 			   info->trailer_end - info->trailer_start);
 		return;
@@ -1132,22 +1141,36 @@ static void format_trailer_info(struct s
 
 	for (i = 0; i < info->trailer_nr; i++) {
 		char *trailer = info->trailers[i];
-		int separator_pos = find_separator(trailer, separators);
+		ssize_t separator_pos = find_separator(trailer, separators);
 
 		if (separator_pos >= 1) {
 			struct strbuf tok = STRBUF_INIT;
 			struct strbuf val = STRBUF_INIT;
 
 			parse_trailer(&tok, &val, NULL, trailer, separator_pos);
-			if (opts->unfold)
-				unfold_value(&val);
-
-			strbuf_addf(out, "%s: %s\n", tok.buf, val.buf);
+			if (!opts->filter || opts->filter(&tok, opts->filter_data)) {
+				if (opts->unfold)
+					unfold_value(&val);
+
+				if (opts->separator && out->len != origlen)
+					strbuf_addbuf(out, opts->separator);
+				if (!opts->value_only)
+					strbuf_addf(out, "%s: ", tok.buf);
+				strbuf_addbuf(out, &val);
+				if (!opts->separator)
+					strbuf_addch(out, '\n');
+			}
 			strbuf_release(&tok);
 			strbuf_release(&val);
 
 		} else if (!opts->only_trailers) {
+			if (opts->separator && out->len != origlen) {
+				strbuf_addbuf(out, opts->separator);
+			}
 			strbuf_addstr(out, trailer);
+			if (opts->separator) {
+				strbuf_rtrim(out);
+			}
 		}
 	}
 
@@ -1158,7 +1181,7 @@ void format_trailers_from_commit(struct
 {
 	struct trailer_info info;
 
-	trailer_info_get(&info, msg);
+	trailer_info_get(&info, msg, opts);
 	format_trailer_info(out, &info, opts);
 	trailer_info_release(&info);
 }
diff -pruN 1.2.1+git2.18.0-1/git/trailer.h 1.2.3+git2.25.1-1/git/trailer.h
--- 1.2.1+git2.18.0-1/git/trailer.h	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/trailer.h	2020-02-17 04:47:35.000000000 +0000
@@ -3,6 +3,8 @@
 
 #include "list.h"
 
+struct strbuf;
+
 enum trailer_where {
 	WHERE_DEFAULT,
 	WHERE_END,
@@ -69,6 +71,11 @@ struct process_trailer_options {
 	int only_trailers;
 	int only_input;
 	int unfold;
+	int no_divider;
+	int value_only;
+	const struct strbuf *separator;
+	int (*filter)(const struct strbuf *, void *);
+	void *filter_data;
 };
 
 #define PROCESS_TRAILER_OPTIONS_INIT {0}
@@ -77,7 +84,8 @@ void process_trailers(const char *file,
 		      const struct process_trailer_options *opts,
 		      struct list_head *new_trailer_head);
 
-void trailer_info_get(struct trailer_info *info, const char *str);
+void trailer_info_get(struct trailer_info *info, const char *str,
+		      const struct process_trailer_options *opts);
 
 void trailer_info_release(struct trailer_info *info);
 
diff -pruN 1.2.1+git2.18.0-1/git/transport.c 1.2.3+git2.25.1-1/git/transport.c
--- 1.2.1+git2.18.0-1/git/transport.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/transport.c	2020-02-17 04:47:35.000000000 +0000
@@ -122,6 +122,7 @@ static void set_upstreams(struct transpo
 struct bundle_transport_data {
 	int fd;
 	struct bundle_header header;
+	unsigned get_refs_from_bundle_called : 1;
 };
 
 static struct ref *get_refs_from_bundle(struct transport *transport,
@@ -135,11 +136,13 @@ static struct ref *get_refs_from_bundle(
 	if (for_push)
 		return NULL;
 
+	data->get_refs_from_bundle_called = 1;
+
 	if (data->fd > 0)
 		close(data->fd);
 	data->fd = read_bundle_header(transport->url, &data->header);
 	if (data->fd < 0)
-		die ("Could not read bundle '%s'.", transport->url);
+		die(_("could not read bundle '%s'"), transport->url);
 	for (i = 0; i < data->header.references.nr; i++) {
 		struct ref_list_entry *e = data->header.references.list + i;
 		struct ref *ref = alloc_ref(e->name);
@@ -154,7 +157,10 @@ static int fetch_refs_from_bundle(struct
 			       int nr_heads, struct ref **to_fetch)
 {
 	struct bundle_transport_data *data = transport->data;
-	return unbundle(&data->header, data->fd,
+
+	if (!data->get_refs_from_bundle_called)
+		get_refs_from_bundle(transport, 0, NULL);
+	return unbundle(the_repository, &data->header, data->fd,
 			transport->progress ? BUNDLE_VERBOSE : 0);
 }
 
@@ -224,6 +230,7 @@ static int set_git_option(struct git_tra
 		opts->no_dependents = !!value;
 		return 0;
 	} else if (!strcmp(name, TRANS_OPT_LIST_OBJECTS_FILTER)) {
+		list_objects_filter_die_if_populated(&opts->filter_options);
 		parse_list_objects_filter(&opts->filter_options, value);
 		return 0;
 	}
@@ -252,8 +259,26 @@ static int connect_setup(struct transpor
 	return 0;
 }
 
-static struct ref *get_refs_via_connect(struct transport *transport, int for_push,
-					const struct argv_array *ref_prefixes)
+static void die_if_server_options(struct transport *transport)
+{
+	if (!transport->server_options || !transport->server_options->nr)
+		return;
+	advise(_("see protocol.version in 'git help config' for more details"));
+	die(_("server options require protocol version 2 or later"));
+}
+
+/*
+ * Obtains the protocol version from the transport and writes it to
+ * transport->data->version, first connecting if not already connected.
+ *
+ * If the protocol version is one that allows skipping the listing of remote
+ * refs, and must_list_refs is 0, the listing of remote refs is skipped and
+ * this function returns NULL. Otherwise, this function returns the list of
+ * remote refs.
+ */
+static struct ref *handshake(struct transport *transport, int for_push,
+			     const struct argv_array *ref_prefixes,
+			     int must_list_refs)
 {
 	struct git_transport_data *data = transport->data;
 	struct ref *refs = NULL;
@@ -263,16 +288,20 @@ static struct ref *get_refs_via_connect(
 
 	packet_reader_init(&reader, data->fd[0], NULL, 0,
 			   PACKET_READ_CHOMP_NEWLINE |
-			   PACKET_READ_GENTLE_ON_EOF);
+			   PACKET_READ_GENTLE_ON_EOF |
+			   PACKET_READ_DIE_ON_ERR_PACKET);
 
 	data->version = discover_version(&reader);
 	switch (data->version) {
 	case protocol_v2:
-		get_remote_refs(data->fd[1], &reader, &refs, for_push,
-				ref_prefixes, transport->server_options);
+		if (must_list_refs)
+			get_remote_refs(data->fd[1], &reader, &refs, for_push,
+					ref_prefixes,
+					transport->server_options);
 		break;
 	case protocol_v1:
 	case protocol_v0:
+		die_if_server_options(transport);
 		get_remote_heads(&reader, &refs,
 				 for_push ? REF_NORMAL : 0,
 				 &data->extra_have,
@@ -283,16 +312,24 @@ static struct ref *get_refs_via_connect(
 	}
 	data->got_remote_heads = 1;
 
+	if (reader.line_peeked)
+		BUG("buffer must be empty at the end of handshake()");
+
 	return refs;
 }
 
+static struct ref *get_refs_via_connect(struct transport *transport, int for_push,
+					const struct argv_array *ref_prefixes)
+{
+	return handshake(transport, for_push, ref_prefixes, 1);
+}
+
 static int fetch_refs_via_pack(struct transport *transport,
 			       int nr_heads, struct ref **to_fetch)
 {
 	int ret = 0;
 	struct git_transport_data *data = transport->data;
 	struct ref *refs = NULL;
-	char *dest = xstrdup(transport->url);
 	struct fetch_pack_args args;
 	struct ref *refs_tmp = NULL;
 
@@ -318,22 +355,33 @@ static int fetch_refs_via_pack(struct tr
 	args.filter_options = data->options.filter_options;
 	args.stateless_rpc = transport->stateless_rpc;
 	args.server_options = transport->server_options;
+	args.negotiation_tips = data->options.negotiation_tips;
 
-	if (!data->got_remote_heads)
-		refs_tmp = get_refs_via_connect(transport, 0, NULL);
+	if (!data->got_remote_heads) {
+		int i;
+		int must_list_refs = 0;
+		for (i = 0; i < nr_heads; i++) {
+			if (!to_fetch[i]->exact_oid) {
+				must_list_refs = 1;
+				break;
+			}
+		}
+		refs_tmp = handshake(transport, 0, NULL, must_list_refs);
+	}
 
 	switch (data->version) {
 	case protocol_v2:
-		refs = fetch_pack(&args, data->fd, data->conn,
+		refs = fetch_pack(&args, data->fd,
 				  refs_tmp ? refs_tmp : transport->remote_refs,
-				  dest, to_fetch, nr_heads, &data->shallow,
+				  to_fetch, nr_heads, &data->shallow,
 				  &transport->pack_lockfile, data->version);
 		break;
 	case protocol_v1:
 	case protocol_v0:
-		refs = fetch_pack(&args, data->fd, data->conn,
+		die_if_server_options(transport);
+		refs = fetch_pack(&args, data->fd,
 				  refs_tmp ? refs_tmp : transport->remote_refs,
-				  dest, to_fetch, nr_heads, &data->shallow,
+				  to_fetch, nr_heads, &data->shallow,
 				  &transport->pack_lockfile, data->version);
 		break;
 	case protocol_unknown_version:
@@ -348,6 +396,7 @@ static int fetch_refs_via_pack(struct tr
 	data->got_remote_heads = 0;
 	data->options.self_contained_and_connected =
 		args.self_contained_and_connected;
+	data->options.connectivity_checked = args.connectivity_checked;
 
 	if (refs == NULL)
 		ret = -1;
@@ -356,7 +405,6 @@ static int fetch_refs_via_pack(struct tr
 
 	free_refs(refs_tmp);
 	free_refs(refs);
-	free(dest);
 	return ret;
 }
 
@@ -654,7 +702,7 @@ static int git_transport_push(struct tra
 
 	switch (data->version) {
 	case protocol_v2:
-		die("support for protocol v2 not implemented yet");
+		die(_("support for protocol v2 not implemented yet"));
 		break;
 	case protocol_v1:
 	case protocol_v0:
@@ -689,7 +737,7 @@ static int disconnect_git(struct transpo
 {
 	struct git_transport_data *data = transport->data;
 	if (data->conn) {
-		if (data->got_remote_heads)
+		if (data->got_remote_heads && !transport->stateless_rpc)
 			packet_flush(data->fd[1]);
 		close(data->fd[0]);
 		close(data->fd[1]);
@@ -780,7 +828,7 @@ static enum protocol_allow_config parse_
 	else if (!strcasecmp(value, "user"))
 		return PROTOCOL_ALLOW_USER_ONLY;
 
-	die("unknown value for config '%s': %s", key, value);
+	die(_("unknown value for config '%s': %s"), key, value);
 }
 
 static enum protocol_allow_config get_protocol_config(const char *type)
@@ -846,7 +894,7 @@ int is_transport_allowed(const char *typ
 void transport_check_allowed(const char *type)
 {
 	if (!is_transport_allowed(type, -1))
-		die("transport '%s' not allowed", type);
+		die(_("transport '%s' not allowed"), type);
 }
 
 static struct transport_vtable bundle_vtable = {
@@ -875,7 +923,7 @@ struct transport *transport_get(struct r
 	ret->progress = isatty(2);
 
 	if (!remote)
-		die("No remote provided to transport_get()");
+		BUG("No remote provided to transport_get()");
 
 	ret->got_remote_refs = 0;
 	ret->remote = remote;
@@ -898,7 +946,7 @@ struct transport *transport_get(struct r
 	if (helper) {
 		transport_helper_init(ret, helper);
 	} else if (starts_with(url, "rsync:")) {
-		die("git-over-rsync is no longer supported");
+		die(_("git-over-rsync is no longer supported"));
 	} else if (url_is_local_not_ssh(url) && is_file(url) && is_bundle(url, 1)) {
 		struct bundle_transport_data *data = xcalloc(1, sizeof(*data));
 		transport_check_allowed("file");
@@ -1026,6 +1074,7 @@ static int run_pre_push_hook(struct tran
 
 	proc.argv = argv;
 	proc.in = -1;
+	proc.trace2_hook_name = "pre-push";
 
 	if (start_command(&proc)) {
 		finish_command(&proc);
@@ -1070,7 +1119,8 @@ static int run_pre_push_hook(struct tran
 	return ret;
 }
 
-int transport_push(struct transport *transport,
+int transport_push(struct repository *r,
+		   struct transport *transport,
 		   struct refspec *rs, int flags,
 		   unsigned int *reject_reasons)
 {
@@ -1095,8 +1145,10 @@ int transport_push(struct transport *tra
 
 		refspec_ref_prefixes(rs, &ref_prefixes);
 
+		trace2_region_enter("transport_push", "get_refs_list", r);
 		remote_refs = transport->vtable->get_refs_list(transport, 1,
 							       &ref_prefixes);
+		trace2_region_leave("transport_push", "get_refs_list", r);
 
 		argv_array_clear(&ref_prefixes);
 
@@ -1132,20 +1184,24 @@ int transport_push(struct transport *tra
 			struct ref *ref = remote_refs;
 			struct oid_array commits = OID_ARRAY_INIT;
 
+			trace2_region_enter("transport_push", "push_submodules", r);
 			for (; ref; ref = ref->next)
 				if (!is_null_oid(&ref->new_oid))
 					oid_array_append(&commits,
 							  &ref->new_oid);
 
-			if (!push_unpushed_submodules(&commits,
+			if (!push_unpushed_submodules(r,
+						      &commits,
 						      transport->remote,
 						      rs,
 						      transport->push_options,
 						      pretend)) {
 				oid_array_clear(&commits);
-				die("Failed to push all needed submodules!");
+				trace2_region_leave("transport_push", "push_submodules", r);
+				die(_("failed to push all needed submodules"));
 			}
 			oid_array_clear(&commits);
+			trace2_region_leave("transport_push", "push_submodules", r);
 		}
 
 		if (((flags & TRANSPORT_RECURSE_SUBMODULES_CHECK) ||
@@ -1156,27 +1212,48 @@ int transport_push(struct transport *tra
 			struct string_list needs_pushing = STRING_LIST_INIT_DUP;
 			struct oid_array commits = OID_ARRAY_INIT;
 
+			trace2_region_enter("transport_push", "check_submodules", r);
 			for (; ref; ref = ref->next)
 				if (!is_null_oid(&ref->new_oid))
 					oid_array_append(&commits,
 							  &ref->new_oid);
 
-			if (find_unpushed_submodules(&commits, transport->remote->name,
-						&needs_pushing)) {
+			if (find_unpushed_submodules(r,
+						     &commits,
+						     transport->remote->name,
+						     &needs_pushing)) {
 				oid_array_clear(&commits);
+				trace2_region_leave("transport_push", "check_submodules", r);
 				die_with_unpushed_submodules(&needs_pushing);
 			}
 			string_list_clear(&needs_pushing, 0);
 			oid_array_clear(&commits);
+			trace2_region_leave("transport_push", "check_submodules", r);
 		}
 
-		if (!(flags & TRANSPORT_RECURSE_SUBMODULES_ONLY))
+		if (!(flags & TRANSPORT_RECURSE_SUBMODULES_ONLY)) {
+			trace2_region_enter("transport_push", "push_refs", r);
 			push_ret = transport->vtable->push_refs(transport, remote_refs, flags);
-		else
+			trace2_region_leave("transport_push", "push_refs", r);
+		} else
 			push_ret = 0;
 		err = push_had_errors(remote_refs);
 		ret = push_ret | err;
 
+		if ((flags & TRANSPORT_PUSH_ATOMIC) && err) {
+			struct ref *it;
+			for (it = remote_refs; it; it = it->next)
+				switch (it->status) {
+				case REF_STATUS_NONE:
+				case REF_STATUS_UPTODATE:
+				case REF_STATUS_OK:
+					it->status = REF_STATUS_ATOMIC_PUSH_FAILED;
+					break;
+				default:
+					break;
+				}
+		}
+
 		if (!quiet || err)
 			transport_print_push_status(transport->url, remote_refs,
 					verbose | porcelain, porcelain,
@@ -1226,7 +1303,7 @@ int transport_fetch_refs(struct transpor
 		nr_refs++;
 		if (rm->peer_ref &&
 		    !is_null_oid(&rm->old_oid) &&
-		    !oidcmp(&rm->peer_ref->old_oid, &rm->old_oid))
+		    oideq(&rm->peer_ref->old_oid, &rm->old_oid))
 			continue;
 		ALLOC_GROW(heads, nr_heads + 1, nr_alloc);
 		heads[nr_heads++] = rm;
@@ -1265,7 +1342,7 @@ int transport_connect(struct transport *
 	if (transport->vtable->connect)
 		return transport->vtable->connect(transport, name, exec, fd);
 	else
-		die("Operation not supported by protocol");
+		die(_("operation not supported by protocol"));
 }
 
 int transport_disconnect(struct transport *transport)
@@ -1322,78 +1399,3 @@ char *transport_anonymize_url(const char
 literal_copy:
 	return xstrdup(url);
 }
-
-static void read_alternate_refs(const char *path,
-				alternate_ref_fn *cb,
-				void *data)
-{
-	struct child_process cmd = CHILD_PROCESS_INIT;
-	struct strbuf line = STRBUF_INIT;
-	FILE *fh;
-
-	cmd.git_cmd = 1;
-	argv_array_pushf(&cmd.args, "--git-dir=%s", path);
-	argv_array_push(&cmd.args, "for-each-ref");
-	argv_array_push(&cmd.args, "--format=%(objectname) %(refname)");
-	cmd.env = local_repo_env;
-	cmd.out = -1;
-
-	if (start_command(&cmd))
-		return;
-
-	fh = xfdopen(cmd.out, "r");
-	while (strbuf_getline_lf(&line, fh) != EOF) {
-		struct object_id oid;
-
-		if (get_oid_hex(line.buf, &oid) ||
-		    line.buf[GIT_SHA1_HEXSZ] != ' ') {
-			warning("invalid line while parsing alternate refs: %s",
-				line.buf);
-			break;
-		}
-
-		cb(line.buf + GIT_SHA1_HEXSZ + 1, &oid, data);
-	}
-
-	fclose(fh);
-	finish_command(&cmd);
-}
-
-struct alternate_refs_data {
-	alternate_ref_fn *fn;
-	void *data;
-};
-
-static int refs_from_alternate_cb(struct alternate_object_database *e,
-				  void *data)
-{
-	struct strbuf path = STRBUF_INIT;
-	size_t base_len;
-	struct alternate_refs_data *cb = data;
-
-	if (!strbuf_realpath(&path, e->path, 0))
-		goto out;
-	if (!strbuf_strip_suffix(&path, "/objects"))
-		goto out;
-	base_len = path.len;
-
-	/* Is this a git repository with refs? */
-	strbuf_addstr(&path, "/refs");
-	if (!is_directory(path.buf))
-		goto out;
-	strbuf_setlen(&path, base_len);
-
-	read_alternate_refs(path.buf, cb->fn, cb->data);
-
-out:
-	strbuf_release(&path);
-	return 0;
-}
-
-void for_each_alternate_ref(alternate_ref_fn fn, void *data)
-{
-	struct alternate_refs_data cb;
-	cb.fn = fn;
-	cb.data = data;
-	foreach_alt_odb(refs_from_alternate_cb, &cb);
-}
diff -pruN 1.2.1+git2.18.0-1/git/transport.h 1.2.3+git2.25.1-1/git/transport.h
--- 1.2.1+git2.18.0-1/git/transport.h	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/transport.h	2020-02-17 04:47:35.000000000 +0000
@@ -18,6 +18,17 @@ struct git_transport_options {
 	unsigned deepen_relative : 1;
 	unsigned from_promisor : 1;
 	unsigned no_dependents : 1;
+
+	/*
+	 * If this transport supports connect or stateless-connect,
+	 * the corresponding field in struct fetch_pack_args is copied
+	 * here after fetching.
+	 *
+	 * See the definition of connectivity_checked in struct
+	 * fetch_pack_args for more information.
+	 */
+	unsigned connectivity_checked:1;
+
 	int depth;
 	const char *deepen_since;
 	const struct string_list *deepen_not;
@@ -25,6 +36,16 @@ struct git_transport_options {
 	const char *receivepack;
 	struct push_cas_option *cas;
 	struct list_objects_filter_options filter_options;
+
+	/*
+	 * This is only used during fetch. See the documentation of
+	 * negotiation_tips in struct fetch_pack_args.
+	 *
+	 * This field is only supported by transports that support connect or
+	 * stateless_connect. Set this field directly instead of using
+	 * transport_set_option().
+	 */
+	struct oid_array *negotiation_tips;
 };
 
 enum transport_family {
@@ -113,7 +134,7 @@ struct transport {
 #define TRANSPORT_PUSH_OPTIONS			(1<<14)
 #define TRANSPORT_RECURSE_SUBMODULES_ONLY	(1<<15)
 
-extern int transport_summary_width(const struct ref *refs);
+int transport_summary_width(const struct ref *refs);
 
 /* Returns a transport suitable for the url */
 struct transport *transport_get(struct remote *, const char *);
@@ -187,6 +208,9 @@ void transport_check_allowed(const char
 /* Filter objects for partial clone and fetch */
 #define TRANS_OPT_LIST_OBJECTS_FILTER "filter"
 
+/* Request atomic (all-or-nothing) updates when pushing */
+#define TRANS_OPT_ATOMIC "atomic"
+
 /**
  * Returns 0 if the option was used, non-zero otherwise. Prints a
  * message to stderr if the option is not used.
@@ -202,7 +226,8 @@ void transport_set_verbosity(struct tran
 #define REJECT_FETCH_FIRST     0x08
 #define REJECT_NEEDS_FORCE     0x10
 
-int transport_push(struct transport *connection,
+int transport_push(struct repository *repo,
+		   struct transport *connection,
 		   struct refspec *rs, int flags,
 		   unsigned int * reject_reasons);
 
@@ -240,6 +265,4 @@ int transport_refs_pushed(struct ref *re
 void transport_print_push_status(const char *dest, struct ref *refs,
 		  int verbose, int porcelain, unsigned int *reject_reasons);
 
-typedef void alternate_ref_fn(const char *refname, const struct object_id *oid, void *);
-extern void for_each_alternate_ref(alternate_ref_fn, void *);
 #endif
diff -pruN 1.2.1+git2.18.0-1/git/transport-helper.c 1.2.3+git2.25.1-1/git/transport-helper.c
--- 1.2.1+git2.18.0-1/git/transport-helper.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/transport-helper.c	2020-02-17 04:47:35.000000000 +0000
@@ -33,6 +33,16 @@ struct helper_data {
 		check_connectivity : 1,
 		no_disconnect_req : 1,
 		no_private_update : 1;
+
+	/*
+	 * As an optimization, the transport code may invoke fetch before
+	 * get_refs_list. If this happens, and if the transport helper doesn't
+	 * support connect or stateless_connect, we need to invoke
+	 * get_refs_list ourselves if we haven't already done so. Keep track of
+	 * whether we have invoked get_refs_list.
+	 */
+	unsigned get_refs_list_called : 1;
+
 	char *export_marks;
 	char *import_marks;
 	/* These go from remote name (as in "list") to private name */
@@ -48,7 +58,7 @@ static void sendline(struct helper_data
 	if (debug)
 		fprintf(stderr, "Debug: Remote helper: -> %s", buffer->buf);
 	if (write_in_full(helper->helper->in, buffer->buf, buffer->len) < 0)
-		die_errno("Full write to remote helper failed");
+		die_errno(_("full write to remote helper failed"));
 }
 
 static int recvline_fh(FILE *helper, struct strbuf *buffer)
@@ -77,7 +87,7 @@ static void write_constant(int fd, const
 	if (debug)
 		fprintf(stderr, "Debug: Remote helper: -> %s", str);
 	if (write_in_full(fd, str, strlen(str)) < 0)
-		die_errno("Full write to remote helper failed");
+		die_errno(_("full write to remote helper failed"));
 }
 
 static const char *remove_ext_force(const char *url)
@@ -127,9 +137,11 @@ static struct child_process *get_helper(
 		argv_array_pushf(&helper->env_array, "%s=%s",
 				 GIT_DIR_ENVIRONMENT, get_git_dir());
 
+	helper->trace2_child_class = helper->args.argv[0]; /* "remote-<name>" */
+
 	code = start_command(helper);
 	if (code < 0 && errno == ENOENT)
-		die("Unable to find remote helper for '%s'", data->name);
+		die(_("unable to find remote helper for '%s'"), data->name);
 	else if (code != 0)
 		exit(code);
 
@@ -145,7 +157,7 @@ static struct child_process *get_helper(
 	 */
 	duped = dup(helper->out);
 	if (duped < 0)
-		die_errno("Can't dup helper output fd");
+		die_errno(_("can't dup helper output fd"));
 	data->out = xfdopen(duped, "r");
 
 	write_constant(helper->in, "capabilities\n");
@@ -196,13 +208,13 @@ static struct child_process *get_helper(
 		} else if (starts_with(capname, "no-private-update")) {
 			data->no_private_update = 1;
 		} else if (mandatory) {
-			die("Unknown mandatory capability %s. This remote "
-			    "helper probably needs newer version of Git.",
+			die(_("unknown mandatory capability %s; this remote "
+			      "helper probably needs newer version of Git"),
 			    capname);
 		}
 	}
 	if (!data->rs.nr && (data->import || data->bidi_import || data->export)) {
-		warning("This remote helper should implement refspec capability.");
+		warning(_("this remote helper should implement refspec capability"));
 	}
 	strbuf_release(&buf);
 	if (debug)
@@ -269,7 +281,7 @@ static int strbuf_set_helper_option(stru
 	else if (!strcmp(buf->buf, "unsupported"))
 		ret = 1;
 	else {
-		warning("%s unexpectedly said: '%s'", data->name, buf->buf);
+		warning(_("%s unexpectedly said: '%s'"), data->name, buf->buf);
 		ret = 1;
 	}
 	return ret;
@@ -398,7 +410,7 @@ static int fetch_with_fetch(struct trans
 		if (starts_with(buf.buf, "lock ")) {
 			const char *name = buf.buf + 5;
 			if (transport->pack_lockfile)
-				warning("%s also locked %s", data->name, name);
+				warning(_("%s also locked %s"), data->name, name);
 			else
 				transport->pack_lockfile = xstrdup(name);
 		}
@@ -409,7 +421,7 @@ static int fetch_with_fetch(struct trans
 		else if (!buf.len)
 			break;
 		else
-			warning("%s unexpectedly said: '%s'", data->name, buf.buf);
+			warning(_("%s unexpectedly said: '%s'"), data->name, buf.buf);
 	}
 	strbuf_release(&buf);
 	return 0;
@@ -421,8 +433,9 @@ static int get_importer(struct transport
 	struct helper_data *data = transport->data;
 	int cat_blob_fd, code;
 	child_process_init(fastimport);
-	fastimport->in = helper->out;
+	fastimport->in = xdup(helper->out);
 	argv_array_push(&fastimport->args, "fast-import");
+	argv_array_push(&fastimport->args, "--allow-unsafe-features");
 	argv_array_push(&fastimport->args, debug ? "--stats" : "--quiet");
 
 	if (data->bidi_import) {
@@ -476,7 +489,7 @@ static int fetch_with_import(struct tran
 	get_helper(transport);
 
 	if (get_importer(transport, &fastimport))
-		die("Couldn't run fast-import");
+		die(_("couldn't run fast-import"));
 
 	for (i = 0; i < nr_heads; i++) {
 		posn = to_fetch[i];
@@ -499,7 +512,7 @@ static int fetch_with_import(struct tran
 	 */
 
 	if (finish_command(&fastimport))
-		die("Error while running fast-import");
+		die(_("error while running fast-import"));
 
 	/*
 	 * The fast-import stream of a remote helper that advertises
@@ -528,7 +541,7 @@ static int fetch_with_import(struct tran
 			private = xstrdup(name);
 		if (private) {
 			if (read_ref(private, &posn->old_oid) < 0)
-				die("Could not read ref %s", private);
+				die(_("could not read ref %s"), private);
 			free(private);
 		}
 	}
@@ -554,7 +567,7 @@ static int run_connect(struct transport
 	 */
 	duped = dup(helper->out);
 	if (duped < 0)
-		die_errno("Can't dup helper output fd");
+		die_errno(_("can't dup helper output fd"));
 	input = xfdopen(duped, "r");
 	setvbuf(input, NULL, _IONBF, 0);
 
@@ -573,8 +586,8 @@ static int run_connect(struct transport
 			fprintf(stderr, "Debug: Falling back to dumb "
 				"transport.\n");
 	} else {
-		die("Unknown response to connect: %s",
-			cmdbuf->buf);
+		die(_("unknown response to connect: %s"),
+		    cmdbuf->buf);
 	}
 
 	fclose(input);
@@ -595,9 +608,9 @@ static int process_connect_service(struc
 	if (strcmp(name, exec)) {
 		int r = set_helper_option(transport, "servpath", exec);
 		if (r > 0)
-			warning("Setting remote service path not supported by protocol.");
+			warning(_("setting remote service path not supported by protocol"));
 		else if (r < 0)
-			warning("Invalid remote service path.");
+			warning(_("invalid remote service path"));
 	}
 
 	if (data->connect) {
@@ -640,27 +653,35 @@ static int connect_helper(struct transpo
 	/* Get_helper so connect is inited. */
 	get_helper(transport);
 	if (!data->connect)
-		die("Operation not supported by protocol.");
+		die(_("operation not supported by protocol"));
 
 	if (!process_connect_service(transport, name, exec))
-		die("Can't connect to subservice %s.", name);
+		die(_("can't connect to subservice %s"), name);
 
 	fd[0] = data->helper->out;
 	fd[1] = data->helper->in;
 	return 0;
 }
 
+static struct ref *get_refs_list_using_list(struct transport *transport,
+					    int for_push);
+
 static int fetch(struct transport *transport,
 		 int nr_heads, struct ref **to_fetch)
 {
 	struct helper_data *data = transport->data;
 	int i, count;
 
+	get_helper(transport);
+
 	if (process_connect(transport, 0)) {
 		do_take_over(transport);
 		return transport->vtable->fetch(transport, nr_heads, to_fetch);
 	}
 
+	if (!data->get_refs_list_called)
+		get_refs_list_using_list(transport, 0);
+
 	count = 0;
 	for (i = 0; i < nr_heads; i++)
 		if (!(to_fetch[i]->status & REF_STATUS_UPTODATE))
@@ -679,10 +700,14 @@ static int fetch(struct transport *trans
 	if (data->transport_options.update_shallow)
 		set_helper_option(transport, "update-shallow", "true");
 
-	if (data->transport_options.filter_options.choice)
-		set_helper_option(
-			transport, "filter",
-			data->transport_options.filter_options.filter_spec);
+	if (data->transport_options.filter_options.choice) {
+		const char *spec = expand_list_objects_filter_spec(
+			&data->transport_options.filter_options);
+		set_helper_option(transport, "filter", spec);
+	}
+
+	if (data->transport_options.negotiation_tips)
+		warning("Ignoring --negotiation-tip because the protocol does not support it.");
 
 	if (data->fetch)
 		return fetch_with_fetch(transport, nr_heads, to_fetch);
@@ -707,7 +732,7 @@ static int push_update_ref_status(struct
 		status = REF_STATUS_REMOTE_REJECT;
 		refname = buf->buf + 6;
 	} else
-		die("expected ok/error, helper said '%s'", buf->buf);
+		die(_("expected ok/error, helper said '%s'"), buf->buf);
 
 	msg = strchr(refname, ' ');
 	if (msg) {
@@ -760,7 +785,7 @@ static int push_update_ref_status(struct
 	if (!*ref)
 		*ref = find_ref_by_name(remote_refs, refname);
 	if (!*ref) {
-		warning("helper reported unexpected status of %s", refname);
+		warning(_("helper reported unexpected status of %s"), refname);
 		return 1;
 	}
 
@@ -821,20 +846,24 @@ static void set_common_push_options(stru
 {
 	if (flags & TRANSPORT_PUSH_DRY_RUN) {
 		if (set_helper_option(transport, "dry-run", "true") != 0)
-			die("helper %s does not support dry-run", name);
+			die(_("helper %s does not support dry-run"), name);
 	} else if (flags & TRANSPORT_PUSH_CERT_ALWAYS) {
 		if (set_helper_option(transport, TRANS_OPT_PUSH_CERT, "true") != 0)
-			die("helper %s does not support --signed", name);
+			die(_("helper %s does not support --signed"), name);
 	} else if (flags & TRANSPORT_PUSH_CERT_IF_ASKED) {
 		if (set_helper_option(transport, TRANS_OPT_PUSH_CERT, "if-asked") != 0)
-			die("helper %s does not support --signed=if-asked", name);
+			die(_("helper %s does not support --signed=if-asked"), name);
 	}
 
+	if (flags & TRANSPORT_PUSH_ATOMIC)
+		if (set_helper_option(transport, TRANS_OPT_ATOMIC, "true") != 0)
+			die(_("helper %s does not support --atomic"), name);
+
 	if (flags & TRANSPORT_PUSH_OPTIONS) {
 		struct string_list_item *item;
 		for_each_string_list_item(item, transport->push_options)
 			if (set_helper_option(transport, "push-option", item->string) != 0)
-				die("helper %s does not support 'push-option'", name);
+				die(_("helper %s does not support 'push-option'"), name);
 	}
 }
 
@@ -843,6 +872,7 @@ static int push_refs_with_push(struct tr
 {
 	int force_all = flags & TRANSPORT_PUSH_FORCE;
 	int mirror = flags & TRANSPORT_PUSH_MIRROR;
+	int atomic = flags & TRANSPORT_PUSH_ATOMIC;
 	struct helper_data *data = transport->data;
 	struct strbuf buf = STRBUF_INIT;
 	struct ref *ref;
@@ -862,6 +892,11 @@ static int push_refs_with_push(struct tr
 		case REF_STATUS_REJECT_NONFASTFORWARD:
 		case REF_STATUS_REJECT_STALE:
 		case REF_STATUS_REJECT_ALREADY_EXISTS:
+			if (atomic) {
+				string_list_clear(&cas_options, 0);
+				return 0;
+			} else
+				continue;
 		case REF_STATUS_UPTODATE:
 			continue;
 		default:
@@ -926,12 +961,12 @@ static int push_refs_with_export(struct
 	struct strbuf buf = STRBUF_INIT;
 
 	if (!data->rs.nr)
-		die("remote-helper doesn't support push; refspec needed");
+		die(_("remote-helper doesn't support push; refspec needed"));
 
 	set_common_push_options(transport, data->name, flags);
 	if (flags & TRANSPORT_PUSH_FORCE) {
 		if (set_helper_option(transport, "force", "true") != 0)
-			warning("helper %s does not support 'force'", data->name);
+			warning(_("helper %s does not support 'force'"), data->name);
 	}
 
 	helper = get_helper(transport);
@@ -978,12 +1013,12 @@ static int push_refs_with_export(struct
 	}
 
 	if (get_exporter(transport, &exporter, &revlist_args))
-		die("Couldn't run fast-export");
+		die(_("couldn't run fast-export"));
 
 	string_list_clear(&revlist_args, 1);
 
 	if (finish_command(&exporter))
-		die("Error while running fast-export");
+		die(_("error while running fast-export"));
 	if (push_update_refs_status(data, remote_refs, flags))
 		return 1;
 
@@ -1007,8 +1042,9 @@ static int push_refs(struct transport *t
 	}
 
 	if (!remote_refs) {
-		fprintf(stderr, "No refs in common and none specified; doing nothing.\n"
-			"Perhaps you should specify a branch such as 'master'.\n");
+		fprintf(stderr,
+			_("No refs in common and none specified; doing nothing.\n"
+			  "Perhaps you should specify a branch such as 'master'.\n"));
 		return 0;
 	}
 
@@ -1022,7 +1058,8 @@ static int push_refs(struct transport *t
 }
 
 
-static int has_attribute(const char *attrs, const char *attr) {
+static int has_attribute(const char *attrs, const char *attr)
+{
 	int len;
 	if (!attrs)
 		return 0;
@@ -1041,6 +1078,19 @@ static int has_attribute(const char *att
 static struct ref *get_refs_list(struct transport *transport, int for_push,
 				 const struct argv_array *ref_prefixes)
 {
+	get_helper(transport);
+
+	if (process_connect(transport, for_push)) {
+		do_take_over(transport);
+		return transport->vtable->get_refs_list(transport, for_push, ref_prefixes);
+	}
+
+	return get_refs_list_using_list(transport, for_push);
+}
+
+static struct ref *get_refs_list_using_list(struct transport *transport,
+					    int for_push)
+{
 	struct helper_data *data = transport->data;
 	struct child_process *helper;
 	struct ref *ret = NULL;
@@ -1048,13 +1098,9 @@ static struct ref *get_refs_list(struct
 	struct ref *posn;
 	struct strbuf buf = STRBUF_INIT;
 
+	data->get_refs_list_called = 1;
 	helper = get_helper(transport);
 
-	if (process_connect(transport, for_push)) {
-		do_take_over(transport);
-		return transport->vtable->get_refs_list(transport, for_push, ref_prefixes);
-	}
-
 	if (data->push && for_push)
 		write_str_in_full(helper->in, "list for-push\n");
 	else
@@ -1070,7 +1116,7 @@ static struct ref *get_refs_list(struct
 
 		eov = strchr(buf.buf, ' ');
 		if (!eov)
-			die("Malformed response in ref list: %s", buf.buf);
+			die(_("malformed response in ref list: %s"), buf.buf);
 		eon = strchr(eov + 1, ' ');
 		*eov = '\0';
 		if (eon)
@@ -1084,7 +1130,7 @@ static struct ref *get_refs_list(struct
 			if (has_attribute(eon + 1, "unchanged")) {
 				(*tail)->status |= REF_STATUS_UPTODATE;
 				if (read_ref((*tail)->name, &(*tail)->old_oid) < 0)
-					die(_("Could not read ref %s"),
+					die(_("could not read ref %s"),
 					    (*tail)->name);
 			}
 		}
@@ -1220,10 +1266,9 @@ static int udt_do_read(struct unidirecti
 		return 0;	/* No space for more. */
 
 	transfer_debug("%s is readable", t->src_name);
-	bytes = read(t->src, t->buf + t->bufuse, BUFFERSIZE - t->bufuse);
-	if (bytes < 0 && errno != EWOULDBLOCK && errno != EAGAIN &&
-		errno != EINTR) {
-		error_errno("read(%s) failed", t->src_name);
+	bytes = xread(t->src, t->buf + t->bufuse, BUFFERSIZE - t->bufuse);
+	if (bytes < 0) {
+		error_errno(_("read(%s) failed"), t->src_name);
 		return -1;
 	} else if (bytes == 0) {
 		transfer_debug("%s EOF (with %i bytes in buffer)",
@@ -1249,8 +1294,8 @@ static int udt_do_write(struct unidirect
 
 	transfer_debug("%s is writable", t->dest_name);
 	bytes = xwrite(t->dest, t->buf, t->bufuse);
-	if (bytes < 0 && errno != EWOULDBLOCK) {
-		error_errno("write(%s) failed", t->dest_name);
+	if (bytes < 0) {
+		error_errno(_("write(%s) failed"), t->dest_name);
 		return -1;
 	} else if (bytes > 0) {
 		t->bufuse -= bytes;
@@ -1299,11 +1344,11 @@ static int tloop_join(pthread_t thread,
 	void *tret;
 	err = pthread_join(thread, &tret);
 	if (!tret) {
-		error("%s thread failed", name);
+		error(_("%s thread failed"), name);
 		return 1;
 	}
 	if (err) {
-		error("%s thread failed to join: %s", name, strerror(err));
+		error(_("%s thread failed to join: %s"), name, strerror(err));
 		return 1;
 	}
 	return 0;
@@ -1322,11 +1367,11 @@ static int tloop_spawnwait_tasks(struct
 	err = pthread_create(&gtp_thread, NULL, udt_copy_task_routine,
 		&s->gtp);
 	if (err)
-		die("Can't start thread for copying data: %s", strerror(err));
+		die(_("can't start thread for copying data: %s"), strerror(err));
 	err = pthread_create(&ptg_thread, NULL, udt_copy_task_routine,
 		&s->ptg);
 	if (err)
-		die("Can't start thread for copying data: %s", strerror(err));
+		die(_("can't start thread for copying data: %s"), strerror(err));
 
 	ret |= tloop_join(gtp_thread, "Git to program copy");
 	ret |= tloop_join(ptg_thread, "Program to git copy");
@@ -1363,11 +1408,11 @@ static int tloop_join(pid_t pid, const c
 {
 	int tret;
 	if (waitpid(pid, &tret, 0) < 0) {
-		error_errno("%s process failed to wait", name);
+		error_errno(_("%s process failed to wait"), name);
 		return 1;
 	}
 	if (!WIFEXITED(tret) || WEXITSTATUS(tret)) {
-		error("%s process failed", name);
+		error(_("%s process failed"), name);
 		return 1;
 	}
 	return 0;
@@ -1385,7 +1430,7 @@ static int tloop_spawnwait_tasks(struct
 	/* Fork thread #1: git to program. */
 	pid1 = fork();
 	if (pid1 < 0)
-		die_errno("Can't start thread for copying data");
+		die_errno(_("can't start thread for copying data"));
 	else if (pid1 == 0) {
 		udt_kill_transfer(&s->ptg);
 		exit(udt_copy_task_routine(&s->gtp) ? 0 : 1);
@@ -1394,7 +1439,7 @@ static int tloop_spawnwait_tasks(struct
 	/* Fork thread #2: program to git. */
 	pid2 = fork();
 	if (pid2 < 0)
-		die_errno("Can't start thread for copying data");
+		die_errno(_("can't start thread for copying data"));
 	else if (pid2 == 0) {
 		udt_kill_transfer(&s->gtp);
 		exit(udt_copy_task_routine(&s->ptg) ? 0 : 1);
diff -pruN 1.2.1+git2.18.0-1/git/.travis.yml 1.2.3+git2.25.1-1/git/.travis.yml
--- 1.2.1+git2.18.0-1/git/.travis.yml	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/.travis.yml	2020-02-17 04:47:35.000000000 +0000
@@ -1,7 +1,5 @@
 language: c
 
-sudo: false
-
 cache:
   directories:
     - $HOME/travis-cache
@@ -10,37 +8,23 @@ os:
   - linux
   - osx
 
+osx_image: xcode10.1
+
 compiler:
   - clang
   - gcc
 
-addons:
-  apt:
-    sources:
-    - ubuntu-toolchain-r-test
-    packages:
-    - language-pack-is
-    - git-svn
-    - apache2
-    - gcc-8
-
 matrix:
   include:
-    - env: jobname=GETTEXT_POISON
+    - env: jobname=GIT_TEST_GETTEXT_POISON
       os: linux
       compiler:
       addons:
       before_install:
-    - env: jobname=Windows
+    - env: jobname=linux-gcc-4.8
       os: linux
+      dist: trusty
       compiler:
-      addons:
-      before_install:
-      script:
-        - >
-          test "$TRAVIS_REPO_SLUG" != "git/git" ||
-          ci/run-windows-build.sh $TRAVIS_BRANCH $(git rev-parse HEAD)
-      after_failure:
     - env: jobname=Linux32
       os: linux
       compiler:
@@ -52,22 +36,11 @@ matrix:
     - env: jobname=StaticAnalysis
       os: linux
       compiler:
-      addons:
-        apt:
-          packages:
-          - coccinelle
-      before_install:
       script: ci/run-static-analysis.sh
       after_failure:
     - env: jobname=Documentation
       os: linux
       compiler:
-      addons:
-        apt:
-          packages:
-          - asciidoc
-          - xmlto
-      before_install:
       script: ci/test-documentation.sh
       after_failure:
 
diff -pruN 1.2.1+git2.18.0-1/git/tree.c 1.2.3+git2.25.1-1/git/tree.c
--- 1.2.1+git2.18.0-1/git/tree.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/tree.c	2020-02-17 04:47:35.000000000 +0000
@@ -1,11 +1,13 @@
-#define NO_THE_INDEX_COMPATIBILITY_MACROS
 #include "cache.h"
 #include "cache-tree.h"
 #include "tree.h"
+#include "object-store.h"
 #include "blob.h"
 #include "commit.h"
 #include "tag.h"
+#include "alloc.h"
 #include "tree-walk.h"
+#include "repository.h"
 
 const char *tree_type = "tree";
 
@@ -16,15 +18,13 @@ static int read_one_entry_opt(struct ind
 			      unsigned mode, int stage, int opt)
 {
 	int len;
-	unsigned int size;
 	struct cache_entry *ce;
 
 	if (S_ISDIR(mode))
 		return READ_TREE_RECURSIVE;
 
 	len = strlen(pathname);
-	size = cache_entry_size(baselen + len);
-	ce = xcalloc(1, size);
+	ce = make_empty_cache_entry(istate, baselen + len);
 
 	ce->ce_mode = create_ce_mode(mode);
 	ce->ce_flags = create_ce_flags(stage);
@@ -59,7 +59,8 @@ static int read_one_entry_quick(const st
 				  ADD_CACHE_JUST_APPEND);
 }
 
-static int read_tree_1(struct tree *tree, struct strbuf *base,
+static int read_tree_1(struct repository *r,
+		       struct tree *tree, struct strbuf *base,
 		       int stage, const struct pathspec *pathspec,
 		       read_tree_fn_t fn, void *context)
 {
@@ -76,14 +77,15 @@ static int read_tree_1(struct tree *tree
 
 	while (tree_entry(&desc, &entry)) {
 		if (retval != all_entries_interesting) {
-			retval = tree_entry_interesting(&entry, base, 0, pathspec);
+			retval = tree_entry_interesting(r->index, &entry,
+							base, 0, pathspec);
 			if (retval == all_entries_not_interesting)
 				break;
 			if (retval == entry_not_interesting)
 				continue;
 		}
 
-		switch (fn(entry.oid, base,
+		switch (fn(&entry.oid, base,
 			   entry.path, entry.mode, stage, context)) {
 		case 0:
 			continue;
@@ -94,19 +96,19 @@ static int read_tree_1(struct tree *tree
 		}
 
 		if (S_ISDIR(entry.mode))
-			oidcpy(&oid, entry.oid);
+			oidcpy(&oid, &entry.oid);
 		else if (S_ISGITLINK(entry.mode)) {
 			struct commit *commit;
 
-			commit = lookup_commit(entry.oid);
+			commit = lookup_commit(r, &entry.oid);
 			if (!commit)
 				die("Commit %s in submodule path %s%s not found",
-				    oid_to_hex(entry.oid),
+				    oid_to_hex(&entry.oid),
 				    base->buf, entry.path);
 
 			if (parse_commit(commit))
 				die("Invalid commit %s in submodule path %s%s",
-				    oid_to_hex(entry.oid),
+				    oid_to_hex(&entry.oid),
 				    base->buf, entry.path);
 
 			oidcpy(&oid, get_commit_tree_oid(commit));
@@ -117,7 +119,7 @@ static int read_tree_1(struct tree *tree
 		len = tree_entry_len(&entry);
 		strbuf_add(base, entry.path, len);
 		strbuf_addch(base, '/');
-		retval = read_tree_1(lookup_tree(&oid),
+		retval = read_tree_1(r, lookup_tree(r, &oid),
 				     base, stage, pathspec,
 				     fn, context);
 		strbuf_setlen(base, oldlen);
@@ -127,7 +129,8 @@ static int read_tree_1(struct tree *tree
 	return 0;
 }
 
-int read_tree_recursive(struct tree *tree,
+int read_tree_recursive(struct repository *r,
+			struct tree *tree,
 			const char *base, int baselen,
 			int stage, const struct pathspec *pathspec,
 			read_tree_fn_t fn, void *context)
@@ -136,7 +139,7 @@ int read_tree_recursive(struct tree *tre
 	int ret;
 
 	strbuf_add(&sb, base, baselen);
-	ret = read_tree_1(tree, &sb, stage, pathspec, fn, context);
+	ret = read_tree_1(r, tree, &sb, stage, pathspec, fn, context);
 	strbuf_release(&sb);
 	return ret;
 }
@@ -151,8 +154,8 @@ static int cmp_cache_name_compare(const
 				  ce2->name, ce2->ce_namelen, ce_stage(ce2));
 }
 
-int read_tree(struct tree *tree, int stage, struct pathspec *match,
-	      struct index_state *istate)
+int read_tree(struct repository *r, struct tree *tree, int stage,
+	      struct pathspec *match, struct index_state *istate)
 {
 	read_tree_fn_t fn = NULL;
 	int i, err;
@@ -180,7 +183,7 @@ int read_tree(struct tree *tree, int sta
 
 	if (!fn)
 		fn = read_one_entry_quick;
-	err = read_tree_recursive(tree, "", 0, stage, match, fn, istate);
+	err = read_tree_recursive(r, tree, "", 0, stage, match, fn, istate);
 	if (fn == read_one_entry || err)
 		return err;
 
@@ -192,12 +195,12 @@ int read_tree(struct tree *tree, int sta
 	return 0;
 }
 
-struct tree *lookup_tree(const struct object_id *oid)
+struct tree *lookup_tree(struct repository *r, const struct object_id *oid)
 {
-	struct object *obj = lookup_object(oid->hash);
+	struct object *obj = lookup_object(r, oid);
 	if (!obj)
-		return create_object(oid->hash, alloc_tree_node());
-	return object_as_type(obj, OBJ_TREE, 0);
+		return create_object(r, oid, alloc_tree_node(r));
+	return object_as_type(r, obj, OBJ_TREE, 0);
 }
 
 int parse_tree_buffer(struct tree *item, void *buffer, unsigned long size)
@@ -241,19 +244,7 @@ void free_tree_buffer(struct tree *tree)
 
 struct tree *parse_tree_indirect(const struct object_id *oid)
 {
-	struct object *obj = parse_object(oid);
-	do {
-		if (!obj)
-			return NULL;
-		if (obj->type == OBJ_TREE)
-			return (struct tree *) obj;
-		else if (obj->type == OBJ_COMMIT)
-			obj = &(get_commit_tree(((struct commit *)obj))->object);
-		else if (obj->type == OBJ_TAG)
-			obj = ((struct tag *) obj)->tagged;
-		else
-			return NULL;
-		if (!obj->parsed)
-			parse_object(&obj->oid);
-	} while (1);
+	struct repository *r = the_repository;
+	struct object *obj = parse_object(r, oid);
+	return (struct tree *)repo_peel_to_type(r, NULL, 0, obj, OBJ_TREE);
 }
diff -pruN 1.2.1+git2.18.0-1/git/tree-diff.c 1.2.3+git2.25.1-1/git/tree-diff.c
--- 1.2.1+git2.18.0-1/git/tree-diff.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/tree-diff.c	2020-02-17 04:47:35.000000000 +0000
@@ -181,7 +181,7 @@ static struct combine_diff_path *emit_pa
 	struct tree_desc *t, struct tree_desc *tp,
 	int imin)
 {
-	unsigned mode;
+	unsigned short mode;
 	const char *path;
 	const struct object_id *oid;
 	int pathlen;
@@ -239,7 +239,7 @@ static struct combine_diff_path *emit_pa
 						DIFF_STATUS_ADDED;
 
 			if (tpi_valid) {
-				oid_i = tp[i].entry.oid;
+				oid_i = &tp[i].entry.oid;
 				mode_i = tp[i].entry.mode;
 			}
 			else {
@@ -280,7 +280,7 @@ static struct combine_diff_path *emit_pa
 			/* same rule as in emitthis */
 			int tpi_valid = tp && !(tp[i].entry.mode & S_IFXMIN_NEQ);
 
-			parents_oid[i] = tpi_valid ? tp[i].entry.oid : NULL;
+			parents_oid[i] = tpi_valid ? &tp[i].entry.oid : NULL;
 		}
 
 		strbuf_add(base, path, pathlen);
@@ -299,7 +299,8 @@ static void skip_uninteresting(struct tr
 	enum interesting match;
 
 	while (t->size) {
-		match = tree_entry_interesting(&t->entry, base, 0, &opt->pathspec);
+		match = tree_entry_interesting(opt->repo->index, &t->entry,
+					       base, 0, &opt->pathspec);
 		if (match) {
 			if (match == all_entries_not_interesting)
 				t->size = 0;
@@ -421,8 +422,8 @@ static struct combine_diff_path *ll_diff
 	 *   diff_tree_oid(parent, commit) )
 	 */
 	for (i = 0; i < nparent; ++i)
-		tptree[i] = fill_tree_descriptor(&tp[i], parents_oid[i]);
-	ttree = fill_tree_descriptor(&t, oid);
+		tptree[i] = fill_tree_descriptor(opt->repo, &tp[i], parents_oid[i]);
+	ttree = fill_tree_descriptor(opt->repo, &t, oid);
 
 	/* Enable recursion indefinitely */
 	opt->pathspec.recursive = opt->flags.recursive;
@@ -491,7 +492,7 @@ static struct combine_diff_path *ll_diff
 						continue;
 
 					/* diff(t,pi) != ø */
-					if (oidcmp(t.entry.oid, tp[i].entry.oid) ||
+					if (!oideq(&t.entry.oid, &tp[i].entry.oid) ||
 					    (t.entry.mode != tp[i].entry.mode))
 						continue;
 
@@ -557,9 +558,7 @@ struct combine_diff_path *diff_tree_path
 	 * free pre-allocated last element, if any
 	 * (see path_appendnew() for details about why)
 	 */
-	if (p->next) {
-		FREE_AND_NULL(p->next);
-	}
+	FREE_AND_NULL(p->next);
 
 	return p;
 }
@@ -607,7 +606,7 @@ static void try_to_follow_renames(const
 	choice = q->queue[0];
 	q->nr = 0;
 
-	diff_setup(&diff_opts);
+	repo_diff_setup(opt->repo, &diff_opts);
 	diff_opts.flags.recursive = 1;
 	diff_opts.flags.find_copies_harder = 1;
 	diff_opts.output_format = DIFF_FORMAT_NO_OUTPUT;
diff -pruN 1.2.1+git2.18.0-1/git/tree.h 1.2.3+git2.25.1-1/git/tree.h
--- 1.2.1+git2.18.0-1/git/tree.h	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/tree.h	2020-02-17 04:47:35.000000000 +0000
@@ -3,7 +3,7 @@
 
 #include "object.h"
 
-extern const char *tree_type;
+struct repository;
 struct strbuf;
 
 struct tree {
@@ -12,7 +12,9 @@ struct tree {
 	unsigned long size;
 };
 
-struct tree *lookup_tree(const struct object_id *oid);
+extern const char *tree_type;
+
+struct tree *lookup_tree(struct repository *r, const struct object_id *oid);
 
 int parse_tree_buffer(struct tree *item, void *buffer, unsigned long size);
 
@@ -29,12 +31,14 @@ struct tree *parse_tree_indirect(const s
 #define READ_TREE_RECURSIVE 1
 typedef int (*read_tree_fn_t)(const struct object_id *, struct strbuf *, const char *, unsigned int, int, void *);
 
-extern int read_tree_recursive(struct tree *tree,
-			       const char *base, int baselen,
-			       int stage, const struct pathspec *pathspec,
-			       read_tree_fn_t fn, void *context);
-
-extern int read_tree(struct tree *tree, int stage, struct pathspec *pathspec,
-		     struct index_state *istate);
+int read_tree_recursive(struct repository *r,
+			struct tree *tree,
+			const char *base, int baselen,
+			int stage, const struct pathspec *pathspec,
+			read_tree_fn_t fn, void *context);
+
+int read_tree(struct repository *r, struct tree *tree,
+	      int stage, struct pathspec *pathspec,
+	      struct index_state *istate);
 
 #endif /* TREE_H */
diff -pruN 1.2.1+git2.18.0-1/git/tree-walk.c 1.2.3+git2.25.1-1/git/tree-walk.c
--- 1.2.1+git2.18.0-1/git/tree-walk.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/tree-walk.c	2020-02-17 04:47:35.000000000 +0000
@@ -2,6 +2,7 @@
 #include "tree-walk.h"
 #include "unpack-trees.h"
 #include "dir.h"
+#include "object-store.h"
 #include "tree.h"
 #include "pathspec.h"
 
@@ -26,8 +27,9 @@ static int decode_tree_entry(struct tree
 {
 	const char *path;
 	unsigned int mode, len;
+	const unsigned hashsz = the_hash_algo->rawsz;
 
-	if (size < 23 || buf[size - 21]) {
+	if (size < hashsz + 3 || buf[size - (hashsz + 1)]) {
 		strbuf_addstr(err, _("too-short tree object"));
 		return -1;
 	}
@@ -46,7 +48,8 @@ static int decode_tree_entry(struct tree
 	/* Initialize the descriptor entry */
 	desc->entry.path = path;
 	desc->entry.mode = canon_mode(mode);
-	desc->entry.oid  = (const struct object_id *)(path + len);
+	desc->entry.pathlen = len - 1;
+	hashcpy(desc->entry.oid.hash, (const unsigned char *)path + len);
 
 	return 0;
 }
@@ -78,13 +81,15 @@ int init_tree_desc_gently(struct tree_de
 	return result;
 }
 
-void *fill_tree_descriptor(struct tree_desc *desc, const struct object_id *oid)
+void *fill_tree_descriptor(struct repository *r,
+			   struct tree_desc *desc,
+			   const struct object_id *oid)
 {
 	unsigned long size = 0;
 	void *buf = NULL;
 
 	if (oid) {
-		buf = read_object_with_reference(oid, tree_type, &size, NULL);
+		buf = read_object_with_reference(r, oid, tree_type, &size, NULL);
 		if (!buf)
 			die("unable to read tree %s", oid_to_hex(oid));
 	}
@@ -105,7 +110,7 @@ static void entry_extract(struct tree_de
 static int update_tree_entry_internal(struct tree_desc *desc, struct strbuf *err)
 {
 	const void *buf = desc->buffer;
-	const unsigned char *end = desc->entry.oid->hash + the_hash_algo->rawsz;
+	const unsigned char *end = (const unsigned char *)desc->entry.path + desc->entry.pathlen + 1 + the_hash_algo->rawsz;
 	unsigned long size = desc->size;
 	unsigned long len = end - (const unsigned char *)buf;
 
@@ -165,38 +170,61 @@ int tree_entry_gently(struct tree_desc *
 
 void setup_traverse_info(struct traverse_info *info, const char *base)
 {
-	int pathlen = strlen(base);
+	size_t pathlen = strlen(base);
 	static struct traverse_info dummy;
 
 	memset(info, 0, sizeof(*info));
 	if (pathlen && base[pathlen-1] == '/')
 		pathlen--;
 	info->pathlen = pathlen ? pathlen + 1 : 0;
-	info->name.path = base;
-	info->name.oid = (void *)(base + pathlen + 1);
+	info->name = base;
+	info->namelen = pathlen;
 	if (pathlen)
 		info->prev = &dummy;
 }
 
-char *make_traverse_path(char *path, const struct traverse_info *info, const struct name_entry *n)
+char *make_traverse_path(char *path, size_t pathlen,
+			 const struct traverse_info *info,
+			 const char *name, size_t namelen)
 {
-	int len = tree_entry_len(n);
-	int pathlen = info->pathlen;
+	/* Always points to the end of the name we're about to add */
+	size_t pos = st_add(info->pathlen, namelen);
 
-	path[pathlen + len] = 0;
+	if (pos >= pathlen)
+		BUG("too small buffer passed to make_traverse_path");
+
+	path[pos] = 0;
 	for (;;) {
-		memcpy(path + pathlen, n->path, len);
-		if (!pathlen)
+		if (pos < namelen)
+			BUG("traverse_info pathlen does not match strings");
+		pos -= namelen;
+		memcpy(path + pos, name, namelen);
+
+		if (!pos)
 			break;
-		path[--pathlen] = '/';
-		n = &info->name;
-		len = tree_entry_len(n);
+		path[--pos] = '/';
+
+		if (!info)
+			BUG("traverse_info ran out of list items");
+		name = info->name;
+		namelen = info->namelen;
 		info = info->prev;
-		pathlen -= len;
 	}
 	return path;
 }
 
+void strbuf_make_traverse_path(struct strbuf *out,
+			       const struct traverse_info *info,
+			       const char *name, size_t namelen)
+{
+	size_t len = traverse_path_len(info, namelen);
+
+	strbuf_grow(out, len);
+	make_traverse_path(out->buf + out->len, out->alloc - out->len,
+			   info, name, namelen);
+	strbuf_setlen(out, out->len + len);
+}
+
 struct tree_desc_skip {
 	struct tree_desc_skip *prev;
 	const void *ptr;
@@ -363,7 +391,8 @@ static void free_extended_entry(struct t
 	}
 }
 
-static inline int prune_traversal(struct name_entry *e,
+static inline int prune_traversal(struct index_state *istate,
+				  struct name_entry *e,
 				  struct traverse_info *info,
 				  struct strbuf *base,
 				  int still_interesting)
@@ -372,10 +401,13 @@ static inline int prune_traversal(struct
 		return 2;
 	if (still_interesting < 0)
 		return still_interesting;
-	return tree_entry_interesting(e, base, 0, info->pathspec);
+	return tree_entry_interesting(istate, e, base,
+				      0, info->pathspec);
 }
 
-int traverse_trees(int n, struct tree_desc *t, struct traverse_info *info)
+int traverse_trees(struct index_state *istate,
+		   int n, struct tree_desc *t,
+		   struct traverse_info *info)
 {
 	int error = 0;
 	struct name_entry *entry = xmalloc(n*sizeof(*entry));
@@ -389,13 +421,12 @@ int traverse_trees(int n, struct tree_de
 		tx[i].d = t[i];
 
 	if (info->prev) {
-		strbuf_grow(&base, info->pathlen);
-		make_traverse_path(base.buf, info->prev, &info->name);
-		base.buf[info->pathlen-1] = '/';
-		strbuf_setlen(&base, info->pathlen);
-		traverse_path = xstrndup(base.buf, info->pathlen);
+		strbuf_make_traverse_path(&base, info->prev,
+					  info->name, info->namelen);
+		strbuf_addch(&base, '/');
+		traverse_path = xstrndup(base.buf, base.len);
 	} else {
-		traverse_path = xstrndup(info->name.path, info->pathlen);
+		traverse_path = xstrndup(info->name, info->pathlen);
 	}
 	info->traverse_path = traverse_path;
 	for (;;) {
@@ -459,7 +490,7 @@ int traverse_trees(int n, struct tree_de
 		}
 		if (!mask)
 			break;
-		interesting = prune_traversal(e, info, &base, interesting);
+		interesting = prune_traversal(istate, e, info, &base, interesting);
 		if (interesting < 0)
 			break;
 		if (interesting) {
@@ -491,15 +522,17 @@ struct dir_state {
 	struct object_id oid;
 };
 
-static int find_tree_entry(struct tree_desc *t, const char *name, struct object_id *result, unsigned *mode)
+static int find_tree_entry(struct repository *r, struct tree_desc *t,
+			   const char *name, struct object_id *result,
+			   unsigned short *mode)
 {
 	int namelen = strlen(name);
 	while (t->size) {
 		const char *entry;
-		const struct object_id *oid;
+		struct object_id oid;
 		int entrylen, cmp;
 
-		oid = tree_entry_extract(t, &entry, mode);
+		oidcpy(&oid, tree_entry_extract(t, &entry, mode));
 		entrylen = tree_entry_len(&t->entry);
 		update_tree_entry(t);
 		if (entrylen > namelen)
@@ -510,7 +543,7 @@ static int find_tree_entry(struct tree_d
 		if (cmp < 0)
 			break;
 		if (entrylen == namelen) {
-			oidcpy(result, oid);
+			oidcpy(result, &oid);
 			return 0;
 		}
 		if (name[entrylen] != '/')
@@ -518,22 +551,26 @@ static int find_tree_entry(struct tree_d
 		if (!S_ISDIR(*mode))
 			break;
 		if (++entrylen == namelen) {
-			oidcpy(result, oid);
+			oidcpy(result, &oid);
 			return 0;
 		}
-		return get_tree_entry(oid, name + entrylen, result, mode);
+		return get_tree_entry(r, &oid, name + entrylen, result, mode);
 	}
 	return -1;
 }
 
-int get_tree_entry(const struct object_id *tree_oid, const char *name, struct object_id *oid, unsigned *mode)
+int get_tree_entry(struct repository *r,
+		   const struct object_id *tree_oid,
+		   const char *name,
+		   struct object_id *oid,
+		   unsigned short *mode)
 {
 	int retval;
 	void *tree;
 	unsigned long size;
 	struct object_id root;
 
-	tree = read_object_with_reference(tree_oid, tree_type, &size, &root);
+	tree = read_object_with_reference(r, tree_oid, tree_type, &size, &root);
 	if (!tree)
 		return -1;
 
@@ -548,7 +585,7 @@ int get_tree_entry(const struct object_i
 	} else {
 		struct tree_desc t;
 		init_tree_desc(&t, tree, size);
-		retval = find_tree_entry(&t, name, oid, mode);
+		retval = find_tree_entry(r, &t, name, oid, mode);
 	}
 	free(tree);
 	return retval;
@@ -573,10 +610,13 @@ int get_tree_entry(const struct object_i
  * with the sha1 of the found object, and *mode will hold the mode of
  * the object.
  *
- * See the code for enum follow_symlink_result for a description of
+ * See the code for enum get_oid_result for a description of
  * the return values.
  */
-enum follow_symlinks_result get_tree_entry_follow_symlinks(struct object_id *tree_oid, const char *name, struct object_id *result, struct strbuf *result_path, unsigned *mode)
+enum get_oid_result get_tree_entry_follow_symlinks(struct repository *r,
+		struct object_id *tree_oid, const char *name,
+		struct object_id *result, struct strbuf *result_path,
+		unsigned short *mode)
 {
 	int retval = MISSING_OBJECT;
 	struct dir_state *parents = NULL;
@@ -600,7 +640,8 @@ enum follow_symlinks_result get_tree_ent
 			void *tree;
 			struct object_id root;
 			unsigned long size;
-			tree = read_object_with_reference(&current_tree_oid,
+			tree = read_object_with_reference(r,
+							  &current_tree_oid,
 							  tree_type, &size,
 							  &root);
 			if (!tree)
@@ -669,7 +710,7 @@ enum follow_symlinks_result get_tree_ent
 		}
 
 		/* Look up the first (or only) path component in the tree. */
-		find_result = find_tree_entry(&t, namebuf.buf,
+		find_result = find_tree_entry(r, &t, namebuf.buf,
 					      &current_tree_oid, mode);
 		if (find_result) {
 			goto done;
@@ -713,7 +754,8 @@ enum follow_symlinks_result get_tree_ent
 			 */
 			retval = DANGLING_SYMLINK;
 
-			contents = read_object_file(&current_tree_oid, &type,
+			contents = repo_read_object_file(r,
+						    &current_tree_oid, &type,
 						    &link_len);
 
 			if (!contents)
@@ -926,7 +968,8 @@ static int match_wildcard_base(const str
  * Pre-condition: either baselen == base_offset (i.e. empty path)
  * or base[baselen-1] == '/' (i.e. with trailing slash).
  */
-static enum interesting do_match(const struct name_entry *entry,
+static enum interesting do_match(struct index_state *istate,
+				 const struct name_entry *entry,
 				 struct strbuf *base, int base_offset,
 				 const struct pathspec *ps,
 				 int exclude)
@@ -942,7 +985,8 @@ static enum interesting do_match(const s
 		       PATHSPEC_LITERAL |
 		       PATHSPEC_GLOB |
 		       PATHSPEC_ICASE |
-		       PATHSPEC_EXCLUDE);
+		       PATHSPEC_EXCLUDE |
+		       PATHSPEC_ATTR);
 
 	if (!ps->nr) {
 		if (!ps->recursive ||
@@ -974,14 +1018,20 @@ static enum interesting do_match(const s
 
 			if (!ps->recursive ||
 			    !(ps->magic & PATHSPEC_MAXDEPTH) ||
-			    ps->max_depth == -1)
-				return all_entries_interesting;
+			    ps->max_depth == -1) {
+				if (!item->attr_match_nr)
+					return all_entries_interesting;
+				else
+					goto interesting;
+			}
 
-			return within_depth(base_str + matchlen + 1,
-					    baselen - matchlen - 1,
-					    !!S_ISDIR(entry->mode),
-					    ps->max_depth) ?
-				entry_interesting : entry_not_interesting;
+			if (within_depth(base_str + matchlen + 1,
+					 baselen - matchlen - 1,
+					 !!S_ISDIR(entry->mode),
+					 ps->max_depth))
+				goto interesting;
+			else
+				return entry_not_interesting;
 		}
 
 		/* Either there must be no base, or the base must match. */
@@ -989,12 +1039,12 @@ static enum interesting do_match(const s
 			if (match_entry(item, entry, pathlen,
 					match + baselen, matchlen - baselen,
 					&never_interesting))
-				return entry_interesting;
+				goto interesting;
 
 			if (item->nowildcard_len < item->len) {
 				if (!git_fnmatch(item, match + baselen, entry->path,
 						 item->nowildcard_len - baselen))
-					return entry_interesting;
+					goto interesting;
 
 				/*
 				 * Match all directories. We'll try to
@@ -1015,7 +1065,7 @@ static enum interesting do_match(const s
 				    !ps_strncmp(item, match + baselen,
 						entry->path,
 						item->nowildcard_len - baselen))
-					return entry_interesting;
+					goto interesting;
 			}
 
 			continue;
@@ -1050,7 +1100,7 @@ match_wildcards:
 		if (!git_fnmatch(item, match, base->buf + base_offset,
 				 item->nowildcard_len)) {
 			strbuf_setlen(base, base_offset + baselen);
-			return entry_interesting;
+			goto interesting;
 		}
 
 		/*
@@ -1064,7 +1114,7 @@ match_wildcards:
 		    !ps_strncmp(item, match, base->buf + base_offset,
 				item->nowildcard_len)) {
 			strbuf_setlen(base, base_offset + baselen);
-			return entry_interesting;
+			goto interesting;
 		}
 
 		strbuf_setlen(base, base_offset + baselen);
@@ -1074,10 +1124,42 @@ match_wildcards:
 		 * later on.
 		 * max_depth is ignored but we may consider support it
 		 * in future, see
-		 * https://public-inbox.org/git/7vmxo5l2g4.fsf@alter.siamese.dyndns.org/
+		 * https://lore.kernel.org/git/7vmxo5l2g4.fsf@alter.siamese.dyndns.org/
 		 */
 		if (ps->recursive && S_ISDIR(entry->mode))
 			return entry_interesting;
+		continue;
+interesting:
+		if (item->attr_match_nr) {
+			int ret;
+
+			/*
+			 * Must not return all_entries_not_interesting
+			 * prematurely. We do not know if all entries do not
+			 * match some attributes with current attr API.
+			 */
+			never_interesting = entry_not_interesting;
+
+			/*
+			 * Consider all directories interesting (because some
+			 * of those files inside may match some attributes
+			 * even though the parent dir does not)
+			 *
+			 * FIXME: attributes _can_ match directories and we
+			 * can probably return all_entries_interesting or
+			 * all_entries_not_interesting here if matched.
+			 */
+			if (S_ISDIR(entry->mode))
+				return entry_interesting;
+
+			strbuf_add(base, entry->path, pathlen);
+			ret = match_pathspec_attrs(istate, base->buf + base_offset,
+						   base->len - base_offset, item);
+			strbuf_setlen(base, base_offset + baselen);
+			if (!ret)
+				continue;
+		}
+		return entry_interesting;
 	}
 	return never_interesting; /* No matches */
 }
@@ -1088,12 +1170,13 @@ match_wildcards:
  * Pre-condition: either baselen == base_offset (i.e. empty path)
  * or base[baselen-1] == '/' (i.e. with trailing slash).
  */
-enum interesting tree_entry_interesting(const struct name_entry *entry,
+enum interesting tree_entry_interesting(struct index_state *istate,
+					const struct name_entry *entry,
 					struct strbuf *base, int base_offset,
 					const struct pathspec *ps)
 {
 	enum interesting positive, negative;
-	positive = do_match(entry, base, base_offset, ps, 0);
+	positive = do_match(istate, entry, base, base_offset, ps, 0);
 
 	/*
 	 * case | entry | positive | negative | result
@@ -1105,7 +1188,7 @@ enum interesting tree_entry_interesting(
 	 *   5  |  file |    1     |    1     |   0
 	 *   6  |  file |    1     |    2     |   0
 	 *   7  |  file |    2     |   -1     |   2
-	 *   8  |  file |    2     |    0     |   2
+	 *   8  |  file |    2     |    0     |   1
 	 *   9  |  file |    2     |    1     |   0
 	 *  10  |  file |    2     |    2     |  -1
 	 * -----+-------+----------+----------+-------
@@ -1116,7 +1199,7 @@ enum interesting tree_entry_interesting(
 	 *  15  |  dir  |    1     |    1     |   1 (*)
 	 *  16  |  dir  |    1     |    2     |   0
 	 *  17  |  dir  |    2     |   -1     |   2
-	 *  18  |  dir  |    2     |    0     |   2
+	 *  18  |  dir  |    2     |    0     |   1
 	 *  19  |  dir  |    2     |    1     |   1 (*)
 	 *  20  |  dir  |    2     |    2     |  -1
 	 *
@@ -1130,9 +1213,14 @@ enum interesting tree_entry_interesting(
 	    positive <= entry_not_interesting) /* #1, #2, #11, #12 */
 		return positive;
 
-	negative = do_match(entry, base, base_offset, ps, 1);
+	negative = do_match(istate, entry, base, base_offset, ps, 1);
+
+	/* #8, #18 */
+	if (positive == all_entries_interesting &&
+	    negative == entry_not_interesting)
+		return entry_interesting;
 
-	/* #3, #4, #7, #8, #13, #14, #17, #18 */
+	/* #3, #4, #7, #13, #14, #17 */
 	if (negative <= entry_not_interesting)
 		return positive;
 
diff -pruN 1.2.1+git2.18.0-1/git/tree-walk.h 1.2.3+git2.25.1-1/git/tree-walk.h
--- 1.2.1+git2.18.0-1/git/tree-walk.h	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/tree-walk.h	2020-02-17 04:47:35.000000000 +0000
@@ -1,28 +1,60 @@
 #ifndef TREE_WALK_H
 #define TREE_WALK_H
 
+#include "cache.h"
+
+/**
+ * The tree walking API is used to traverse and inspect trees.
+ */
+
+/**
+ * An entry in a tree. Each entry has a sha1 identifier, pathname, and mode.
+ */
 struct name_entry {
-	const struct object_id *oid;
+	struct object_id oid;
 	const char *path;
+	int pathlen;
 	unsigned int mode;
 };
 
+/**
+ * A semi-opaque data structure used to maintain the current state of the walk.
+ */
 struct tree_desc {
+	/*
+	 * pointer into the memory representation of the tree. It always
+	 * points at the current entry being visited.
+	 */
 	const void *buffer;
+
+	/* points to the current entry being visited. */
 	struct name_entry entry;
+
+	/* counts the number of bytes left in the `buffer`. */
 	unsigned int size;
 };
 
-static inline const struct object_id *tree_entry_extract(struct tree_desc *desc, const char **pathp, unsigned int *modep)
+/**
+ * Decode the entry currently being visited (the one pointed to by
+ * `tree_desc's` `entry` member) and return the sha1 of the entry. The
+ * `pathp` and `modep` arguments are set to the entry's pathname and mode
+ * respectively.
+ */
+static inline const struct object_id *tree_entry_extract(struct tree_desc *desc, const char **pathp, unsigned short *modep)
 {
 	*pathp = desc->entry.path;
 	*modep = desc->entry.mode;
-	return desc->entry.oid;
+	return &desc->entry.oid;
 }
 
+/**
+ * Calculate the length of a tree entry's pathname. This utilizes the
+ * memory structure of a tree entry to avoid the overhead of using a
+ * generic strlen().
+ */
 static inline int tree_entry_len(const struct name_entry *ne)
 {
-	return (const char *)ne->oid - ne->path - 1;
+	return ne->pathlen;
 }
 
 /*
@@ -30,62 +62,145 @@ static inline int tree_entry_len(const s
  * corrupt tree entry rather than dying,
  */
 
+/**
+ * Walk to the next entry in a tree. This is commonly used in conjunction
+ * with `tree_entry_extract` to inspect the current entry.
+ */
 void update_tree_entry(struct tree_desc *);
+
 int update_tree_entry_gently(struct tree_desc *);
+
+/**
+ * Initialize a `tree_desc` and decode its first entry. The buffer and
+ * size parameters are assumed to be the same as the buffer and size
+ * members of `struct tree`.
+ */
 void init_tree_desc(struct tree_desc *desc, const void *buf, unsigned long size);
+
 int init_tree_desc_gently(struct tree_desc *desc, const void *buf, unsigned long size);
 
 /*
- * Helper function that does both tree_entry_extract() and update_tree_entry()
- * and returns true for success
+ * Visit the next entry in a tree. Returns 1 when there are more entries
+ * left to visit and 0 when all entries have been visited. This is
+ * commonly used in the test of a while loop.
  */
 int tree_entry(struct tree_desc *, struct name_entry *);
+
 int tree_entry_gently(struct tree_desc *, struct name_entry *);
 
-void *fill_tree_descriptor(struct tree_desc *desc, const struct object_id *oid);
+/**
+ * Initialize a `tree_desc` and decode its first entry given the
+ * object ID of a tree. Returns the `buffer` member if the latter
+ * is a valid tree identifier and NULL otherwise.
+ */
+void *fill_tree_descriptor(struct repository *r,
+			   struct tree_desc *desc,
+			   const struct object_id *oid);
 
 struct traverse_info;
 typedef int (*traverse_callback_t)(int n, unsigned long mask, unsigned long dirmask, struct name_entry *entry, struct traverse_info *);
-int traverse_trees(int n, struct tree_desc *t, struct traverse_info *info);
 
-enum follow_symlinks_result {
-	FOUND = 0, /* This includes out-of-tree links */
-	MISSING_OBJECT = -1, /* The initial symlink is missing */
-	DANGLING_SYMLINK = -2, /*
-				* The initial symlink is there, but
-				* (transitively) points to a missing
-				* in-tree file
-				*/
-	SYMLINK_LOOP = -3,
-	NOT_DIR = -4, /*
-		       * Somewhere along the symlink chain, a path is
-		       * requested which contains a file as a
-		       * non-final element.
-		       */
-};
+/**
+ * Traverse `n` number of trees in parallel. The `fn` callback member of
+ * `traverse_info` is called once for each tree entry.
+ */
+int traverse_trees(struct index_state *istate, int n, struct tree_desc *t, struct traverse_info *info);
 
-enum follow_symlinks_result get_tree_entry_follow_symlinks(struct object_id *tree_oid, const char *name, struct object_id *result, struct strbuf *result_path, unsigned *mode);
+enum get_oid_result get_tree_entry_follow_symlinks(struct repository *r, struct object_id *tree_oid, const char *name, struct object_id *result, struct strbuf *result_path, unsigned short *mode);
 
+/**
+ * A structure used to maintain the state of a traversal.
+ */
 struct traverse_info {
 	const char *traverse_path;
+
+	/*
+	 * points to the traverse_info which was used to descend into the
+	 * current tree. If this is the top-level tree `prev` will point to
+	 * a dummy traverse_info.
+	 */
 	struct traverse_info *prev;
-	struct name_entry name;
-	int pathlen;
+
+	/* is the entry for the current tree (if the tree is a subtree). */
+	const char *name;
+
+	size_t namelen;
+	unsigned mode;
+
+	/* is the length of the full path for the current tree. */
+	size_t pathlen;
+
 	struct pathspec *pathspec;
 
+	/* can be used by callbacks to maintain directory-file conflicts. */
 	unsigned long df_conflicts;
+
+	/* a callback called for each entry in the tree.
+	 *
+	 * The arguments passed to the traverse callback are as follows:
+	 *
+	 * - `n` counts the number of trees being traversed.
+	 *
+	 * - `mask` has its nth bit set if something exists in the nth entry.
+	 *
+	 * - `dirmask` has its nth bit set if the nth tree's entry is a directory.
+	 *
+	 * - `entry` is an array of size `n` where the nth entry is from the nth tree.
+	 *
+	 * - `info` maintains the state of the traversal.
+	 *
+	 * Returning a negative value will terminate the traversal. Otherwise the
+	 * return value is treated as an update mask. If the nth bit is set the nth tree
+	 * will be updated and if the bit is not set the nth tree entry will be the
+	 * same in the next callback invocation.
+	 */
 	traverse_callback_t fn;
+
+	/* can be anything the `fn` callback would want to use. */
 	void *data;
+
+	/* tells whether to stop at the first error or not. */
 	int show_all_errors;
 };
 
-int get_tree_entry(const struct object_id *, const char *, struct object_id *, unsigned *);
-extern char *make_traverse_path(char *path, const struct traverse_info *info, const struct name_entry *n);
-extern void setup_traverse_info(struct traverse_info *info, const char *base);
+/**
+ * Find an entry in a tree given a pathname and the sha1 of a tree to
+ * search. Returns 0 if the entry is found and -1 otherwise. The third
+ * and fourth parameters are set to the entry's sha1 and mode respectively.
+ */
+int get_tree_entry(struct repository *, const struct object_id *, const char *, struct object_id *, unsigned short *);
+
+/**
+ * Generate the full pathname of a tree entry based from the root of the
+ * traversal. For example, if the traversal has recursed into another
+ * tree named "bar" the pathname of an entry "baz" in the "bar"
+ * tree would be "bar/baz".
+ */
+char *make_traverse_path(char *path, size_t pathlen, const struct traverse_info *info,
+			 const char *name, size_t namelen);
 
-static inline int traverse_path_len(const struct traverse_info *info, const struct name_entry *n)
+/**
+ * Convenience wrapper to `make_traverse_path` into a strbuf.
+ */
+void strbuf_make_traverse_path(struct strbuf *out,
+			       const struct traverse_info *info,
+			       const char *name, size_t namelen);
+
+/**
+ * Initialize a `traverse_info` given the pathname of the tree to start
+ * traversing from.
+ */
+void setup_traverse_info(struct traverse_info *info, const char *base);
+
+/**
+ * Calculate the length of a pathname returned by `make_traverse_path`.
+ * This utilizes the memory structure of a tree entry to avoid the
+ * overhead of using a generic strlen().
+ */
+static inline size_t traverse_path_len(const struct traverse_info *info,
+				       size_t namelen)
 {
-	return info->pathlen + tree_entry_len(n);
+	return st_add(info->pathlen, namelen);
 }
 
 /* in general, positive means "kind of interesting" */
@@ -96,8 +211,9 @@ enum interesting {
 	all_entries_interesting = 2 /* yes, and all subsequent entries will be */
 };
 
-extern enum interesting tree_entry_interesting(const struct name_entry *,
-					       struct strbuf *, int,
-					       const struct pathspec *ps);
+enum interesting tree_entry_interesting(struct index_state *istate,
+					const struct name_entry *,
+					struct strbuf *, int,
+					const struct pathspec *ps);
 
 #endif
diff -pruN 1.2.1+git2.18.0-1/git/unicode-width.h 1.2.3+git2.25.1-1/git/unicode-width.h
--- 1.2.1+git2.18.0-1/git/unicode-width.h	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/unicode-width.h	2020-02-17 04:47:35.000000000 +0000
@@ -20,12 +20,13 @@ static const struct interval zero_width[
 { 0x0730, 0x074A },
 { 0x07A6, 0x07B0 },
 { 0x07EB, 0x07F3 },
+{ 0x07FD, 0x07FD },
 { 0x0816, 0x0819 },
 { 0x081B, 0x0823 },
 { 0x0825, 0x0827 },
 { 0x0829, 0x082D },
 { 0x0859, 0x085B },
-{ 0x08D4, 0x0902 },
+{ 0x08D3, 0x0902 },
 { 0x093A, 0x093A },
 { 0x093C, 0x093C },
 { 0x0941, 0x0948 },
@@ -37,6 +38,7 @@ static const struct interval zero_width[
 { 0x09C1, 0x09C4 },
 { 0x09CD, 0x09CD },
 { 0x09E2, 0x09E3 },
+{ 0x09FE, 0x09FE },
 { 0x0A01, 0x0A02 },
 { 0x0A3C, 0x0A3C },
 { 0x0A41, 0x0A42 },
@@ -63,6 +65,7 @@ static const struct interval zero_width[
 { 0x0BC0, 0x0BC0 },
 { 0x0BCD, 0x0BCD },
 { 0x0C00, 0x0C00 },
+{ 0x0C04, 0x0C04 },
 { 0x0C3E, 0x0C40 },
 { 0x0C46, 0x0C48 },
 { 0x0C4A, 0x0C4D },
@@ -86,8 +89,7 @@ static const struct interval zero_width[
 { 0x0E34, 0x0E3A },
 { 0x0E47, 0x0E4E },
 { 0x0EB1, 0x0EB1 },
-{ 0x0EB4, 0x0EB9 },
-{ 0x0EBB, 0x0EBC },
+{ 0x0EB4, 0x0EBC },
 { 0x0EC8, 0x0ECD },
 { 0x0F18, 0x0F19 },
 { 0x0F35, 0x0F35 },
@@ -182,12 +184,13 @@ static const struct interval zero_width[
 { 0xA825, 0xA826 },
 { 0xA8C4, 0xA8C5 },
 { 0xA8E0, 0xA8F1 },
+{ 0xA8FF, 0xA8FF },
 { 0xA926, 0xA92D },
 { 0xA947, 0xA951 },
 { 0xA980, 0xA982 },
 { 0xA9B3, 0xA9B3 },
 { 0xA9B6, 0xA9B9 },
-{ 0xA9BC, 0xA9BC },
+{ 0xA9BC, 0xA9BD },
 { 0xA9E5, 0xA9E5 },
 { 0xAA29, 0xAA2E },
 { 0xAA31, 0xAA32 },
@@ -219,19 +222,22 @@ static const struct interval zero_width[
 { 0x10A38, 0x10A3A },
 { 0x10A3F, 0x10A3F },
 { 0x10AE5, 0x10AE6 },
+{ 0x10D24, 0x10D27 },
+{ 0x10F46, 0x10F50 },
 { 0x11001, 0x11001 },
 { 0x11038, 0x11046 },
 { 0x1107F, 0x11081 },
 { 0x110B3, 0x110B6 },
 { 0x110B9, 0x110BA },
 { 0x110BD, 0x110BD },
+{ 0x110CD, 0x110CD },
 { 0x11100, 0x11102 },
 { 0x11127, 0x1112B },
 { 0x1112D, 0x11134 },
 { 0x11173, 0x11173 },
 { 0x11180, 0x11181 },
 { 0x111B6, 0x111BE },
-{ 0x111CA, 0x111CC },
+{ 0x111C9, 0x111CC },
 { 0x1122F, 0x11231 },
 { 0x11234, 0x11234 },
 { 0x11236, 0x11237 },
@@ -239,13 +245,14 @@ static const struct interval zero_width[
 { 0x112DF, 0x112DF },
 { 0x112E3, 0x112EA },
 { 0x11300, 0x11301 },
-{ 0x1133C, 0x1133C },
+{ 0x1133B, 0x1133C },
 { 0x11340, 0x11340 },
 { 0x11366, 0x1136C },
 { 0x11370, 0x11374 },
 { 0x11438, 0x1143F },
 { 0x11442, 0x11444 },
 { 0x11446, 0x11446 },
+{ 0x1145E, 0x1145E },
 { 0x114B3, 0x114B8 },
 { 0x114BA, 0x114BA },
 { 0x114BF, 0x114C0 },
@@ -264,8 +271,12 @@ static const struct interval zero_width[
 { 0x1171D, 0x1171F },
 { 0x11722, 0x11725 },
 { 0x11727, 0x1172B },
-{ 0x11A01, 0x11A06 },
-{ 0x11A09, 0x11A0A },
+{ 0x1182F, 0x11837 },
+{ 0x11839, 0x1183A },
+{ 0x119D4, 0x119D7 },
+{ 0x119DA, 0x119DB },
+{ 0x119E0, 0x119E0 },
+{ 0x11A01, 0x11A0A },
 { 0x11A33, 0x11A38 },
 { 0x11A3B, 0x11A3E },
 { 0x11A47, 0x11A47 },
@@ -285,8 +296,14 @@ static const struct interval zero_width[
 { 0x11D3C, 0x11D3D },
 { 0x11D3F, 0x11D45 },
 { 0x11D47, 0x11D47 },
+{ 0x11D90, 0x11D91 },
+{ 0x11D95, 0x11D95 },
+{ 0x11D97, 0x11D97 },
+{ 0x11EF3, 0x11EF4 },
+{ 0x13430, 0x13438 },
 { 0x16AF0, 0x16AF4 },
 { 0x16B30, 0x16B36 },
+{ 0x16F4F, 0x16F4F },
 { 0x16F8F, 0x16F92 },
 { 0x1BC9D, 0x1BC9E },
 { 0x1BCA0, 0x1BCA3 },
@@ -306,6 +323,8 @@ static const struct interval zero_width[
 { 0x1E01B, 0x1E021 },
 { 0x1E023, 0x1E024 },
 { 0x1E026, 0x1E02A },
+{ 0x1E130, 0x1E136 },
+{ 0x1E2EC, 0x1E2EF },
 { 0x1E8D0, 0x1E8D6 },
 { 0x1E944, 0x1E94A },
 { 0xE0001, 0xE0001 },
@@ -355,14 +374,13 @@ static const struct interval double_widt
 { 0x3000, 0x303E },
 { 0x3041, 0x3096 },
 { 0x3099, 0x30FF },
-{ 0x3105, 0x312E },
+{ 0x3105, 0x312F },
 { 0x3131, 0x318E },
 { 0x3190, 0x31BA },
 { 0x31C0, 0x31E3 },
 { 0x31F0, 0x321E },
 { 0x3220, 0x3247 },
-{ 0x3250, 0x32FE },
-{ 0x3300, 0x4DBF },
+{ 0x3250, 0x4DBF },
 { 0x4E00, 0xA48C },
 { 0xA490, 0xA4C6 },
 { 0xA960, 0xA97C },
@@ -374,10 +392,12 @@ static const struct interval double_widt
 { 0xFE68, 0xFE6B },
 { 0xFF01, 0xFF60 },
 { 0xFFE0, 0xFFE6 },
-{ 0x16FE0, 0x16FE1 },
-{ 0x17000, 0x187EC },
+{ 0x16FE0, 0x16FE3 },
+{ 0x17000, 0x187F7 },
 { 0x18800, 0x18AF2 },
 { 0x1B000, 0x1B11E },
+{ 0x1B150, 0x1B152 },
+{ 0x1B164, 0x1B167 },
 { 0x1B170, 0x1B2FB },
 { 0x1F004, 0x1F004 },
 { 0x1F0CF, 0x1F0CF },
@@ -409,14 +429,20 @@ static const struct interval double_widt
 { 0x1F680, 0x1F6C5 },
 { 0x1F6CC, 0x1F6CC },
 { 0x1F6D0, 0x1F6D2 },
+{ 0x1F6D5, 0x1F6D5 },
 { 0x1F6EB, 0x1F6EC },
-{ 0x1F6F4, 0x1F6F8 },
-{ 0x1F910, 0x1F93E },
-{ 0x1F940, 0x1F94C },
-{ 0x1F950, 0x1F96B },
-{ 0x1F980, 0x1F997 },
-{ 0x1F9C0, 0x1F9C0 },
-{ 0x1F9D0, 0x1F9E6 },
+{ 0x1F6F4, 0x1F6FA },
+{ 0x1F7E0, 0x1F7EB },
+{ 0x1F90D, 0x1F971 },
+{ 0x1F973, 0x1F976 },
+{ 0x1F97A, 0x1F9A2 },
+{ 0x1F9A5, 0x1F9AA },
+{ 0x1F9AE, 0x1F9CA },
+{ 0x1F9CD, 0x1F9FF },
+{ 0x1FA70, 0x1FA73 },
+{ 0x1FA78, 0x1FA7A },
+{ 0x1FA80, 0x1FA82 },
+{ 0x1FA90, 0x1FA95 },
 { 0x20000, 0x2FFFD },
 { 0x30000, 0x3FFFD }
 };
diff -pruN 1.2.1+git2.18.0-1/git/unpack-trees.c 1.2.3+git2.25.1-1/git/unpack-trees.c
--- 1.2.1+git2.18.0-1/git/unpack-trees.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/unpack-trees.c	2020-02-17 04:47:35.000000000 +0000
@@ -1,4 +1,3 @@
-#define NO_THE_INDEX_COMPATIBILITY_MACROS
 #include "cache.h"
 #include "argv-array.h"
 #include "repository.h"
@@ -12,11 +11,11 @@
 #include "refs.h"
 #include "attr.h"
 #include "split-index.h"
-#include "dir.h"
 #include "submodule.h"
 #include "submodule-config.h"
 #include "fsmonitor.h"
-#include "fetch-object.h"
+#include "object-store.h"
+#include "promisor-remote.h"
 
 /*
  * Error messages expected by scripts out of plumbing commands such as
@@ -203,20 +202,11 @@ static int do_add_entry(struct unpack_tr
 			       ADD_CACHE_OK_TO_ADD | ADD_CACHE_OK_TO_REPLACE);
 }
 
-static struct cache_entry *dup_entry(const struct cache_entry *ce)
-{
-	unsigned int size = ce_size(ce);
-	struct cache_entry *new_entry = xmalloc(size);
-
-	memcpy(new_entry, ce, size);
-	return new_entry;
-}
-
 static void add_entry(struct unpack_trees_options *o,
 		      const struct cache_entry *ce,
 		      unsigned int set, unsigned int clear)
 {
-	do_add_entry(o, dup_entry(ce), set, clear);
+	do_add_entry(o, dup_cache_entry(ce, &o->result), set, clear);
 }
 
 /*
@@ -228,6 +218,9 @@ static int add_rejected_path(struct unpa
 			     enum unpack_trees_error_types e,
 			     const char *path)
 {
+	if (o->quiet)
+		return -1;
+
 	if (!o->show_all_errors)
 		return error(ERRORMSG(o, e), super_prefixed(path));
 
@@ -277,15 +270,14 @@ static int check_submodule_move_head(con
 		flags |= SUBMODULE_MOVE_HEAD_FORCE;
 
 	if (submodule_move_head(ce->name, old_id, new_id, flags))
-		return o->gently ? -1 :
-				   add_rejected_path(o, ERROR_WOULD_LOSE_SUBMODULE, ce->name);
+		return add_rejected_path(o, ERROR_WOULD_LOSE_SUBMODULE, ce->name);
 	return 0;
 }
 
 /*
- * Preform the loading of the repository's gitmodules file.  This function is
+ * Perform the loading of the repository's gitmodules file.  This function is
  * used by 'check_update()' to perform loading of the gitmodules file in two
- * differnt situations:
+ * different situations:
  * (1) before removing entries from the working tree if the gitmodules file has
  *     been marked for removal.  This situation is specified by 'state' == NULL.
  * (2) before checking out entries to the working tree if the gitmodules file
@@ -302,31 +294,12 @@ static void load_gitmodules_file(struct
 			repo_read_gitmodules(the_repository);
 		} else if (state && (ce->ce_flags & CE_UPDATE)) {
 			submodule_free(the_repository);
-			checkout_entry(ce, state, NULL);
+			checkout_entry(ce, state, NULL, NULL);
 			repo_read_gitmodules(the_repository);
 		}
 	}
 }
 
-/*
- * Unlink the last component and schedule the leading directories for
- * removal, such that empty directories get removed.
- */
-static void unlink_entry(const struct cache_entry *ce)
-{
-	const struct submodule *sub = submodule_from_ce(ce);
-	if (sub) {
-		/* state.force is set at the caller. */
-		submodule_move_head(ce->name, "HEAD", NULL,
-				    SUBMODULE_MOVE_HEAD_FORCE);
-	}
-	if (!check_leading_path(ce->name, ce_namelen(ce)))
-		return;
-	if (remove_or_warn(ce->ce_mode, ce->name))
-		return;
-	schedule_dir_for_removal(ce->name, ce_namelen(ce));
-}
-
 static struct progress *get_progress(struct unpack_trees_options *o)
 {
 	unsigned cnt = 0, total = 0;
@@ -341,27 +314,71 @@ static struct progress *get_progress(str
 			total++;
 	}
 
-	return start_delayed_progress(_("Checking out files"), total);
+	return start_delayed_progress(_("Updating files"), total);
+}
+
+static void setup_collided_checkout_detection(struct checkout *state,
+					      struct index_state *index)
+{
+	int i;
+
+	state->clone = 1;
+	for (i = 0; i < index->cache_nr; i++)
+		index->cache[i]->ce_flags &= ~CE_MATCHED;
+}
+
+static void report_collided_checkout(struct index_state *index)
+{
+	struct string_list list = STRING_LIST_INIT_NODUP;
+	int i;
+
+	for (i = 0; i < index->cache_nr; i++) {
+		struct cache_entry *ce = index->cache[i];
+
+		if (!(ce->ce_flags & CE_MATCHED))
+			continue;
+
+		string_list_append(&list, ce->name);
+		ce->ce_flags &= ~CE_MATCHED;
+	}
+
+	list.cmp = fspathcmp;
+	string_list_sort(&list);
+
+	if (list.nr) {
+		warning(_("the following paths have collided (e.g. case-sensitive paths\n"
+			  "on a case-insensitive filesystem) and only one from the same\n"
+			  "colliding group is in the working tree:\n"));
+
+		for (i = 0; i < list.nr; i++)
+			fprintf(stderr, "  '%s'\n", list.items[i].string);
+	}
+
+	string_list_clear(&list, 0);
 }
 
 static int check_updates(struct unpack_trees_options *o)
 {
 	unsigned cnt = 0;
 	int errs = 0;
-	struct progress *progress = NULL;
+	struct progress *progress;
 	struct index_state *index = &o->result;
 	struct checkout state = CHECKOUT_INIT;
 	int i;
 
+	trace_performance_enter();
 	state.force = 1;
 	state.quiet = 1;
 	state.refresh_cache = 1;
 	state.istate = index;
 
+	if (o->clone)
+		setup_collided_checkout_detection(&state, index);
+
 	progress = get_progress(o);
 
 	if (o->update)
-		git_attr_set_direction(GIT_ATTR_CHECKOUT, index);
+		git_attr_set_direction(GIT_ATTR_CHECKOUT);
 
 	if (should_update_submodules() && o->update && !o->dry_run)
 		load_gitmodules_file(index, NULL);
@@ -375,33 +392,34 @@ static int check_updates(struct unpack_t
 				unlink_entry(ce);
 		}
 	}
-	remove_marked_cache_entries(index);
+	remove_marked_cache_entries(index, 0);
 	remove_scheduled_dirs();
 
 	if (should_update_submodules() && o->update && !o->dry_run)
 		load_gitmodules_file(index, &state);
 
 	enable_delayed_checkout(&state);
-	if (repository_format_partial_clone && o->update && !o->dry_run) {
+	if (has_promisor_remote() && o->update && !o->dry_run) {
 		/*
 		 * Prefetch the objects that are to be checked out in the loop
 		 * below.
 		 */
 		struct oid_array to_fetch = OID_ARRAY_INIT;
-		int fetch_if_missing_store = fetch_if_missing;
-		fetch_if_missing = 0;
 		for (i = 0; i < index->cache_nr; i++) {
 			struct cache_entry *ce = index->cache[i];
-			if ((ce->ce_flags & CE_UPDATE) &&
-			    !S_ISGITLINK(ce->ce_mode)) {
-				if (!has_object_file(&ce->oid))
-					oid_array_append(&to_fetch, &ce->oid);
-			}
+
+			if (!(ce->ce_flags & CE_UPDATE) ||
+			    S_ISGITLINK(ce->ce_mode))
+				continue;
+			if (!oid_object_info_extended(the_repository, &ce->oid,
+						      NULL,
+						      OBJECT_INFO_FOR_PREFETCH))
+				continue;
+			oid_array_append(&to_fetch, &ce->oid);
 		}
 		if (to_fetch.nr)
-			fetch_objects(repository_format_partial_clone,
-				      &to_fetch);
-		fetch_if_missing = fetch_if_missing_store;
+			promisor_remote_get_direct(the_repository,
+						   to_fetch.oid, to_fetch.nr);
 		oid_array_clear(&to_fetch);
 	}
 	for (i = 0; i < index->cache_nr; i++) {
@@ -414,14 +432,19 @@ static int check_updates(struct unpack_t
 			display_progress(progress, ++cnt);
 			ce->ce_flags &= ~CE_UPDATE;
 			if (o->update && !o->dry_run) {
-				errs |= checkout_entry(ce, &state, NULL);
+				errs |= checkout_entry(ce, &state, NULL, NULL);
 			}
 		}
 	}
 	stop_progress(&progress);
-	errs |= finish_delayed_checkout(&state);
+	errs |= finish_delayed_checkout(&state, NULL);
 	if (o->update)
-		git_attr_set_direction(GIT_ATTR_CHECKIN, NULL);
+		git_attr_set_direction(GIT_ATTR_CHECKIN);
+
+	if (o->clone)
+		report_collided_checkout(index);
+
+	trace_performance_leave("check_updates");
 	return errs != 0;
 }
 
@@ -608,7 +631,7 @@ static int unpack_index_entry(struct cac
 	return ret;
 }
 
-static int find_cache_pos(struct traverse_info *, const struct name_entry *);
+static int find_cache_pos(struct traverse_info *, const char *p, size_t len);
 
 static void restore_cache_bottom(struct traverse_info *info, int bottom)
 {
@@ -627,7 +650,7 @@ static int switch_cache_bottom(struct tr
 	if (o->diff_index_cached)
 		return 0;
 	ret = o->cache_bottom;
-	pos = find_cache_pos(info->prev, &info->name);
+	pos = find_cache_pos(info->prev, info->name, info->namelen);
 
 	if (pos < -1)
 		o->cache_bottom = -2 - pos;
@@ -638,7 +661,113 @@ static int switch_cache_bottom(struct tr
 
 static inline int are_same_oid(struct name_entry *name_j, struct name_entry *name_k)
 {
-	return name_j->oid && name_k->oid && !oidcmp(name_j->oid, name_k->oid);
+	return !is_null_oid(&name_j->oid) && !is_null_oid(&name_k->oid) && oideq(&name_j->oid, &name_k->oid);
+}
+
+static int all_trees_same_as_cache_tree(int n, unsigned long dirmask,
+					struct name_entry *names,
+					struct traverse_info *info)
+{
+	struct unpack_trees_options *o = info->data;
+	int i;
+
+	if (!o->merge || dirmask != ((1 << n) - 1))
+		return 0;
+
+	for (i = 1; i < n; i++)
+		if (!are_same_oid(names, names + i))
+			return 0;
+
+	return cache_tree_matches_traversal(o->src_index->cache_tree, names, info);
+}
+
+static int index_pos_by_traverse_info(struct name_entry *names,
+				      struct traverse_info *info)
+{
+	struct unpack_trees_options *o = info->data;
+	struct strbuf name = STRBUF_INIT;
+	int pos;
+
+	strbuf_make_traverse_path(&name, info, names->path, names->pathlen);
+	strbuf_addch(&name, '/');
+	pos = index_name_pos(o->src_index, name.buf, name.len);
+	if (pos >= 0)
+		BUG("This is a directory and should not exist in index");
+	pos = -pos - 1;
+	if (pos >= o->src_index->cache_nr ||
+	    !starts_with(o->src_index->cache[pos]->name, name.buf) ||
+	    (pos > 0 && starts_with(o->src_index->cache[pos-1]->name, name.buf)))
+		BUG("pos %d doesn't point to the first entry of %s in index",
+		    pos, name.buf);
+	strbuf_release(&name);
+	return pos;
+}
+
+/*
+ * Fast path if we detect that all trees are the same as cache-tree at this
+ * path. We'll walk these trees in an iterative loop using cache-tree/index
+ * instead of ODB since we already know what these trees contain.
+ */
+static int traverse_by_cache_tree(int pos, int nr_entries, int nr_names,
+				  struct traverse_info *info)
+{
+	struct cache_entry *src[MAX_UNPACK_TREES + 1] = { NULL, };
+	struct unpack_trees_options *o = info->data;
+	struct cache_entry *tree_ce = NULL;
+	int ce_len = 0;
+	int i, d;
+
+	if (!o->merge)
+		BUG("We need cache-tree to do this optimization");
+
+	/*
+	 * Do what unpack_callback() and unpack_nondirectories() normally
+	 * do. But we walk all paths in an iterative loop instead.
+	 *
+	 * D/F conflicts and higher stage entries are not a concern
+	 * because cache-tree would be invalidated and we would never
+	 * get here in the first place.
+	 */
+	for (i = 0; i < nr_entries; i++) {
+		int new_ce_len, len, rc;
+
+		src[0] = o->src_index->cache[pos + i];
+
+		len = ce_namelen(src[0]);
+		new_ce_len = cache_entry_size(len);
+
+		if (new_ce_len > ce_len) {
+			new_ce_len <<= 1;
+			tree_ce = xrealloc(tree_ce, new_ce_len);
+			memset(tree_ce, 0, new_ce_len);
+			ce_len = new_ce_len;
+
+			tree_ce->ce_flags = create_ce_flags(0);
+
+			for (d = 1; d <= nr_names; d++)
+				src[d] = tree_ce;
+		}
+
+		tree_ce->ce_mode = src[0]->ce_mode;
+		tree_ce->ce_namelen = len;
+		oidcpy(&tree_ce->oid, &src[0]->oid);
+		memcpy(tree_ce->name, src[0]->name, len + 1);
+
+		rc = call_unpack_fn((const struct cache_entry * const *)src, o);
+		if (rc < 0) {
+			free(tree_ce);
+			return rc;
+		}
+
+		mark_ce_used(src[0], o);
+	}
+	free(tree_ce);
+	if (o->debug_unpack)
+		printf("Unpacked %d entries from %s to %s using cache-tree\n",
+		       nr_entries,
+		       o->src_index->cache[pos]->name,
+		       o->src_index->cache[pos + nr_entries - 1]->name);
+	return 0;
 }
 
 static int traverse_trees_recursive(int n, unsigned long dirmask,
@@ -646,12 +775,33 @@ static int traverse_trees_recursive(int
 				    struct name_entry *names,
 				    struct traverse_info *info)
 {
+	struct unpack_trees_options *o = info->data;
 	int i, ret, bottom;
 	int nr_buf = 0;
 	struct tree_desc t[MAX_UNPACK_TREES];
 	void *buf[MAX_UNPACK_TREES];
 	struct traverse_info newinfo;
 	struct name_entry *p;
+	int nr_entries;
+
+	nr_entries = all_trees_same_as_cache_tree(n, dirmask, names, info);
+	if (nr_entries > 0) {
+		int pos = index_pos_by_traverse_info(names, info);
+
+		if (!o->merge || df_conflicts)
+			BUG("Wrong condition to get here buddy");
+
+		/*
+		 * All entries up to 'pos' must have been processed
+		 * (i.e. marked CE_UNPACKED) at this point. But to be safe,
+		 * save and restore cache_bottom anyway to not miss
+		 * unprocessed entries before 'pos'.
+		 */
+		bottom = o->cache_bottom;
+		ret = traverse_by_cache_tree(pos, nr_entries, n, info);
+		o->cache_bottom = bottom;
+		return ret;
+	}
 
 	p = names;
 	while (!p->mode)
@@ -660,8 +810,10 @@ static int traverse_trees_recursive(int
 	newinfo = *info;
 	newinfo.prev = info;
 	newinfo.pathspec = info->pathspec;
-	newinfo.name = *p;
-	newinfo.pathlen += tree_entry_len(p) + 1;
+	newinfo.name = p->path;
+	newinfo.namelen = p->pathlen;
+	newinfo.mode = p->mode;
+	newinfo.pathlen = st_add3(newinfo.pathlen, tree_entry_len(p), 1);
 	newinfo.df_conflicts |= df_conflicts;
 
 	/*
@@ -688,13 +840,13 @@ static int traverse_trees_recursive(int
 		else {
 			const struct object_id *oid = NULL;
 			if (dirmask & 1)
-				oid = names[i].oid;
-			buf[nr_buf++] = fill_tree_descriptor(t + i, oid);
+				oid = &names[i].oid;
+			buf[nr_buf++] = fill_tree_descriptor(the_repository, t + i, oid);
 		}
 	}
 
 	bottom = switch_cache_bottom(&newinfo);
-	ret = traverse_trees(n, t, &newinfo);
+	ret = traverse_trees(o->src_index, n, t, &newinfo);
 	restore_cache_bottom(&newinfo, bottom);
 
 	for (i = 0; i < nr_buf; i++)
@@ -712,14 +864,18 @@ static int traverse_trees_recursive(int
  * itself - the caller needs to do the final check for the cache
  * entry having more data at the end!
  */
-static int do_compare_entry_piecewise(const struct cache_entry *ce, const struct traverse_info *info, const struct name_entry *n)
+static int do_compare_entry_piecewise(const struct cache_entry *ce,
+				      const struct traverse_info *info,
+				      const char *name, size_t namelen,
+				      unsigned mode)
 {
-	int len, pathlen, ce_len;
+	int pathlen, ce_len;
 	const char *ce_name;
 
 	if (info->prev) {
 		int cmp = do_compare_entry_piecewise(ce, info->prev,
-						     &info->name);
+						     info->name, info->namelen,
+						     info->mode);
 		if (cmp)
 			return cmp;
 	}
@@ -733,15 +889,15 @@ static int do_compare_entry_piecewise(co
 	ce_len -= pathlen;
 	ce_name = ce->name + pathlen;
 
-	len = tree_entry_len(n);
-	return df_name_compare(ce_name, ce_len, S_IFREG, n->path, len, n->mode);
+	return df_name_compare(ce_name, ce_len, S_IFREG, name, namelen, mode);
 }
 
 static int do_compare_entry(const struct cache_entry *ce,
 			    const struct traverse_info *info,
-			    const struct name_entry *n)
+			    const char *name, size_t namelen,
+			    unsigned mode)
 {
-	int len, pathlen, ce_len;
+	int pathlen, ce_len;
 	const char *ce_name;
 	int cmp;
 
@@ -751,7 +907,7 @@ static int do_compare_entry(const struct
 	 * it is quicker to use the precomputed version.
 	 */
 	if (!info->traverse_path)
-		return do_compare_entry_piecewise(ce, info, n);
+		return do_compare_entry_piecewise(ce, info, name, namelen, mode);
 
 	cmp = strncmp(ce->name, info->traverse_path, info->pathlen);
 	if (cmp)
@@ -766,13 +922,12 @@ static int do_compare_entry(const struct
 	ce_len -= pathlen;
 	ce_name = ce->name + pathlen;
 
-	len = tree_entry_len(n);
-	return df_name_compare(ce_name, ce_len, S_IFREG, n->path, len, n->mode);
+	return df_name_compare(ce_name, ce_len, S_IFREG, name, namelen, mode);
 }
 
 static int compare_entry(const struct cache_entry *ce, const struct traverse_info *info, const struct name_entry *n)
 {
-	int cmp = do_compare_entry(ce, info, n);
+	int cmp = do_compare_entry(ce, info, n->path, n->pathlen, n->mode);
 	if (cmp)
 		return cmp;
 
@@ -780,7 +935,7 @@ static int compare_entry(const struct ca
 	 * Even if the beginning compared identically, the ce should
 	 * compare as bigger than a directory leading up to it!
 	 */
-	return ce_namelen(ce) > traverse_path_len(info, n);
+	return ce_namelen(ce) > traverse_path_len(info, tree_entry_len(n));
 }
 
 static int ce_in_traverse_path(const struct cache_entry *ce,
@@ -788,7 +943,8 @@ static int ce_in_traverse_path(const str
 {
 	if (!info->prev)
 		return 1;
-	if (do_compare_entry(ce, info->prev, &info->name))
+	if (do_compare_entry(ce, info->prev,
+			     info->name, info->namelen, info->mode))
 		return 0;
 	/*
 	 * If ce (blob) is the same name as the path (which is a tree
@@ -797,20 +953,33 @@ static int ce_in_traverse_path(const str
 	return (info->pathlen < ce_namelen(ce));
 }
 
-static struct cache_entry *create_ce_entry(const struct traverse_info *info, const struct name_entry *n, int stage)
-{
-	int len = traverse_path_len(info, n);
-	struct cache_entry *ce = xcalloc(1, cache_entry_size(len));
+static struct cache_entry *create_ce_entry(const struct traverse_info *info,
+	const struct name_entry *n,
+	int stage,
+	struct index_state *istate,
+	int is_transient)
+{
+	size_t len = traverse_path_len(info, tree_entry_len(n));
+	struct cache_entry *ce =
+		is_transient ?
+		make_empty_transient_cache_entry(len) :
+		make_empty_cache_entry(istate, len);
 
 	ce->ce_mode = create_ce_mode(n->mode);
 	ce->ce_flags = create_ce_flags(stage);
 	ce->ce_namelen = len;
-	oidcpy(&ce->oid, n->oid);
-	make_traverse_path(ce->name, info, n);
+	oidcpy(&ce->oid, &n->oid);
+	/* len+1 because the cache_entry allocates space for NUL */
+	make_traverse_path(ce->name, len + 1, info, n->path, n->pathlen);
 
 	return ce;
 }
 
+/*
+ * Note that traverse_by_cache_tree() duplicates some logic in this function
+ * without actually calling it. If you change the logic here you may need to
+ * check and change there as well.
+ */
 static int unpack_nondirectories(int n, unsigned long mask,
 				 unsigned long dirmask,
 				 struct cache_entry **src,
@@ -846,7 +1015,15 @@ static int unpack_nondirectories(int n,
 			stage = 3;
 		else
 			stage = 2;
-		src[i + o->merge] = create_ce_entry(info, names + i, stage);
+
+		/*
+		 * If the merge bit is set, then the cache entries are
+		 * discarded in the following block.  In this case,
+		 * construct "transient" cache_entries, as they are
+		 * not stored in the index.  otherwise construct the
+		 * cache entry from the index aware logic.
+		 */
+		src[i + o->merge] = create_ce_entry(info, names + i, stage, &o->result, o->merge);
 	}
 
 	if (o->merge) {
@@ -855,7 +1032,7 @@ static int unpack_nondirectories(int n,
 		for (i = 0; i < n; i++) {
 			struct cache_entry *ce = src[i + o->merge];
 			if (ce != o->df_conflict_entry)
-				free(ce);
+				discard_cache_entry(ce);
 		}
 		return rc;
 	}
@@ -871,7 +1048,7 @@ static int unpack_nondirectories(int n,
 static int unpack_failed(struct unpack_trees_options *o, const char *message)
 {
 	discard_index(&o->result);
-	if (!o->gently && !o->exiting_early) {
+	if (!o->quiet && !o->exiting_early) {
 		if (message)
 			return error("%s", message);
 		return -1;
@@ -886,13 +1063,12 @@ static int unpack_failed(struct unpack_t
  * the directory.
  */
 static int find_cache_pos(struct traverse_info *info,
-			  const struct name_entry *p)
+			  const char *p, size_t p_len)
 {
 	int pos;
 	struct unpack_trees_options *o = info->data;
 	struct index_state *index = o->src_index;
 	int pfxlen = info->pathlen;
-	int p_len = tree_entry_len(p);
 
 	for (pos = o->cache_bottom; pos < index->cache_nr; pos++) {
 		const struct cache_entry *ce = index->cache[pos];
@@ -928,7 +1104,7 @@ static int find_cache_pos(struct travers
 			ce_len = ce_slash - ce_name;
 		else
 			ce_len = ce_namelen(ce) - pfxlen;
-		cmp = name_compare(p->path, p_len, ce_name, ce_len);
+		cmp = name_compare(p, p_len, ce_name, ce_len);
 		/*
 		 * Exact match; if we have a directory we need to
 		 * delay returning it.
@@ -943,7 +1119,7 @@ static int find_cache_pos(struct travers
 		 * E.g.  ce_name == "t-i", and p->path == "t"; we may
 		 * have "t/a" in the index.
 		 */
-		if (p_len < ce_len && !memcmp(ce_name, p->path, p_len) &&
+		if (p_len < ce_len && !memcmp(ce_name, p, p_len) &&
 		    ce_name[p_len] < '/')
 			continue; /* keep looking */
 		break;
@@ -954,7 +1130,7 @@ static int find_cache_pos(struct travers
 static struct cache_entry *find_cache_entry(struct traverse_info *info,
 					    const struct name_entry *p)
 {
-	int pos = find_cache_pos(info, p);
+	int pos = find_cache_pos(info, p->path, p->pathlen);
 	struct unpack_trees_options *o = info->data;
 
 	if (0 <= pos)
@@ -967,10 +1143,10 @@ static void debug_path(struct traverse_i
 {
 	if (info->prev) {
 		debug_path(info->prev);
-		if (*info->prev->name.path)
+		if (*info->prev->name)
 			putchar('/');
 	}
-	printf("%s", info->name.path);
+	printf("%s", info->name);
 }
 
 static void debug_name_entry(int i, struct name_entry *n)
@@ -995,6 +1171,11 @@ static void debug_unpack_callback(int n,
 		debug_name_entry(i, names + i);
 }
 
+/*
+ * Note that traverse_by_cache_tree() duplicates some logic in this function
+ * without actually calling it. If you change the logic here you may need to
+ * check and change there as well.
+ */
 static int unpack_callback(int n, unsigned long mask, unsigned long dirmask, struct name_entry *names, struct traverse_info *info)
 {
 	struct cache_entry *src[MAX_UNPACK_TREES + 1] = { NULL, };
@@ -1085,29 +1266,38 @@ static int unpack_callback(int n, unsign
 	return mask;
 }
 
-static int clear_ce_flags_1(struct cache_entry **cache, int nr,
+static int clear_ce_flags_1(struct index_state *istate,
+			    struct cache_entry **cache, int nr,
 			    struct strbuf *prefix,
 			    int select_mask, int clear_mask,
-			    struct exclude_list *el, int defval);
+			    struct pattern_list *pl,
+			    enum pattern_match_result default_match,
+			    int progress_nr);
 
 /* Whole directory matching */
-static int clear_ce_flags_dir(struct cache_entry **cache, int nr,
+static int clear_ce_flags_dir(struct index_state *istate,
+			      struct cache_entry **cache, int nr,
 			      struct strbuf *prefix,
 			      char *basename,
 			      int select_mask, int clear_mask,
-			      struct exclude_list *el, int defval)
+			      struct pattern_list *pl,
+			      enum pattern_match_result default_match,
+			      int progress_nr)
 {
 	struct cache_entry **cache_end;
 	int dtype = DT_DIR;
-	int ret = is_excluded_from_list(prefix->buf, prefix->len,
-					basename, &dtype, el, &the_index);
 	int rc;
+	enum pattern_match_result ret, orig_ret;
+	orig_ret = path_matches_pattern_list(prefix->buf, prefix->len,
+					     basename, &dtype, pl, istate);
 
 	strbuf_addch(prefix, '/');
 
 	/* If undecided, use matching result of parent dir in defval */
-	if (ret < 0)
-		ret = defval;
+	if (orig_ret == UNDECIDED)
+		ret = default_match;
+	else
+		ret = orig_ret;
 
 	for (cache_end = cache; cache_end != cache + nr; cache_end++) {
 		struct cache_entry *ce = *cache_end;
@@ -1115,24 +1305,31 @@ static int clear_ce_flags_dir(struct cac
 			break;
 	}
 
-	/*
-	 * TODO: check el, if there are no patterns that may conflict
-	 * with ret (iow, we know in advance the incl/excl
-	 * decision for the entire directory), clear flag here without
-	 * calling clear_ce_flags_1(). That function will call
-	 * the expensive is_excluded_from_list() on every entry.
-	 */
-	rc = clear_ce_flags_1(cache, cache_end - cache,
-			      prefix,
-			      select_mask, clear_mask,
-			      el, ret);
+	if (pl->use_cone_patterns && orig_ret == MATCHED_RECURSIVE) {
+		struct cache_entry **ce = cache;
+		rc = cache_end - cache;
+
+		while (ce < cache_end) {
+			(*ce)->ce_flags &= ~clear_mask;
+			ce++;
+		}
+	} else if (pl->use_cone_patterns && orig_ret == NOT_MATCHED) {
+		rc = cache_end - cache;
+	} else {
+		rc = clear_ce_flags_1(istate, cache, cache_end - cache,
+				      prefix,
+				      select_mask, clear_mask,
+				      pl, ret,
+				      progress_nr);
+	}
+
 	strbuf_setlen(prefix, prefix->len - 1);
 	return rc;
 }
 
 /*
  * Traverse the index, find every entry that matches according to
- * o->el. Do "ce_flags &= ~clear_mask" on those entries. Return the
+ * o->pl. Do "ce_flags &= ~clear_mask" on those entries. Return the
  * number of traversed entries.
  *
  * If select_mask is non-zero, only entries whose ce_flags has on of
@@ -1145,10 +1342,13 @@ static int clear_ce_flags_dir(struct cac
  *   cache[0]->name[0..(prefix_len-1)]
  * Top level path has prefix_len zero.
  */
-static int clear_ce_flags_1(struct cache_entry **cache, int nr,
+static int clear_ce_flags_1(struct index_state *istate,
+			    struct cache_entry **cache, int nr,
 			    struct strbuf *prefix,
 			    int select_mask, int clear_mask,
-			    struct exclude_list *el, int defval)
+			    struct pattern_list *pl,
+			    enum pattern_match_result default_match,
+			    int progress_nr)
 {
 	struct cache_entry **cache_end = cache + nr;
 
@@ -1159,10 +1359,14 @@ static int clear_ce_flags_1(struct cache
 	while(cache != cache_end) {
 		struct cache_entry *ce = *cache;
 		const char *name, *slash;
-		int len, dtype, ret;
+		int len, dtype;
+		enum pattern_match_result ret;
+
+		display_progress(istate->progress, progress_nr);
 
 		if (select_mask && !(ce->ce_flags & select_mask)) {
 			cache++;
+			progress_nr++;
 			continue;
 		}
 
@@ -1179,60 +1383,88 @@ static int clear_ce_flags_1(struct cache
 			len = slash - name;
 			strbuf_add(prefix, name, len);
 
-			processed = clear_ce_flags_dir(cache, cache_end - cache,
+			processed = clear_ce_flags_dir(istate, cache, cache_end - cache,
 						       prefix,
 						       prefix->buf + prefix->len - len,
 						       select_mask, clear_mask,
-						       el, defval);
+						       pl, default_match,
+						       progress_nr);
 
 			/* clear_c_f_dir eats a whole dir already? */
 			if (processed) {
 				cache += processed;
+				progress_nr += processed;
 				strbuf_setlen(prefix, prefix->len - len);
 				continue;
 			}
 
 			strbuf_addch(prefix, '/');
-			cache += clear_ce_flags_1(cache, cache_end - cache,
-						  prefix,
-						  select_mask, clear_mask, el, defval);
+			processed = clear_ce_flags_1(istate, cache, cache_end - cache,
+						     prefix,
+						     select_mask, clear_mask, pl,
+						     default_match, progress_nr);
+
+			cache += processed;
+			progress_nr += processed;
+
 			strbuf_setlen(prefix, prefix->len - len - 1);
 			continue;
 		}
 
 		/* Non-directory */
 		dtype = ce_to_dtype(ce);
-		ret = is_excluded_from_list(ce->name, ce_namelen(ce),
-					    name, &dtype, el, &the_index);
-		if (ret < 0)
-			ret = defval;
-		if (ret > 0)
+		ret = path_matches_pattern_list(ce->name,
+						ce_namelen(ce),
+						name, &dtype, pl, istate);
+		if (ret == UNDECIDED)
+			ret = default_match;
+		if (ret == MATCHED)
 			ce->ce_flags &= ~clear_mask;
 		cache++;
+		progress_nr++;
 	}
+
+	display_progress(istate->progress, progress_nr);
 	return nr - (cache_end - cache);
 }
 
-static int clear_ce_flags(struct cache_entry **cache, int nr,
-			    int select_mask, int clear_mask,
-			    struct exclude_list *el)
+static int clear_ce_flags(struct index_state *istate,
+			  int select_mask, int clear_mask,
+			  struct pattern_list *pl,
+			  int show_progress)
 {
 	static struct strbuf prefix = STRBUF_INIT;
+	char label[100];
+	int rval;
 
 	strbuf_reset(&prefix);
-
-	return clear_ce_flags_1(cache, nr,
+	if (show_progress)
+		istate->progress = start_delayed_progress(
+					_("Updating index flags"),
+					istate->cache_nr);
+
+	xsnprintf(label, sizeof(label), "clear_ce_flags(0x%08lx,0x%08lx)",
+		  (unsigned long)select_mask, (unsigned long)clear_mask);
+	trace2_region_enter("unpack_trees", label, the_repository);
+	rval = clear_ce_flags_1(istate,
+				istate->cache,
+				istate->cache_nr,
 				&prefix,
 				select_mask, clear_mask,
-				el, 0);
+				pl, 0, 0);
+	trace2_region_leave("unpack_trees", label, the_repository);
+
+	stop_progress(&istate->progress);
+	return rval;
 }
 
 /*
  * Set/Clear CE_NEW_SKIP_WORKTREE according to $GIT_DIR/info/sparse-checkout
  */
-static void mark_new_skip_worktree(struct exclude_list *el,
-				   struct index_state *the_index,
-				   int select_flag, int skip_wt_flag)
+static void mark_new_skip_worktree(struct pattern_list *pl,
+				   struct index_state *istate,
+				   int select_flag, int skip_wt_flag,
+				   int show_progress)
 {
 	int i;
 
@@ -1240,13 +1472,13 @@ static void mark_new_skip_worktree(struc
 	 * 1. Pretend the narrowest worktree: only unmerged entries
 	 * are checked out
 	 */
-	for (i = 0; i < the_index->cache_nr; i++) {
-		struct cache_entry *ce = the_index->cache[i];
+	for (i = 0; i < istate->cache_nr; i++) {
+		struct cache_entry *ce = istate->cache[i];
 
 		if (select_flag && !(ce->ce_flags & select_flag))
 			continue;
 
-		if (!ce_stage(ce))
+		if (!ce_stage(ce) && !(ce->ce_flags & CE_CONFLICTED))
 			ce->ce_flags |= skip_wt_flag;
 		else
 			ce->ce_flags &= ~skip_wt_flag;
@@ -1256,8 +1488,7 @@ static void mark_new_skip_worktree(struc
 	 * 2. Widen worktree according to sparse-checkout file.
 	 * Matched entries will have skip_wt_flag cleared (i.e. "in")
 	 */
-	clear_ce_flags(the_index->cache, the_index->cache_nr,
-		       select_flag, skip_wt_flag, el);
+	clear_ce_flags(istate, select_flag, skip_wt_flag, pl, show_progress);
 }
 
 static int verify_absent(const struct cache_entry *,
@@ -1273,20 +1504,22 @@ int unpack_trees(unsigned len, struct tr
 {
 	int i, ret;
 	static struct cache_entry *dfc;
-	struct exclude_list el;
+	struct pattern_list pl;
 
 	if (len > MAX_UNPACK_TREES)
 		die("unpack_trees takes at most %d trees", MAX_UNPACK_TREES);
 
-	memset(&el, 0, sizeof(el));
+	trace_performance_enter();
+	memset(&pl, 0, sizeof(pl));
 	if (!core_apply_sparse_checkout || !o->update)
 		o->skip_sparse_checkout = 1;
-	if (!o->skip_sparse_checkout) {
+	if (!o->skip_sparse_checkout && !o->pl) {
 		char *sparse = git_pathdup("info/sparse-checkout");
-		if (add_excludes_from_file_to_list(sparse, "", 0, &el, NULL) < 0)
+		pl.use_cone_patterns = core_sparse_checkout_cone;
+		if (add_patterns_from_file_to_list(sparse, "", 0, &pl, NULL) < 0)
 			o->skip_sparse_checkout = 1;
 		else
-			o->el = &el;
+			o->pl = &pl;
 		free(sparse);
 	}
 
@@ -1313,11 +1546,15 @@ int unpack_trees(unsigned len, struct tr
 	o->merge_size = len;
 	mark_all_ce_unused(o->src_index);
 
+	if (o->src_index->fsmonitor_last_update)
+		o->result.fsmonitor_last_update = o->src_index->fsmonitor_last_update;
+
 	/*
 	 * Sparse checkout loop #1: set NEW_SKIP_WORKTREE on existing entries
 	 */
 	if (!o->skip_sparse_checkout)
-		mark_new_skip_worktree(o->el, o->src_index, 0, CE_NEW_SKIP_WORKTREE);
+		mark_new_skip_worktree(o->pl, o->src_index, 0,
+				       CE_NEW_SKIP_WORKTREE, o->verbose_update);
 
 	if (!dfc)
 		dfc = xcalloc(1, cache_entry_size(0));
@@ -1350,7 +1587,10 @@ int unpack_trees(unsigned len, struct tr
 			}
 		}
 
-		if (traverse_trees(len, t, &info) < 0)
+		trace_performance_enter();
+		ret = traverse_trees(o->src_index, len, t, &info);
+		trace_performance_leave("traverse_trees");
+		if (ret < 0)
 			goto return_failed;
 	}
 
@@ -1379,7 +1619,9 @@ int unpack_trees(unsigned len, struct tr
 		 * If the will have NEW_SKIP_WORKTREE, also set CE_SKIP_WORKTREE
 		 * so apply_sparse_checkout() won't attempt to remove it from worktree
 		 */
-		mark_new_skip_worktree(o->el, &o->result, CE_ADDED, CE_SKIP_WORKTREE | CE_NEW_SKIP_WORKTREE);
+		mark_new_skip_worktree(o->pl, &o->result,
+				       CE_ADDED, CE_SKIP_WORKTREE | CE_NEW_SKIP_WORKTREE,
+				       o->verbose_update);
 
 		ret = 0;
 		for (i = 0; i < o->result.cache_nr; i++) {
@@ -1425,7 +1667,10 @@ int unpack_trees(unsigned len, struct tr
 
 	ret = check_updates(o) ? (-2) : 0;
 	if (o->dst_index) {
+		move_index_extensions(&o->result, o->src_index);
 		if (!ret) {
+			if (git_env_bool("GIT_TEST_CHECK_CACHE_TREE", 0))
+				cache_tree_verify(the_repository, &o->result);
 			if (!o->result.cache_tree)
 				o->result.cache_tree = cache_tree();
 			if (!cache_tree_fully_valid(o->result.cache_tree))
@@ -1433,7 +1678,8 @@ int unpack_trees(unsigned len, struct tr
 						  WRITE_TREE_SILENT |
 						  WRITE_TREE_REPAIR);
 		}
-		move_index_extensions(&o->result, o->src_index);
+
+		o->result.updated_workdir = 1;
 		discard_index(o->dst_index);
 		*o->dst_index = o->result;
 	} else {
@@ -1442,7 +1688,9 @@ int unpack_trees(unsigned len, struct tr
 	o->src_index = NULL;
 
 done:
-	clear_exclude_list(&el);
+	trace_performance_leave("unpack_trees");
+	if (!o->keep_pattern_list)
+		clear_pattern_list(&pl);
 	return ret;
 
 return_failed:
@@ -1460,8 +1708,7 @@ return_failed:
 static int reject_merge(const struct cache_entry *ce,
 			struct unpack_trees_options *o)
 {
-	return o->gently ? -1 :
-		add_rejected_path(o, ERROR_WOULD_OVERWRITE, ce->name);
+	return add_rejected_path(o, ERROR_WOULD_OVERWRITE, ce->name);
 }
 
 static int same(const struct cache_entry *a, const struct cache_entry *b)
@@ -1473,7 +1720,7 @@ static int same(const struct cache_entry
 	if ((a->ce_flags | b->ce_flags) & CE_CONFLICTED)
 		return 0;
 	return a->ce_mode == b->ce_mode &&
-	       !oidcmp(&a->oid, &b->oid);
+	       oideq(&a->oid, &b->oid);
 }
 
 
@@ -1508,8 +1755,7 @@ static int verify_uptodate_1(const struc
 			int r = check_submodule_move_head(ce,
 				"HEAD", oid_to_hex(&ce->oid), o);
 			if (r)
-				return o->gently ? -1 :
-					add_rejected_path(o, error_type, ce->name);
+				return add_rejected_path(o, error_type, ce->name);
 			return 0;
 		}
 
@@ -1527,8 +1773,7 @@ static int verify_uptodate_1(const struc
 	}
 	if (errno == ENOENT)
 		return 0;
-	return o->gently ? -1 :
-		add_rejected_path(o, error_type, ce->name);
+	return add_rejected_path(o, error_type, ce->name);
 }
 
 int verify_uptodate(const struct cache_entry *ce,
@@ -1545,6 +1790,17 @@ static int verify_uptodate_sparse(const
 	return verify_uptodate_1(ce, o, ERROR_SPARSE_NOT_UPTODATE_FILE);
 }
 
+/*
+ * TODO: We should actually invalidate o->result, not src_index [1].
+ * But since cache tree and untracked cache both are not copied to
+ * o->result until unpacking is complete, we invalidate them on
+ * src_index instead with the assumption that they will be copied to
+ * dst_index at the end.
+ *
+ * [1] src_index->cache_tree is also used in unpack_callback() so if
+ * we invalidate o->result, we need to update it to use
+ * o->result.cache_tree as well.
+ */
 static void invalidate_ce_path(const struct cache_entry *ce,
 			       struct unpack_trees_options *o)
 {
@@ -1563,7 +1819,6 @@ static void invalidate_ce_path(const str
  */
 static int verify_clean_submodule(const char *old_sha1,
 				  const struct cache_entry *ce,
-				  enum unpack_trees_error_types error_type,
 				  struct unpack_trees_options *o)
 {
 	if (!submodule_from_ce(ce))
@@ -1574,7 +1829,6 @@ static int verify_clean_submodule(const
 }
 
 static int verify_clean_subdirectory(const struct cache_entry *ce,
-				     enum unpack_trees_error_types error_type,
 				     struct unpack_trees_options *o)
 {
 	/*
@@ -1594,10 +1848,10 @@ static int verify_clean_subdirectory(con
 		 * If we are not going to update the submodule, then
 		 * we don't care.
 		 */
-		if (!sub_head && !oidcmp(&oid, &ce->oid))
+		if (!sub_head && oideq(&oid, &ce->oid))
 			return 0;
 		return verify_clean_submodule(sub_head ? NULL : oid_to_hex(&oid),
-					      ce, error_type, o);
+					      ce, o);
 	}
 
 	/*
@@ -1622,6 +1876,7 @@ static int verify_clean_subdirectory(con
 			if (verify_uptodate(ce2, o))
 				return -1;
 			add_entry(o, ce2, CE_REMOVE, 0);
+			invalidate_ce_path(ce, o);
 			mark_ce_used(ce2, o);
 		}
 		cnt++;
@@ -1636,10 +1891,9 @@ static int verify_clean_subdirectory(con
 	memset(&d, 0, sizeof(d));
 	if (o->dir)
 		d.exclude_per_dir = o->dir->exclude_per_dir;
-	i = read_directory(&d, &the_index, pathbuf, namelen+1, NULL);
+	i = read_directory(&d, o->src_index, pathbuf, namelen+1, NULL);
 	if (i)
-		return o->gently ? -1 :
-			add_rejected_path(o, ERROR_NOT_UPTODATE_DIR, ce->name);
+		return add_rejected_path(o, ERROR_NOT_UPTODATE_DIR, ce->name);
 	free(pathbuf);
 	return cnt;
 }
@@ -1678,7 +1932,7 @@ static int check_ok_to_remove(const char
 		return 0;
 
 	if (o->dir &&
-	    is_excluded(o->dir, &the_index, name, &dtype))
+	    is_excluded(o->dir, o->src_index, name, &dtype))
 		/*
 		 * ce->name is explicitly excluded, so it is Ok to
 		 * overwrite it.
@@ -1692,7 +1946,7 @@ static int check_ok_to_remove(const char
 		 * files that are in "foo/" we would lose
 		 * them.
 		 */
-		if (verify_clean_subdirectory(ce, error_type, o) < 0)
+		if (verify_clean_subdirectory(ce, o) < 0)
 			return -1;
 		return 0;
 	}
@@ -1708,8 +1962,7 @@ static int check_ok_to_remove(const char
 			return 0;
 	}
 
-	return o->gently ? -1 :
-		add_rejected_path(o, error_type, name);
+	return add_rejected_path(o, error_type, name);
 }
 
 /*
@@ -1787,7 +2040,7 @@ static int merged_entry(const struct cac
 			struct unpack_trees_options *o)
 {
 	int update = CE_UPDATE;
-	struct cache_entry *merge = dup_entry(ce);
+	struct cache_entry *merge = dup_cache_entry(ce, &o->result);
 
 	if (!old) {
 		/*
@@ -1807,7 +2060,7 @@ static int merged_entry(const struct cac
 
 		if (verify_absent(merge,
 				  ERROR_WOULD_LOSE_UNTRACKED_OVERWRITTEN, o)) {
-			free(merge);
+			discard_cache_entry(merge);
 			return -1;
 		}
 		invalidate_ce_path(merge, o);
@@ -1833,7 +2086,7 @@ static int merged_entry(const struct cac
 			update = 0;
 		} else {
 			if (verify_uptodate(old, o)) {
-				free(merge);
+				discard_cache_entry(merge);
 				return -1;
 			}
 			/* Migrate old flags over */
@@ -1856,7 +2109,8 @@ static int merged_entry(const struct cac
 		invalidate_ce_path(old, o);
 	}
 
-	do_add_entry(o, merge, update, CE_STAGEMASK);
+	if (do_add_entry(o, merge, update, CE_STAGEMASK) < 0)
+		return -1;
 	return 1;
 }
 
@@ -1881,6 +2135,8 @@ static int keep_entry(const struct cache
 		      struct unpack_trees_options *o)
 {
 	add_entry(o, ce, 0, 0);
+	if (ce_stage(ce))
+		invalidate_ce_path(ce, o);
 	return 1;
 }
 
@@ -2147,7 +2403,7 @@ int bind_merge(const struct cache_entry
 		return error("Cannot do a bind merge of %d trees",
 			     o->merge_size);
 	if (a && old)
-		return o->gently ? -1 :
+		return o->quiet ? -1 :
 			error(ERRORMSG(o, ERROR_BIND_OVERLAP),
 			      super_prefixed(a->name),
 			      super_prefixed(old->name));
@@ -2178,7 +2434,8 @@ int oneway_merge(const struct cache_entr
 
 	if (old && same(old, a)) {
 		int update = 0;
-		if (o->reset && o->update && !ce_uptodate(old) && !ce_skip_worktree(old)) {
+		if (o->reset && o->update && !ce_uptodate(old) && !ce_skip_worktree(old) &&
+			!(old->ce_flags & CE_FSMONITOR_VALID)) {
 			struct stat st;
 			if (lstat(old->name, &st) ||
 			    ie_match_stat(o->src_index, old, &st, CE_MATCH_IGNORE_VALID|CE_MATCH_IGNORE_SKIP_WORKTREE))
@@ -2187,7 +2444,7 @@ int oneway_merge(const struct cache_entr
 		if (o->update && S_ISGITLINK(old->ce_mode) &&
 		    should_update_submodules() && !verify_uptodate(old, o))
 			update |= CE_UPDATE;
-		add_entry(o, old, update, 0);
+		add_entry(o, old, update, CE_STAGEMASK);
 		return 0;
 	}
 	return merged_entry(a, old, o);
diff -pruN 1.2.1+git2.18.0-1/git/unpack-trees.h 1.2.3+git2.25.1-1/git/unpack-trees.h
--- 1.2.1+git2.18.0-1/git/unpack-trees.h	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/unpack-trees.h	2020-02-17 04:47:35.000000000 +0000
@@ -1,13 +1,16 @@
 #ifndef UNPACK_TREES_H
 #define UNPACK_TREES_H
 
-#include "tree-walk.h"
+#include "cache.h"
 #include "argv-array.h"
+#include "string-list.h"
+#include "tree-walk.h"
 
 #define MAX_UNPACK_TREES 8
 
+struct cache_entry;
 struct unpack_trees_options;
-struct exclude_list;
+struct pattern_list;
 
 typedef int (*merge_fn_t)(const struct cache_entry * const *src,
 		struct unpack_trees_options *options);
@@ -42,6 +45,7 @@ struct unpack_trees_options {
 	unsigned int reset,
 		     merge,
 		     update,
+		     clone,
 		     index_only,
 		     nontrivial_merge,
 		     trivial_merges_only,
@@ -52,10 +56,11 @@ struct unpack_trees_options {
 		     diff_index_cached,
 		     debug_unpack,
 		     skip_sparse_checkout,
-		     gently,
+		     quiet,
 		     exiting_early,
 		     show_all_errors,
-		     dry_run;
+		     dry_run,
+		     keep_pattern_list;
 	const char *prefix;
 	int cache_bottom;
 	struct dir_struct *dir;
@@ -79,11 +84,11 @@ struct unpack_trees_options {
 	struct index_state *src_index;
 	struct index_state result;
 
-	struct exclude_list *el; /* for internal use */
+	struct pattern_list *pl; /* for internal use */
 };
 
-extern int unpack_trees(unsigned n, struct tree_desc *t,
-		struct unpack_trees_options *options);
+int unpack_trees(unsigned n, struct tree_desc *t,
+		 struct unpack_trees_options *options);
 
 int verify_uptodate(const struct cache_entry *ce,
 		    struct unpack_trees_options *o);
diff -pruN 1.2.1+git2.18.0-1/git/upload-pack.c 1.2.3+git2.25.1-1/git/upload-pack.c
--- 1.2.1+git2.18.0-1/git/upload-pack.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/upload-pack.c	2020-02-17 04:47:35.000000000 +0000
@@ -3,6 +3,8 @@
 #include "refs.h"
 #include "pkt-line.h"
 #include "sideband.h"
+#include "repository.h"
+#include "object-store.h"
 #include "tag.h"
 #include "object.h"
 #include "commit.h"
@@ -22,22 +24,25 @@
 #include "quote.h"
 #include "upload-pack.h"
 #include "serve.h"
+#include "commit-graph.h"
+#include "commit-reach.h"
 
 /* Remember to update object flag allocation in object.h */
 #define THEY_HAVE	(1u << 11)
 #define OUR_REF		(1u << 12)
 #define WANTED		(1u << 13)
 #define COMMON_KNOWN	(1u << 14)
-#define REACHABLE	(1u << 15)
 
 #define SHALLOW		(1u << 16)
 #define NOT_SHALLOW	(1u << 17)
 #define CLIENT_SHALLOW	(1u << 18)
 #define HIDDEN_REF	(1u << 19)
 
+#define ALL_FLAGS (THEY_HAVE | OUR_REF | WANTED | COMMON_KNOWN | SHALLOW | \
+		NOT_SHALLOW | CLIENT_SHALLOW | HIDDEN_REF)
+
 static timestamp_t oldest_have;
 
-static int deepen_relative;
 static int multi_ack;
 static int no_done;
 static int use_thin_pack, use_ofs_delta, use_include_tag;
@@ -50,8 +55,6 @@ static int no_progress, daemon_mode;
 #define ALLOW_ANY_SHA1	07
 static unsigned int allow_unadvertised_object_request;
 static int shallow_nr;
-static struct object_array have_obj;
-static struct object_array want_obj;
 static struct object_array extra_edge_obj;
 static unsigned int timeout;
 static int keepalive = 5;
@@ -64,8 +67,11 @@ static const char *pack_objects_hook;
 
 static int filter_capability_requested;
 static int allow_filter;
+static int allow_ref_in_want;
 static struct list_objects_filter_options filter_options;
 
+static int allow_sideband_all;
+
 static void reset_timeout(void)
 {
 	alarm(timeout);
@@ -96,7 +102,8 @@ static int write_one_shallow(const struc
 	return 0;
 }
 
-static void create_pack_file(void)
+static void create_pack_file(const struct object_array *have_obj,
+			     const struct object_array *want_obj)
 {
 	struct child_process pack_objects = CHILD_PROCESS_INIT;
 	char data[8193], progress[128];
@@ -133,15 +140,17 @@ static void create_pack_file(void)
 		argv_array_push(&pack_objects.args, "--delta-base-offset");
 	if (use_include_tag)
 		argv_array_push(&pack_objects.args, "--include-tag");
-	if (filter_options.filter_spec) {
+	if (filter_options.choice) {
+		const char *spec =
+			expand_list_objects_filter_spec(&filter_options);
 		if (pack_objects.use_shell) {
 			struct strbuf buf = STRBUF_INIT;
-			sq_quote_buf(&buf, filter_options.filter_spec);
+			sq_quote_buf(&buf, spec);
 			argv_array_pushf(&pack_objects.args, "--filter=%s", buf.buf);
 			strbuf_release(&buf);
 		} else {
 			argv_array_pushf(&pack_objects.args, "--filter=%s",
-					 filter_options.filter_spec);
+					 spec);
 		}
 	}
 
@@ -157,13 +166,13 @@ static void create_pack_file(void)
 	if (shallow_nr)
 		for_each_commit_graft(write_one_shallow, pipe_fd);
 
-	for (i = 0; i < want_obj.nr; i++)
+	for (i = 0; i < want_obj->nr; i++)
 		fprintf(pipe_fd, "%s\n",
-			oid_to_hex(&want_obj.objects[i].item->oid));
+			oid_to_hex(&want_obj->objects[i].item->oid));
 	fprintf(pipe_fd, "--not\n");
-	for (i = 0; i < have_obj.nr; i++)
+	for (i = 0; i < have_obj->nr; i++)
 		fprintf(pipe_fd, "%s\n",
-			oid_to_hex(&have_obj.objects[i].item->oid));
+			oid_to_hex(&have_obj->objects[i].item->oid));
 	for (i = 0; i < extra_edge_obj.nr; i++)
 		fprintf(pipe_fd, "%s\n",
 			oid_to_hex(&extra_edge_obj.objects[i].item->oid));
@@ -300,7 +309,8 @@ static void create_pack_file(void)
 	die("git upload-pack: %s", abort_msg);
 }
 
-static int got_oid(const char *hex, struct object_id *oid)
+static int got_oid(const char *hex, struct object_id *oid,
+		   struct object_array *have_obj)
 {
 	struct object *o;
 	int we_knew_they_have = 0;
@@ -310,7 +320,7 @@ static int got_oid(const char *hex, stru
 	if (!has_object_file(oid))
 		return -1;
 
-	o = parse_object(oid);
+	o = parse_object(the_repository, oid);
 	if (!o)
 		die("oops (%s)", oid_to_hex(oid));
 	if (o->type == OBJ_COMMIT) {
@@ -328,73 +338,28 @@ static int got_oid(const char *hex, stru
 			parents->item->object.flags |= THEY_HAVE;
 	}
 	if (!we_knew_they_have) {
-		add_object_array(o, NULL, &have_obj);
+		add_object_array(o, NULL, have_obj);
 		return 1;
 	}
 	return 0;
 }
 
-static int reachable(struct commit *want)
-{
-	struct prio_queue work = { compare_commits_by_commit_date };
-
-	prio_queue_put(&work, want);
-	while (work.nr) {
-		struct commit_list *list;
-		struct commit *commit = prio_queue_get(&work);
-
-		if (commit->object.flags & THEY_HAVE) {
-			want->object.flags |= COMMON_KNOWN;
-			break;
-		}
-		if (!commit->object.parsed)
-			parse_object(&commit->object.oid);
-		if (commit->object.flags & REACHABLE)
-			continue;
-		commit->object.flags |= REACHABLE;
-		if (commit->date < oldest_have)
-			continue;
-		for (list = commit->parents; list; list = list->next) {
-			struct commit *parent = list->item;
-			if (!(parent->object.flags & REACHABLE))
-				prio_queue_put(&work, parent);
-		}
-	}
-	want->object.flags |= REACHABLE;
-	clear_commit_marks(want, REACHABLE);
-	clear_prio_queue(&work);
-	return (want->object.flags & COMMON_KNOWN);
-}
-
-static int ok_to_give_up(void)
+static int ok_to_give_up(const struct object_array *have_obj,
+			 struct object_array *want_obj)
 {
-	int i;
+	uint32_t min_generation = GENERATION_NUMBER_ZERO;
 
-	if (!have_obj.nr)
+	if (!have_obj->nr)
 		return 0;
 
-	for (i = 0; i < want_obj.nr; i++) {
-		struct object *want = want_obj.objects[i].item;
-
-		if (want->flags & COMMON_KNOWN)
-			continue;
-		want = deref_tag(want, "a want line", 0);
-		if (!want || want->type != OBJ_COMMIT) {
-			/* no way to tell if this is reachable by
-			 * looking at the ancestry chain alone, so
-			 * leave a note to ourselves not to worry about
-			 * this object anymore.
-			 */
-			want_obj.objects[i].item->flags |= COMMON_KNOWN;
-			continue;
-		}
-		if (!reachable((struct commit *)want))
-			return 0;
-	}
-	return 1;
+	return can_all_from_reach_with_flag(want_obj, THEY_HAVE,
+					    COMMON_KNOWN, oldest_have,
+					    min_generation);
 }
 
-static int get_common_commits(void)
+static int get_common_commits(struct packet_reader *reader,
+			      struct object_array *have_obj,
+			      struct object_array *want_obj)
 {
 	struct object_id oid;
 	char last_hex[GIT_MAX_HEXSZ + 1];
@@ -405,18 +370,17 @@ static int get_common_commits(void)
 	save_commit_buffer = 0;
 
 	for (;;) {
-		char *line = packet_read_line(0, NULL);
 		const char *arg;
 
 		reset_timeout();
 
-		if (!line) {
+		if (packet_reader_read(reader) != PACKET_READ_NORMAL) {
 			if (multi_ack == 2 && got_common
-			    && !got_other && ok_to_give_up()) {
+			    && !got_other && ok_to_give_up(have_obj, want_obj)) {
 				sent_ready = 1;
 				packet_write_fmt(1, "ACK %s ready\n", last_hex);
 			}
-			if (have_obj.nr == 0 || multi_ack)
+			if (have_obj->nr == 0 || multi_ack)
 				packet_write_fmt(1, "NAK\n");
 
 			if (no_done && sent_ready) {
@@ -429,11 +393,11 @@ static int get_common_commits(void)
 			got_other = 0;
 			continue;
 		}
-		if (skip_prefix(line, "have ", &arg)) {
-			switch (got_oid(arg, &oid)) {
+		if (skip_prefix(reader->line, "have ", &arg)) {
+			switch (got_oid(arg, &oid, have_obj)) {
 			case -1: /* they have what we do not */
 				got_other = 1;
-				if (multi_ack && ok_to_give_up()) {
+				if (multi_ack && ok_to_give_up(have_obj, want_obj)) {
 					const char *hex = oid_to_hex(&oid);
 					if (multi_ack == 2) {
 						sent_ready = 1;
@@ -449,14 +413,14 @@ static int get_common_commits(void)
 					packet_write_fmt(1, "ACK %s common\n", last_hex);
 				else if (multi_ack)
 					packet_write_fmt(1, "ACK %s continue\n", last_hex);
-				else if (have_obj.nr == 1)
+				else if (have_obj->nr == 1)
 					packet_write_fmt(1, "ACK %s\n", last_hex);
 				break;
 			}
 			continue;
 		}
-		if (!strcmp(line, "done")) {
-			if (have_obj.nr > 0) {
+		if (!strcmp(reader->line, "done")) {
+			if (have_obj->nr > 0) {
 				if (multi_ack)
 					packet_write_fmt(1, "ACK %s\n", last_hex);
 				return 0;
@@ -464,7 +428,7 @@ static int get_common_commits(void)
 			packet_write_fmt(1, "NAK\n");
 			return -1;
 		}
-		die("git upload-pack: expected SHA1 list, got '%s'", line);
+		die("git upload-pack: expected SHA1 list, got '%s'", reader->line);
 	}
 }
 
@@ -488,6 +452,7 @@ static int do_reachable_revlist(struct c
 	struct object *o;
 	char namebuf[GIT_MAX_HEXSZ + 2]; /* ^ + hash + LF */
 	int i;
+	const unsigned hexsz = the_hash_algo->hexsz;
 
 	cmd->argv = argv;
 	cmd->git_cmd = 1;
@@ -506,7 +471,7 @@ static int do_reachable_revlist(struct c
 		goto error;
 
 	namebuf[0] = '^';
-	namebuf[GIT_SHA1_HEXSZ + 1] = '\n';
+	namebuf[hexsz + 1] = '\n';
 	for (i = get_max_object_index(); 0 < i; ) {
 		o = get_indexed_object(--i);
 		if (!o)
@@ -515,11 +480,11 @@ static int do_reachable_revlist(struct c
 			o->flags &= ~TMP_MARK;
 		if (!is_our_ref(o))
 			continue;
-		memcpy(namebuf + 1, oid_to_hex(&o->oid), GIT_SHA1_HEXSZ);
-		if (write_in_full(cmd->in, namebuf, GIT_SHA1_HEXSZ + 2) < 0)
+		memcpy(namebuf + 1, oid_to_hex(&o->oid), hexsz);
+		if (write_in_full(cmd->in, namebuf, hexsz + 2) < 0)
 			goto error;
 	}
-	namebuf[GIT_SHA1_HEXSZ] = '\n';
+	namebuf[hexsz] = '\n';
 	for (i = 0; i < src->nr; i++) {
 		o = src->objects[i].item;
 		if (is_our_ref(o)) {
@@ -529,8 +494,8 @@ static int do_reachable_revlist(struct c
 		}
 		if (reachable && o->type == OBJ_COMMIT)
 			o->flags |= TMP_MARK;
-		memcpy(namebuf, oid_to_hex(&o->oid), GIT_SHA1_HEXSZ);
-		if (write_in_full(cmd->in, namebuf, GIT_SHA1_HEXSZ + 1) < 0)
+		memcpy(namebuf, oid_to_hex(&o->oid), hexsz);
+		if (write_in_full(cmd->in, namebuf, hexsz + 1) < 0)
 			goto error;
 	}
 	close(cmd->in);
@@ -562,13 +527,13 @@ static int get_reachable_list(struct obj
 		return -1;
 
 	while ((i = read_in_full(cmd.out, namebuf, hexsz + 1)) == hexsz + 1) {
-		struct object_id sha1;
+		struct object_id oid;
 		const char *p;
 
-		if (parse_oid_hex(namebuf, &sha1, &p) || *p != '\n')
+		if (parse_oid_hex(namebuf, &oid, &p) || *p != '\n')
 			break;
 
-		o = lookup_object(sha1.hash);
+		o = lookup_object(the_repository, &oid);
 		if (o && o->type == OBJ_COMMIT) {
 			o->flags &= ~TMP_MARK;
 		}
@@ -626,7 +591,8 @@ error:
 	return 1;
 }
 
-static void check_non_tip(void)
+static void check_non_tip(struct object_array *want_obj,
+			  struct packet_writer *writer)
 {
 	int i;
 
@@ -637,35 +603,42 @@ static void check_non_tip(void)
 	 */
 	if (!stateless_rpc && !(allow_unadvertised_object_request & ALLOW_REACHABLE_SHA1))
 		goto error;
-	if (!has_unreachable(&want_obj))
+	if (!has_unreachable(want_obj))
 		/* All the non-tip ones are ancestors of what we advertised */
 		return;
 
 error:
 	/* Pick one of them (we know there at least is one) */
-	for (i = 0; i < want_obj.nr; i++) {
-		struct object *o = want_obj.objects[i].item;
-		if (!is_our_ref(o))
+	for (i = 0; i < want_obj->nr; i++) {
+		struct object *o = want_obj->objects[i].item;
+		if (!is_our_ref(o)) {
+			packet_writer_error(writer,
+					    "upload-pack: not our ref %s",
+					    oid_to_hex(&o->oid));
 			die("git upload-pack: not our ref %s",
 			    oid_to_hex(&o->oid));
+		}
 	}
 }
 
-static void send_shallow(struct commit_list *result)
+static void send_shallow(struct packet_writer *writer,
+			 struct commit_list *result)
 {
 	while (result) {
 		struct object *object = &result->item->object;
 		if (!(object->flags & (CLIENT_SHALLOW|NOT_SHALLOW))) {
-			packet_write_fmt(1, "shallow %s",
-					 oid_to_hex(&object->oid));
-			register_shallow(&object->oid);
+			packet_writer_write(writer, "shallow %s",
+					    oid_to_hex(&object->oid));
+			register_shallow(the_repository, &object->oid);
 			shallow_nr++;
 		}
 		result = result->next;
 	}
 }
 
-static void send_unshallow(const struct object_array *shallows)
+static void send_unshallow(struct packet_writer *writer,
+			   const struct object_array *shallows,
+			   struct object_array *want_obj)
 {
 	int i;
 
@@ -673,8 +646,8 @@ static void send_unshallow(const struct
 		struct object *object = shallows->objects[i].item;
 		if (object->flags & NOT_SHALLOW) {
 			struct commit_list *parents;
-			packet_write_fmt(1, "unshallow %s",
-					 oid_to_hex(&object->oid));
+			packet_writer_write(writer, "unshallow %s",
+					    oid_to_hex(&object->oid));
 			object->flags &= ~CLIENT_SHALLOW;
 			/*
 			 * We want to _register_ "object" as shallow, but we
@@ -689,20 +662,22 @@ static void send_unshallow(const struct
 			parents = ((struct commit *)object)->parents;
 			while (parents) {
 				add_object_array(&parents->item->object,
-						 NULL, &want_obj);
+						 NULL, want_obj);
 				parents = parents->next;
 			}
 			add_object_array(object, NULL, &extra_edge_obj);
 		}
 		/* make sure commit traversal conforms to client */
-		register_shallow(&object->oid);
+		register_shallow(the_repository, &object->oid);
 	}
 }
 
-static void deepen(int depth, int deepen_relative,
-		   struct object_array *shallows)
+static int check_ref(const char *refname_full, const struct object_id *oid,
+		     int flag, void *cb_data);
+static void deepen(struct packet_writer *writer, int depth, int deepen_relative,
+		   struct object_array *shallows, struct object_array *want_obj)
 {
-	if (depth == INFINITE_DEPTH && !is_repository_shallow()) {
+	if (depth == INFINITE_DEPTH && !is_repository_shallow(the_repository)) {
 		int i;
 
 		for (i = 0; i < shallows->nr; i++) {
@@ -713,48 +688,61 @@ static void deepen(int depth, int deepen
 		struct object_array reachable_shallows = OBJECT_ARRAY_INIT;
 		struct commit_list *result;
 
+		/*
+		 * Checking for reachable shallows requires that our refs be
+		 * marked with OUR_REF.
+		 */
+		head_ref_namespaced(check_ref, NULL);
+		for_each_namespaced_ref(check_ref, NULL);
+
 		get_reachable_list(shallows, &reachable_shallows);
 		result = get_shallow_commits(&reachable_shallows,
 					     depth + 1,
 					     SHALLOW, NOT_SHALLOW);
-		send_shallow(result);
+		send_shallow(writer, result);
 		free_commit_list(result);
 		object_array_clear(&reachable_shallows);
 	} else {
 		struct commit_list *result;
 
-		result = get_shallow_commits(&want_obj, depth,
+		result = get_shallow_commits(want_obj, depth,
 					     SHALLOW, NOT_SHALLOW);
-		send_shallow(result);
+		send_shallow(writer, result);
 		free_commit_list(result);
 	}
 
-	send_unshallow(shallows);
+	send_unshallow(writer, shallows, want_obj);
 }
 
-static void deepen_by_rev_list(int ac, const char **av,
-			       struct object_array *shallows)
+static void deepen_by_rev_list(struct packet_writer *writer, int ac,
+			       const char **av,
+			       struct object_array *shallows,
+			       struct object_array *want_obj)
 {
 	struct commit_list *result;
 
+	disable_commit_graph(the_repository);
 	result = get_shallow_commits_by_rev_list(ac, av, SHALLOW, NOT_SHALLOW);
-	send_shallow(result);
+	send_shallow(writer, result);
 	free_commit_list(result);
-	send_unshallow(shallows);
+	send_unshallow(writer, shallows, want_obj);
 }
 
 /* Returns 1 if a shallow list is sent or 0 otherwise */
-static int send_shallow_list(int depth, int deepen_rev_list,
+static int send_shallow_list(struct packet_writer *writer,
+			     int depth, int deepen_rev_list,
 			     timestamp_t deepen_since,
 			     struct string_list *deepen_not,
-			     struct object_array *shallows)
+			     int deepen_relative,
+			     struct object_array *shallows,
+			     struct object_array *want_obj)
 {
 	int ret = 0;
 
 	if (depth > 0 && deepen_rev_list)
 		die("git upload-pack: deepen and deepen-since (or deepen-not) cannot be used together");
 	if (depth > 0) {
-		deepen(depth, deepen_relative, shallows);
+		deepen(writer, depth, deepen_relative, shallows, want_obj);
 		ret = 1;
 	} else if (deepen_rev_list) {
 		struct argv_array av = ARGV_ARRAY_INIT;
@@ -771,18 +759,19 @@ static int send_shallow_list(int depth,
 			}
 			argv_array_push(&av, "--not");
 		}
-		for (i = 0; i < want_obj.nr; i++) {
-			struct object *o = want_obj.objects[i].item;
+		for (i = 0; i < want_obj->nr; i++) {
+			struct object *o = want_obj->objects[i].item;
 			argv_array_push(&av, oid_to_hex(&o->oid));
 		}
-		deepen_by_rev_list(av.argc, av.argv, shallows);
+		deepen_by_rev_list(writer, av.argc, av.argv, shallows, want_obj);
 		argv_array_clear(&av);
 		ret = 1;
 	} else {
 		if (shallows->nr > 0) {
 			int i;
 			for (i = 0; i < shallows->nr; i++)
-				register_shallow(&shallows->objects[i].item->oid);
+				register_shallow(the_repository,
+						 &shallows->objects[i].item->oid);
 		}
 	}
 
@@ -798,7 +787,7 @@ static int process_shallow(const char *l
 		struct object *object;
 		if (get_oid_hex(arg, &oid))
 			die("invalid shallow line: %s", line);
-		object = parse_object(&oid);
+		object = parse_object(the_repository, &oid);
 		if (!object)
 			return 1;
 		if (object->type != OBJ_COMMIT)
@@ -849,7 +838,7 @@ static int process_deepen_not(const char
 	if (skip_prefix(line, "deepen-not ", &arg)) {
 		char *ref = NULL;
 		struct object_id oid;
-		if (expand_ref(arg, strlen(arg), &oid, &ref) != 1)
+		if (expand_ref(the_repository, arg, strlen(arg), &oid, &ref) != 1)
 			die("git upload-pack: ambiguous deepen-not: %s", line);
 		string_list_append(deepen_not, ref);
 		free(ref);
@@ -859,7 +848,7 @@ static int process_deepen_not(const char
 	return 0;
 }
 
-static void receive_needs(void)
+static void receive_needs(struct packet_reader *reader, struct object_array *want_obj)
 {
 	struct object_array shallows = OBJECT_ARRAY_INIT;
 	struct string_list deepen_not = STRING_LIST_INIT_DUP;
@@ -867,39 +856,42 @@ static void receive_needs(void)
 	int has_non_tip = 0;
 	timestamp_t deepen_since = 0;
 	int deepen_rev_list = 0;
+	int deepen_relative = 0;
+	struct packet_writer writer;
 
 	shallow_nr = 0;
+	packet_writer_init(&writer, 1);
 	for (;;) {
 		struct object *o;
 		const char *features;
 		struct object_id oid_buf;
-		char *line = packet_read_line(0, NULL);
 		const char *arg;
 
 		reset_timeout();
-		if (!line)
+		if (packet_reader_read(reader) != PACKET_READ_NORMAL)
 			break;
 
-		if (process_shallow(line, &shallows))
+		if (process_shallow(reader->line, &shallows))
 			continue;
-		if (process_deepen(line, &depth))
+		if (process_deepen(reader->line, &depth))
 			continue;
-		if (process_deepen_since(line, &deepen_since, &deepen_rev_list))
+		if (process_deepen_since(reader->line, &deepen_since, &deepen_rev_list))
 			continue;
-		if (process_deepen_not(line, &deepen_not, &deepen_rev_list))
+		if (process_deepen_not(reader->line, &deepen_not, &deepen_rev_list))
 			continue;
 
-		if (skip_prefix(line, "filter ", &arg)) {
+		if (skip_prefix(reader->line, "filter ", &arg)) {
 			if (!filter_capability_requested)
 				die("git upload-pack: filtering capability not negotiated");
+			list_objects_filter_die_if_populated(&filter_options);
 			parse_list_objects_filter(&filter_options, arg);
 			continue;
 		}
 
-		if (!skip_prefix(line, "want ", &arg) ||
+		if (!skip_prefix(reader->line, "want ", &arg) ||
 		    parse_oid_hex(arg, &oid_buf, &features))
 			die("git upload-pack: protocol error, "
-			    "expected to get object ID, not '%s'", line);
+			    "expected to get object ID, not '%s'", reader->line);
 
 		if (parse_feature_request(features, "deepen-relative"))
 			deepen_relative = 1;
@@ -924,11 +916,11 @@ static void receive_needs(void)
 		if (allow_filter && parse_feature_request(features, "filter"))
 			filter_capability_requested = 1;
 
-		o = parse_object(&oid_buf);
+		o = parse_object(the_repository, &oid_buf);
 		if (!o) {
-			packet_write_fmt(1,
-					 "ERR upload-pack: not our ref %s",
-					 oid_to_hex(&oid_buf));
+			packet_writer_error(&writer,
+					    "upload-pack: not our ref %s",
+					    oid_to_hex(&oid_buf));
 			die("git upload-pack: not our ref %s",
 			    oid_to_hex(&oid_buf));
 		}
@@ -937,7 +929,7 @@ static void receive_needs(void)
 			if (!((allow_unadvertised_object_request & ALLOW_ANY_SHA1) == ALLOW_ANY_SHA1
 			      || is_our_ref(o)))
 				has_non_tip = 1;
-			add_object_array(o, NULL, &want_obj);
+			add_object_array(o, NULL, want_obj);
 		}
 	}
 
@@ -949,7 +941,7 @@ static void receive_needs(void)
 	 * by another process that handled the initial request.
 	 */
 	if (has_non_tip)
-		check_non_tip();
+		check_non_tip(want_obj, &writer);
 
 	if (!use_sideband && daemon_mode)
 		no_progress = 1;
@@ -957,8 +949,9 @@ static void receive_needs(void)
 	if (depth == 0 && !deepen_rev_list && shallows.nr == 0)
 		return;
 
-	if (send_shallow_list(depth, deepen_rev_list, deepen_since,
-			      &deepen_not, &shallows))
+	if (send_shallow_list(&writer, depth, deepen_rev_list, deepen_since,
+			      &deepen_not, deepen_relative, &shallows,
+			      want_obj))
 		packet_flush(1);
 	object_array_clear(&shallows);
 }
@@ -967,7 +960,7 @@ static void receive_needs(void)
 static int mark_our_ref(const char *refname, const char *refname_full,
 			const struct object_id *oid)
 {
-	struct object *o = lookup_unknown_object(oid->hash);
+	struct object *o = lookup_unknown_object(oid);
 
 	if (ref_is_hidden(refname, refname_full)) {
 		o->flags |= HIDDEN_REF;
@@ -1044,8 +1037,8 @@ static int find_symref(const char *refna
 	symref_target = resolve_ref_unsafe(refname, 0, NULL, &flag);
 	if (!symref_target || (flag & REF_ISSYMREF) == 0)
 		die("'%s' is a symref but it is not?", refname);
-	item = string_list_append(cb_data, refname);
-	item->util = xstrdup(symref_target);
+	item = string_list_append(cb_data, strip_namespace(refname));
+	item->util = xstrdup(strip_namespace(symref_target));
 	return 0;
 }
 
@@ -1070,18 +1063,29 @@ static int upload_pack_config(const char
 		keepalive = git_config_int(var, value);
 		if (!keepalive)
 			keepalive = -1;
-	} else if (current_config_scope() != CONFIG_SCOPE_REPO) {
-		if (!strcmp("uploadpack.packobjectshook", var))
-			return git_config_string(&pack_objects_hook, var, value);
 	} else if (!strcmp("uploadpack.allowfilter", var)) {
 		allow_filter = git_config_bool(var, value);
+	} else if (!strcmp("uploadpack.allowrefinwant", var)) {
+		allow_ref_in_want = git_config_bool(var, value);
+	} else if (!strcmp("uploadpack.allowsidebandall", var)) {
+		allow_sideband_all = git_config_bool(var, value);
+	} else if (!strcmp("core.precomposeunicode", var)) {
+		precomposed_unicode = git_config_bool(var, value);
 	}
+
+	if (current_config_scope() != CONFIG_SCOPE_REPO) {
+		if (!strcmp("uploadpack.packobjectshook", var))
+			return git_config_string(&pack_objects_hook, var, value);
+	}
+
 	return parse_hide_refs_config(var, value, "uploadpack");
 }
 
 void upload_pack(struct upload_pack_options *options)
 {
 	struct string_list symref = STRING_LIST_INIT_DUP;
+	struct object_array want_obj = OBJECT_ARRAY_INIT;
+	struct packet_reader reader;
 
 	stateless_rpc = options->stateless_rpc;
 	timeout = options->timeout;
@@ -1105,15 +1109,21 @@ void upload_pack(struct upload_pack_opti
 	if (options->advertise_refs)
 		return;
 
-	receive_needs();
+	packet_reader_init(&reader, 0, NULL, 0,
+			   PACKET_READ_CHOMP_NEWLINE |
+			   PACKET_READ_DIE_ON_ERR_PACKET);
+
+	receive_needs(&reader, &want_obj);
 	if (want_obj.nr) {
-		get_common_commits();
-		create_pack_file();
+		struct object_array have_obj = OBJECT_ARRAY_INIT;
+		get_common_commits(&reader, &have_obj, &want_obj);
+		create_pack_file(&have_obj, &want_obj);
 	}
 }
 
 struct upload_pack_data {
 	struct object_array wants;
+	struct string_list wanted_refs;
 	struct oid_array haves;
 
 	struct object_array shallows;
@@ -1123,6 +1133,8 @@ struct upload_pack_data {
 	int deepen_rev_list;
 	int deepen_relative;
 
+	struct packet_writer writer;
+
 	unsigned stateless_rpc : 1;
 
 	unsigned use_thin_pack : 1;
@@ -1135,26 +1147,31 @@ struct upload_pack_data {
 static void upload_pack_data_init(struct upload_pack_data *data)
 {
 	struct object_array wants = OBJECT_ARRAY_INIT;
+	struct string_list wanted_refs = STRING_LIST_INIT_DUP;
 	struct oid_array haves = OID_ARRAY_INIT;
 	struct object_array shallows = OBJECT_ARRAY_INIT;
 	struct string_list deepen_not = STRING_LIST_INIT_DUP;
 
 	memset(data, 0, sizeof(*data));
 	data->wants = wants;
+	data->wanted_refs = wanted_refs;
 	data->haves = haves;
 	data->shallows = shallows;
 	data->deepen_not = deepen_not;
+	packet_writer_init(&data->writer, 1);
 }
 
 static void upload_pack_data_clear(struct upload_pack_data *data)
 {
 	object_array_clear(&data->wants);
+	string_list_clear(&data->wanted_refs, 1);
 	oid_array_clear(&data->haves);
 	object_array_clear(&data->shallows);
 	string_list_clear(&data->deepen_not, 0);
 }
 
-static int parse_want(const char *line)
+static int parse_want(struct packet_writer *writer, const char *line,
+		      struct object_array *want_obj)
 {
 	const char *arg;
 	if (skip_prefix(line, "want ", &arg)) {
@@ -1165,18 +1182,48 @@ static int parse_want(const char *line)
 			die("git upload-pack: protocol error, "
 			    "expected to get oid, not '%s'", line);
 
-		o = parse_object(&oid);
+		o = parse_object(the_repository, &oid);
 		if (!o) {
-			packet_write_fmt(1,
-					 "ERR upload-pack: not our ref %s",
-					 oid_to_hex(&oid));
+			packet_writer_error(writer,
+					    "upload-pack: not our ref %s",
+					    oid_to_hex(&oid));
 			die("git upload-pack: not our ref %s",
 			    oid_to_hex(&oid));
 		}
 
 		if (!(o->flags & WANTED)) {
 			o->flags |= WANTED;
-			add_object_array(o, NULL, &want_obj);
+			add_object_array(o, NULL, want_obj);
+		}
+
+		return 1;
+	}
+
+	return 0;
+}
+
+static int parse_want_ref(struct packet_writer *writer, const char *line,
+			  struct string_list *wanted_refs,
+			  struct object_array *want_obj)
+{
+	const char *arg;
+	if (skip_prefix(line, "want-ref ", &arg)) {
+		struct object_id oid;
+		struct string_list_item *item;
+		struct object *o;
+
+		if (read_ref(arg, &oid)) {
+			packet_writer_error(writer, "unknown ref %s", arg);
+			die("unknown ref %s", arg);
+		}
+
+		item = string_list_append(wanted_refs, arg);
+		item->util = oiddup(&oid);
+
+		o = parse_object_or_die(&oid, arg);
+		if (!(o->flags & WANTED)) {
+			o->flags |= WANTED;
+			add_object_array(o, NULL, want_obj);
 		}
 
 		return 1;
@@ -1201,14 +1248,19 @@ static int parse_have(const char *line,
 }
 
 static void process_args(struct packet_reader *request,
-			 struct upload_pack_data *data)
+			 struct upload_pack_data *data,
+			 struct object_array *want_obj)
 {
 	while (packet_reader_read(request) != PACKET_READ_FLUSH) {
 		const char *arg = request->line;
 		const char *p;
 
 		/* process want */
-		if (parse_want(arg))
+		if (parse_want(&data->writer, arg, want_obj))
+			continue;
+		if (allow_ref_in_want &&
+		    parse_want_ref(&data->writer, arg, &data->wanted_refs,
+				   want_obj))
 			continue;
 		/* process have line */
 		if (parse_have(arg, &data->haves))
@@ -1253,16 +1305,25 @@ static void process_args(struct packet_r
 		}
 
 		if (allow_filter && skip_prefix(arg, "filter ", &p)) {
+			list_objects_filter_die_if_populated(&filter_options);
 			parse_list_objects_filter(&filter_options, p);
 			continue;
 		}
 
+		if ((git_env_bool("GIT_TEST_SIDEBAND_ALL", 0) ||
+		     allow_sideband_all) &&
+		    !strcmp(arg, "sideband-all")) {
+			data->writer.use_sideband = 1;
+			continue;
+		}
+
 		/* ignore unknown lines maybe? */
 		die("unexpected line: '%s'", arg);
 	}
 }
 
-static int process_haves(struct oid_array *haves, struct oid_array *common)
+static int process_haves(struct oid_array *haves, struct oid_array *common,
+			 struct object_array *have_obj)
 {
 	int i;
 
@@ -1277,7 +1338,7 @@ static int process_haves(struct oid_arra
 
 		oid_array_append(common, oid);
 
-		o = parse_object(oid);
+		o = parse_object(the_repository, oid);
 		if (!o)
 			die("oops (%s)", oid_to_hex(oid));
 		if (o->type == OBJ_COMMIT) {
@@ -1295,76 +1356,98 @@ static int process_haves(struct oid_arra
 				parents->item->object.flags |= THEY_HAVE;
 		}
 		if (!we_knew_they_have)
-			add_object_array(o, NULL, &have_obj);
+			add_object_array(o, NULL, have_obj);
 	}
 
 	return 0;
 }
 
-static int send_acks(struct oid_array *acks, struct strbuf *response)
+static int send_acks(struct packet_writer *writer, struct oid_array *acks,
+		     const struct object_array *have_obj,
+		     struct object_array *want_obj)
 {
 	int i;
 
-	packet_buf_write(response, "acknowledgments\n");
+	packet_writer_write(writer, "acknowledgments\n");
 
 	/* Send Acks */
 	if (!acks->nr)
-		packet_buf_write(response, "NAK\n");
+		packet_writer_write(writer, "NAK\n");
 
 	for (i = 0; i < acks->nr; i++) {
-		packet_buf_write(response, "ACK %s\n",
-				 oid_to_hex(&acks->oid[i]));
+		packet_writer_write(writer, "ACK %s\n",
+				    oid_to_hex(&acks->oid[i]));
 	}
 
-	if (ok_to_give_up()) {
+	if (ok_to_give_up(have_obj, want_obj)) {
 		/* Send Ready */
-		packet_buf_write(response, "ready\n");
+		packet_writer_write(writer, "ready\n");
 		return 1;
 	}
 
 	return 0;
 }
 
-static int process_haves_and_send_acks(struct upload_pack_data *data)
+static int process_haves_and_send_acks(struct upload_pack_data *data,
+				       struct object_array *have_obj,
+				       struct object_array *want_obj)
 {
 	struct oid_array common = OID_ARRAY_INIT;
-	struct strbuf response = STRBUF_INIT;
 	int ret = 0;
 
-	process_haves(&data->haves, &common);
+	process_haves(&data->haves, &common, have_obj);
 	if (data->done) {
 		ret = 1;
-	} else if (send_acks(&common, &response)) {
-		packet_buf_delim(&response);
+	} else if (send_acks(&data->writer, &common, have_obj, want_obj)) {
+		packet_writer_delim(&data->writer);
 		ret = 1;
 	} else {
 		/* Add Flush */
-		packet_buf_flush(&response);
+		packet_writer_flush(&data->writer);
 		ret = 0;
 	}
 
-	/* Send response */
-	write_or_die(1, response.buf, response.len);
-	strbuf_release(&response);
-
 	oid_array_clear(&data->haves);
 	oid_array_clear(&common);
 	return ret;
 }
 
-static void send_shallow_info(struct upload_pack_data *data)
+static void send_wanted_ref_info(struct upload_pack_data *data)
+{
+	const struct string_list_item *item;
+
+	if (!data->wanted_refs.nr)
+		return;
+
+	packet_writer_write(&data->writer, "wanted-refs\n");
+
+	for_each_string_list_item(item, &data->wanted_refs) {
+		packet_writer_write(&data->writer, "%s %s\n",
+				    oid_to_hex(item->util),
+				    item->string);
+	}
+
+	packet_writer_delim(&data->writer);
+}
+
+static void send_shallow_info(struct upload_pack_data *data,
+			      struct object_array *want_obj)
 {
 	/* No shallow info needs to be sent */
 	if (!data->depth && !data->deepen_rev_list && !data->shallows.nr &&
-	    !is_repository_shallow())
+	    !is_repository_shallow(the_repository))
 		return;
 
-	packet_write_fmt(1, "shallow-info\n");
+	packet_writer_write(&data->writer, "shallow-info\n");
 
-	if (!send_shallow_list(data->depth, data->deepen_rev_list,
+	if (!send_shallow_list(&data->writer, data->depth,
+			       data->deepen_rev_list,
 			       data->deepen_since, &data->deepen_not,
-			       &data->shallows) && is_repository_shallow())
-		deepen(INFINITE_DEPTH, data->deepen_relative, &data->shallows);
+			       data->deepen_relative,
+			       &data->shallows, want_obj) &&
+	    is_repository_shallow(the_repository))
+		deepen(&data->writer, INFINITE_DEPTH, data->deepen_relative,
+		       &data->shallows, want_obj);
 
 	packet_delim(1);
 }
@@ -1381,6 +1464,10 @@ int upload_pack_v2(struct repository *r,
 {
 	enum fetch_state state = FETCH_PROCESS_ARGS;
 	struct upload_pack_data data;
+	struct object_array have_obj = OBJECT_ARRAY_INIT;
+	struct object_array want_obj = OBJECT_ARRAY_INIT;
+
+	clear_object_flags(ALL_FLAGS);
 
 	git_config(upload_pack_config, NULL);
 
@@ -1390,7 +1477,7 @@ int upload_pack_v2(struct repository *r,
 	while (state != FETCH_DONE) {
 		switch (state) {
 		case FETCH_PROCESS_ARGS:
-			process_args(request, &data);
+			process_args(request, &data, &want_obj);
 
 			if (!want_obj.nr) {
 				/*
@@ -1412,16 +1499,18 @@ int upload_pack_v2(struct repository *r,
 			}
 			break;
 		case FETCH_SEND_ACKS:
-			if (process_haves_and_send_acks(&data))
+			if (process_haves_and_send_acks(&data, &have_obj,
+							&want_obj))
 				state = FETCH_SEND_PACK;
 			else
 				state = FETCH_DONE;
 			break;
 		case FETCH_SEND_PACK:
-			send_shallow_info(&data);
+			send_wanted_ref_info(&data);
+			send_shallow_info(&data, &want_obj);
 
-			packet_write_fmt(1, "packfile\n");
-			create_pack_file();
+			packet_writer_write(&data.writer, "packfile\n");
+			create_pack_file(&have_obj, &want_obj);
 			state = FETCH_DONE;
 			break;
 		case FETCH_DONE:
@@ -1430,6 +1519,8 @@ int upload_pack_v2(struct repository *r,
 	}
 
 	upload_pack_data_clear(&data);
+	object_array_clear(&have_obj);
+	object_array_clear(&want_obj);
 	return 0;
 }
 
@@ -1438,12 +1529,30 @@ int upload_pack_advertise(struct reposit
 {
 	if (value) {
 		int allow_filter_value;
+		int allow_ref_in_want;
+		int allow_sideband_all_value;
+
 		strbuf_addstr(value, "shallow");
+
 		if (!repo_config_get_bool(the_repository,
 					 "uploadpack.allowfilter",
 					 &allow_filter_value) &&
 		    allow_filter_value)
 			strbuf_addstr(value, " filter");
+
+		if (!repo_config_get_bool(the_repository,
+					 "uploadpack.allowrefinwant",
+					 &allow_ref_in_want) &&
+		    allow_ref_in_want)
+			strbuf_addstr(value, " ref-in-want");
+
+		if (git_env_bool("GIT_TEST_SIDEBAND_ALL", 0) ||
+		    (!repo_config_get_bool(the_repository,
+					   "uploadpack.allowsidebandall",
+					   &allow_sideband_all_value) &&
+		     allow_sideband_all_value))
+			strbuf_addstr(value, " sideband-all");
 	}
+
 	return 1;
 }
diff -pruN 1.2.1+git2.18.0-1/git/upload-pack.h 1.2.3+git2.25.1-1/git/upload-pack.h
--- 1.2.1+git2.18.0-1/git/upload-pack.h	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/upload-pack.h	2020-02-17 04:47:35.000000000 +0000
@@ -13,11 +13,11 @@ void upload_pack(struct upload_pack_opti
 struct repository;
 struct argv_array;
 struct packet_reader;
-extern int upload_pack_v2(struct repository *r, struct argv_array *keys,
-			  struct packet_reader *request);
+int upload_pack_v2(struct repository *r, struct argv_array *keys,
+		   struct packet_reader *request);
 
 struct strbuf;
-extern int upload_pack_advertise(struct repository *r,
-				 struct strbuf *value);
+int upload_pack_advertise(struct repository *r,
+			  struct strbuf *value);
 
 #endif /* UPLOAD_PACK_H */
diff -pruN 1.2.1+git2.18.0-1/git/url.c 1.2.3+git2.25.1-1/git/url.c
--- 1.2.1+git2.18.0-1/git/url.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/url.c	2020-02-17 04:47:35.000000000 +0000
@@ -5,7 +5,7 @@ int is_urlschemechar(int first_flag, int
 {
 	/*
 	 * The set of valid URL schemes, as per STD66 (RFC3986) is
-	 * '[A-Za-z][A-Za-z0-9+.-]*'. But use sightly looser check
+	 * '[A-Za-z][A-Za-z0-9+.-]*'. But use slightly looser check
 	 * of '[A-Za-z0-9][A-Za-z0-9+.-]*' because earlier version
 	 * of check used '[A-Za-z0-9]+' so not to break any remote
 	 * helpers.
@@ -46,9 +46,9 @@ static char *url_decode_internal(const c
 			break;
 		}
 
-		if (c == '%') {
+		if (c == '%' && (len < 0 || len >= 3)) {
 			int val = hex2chr(q + 1);
-			if (0 <= val) {
+			if (0 < val) {
 				strbuf_addch(out, val);
 				q += 3;
 				len -= 3;
@@ -86,6 +86,12 @@ char *url_decode_mem(const char *url, in
 	return url_decode_internal(&url, len, NULL, &out, 0);
 }
 
+char *url_percent_decode(const char *encoded)
+{
+	struct strbuf out = STRBUF_INIT;
+	return url_decode_internal(&encoded, strlen(encoded), NULL, &out, 0);
+}
+
 char *url_decode_parameter_name(const char **query)
 {
 	struct strbuf out = STRBUF_INIT;
@@ -104,7 +110,8 @@ void end_url_with_slash(struct strbuf *b
 	strbuf_complete(buf, '/');
 }
 
-void str_end_url_with_slash(const char *url, char **dest) {
+void str_end_url_with_slash(const char *url, char **dest)
+{
 	struct strbuf buf = STRBUF_INIT;
 	end_url_with_slash(&buf, url);
 	free(*dest);
diff -pruN 1.2.1+git2.18.0-1/git/url.h 1.2.3+git2.25.1-1/git/url.h
--- 1.2.1+git2.18.0-1/git/url.h	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/url.h	2020-02-17 04:47:35.000000000 +0000
@@ -1,14 +1,24 @@
 #ifndef URL_H
 #define URL_H
 
-extern int is_url(const char *url);
-extern int is_urlschemechar(int first_flag, int ch);
-extern char *url_decode(const char *url);
-extern char *url_decode_mem(const char *url, int len);
-extern char *url_decode_parameter_name(const char **query);
-extern char *url_decode_parameter_value(const char **query);
+struct strbuf;
 
-extern void end_url_with_slash(struct strbuf *buf, const char *url);
-extern void str_end_url_with_slash(const char *url, char **dest);
+int is_url(const char *url);
+int is_urlschemechar(int first_flag, int ch);
+char *url_decode(const char *url);
+char *url_decode_mem(const char *url, int len);
+
+/*
+ * Similar to the url_decode_{,mem} methods above, but doesn't assume there
+ * is a scheme followed by a : at the start of the string. Instead, %-sequences
+ * before any : are also parsed.
+ */
+char *url_percent_decode(const char *encoded);
+
+char *url_decode_parameter_name(const char **query);
+char *url_decode_parameter_value(const char **query);
+
+void end_url_with_slash(struct strbuf *buf, const char *url);
+void str_end_url_with_slash(const char *url, char **dest);
 
 #endif /* URL_H */
diff -pruN 1.2.1+git2.18.0-1/git/urlmatch.h 1.2.3+git2.25.1-1/git/urlmatch.h
--- 1.2.1+git2.18.0-1/git/urlmatch.h	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/urlmatch.h	2020-02-17 04:47:35.000000000 +0000
@@ -1,4 +1,6 @@
 #ifndef URL_MATCH_H
+#define URL_MATCH_H
+
 #include "string-list.h"
 
 struct url_info {
@@ -31,7 +33,7 @@ struct url_info {
 				 * '?...' and '#...' portion; will always be >= 1 */
 };
 
-extern char *url_normalize(const char *, struct url_info *);
+char *url_normalize(const char *, struct url_info *);
 
 struct urlmatch_item {
 	size_t hostmatch_len;
@@ -50,6 +52,6 @@ struct urlmatch_config {
 	int (*cascade_fn)(const char *var, const char *value, void *cb);
 };
 
-extern int urlmatch_config_entry(const char *var, const char *value, void *cb);
+int urlmatch_config_entry(const char *var, const char *value, void *cb);
 
 #endif /* URL_MATCH_H */
diff -pruN 1.2.1+git2.18.0-1/git/usage.c 1.2.3+git2.25.1-1/git/usage.c
--- 1.2.1+git2.18.0-1/git/usage.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/usage.c	2020-02-17 04:47:35.000000000 +0000
@@ -9,30 +9,73 @@
 void vreportf(const char *prefix, const char *err, va_list params)
 {
 	char msg[4096];
-	char *p;
+	char *p, *pend = msg + sizeof(msg);
+	size_t prefix_len = strlen(prefix);
 
-	vsnprintf(msg, sizeof(msg), err, params);
-	for (p = msg; *p; p++) {
+	if (sizeof(msg) <= prefix_len) {
+		fprintf(stderr, "BUG!!! too long a prefix '%s'\n", prefix);
+		abort();
+	}
+	memcpy(msg, prefix, prefix_len);
+	p = msg + prefix_len;
+	if (vsnprintf(p, pend - p, err, params) < 0)
+		*p = '\0'; /* vsnprintf() failed, clip at prefix */
+
+	for (; p != pend - 1 && *p; p++) {
 		if (iscntrl(*p) && *p != '\t' && *p != '\n')
 			*p = '?';
 	}
-	fprintf(stderr, "%s%s\n", prefix, msg);
+
+	*(p++) = '\n'; /* we no longer need a NUL */
+	fflush(stderr);
+	write_in_full(2, msg, p - msg);
 }
 
 static NORETURN void usage_builtin(const char *err, va_list params)
 {
 	vreportf("usage: ", err, params);
+
+	/*
+	 * When we detect a usage error *before* the command dispatch in
+	 * cmd_main(), we don't know what verb to report.  Force it to this
+	 * to facilitate post-processing.
+	 */
+	trace2_cmd_name("_usage_");
+
+	/*
+	 * Currently, the (err, params) are usually just the static usage
+	 * string which isn't very useful here.  Usually, the call site
+	 * manually calls fprintf(stderr,...) with the actual detailed
+	 * syntax error before calling usage().
+	 *
+	 * TODO It would be nice to update the call sites to pass both
+	 * the static usage string and the detailed error message.
+	 */
+
 	exit(129);
 }
 
 static NORETURN void die_builtin(const char *err, va_list params)
 {
+	/*
+	 * We call this trace2 function first and expect it to va_copy 'params'
+	 * before using it (because an 'ap' can only be walked once).
+	 */
+	trace2_cmd_error_va(err, params);
+
 	vreportf("fatal: ", err, params);
+
 	exit(128);
 }
 
 static void error_builtin(const char *err, va_list params)
 {
+	/*
+	 * We call this trace2 function first and expect it to va_copy 'params'
+	 * before using it (because an 'ap' can only be walked once).
+	 */
+	trace2_cmd_error_va(err, params);
+
 	vreportf("error: ", err, params);
 }
 
diff -pruN 1.2.1+git2.18.0-1/git/userdiff.c 1.2.3+git2.25.1-1/git/userdiff.c
--- 1.2.1+git2.18.0-1/git/userdiff.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/userdiff.c	2020-02-17 04:47:35.000000000 +0000
@@ -23,6 +23,28 @@ IPATTERN("ada",
 	 "[a-zA-Z][a-zA-Z0-9_]*"
 	 "|[-+]?[0-9][0-9#_.aAbBcCdDeEfF]*([eE][+-]?[0-9_]+)?"
 	 "|=>|\\.\\.|\\*\\*|:=|/=|>=|<=|<<|>>|<>"),
+PATTERNS("dts",
+	 "!;\n"
+	 "!=\n"
+	 /* lines beginning with a word optionally preceded by '&' or the root */
+	 "^[ \t]*((/[ \t]*\\{|&?[a-zA-Z_]).*)",
+	 /* -- */
+	 /* Property names and math operators */
+	 "[a-zA-Z0-9,._+?#-]+"
+	 "|[-+*/%&^|!~]|>>|<<|&&|\\|\\|"),
+PATTERNS("elixir",
+	 "^[ \t]*((def(macro|module|impl|protocol|p)?|test)[ \t].*)$",
+	 /* -- */
+	 /* Atoms, names, and module attributes */
+	 "[@:]?[a-zA-Z0-9@_?!]+"
+	 /* Numbers with specific base */
+	 "|[-+]?0[xob][0-9a-fA-F]+"
+	 /* Numbers */
+	 "|[-+]?[0-9][0-9_.]*([eE][-+]?[0-9_]+)?"
+	 /* Operators and atoms that represent them */
+	 "|:?(\\+\\+|--|\\.\\.|~~~|<>|\\^\\^\\^|<?\\|>|<<<?|>?>>|<<?~|~>?>|<~>|<=|>=|===?|!==?|=~|&&&?|\\|\\|\\|?|=>|<-|\\\\\\\\|->)"
+	 /* Not real operators, but should be grouped */
+	 "|:?%[A-Za-z0-9_.]\\{\\}?"),
 IPATTERN("fortran",
 	 "!^([C*]|[ \t]*!)\n"
 	 "!^[ \t]*MODULE[ \t]+PROCEDURE[ \t]\n"
@@ -58,7 +80,12 @@ PATTERNS("java",
 	 "|[-+*/<>%&^|=!]="
 	 "|--|\\+\\+|<<=?|>>>?=?|&&|\\|\\|"),
 PATTERNS("matlab",
-	 "^[[:space:]]*((classdef|function)[[:space:]].*)$|^%%[[:space:]].*$",
+	 /*
+	  * Octave pattern is mostly the same as matlab, except that '%%%' and
+	  * '##' can also be used to begin code sections, in addition to '%%'
+	  * that is understood by both.
+	  */
+	 "^[[:space:]]*((classdef|function)[[:space:]].*)$|^(%%%?|##)[[:space:]].*$",
 	 "[a-zA-Z_][a-zA-Z0-9_]*|[-+0-9.e]+|[=~<>]=|\\.[*/\\^']|\\|\\||&&"),
 PATTERNS("objc",
 	 /* Negate C statements that can look like functions */
@@ -114,12 +141,12 @@ PATTERNS("perl",
 	 "|<<|<>|<=>|>>"),
 PATTERNS("php",
 	 "^[\t ]*(((public|protected|private|static)[\t ]+)*function.*)$\n"
-	 "^[\t ]*(class.*)$",
+	 "^[\t ]*((((final|abstract)[\t ]+)?class|interface|trait).*)$",
 	 /* -- */
 	 "[a-zA-Z_][a-zA-Z0-9_]*"
 	 "|[-+0-9.e]+|0[xXbB]?[0-9a-fA-F]+"
 	 "|[-+*/<>%&^|=!.]=|--|\\+\\+|<<=?|>>=?|===|&&|\\|\\||::|->"),
-PATTERNS("python", "^[ \t]*((class|def)[ \t].*)$",
+PATTERNS("python", "^[ \t]*((class|(async[ \t]+)?def)[ \t].*)$",
 	 /* -- */
 	 "[a-zA-Z_][a-zA-Z0-9_]*"
 	 "|[-+0-9.e]+[jJlL]?|0[xX]?[0-9a-fA-F]+[lL]?"
@@ -130,6 +157,12 @@ PATTERNS("ruby", "^[ \t]*((class|module|
 	 "(@|@@|\\$)?[a-zA-Z_][a-zA-Z0-9_]*"
 	 "|[-+0-9.e]+|0[xXbB]?[0-9a-fA-F]+|\\?(\\\\C-)?(\\\\M-)?."
 	 "|//=?|[-+*/<>%&^|=!]=|<<=?|>>=?|===|\\.{1,3}|::|[!=]~"),
+PATTERNS("rust",
+	 "^[\t ]*((pub(\\([^\\)]+\\))?[\t ]+)?((async|const|unsafe|extern([\t ]+\"[^\"]+\"))[\t ]+)?(struct|enum|union|mod|trait|fn|impl)[< \t]+[^;]*)$",
+	 /* -- */
+	 "[a-zA-Z_][a-zA-Z0-9_]*"
+	 "|[0-9][0-9_a-fA-Fiosuxz]*(\\.([0-9]*[eE][+-]?)?[0-9_fF]*)?"
+	 "|[-+*\\/<>%&^|=!:]=|<<=?|>>=?|&&|\\|\\||->|=>|\\.{2}=|\\.{3}|::"),
 PATTERNS("bibtex", "(@[a-zA-Z]{1,}[ \t]*\\{{0,1}[ \t]*[^ \t\"@',\\#}{~%]*).*$",
 	 "[={}\"]|[^={}\" \t]+"),
 PATTERNS("tex", "^(\\\\((sub)*section|chapter|part)\\*{0,1}\\{.*)$",
@@ -265,12 +298,14 @@ int userdiff_config(const char *k, const
 	return 0;
 }
 
-struct userdiff_driver *userdiff_find_by_name(const char *name) {
+struct userdiff_driver *userdiff_find_by_name(const char *name)
+{
 	int len = strlen(name);
 	return userdiff_find_by_namelen(name, len);
 }
 
-struct userdiff_driver *userdiff_find_by_path(const char *path)
+struct userdiff_driver *userdiff_find_by_path(struct index_state *istate,
+					      const char *path)
 {
 	static struct attr_check *check;
 
@@ -278,8 +313,7 @@ struct userdiff_driver *userdiff_find_by
 		check = attr_check_initl("diff", NULL);
 	if (!path)
 		return NULL;
-	if (git_check_attr(path, check))
-		return NULL;
+	git_check_attr(istate, path, check);
 
 	if (ATTR_TRUE(check->items[0].value))
 		return &driver_true;
@@ -290,7 +324,8 @@ struct userdiff_driver *userdiff_find_by
 	return userdiff_find_by_name(check->items[0].value);
 }
 
-struct userdiff_driver *userdiff_get_textconv(struct userdiff_driver *driver)
+struct userdiff_driver *userdiff_get_textconv(struct repository *r,
+					      struct userdiff_driver *driver)
 {
 	if (!driver->textconv)
 		return NULL;
@@ -300,7 +335,7 @@ struct userdiff_driver *userdiff_get_tex
 		struct strbuf name = STRBUF_INIT;
 
 		strbuf_addf(&name, "textconv/%s", driver->name);
-		notes_cache_init(c, name.buf, driver->textconv);
+		notes_cache_init(r, c, name.buf, driver->textconv);
 		driver->textconv_cache = c;
 		strbuf_release(&name);
 	}
diff -pruN 1.2.1+git2.18.0-1/git/userdiff.h 1.2.3+git2.25.1-1/git/userdiff.h
--- 1.2.1+git2.18.0-1/git/userdiff.h	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/userdiff.h	2020-02-17 04:47:35.000000000 +0000
@@ -3,6 +3,9 @@
 
 #include "notes-cache.h"
 
+struct index_state;
+struct repository;
+
 struct userdiff_funcname {
 	const char *pattern;
 	int cflags;
@@ -21,12 +24,14 @@ struct userdiff_driver {
 
 int userdiff_config(const char *k, const char *v);
 struct userdiff_driver *userdiff_find_by_name(const char *name);
-struct userdiff_driver *userdiff_find_by_path(const char *path);
+struct userdiff_driver *userdiff_find_by_path(struct index_state *istate,
+					      const char *path);
 
 /*
  * Initialize any textconv-related fields in the driver and return it, or NULL
  * if it does not have textconv enabled at all.
  */
-struct userdiff_driver *userdiff_get_textconv(struct userdiff_driver *driver);
+struct userdiff_driver *userdiff_get_textconv(struct repository *r,
+					      struct userdiff_driver *driver);
 
 #endif /* USERDIFF */
diff -pruN 1.2.1+git2.18.0-1/git/utf8.c 1.2.3+git2.25.1-1/git/utf8.c
--- 1.2.1+git2.18.0-1/git/utf8.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/utf8.c	2020-02-17 04:47:35.000000000 +0000
@@ -4,6 +4,11 @@
 
 /* This code is originally from http://www.cl.cam.ac.uk/~mgk25/ucs/ */
 
+static const char utf16_be_bom[] = {'\xFE', '\xFF'};
+static const char utf16_le_bom[] = {'\xFF', '\xFE'};
+static const char utf32_be_bom[] = {'\0', '\0', '\xFE', '\xFF'};
+static const char utf32_le_bom[] = {'\xFF', '\xFE', '\0', '\0'};
+
 struct interval {
 	ucs_char_t first;
 	ucs_char_t last;
@@ -90,13 +95,11 @@ static int git_wcwidth(ucs_char_t ch)
 		return -1;
 
 	/* binary search in table of non-spacing characters */
-	if (bisearch(ch, zero_width, sizeof(zero_width)
-				/ sizeof(struct interval) - 1))
+	if (bisearch(ch, zero_width, ARRAY_SIZE(zero_width) - 1))
 		return 0;
 
 	/* binary search in table of double width characters */
-	if (bisearch(ch, double_width, sizeof(double_width)
-				/ sizeof(struct interval) - 1))
+	if (bisearch(ch, double_width, ARRAY_SIZE(double_width) - 1))
 		return 2;
 
 	return 1;
@@ -408,11 +411,10 @@ out:
  */
 static int same_utf_encoding(const char *src, const char *dst)
 {
-	if (istarts_with(src, "utf") && istarts_with(dst, "utf")) {
-		/* src[3] or dst[3] might be '\0' */
-		int i = (src[3] == '-' ? 4 : 3);
-		int j = (dst[3] == '-' ? 4 : 3);
-		return !strcasecmp(src+i, dst+j);
+	if (skip_iprefix(src, "utf", &src) && skip_iprefix(dst, "utf", &dst)) {
+		skip_prefix(src, "-", &src);
+		skip_prefix(dst, "-", &dst);
+		return !strcasecmp(src, dst);
 	}
 	return 0;
 }
@@ -470,16 +472,17 @@ int utf8_fprintf(FILE *stream, const cha
 #else
 	typedef char * iconv_ibp;
 #endif
-char *reencode_string_iconv(const char *in, size_t insz, iconv_t conv, int *outsz_p)
+char *reencode_string_iconv(const char *in, size_t insz, iconv_t conv,
+			    size_t bom_len, size_t *outsz_p)
 {
 	size_t outsz, outalloc;
 	char *out, *outpos;
 	iconv_ibp cp;
 
 	outsz = insz;
-	outalloc = outsz + 1; /* for terminating NUL */
+	outalloc = st_add(outsz, 1 + bom_len); /* for terminating NUL */
 	out = xmalloc(outalloc);
-	outpos = out;
+	outpos = out + bom_len;
 	cp = (iconv_ibp)in;
 
 	while (1) {
@@ -497,7 +500,7 @@ char *reencode_string_iconv(const char *
 			 * converting the rest.
 			 */
 			sofar = outpos - out;
-			outalloc = sofar + insz * 2 + 32;
+			outalloc = st_add3(sofar, st_mult(insz, 2), 32);
 			out = xrealloc(out, outalloc);
 			outpos = out + sofar;
 			outsz = outalloc - sofar - 1;
@@ -534,16 +537,50 @@ static const char *fallback_encoding(con
 	return name;
 }
 
-char *reencode_string_len(const char *in, int insz,
+char *reencode_string_len(const char *in, size_t insz,
 			  const char *out_encoding, const char *in_encoding,
-			  int *outsz)
+			  size_t *outsz)
 {
 	iconv_t conv;
 	char *out;
+	const char *bom_str = NULL;
+	size_t bom_len = 0;
 
 	if (!in_encoding)
 		return NULL;
 
+	/* UTF-16LE-BOM is the same as UTF-16 for reading */
+	if (same_utf_encoding("UTF-16LE-BOM", in_encoding))
+		in_encoding = "UTF-16";
+
+	/*
+	 * For writing, UTF-16 iconv typically creates "UTF-16BE-BOM"
+	 * Some users under Windows want the little endian version
+	 *
+	 * We handle UTF-16 and UTF-32 ourselves only if the platform does not
+	 * provide a BOM (which we require), since we want to match the behavior
+	 * of the system tools and libc as much as possible.
+	 */
+	if (same_utf_encoding("UTF-16LE-BOM", out_encoding)) {
+		bom_str = utf16_le_bom;
+		bom_len = sizeof(utf16_le_bom);
+		out_encoding = "UTF-16LE";
+	} else if (same_utf_encoding("UTF-16BE-BOM", out_encoding)) {
+		bom_str = utf16_be_bom;
+		bom_len = sizeof(utf16_be_bom);
+		out_encoding = "UTF-16BE";
+#ifdef ICONV_OMITS_BOM
+	} else if (same_utf_encoding("UTF-16", out_encoding)) {
+		bom_str = utf16_be_bom;
+		bom_len = sizeof(utf16_be_bom);
+		out_encoding = "UTF-16BE";
+	} else if (same_utf_encoding("UTF-32", out_encoding)) {
+		bom_str = utf32_be_bom;
+		bom_len = sizeof(utf32_be_bom);
+		out_encoding = "UTF-32BE";
+#endif
+	}
+
 	conv = iconv_open(out_encoding, in_encoding);
 	if (conv == (iconv_t) -1) {
 		in_encoding = fallback_encoding(in_encoding);
@@ -553,9 +590,10 @@ char *reencode_string_len(const char *in
 		if (conv == (iconv_t) -1)
 			return NULL;
 	}
-
-	out = reencode_string_iconv(in, insz, conv, outsz);
+	out = reencode_string_iconv(in, insz, conv, bom_len, outsz);
 	iconv_close(conv);
+	if (out && bom_str && bom_len)
+		memcpy(out, bom_str, bom_len);
 	return out;
 }
 #endif
@@ -566,11 +604,6 @@ static int has_bom_prefix(const char *da
 	return data && bom && (len >= bom_len) && !memcmp(data, bom, bom_len);
 }
 
-static const char utf16_be_bom[] = {0xFE, 0xFF};
-static const char utf16_le_bom[] = {0xFF, 0xFE};
-static const char utf32_be_bom[] = {0x00, 0x00, 0xFE, 0xFF};
-static const char utf32_le_bom[] = {0xFF, 0xFE, 0x00, 0x00};
-
 int has_prohibited_utf_bom(const char *enc, const char *data, size_t len)
 {
 	return (
diff -pruN 1.2.1+git2.18.0-1/git/utf8.h 1.2.3+git2.25.1-1/git/utf8.h
--- 1.2.1+git2.18.0-1/git/utf8.h	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/utf8.h	2020-02-17 04:47:35.000000000 +0000
@@ -1,6 +1,8 @@
 #ifndef GIT_UTF8_H
 #define GIT_UTF8_H
 
+struct strbuf;
+
 typedef unsigned int ucs_char_t;  /* assuming 32bit int */
 
 size_t display_mode_esc_sequence_len(const char *s);
@@ -14,7 +16,7 @@ __attribute__((format (printf, 2, 3)))
 int utf8_fprintf(FILE *, const char *, ...);
 
 extern const char utf8_bom[];
-extern int skip_utf8_bom(char **, size_t);
+int skip_utf8_bom(char **, size_t);
 
 void strbuf_add_wrapped_text(struct strbuf *buf,
 		const char *text, int indent, int indent2, int width);
@@ -25,14 +27,14 @@ void strbuf_utf8_replace(struct strbuf *
 
 #ifndef NO_ICONV
 char *reencode_string_iconv(const char *in, size_t insz,
-			    iconv_t conv, int *outsz);
-char *reencode_string_len(const char *in, int insz,
+			    iconv_t conv, size_t bom_len, size_t *outsz);
+char *reencode_string_len(const char *in, size_t insz,
 			  const char *out_encoding,
 			  const char *in_encoding,
-			  int *outsz);
+			  size_t *outsz);
 #else
-static inline char *reencode_string_len(const char *a, int b,
-					const char *c, const char *d, int *e)
+static inline char *reencode_string_len(const char *a, size_t b,
+					const char *c, const char *d, size_t *e)
 { if (e) *e = 0; return NULL; }
 #endif
 
diff -pruN 1.2.1+git2.18.0-1/git/varint.h 1.2.3+git2.25.1-1/git/varint.h
--- 1.2.1+git2.18.0-1/git/varint.h	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/varint.h	2020-02-17 04:47:35.000000000 +0000
@@ -1,7 +1,7 @@
 #ifndef VARINT_H
 #define VARINT_H
 
-extern int encode_varint(uintmax_t, unsigned char *);
-extern uintmax_t decode_varint(const unsigned char **);
+int encode_varint(uintmax_t, unsigned char *);
+uintmax_t decode_varint(const unsigned char **);
 
 #endif /* VARINT_H */
diff -pruN 1.2.1+git2.18.0-1/git/vcs-svn/fast_export.h 1.2.3+git2.25.1-1/git/vcs-svn/fast_export.h
--- 1.2.1+git2.18.0-1/git/vcs-svn/fast_export.h	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/vcs-svn/fast_export.h	2020-02-17 04:47:35.000000000 +0000
@@ -1,5 +1,5 @@
-#ifndef FAST_EXPORT_H_
-#define FAST_EXPORT_H_
+#ifndef FAST_EXPORT_H
+#define FAST_EXPORT_H
 
 struct strbuf;
 struct line_buffer;
diff -pruN 1.2.1+git2.18.0-1/git/vcs-svn/line_buffer.h 1.2.3+git2.25.1-1/git/vcs-svn/line_buffer.h
--- 1.2.1+git2.18.0-1/git/vcs-svn/line_buffer.h	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/vcs-svn/line_buffer.h	2020-02-17 04:47:35.000000000 +0000
@@ -1,5 +1,5 @@
-#ifndef LINE_BUFFER_H_
-#define LINE_BUFFER_H_
+#ifndef LINE_BUFFER_H
+#define LINE_BUFFER_H
 
 #include "strbuf.h"
 
diff -pruN 1.2.1+git2.18.0-1/git/vcs-svn/sliding_window.h 1.2.3+git2.25.1-1/git/vcs-svn/sliding_window.h
--- 1.2.1+git2.18.0-1/git/vcs-svn/sliding_window.h	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/vcs-svn/sliding_window.h	2020-02-17 04:47:35.000000000 +0000
@@ -1,5 +1,5 @@
-#ifndef SLIDING_WINDOW_H_
-#define SLIDING_WINDOW_H_
+#ifndef SLIDING_WINDOW_H
+#define SLIDING_WINDOW_H
 
 #include "strbuf.h"
 
@@ -13,6 +13,6 @@ struct sliding_view {
 
 #define SLIDING_VIEW_INIT(input, len)	{ (input), 0, 0, (len), STRBUF_INIT }
 
-extern int move_window(struct sliding_view *view, off_t off, size_t width);
+int move_window(struct sliding_view *view, off_t off, size_t width);
 
 #endif
diff -pruN 1.2.1+git2.18.0-1/git/vcs-svn/svndiff.h 1.2.3+git2.25.1-1/git/vcs-svn/svndiff.h
--- 1.2.1+git2.18.0-1/git/vcs-svn/svndiff.h	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/vcs-svn/svndiff.h	2020-02-17 04:47:35.000000000 +0000
@@ -1,10 +1,10 @@
-#ifndef SVNDIFF_H_
-#define SVNDIFF_H_
+#ifndef SVNDIFF_H
+#define SVNDIFF_H
 
 struct line_buffer;
 struct sliding_view;
 
-extern int svndiff0_apply(struct line_buffer *delta, off_t delta_len,
-		struct sliding_view *preimage, FILE *postimage);
+int svndiff0_apply(struct line_buffer *delta, off_t delta_len,
+		   struct sliding_view *preimage, FILE *postimage);
 
 #endif
diff -pruN 1.2.1+git2.18.0-1/git/vcs-svn/svndump.h 1.2.3+git2.25.1-1/git/vcs-svn/svndump.h
--- 1.2.1+git2.18.0-1/git/vcs-svn/svndump.h	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/vcs-svn/svndump.h	2020-02-17 04:47:35.000000000 +0000
@@ -1,5 +1,5 @@
-#ifndef SVNDUMP_H_
-#define SVNDUMP_H_
+#ifndef SVNDUMP_H
+#define SVNDUMP_H
 
 int svndump_init(const char *filename);
 int svndump_init_fd(int in_fd, int back_fd);
diff -pruN 1.2.1+git2.18.0-1/git/version 1.2.3+git2.25.1-1/git/version
--- 1.2.1+git2.18.0-1/git/version	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/version	2020-02-17 04:47:36.000000000 +0000
@@ -1 +1 @@
-2.18.0
+2.25.1
diff -pruN 1.2.1+git2.18.0-1/git/walker.c 1.2.3+git2.25.1-1/git/walker.c
--- 1.2.1+git2.18.0-1/git/walker.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/walker.c	2020-02-17 04:47:35.000000000 +0000
@@ -1,5 +1,7 @@
 #include "cache.h"
 #include "walker.h"
+#include "repository.h"
+#include "object-store.h"
 #include "commit.h"
 #include "tree.h"
 #include "tree-walk.h"
@@ -47,12 +49,14 @@ static int process_tree(struct walker *w
 		if (S_ISGITLINK(entry.mode))
 			continue;
 		if (S_ISDIR(entry.mode)) {
-			struct tree *tree = lookup_tree(entry.oid);
+			struct tree *tree = lookup_tree(the_repository,
+							&entry.oid);
 			if (tree)
 				obj = &tree->object;
 		}
 		else {
-			struct blob *blob = lookup_blob(entry.oid);
+			struct blob *blob = lookup_blob(the_repository,
+							&entry.oid);
 			if (blob)
 				obj = &blob->object;
 		}
@@ -177,7 +181,7 @@ static int loop(struct walker *walker)
 			}
 		}
 		if (!obj->type)
-			parse_object(&obj->oid);
+			parse_object(the_repository, &obj->oid);
 		if (process_object(walker, obj))
 			return -1;
 	}
@@ -203,7 +207,8 @@ static int interpret_target(struct walke
 static int mark_complete(const char *path, const struct object_id *oid,
 			 int flag, void *cb_data)
 {
-	struct commit *commit = lookup_commit_reference_gently(oid, 1);
+	struct commit *commit = lookup_commit_reference_gently(the_repository,
+							       oid, 1);
 
 	if (commit) {
 		commit->object.flags |= COMPLETE;
@@ -280,7 +285,7 @@ int walker_fetch(struct walker *walker,
 			error("Could not interpret response from server '%s' as something to pull", target[i]);
 			goto done;
 		}
-		if (process(walker, lookup_unknown_object(oids[i].hash)))
+		if (process(walker, lookup_unknown_object(&oids[i])))
 			goto done;
 	}
 
diff -pruN 1.2.1+git2.18.0-1/git/wildmatch.c 1.2.3+git2.25.1-1/git/wildmatch.c
--- 1.2.1+git2.18.0-1/git/wildmatch.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/wildmatch.c	2020-02-17 04:47:35.000000000 +0000
@@ -104,8 +104,8 @@ static int dowild(const uchar *p, const
 					    dowild(p + 1, text, flags) == WM_MATCH)
 						return WM_MATCH;
 					match_slash = 1;
-				} else
-					return WM_ABORT_MALFORMED;
+				} else /* WM_PATHNAME is set */
+					match_slash = 0;
 			} else
 				/* without WM_PATHNAME, '*' == '**' */
 				match_slash = flags & WM_PATHNAME ? 0 : 1;
diff -pruN 1.2.1+git2.18.0-1/git/wildmatch.h 1.2.3+git2.25.1-1/git/wildmatch.h
--- 1.2.1+git2.18.0-1/git/wildmatch.h	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/wildmatch.h	2020-02-17 04:47:35.000000000 +0000
@@ -4,7 +4,6 @@
 #define WM_CASEFOLD 1
 #define WM_PATHNAME 2
 
-#define WM_ABORT_MALFORMED 2
 #define WM_NOMATCH 1
 #define WM_MATCH 0
 #define WM_ABORT_ALL -1
diff -pruN 1.2.1+git2.18.0-1/git/worktree.c 1.2.3+git2.25.1-1/git/worktree.c
--- 1.2.1+git2.18.0-1/git/worktree.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/worktree.c	2020-02-17 04:47:35.000000000 +0000
@@ -49,18 +49,24 @@ static struct worktree *get_main_worktre
 	struct worktree *worktree = NULL;
 	struct strbuf path = STRBUF_INIT;
 	struct strbuf worktree_path = STRBUF_INIT;
-	int is_bare = 0;
 
 	strbuf_add_absolute_path(&worktree_path, get_git_common_dir());
-	is_bare = !strbuf_strip_suffix(&worktree_path, "/.git");
-	if (is_bare)
+	if (!strbuf_strip_suffix(&worktree_path, "/.git"))
 		strbuf_strip_suffix(&worktree_path, "/.");
 
 	strbuf_addf(&path, "%s/HEAD", get_git_common_dir());
 
 	worktree = xcalloc(1, sizeof(*worktree));
 	worktree->path = strbuf_detach(&worktree_path, NULL);
-	worktree->is_bare = is_bare;
+	/*
+	 * NEEDSWORK: If this function is called from a secondary worktree and
+	 * config.worktree is present, is_bare_repository_cfg will reflect the
+	 * contents of config.worktree, not the contents of the main worktree.
+	 * This means that worktree->is_bare may be set to 0 even if the main
+	 * worktree is configured to be bare.
+	 */
+	worktree->is_bare = (is_bare_repository_cfg == 1) ||
+		is_bare_repository();
 	add_head_info(worktree);
 
 	strbuf_release(&path);
@@ -217,10 +223,17 @@ struct worktree *find_worktree(struct wo
 
 	if (prefix)
 		arg = to_free = prefix_filename(prefix, arg);
-	path = real_pathdup(arg, 1);
-	for (; *list; list++)
-		if (!fspathcmp(path, real_path((*list)->path)))
+	path = real_pathdup(arg, 0);
+	if (!path) {
+		free(to_free);
+		return NULL;
+	}
+	for (; *list; list++) {
+		const char *wt_path = real_path_if_valid((*list)->path);
+
+		if (wt_path && !fspathcmp(path, wt_path))
 			break;
+	}
 	free(path);
 	free(to_free);
 	return *list;
@@ -231,7 +244,7 @@ int is_main_worktree(const struct worktr
 	return !wt->id;
 }
 
-const char *is_worktree_locked(struct worktree *wt)
+const char *worktree_lock_reason(struct worktree *wt)
 {
 	assert(!is_main_worktree(wt));
 
@@ -440,7 +453,7 @@ int submodule_uses_worktrees(const char
 	DIR *dir;
 	struct dirent *d;
 	int ret = 0;
-	struct repository_format format;
+	struct repository_format format = REPOSITORY_FORMAT_INIT;
 
 	submodule_gitdir = git_pathdup_submodule(path, "%s", "");
 	if (!submodule_gitdir)
@@ -458,8 +471,10 @@ int submodule_uses_worktrees(const char
 	read_repository_format(&format, sb.buf);
 	if (format.version != 0) {
 		strbuf_release(&sb);
+		clear_repository_format(&format);
 		return 1;
 	}
+	clear_repository_format(&format);
 
 	/* Replace config by worktrees. */
 	strbuf_setlen(&sb, sb.len - strlen("config"));
@@ -483,6 +498,75 @@ int submodule_uses_worktrees(const char
 	return ret;
 }
 
+int parse_worktree_ref(const char *worktree_ref, const char **name,
+		       int *name_length, const char **ref)
+{
+	if (skip_prefix(worktree_ref, "main-worktree/", &worktree_ref)) {
+		if (!*worktree_ref)
+			return -1;
+		if (name)
+			*name = NULL;
+		if (name_length)
+			*name_length = 0;
+		if (ref)
+			*ref = worktree_ref;
+		return 0;
+	}
+	if (skip_prefix(worktree_ref, "worktrees/", &worktree_ref)) {
+		const char *slash = strchr(worktree_ref, '/');
+
+		if (!slash || slash == worktree_ref || !slash[1])
+			return -1;
+		if (name)
+			*name = worktree_ref;
+		if (name_length)
+			*name_length = slash - worktree_ref;
+		if (ref)
+			*ref = slash + 1;
+		return 0;
+	}
+	return -1;
+}
+
+void strbuf_worktree_ref(const struct worktree *wt,
+			 struct strbuf *sb,
+			 const char *refname)
+{
+	switch (ref_type(refname)) {
+	case REF_TYPE_PSEUDOREF:
+	case REF_TYPE_PER_WORKTREE:
+		if (wt && !wt->is_current) {
+			if (is_main_worktree(wt))
+				strbuf_addstr(sb, "main-worktree/");
+			else
+				strbuf_addf(sb, "worktrees/%s/", wt->id);
+		}
+		break;
+
+	case REF_TYPE_MAIN_PSEUDOREF:
+	case REF_TYPE_OTHER_PSEUDOREF:
+		break;
+
+	case REF_TYPE_NORMAL:
+		/*
+		 * For shared refs, don't prefix worktrees/ or
+		 * main-worktree/. It's not necessary and
+		 * files-backend.c can't handle it anyway.
+		 */
+		break;
+	}
+	strbuf_addstr(sb, refname);
+}
+
+const char *worktree_ref(const struct worktree *wt, const char *refname)
+{
+	static struct strbuf sb = STRBUF_INIT;
+
+	strbuf_reset(&sb);
+	strbuf_worktree_ref(wt, &sb, refname);
+	return sb.buf;
+}
+
 int other_head_refs(each_ref_fn fn, void *cb_data)
 {
 	struct worktree **worktrees, **p;
@@ -491,13 +575,17 @@ int other_head_refs(each_ref_fn fn, void
 	worktrees = get_worktrees(0);
 	for (p = worktrees; *p; p++) {
 		struct worktree *wt = *p;
-		struct ref_store *refs;
+		struct object_id oid;
+		int flag;
 
 		if (wt->is_current)
 			continue;
 
-		refs = get_worktree_ref_store(wt);
-		ret = refs_head_ref(refs, fn, cb_data);
+		if (!refs_read_ref_full(get_main_ref_store(the_repository),
+					worktree_ref(wt, "HEAD"),
+					RESOLVE_REF_READING,
+					&oid, &flag))
+			ret = fn(worktree_ref(wt, "HEAD"), &oid, flag, cb_data);
 		if (ret)
 			break;
 	}
diff -pruN 1.2.1+git2.18.0-1/git/worktree.h 1.2.3+git2.25.1-1/git/worktree.h
--- 1.2.1+git2.18.0-1/git/worktree.h	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/worktree.h	2020-02-17 04:47:35.000000000 +0000
@@ -1,6 +1,7 @@
 #ifndef WORKTREE_H
 #define WORKTREE_H
 
+#include "cache.h"
 #include "refs.h"
 
 struct strbuf;
@@ -9,12 +10,12 @@ struct worktree {
 	char *path;
 	char *id;
 	char *head_ref;		/* NULL if HEAD is broken or detached */
-	char *lock_reason;	/* internal use */
+	char *lock_reason;	/* private - use worktree_lock_reason */
 	struct object_id head_oid;
 	int is_detached;
 	int is_bare;
 	int is_current;
-	int lock_reason_valid;
+	int lock_reason_valid; /* private */
 };
 
 /* Functions for acting on the information about worktrees. */
@@ -29,37 +30,37 @@ struct worktree {
  * The caller is responsible for freeing the memory from the returned
  * worktree(s).
  */
-extern struct worktree **get_worktrees(unsigned flags);
+struct worktree **get_worktrees(unsigned flags);
 
 /*
  * Returns 1 if linked worktrees exist, 0 otherwise.
  */
-extern int submodule_uses_worktrees(const char *path);
+int submodule_uses_worktrees(const char *path);
 
 /*
  * Return git dir of the worktree. Note that the path may be relative.
  * If wt is NULL, git dir of current worktree is returned.
  */
-extern const char *get_worktree_git_dir(const struct worktree *wt);
+const char *get_worktree_git_dir(const struct worktree *wt);
 
 /*
  * Search a worktree that can be unambiguously identified by
  * "arg". "prefix" must not be NULL.
  */
-extern struct worktree *find_worktree(struct worktree **list,
-				      const char *prefix,
-				      const char *arg);
+struct worktree *find_worktree(struct worktree **list,
+			       const char *prefix,
+			       const char *arg);
 
 /*
  * Return true if the given worktree is the main one.
  */
-extern int is_main_worktree(const struct worktree *wt);
+int is_main_worktree(const struct worktree *wt);
 
 /*
  * Return the reason string if the given worktree is locked or NULL
  * otherwise.
  */
-extern const char *is_worktree_locked(struct worktree *wt);
+const char *worktree_lock_reason(struct worktree *wt);
 
 #define WT_VALIDATE_WORKTREE_MISSING_OK (1 << 0)
 
@@ -67,28 +68,28 @@ extern const char *is_worktree_locked(st
  * Return zero if the worktree is in good condition. Error message is
  * returned if "errmsg" is not NULL.
  */
-extern int validate_worktree(const struct worktree *wt,
-			     struct strbuf *errmsg,
-			     unsigned flags);
+int validate_worktree(const struct worktree *wt,
+		      struct strbuf *errmsg,
+		      unsigned flags);
 
 /*
  * Update worktrees/xxx/gitdir with the new path.
  */
-extern void update_worktree_location(struct worktree *wt,
-				     const char *path_);
+void update_worktree_location(struct worktree *wt,
+			      const char *path_);
 
 /*
  * Free up the memory for worktree(s)
  */
-extern void free_worktrees(struct worktree **);
+void free_worktrees(struct worktree **);
 
 /*
  * Check if a per-worktree symref points to a ref in the main worktree
  * or any linked worktree, and return the worktree that holds the ref,
  * or NULL otherwise. The result may be destroyed by the next call.
  */
-extern const struct worktree *find_shared_symref(const char *symref,
-						 const char *target);
+const struct worktree *find_shared_symref(const char *symref,
+					  const char *target);
 
 /*
  * Similar to head_ref() for all HEADs _except_ one from the current
@@ -103,8 +104,32 @@ int is_worktree_being_bisected(const str
  * Similar to git_path() but can produce paths for a specified
  * worktree instead of current one
  */
-extern const char *worktree_git_path(const struct worktree *wt,
-				     const char *fmt, ...)
+const char *worktree_git_path(const struct worktree *wt,
+			      const char *fmt, ...)
 	__attribute__((format (printf, 2, 3)));
 
+/*
+ * Parse a worktree ref (i.e. with prefix main-worktree/ or
+ * worktrees/) and return the position of the worktree's name and
+ * length (or NULL and zero if it's main worktree), and ref.
+ *
+ * All name, name_length and ref arguments could be NULL.
+ */
+int parse_worktree_ref(const char *worktree_ref, const char **name,
+		       int *name_length, const char **ref);
+
+/*
+ * Return a refname suitable for access from the current ref store.
+ */
+void strbuf_worktree_ref(const struct worktree *wt,
+			 struct strbuf *sb,
+			 const char *refname);
+
+/*
+ * Return a refname suitable for access from the current ref
+ * store. The result will be destroyed at the next call.
+ */
+const char *worktree_ref(const struct worktree *wt,
+			 const char *refname);
+
 #endif
diff -pruN 1.2.1+git2.18.0-1/git/wrapper.c 1.2.3+git2.25.1-1/git/wrapper.c
--- 1.2.1+git2.18.0-1/git/wrapper.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/wrapper.c	2020-02-17 04:47:35.000000000 +0000
@@ -4,12 +4,6 @@
 #include "cache.h"
 #include "config.h"
 
-static void do_nothing(size_t size)
-{
-}
-
-static void (*try_to_free_routine)(size_t size) = do_nothing;
-
 static int memory_limit_check(size_t size, int gentle)
 {
 	static size_t limit = 0;
@@ -30,24 +24,11 @@ static int memory_limit_check(size_t siz
 	return 0;
 }
 
-try_to_free_t set_try_to_free_routine(try_to_free_t routine)
-{
-	try_to_free_t old = try_to_free_routine;
-	if (!routine)
-		routine = do_nothing;
-	try_to_free_routine = routine;
-	return old;
-}
-
 char *xstrdup(const char *str)
 {
 	char *ret = strdup(str);
-	if (!ret) {
-		try_to_free_routine(strlen(str) + 1);
-		ret = strdup(str);
-		if (!ret)
-			die("Out of memory, strdup failed");
-	}
+	if (!ret)
+		die("Out of memory, strdup failed");
 	return ret;
 }
 
@@ -61,19 +42,13 @@ static void *do_xmalloc(size_t size, int
 	if (!ret && !size)
 		ret = malloc(1);
 	if (!ret) {
-		try_to_free_routine(size);
-		ret = malloc(size);
-		if (!ret && !size)
-			ret = malloc(1);
-		if (!ret) {
-			if (!gentle)
-				die("Out of memory, malloc failed (tried to allocate %lu bytes)",
-				    (unsigned long)size);
-			else {
-				error("Out of memory, malloc failed (tried to allocate %lu bytes)",
-				      (unsigned long)size);
-				return NULL;
-			}
+		if (!gentle)
+			die("Out of memory, malloc failed (tried to allocate %lu bytes)",
+			    (unsigned long)size);
+		else {
+			error("Out of memory, malloc failed (tried to allocate %lu bytes)",
+			      (unsigned long)size);
+			return NULL;
 		}
 	}
 #ifdef XMALLOC_POISON
@@ -138,14 +113,8 @@ void *xrealloc(void *ptr, size_t size)
 	ret = realloc(ptr, size);
 	if (!ret && !size)
 		ret = realloc(ptr, 1);
-	if (!ret) {
-		try_to_free_routine(size);
-		ret = realloc(ptr, size);
-		if (!ret && !size)
-			ret = realloc(ptr, 1);
-		if (!ret)
-			die("Out of memory, realloc failed");
-	}
+	if (!ret)
+		die("Out of memory, realloc failed");
 	return ret;
 }
 
@@ -160,14 +129,8 @@ void *xcalloc(size_t nmemb, size_t size)
 	ret = calloc(nmemb, size);
 	if (!ret && (!nmemb || !size))
 		ret = calloc(1, 1);
-	if (!ret) {
-		try_to_free_routine(nmemb * size);
-		ret = calloc(nmemb, size);
-		if (!ret && (!nmemb || !size))
-			ret = calloc(1, 1);
-		if (!ret)
-			die("Out of memory, calloc failed");
-	}
+	if (!ret)
+		die("Out of memory, calloc failed");
 	return ret;
 }
 
@@ -478,7 +441,9 @@ int git_mkstemps_mode(char *pattern, int
 		"abcdefghijklmnopqrstuvwxyz"
 		"ABCDEFGHIJKLMNOPQRSTUVWXYZ"
 		"0123456789";
-	static const int num_letters = 62;
+	static const int num_letters = ARRAY_SIZE(letters) - 1;
+	static const char x_pattern[] = "XXXXXX";
+	static const int num_x = ARRAY_SIZE(x_pattern) - 1;
 	uint64_t value;
 	struct timeval tv;
 	char *filename_template;
@@ -487,12 +452,12 @@ int git_mkstemps_mode(char *pattern, int
 
 	len = strlen(pattern);
 
-	if (len < 6 + suffix_len) {
+	if (len < num_x + suffix_len) {
 		errno = EINVAL;
 		return -1;
 	}
 
-	if (strncmp(&pattern[len - 6 - suffix_len], "XXXXXX", 6)) {
+	if (strncmp(&pattern[len - num_x - suffix_len], x_pattern, num_x)) {
 		errno = EINVAL;
 		return -1;
 	}
@@ -502,17 +467,16 @@ int git_mkstemps_mode(char *pattern, int
 	 * Try TMP_MAX different filenames.
 	 */
 	gettimeofday(&tv, NULL);
-	value = ((size_t)(tv.tv_usec << 16)) ^ tv.tv_sec ^ getpid();
-	filename_template = &pattern[len - 6 - suffix_len];
+	value = ((uint64_t)tv.tv_usec << 16) ^ tv.tv_sec ^ getpid();
+	filename_template = &pattern[len - num_x - suffix_len];
 	for (count = 0; count < TMP_MAX; ++count) {
 		uint64_t v = value;
+		int i;
 		/* Fill in the random bits. */
-		filename_template[0] = letters[v % num_letters]; v /= num_letters;
-		filename_template[1] = letters[v % num_letters]; v /= num_letters;
-		filename_template[2] = letters[v % num_letters]; v /= num_letters;
-		filename_template[3] = letters[v % num_letters]; v /= num_letters;
-		filename_template[4] = letters[v % num_letters]; v /= num_letters;
-		filename_template[5] = letters[v % num_letters]; v /= num_letters;
+		for (i = 0; i < num_x; i++) {
+			filename_template[i] = letters[v % num_letters];
+			v /= num_letters;
+		}
 
 		fd = open(pattern, O_CREAT | O_EXCL | O_RDWR, mode);
 		if (fd >= 0)
@@ -690,3 +654,16 @@ int xgethostname(char *buf, size_t len)
 		buf[len - 1] = 0;
 	return ret;
 }
+
+int is_empty_or_missing_file(const char *filename)
+{
+	struct stat st;
+
+	if (stat(filename, &st) < 0) {
+		if (errno == ENOENT)
+			return 1;
+		die_errno(_("could not stat %s"), filename);
+	}
+
+	return !st.st_size;
+}
diff -pruN 1.2.1+git2.18.0-1/git/ws.c 1.2.3+git2.25.1-1/git/ws.c
--- 1.2.1+git2.18.0-1/git/ws.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/ws.c	2020-02-17 04:47:35.000000000 +0000
@@ -3,7 +3,6 @@
  *
  * Copyright (c) 2007 Junio C Hamano
  */
-
 #include "cache.h"
 #include "attr.h"
 
@@ -71,38 +70,34 @@ unsigned parse_whitespace_rule(const cha
 	return rule;
 }
 
-unsigned whitespace_rule(const char *pathname)
+unsigned whitespace_rule(struct index_state *istate, const char *pathname)
 {
 	static struct attr_check *attr_whitespace_rule;
+	const char *value;
 
 	if (!attr_whitespace_rule)
 		attr_whitespace_rule = attr_check_initl("whitespace", NULL);
 
-	if (!git_check_attr(pathname, attr_whitespace_rule)) {
-		const char *value;
-
-		value = attr_whitespace_rule->items[0].value;
-		if (ATTR_TRUE(value)) {
-			/* true (whitespace) */
-			unsigned all_rule = ws_tab_width(whitespace_rule_cfg);
-			int i;
-			for (i = 0; i < ARRAY_SIZE(whitespace_rule_names); i++)
-				if (!whitespace_rule_names[i].loosens_error &&
-				    !whitespace_rule_names[i].exclude_default)
-					all_rule |= whitespace_rule_names[i].rule_bits;
-			return all_rule;
-		} else if (ATTR_FALSE(value)) {
-			/* false (-whitespace) */
-			return ws_tab_width(whitespace_rule_cfg);
-		} else if (ATTR_UNSET(value)) {
-			/* reset to default (!whitespace) */
-			return whitespace_rule_cfg;
-		} else {
-			/* string */
-			return parse_whitespace_rule(value);
-		}
-	} else {
+	git_check_attr(istate, pathname, attr_whitespace_rule);
+	value = attr_whitespace_rule->items[0].value;
+	if (ATTR_TRUE(value)) {
+		/* true (whitespace) */
+		unsigned all_rule = ws_tab_width(whitespace_rule_cfg);
+		int i;
+		for (i = 0; i < ARRAY_SIZE(whitespace_rule_names); i++)
+			if (!whitespace_rule_names[i].loosens_error &&
+			    !whitespace_rule_names[i].exclude_default)
+				all_rule |= whitespace_rule_names[i].rule_bits;
+		return all_rule;
+	} else if (ATTR_FALSE(value)) {
+		/* false (-whitespace) */
+		return ws_tab_width(whitespace_rule_cfg);
+	} else if (ATTR_UNSET(value)) {
+		/* reset to default (!whitespace) */
 		return whitespace_rule_cfg;
+	} else {
+		/* string */
+		return parse_whitespace_rule(value);
 	}
 }
 
diff -pruN 1.2.1+git2.18.0-1/git/wt-status.c 1.2.3+git2.25.1-1/git/wt-status.c
--- 1.2.1+git2.18.0-1/git/wt-status.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/wt-status.c	2020-02-17 04:47:35.000000000 +0000
@@ -17,6 +17,9 @@
 #include "utf8.h"
 #include "worktree.h"
 #include "lockfile.h"
+#include "sequencer.h"
+
+#define AB_DELAY_WARNING_IN_MS (2 * 1000)
 
 static const char cut_line[] =
 "------------------------ >8 ------------------------\n";
@@ -119,9 +122,10 @@ static void status_printf_more(struct wt
 	va_end(ap);
 }
 
-void wt_status_prepare(struct wt_status *s)
+void wt_status_prepare(struct repository *r, struct wt_status *s)
 {
 	memset(s, 0, sizeof(*s));
+	s->repo = r;
 	memcpy(s->color_palette, default_wt_status_colors,
 	       sizeof(default_wt_status_colors));
 	s->show_untracked_files = SHOW_NORMAL_UNTRACKED_FILES;
@@ -177,9 +181,15 @@ static void wt_longstatus_print_unmerged
 		return;
 	if (s->whence != FROM_COMMIT)
 		;
-	else if (!s->is_initial)
-		status_printf_ln(s, c, _("  (use \"git reset %s <file>...\" to unstage)"), s->reference);
-	else
+	else if (!s->is_initial) {
+		if (!strcmp(s->reference, "HEAD"))
+			status_printf_ln(s, c,
+					 _("  (use \"git restore --staged <file>...\" to unstage)"));
+		else
+			status_printf_ln(s, c,
+					 _("  (use \"git restore --source=%s --staged <file>...\" to unstage)"),
+					 s->reference);
+	} else
 		status_printf_ln(s, c, _("  (use \"git rm --cached <file>...\" to unstage)"));
 
 	if (!both_deleted) {
@@ -192,7 +202,6 @@ static void wt_longstatus_print_unmerged
 	} else {
 		status_printf_ln(s, c, _("  (use \"git add/rm <file>...\" as appropriate to mark resolution)"));
 	}
-	status_printf_ln(s, c, "%s", "");
 }
 
 static void wt_longstatus_print_cached_header(struct wt_status *s)
@@ -204,11 +213,16 @@ static void wt_longstatus_print_cached_h
 		return;
 	if (s->whence != FROM_COMMIT)
 		; /* NEEDSWORK: use "git reset --unresolve"??? */
-	else if (!s->is_initial)
-		status_printf_ln(s, c, _("  (use \"git reset %s <file>...\" to unstage)"), s->reference);
-	else
+	else if (!s->is_initial) {
+		if (!strcmp(s->reference, "HEAD"))
+			status_printf_ln(s, c
+					 , _("  (use \"git restore --staged <file>...\" to unstage)"));
+		else
+			status_printf_ln(s, c,
+					 _("  (use \"git restore --source=%s --staged <file>...\" to unstage)"),
+					 s->reference);
+	} else
 		status_printf_ln(s, c, _("  (use \"git rm --cached <file>...\" to unstage)"));
-	status_printf_ln(s, c, "%s", "");
 }
 
 static void wt_longstatus_print_dirty_header(struct wt_status *s,
@@ -224,10 +238,9 @@ static void wt_longstatus_print_dirty_he
 		status_printf_ln(s, c, _("  (use \"git add <file>...\" to update what will be committed)"));
 	else
 		status_printf_ln(s, c, _("  (use \"git add/rm <file>...\" to update what will be committed)"));
-	status_printf_ln(s, c, _("  (use \"git checkout -- <file>...\" to discard changes in working directory)"));
+	status_printf_ln(s, c, _("  (use \"git restore <file>...\" to discard changes in working directory)"));
 	if (has_dirty_submodules)
 		status_printf_ln(s, c, _("  (commit or discard the untracked or modified content in submodules)"));
-	status_printf_ln(s, c, "%s", "");
 }
 
 static void wt_longstatus_print_other_header(struct wt_status *s,
@@ -239,7 +252,6 @@ static void wt_longstatus_print_other_he
 	if (!s->hints)
 		return;
 	status_printf_ln(s, c, _("  (use \"git %s <file>...\" to include in what will be committed)"), how);
-	status_printf_ln(s, c, "%s", "");
 }
 
 static void wt_longstatus_print_trailer(struct wt_status *s)
@@ -453,8 +465,8 @@ static void wt_status_collect_changed_cb
 			d->worktree_status = p->status;
 		if (S_ISGITLINK(p->two->mode)) {
 			d->dirty_submodule = p->two->dirty_submodule;
-			d->new_submodule_commits = !!oidcmp(&p->one->oid,
-							    &p->two->oid);
+			d->new_submodule_commits = !oideq(&p->one->oid,
+							  &p->two->oid);
 			if (s->status_format == STATUS_FORMAT_SHORT)
 				d->worktree_status = short_submodule_status(d);
 		}
@@ -494,19 +506,19 @@ static void wt_status_collect_changed_cb
 	}
 }
 
-static int unmerged_mask(const char *path)
+static int unmerged_mask(struct index_state *istate, const char *path)
 {
 	int pos, mask;
 	const struct cache_entry *ce;
 
-	pos = cache_name_pos(path, strlen(path));
+	pos = index_name_pos(istate, path, strlen(path));
 	if (0 <= pos)
 		return 0;
 
 	mask = 0;
 	pos = -pos-1;
-	while (pos < active_nr) {
-		ce = active_cache[pos++];
+	while (pos < istate->cache_nr) {
+		ce = istate->cache[pos++];
 		if (strcmp(ce->name, path) || !ce_stage(ce))
 			break;
 		mask |= (1 << (ce_stage(ce) - 1));
@@ -540,10 +552,12 @@ static void wt_status_collect_updated_cb
 			/* Leave {mode,oid}_head zero for an add. */
 			d->mode_index = p->two->mode;
 			oidcpy(&d->oid_index, &p->two->oid);
+			s->committable = 1;
 			break;
 		case DIFF_STATUS_DELETED:
 			d->mode_head = p->one->mode;
 			oidcpy(&d->oid_head, &p->one->oid);
+			s->committable = 1;
 			/* Leave {mode,oid}_index zero for a delete. */
 			break;
 
@@ -561,9 +575,11 @@ static void wt_status_collect_updated_cb
 			d->mode_index = p->two->mode;
 			oidcpy(&d->oid_head, &p->one->oid);
 			oidcpy(&d->oid_index, &p->two->oid);
+			s->committable = 1;
 			break;
 		case DIFF_STATUS_UNMERGED:
-			d->stagemask = unmerged_mask(p->two->path);
+			d->stagemask = unmerged_mask(s->repo->index,
+						     p->two->path);
 			/*
 			 * Don't bother setting {mode,oid}_{head,index} since the print
 			 * code will output the stage values directly and not use the
@@ -582,7 +598,7 @@ static void wt_status_collect_changes_wo
 {
 	struct rev_info rev;
 
-	init_revisions(&rev, NULL);
+	repo_init_revisions(s->repo, &rev, NULL);
 	setup_revisions(0, NULL, &rev, NULL);
 	rev.diffopt.output_format |= DIFF_FORMAT_CALLBACK;
 	rev.diffopt.flags.dirty_submodules = 1;
@@ -607,7 +623,7 @@ static void wt_status_collect_changes_in
 	struct rev_info rev;
 	struct setup_revision_opt opt;
 
-	init_revisions(&rev, NULL);
+	repo_init_revisions(s->repo, &rev, NULL);
 	memset(&opt, 0, sizeof(opt));
 	opt.def = s->is_initial ? empty_tree_oid_hex() : s->reference;
 	setup_revisions(0, NULL, &rev, &opt);
@@ -640,14 +656,15 @@ static void wt_status_collect_changes_in
 
 static void wt_status_collect_changes_initial(struct wt_status *s)
 {
+	struct index_state *istate = s->repo->index;
 	int i;
 
-	for (i = 0; i < active_nr; i++) {
+	for (i = 0; i < istate->cache_nr; i++) {
 		struct string_list_item *it;
 		struct wt_status_change_data *d;
-		const struct cache_entry *ce = active_cache[i];
+		const struct cache_entry *ce = istate->cache[i];
 
-		if (!ce_path_match(ce, &s->pathspec, NULL))
+		if (!ce_path_match(istate, ce, &s->pathspec, NULL))
 			continue;
 		if (ce_intent_to_add(ce))
 			continue;
@@ -665,11 +682,13 @@ static void wt_status_collect_changes_in
 			 * code will output the stage values directly and not use the
 			 * values in these fields.
 			 */
+			s->committable = 1;
 		} else {
 			d->index_status = DIFF_STATUS_ADDED;
 			/* Leave {mode,oid}_head zero for adds. */
 			d->mode_index = ce->ce_mode;
 			oidcpy(&d->oid_index, &ce->oid);
+			s->committable = 1;
 		}
 	}
 }
@@ -679,6 +698,7 @@ static void wt_status_collect_untracked(
 	int i;
 	struct dir_struct dir;
 	uint64_t t_begin = getnanotime();
+	struct index_state *istate = s->repo->index;
 
 	if (!s->show_untracked_files)
 		return;
@@ -693,25 +713,25 @@ static void wt_status_collect_untracked(
 		if (s->show_ignored_mode == SHOW_MATCHING_IGNORED)
 			dir.flags |= DIR_SHOW_IGNORED_TOO_MODE_MATCHING;
 	} else {
-		dir.untracked = the_index.untracked;
+		dir.untracked = istate->untracked;
 	}
 
 	setup_standard_excludes(&dir);
 
-	fill_directory(&dir, &the_index, &s->pathspec);
+	fill_directory(&dir, istate, &s->pathspec);
 
 	for (i = 0; i < dir.nr; i++) {
 		struct dir_entry *ent = dir.entries[i];
-		if (cache_name_is_other(ent->name, ent->len) &&
-		    dir_path_match(ent, &s->pathspec, 0, NULL))
+		if (index_name_is_other(istate, ent->name, ent->len) &&
+		    dir_path_match(istate, ent, &s->pathspec, 0, NULL))
 			string_list_insert(&s->untracked, ent->name);
 		free(ent);
 	}
 
 	for (i = 0; i < dir.ignored_nr; i++) {
 		struct dir_entry *ent = dir.ignored[i];
-		if (cache_name_is_other(ent->name, ent->len) &&
-		    dir_path_match(ent, &s->pathspec, 0, NULL))
+		if (index_name_is_other(istate, ent->name, ent->len) &&
+		    dir_path_match(istate, ent, &s->pathspec, 0, NULL))
 			string_list_insert(&s->ignored, ent->name);
 		free(ent);
 	}
@@ -724,15 +744,49 @@ static void wt_status_collect_untracked(
 		s->untracked_in_ms = (getnanotime() - t_begin) / 1000000;
 }
 
+static int has_unmerged(struct wt_status *s)
+{
+	int i;
+
+	for (i = 0; i < s->change.nr; i++) {
+		struct wt_status_change_data *d;
+		d = s->change.items[i].util;
+		if (d->stagemask)
+			return 1;
+	}
+	return 0;
+}
+
 void wt_status_collect(struct wt_status *s)
 {
+	trace2_region_enter("status", "worktrees", s->repo);
 	wt_status_collect_changes_worktree(s);
+	trace2_region_leave("status", "worktrees", s->repo);
 
-	if (s->is_initial)
+	if (s->is_initial) {
+		trace2_region_enter("status", "initial", s->repo);
 		wt_status_collect_changes_initial(s);
-	else
+		trace2_region_leave("status", "initial", s->repo);
+	} else {
+		trace2_region_enter("status", "index", s->repo);
 		wt_status_collect_changes_index(s);
+		trace2_region_leave("status", "index", s->repo);
+	}
+
+	trace2_region_enter("status", "untracked", s->repo);
 	wt_status_collect_untracked(s);
+	trace2_region_leave("status", "untracked", s->repo);
+
+	wt_status_get_state(s->repo, &s->state, s->branch && !strcmp(s->branch, "HEAD"));
+	if (s->state.merge_in_progress && !has_unmerged(s))
+		s->committable = 1;
+}
+
+void wt_status_collect_free_buffers(struct wt_status *s)
+{
+	free(s->state.branch);
+	free(s->state.onto);
+	free(s->state.detached_from);
 }
 
 static void wt_longstatus_print_unmerged(struct wt_status *s)
@@ -773,7 +827,6 @@ static void wt_longstatus_print_updated(
 			continue;
 		if (!shown_header) {
 			wt_longstatus_print_cached_header(s);
-			s->commitable = 1;
 			shown_header = 1;
 		}
 		wt_longstatus_print_change_data(s, WT_STATUS_UPDATED, it);
@@ -964,13 +1017,19 @@ size_t wt_status_locate_end(const char *
 	return len;
 }
 
-void wt_status_add_cut_line(FILE *fp)
+void wt_status_append_cut_line(struct strbuf *buf)
 {
 	const char *explanation = _("Do not modify or remove the line above.\nEverything below it will be ignored.");
+
+	strbuf_commented_addf(buf, "%s", cut_line);
+	strbuf_add_commented_lines(buf, explanation, strlen(explanation));
+}
+
+void wt_status_add_cut_line(FILE *fp)
+{
 	struct strbuf buf = STRBUF_INIT;
 
-	fprintf(fp, "%c %s", comment_line_char, cut_line);
-	strbuf_add_commented_lines(&buf, explanation, strlen(explanation));
+	wt_status_append_cut_line(&buf);
 	fputs(buf.buf, fp);
 	strbuf_release(&buf);
 }
@@ -982,7 +1041,7 @@ static void wt_longstatus_print_verbose(
 	int dirty_submodules;
 	const char *c = color(WT_STATUS_HEADER, s);
 
-	init_revisions(&rev, NULL);
+	repo_init_revisions(s->repo, &rev, NULL);
 	rev.diffopt.flags.allow_textconv = 1;
 	rev.diffopt.ita_invisible_in_index = 1;
 
@@ -1008,7 +1067,7 @@ static void wt_longstatus_print_verbose(
 		rev.diffopt.use_color = 0;
 		wt_status_add_cut_line(s->fp);
 	}
-	if (s->verbose > 1 && s->commitable) {
+	if (s->verbose > 1 && s->committable) {
 		/* print_updated() printed a header, so do we */
 		if (s->fp != stdout)
 			wt_longstatus_print_trailer(s);
@@ -1036,14 +1095,29 @@ static void wt_longstatus_print_tracking
 	struct branch *branch;
 	char comment_line_string[3];
 	int i;
+	uint64_t t_begin = 0;
 
 	assert(s->branch && !s->is_initial);
 	if (!skip_prefix(s->branch, "refs/heads/", &branch_name))
 		return;
 	branch = branch_get(branch_name);
+
+	t_begin = getnanotime();
+
 	if (!format_tracking_info(branch, &sb, s->ahead_behind_flags))
 		return;
 
+	if (advice_status_ahead_behind_warning &&
+	    s->ahead_behind_flags == AHEAD_BEHIND_FULL) {
+		uint64_t t_delta_in_ms = (getnanotime() - t_begin) / 1000000;
+		if (t_delta_in_ms > AB_DELAY_WARNING_IN_MS) {
+			strbuf_addf(&sb, _("\n"
+					   "It took %.2f seconds to compute the branch ahead/behind values.\n"
+					   "You can use '--no-ahead-behind' to avoid this.\n"),
+				    t_delta_in_ms / 1000.0);
+		}
+	}
+
 	i = 0;
 	if (s->display_comment_prefix) {
 		comment_line_string[i++] = comment_line_char;
@@ -1063,22 +1137,8 @@ static void wt_longstatus_print_tracking
 	strbuf_release(&sb);
 }
 
-static int has_unmerged(struct wt_status *s)
-{
-	int i;
-
-	for (i = 0; i < s->change.nr; i++) {
-		struct wt_status_change_data *d;
-		d = s->change.items[i].util;
-		if (d->stagemask)
-			return 1;
-	}
-	return 0;
-}
-
 static void show_merge_in_progress(struct wt_status *s,
-				struct wt_status_state *state,
-				const char *color)
+				   const char *color)
 {
 	if (has_unmerged(s)) {
 		status_printf_ln(s, color, _("You have unmerged paths."));
@@ -1089,7 +1149,6 @@ static void show_merge_in_progress(struc
 					 _("  (use \"git merge --abort\" to abort the merge)"));
 		}
 	} else {
-		s-> commitable = 1;
 		status_printf_ln(s, color,
 			_("All conflicts fixed but you are still merging."));
 		if (s->hints)
@@ -1100,16 +1159,15 @@ static void show_merge_in_progress(struc
 }
 
 static void show_am_in_progress(struct wt_status *s,
-				struct wt_status_state *state,
 				const char *color)
 {
 	status_printf_ln(s, color,
 		_("You are in the middle of an am session."));
-	if (state->am_empty_patch)
+	if (s->state.am_empty_patch)
 		status_printf_ln(s, color,
 			_("The current patch is empty."));
 	if (s->hints) {
-		if (!state->am_empty_patch)
+		if (!s->state.am_empty_patch)
 			status_printf_ln(s, color,
 				_("  (fix conflicts and then run \"git am --continue\")"));
 		status_printf_ln(s, color,
@@ -1182,7 +1240,9 @@ static void abbrev_sha1_in_line(struct s
 	int i;
 
 	if (starts_with(line->buf, "exec ") ||
-	    starts_with(line->buf, "x "))
+	    starts_with(line->buf, "x ") ||
+	    starts_with(line->buf, "label ") ||
+	    starts_with(line->buf, "l "))
 		return;
 
 	split = strbuf_split_max(line, ' ', 3);
@@ -1233,10 +1293,9 @@ static int read_rebase_todolist(const ch
 }
 
 static void show_rebase_information(struct wt_status *s,
-					struct wt_status_state *state,
-					const char *color)
+				    const char *color)
 {
-	if (state->rebase_interactive_in_progress) {
+	if (s->state.rebase_interactive_in_progress) {
 		int i;
 		int nr_lines_to_show = 2;
 
@@ -1287,28 +1346,26 @@ static void show_rebase_information(stru
 }
 
 static void print_rebase_state(struct wt_status *s,
-				struct wt_status_state *state,
-				const char *color)
+			       const char *color)
 {
-	if (state->branch)
+	if (s->state.branch)
 		status_printf_ln(s, color,
 				 _("You are currently rebasing branch '%s' on '%s'."),
-				 state->branch,
-				 state->onto);
+				 s->state.branch,
+				 s->state.onto);
 	else
 		status_printf_ln(s, color,
 				 _("You are currently rebasing."));
 }
 
 static void show_rebase_in_progress(struct wt_status *s,
-				struct wt_status_state *state,
-				const char *color)
+				    const char *color)
 {
 	struct stat st;
 
-	show_rebase_information(s, state, color);
+	show_rebase_information(s, color);
 	if (has_unmerged(s)) {
-		print_rebase_state(s, state, color);
+		print_rebase_state(s, color);
 		if (s->hints) {
 			status_printf_ln(s, color,
 				_("  (fix conflicts and then run \"git rebase --continue\")"));
@@ -1317,17 +1374,18 @@ static void show_rebase_in_progress(stru
 			status_printf_ln(s, color,
 				_("  (use \"git rebase --abort\" to check out the original branch)"));
 		}
-	} else if (state->rebase_in_progress || !stat(git_path_merge_msg(), &st)) {
-		print_rebase_state(s, state, color);
+	} else if (s->state.rebase_in_progress ||
+		   !stat(git_path_merge_msg(s->repo), &st)) {
+		print_rebase_state(s, color);
 		if (s->hints)
 			status_printf_ln(s, color,
 				_("  (all conflicts fixed: run \"git rebase --continue\")"));
 	} else if (split_commit_in_progress(s)) {
-		if (state->branch)
+		if (s->state.branch)
 			status_printf_ln(s, color,
 					 _("You are currently splitting a commit while rebasing branch '%s' on '%s'."),
-					 state->branch,
-					 state->onto);
+					 s->state.branch,
+					 s->state.onto);
 		else
 			status_printf_ln(s, color,
 					 _("You are currently splitting a commit during a rebase."));
@@ -1335,11 +1393,11 @@ static void show_rebase_in_progress(stru
 			status_printf_ln(s, color,
 				_("  (Once your working directory is clean, run \"git rebase --continue\")"));
 	} else {
-		if (state->branch)
+		if (s->state.branch)
 			status_printf_ln(s, color,
 					 _("You are currently editing a commit while rebasing branch '%s' on '%s'."),
-					 state->branch,
-					 state->onto);
+					 s->state.branch,
+					 s->state.onto);
 		else
 			status_printf_ln(s, color,
 					 _("You are currently editing a commit during a rebase."));
@@ -1354,51 +1412,71 @@ static void show_rebase_in_progress(stru
 }
 
 static void show_cherry_pick_in_progress(struct wt_status *s,
-					struct wt_status_state *state,
-					const char *color)
+					 const char *color)
 {
-	status_printf_ln(s, color, _("You are currently cherry-picking commit %s."),
-			find_unique_abbrev(&state->cherry_pick_head_oid, DEFAULT_ABBREV));
+	if (is_null_oid(&s->state.cherry_pick_head_oid))
+		status_printf_ln(s, color,
+			_("Cherry-pick currently in progress."));
+	else
+		status_printf_ln(s, color,
+			_("You are currently cherry-picking commit %s."),
+			find_unique_abbrev(&s->state.cherry_pick_head_oid,
+					   DEFAULT_ABBREV));
+
 	if (s->hints) {
 		if (has_unmerged(s))
 			status_printf_ln(s, color,
 				_("  (fix conflicts and run \"git cherry-pick --continue\")"));
+		else if (is_null_oid(&s->state.cherry_pick_head_oid))
+			status_printf_ln(s, color,
+				_("  (run \"git cherry-pick --continue\" to continue)"));
 		else
 			status_printf_ln(s, color,
 				_("  (all conflicts fixed: run \"git cherry-pick --continue\")"));
 		status_printf_ln(s, color,
+			_("  (use \"git cherry-pick --skip\" to skip this patch)"));
+		status_printf_ln(s, color,
 			_("  (use \"git cherry-pick --abort\" to cancel the cherry-pick operation)"));
 	}
 	wt_longstatus_print_trailer(s);
 }
 
 static void show_revert_in_progress(struct wt_status *s,
-					struct wt_status_state *state,
-					const char *color)
+				    const char *color)
 {
-	status_printf_ln(s, color, _("You are currently reverting commit %s."),
-			 find_unique_abbrev(&state->revert_head_oid, DEFAULT_ABBREV));
+	if (is_null_oid(&s->state.revert_head_oid))
+		status_printf_ln(s, color,
+			_("Revert currently in progress."));
+	else
+		status_printf_ln(s, color,
+			_("You are currently reverting commit %s."),
+			find_unique_abbrev(&s->state.revert_head_oid,
+					   DEFAULT_ABBREV));
 	if (s->hints) {
 		if (has_unmerged(s))
 			status_printf_ln(s, color,
 				_("  (fix conflicts and run \"git revert --continue\")"));
+		else if (is_null_oid(&s->state.revert_head_oid))
+			status_printf_ln(s, color,
+				_("  (run \"git revert --continue\" to continue)"));
 		else
 			status_printf_ln(s, color,
 				_("  (all conflicts fixed: run \"git revert --continue\")"));
 		status_printf_ln(s, color,
+			_("  (use \"git revert --skip\" to skip this patch)"));
+		status_printf_ln(s, color,
 			_("  (use \"git revert --abort\" to cancel the revert operation)"));
 	}
 	wt_longstatus_print_trailer(s);
 }
 
 static void show_bisect_in_progress(struct wt_status *s,
-				struct wt_status_state *state,
-				const char *color)
+				    const char *color)
 {
-	if (state->branch)
+	if (s->state.branch)
 		status_printf_ln(s, color,
 				 _("You are currently bisecting, started from branch '%s'."),
-				 state->branch);
+				 s->state.branch);
 	else
 		status_printf_ln(s, color,
 				 _("You are currently bisecting."));
@@ -1472,7 +1550,8 @@ static int grab_1st_switch(struct object
 	return 1;
 }
 
-static void wt_status_get_detached_from(struct wt_status_state *state)
+static void wt_status_get_detached_from(struct repository *r,
+					struct wt_status_state *state)
 {
 	struct grab_1st_switch_cbdata cb;
 	struct commit *commit;
@@ -1487,10 +1566,10 @@ static void wt_status_get_detached_from(
 
 	if (dwim_ref(cb.buf.buf, cb.buf.len, &oid, &ref) == 1 &&
 	    /* sha1 is a commit? match without further lookup */
-	    (!oidcmp(&cb.noid, &oid) ||
+	    (oideq(&cb.noid, &oid) ||
 	     /* perhaps sha1 is a tag, try to dereference to a commit */
-	     ((commit = lookup_commit_reference_gently(&oid, 1)) != NULL &&
-	      !oidcmp(&cb.noid, &commit->object.oid)))) {
+	     ((commit = lookup_commit_reference_gently(r, &oid, 1)) != NULL &&
+	      oideq(&cb.noid, &commit->object.oid)))) {
 		const char *from = ref;
 		if (!skip_prefix(from, "refs/tags/", &from))
 			skip_prefix(from, "refs/remotes/", &from);
@@ -1500,7 +1579,7 @@ static void wt_status_get_detached_from(
 			xstrdup(find_unique_abbrev(&cb.noid, DEFAULT_ABBREV));
 	oidcpy(&state->detached_oid, &cb.noid);
 	state->detached_at = !get_oid("HEAD", &oid) &&
-			     !oidcmp(&oid, &state->detached_oid);
+			     oideq(&oid, &state->detached_oid);
 
 	free(ref);
 	strbuf_release(&cb.buf);
@@ -1546,77 +1625,89 @@ int wt_status_check_bisect(const struct
 	return 0;
 }
 
-void wt_status_get_state(struct wt_status_state *state,
+void wt_status_get_state(struct repository *r,
+			 struct wt_status_state *state,
 			 int get_detached_from)
 {
 	struct stat st;
 	struct object_id oid;
+	enum replay_action action;
 
-	if (!stat(git_path_merge_head(), &st)) {
+	if (!stat(git_path_merge_head(r), &st)) {
+		wt_status_check_rebase(NULL, state);
 		state->merge_in_progress = 1;
 	} else if (wt_status_check_rebase(NULL, state)) {
 		;		/* all set */
-	} else if (!stat(git_path_cherry_pick_head(), &st) &&
+	} else if (!stat(git_path_cherry_pick_head(r), &st) &&
 			!get_oid("CHERRY_PICK_HEAD", &oid)) {
 		state->cherry_pick_in_progress = 1;
 		oidcpy(&state->cherry_pick_head_oid, &oid);
 	}
 	wt_status_check_bisect(NULL, state);
-	if (!stat(git_path_revert_head(), &st) &&
+	if (!stat(git_path_revert_head(r), &st) &&
 	    !get_oid("REVERT_HEAD", &oid)) {
 		state->revert_in_progress = 1;
 		oidcpy(&state->revert_head_oid, &oid);
 	}
-
+	if (!sequencer_get_last_command(r, &action)) {
+		if (action == REPLAY_PICK) {
+			state->cherry_pick_in_progress = 1;
+			oidcpy(&state->cherry_pick_head_oid, &null_oid);
+		} else {
+			state->revert_in_progress = 1;
+			oidcpy(&state->revert_head_oid, &null_oid);
+		}
+	}
 	if (get_detached_from)
-		wt_status_get_detached_from(state);
+		wt_status_get_detached_from(r, state);
 }
 
-static void wt_longstatus_print_state(struct wt_status *s,
-				      struct wt_status_state *state)
+static void wt_longstatus_print_state(struct wt_status *s)
 {
 	const char *state_color = color(WT_STATUS_HEADER, s);
-	if (state->merge_in_progress)
-		show_merge_in_progress(s, state, state_color);
-	else if (state->am_in_progress)
-		show_am_in_progress(s, state, state_color);
+	struct wt_status_state *state = &s->state;
+
+	if (state->merge_in_progress) {
+		if (state->rebase_interactive_in_progress) {
+			show_rebase_information(s, state_color);
+			fputs("\n", s->fp);
+		}
+		show_merge_in_progress(s, state_color);
+	} else if (state->am_in_progress)
+		show_am_in_progress(s, state_color);
 	else if (state->rebase_in_progress || state->rebase_interactive_in_progress)
-		show_rebase_in_progress(s, state, state_color);
+		show_rebase_in_progress(s, state_color);
 	else if (state->cherry_pick_in_progress)
-		show_cherry_pick_in_progress(s, state, state_color);
+		show_cherry_pick_in_progress(s, state_color);
 	else if (state->revert_in_progress)
-		show_revert_in_progress(s, state, state_color);
+		show_revert_in_progress(s, state_color);
 	if (state->bisect_in_progress)
-		show_bisect_in_progress(s, state, state_color);
+		show_bisect_in_progress(s, state_color);
 }
 
 static void wt_longstatus_print(struct wt_status *s)
 {
 	const char *branch_color = color(WT_STATUS_ONBRANCH, s);
 	const char *branch_status_color = color(WT_STATUS_HEADER, s);
-	struct wt_status_state state;
-
-	memset(&state, 0, sizeof(state));
-	wt_status_get_state(&state,
-			    s->branch && !strcmp(s->branch, "HEAD"));
 
 	if (s->branch) {
 		const char *on_what = _("On branch ");
 		const char *branch_name = s->branch;
 		if (!strcmp(branch_name, "HEAD")) {
 			branch_status_color = color(WT_STATUS_NOBRANCH, s);
-			if (state.rebase_in_progress || state.rebase_interactive_in_progress) {
-				if (state.rebase_interactive_in_progress)
+			if (s->state.rebase_in_progress ||
+			    s->state.rebase_interactive_in_progress) {
+				if (s->state.rebase_interactive_in_progress)
 					on_what = _("interactive rebase in progress; onto ");
 				else
 					on_what = _("rebase in progress; onto ");
-				branch_name = state.onto;
-			} else if (state.detached_from) {
-				branch_name = state.detached_from;
-				if (state.detached_at)
-					on_what = _("HEAD detached at ");
+				branch_name = s->state.onto;
+			} else if (s->state.detached_from) {
+				branch_name = s->state.detached_from;
+				if (s->state.detached_at)
+					on_what = HEAD_DETACHED_AT;
 				else
-					on_what = _("HEAD detached from ");
+					on_what = HEAD_DETACHED_FROM;
 			} else {
 				branch_name = "";
 				on_what = _("Not currently on any branch.");
@@ -1630,10 +1721,7 @@ static void wt_longstatus_print(struct w
 			wt_longstatus_print_tracking(s);
 	}
 
-	wt_longstatus_print_state(s, &state);
-	free(state.branch);
-	free(state.onto);
-	free(state.detached_from);
+	wt_longstatus_print_state(s);
 
 	if (s->is_initial) {
 		status_printf_ln(s, color(WT_STATUS_HEADER, s), "%s", "");
@@ -1665,14 +1753,14 @@ static void wt_longstatus_print(struct w
 					   "new files yourself (see 'git help status')."),
 					 s->untracked_in_ms / 1000.0);
 		}
-	} else if (s->commitable)
+	} else if (s->committable)
 		status_printf_ln(s, GIT_COLOR_NORMAL, _("Untracked files not listed%s"),
 			s->hints
 			? _(" (use -u option to show untracked files)") : "");
 
 	if (s->verbose)
 		wt_longstatus_print_verbose(s);
-	if (!s->commitable) {
+	if (!s->committable) {
 		if (s->amend)
 			status_printf_ln(s, GIT_COLOR_NORMAL, _("No changes"));
 		else if (s->nowarn)
@@ -1829,7 +1917,7 @@ static void wt_shortstatus_print_trackin
 	color_fprintf(s->fp, branch_color_local, "%s", branch_name);
 
 	sti = stat_tracking_info(branch, &num_ours, &num_theirs, &base,
-				 s->ahead_behind_flags);
+				 0, s->ahead_behind_flags);
 	if (sti < 0) {
 		if (!base)
 			goto conclude;
@@ -1937,15 +2025,11 @@ static void wt_porcelain_v2_print_tracki
 	struct branch *branch;
 	const char *base;
 	const char *branch_name;
-	struct wt_status_state state;
 	int ab_info, nr_ahead, nr_behind;
 	char eol = s->null_termination ? '\0' : '\n';
 
-	memset(&state, 0, sizeof(state));
-	wt_status_get_state(&state, s->branch && !strcmp(s->branch, "HEAD"));
-
 	fprintf(s->fp, "# branch.oid %s%c",
-			(s->is_initial ? "(initial)" : sha1_to_hex(s->sha1_commit)),
+			(s->is_initial ? "(initial)" : oid_to_hex(&s->oid_commit)),
 			eol);
 
 	if (!s->branch)
@@ -1954,10 +2038,11 @@ static void wt_porcelain_v2_print_tracki
 		if (!strcmp(s->branch, "HEAD")) {
 			fprintf(s->fp, "# branch.head %s%c", "(detached)", eol);
 
-			if (state.rebase_in_progress || state.rebase_interactive_in_progress)
-				branch_name = state.onto;
-			else if (state.detached_from)
-				branch_name = state.detached_from;
+			if (s->state.rebase_in_progress ||
+			    s->state.rebase_interactive_in_progress)
+				branch_name = s->state.onto;
+			else if (s->state.detached_from)
+				branch_name = s->state.detached_from;
 			else
 				branch_name = "";
 		} else {
@@ -1971,7 +2056,7 @@ static void wt_porcelain_v2_print_tracki
 		branch = branch_get(branch_name);
 		base = NULL;
 		ab_info = stat_tracking_info(branch, &nr_ahead, &nr_behind,
-					     &base, s->ahead_behind_flags);
+					     &base, 0, s->ahead_behind_flags);
 		if (base) {
 			base = shorten_unambiguous_ref(base, 0);
 			fprintf(s->fp, "# branch.upstream %s%c", base, eol);
@@ -1991,10 +2076,6 @@ static void wt_porcelain_v2_print_tracki
 			}
 		}
 	}
-
-	free(state.branch);
-	free(state.onto);
-	free(state.detached_from);
 }
 
 /*
@@ -2024,9 +2105,7 @@ static void wt_porcelain_v2_submodule_st
 /*
  * Fix-up changed entries before we print them.
  */
-static void wt_porcelain_v2_fix_up_changed(
-	struct string_list_item *it,
-	struct wt_status *s)
+static void wt_porcelain_v2_fix_up_changed(struct string_list_item *it)
 {
 	struct wt_status_change_data *d = it->util;
 
@@ -2086,7 +2165,7 @@ static void wt_porcelain_v2_print_change
 	char submodule_token[5];
 	char sep_char, eol_char;
 
-	wt_porcelain_v2_fix_up_changed(it, s);
+	wt_porcelain_v2_fix_up_changed(it);
 	wt_porcelain_v2_submodule_state(d, submodule_token);
 
 	key[0] = d->index_status ? d->index_status : '.';
@@ -2142,6 +2221,7 @@ static void wt_porcelain_v2_print_unmerg
 	struct wt_status *s)
 {
 	struct wt_status_change_data *d = it->util;
+	struct index_state *istate = s->repo->index;
 	const struct cache_entry *ce;
 	struct strbuf buf_index = STRBUF_INIT;
 	const char *path_index = NULL;
@@ -2180,11 +2260,11 @@ static void wt_porcelain_v2_print_unmerg
 	 */
 	memset(stages, 0, sizeof(stages));
 	sum = 0;
-	pos = cache_name_pos(it->string, strlen(it->string));
+	pos = index_name_pos(istate, it->string, strlen(it->string));
 	assert(pos < 0);
 	pos = -pos-1;
-	while (pos < active_nr) {
-		ce = active_cache[pos++];
+	while (pos < istate->cache_nr) {
+		ce = istate->cache[pos++];
 		stage = ce_stage(ce);
 		if (strcmp(ce->name, it->string) || !stage)
 			break;
@@ -2286,6 +2366,13 @@ static void wt_porcelain_v2_print(struct
 
 void wt_status_print(struct wt_status *s)
 {
+	trace2_data_intmax("status", s->repo, "count/changed", s->change.nr);
+	trace2_data_intmax("status", s->repo, "count/untracked",
+			   s->untracked.nr);
+	trace2_data_intmax("status", s->repo, "count/ignored", s->ignored.nr);
+
+	trace2_region_enter("status", "print", s->repo);
+
 	switch (s->status_format) {
 	case STATUS_FORMAT_SHORT:
 		wt_shortstatus_print(s);
@@ -2304,17 +2391,19 @@ void wt_status_print(struct wt_status *s
 		wt_longstatus_print(s);
 		break;
 	}
+
+	trace2_region_leave("status", "print", s->repo);
 }
 
 /**
  * Returns 1 if there are unstaged changes, 0 otherwise.
  */
-int has_unstaged_changes(int ignore_submodules)
+int has_unstaged_changes(struct repository *r, int ignore_submodules)
 {
 	struct rev_info rev_info;
 	int result;
 
-	init_revisions(&rev_info, NULL);
+	repo_init_revisions(r, &rev_info, NULL);
 	if (ignore_submodules) {
 		rev_info.diffopt.flags.ignore_submodules = 1;
 		rev_info.diffopt.flags.override_submodule_config = 1;
@@ -2328,19 +2417,30 @@ int has_unstaged_changes(int ignore_subm
 /**
  * Returns 1 if there are uncommitted changes, 0 otherwise.
  */
-int has_uncommitted_changes(int ignore_submodules)
+int has_uncommitted_changes(struct repository *r,
+			    int ignore_submodules)
 {
 	struct rev_info rev_info;
 	int result;
 
-	if (is_cache_unborn())
+	if (is_index_unborn(r->index))
 		return 0;
 
-	init_revisions(&rev_info, NULL);
+	repo_init_revisions(r, &rev_info, NULL);
 	if (ignore_submodules)
 		rev_info.diffopt.flags.ignore_submodules = 1;
 	rev_info.diffopt.flags.quick = 1;
+
 	add_head_to_pending(&rev_info);
+	if (!rev_info.pending.nr) {
+		/*
+		 * We have no head (or it's corrupt); use the empty tree,
+		 * which will complain if the index is non-empty.
+		 */
+		struct tree *tree = lookup_tree(r, the_hash_algo->empty_tree);
+		add_pending_object(&rev_info, &tree->object, "");
+	}
+
 	diff_setup_done(&rev_info.diffopt);
 	result = run_diff_index(&rev_info, 1);
 	return diff_result_code(&rev_info.diffopt, result);
@@ -2350,24 +2450,28 @@ int has_uncommitted_changes(int ignore_s
  * If the work tree has unstaged or uncommitted changes, dies with the
  * appropriate message.
  */
-int require_clean_work_tree(const char *action, const char *hint, int ignore_submodules, int gently)
+int require_clean_work_tree(struct repository *r,
+			    const char *action,
+			    const char *hint,
+			    int ignore_submodules,
+			    int gently)
 {
 	struct lock_file lock_file = LOCK_INIT;
 	int err = 0, fd;
 
-	fd = hold_locked_index(&lock_file, 0);
-	refresh_cache(REFRESH_QUIET);
+	fd = repo_hold_locked_index(r, &lock_file, 0);
+	refresh_index(r->index, REFRESH_QUIET, NULL, NULL, NULL);
 	if (0 <= fd)
-		update_index_if_able(&the_index, &lock_file);
+		repo_update_index_if_able(r, &lock_file);
 	rollback_lock_file(&lock_file);
 
-	if (has_unstaged_changes(ignore_submodules)) {
+	if (has_unstaged_changes(r, ignore_submodules)) {
 		/* TRANSLATORS: the action is e.g. "pull with rebase" */
 		error(_("cannot %s: You have unstaged changes."), _(action));
 		err = 1;
 	}
 
-	if (has_uncommitted_changes(ignore_submodules)) {
+	if (has_uncommitted_changes(r, ignore_submodules)) {
 		if (err)
 			error(_("additionally, your index contains uncommitted changes."));
 		else
diff -pruN 1.2.1+git2.18.0-1/git/wt-status.h 1.2.3+git2.25.1-1/git/wt-status.h
--- 1.2.1+git2.18.0-1/git/wt-status.h	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/wt-status.h	2020-02-17 04:47:35.000000000 +0000
@@ -1,12 +1,12 @@
 #ifndef STATUS_H
 #define STATUS_H
 
-#include <stdio.h>
 #include "string-list.h"
 #include "color.h"
 #include "pathspec.h"
 #include "remote.h"
 
+struct repository;
 struct worktree;
 
 enum color_wt_status {
@@ -64,7 +64,29 @@ enum wt_status_format {
 	STATUS_FORMAT_UNSPECIFIED
 };
 
+#define HEAD_DETACHED_AT _("HEAD detached at ")
+#define HEAD_DETACHED_FROM _("HEAD detached from ")
+
+struct wt_status_state {
+	int merge_in_progress;
+	int am_in_progress;
+	int am_empty_patch;
+	int rebase_in_progress;
+	int rebase_interactive_in_progress;
+	int cherry_pick_in_progress;
+	int bisect_in_progress;
+	int revert_in_progress;
+	int detached_at;
+	char *branch;
+	char *onto;
+	char *detached_from;
+	struct object_id detached_oid;
+	struct object_id revert_head_oid;
+	struct object_id cherry_pick_head_oid;
+};
+
 struct wt_status {
+	struct repository *repo;
 	int is_initial;
 	char *branch;
 	const char *reference;
@@ -93,10 +115,11 @@ struct wt_status {
 	int rename_score;
 	int rename_limit;
 	enum wt_status_format status_format;
-	unsigned char sha1_commit[GIT_MAX_RAWSZ]; /* when not Initial */
+	struct wt_status_state state;
+	struct object_id oid_commit; /* when not Initial */
 
 	/* These are computed during processing of the individual sections */
-	int commitable;
+	int committable;
 	int workdir_dirty;
 	const char *index_file;
 	FILE *fp;
@@ -107,30 +130,16 @@ struct wt_status {
 	uint32_t untracked_in_ms;
 };
 
-struct wt_status_state {
-	int merge_in_progress;
-	int am_in_progress;
-	int am_empty_patch;
-	int rebase_in_progress;
-	int rebase_interactive_in_progress;
-	int cherry_pick_in_progress;
-	int bisect_in_progress;
-	int revert_in_progress;
-	int detached_at;
-	char *branch;
-	char *onto;
-	char *detached_from;
-	struct object_id detached_oid;
-	struct object_id revert_head_oid;
-	struct object_id cherry_pick_head_oid;
-};
-
 size_t wt_status_locate_end(const char *s, size_t len);
+void wt_status_append_cut_line(struct strbuf *buf);
 void wt_status_add_cut_line(FILE *fp);
-void wt_status_prepare(struct wt_status *s);
+void wt_status_prepare(struct repository *r, struct wt_status *s);
 void wt_status_print(struct wt_status *s);
 void wt_status_collect(struct wt_status *s);
-void wt_status_get_state(struct wt_status_state *state, int get_detached_from);
+void wt_status_collect_free_buffers(struct wt_status *s);
+void wt_status_get_state(struct repository *repo,
+			 struct wt_status_state *state,
+			 int get_detached_from);
 int wt_status_check_rebase(const struct worktree *wt,
 			   struct wt_status_state *state);
 int wt_status_check_bisect(const struct worktree *wt,
@@ -142,9 +151,14 @@ __attribute__((format (printf, 3, 4)))
 void status_printf(struct wt_status *s, const char *color, const char *fmt, ...);
 
 /* The following functions expect that the caller took care of reading the index. */
-int has_unstaged_changes(int ignore_submodules);
-int has_uncommitted_changes(int ignore_submodules);
-int require_clean_work_tree(const char *action, const char *hint,
-	int ignore_submodules, int gently);
+int has_unstaged_changes(struct repository *repo,
+			 int ignore_submodules);
+int has_uncommitted_changes(struct repository *repo,
+			    int ignore_submodules);
+int require_clean_work_tree(struct repository *repo,
+			    const char *action,
+			    const char *hint,
+			    int ignore_submodules,
+			    int gently);
 
 #endif /* STATUS_H */
diff -pruN 1.2.1+git2.18.0-1/git/xdiff/xdiff.h 1.2.3+git2.25.1-1/git/xdiff/xdiff.h
--- 1.2.1+git2.18.0-1/git/xdiff/xdiff.h	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/xdiff/xdiff.h	2020-02-17 04:47:35.000000000 +0000
@@ -52,14 +52,6 @@ extern "C" {
 #define XDL_EMIT_FUNCNAMES (1 << 0)
 #define XDL_EMIT_FUNCCONTEXT (1 << 2)
 
-#define XDL_MMB_READONLY (1 << 0)
-
-#define XDL_MMF_ATOMIC (1 << 0)
-
-#define XDL_BDOP_INS 1
-#define XDL_BDOP_CPY 2
-#define XDL_BDOP_INSB 3
-
 /* merge simplification levels */
 #define XDL_MERGE_MINIMAL 0
 #define XDL_MERGE_EAGER 1
@@ -94,7 +86,11 @@ typedef struct s_xpparam {
 
 typedef struct s_xdemitcb {
 	void *priv;
-	int (*outf)(void *, mmbuffer_t *, int);
+	int (*out_hunk)(void *,
+			long old_begin, long old_nr,
+			long new_begin, long new_nr,
+			const char *func, long funclen);
+	int (*out_line)(void *, mmbuffer_t *, int);
 } xdemitcb_t;
 
 typedef long (*find_func_t)(const char *line, long line_len, char *buffer, long buffer_size, void *priv);
@@ -117,9 +113,9 @@ typedef struct s_bdiffparam {
 } bdiffparam_t;
 
 
-#define xdl_malloc(x) malloc(x)
+#define xdl_malloc(x) xmalloc(x)
 #define xdl_free(ptr) free(ptr)
-#define xdl_realloc(ptr,x) realloc(ptr,x)
+#define xdl_realloc(ptr,x) xrealloc(ptr,x)
 
 void *xdl_mmfile_first(mmfile_t *mmf, long *size);
 long xdl_mmfile_size(mmfile_t *mmf);
diff -pruN 1.2.1+git2.18.0-1/git/xdiff/xdiffi.c 1.2.3+git2.25.1-1/git/xdiff/xdiffi.c
--- 1.2.1+git2.18.0-1/git/xdiff/xdiffi.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/xdiff/xdiffi.c	2020-02-17 04:47:35.000000000 +0000
@@ -22,42 +22,25 @@
 
 #include "xinclude.h"
 
-
-
 #define XDL_MAX_COST_MIN 256
 #define XDL_HEUR_MIN_COST 256
 #define XDL_LINE_MAX (long)((1UL << (CHAR_BIT * sizeof(long) - 1)) - 1)
 #define XDL_SNAKE_CNT 20
 #define XDL_K_HEUR 4
 
-
-
 typedef struct s_xdpsplit {
 	long i1, i2;
 	int min_lo, min_hi;
 } xdpsplit_t;
 
-
-
-
-static long xdl_split(unsigned long const *ha1, long off1, long lim1,
-		      unsigned long const *ha2, long off2, long lim2,
-		      long *kvdf, long *kvdb, int need_min, xdpsplit_t *spl,
-		      xdalgoenv_t *xenv);
-static xdchange_t *xdl_add_change(xdchange_t *xscr, long i1, long i2, long chg1, long chg2);
-
-
-
-
-
 /*
  * See "An O(ND) Difference Algorithm and its Variations", by Eugene Myers.
  * Basically considers a "box" (off1, off2, lim1, lim2) and scan from both
  * the forward diagonal starting from (off1, off2) and the backward diagonal
  * starting from (lim1, lim2). If the K values on the same diagonal crosses
- * returns the furthest point of reach. We might end up having to expensive
- * cases using this algorithm is full, so a little bit of heuristic is needed
- * to cut the search and to return a suboptimal point.
+ * returns the furthest point of reach. We might encounter expensive edge cases
+ * using this algorithm, so a little bit of heuristic is needed to cut the
+ * search and to return a suboptimal point.
  */
 static long xdl_split(unsigned long const *ha1, long off1, long lim1,
 		      unsigned long const *ha2, long off2, long lim2,
@@ -80,11 +63,13 @@ static long xdl_split(unsigned long cons
 		int got_snake = 0;
 
 		/*
-		 * We need to extent the diagonal "domain" by one. If the next
+		 * We need to extend the diagonal "domain" by one. If the next
 		 * values exits the box boundaries we need to change it in the
-		 * opposite direction because (max - min) must be a power of two.
+		 * opposite direction because (max - min) must be a power of
+		 * two.
+		 *
 		 * Also we initialize the external K value to -1 so that we can
-		 * avoid extra conditions check inside the core loop.
+		 * avoid extra conditions in the check inside the core loop.
 		 */
 		if (fmin > dmin)
 			kvdf[--fmin - 1] = -1;
@@ -115,11 +100,13 @@ static long xdl_split(unsigned long cons
 		}
 
 		/*
-		 * We need to extent the diagonal "domain" by one. If the next
+		 * We need to extend the diagonal "domain" by one. If the next
 		 * values exits the box boundaries we need to change it in the
-		 * opposite direction because (max - min) must be a power of two.
+		 * opposite direction because (max - min) must be a power of
+		 * two.
+		 *
 		 * Also we initialize the external K value to -1 so that we can
-		 * avoid extra conditions check inside the core loop.
+		 * avoid extra conditions in the check inside the core loop.
 		 */
 		if (bmin > dmin)
 			kvdb[--bmin - 1] = XDL_LINE_MAX;
@@ -155,7 +142,7 @@ static long xdl_split(unsigned long cons
 		/*
 		 * If the edit cost is above the heuristic trigger and if
 		 * we got a good snake, we sample current diagonals to see
-		 * if some of the, have reached an "interesting" path. Our
+		 * if some of them have reached an "interesting" path. Our
 		 * measure is a function of the distance from the diagonal
 		 * corner (i1 + i2) penalized with the distance from the
 		 * mid diagonal itself. If this value is above the current
@@ -213,8 +200,9 @@ static long xdl_split(unsigned long cons
 		}
 
 		/*
-		 * Enough is enough. We spent too much time here and now we collect
-		 * the furthest reaching path using the (i1 + i2) measure.
+		 * Enough is enough. We spent too much time here and now we
+		 * collect the furthest reaching path using the (i1 + i2)
+		 * measure.
 		 */
 		if (ec >= xenv->mxcost) {
 			long fbest, fbest1, bbest, bbest1;
@@ -261,9 +249,9 @@ static long xdl_split(unsigned long cons
 
 
 /*
- * Rule: "Divide et Impera". Recursively split the box in sub-boxes by calling
- * the box splitting function. Note that the real job (marking changed lines)
- * is done in the two boundary reaching checks.
+ * Rule: "Divide et Impera" (divide & conquer). Recursively split the box in
+ * sub-boxes by calling the box splitting function. Note that the real job
+ * (marking changed lines) is done in the two boundary reaching checks.
  */
 int xdl_recs_cmp(diffdata_t *dd1, long off1, long lim1,
 		 diffdata_t *dd2, long off2, long lim2,
@@ -340,7 +328,9 @@ int xdl_do_diff(mmfile_t *mf1, mmfile_t
 	}
 
 	/*
-	 * Allocate and setup K vectors to be used by the differential algorithm.
+	 * Allocate and setup K vectors to be used by the differential
+	 * algorithm.
+	 *
 	 * One is to store the forward path and one to store the backward path.
 	 */
 	ndiags = xe->xdf1.nreff + xe->xdf2.nreff + 3;
@@ -411,8 +401,8 @@ static int recs_match(xrecord_t *rec1, x
 /*
  * If a line is indented more than this, get_indent() just returns this value.
  * This avoids having to do absurd amounts of work for data that are not
- * human-readable text, and also ensures that the output of get_indent fits within
- * an int.
+ * human-readable text, and also ensures that the output of get_indent fits
+ * within an int.
  */
 #define MAX_INDENT 200
 
@@ -446,9 +436,9 @@ static int get_indent(xrecord_t *rec)
 }
 
 /*
- * If more than this number of consecutive blank rows are found, just return this
- * value. This avoids requiring O(N^2) work for pathological cases, and also
- * ensures that the output of score_split fits in an int.
+ * If more than this number of consecutive blank rows are found, just return
+ * this value. This avoids requiring O(N^2) work for pathological cases, and
+ * also ensures that the output of score_split fits in an int.
  */
 #define MAX_BLANKS 20
 
@@ -460,8 +450,8 @@ struct split_measurement {
 	int end_of_file;
 
 	/*
-	 * How much is the line immediately following the split indented (or -1 if
-	 * the line is blank):
+	 * How much is the line immediately following the split indented (or -1
+	 * if the line is blank):
 	 */
 	int indent;
 
@@ -471,8 +461,8 @@ struct split_measurement {
 	int pre_blank;
 
 	/*
-	 * How much is the nearest non-blank line above the split indented (or -1
-	 * if there is no such line)?
+	 * How much is the nearest non-blank line above the split indented (or
+	 * -1 if there is no such line)?
 	 */
 	int pre_indent;
 
@@ -592,14 +582,19 @@ static void measure_split(const xdfile_t
 #define INDENT_WEIGHT 60
 
 /*
+ * How far do we slide a hunk at most?
+ */
+#define INDENT_HEURISTIC_MAX_SLIDING 100
+
+/*
  * Compute a badness score for the hypothetical split whose measurements are
- * stored in m. The weight factors were determined empirically using the tools and
- * corpus described in
+ * stored in m. The weight factors were determined empirically using the tools
+ * and corpus described in
  *
  *     https://github.com/mhagger/diff-slider-tools
  *
- * Also see that project if you want to improve the weights based on, for example,
- * a larger or more diverse corpus.
+ * Also see that project if you want to improve the weights based on, for
+ * example, a larger or more diverse corpus.
  */
 static void score_add_split(const struct split_measurement *m, struct split_score *s)
 {
@@ -821,13 +816,16 @@ int xdl_change_compact(xdfile_t *xdf, xd
 	group_init(xdfo, &go);
 
 	while (1) {
-		/* If the group is empty in the to-be-compacted file, skip it: */
+		/*
+		 * If the group is empty in the to-be-compacted file, skip it:
+		 */
 		if (g.end == g.start)
 			goto next;
 
 		/*
 		 * Now shift the change up and then down as far as possible in
-		 * each direction. If it bumps into any other changes, merge them.
+		 * each direction. If it bumps into any other changes, merge
+		 * them.
 		 */
 		do {
 			groupsize = g.end - g.start;
@@ -870,17 +868,17 @@ int xdl_change_compact(xdfile_t *xdf, xd
 		 * If the group can be shifted, then we can possibly use this
 		 * freedom to produce a more intuitive diff.
 		 *
-		 * The group is currently shifted as far down as possible, so the
-		 * heuristics below only have to handle upwards shifts.
+		 * The group is currently shifted as far down as possible, so
+		 * the heuristics below only have to handle upwards shifts.
 		 */
 
 		if (g.end == earliest_end) {
 			/* no shifting was possible */
 		} else if (end_matching_other != -1) {
 			/*
-			 * Move the possibly merged group of changes back to line
-			 * up with the last group of changes from the other file
-			 * that it can align with.
+			 * Move the possibly merged group of changes back to
+			 * line up with the last group of changes from the
+			 * other file that it can align with.
 			 */
 			while (go.end == go.start) {
 				if (group_slide_up(xdf, &g, flags))
@@ -891,19 +889,25 @@ int xdl_change_compact(xdfile_t *xdf, xd
 		} else if (flags & XDF_INDENT_HEURISTIC) {
 			/*
 			 * Indent heuristic: a group of pure add/delete lines
-			 * implies two splits, one between the end of the "before"
-			 * context and the start of the group, and another between
-			 * the end of the group and the beginning of the "after"
-			 * context. Some splits are aesthetically better and some
-			 * are worse. We compute a badness "score" for each split,
-			 * and add the scores for the two splits to define a
-			 * "score" for each position that the group can be shifted
-			 * to. Then we pick the shift with the lowest score.
+			 * implies two splits, one between the end of the
+			 * "before" context and the start of the group, and
+			 * another between the end of the group and the
+			 * beginning of the "after" context. Some splits are
+			 * aesthetically better and some are worse. We compute
+			 * a badness "score" for each split, and add the scores
+			 * for the two splits to define a "score" for each
+			 * position that the group can be shifted to. Then we
+			 * pick the shift with the lowest score.
 			 */
 			long shift, best_shift = -1;
 			struct split_score best_score;
 
-			for (shift = earliest_end; shift <= g.end; shift++) {
+			shift = earliest_end;
+			if (g.end - groupsize - 1 > shift)
+				shift = g.end - groupsize - 1;
+			if (g.end - INDENT_HEURISTIC_MAX_SLIDING > shift)
+				shift = g.end - INDENT_HEURISTIC_MAX_SLIDING;
+			for (; shift <= g.end; shift++) {
 				struct split_measurement m;
 				struct split_score score = {0, 0};
 
diff -pruN 1.2.1+git2.18.0-1/git/xdiff/xemit.c 1.2.3+git2.25.1-1/git/xdiff/xemit.c
--- 1.2.1+git2.18.0-1/git/xdiff/xemit.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/xdiff/xemit.c	2020-02-17 04:47:35.000000000 +0000
@@ -172,10 +172,12 @@ int xdl_emit_diff(xdfenv_t *xe, xdchange
 	struct func_line func_line = { 0 };
 
 	for (xch = xscr; xch; xch = xche->next) {
+		xdchange_t *xchp = xch;
 		xche = xdl_get_hunk(&xch, xecfg);
 		if (!xch)
 			break;
 
+pre_context_calculation:
 		s1 = XDL_MAX(xch->i1 - xecfg->ctxlen, 0);
 		s2 = XDL_MAX(xch->i2 - xecfg->ctxlen, 0);
 
@@ -210,8 +212,23 @@ int xdl_emit_diff(xdfenv_t *xe, xdchange
 			if (fs1 < 0)
 				fs1 = 0;
 			if (fs1 < s1) {
-				s2 -= s1 - fs1;
+				s2 = XDL_MAX(s2 - (s1 - fs1), 0);
 				s1 = fs1;
+
+				/*
+				 * Did we extend context upwards into an
+				 * ignored change?
+				 */
+				while (xchp != xch &&
+				       xchp->i1 + xchp->chg1 <= s1 &&
+				       xchp->i2 + xchp->chg2 <= s2)
+					xchp = xchp->next;
+
+				/* If so, show it after all. */
+				if (xchp != xch) {
+					xch = xchp;
+					goto pre_context_calculation;
+				}
 			}
 		}
 
@@ -232,7 +249,7 @@ int xdl_emit_diff(xdfenv_t *xe, xdchange
 			if (fe1 < 0)
 				fe1 = xe->xdf1.nrec;
 			if (fe1 > e1) {
-				e2 += fe1 - e1;
+				e2 = XDL_MIN(e2 + (fe1 - e1), xe->xdf2.nrec);
 				e1 = fe1;
 			}
 
diff -pruN 1.2.1+git2.18.0-1/git/xdiff/xhistogram.c 1.2.3+git2.25.1-1/git/xdiff/xhistogram.c
--- 1.2.1+git2.18.0-1/git/xdiff/xhistogram.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/xdiff/xhistogram.c	2020-02-17 04:47:35.000000000 +0000
@@ -42,8 +42,6 @@
  */
 
 #include "xinclude.h"
-#include "xtypes.h"
-#include "xdiff.h"
 
 #define MAX_PTR	UINT_MAX
 #define MAX_CNT	UINT_MAX
@@ -233,54 +231,31 @@ static int try_lcs(struct histindex *ind
 	return b_next;
 }
 
-static int find_lcs(struct histindex *index, struct region *lcs,
-	int line1, int count1, int line2, int count2) {
-	int b_ptr;
-
-	if (scanA(index, line1, count1))
-		return -1;
-
-	index->cnt = index->max_chain_length + 1;
-
-	for (b_ptr = line2; b_ptr <= LINE_END(2); )
-		b_ptr = try_lcs(index, lcs, b_ptr, line1, count1, line2, count2);
-
-	return index->has_common && index->max_chain_length < index->cnt;
-}
-
-static int fall_back_to_classic_diff(struct histindex *index,
+static int fall_back_to_classic_diff(xpparam_t const *xpp, xdfenv_t *env,
 		int line1, int count1, int line2, int count2)
 {
-	xpparam_t xpp;
-	xpp.flags = index->xpp->flags & ~XDF_DIFF_ALGORITHM_MASK;
+	xpparam_t xpparam;
+	xpparam.flags = xpp->flags & ~XDF_DIFF_ALGORITHM_MASK;
 
-	return xdl_fall_back_diff(index->env, &xpp,
+	return xdl_fall_back_diff(env, &xpparam,
 				  line1, count1, line2, count2);
 }
 
-static int histogram_diff(xpparam_t const *xpp, xdfenv_t *env,
-	int line1, int count1, int line2, int count2)
+static inline void free_index(struct histindex *index)
 {
-	struct histindex index;
-	struct region lcs;
-	int sz;
-	int result = -1;
-
-	if (count1 <= 0 && count2 <= 0)
-		return 0;
-
-	if (LINE_END(1) >= MAX_PTR)
-		return -1;
+	xdl_free(index->records);
+	xdl_free(index->line_map);
+	xdl_free(index->next_ptrs);
+	xdl_cha_free(&index->rcha);
+}
 
-	if (!count1) {
-		while(count2--)
-			env->xdf2.rchg[line2++ - 1] = 1;
-		return 0;
-	} else if (!count2) {
-		while(count1--)
-			env->xdf1.rchg[line1++ - 1] = 1;
-		return 0;
-	}
+static int find_lcs(xpparam_t const *xpp, xdfenv_t *env,
+		    struct region *lcs,
+		    int line1, int count1, int line2, int count2)
+{
+	int b_ptr;
+	int sz, ret = -1;
+	struct histindex index;
 
 	memset(&index, 0, sizeof(index));
 
@@ -318,9 +293,55 @@ static int histogram_diff(xpparam_t cons
 	index.ptr_shift = line1;
 	index.max_chain_length = 64;
 
+	if (scanA(&index, line1, count1))
+		goto cleanup;
+
+	index.cnt = index.max_chain_length + 1;
+
+	for (b_ptr = line2; b_ptr <= LINE_END(2); )
+		b_ptr = try_lcs(&index, lcs, b_ptr, line1, count1, line2, count2);
+
+	if (index.has_common && index.max_chain_length < index.cnt)
+		ret = 1;
+	else
+		ret = 0;
+
+cleanup:
+	free_index(&index);
+	return ret;
+}
+
+static int histogram_diff(xpparam_t const *xpp, xdfenv_t *env,
+	int line1, int count1, int line2, int count2)
+{
+	struct region lcs;
+	int lcs_found;
+	int result;
+redo:
+	result = -1;
+
+	if (count1 <= 0 && count2 <= 0)
+		return 0;
+
+	if (LINE_END(1) >= MAX_PTR)
+		return -1;
+
+	if (!count1) {
+		while(count2--)
+			env->xdf2.rchg[line2++ - 1] = 1;
+		return 0;
+	} else if (!count2) {
+		while(count1--)
+			env->xdf1.rchg[line1++ - 1] = 1;
+		return 0;
+	}
+
 	memset(&lcs, 0, sizeof(lcs));
-	if (find_lcs(&index, &lcs, line1, count1, line2, count2))
-		result = fall_back_to_classic_diff(&index, line1, count1, line2, count2);
+	lcs_found = find_lcs(xpp, env, &lcs, line1, count1, line2, count2);
+	if (lcs_found < 0)
+		goto out;
+	else if (lcs_found)
+		result = fall_back_to_classic_diff(xpp, env, line1, count1, line2, count2);
 	else {
 		if (lcs.begin1 == 0 && lcs.begin2 == 0) {
 			while (count1--)
@@ -333,21 +354,21 @@ static int histogram_diff(xpparam_t cons
 						line1, lcs.begin1 - line1,
 						line2, lcs.begin2 - line2);
 			if (result)
-				goto cleanup;
-			result = histogram_diff(xpp, env,
-						lcs.end1 + 1, LINE_END(1) - lcs.end1,
-						lcs.end2 + 1, LINE_END(2) - lcs.end2);
-			if (result)
-				goto cleanup;
+				goto out;
+			/*
+			 * result = histogram_diff(xpp, env,
+			 *            lcs.end1 + 1, LINE_END(1) - lcs.end1,
+			 *            lcs.end2 + 1, LINE_END(2) - lcs.end2);
+			 * but let's optimize tail recursion ourself:
+			*/
+			count1 = LINE_END(1) - lcs.end1;
+			line1 = lcs.end1 + 1;
+			count2 = LINE_END(2) - lcs.end2;
+			line2 = lcs.end2 + 1;
+			goto redo;
 		}
 	}
-
-cleanup:
-	xdl_free(index.records);
-	xdl_free(index.line_map);
-	xdl_free(index.next_ptrs);
-	xdl_cha_free(&index.rcha);
-
+out:
 	return result;
 }
 
diff -pruN 1.2.1+git2.18.0-1/git/xdiff/xinclude.h 1.2.3+git2.25.1-1/git/xdiff/xinclude.h
--- 1.2.1+git2.18.0-1/git/xdiff/xinclude.h	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/xdiff/xinclude.h	2020-02-17 04:47:35.000000000 +0000
@@ -23,13 +23,7 @@
 #if !defined(XINCLUDE_H)
 #define XINCLUDE_H
 
-#include <ctype.h>
-#include <stdio.h>
-#include <stdlib.h>
-#include <unistd.h>
-#include <string.h>
-#include <limits.h>
-
+#include "git-compat-util.h"
 #include "xmacros.h"
 #include "xdiff.h"
 #include "xtypes.h"
diff -pruN 1.2.1+git2.18.0-1/git/xdiff/xpatience.c 1.2.3+git2.25.1-1/git/xdiff/xpatience.c
--- 1.2.1+git2.18.0-1/git/xdiff/xpatience.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/xdiff/xpatience.c	2020-02-17 04:47:35.000000000 +0000
@@ -20,8 +20,6 @@
  *
  */
 #include "xinclude.h"
-#include "xtypes.h"
-#include "xdiff.h"
 
 /*
  * The basic idea of patience diff is to find lines that are unique in
diff -pruN 1.2.1+git2.18.0-1/git/xdiff/xutils.c 1.2.3+git2.25.1-1/git/xdiff/xutils.c
--- 1.2.1+git2.18.0-1/git/xdiff/xutils.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/xdiff/xutils.c	2020-02-17 04:47:35.000000000 +0000
@@ -20,13 +20,9 @@
  *
  */
 
-#include <limits.h>
-#include <assert.h>
 #include "xinclude.h"
 
 
-
-
 long xdl_bogosqrt(long n) {
 	long i;
 
@@ -54,7 +50,7 @@ int xdl_emit_diffrec(char const *rec, lo
 		mb[2].size = strlen(mb[2].ptr);
 		i++;
 	}
-	if (ecb->outf(ecb->priv, mb, i) < 0) {
+	if (ecb->out_line(ecb->priv, mb, i) < 0) {
 
 		return -1;
 	}
@@ -344,8 +340,9 @@ int xdl_num_out(char *out, long val) {
 	return str - out;
 }
 
-int xdl_emit_hunk_hdr(long s1, long c1, long s2, long c2,
-		      const char *func, long funclen, xdemitcb_t *ecb) {
+static int xdl_format_hunk_hdr(long s1, long c1, long s2, long c2,
+			       const char *func, long funclen,
+			       xdemitcb_t *ecb) {
 	int nb = 0;
 	mmbuffer_t mb;
 	char buf[128];
@@ -387,9 +384,21 @@ int xdl_emit_hunk_hdr(long s1, long c1,
 
 	mb.ptr = buf;
 	mb.size = nb;
-	if (ecb->outf(ecb->priv, &mb, 1) < 0)
+	if (ecb->out_line(ecb->priv, &mb, 1) < 0)
 		return -1;
+	return 0;
+}
 
+int xdl_emit_hunk_hdr(long s1, long c1, long s2, long c2,
+		      const char *func, long funclen,
+		      xdemitcb_t *ecb) {
+	if (!ecb->out_hunk)
+		return xdl_format_hunk_hdr(s1, c1, s2, c2, func, funclen, ecb);
+	if (ecb->out_hunk(ecb->priv,
+			  c1 ? s1 : s1 - 1, c1,
+			  c2 ? s2 : s2 - 1, c2,
+			  func, funclen) < 0)
+		return -1;
 	return 0;
 }
 
diff -pruN 1.2.1+git2.18.0-1/git/xdiff-interface.c 1.2.3+git2.25.1-1/git/xdiff-interface.c
--- 1.2.1+git2.18.0-1/git/xdiff-interface.c	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/xdiff-interface.c	2020-02-17 04:47:35.000000000 +0000
@@ -1,5 +1,6 @@
 #include "cache.h"
 #include "config.h"
+#include "object-store.h"
 #include "xdiff-interface.h"
 #include "xdiff/xtypes.h"
 #include "xdiff/xdiffi.h"
@@ -8,54 +9,26 @@
 #include "xdiff/xutils.h"
 
 struct xdiff_emit_state {
-	xdiff_emit_consume_fn consume;
+	xdiff_emit_hunk_fn hunk_fn;
+	xdiff_emit_line_fn line_fn;
 	void *consume_callback_data;
 	struct strbuf remainder;
 };
 
-static int parse_num(char **cp_p, int *num_p)
+static int xdiff_out_hunk(void *priv_,
+			  long old_begin, long old_nr,
+			  long new_begin, long new_nr,
+			  const char *func, long funclen)
 {
-	char *cp = *cp_p;
-	int num = 0;
+	struct xdiff_emit_state *priv = priv_;
 
-	while ('0' <= *cp && *cp <= '9')
-		num = num * 10 + *cp++ - '0';
-	if (!(cp - *cp_p))
-		return -1;
-	*cp_p = cp;
-	*num_p = num;
-	return 0;
-}
+	if (priv->remainder.len)
+		BUG("xdiff emitted hunk in the middle of a line");
 
-int parse_hunk_header(char *line, int len,
-		      int *ob, int *on,
-		      int *nb, int *nn)
-{
-	char *cp;
-	cp = line + 4;
-	if (parse_num(&cp, ob)) {
-	bad_line:
-		return error("malformed diff output: %s", line);
-	}
-	if (*cp == ',') {
-		cp++;
-		if (parse_num(&cp, on))
-			goto bad_line;
-	}
-	else
-		*on = 1;
-	if (*cp++ != ' ' || *cp++ != '+')
-		goto bad_line;
-	if (parse_num(&cp, nb))
-		goto bad_line;
-	if (*cp == ',') {
-		cp++;
-		if (parse_num(&cp, nn))
-			goto bad_line;
-	}
-	else
-		*nn = 1;
-	return -!!memcmp(cp, " @@", 3);
+	priv->hunk_fn(priv->consume_callback_data,
+		      old_begin, old_nr, new_begin, new_nr,
+		      func, funclen);
+	return 0;
 }
 
 static void consume_one(void *priv_, char *s, unsigned long size)
@@ -66,7 +39,7 @@ static void consume_one(void *priv_, cha
 		unsigned long this_size;
 		ep = memchr(s, '\n', size);
 		this_size = (ep == NULL) ? size : (ep - s + 1);
-		priv->consume(priv->consume_callback_data, s, this_size);
+		priv->line_fn(priv->consume_callback_data, s, this_size);
 		size -= this_size;
 		s += this_size;
 	}
@@ -77,6 +50,9 @@ static int xdiff_outf(void *priv_, mmbuf
 	struct xdiff_emit_state *priv = priv_;
 	int i;
 
+	if (!priv->line_fn)
+		return 0;
+
 	for (i = 0; i < nbuf; i++) {
 		if (mb[i].ptr[mb[i].size-1] != '\n') {
 			/* Incomplete line */
@@ -139,8 +115,16 @@ int xdi_diff(mmfile_t *mf1, mmfile_t *mf
 	return xdl_diff(&a, &b, xpp, xecfg, xecb);
 }
 
+void discard_hunk_line(void *priv,
+		       long ob, long on, long nb, long nn,
+		       const char *func, long funclen)
+{
+}
+
 int xdi_diff_outf(mmfile_t *mf1, mmfile_t *mf2,
-		  xdiff_emit_consume_fn fn, void *consume_callback_data,
+		  xdiff_emit_hunk_fn hunk_fn,
+		  xdiff_emit_line_fn line_fn,
+		  void *consume_callback_data,
 		  xpparam_t const *xpp, xdemitconf_t const *xecfg)
 {
 	int ret;
@@ -148,10 +132,13 @@ int xdi_diff_outf(mmfile_t *mf1, mmfile_
 	xdemitcb_t ecb;
 
 	memset(&state, 0, sizeof(state));
-	state.consume = fn;
+	state.hunk_fn = hunk_fn;
+	state.line_fn = line_fn;
 	state.consume_callback_data = consume_callback_data;
 	memset(&ecb, 0, sizeof(ecb));
-	ecb.outf = xdiff_outf;
+	if (hunk_fn)
+		ecb.out_hunk = xdiff_out_hunk;
+	ecb.out_line = xdiff_outf;
 	ecb.priv = &state;
 	strbuf_init(&state.remainder, 0);
 	ret = xdi_diff(mf1, mf2, xpp, xecfg, &ecb);
@@ -185,7 +172,7 @@ void read_mmblob(mmfile_t *ptr, const st
 	unsigned long size;
 	enum object_type type;
 
-	if (!oidcmp(oid, &null_oid)) {
+	if (oideq(oid, &null_oid)) {
 		ptr->ptr = xstrdup("");
 		ptr->size = 0;
 		return;
@@ -319,6 +306,10 @@ int git_xmerge_config(const char *var, c
 			git_xmerge_style = XDL_MERGE_DIFF3;
 		else if (!strcmp(value, "merge"))
 			git_xmerge_style = 0;
+		/*
+		 * Please update _git_checkout() in
+		 * git-completion.bash when you add new merge config
+		 */
 		else
 			die("unknown style '%s' given for '%s'",
 			    value, var);
diff -pruN 1.2.1+git2.18.0-1/git/xdiff-interface.h 1.2.3+git2.25.1-1/git/xdiff-interface.h
--- 1.2.1+git2.18.0-1/git/xdiff-interface.h	2018-06-21 17:18:50.000000000 +0000
+++ 1.2.3+git2.25.1-1/git/xdiff-interface.h	2020-02-17 04:47:35.000000000 +0000
@@ -11,38 +11,49 @@
  */
 #define MAX_XDIFF_SIZE (1024UL * 1024 * 1023)
 
-typedef void (*xdiff_emit_consume_fn)(void *, char *, unsigned long);
+typedef void (*xdiff_emit_line_fn)(void *, char *, unsigned long);
+typedef void (*xdiff_emit_hunk_fn)(void *data,
+				   long old_begin, long old_nr,
+				   long new_begin, long new_nr,
+				   const char *func, long funclen);
 
 int xdi_diff(mmfile_t *mf1, mmfile_t *mf2, xpparam_t const *xpp, xdemitconf_t const *xecfg, xdemitcb_t *ecb);
 int xdi_diff_outf(mmfile_t *mf1, mmfile_t *mf2,
-		  xdiff_emit_consume_fn fn, void *consume_callback_data,
+		  xdiff_emit_hunk_fn hunk_fn,
+		  xdiff_emit_line_fn line_fn,
+		  void *consume_callback_data,
 		  xpparam_t const *xpp, xdemitconf_t const *xecfg);
-int parse_hunk_header(char *line, int len,
-		      int *ob, int *on,
-		      int *nb, int *nn);
 int read_mmfile(mmfile_t *ptr, const char *filename);
 void read_mmblob(mmfile_t *ptr, const struct object_id *oid);
 int buffer_is_binary(const char *ptr, unsigned long size);
 
-extern void xdiff_set_find_func(xdemitconf_t *xecfg, const char *line, int cflags);
-extern void xdiff_clear_find_func(xdemitconf_t *xecfg);
-extern int git_xmerge_config(const char *var, const char *value, void *cb);
+void xdiff_set_find_func(xdemitconf_t *xecfg, const char *line, int cflags);
+void xdiff_clear_find_func(xdemitconf_t *xecfg);
+int git_xmerge_config(const char *var, const char *value, void *cb);
 extern int git_xmerge_style;
 
 /*
+ * Can be used as a no-op hunk_fn for xdi_diff_outf(), since a NULL
+ * one just sends the hunk line to the line_fn callback).
+ */
+void discard_hunk_line(void *priv,
+		       long ob, long on, long nb, long nn,
+		       const char *func, long funclen);
+
+/*
  * Compare the strings l1 with l2 which are of size s1 and s2 respectively.
  * Returns 1 if the strings are deemed equal, 0 otherwise.
  * The `flags` given as XDF_WHITESPACE_FLAGS determine how white spaces
- * are treated for the comparision.
+ * are treated for the comparison.
  */
-extern int xdiff_compare_lines(const char *l1, long s1,
-			       const char *l2, long s2, long flags);
+int xdiff_compare_lines(const char *l1, long s1,
+			const char *l2, long s2, long flags);
 
 /*
  * Returns a hash of the string s of length len.
  * The `flags` given as XDF_WHITESPACE_FLAGS determine how white spaces
  * are treated for the hash.
  */
-extern unsigned long xdiff_hash_string(const char *s, size_t len, long flags);
+unsigned long xdiff_hash_string(const char *s, size_t len, long flags);
 
 #endif
diff -pruN 1.2.1+git2.18.0-1/Makefile 1.2.3+git2.25.1-1/Makefile
--- 1.2.1+git2.18.0-1/Makefile	2018-08-03 15:04:03.000000000 +0000
+++ 1.2.3+git2.25.1-1/Makefile	2020-03-13 23:49:52.000000000 +0000
@@ -1,6 +1,6 @@
 all::
 
-CGIT_VERSION = v1.2.1
+CGIT_VERSION = v1.2.3
 CGIT_SCRIPT_NAME = cgit.cgi
 CGIT_SCRIPT_PATH = /var/www/htdocs/cgit
 CGIT_DATA_PATH = $(CGIT_SCRIPT_PATH)
@@ -14,8 +14,8 @@ htmldir = $(docdir)
 pdfdir = $(docdir)
 mandir = $(prefix)/share/man
 SHA1_HEADER = <openssl/sha.h>
-GIT_VER = 2.18.0
-GIT_URL = https://www.kernel.org/pub/software/scm/git/git-$(GIT_VER).tar.gz
+GIT_VER = 2.25.1
+GIT_URL = https://www.kernel.org/pub/software/scm/git/git-$(GIT_VER).tar.xz
 INSTALL = install
 COPYTREE = cp -r
 MAN5_TXT = $(wildcard *.5.txt)
@@ -157,7 +157,7 @@ clean-doc:
 	$(RM) cgitrc.5 cgitrc.5.html cgitrc.5.pdf cgitrc.5.xml cgitrc.5.fo
 
 get-git:
-	curl -L $(GIT_URL) | tar -xzf - && rm -rf git && mv git-$(GIT_VER) git
+	curl -L $(GIT_URL) | tar -xJf - && rm -rf git && mv git-$(GIT_VER) git
 
 tags:
 	$(QUIET_TAGS)find . -name '*.[ch]' | xargs ctags
diff -pruN 1.2.1+git2.18.0-1/parsing.c 1.2.3+git2.25.1-1/parsing.c
--- 1.2.1+git2.18.0-1/parsing.c	2018-08-03 15:04:03.000000000 +0000
+++ 1.2.3+git2.25.1-1/parsing.c	2020-03-13 23:49:52.000000000 +0000
@@ -63,8 +63,7 @@ static char *substr(const char *head, co
 	if (tail < head)
 		return xstrdup("");
 	buf = xmalloc(tail - head + 1);
-	strncpy(buf, head, tail - head);
-	buf[tail - head] = '\0';
+	strlcpy(buf, head, tail - head + 1);
 	return buf;
 }
 
@@ -78,7 +77,7 @@ static void parse_user(const char *t, ch
 
 		email_len = ident.mail_end - ident.mail_begin;
 		*email = xmalloc(strlen("<") + email_len + strlen(">") + 1);
-		sprintf(*email, "<%.*s>", email_len, ident.mail_begin);
+		xsnprintf(*email, email_len + 3, "<%.*s>", email_len, ident.mail_begin);
 
 		if (ident.date_begin)
 			*date = strtoul(ident.date_begin, NULL, 10);
@@ -130,7 +129,7 @@ struct commitinfo *cgit_parse_commit(str
 {
 	const int sha1hex_len = 40;
 	struct commitinfo *ret;
-	const char *p = get_cached_commit_buffer(commit, NULL);
+	const char *p = repo_get_commit_buffer(the_repository, commit, NULL);
 	const char *t;
 
 	ret = xcalloc(1, sizeof(struct commitinfo));
diff -pruN 1.2.1+git2.18.0-1/shared.c 1.2.3+git2.25.1-1/shared.c
--- 1.2.1+git2.18.0-1/shared.c	2018-08-03 15:04:03.000000000 +0000
+++ 1.2.3+git2.25.1-1/shared.c	2020-03-13 23:49:52.000000000 +0000
@@ -58,6 +58,7 @@ struct cgit_repo *cgit_add_repo(const ch
 	ret->homepage = NULL;
 	ret->section = ctx.cfg.section;
 	ret->snapshots = ctx.cfg.snapshots;
+	ret->enable_blame = ctx.cfg.enable_blame;
 	ret->enable_commit_graph = ctx.cfg.enable_commit_graph;
 	ret->enable_log_filecount = ctx.cfg.enable_log_filecount;
 	ret->enable_log_linecount = ctx.cfg.enable_log_linecount;
@@ -161,7 +162,7 @@ static struct refinfo *cgit_mk_refinfo(c
 
 	ref = xmalloc(sizeof (struct refinfo));
 	ref->refname = xstrdup(refname);
-	ref->object = parse_object(oid);
+	ref->object = parse_object(the_repository, oid);
 	switch (ref->object->type) {
 	case OBJ_TAG:
 		ref->tag = cgit_parse_tag((struct tag *)ref->object);
@@ -325,7 +326,7 @@ int cgit_diff_files(const struct object_
 		diff_params.flags |= XDF_IGNORE_WHITESPACE;
 	emit_params.ctxlen = context > 0 ? context : 3;
 	emit_params.flags = XDL_EMIT_FUNCNAMES;
-	emit_cb.outf = filediff_cb;
+	emit_cb.out_line = filediff_cb;
 	emit_cb.priv = fn;
 	xdl_diff(&file1, &file2, &diff_params, &emit_params, &emit_cb);
 	if (file1.size)
diff -pruN 1.2.1+git2.18.0-1/tests/setup.sh 1.2.3+git2.25.1-1/tests/setup.sh
--- 1.2.1+git2.18.0-1/tests/setup.sh	2018-08-03 15:04:03.000000000 +0000
+++ 1.2.3+git2.25.1-1/tests/setup.sh	2020-03-13 23:49:52.000000000 +0000
@@ -104,7 +104,7 @@ virtual-root=/
 cache-root=$PWD/cache
 
 cache-size=1021
-snapshots=tar.gz tar.bz zip
+snapshots=tar.gz tar.bz tar.lz tar.xz tar.zst zip
 enable-log-filecount=1
 enable-log-linecount=1
 summary-log=5
diff -pruN 1.2.1+git2.18.0-1/tests/t0001-validate-git-versions.sh 1.2.3+git2.25.1-1/tests/t0001-validate-git-versions.sh
--- 1.2.1+git2.18.0-1/tests/t0001-validate-git-versions.sh	2018-08-03 15:04:03.000000000 +0000
+++ 1.2.3+git2.25.1-1/tests/t0001-validate-git-versions.sh	2020-03-13 23:49:52.000000000 +0000
@@ -1,5 +1,9 @@
 #!/bin/sh
 
+if [ "${CGIT_TEST_NO_GIT_VERSION}" = "YesPlease" ]; then
+	exit 0
+fi
+
 test_description='Check Git version is correct'
 CGIT_TEST_NO_CREATE_REPOS=YesPlease
 . ./setup.sh
@@ -33,7 +37,7 @@ test_expect_success 'test submodule vers
 				sed -e "s/^[0-9]* \\([0-9a-f]*\\) [0-9]	.*$/\\1/") &&
 			cd git &&
 			git describe --match "v[0-9]*" $sm_sha1
-		) | sed -e "s/^v//" >sm_version &&
+		) | sed -e "s/^v//" -e "s/-/./" >sm_version &&
 		test_cmp sm_version makefile_version
 	fi
 '
diff -pruN 1.2.1+git2.18.0-1/tests/t0107-snapshot.sh 1.2.3+git2.25.1-1/tests/t0107-snapshot.sh
--- 1.2.1+git2.18.0-1/tests/t0107-snapshot.sh	2018-08-03 15:04:03.000000000 +0000
+++ 1.2.3+git2.25.1-1/tests/t0107-snapshot.sh	2020-03-13 23:49:52.000000000 +0000
@@ -38,6 +38,132 @@ test_expect_success 'verify untarred fil
 	test_line_count = 1 master/file-5
 '
 
+if test -n "$(which lzip 2>/dev/null)"; then
+	test_set_prereq LZIP
+else
+	say 'Skipping LZIP validation tests: lzip not found'
+fi
+
+test_expect_success LZIP 'get foo/snapshot/master.tar.lz' '
+	cgit_url "foo/snapshot/master.tar.lz" >tmp
+'
+
+test_expect_success LZIP 'check html headers' '
+	head -n 1 tmp |
+	grep "Content-Type: application/x-lzip" &&
+
+	head -n 2 tmp |
+	grep "Content-Disposition: inline; filename=.master.tar.lz."
+'
+
+test_expect_success LZIP 'strip off the header lines' '
+	strip_headers <tmp >master.tar.lz
+'
+
+test_expect_success LZIP 'verify lzip format' '
+	lzip --test master.tar.lz &&
+	cp master.tar.lz /tmp/.
+'
+
+test_expect_success LZIP 'untar' '
+	rm -rf master &&
+	tar --lzip -xf master.tar.lz
+'
+
+test_expect_success LZIP 'count files' '
+	ls master/ >output &&
+	test_line_count = 5 output
+'
+
+test_expect_success LZIP 'verify untarred file-5' '
+	grep "^5$" master/file-5 &&
+	test_line_count = 1 master/file-5
+'
+
+if test -n "$(which xz 2>/dev/null)"; then
+	test_set_prereq XZ
+else
+	say 'Skipping XZ validation tests: xz not found'
+fi
+
+test_expect_success XZ 'get foo/snapshot/master.tar.xz' '
+	cgit_url "foo/snapshot/master.tar.xz" >tmp
+'
+
+test_expect_success XZ 'check html headers' '
+	head -n 1 tmp |
+	grep "Content-Type: application/x-xz" &&
+
+	head -n 2 tmp |
+	grep "Content-Disposition: inline; filename=.master.tar.xz."
+'
+
+test_expect_success XZ 'strip off the header lines' '
+	strip_headers <tmp >master.tar.xz
+'
+
+test_expect_success XZ 'verify xz format' '
+	xz --test master.tar.xz &&
+	cp master.tar.xz /tmp/.
+'
+
+test_expect_success XZ 'untar' '
+	rm -rf master &&
+	tar --xz -xf master.tar.xz
+'
+
+test_expect_success XZ 'count files' '
+	ls master/ >output &&
+	test_line_count = 5 output
+'
+
+test_expect_success XZ 'verify untarred file-5' '
+	grep "^5$" master/file-5 &&
+	test_line_count = 1 master/file-5
+'
+
+if test -n "$(which zstd 2>/dev/null)"; then
+	test_set_prereq ZSTD
+else
+	say 'Skipping ZSTD validation tests: zstd not found'
+fi
+
+test_expect_success ZSTD 'get foo/snapshot/master.tar.zst' '
+	cgit_url "foo/snapshot/master.tar.zst" >tmp
+'
+
+test_expect_success ZSTD 'check html headers' '
+	head -n 1 tmp |
+	grep "Content-Type: application/x-zstd" &&
+
+	head -n 2 tmp |
+	grep "Content-Disposition: inline; filename=.master.tar.zst."
+'
+
+test_expect_success ZSTD 'strip off the header lines' '
+	strip_headers <tmp >master.tar.zst
+'
+
+test_expect_success ZSTD 'verify zstd format' '
+	zstd --test master.tar.zst &&
+	cp master.tar.zst /tmp/.
+'
+
+test_expect_success ZSTD 'untar' '
+	rm -rf master &&
+	tar --zstd -xf master.tar.zst
+'
+
+test_expect_success ZSTD 'count files' '
+	ls master/ >output &&
+	test_line_count = 5 output
+'
+
+test_expect_success ZSTD 'verify untarred file-5' '
+	grep "^5$" master/file-5 &&
+	test_line_count = 1 master/file-5
+'
+
 test_expect_success 'get foo/snapshot/master.zip' '
 	cgit_url "foo/snapshot/master.zip" >tmp
 '
diff -pruN 1.2.1+git2.18.0-1/tests/t0109-gitconfig.sh 1.2.3+git2.25.1-1/tests/t0109-gitconfig.sh
--- 1.2.1+git2.18.0-1/tests/t0109-gitconfig.sh	2018-08-03 15:04:03.000000000 +0000
+++ 1.2.3+git2.25.1-1/tests/t0109-gitconfig.sh	2020-03-13 23:49:52.000000000 +0000
@@ -9,6 +9,12 @@ test -n "$(which strace 2>/dev/null)" ||
 	exit
 }
 
+strace true 2>/dev/null || {
+	skip_all='Skipping access validation tests: strace not functional'
+	test_done
+	exit
+}
+
 test_no_home_access () {
 	non_existent_path="/path/to/some/place/that/does/not/possibly/exist"
 	while test -d "$non_existent_path"; do
diff -pruN 1.2.1+git2.18.0-1/ui-atom.c 1.2.3+git2.25.1-1/ui-atom.c
--- 1.2.1+git2.18.0-1/ui-atom.c	2018-08-03 15:04:03.000000000 +0000
+++ 1.2.3+git2.25.1-1/ui-atom.c	2020-03-13 23:49:52.000000000 +0000
@@ -83,7 +83,7 @@ static void add_entry(struct commit *com
 }
 
 
-void cgit_print_atom(char *tip, char *path, int max_count)
+void cgit_print_atom(char *tip, const char *path, int max_count)
 {
 	char *host;
 	const char *argv[] = {NULL, tip, NULL, NULL, NULL};
@@ -140,7 +140,7 @@ void cgit_print_atom(char *tip, char *pa
 	}
 	while ((commit = get_revision(&rev)) != NULL) {
 		add_entry(commit, host);
-		free_commit_buffer(commit);
+		free_commit_buffer(the_repository->parsed_objects, commit);
 		free_commit_list(commit->parents);
 		commit->parents = NULL;
 	}
diff -pruN 1.2.1+git2.18.0-1/ui-atom.h 1.2.3+git2.25.1-1/ui-atom.h
--- 1.2.1+git2.18.0-1/ui-atom.h	2018-08-03 15:04:03.000000000 +0000
+++ 1.2.3+git2.25.1-1/ui-atom.h	2020-03-13 23:49:52.000000000 +0000
@@ -1,6 +1,6 @@
 #ifndef UI_ATOM_H
 #define UI_ATOM_H
 
-extern void cgit_print_atom(char *tip, char *path, int max_count);
+extern void cgit_print_atom(char *tip, const char *path, int max_count);
 
 #endif
diff -pruN 1.2.1+git2.18.0-1/ui-blame.c 1.2.3+git2.25.1-1/ui-blame.c
--- 1.2.1+git2.18.0-1/ui-blame.c	2018-08-03 15:04:03.000000000 +0000
+++ 1.2.3+git2.25.1-1/ui-blame.c	2020-03-13 23:49:52.000000000 +0000
@@ -131,6 +131,7 @@ static void print_object(const struct ob
 	setup_revisions(rev_argv.argc, rev_argv.argv, &revs, NULL);
 	init_scoreboard(&sb);
 	sb.revs = &revs;
+	sb.repo = the_repository;
 	setup_scoreboard(&sb, path, &o);
 	o->suspects = blame_entry_prepend(NULL, 0, sb.num_lines, o);
 	prio_queue_put(&sb.commits, o->commit);
@@ -278,7 +279,7 @@ void cgit_print_blame(void)
 			"Invalid revision name: %s", rev);
 		return;
 	}
-	commit = lookup_commit_reference(&oid);
+	commit = lookup_commit_reference(the_repository, &oid);
 	if (!commit || parse_commit(commit)) {
 		cgit_print_error_page(404, "Not found",
 			"Invalid commit reference: %s", rev);
@@ -289,8 +290,10 @@ void cgit_print_blame(void)
 	walk_tree_ctx.match_baselen = (path_items.match) ?
 				       basedir_len(path_items.match) : -1;
 
-	read_tree_recursive(commit->maybe_tree, "", 0, 0, &paths, walk_tree,
-		&walk_tree_ctx);
+	read_tree_recursive(the_repository,
+			    repo_get_commit_tree(the_repository, commit),
+			    "", 0, 0,
+			    &paths, walk_tree, &walk_tree_ctx);
 	if (!walk_tree_ctx.state)
 		cgit_print_error_page(404, "Not found", "Not found");
 	else if (walk_tree_ctx.state == 2)
diff -pruN 1.2.1+git2.18.0-1/ui-blob.c 1.2.3+git2.25.1-1/ui-blob.c
--- 1.2.1+git2.18.0-1/ui-blob.c	2018-08-03 15:04:03.000000000 +0000
+++ 1.2.3+git2.25.1-1/ui-blob.c	2020-03-13 23:49:52.000000000 +0000
@@ -56,7 +56,9 @@ int cgit_ref_path_exists(const char *pat
 		goto done;
 	if (oid_object_info(the_repository, &oid, &size) != OBJ_COMMIT)
 		goto done;
-	read_tree_recursive(lookup_commit_reference(&oid)->maybe_tree, "", 0, 0, &paths, walk_tree, &walk_tree_ctx);
+	read_tree_recursive(the_repository,
+			    repo_get_commit_tree(the_repository, lookup_commit_reference(the_repository, &oid)),
+			    "", 0, 0, &paths, walk_tree, &walk_tree_ctx);
 
 done:
 	free(path_items.match);
@@ -89,8 +91,11 @@ int cgit_print_file(char *path, const ch
 		return -1;
 	type = oid_object_info(the_repository, &oid, &size);
 	if (type == OBJ_COMMIT) {
-		commit = lookup_commit_reference(&oid);
-		read_tree_recursive(commit->maybe_tree, "", 0, 0, &paths, walk_tree, &walk_tree_ctx);
+		commit = lookup_commit_reference(the_repository, &oid);
+		read_tree_recursive(the_repository,
+				    repo_get_commit_tree(the_repository, commit),
+				    "", 0, 0, &paths, walk_tree,
+				    &walk_tree_ctx);
 		if (!walk_tree_ctx.found_path)
 			return -1;
 		type = oid_object_info(the_repository, &oid, &size);
@@ -145,8 +150,11 @@ void cgit_print_blob(const char *hex, ch
 	type = oid_object_info(the_repository, &oid, &size);
 
 	if ((!hex) && type == OBJ_COMMIT && path) {
-		commit = lookup_commit_reference(&oid);
-		read_tree_recursive(commit->maybe_tree, "", 0, 0, &paths, walk_tree, &walk_tree_ctx);
+		commit = lookup_commit_reference(the_repository, &oid);
+		read_tree_recursive(the_repository,
+				    repo_get_commit_tree(the_repository, commit),
+				    "", 0, 0, &paths, walk_tree,
+				    &walk_tree_ctx);
 		type = oid_object_info(the_repository, &oid, &size);
 	}
 
diff -pruN 1.2.1+git2.18.0-1/ui-clone.c 1.2.3+git2.25.1-1/ui-clone.c
--- 1.2.1+git2.18.0-1/ui-clone.c	2018-08-03 15:04:03.000000000 +0000
+++ 1.2.3+git2.25.1-1/ui-clone.c	2020-03-13 23:49:52.000000000 +0000
@@ -19,12 +19,12 @@ static int print_ref_info(const char *re
 {
 	struct object *obj;
 
-	if (!(obj = parse_object(oid)))
+	if (!(obj = parse_object(the_repository, oid)))
 		return 0;
 
 	htmlf("%s\t%s\n", oid_to_hex(oid), refname);
 	if (obj->type == OBJ_TAG) {
-		if (!(obj = deref_tag(obj, refname, 0)))
+		if (!(obj = deref_tag(the_repository, obj, refname, 0)))
 			return 0;
 		htmlf("%s\t%s^{}\n", oid_to_hex(&obj->oid), refname);
 	}
diff -pruN 1.2.1+git2.18.0-1/ui-commit.c 1.2.3+git2.25.1-1/ui-commit.c
--- 1.2.1+git2.18.0-1/ui-commit.c	2018-08-03 15:04:03.000000000 +0000
+++ 1.2.3+git2.25.1-1/ui-commit.c	2020-03-13 23:49:52.000000000 +0000
@@ -31,7 +31,7 @@ void cgit_print_commit(char *hex, const
 				"Bad object id: %s", hex);
 		return;
 	}
-	commit = lookup_commit_reference(&oid);
+	commit = lookup_commit_reference(the_repository, &oid);
 	if (!commit) {
 		cgit_print_error_page(404, "Not found",
 				"Bad commit reference: %s", hex);
@@ -78,7 +78,7 @@ void cgit_print_commit(char *hex, const
 	html(")</td></tr>\n");
 	html("<tr><th>tree</th><td colspan='2' class='sha1'>");
 	tmp = xstrdup(hex);
-	cgit_tree_link(oid_to_hex(&commit->maybe_tree->object.oid), NULL, NULL,
+	cgit_tree_link(oid_to_hex(get_commit_tree_oid(commit)), NULL, NULL,
 		       ctx.qry.head, tmp, NULL);
 	if (prefix) {
 		html(" /");
@@ -87,7 +87,7 @@ void cgit_print_commit(char *hex, const
 	free(tmp);
 	html("</td></tr>\n");
 	for (p = commit->parents; p; p = p->next) {
-		parent = lookup_commit_reference(&p->item->object.oid);
+		parent = lookup_commit_reference(the_repository, &p->item->object.oid);
 		if (!parent) {
 			html("<tr><td colspan='3'>");
 			cgit_print_error("Error reading parent commit");
diff -pruN 1.2.1+git2.18.0-1/ui-diff.c 1.2.3+git2.25.1-1/ui-diff.c
--- 1.2.1+git2.18.0-1/ui-diff.c	2018-08-03 15:04:03.000000000 +0000
+++ 1.2.3+git2.25.1-1/ui-diff.c	2020-03-13 23:49:52.000000000 +0000
@@ -82,7 +82,7 @@ static void print_fileinfo(struct filein
 	}
 
 	html("<tr>");
-	htmlf("<td class='mode'>");
+	html("<td class='mode'>");
 	if (is_null_oid(info->new_oid)) {
 		cgit_print_filemode(info->old_mode);
 	} else {
@@ -407,13 +407,13 @@ void cgit_print_diff(const char *new_rev
 			"Bad object name: %s", new_rev);
 		return;
 	}
-	commit = lookup_commit_reference(new_rev_oid);
+	commit = lookup_commit_reference(the_repository, new_rev_oid);
 	if (!commit || parse_commit(commit)) {
 		cgit_print_error_page(404, "Not found",
 			"Bad commit: %s", oid_to_hex(new_rev_oid));
 		return;
 	}
-	new_tree_oid = &commit->maybe_tree->object.oid;
+	new_tree_oid = get_commit_tree_oid(commit);
 
 	if (old_rev) {
 		if (get_oid(old_rev, old_rev_oid)) {
@@ -428,13 +428,13 @@ void cgit_print_diff(const char *new_rev
 	}
 
 	if (!is_null_oid(old_rev_oid)) {
-		commit2 = lookup_commit_reference(old_rev_oid);
+		commit2 = lookup_commit_reference(the_repository, old_rev_oid);
 		if (!commit2 || parse_commit(commit2)) {
 			cgit_print_error_page(404, "Not found",
 				"Bad commit: %s", oid_to_hex(old_rev_oid));
 			return;
 		}
-		old_tree_oid = &commit2->maybe_tree->object.oid;
+		old_tree_oid = get_commit_tree_oid(commit2);
 	} else {
 		old_tree_oid = NULL;
 	}
diff -pruN 1.2.1+git2.18.0-1/ui-log.c 1.2.3+git2.25.1-1/ui-log.c
--- 1.2.1+git2.18.0-1/ui-log.c	2018-08-03 15:04:03.000000000 +0000
+++ 1.2.3+git2.25.1-1/ui-log.c	2020-03-13 23:49:52.000000000 +0000
@@ -67,7 +67,7 @@ void show_commit_decorations(struct comm
 	while (deco) {
 		struct object_id peeled;
 		int is_annotated = 0;
-		strncpy(buf, prettify_refname(deco->name), sizeof(buf) - 1);
+		strlcpy(buf, prettify_refname(deco->name), sizeof(buf));
 		switch(deco->type) {
 		case DECORATION_NONE:
 			/* If the git-core doesn't recognize it,
@@ -153,8 +153,8 @@ static int show_commit(struct commit *co
 	rem_lines = 0;
 
 	revs->diffopt.flags.recursive = 1;
-	diff_tree_oid(&parent->maybe_tree->object.oid,
-		      &commit->maybe_tree->object.oid,
+	diff_tree_oid(get_commit_tree_oid(parent),
+		      get_commit_tree_oid(commit),
 		      "", &revs->diffopt);
 	diffcore_std(&revs->diffopt);
 
@@ -234,7 +234,7 @@ static void print_commit(struct commit *
 			strbuf_add(&msgbuf, "\n\n", 2);
 
 			/* Place wrap_symbol at position i in info->subject */
-			strcpy(info->subject + i, wrap_symbol);
+			strlcpy(info->subject + i, wrap_symbol, subject_len - i + 1);
 		}
 	}
 	cgit_commit_link(info->subject, NULL, NULL, ctx.qry.head,
@@ -362,7 +362,7 @@ static char *next_token(char **src)
 }
 
 void cgit_print_log(const char *tip, int ofs, int cnt, char *grep, char *pattern,
-		    char *path, int pager, int commit_graph, int commit_sort)
+		    const char *path, int pager, int commit_graph, int commit_sort)
 {
 	struct rev_info rev;
 	struct commit *commit;
@@ -488,7 +488,7 @@ void cgit_print_log(const char *tip, int
 	for (i = 0; i < ofs && (commit = get_revision(&rev)) != NULL; /* nop */) {
 		if (show_commit(commit, &rev))
 			i++;
-		free_commit_buffer(commit);
+		free_commit_buffer(the_repository->parsed_objects, commit);
 		free_commit_list(commit->parents);
 		commit->parents = NULL;
 	}
@@ -510,7 +510,7 @@ void cgit_print_log(const char *tip, int
 			i++;
 			print_commit(commit, &rev);
 		}
-		free_commit_buffer(commit);
+		free_commit_buffer(the_repository->parsed_objects, commit);
 		free_commit_list(commit->parents);
 		commit->parents = NULL;
 	}
diff -pruN 1.2.1+git2.18.0-1/ui-log.h 1.2.3+git2.25.1-1/ui-log.h
--- 1.2.1+git2.18.0-1/ui-log.h	2018-08-03 15:04:03.000000000 +0000
+++ 1.2.3+git2.25.1-1/ui-log.h	2020-03-13 23:49:52.000000000 +0000
@@ -2,7 +2,7 @@
 #define UI_LOG_H
 
 extern void cgit_print_log(const char *tip, int ofs, int cnt, char *grep,
-			   char *pattern, char *path, int pager,
+			   char *pattern, const char *path, int pager,
 			   int commit_graph, int commit_sort);
 extern void show_commit_decorations(struct commit *commit);
 
diff -pruN 1.2.1+git2.18.0-1/ui-patch.c 1.2.3+git2.25.1-1/ui-patch.c
--- 1.2.1+git2.18.0-1/ui-patch.c	2018-08-03 15:04:03.000000000 +0000
+++ 1.2.3+git2.25.1-1/ui-patch.c	2020-03-13 23:49:52.000000000 +0000
@@ -11,13 +11,16 @@
 #include "html.h"
 #include "ui-shared.h"
 
+/* two commit hashes with two dots in between and termination */
+#define REV_RANGE_LEN 2 * GIT_MAX_HEXSZ + 3
+
 void cgit_print_patch(const char *new_rev, const char *old_rev,
 		      const char *prefix)
 {
 	struct rev_info rev;
 	struct commit *commit;
 	struct object_id new_rev_oid, old_rev_oid;
-	char rev_range[2 * 40 + 3];
+	char rev_range[REV_RANGE_LEN];
 	const char *rev_argv[] = { NULL, "--reverse", "--format=email", rev_range, "--", prefix, NULL };
 	int rev_argc = ARRAY_SIZE(rev_argv) - 1;
 	char *patchname;
@@ -33,7 +36,7 @@ void cgit_print_patch(const char *new_re
 				"Bad object id: %s", new_rev);
 		return;
 	}
-	commit = lookup_commit_reference(&new_rev_oid);
+	commit = lookup_commit_reference(the_repository, &new_rev_oid);
 	if (!commit) {
 		cgit_print_error_page(404, "Not found",
 				"Bad commit reference: %s", new_rev);
@@ -46,7 +49,7 @@ void cgit_print_patch(const char *new_re
 					"Bad object id: %s", old_rev);
 			return;
 		}
-		if (!lookup_commit_reference(&old_rev_oid)) {
+		if (!lookup_commit_reference(the_repository, &old_rev_oid)) {
 			cgit_print_error_page(404, "Not found",
 					"Bad commit reference: %s", old_rev);
 			return;
@@ -60,7 +63,7 @@ void cgit_print_patch(const char *new_re
 	if (is_null_oid(&old_rev_oid)) {
 		memcpy(rev_range, oid_to_hex(&new_rev_oid), GIT_SHA1_HEXSZ + 1);
 	} else {
-		sprintf(rev_range, "%s..%s", oid_to_hex(&old_rev_oid),
+		xsnprintf(rev_range, REV_RANGE_LEN, "%s..%s", oid_to_hex(&old_rev_oid),
 			oid_to_hex(&new_rev_oid));
 	}
 
diff -pruN 1.2.1+git2.18.0-1/ui-plain.c 1.2.3+git2.25.1-1/ui-plain.c
--- 1.2.1+git2.18.0-1/ui-plain.c	2018-08-03 15:04:03.000000000 +0000
+++ 1.2.3+git2.25.1-1/ui-plain.c	2020-03-13 23:49:52.000000000 +0000
@@ -185,7 +185,7 @@ void cgit_print_plain(void)
 		cgit_print_error_page(404, "Not found", "Not found");
 		return;
 	}
-	commit = lookup_commit_reference(&oid);
+	commit = lookup_commit_reference(the_repository, &oid);
 	if (!commit || parse_commit(commit)) {
 		cgit_print_error_page(404, "Not found", "Not found");
 		return;
@@ -193,12 +193,14 @@ void cgit_print_plain(void)
 	if (!path_items.match) {
 		path_items.match = "";
 		walk_tree_ctx.match_baselen = -1;
-		print_dir(&commit->maybe_tree->object.oid, "", 0, "");
+		print_dir(get_commit_tree_oid(commit), "", 0, "");
 		walk_tree_ctx.match = 2;
 	}
 	else
 		walk_tree_ctx.match_baselen = basedir_len(path_items.match);
-	read_tree_recursive(commit->maybe_tree, "", 0, 0, &paths, walk_tree, &walk_tree_ctx);
+	read_tree_recursive(the_repository,
+		            repo_get_commit_tree(the_repository, commit),
+		            "", 0, 0, &paths, walk_tree, &walk_tree_ctx);
 	if (!walk_tree_ctx.match)
 		cgit_print_error_page(404, "Not found", "Not found");
 	else if (walk_tree_ctx.match == 2)
diff -pruN 1.2.1+git2.18.0-1/ui-refs.c 1.2.3+git2.25.1-1/ui-refs.c
--- 1.2.1+git2.18.0-1/ui-refs.c	2018-08-03 15:04:03.000000000 +0000
+++ 1.2.3+git2.25.1-1/ui-refs.c	2020-03-13 23:49:52.000000000 +0000
@@ -136,7 +136,7 @@ static int print_tag(struct refinfo *ref
 	return 0;
 }
 
-static void print_refs_link(char *path)
+static void print_refs_link(const char *path)
 {
 	html("<tr class='nohover'><td colspan='5'>");
 	cgit_refs_link("[...]", NULL, NULL, ctx.qry.head, NULL, path);
diff -pruN 1.2.1+git2.18.0-1/ui-repolist.c 1.2.3+git2.25.1-1/ui-repolist.c
--- 1.2.1+git2.18.0-1/ui-repolist.c	2018-08-03 15:04:03.000000000 +0000
+++ 1.2.3+git2.25.1-1/ui-repolist.c	2020-03-13 23:49:52.000000000 +0000
@@ -11,7 +11,7 @@
 #include "html.h"
 #include "ui-shared.h"
 
-static time_t read_agefile(char *path)
+static time_t read_agefile(const char *path)
 {
 	time_t result;
 	size_t size;
@@ -20,7 +20,7 @@ static time_t read_agefile(char *path)
 
 	if (readfile(path, &buf, &size)) {
 		free(buf);
-		return -1;
+		return 0;
 	}
 
 	if (parse_date(buf, &date_buf) == 0)
diff -pruN 1.2.1+git2.18.0-1/ui-shared.c 1.2.3+git2.25.1-1/ui-shared.c
--- 1.2.1+git2.18.0-1/ui-shared.c	2018-08-03 15:04:03.000000000 +0000
+++ 1.2.3+git2.25.1-1/ui-shared.c	2020-03-13 23:49:52.000000000 +0000
@@ -68,15 +68,48 @@ char *cgit_hosturl(void)
 char *cgit_currenturl(void)
 {
 	const char *root = cgit_rooturl();
-	size_t len = strlen(root);
 
 	if (!ctx.qry.url)
 		return xstrdup(root);
-	if (len && root[len - 1] == '/')
+	if (root[0] && root[strlen(root) - 1] == '/')
 		return fmtalloc("%s%s", root, ctx.qry.url);
 	return fmtalloc("%s/%s", root, ctx.qry.url);
 }
 
+char *cgit_currentfullurl(void)
+{
+	const char *root = cgit_rooturl();
+	const char *orig_query = ctx.env.query_string ? ctx.env.query_string : "";
+	size_t len = strlen(orig_query);
+	char *query = xmalloc(len + 2), *start_url, *ret;
+
+	/* Remove all url=... parts from query string */
+	memcpy(query + 1, orig_query, len + 1);
+	query[0] = '?';
+	start_url = query;
+	while ((start_url = strstr(start_url, "url=")) != NULL) {
+		if (start_url[-1] == '?' || start_url[-1] == '&') {
+			const char *end_url = strchr(start_url, '&');
+			if (end_url)
+				memmove(start_url, end_url + 1, strlen(end_url));
+			else
+				start_url[0] = '\0';
+		} else
+			++start_url;
+	}
+	if (!query[1])
+		query[0] = '\0';
+
+	if (!ctx.qry.url)
+		ret = fmtalloc("%s%s", root, query);
+	else if (root[0] && root[strlen(root) - 1] == '/')
+		ret = fmtalloc("%s%s%s", root, ctx.qry.url, query);
+	else
+		ret = fmtalloc("%s/%s%s", root, ctx.qry.url, query);
+	free(query);
+	return ret;
+}
+
 const char *cgit_rooturl(void)
 {
 	if (ctx.cfg.virtual_root)
@@ -912,12 +945,13 @@ static void cgit_print_path_crumbs(char
 {
 	char *old_path = ctx.qry.path;
 	char *p = path, *q, *end = path + strlen(path);
+	int levels = 0;
 
 	ctx.qry.path = NULL;
 	cgit_self_link("root", NULL, NULL);
 	ctx.qry.path = p = path;
 	while (p < end) {
-		if (!(q = strchr(p, '/')))
+		if (!(q = strchr(p, '/')) || levels > 15)
 			q = end;
 		*q = '\0';
 		html_txt("/");
@@ -925,6 +959,7 @@ static void cgit_print_path_crumbs(char
 		if (q < end)
 			*q = '/';
 		p = q + 1;
+		++levels;
 	}
 	ctx.qry.path = old_path;
 }
@@ -1159,31 +1194,17 @@ void cgit_print_snapshot_links(const str
 
 void cgit_set_title_from_path(const char *path)
 {
-	size_t path_len, path_index, path_last_end;
-	char *new_title;
+	struct strbuf sb = STRBUF_INIT;
+	const char *slash, *last_slash;
 
 	if (!path)
 		return;
 
-	path_len = strlen(path);
-	new_title = xmalloc(path_len + 3 + strlen(ctx.page.title) + 1);
-	new_title[0] = '\0';
-
-	for (path_index = path_len, path_last_end = path_len; path_index-- > 0;) {
-		if (path[path_index] == '/') {
-			if (path_index == path_len - 1) {
-				path_last_end = path_index - 1;
-				continue;
-			}
-			strncat(new_title, &path[path_index + 1], path_last_end - path_index - 1);
-			strcat(new_title, "\\");
-			path_last_end = path_index;
-		}
-	}
-	if (path_last_end)
-		strncat(new_title, path, path_last_end);
-
-	strcat(new_title, " - ");
-	strcat(new_title, ctx.page.title);
-	ctx.page.title = new_title;
+	for (last_slash = path + strlen(path); (slash = memrchr(path, '/', last_slash - path)) != NULL; last_slash = slash) {
+		strbuf_add(&sb, slash + 1, last_slash - slash - 1);
+		strbuf_addstr(&sb, " \xc2\xab ");
+	}
+	strbuf_add(&sb, path, last_slash - path);
+	strbuf_addf(&sb, " - %s", ctx.page.title);
+	ctx.page.title = strbuf_detach(&sb, NULL);
 }
diff -pruN 1.2.1+git2.18.0-1/ui-shared.h 1.2.3+git2.25.1-1/ui-shared.h
--- 1.2.1+git2.18.0-1/ui-shared.h	2018-08-03 15:04:03.000000000 +0000
+++ 1.2.3+git2.25.1-1/ui-shared.h	2020-03-13 23:49:52.000000000 +0000
@@ -5,6 +5,7 @@ extern const char *cgit_httpscheme(void)
 extern char *cgit_hosturl(void);
 extern const char *cgit_rooturl(void);
 extern char *cgit_currenturl(void);
+extern char *cgit_currentfullurl(void);
 extern const char *cgit_loginurl(void);
 extern char *cgit_repourl(const char *reponame);
 extern char *cgit_fileurl(const char *reponame, const char *pagename,
diff -pruN 1.2.1+git2.18.0-1/ui-snapshot.c 1.2.3+git2.25.1-1/ui-snapshot.c
--- 1.2.1+git2.18.0-1/ui-snapshot.c	2018-08-03 15:04:03.000000000 +0000
+++ 1.2.3+git2.25.1-1/ui-snapshot.c	2020-03-13 23:49:52.000000000 +0000
@@ -37,7 +37,7 @@ static int write_archive_type(const char
 	/* argv_array guarantees a trailing NULL entry. */
 	memcpy(nargv, argv.argv, sizeof(char *) * (argv.argc + 1));
 
-	result = write_archive(argv.argc, nargv, NULL, NULL, 0);
+	result = write_archive(argv.argc, nargv, NULL, the_repository, NULL, 0);
 	argv_array_clear(&argv);
 	free(nargv);
 	return result;
@@ -79,18 +79,32 @@ static int write_tar_bzip2_archive(const
 	return write_compressed_tar_archive(hex, prefix, argv);
 }
 
+static int write_tar_lzip_archive(const char *hex, const char *prefix)
+{
+	char *argv[] = { "lzip", NULL };
+	return write_compressed_tar_archive(hex, prefix, argv);
+}
+
 static int write_tar_xz_archive(const char *hex, const char *prefix)
 {
 	char *argv[] = { "xz", NULL };
 	return write_compressed_tar_archive(hex, prefix, argv);
 }
 
+static int write_tar_zstd_archive(const char *hex, const char *prefix)
+{
+	char *argv[] = { "zstd", "-T0", NULL };
+	return write_compressed_tar_archive(hex, prefix, argv);
+}
+
 const struct cgit_snapshot_format cgit_snapshot_formats[] = {
 	/* .tar must remain the 0 index */
 	{ ".tar",	"application/x-tar",	write_tar_archive	},
 	{ ".tar.gz",	"application/x-gzip",	write_tar_gzip_archive	},
 	{ ".tar.bz2",	"application/x-bzip2",	write_tar_bzip2_archive	},
+	{ ".tar.lz",	"application/x-lzip",	write_tar_lzip_archive	},
 	{ ".tar.xz",	"application/x-xz",	write_tar_xz_archive	},
+	{ ".tar.zst",	"application/x-zstd",	write_tar_zstd_archive	},
 	{ ".zip",	"application/x-zip",	write_zip_archive	},
 	{ NULL }
 };
@@ -147,7 +161,7 @@ static int make_snapshot(const struct cg
 				"Bad object id: %s", hex);
 		return 1;
 	}
-	if (!lookup_commit_reference(&oid)) {
+	if (!lookup_commit_reference(the_repository, &oid)) {
 		cgit_print_error_page(400, "Bad request",
 				"Not a commit reference: %s", hex);
 		return 1;
@@ -156,6 +170,7 @@ static int make_snapshot(const struct cg
 	ctx.page.mimetype = xstrdup(format->mimetype);
 	ctx.page.filename = xstrdup(filename);
 	cgit_print_http_headers();
+	init_archivers();
 	format->write_func(hex, prefix);
 	return 0;
 }
diff -pruN 1.2.1+git2.18.0-1/ui-ssdiff.c 1.2.3+git2.25.1-1/ui-ssdiff.c
--- 1.2.1+git2.18.0-1/ui-ssdiff.c	2018-08-03 15:04:03.000000000 +0000
+++ 1.2.3+git2.25.1-1/ui-ssdiff.c	2020-03-13 23:49:52.000000000 +0000
@@ -103,8 +103,7 @@ static int line_from_hunk(char *line, ch
 		return 0;
 	len = buf2 - buf1;
 	buf2 = xmalloc(len + 1);
-	strncpy(buf2, buf1, len);
-	buf2[len] = '\0';
+	strlcpy(buf2, buf1, len + 1);
 	res = atoi(buf2);
 	free(buf2);
 	return res;
@@ -118,6 +117,7 @@ static char *replace_tabs(char *line)
 	int n_tabs = 0;
 	int i;
 	char *result;
+	size_t result_len;
 
 	if (linelen == 0) {
 		result = xmalloc(1);
@@ -129,16 +129,19 @@ static char *replace_tabs(char *line)
 		if (line[i] == '\t')
 			n_tabs += 1;
 	}
-	result = xmalloc(linelen + n_tabs * 8 + 1);
+	result_len = linelen + n_tabs * 8;
+	result = xmalloc(result_len + 1);
 	result[0] = '\0';
 
 	for (;;) {
 		cur_buf = strchr(prev_buf, '\t');
 		if (!cur_buf) {
-			strcat(result, prev_buf);
+			linelen = strlen(result);
+			strlcpy(&result[linelen], prev_buf, result_len - linelen + 1);
 			break;
 		} else {
-			strncat(result, prev_buf, cur_buf - prev_buf);
+			linelen = strlen(result);
+			strlcpy(&result[linelen], prev_buf, cur_buf - prev_buf + 1);
 			linelen = strlen(result);
 			memset(&result[linelen], ' ', 8 - (linelen % 8));
 			result[linelen + 8 - (linelen % 8)] = '\0';
@@ -206,11 +209,13 @@ static void print_part_with_lcs(char *cl
 			}
 		} else if (line[i] == lcs[j]) {
 			same = 1;
-			htmlf("</span>");
+			html("</span>");
 			j += 1;
 		}
 		html_txt(c);
 	}
+	if (!same)
+		html("</span>");
 }
 
 static void print_ssdiff_line(char *class,
@@ -235,7 +240,7 @@ static void print_ssdiff_line(char *clas
 		char *fileurl = cgit_fileurl(ctx.repo->url, "tree", old_file->path, id_str);
 		html("<td class='lineno'><a href='");
 		html(fileurl);
-		htmlf("' id='%s'>%s</a>", lineno_str, lineno_str + 1);
+		htmlf("'>%s</a>", lineno_str + 1);
 		html("</td>");
 		htmlf("<td class='%s'>", class);
 		free(fileurl);
@@ -258,7 +263,7 @@ static void print_ssdiff_line(char *clas
 		char *fileurl = cgit_fileurl(ctx.repo->url, "tree", new_file->path, id_str);
 		html("<td class='lineno'><a href='");
 		html(fileurl);
-		htmlf("' id='%s'>%s</a>", lineno_str, lineno_str + 1);
+		htmlf("'>%s</a>", lineno_str + 1);
 		html("</td>");
 		htmlf("<td class='%s'>", class);
 		free(fileurl);
@@ -404,7 +409,7 @@ void cgit_ssdiff_header_begin(void)
 
 void cgit_ssdiff_header_end(void)
 {
-	html("</td><tr>");
+	html("</td></tr>");
 }
 
 void cgit_ssdiff_footer(void)
diff -pruN 1.2.1+git2.18.0-1/ui-stats.c 1.2.3+git2.25.1-1/ui-stats.c
--- 1.2.1+git2.18.0-1/ui-stats.c	2018-08-03 15:04:03.000000000 +0000
+++ 1.2.3+git2.25.1-1/ui-stats.c	2020-03-13 23:49:52.000000000 +0000
@@ -241,7 +241,7 @@ static struct string_list collect_stats(
 	memset(&authors, 0, sizeof(authors));
 	while ((commit = get_revision(&rev)) != NULL) {
 		add_commit(&authors, commit, period);
-		free_commit_buffer(commit);
+		free_commit_buffer(the_repository->parsed_objects, commit);
 		free_commit_list(commit->parents);
 		commit->parents = NULL;
 	}
diff -pruN 1.2.1+git2.18.0-1/ui-summary.c 1.2.3+git2.25.1-1/ui-summary.c
--- 1.2.1+git2.18.0-1/ui-summary.c	2018-08-03 15:04:03.000000000 +0000
+++ 1.2.3+git2.25.1-1/ui-summary.c	2020-03-13 23:49:52.000000000 +0000
@@ -99,7 +99,7 @@ static char* append_readme_path(const ch
 	return full_path;
 }
 
-void cgit_print_repo_readme(char *path)
+void cgit_print_repo_readme(const char *path)
 {
 	char *filename, *ref, *mimetype;
 	int free_filename = 0;
diff -pruN 1.2.1+git2.18.0-1/ui-summary.h 1.2.3+git2.25.1-1/ui-summary.h
--- 1.2.1+git2.18.0-1/ui-summary.h	2018-08-03 15:04:03.000000000 +0000
+++ 1.2.3+git2.25.1-1/ui-summary.h	2020-03-13 23:49:52.000000000 +0000
@@ -2,6 +2,6 @@
 #define UI_SUMMARY_H
 
 extern void cgit_print_summary(void);
-extern void cgit_print_repo_readme(char *path);
+extern void cgit_print_repo_readme(const char *path);
 
 #endif /* UI_SUMMARY_H */
diff -pruN 1.2.1+git2.18.0-1/ui-tag.c 1.2.3+git2.25.1-1/ui-tag.c
--- 1.2.1+git2.18.0-1/ui-tag.c	2018-08-03 15:04:03.000000000 +0000
+++ 1.2.3+git2.25.1-1/ui-tag.c	2020-03-13 23:49:52.000000000 +0000
@@ -53,7 +53,7 @@ void cgit_print_tag(char *revname)
 			"Bad tag reference: %s", revname);
 		goto cleanup;
 	}
-	obj = parse_object(&oid);
+	obj = parse_object(the_repository, &oid);
 	if (!obj) {
 		cgit_print_error_page(500, "Internal server error",
 			"Bad object id: %s", oid_to_hex(&oid));
@@ -63,7 +63,7 @@ void cgit_print_tag(char *revname)
 		struct tag *tag;
 		struct taginfo *info;
 
-		tag = lookup_tag(&oid);
+		tag = lookup_tag(the_repository, &oid);
 		if (!tag || parse_tag(tag) || !(info = cgit_parse_tag(tag))) {
 			cgit_print_error_page(500, "Internal server error",
 				"Bad tag object: %s", revname);
@@ -71,7 +71,7 @@ void cgit_print_tag(char *revname)
 		}
 		cgit_print_layout_start();
 		html("<table class='commit-info'>\n");
-		htmlf("<tr><td>tag name</td><td>");
+		html("<tr><td>tag name</td><td>");
 		html_txt(revname);
 		htmlf(" (%s)</td></tr>\n", oid_to_hex(&oid));
 		if (info->tagger_date > 0) {
@@ -103,7 +103,7 @@ void cgit_print_tag(char *revname)
 	} else {
 		cgit_print_layout_start();
 		html("<table class='commit-info'>\n");
-		htmlf("<tr><td>tag name</td><td>");
+		html("<tr><td>tag name</td><td>");
 		html_txt(revname);
 		html("</td></tr>\n");
 		html("<tr><td>tagged object</td><td class='sha1'>");
diff -pruN 1.2.1+git2.18.0-1/ui-tree.c 1.2.3+git2.25.1-1/ui-tree.c
--- 1.2.1+git2.18.0-1/ui-tree.c	2018-08-03 15:04:03.000000000 +0000
+++ 1.2.3+git2.25.1-1/ui-tree.c	2020-03-13 23:49:52.000000000 +0000
@@ -84,7 +84,7 @@ static void print_binary_buffer(char *bu
 	html("</table>\n");
 }
 
-static void print_object(const struct object_id *oid, char *path, const char *basename, const char *rev)
+static void print_object(const struct object_id *oid, const char *path, const char *basename, const char *rev)
 {
 	enum object_type type;
 	char *buf;
@@ -110,7 +110,7 @@ static void print_object(const struct ob
 	htmlf("blob: %s (", oid_to_hex(oid));
 	cgit_plain_link("plain", NULL, NULL, ctx.qry.head,
 		        rev, path);
-	if (ctx.cfg.enable_blame) {
+	if (ctx.repo->enable_blame) {
 		html(") (");
 		cgit_blame_link("blame", NULL, NULL, ctx.qry.head,
 			        rev, path);
@@ -177,7 +177,7 @@ static void write_tree_link(const struct
 		cgit_tree_link(name, NULL, "ls-dir", ctx.qry.head, rev,
 			       fullpath->buf);
 
-		tree = lookup_tree(&tree_ctx.oid);
+		tree = lookup_tree(the_repository, &tree_ctx.oid);
 		if (!tree)
 			return;
 
@@ -185,8 +185,8 @@ static void write_tree_link(const struct
 		tree_ctx.name = NULL;
 		tree_ctx.count = 0;
 
-		read_tree_recursive(tree, "", 0, 1, &paths, single_tree_cb,
-				    &tree_ctx);
+		read_tree_recursive(the_repository, tree, "", 0, 1,
+			&paths, single_tree_cb, &tree_ctx);
 
 		if (tree_ctx.count != 1)
 			break;
@@ -251,7 +251,7 @@ static int ls_item(const struct object_i
 	if (!S_ISGITLINK(mode))
 		cgit_plain_link("plain", NULL, "button", ctx.qry.head,
 				walk_tree_ctx->curr_rev, fullpath.buf);
-	if (!S_ISDIR(mode) && ctx.cfg.enable_blame)
+	if (!S_ISDIR(mode) && ctx.repo->enable_blame)
 		cgit_blame_link("blame", NULL, "button", ctx.qry.head,
 				walk_tree_ctx->curr_rev, fullpath.buf);
 	html("</td></tr>\n");
@@ -279,7 +279,7 @@ static void ls_tail(void)
 	cgit_print_layout_end();
 }
 
-static void ls_tree(const struct object_id *oid, char *path, struct walk_tree_context *walk_tree_ctx)
+static void ls_tree(const struct object_id *oid, const char *path, struct walk_tree_context *walk_tree_ctx)
 {
 	struct tree *tree;
 	struct pathspec paths = {
@@ -294,7 +294,8 @@ static void ls_tree(const struct object_
 	}
 
 	ls_head();
-	read_tree_recursive(tree, "", 0, 1, &paths, ls_item, walk_tree_ctx);
+	read_tree_recursive(the_repository, tree, "", 0, 1,
+		&paths, ls_item, walk_tree_ctx);
 	ls_tail();
 }
 
@@ -359,7 +360,7 @@ void cgit_print_tree(const char *rev, ch
 			"Invalid revision name: %s", rev);
 		return;
 	}
-	commit = lookup_commit_reference(&oid);
+	commit = lookup_commit_reference(the_repository, &oid);
 	if (!commit || parse_commit(commit)) {
 		cgit_print_error_page(404, "Not found",
 			"Invalid commit reference: %s", rev);
@@ -369,11 +370,14 @@ void cgit_print_tree(const char *rev, ch
 	walk_tree_ctx.curr_rev = xstrdup(rev);
 
 	if (path == NULL) {
-		ls_tree(&commit->maybe_tree->object.oid, NULL, &walk_tree_ctx);
+		ls_tree(get_commit_tree_oid(commit), NULL, &walk_tree_ctx);
 		goto cleanup;
 	}
 
-	read_tree_recursive(commit->maybe_tree, "", 0, 0, &paths, walk_tree, &walk_tree_ctx);
+	read_tree_recursive(the_repository,
+			    repo_get_commit_tree(the_repository, commit),
+			    "", 0, 0,
+			    &paths, walk_tree, &walk_tree_ctx);
 	if (walk_tree_ctx.state == 1)
 		ls_tail();
 	else if (walk_tree_ctx.state == 2)
